-- MySQL dump 10.13  Distrib 5.7.42, for Linux (x86_64)
--
-- Host: localhost    Database: oscom41463493
-- ------------------------------------------------------
-- Server version	5.7.42

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `access_control_list`
--

DROP TABLE IF EXISTS `access_control_list`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `access_control_list` (
  `access_control_list_id` int(11) NOT NULL AUTO_INCREMENT,
  `parent_id` int(11) NOT NULL DEFAULT '0',
  `access_control_list_key` varchar(64) NOT NULL DEFAULT '',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`access_control_list_id`),
  KEY `access_control_list_key` (`access_control_list_key`),
  KEY `parent_id` (`parent_id`)
) ENGINE=InnoDB AUTO_INCREMENT=459 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `access_control_list`
--

LOCK TABLES `access_control_list` WRITE;
/*!40000 ALTER TABLE `access_control_list` DISABLE KEYS */;
INSERT INTO `access_control_list` VALUES (1,0,'BOX_HEADING_CUSTOMERS',0),(2,0,'BOX_HEADING_CATALOG',1),(3,0,'BOX_HEADING_REPORTS',2),(4,0,'BOX_HEADING_MARKETING_TOOLS',3),(5,0,'BOX_HEADING_SEO',4),(6,0,'BOX_HEADING_DESIGN_CONTROLS',5),(7,0,'BOX_HEADING_MODULES',6),(8,0,'BOX_HEADING_ADMINISTRATOR',7),(9,0,'TEXT_SETTINGS',8),(10,1,'BOX_CUSTOMERS_ORDERS',0),(11,1,'BOX_CUSTOMERS_CUSTOMERS',1),(12,1,'BOX_CUSTOMERS_GROUPS',3),(13,2,'BOX_CATALOG_CATEGORIES_PRODUCTS',0),(14,2,'BOX_CATALOG_REVIEWS',2),(16,2,'BOX_CATALOG_CATEGORIES_PRODUCTS_ATTRIBUTES',4),(17,2,'BOX_CATALOG_PROPERTIES',6),(18,49,'BOX_CATALOG_SUPPIERS',15),(19,2,'BOX_CATALOG_EASYPOPULATE',10),(23,3,'BOX_REPORTS_SALES',0),(25,4,'BOX_HEADING_GV_ADMIN',0),(27,4,'BOX_TOOLS_BANNER_MANAGER',2),(28,4,'BOX_CATALOG_SPECIALS',4),(29,4,'BOX_CATALOG_GIVE_AWAY',5),(30,4,'BOX_CATALOG_FEATURED',6),(31,25,'BOX_COUPON_ADMIN',0),(32,25,'BOX_GV_ADMIN_QUEUE',1),(33,25,'BOX_GV_ADMIN_MAIL',2),(34,25,'BOX_GV_ADMIN_SENT',3),(35,5,'BOX_META_TAGS',0),(36,5,'BOX_MARKETING_SITEMAP',1),(38,5,'BOX_HEADING_GOOGLE_ANALYTICS',3),(39,6,'BOX_INFORMATION_MANAGER',0),(40,6,'FILENAME_CMS_MENUS',1),(41,6,'BOX_HEADING_THEMES',2),(42,6,'BOX_TRANSLATION_TEXTS',3),(43,0,'MANAGE_EMAIL_TEMPLATES',903),(44,7,'BOX_MODULES_PAYMENT',0),(45,7,'BOX_MODULES_SHIPPING',1),(46,7,'BOX_MODULES_ORDER_TOTAL',3),(47,0,'MANAGE_MEMBERS',902),(48,8,'BOX_ADMINISTRATOR_BOXES',1),(49,9,'BOX_HEADING_CONFIGURATION',0),(50,9,'BOX_LOCALIZATION_ORDERS_STATUS',1),(51,9,'BOX_HEADING_CACHE_CONTROL',4),(53,9,'BOX_HEADING_FILTERS',7),(54,9,'BOX_HEADING_LOCATION',8),(55,9,'BOX_HEADING_TAXES',9),(56,9,'BOX_HEADING_LOCALIZATION',10),(57,9,'BOX_HEADING_TOOLS',11),(58,9,'BOX_HEADING_LOGGING',13),(59,9,'BOX_HEADING_FEATURES',59),(60,0,'BOX_HEADING_FRONENDS',9),(61,50,'BOX_ORDERS_STATUS_GROUPS',0),(62,50,'BOX_ORDERS_STATUS',1),(63,54,'BOX_TAXES_COUNTRIES',0),(64,54,'BOX_TAXES_ZONES',1),(65,55,'BOX_TAXES_GEO_ZONES',0),(66,55,'BOX_TAXES_TAX_CLASSES',1),(67,55,'BOX_TAXES_TAX_RATES',2),(68,56,'BOX_LOCALIZATION_CURRENCIES',0),(69,56,'BOX_LOCALIZATION_LANGUAGES',1),(70,57,'BOX_TOOLS_BACKUP',0),(71,57,'BOX_TOOLS_SERVER_INFO',1),(72,57,'BOX_TOOLS_CLEANER',4),(73,43,'INSERT_EMAIL_TEMPLATES',73),(74,43,'DELETE_EMAIL_TEMPLATES',74),(75,25,'BOX_VIRTUAL_GIFT_CARD',4),(76,47,'TEXT_DISABLE_USER',76),(77,47,'TEXT_ENABLE_USER',77),(78,57,'BOX_HEADING_WHOS_ONLINE',2),(82,9,'BOX_SETTINGS_BOX_STOCK_INDICATION',2),(83,82,'BOX_SETTINGS_BOX_STOCK_INDICATION_INDICATION',0),(84,82,'BOX_SETTINGS_BOX_STOCK_INDICATION_DELIVERY_TERMS',1),(85,7,'BOX_HEADING_SOCIALS',4),(86,54,'BOX_GEO_ZONES',2),(101,0,'TABLE_HEADING_PRODUCTS',900),(102,101,'IMAGE_EDIT',102),(103,101,'IMAGE_DELETE',103),(104,101,'IMAGE_MOVE',104),(105,101,'IMAGE_COPY_TO',105),(106,101,'IMAGE_COPY_ATTRIBUTES',106),(107,0,'TEXT_CATEGORIES',901),(109,107,'IMAGE_MOVE',109),(110,107,'IMAGE_DELETE',110),(111,102,'TEXT_STATIC',111),(112,102,'TEXT_PRICE_COST_W',112),(113,102,'TEXT_NAME_DESCRIPTION',113),(114,102,'TEXT_MAIN_DETAILS',114),(115,102,'TEXT_ATTR_INVENTORY',115),(116,102,'TAB_IMAGES',116),(117,102,'TEXT_VIDEO',117),(118,102,'TEXT_SIZE_PACKAGING',118),(119,102,'TEXT_SEO',119),(120,102,'TEXT_MARKETING',120),(121,102,'TAB_PROPERTIES',121),(122,102,'TAB_BUNDLES',122),(126,57,'BOX_IP_RESTRICTION',3),(129,16,'TEXT_PRODUCTS_ATTRIBUTES',0),(130,16,'BOX_CATALOG_CATEGORIES_OPTIONS_TEMPLATES',1),(131,3,'BOX_REPORTS_STOCK_COST',3),(135,2,'BOX_CATALOG_PRODUCTS_GROUPS',5),(144,7,'BOX_MODULES_DROPSHIPPING',4),(145,54,'BOX_CITIES',3),(149,2,'BOX_CATALOG_WAREHOUSES',8),(154,47,'TEXT_MANAGE_CHAT',154),(155,4,'BOX_NEWSLETTERS',12),(156,102,'TEXT_PRODUCT_SOAP_CONFIG',156),(162,9,'BOX_LOCALIZATION_XSELL_TYPES',3),(169,8,'BOX_ADMINISTRATOR_MEMBERS',0),(170,6,'BOX_TRANSLATION_EMAIL_TEMPLATES',4),(172,49,'BOX_CONFIGURATION_MYSTORE',0),(173,49,'BOX_CONFIGURATION_MINIMUM_VALUES',1),(174,49,'BOX_CONFIGURATION_MAXIMUM_VALUES',2),(175,49,'BOX_CONFIGURATION_WIDE_SEACH',3),(176,49,'BOX_CONFIGURATION_CUSTOMER_DETAILS',4),(178,49,'BOX_CONFIGURATION_SHIPPING_PACKAGING',7),(179,49,'TEXT_LISTING_PRODUCTS',9),(180,49,'TEXT_STOCK',10),(181,49,'BOX_CONFIGURATION_E_MAIL_OPTIONS',11),(183,49,'BOX_CONFIGURATION_SESSIONS',13),(184,49,'BOX_CONFIGURATION_EDIT_ORDER_SETTINGS',14),(185,49,'BOX_CONFIGURATION_SEO_OPTIONS',16),(187,49,'BOX_CONFIGURATION_BONUS_PROGRAMS',17),(191,8,'BOX_ADMINISTRATOR_MENU',2),(192,49,'BOX_SUPPLIER_SETTINGS',120),(194,50,'BOX_ORDERS_COMMENT_TEMPLATE',1),(199,2,'BOX_CATALOG_SUPPIERS',7),(201,9,'BOX_ADDRESS_FORMATS',17),(202,49,'BOX_SHIPPING_CUSTOMER_DETAILS',5),(203,49,'BOX_BILLING_CUSTOMER_DETAILS',6),(204,50,'BOX_FLAG',2),(205,50,'BOX_MARKER',3),(206,9,'BOX_SETTINGS_ORDERS_PRODUCTS_STATUS',1),(207,206,'BOX_ORDERS_PRODUCTS_STATUS',1),(208,206,'BOX_ORDERS_PRODUCTS_STATUS_MANUAL',2),(209,44,'BOX_MODULES_PAYMENT_ONLINE',1),(210,44,'BOX_MODULES_PAYMENT_OFFLINE',1),(211,7,'BOX_MODULES_LABEL',2),(226,7,'BOX_MODULES_EXTENSIONS',5),(233,9,'BOX_IMAGE_SETTINGS',19),(235,287,'BOX_HEADING_PRINTERS',1),(238,49,'BOX_TWO_STEP_AUTH_INTERVAL',22),(240,0,'BOX_HEADING_INSTALL',10),(242,102,'TAB_NOTES',0),(247,127,'BOX_CATALOG_PRODUCTDESIGNER_TEMPLATE',0),(248,127,'BOX_CATALOG_PRODUCTDESIGNER_GROUP',1),(249,127,'BOX_CATALOG_PRODUCTDESIGNER_ITEM',1),(262,49,'BOX_CONFIGURATION_LOGGING',25),(269,49,'BOX_CONFIGURATION_CACHE',32),(270,49,'BOX_CONFIGURATION_DOWNLOAD',33),(272,49,'BOX_CONFIGURATION_PANEL',35),(280,49,'BOX_CONFIGURATION_TRASH',43),(281,49,'BOX_CONFIGURATION_ONEPAGE_CHECKOUT',44),(287,9,'BOX_GOOGLE_SETTINGS',21),(288,287,'BOX_GOOGLE_MAIN_SETTINGS',0),(291,9,'BOX_HEADING_FEATURED_TYPES',22),(292,9,'BOX_HEADING_SPECIALS_TAGS',23),(293,54,'BOX_POSTAL_CODES',4),(294,0,'ACL_ORDER',999),(295,294,'IMAGE_NEW',1),(297,294,'IMAGE_DELETE',3),(298,294,'IMAGE_TRANSACTIONS',4),(300,294,'IMAGE_HOLD_ON',6),(301,294,'TEXT_SEND_CUSTOMER_REQUEST',7),(302,294,'IMAGE_EDIT_PRODUCT',8),(303,294,'HEADER_ADD_TOTAL_ELEMENT',9),(304,294,'IMAGE_EDIT_PAID',10),(305,294,'TEXT_ORDER_OWNER',11),(306,49,'BOX_CONFIGURATION_ADMIN',46),(307,10,'RULE_ALLOW_WAREHOUSES',1),(308,10,'RULE_ALLOW_SUPPLIERS',2),(309,0,'TEXT_DASHBOARD',1000),(310,309,'WIDGET_SALESSUMMARY',1),(311,309,'WIDGET_NEWORDERS',2),(312,309,'WIDGET_SALESGRAPH',3),(313,309,'WIDGET_GOOGLEMAPS',4),(314,11,'TEXT_GDPR',1),(315,294,'IMAGE_REASSIGN',12),(316,294,'TEXT_INVOICE',13),(317,294,'IMAGE_ORDERS_PACKINGSLIP',14),(318,294,'TEXT_PRINT_LABEL',15),(319,0,'ACL_CUSTORER',997),(320,319,'IMAGE_NEW',1),(322,319,'IMAGE_DELETE',3),(323,319,'T_UPDATE_PASS',4),(324,319,'T_SEND_COUPON',5),(325,319,'TEXT_MERGE_CUSTOMER',6),(326,3,'BOX_DELETED_ORDERS',120),(330,7,'BOX_MODULES_CONNECTORS',50),(344,0,'TEXT_LABEL_BRAND',0),(350,0,'SUPERUSER',-1),(360,102,'TAB_IMPORT_EXPORT',167),(362,1,'BOX_CUSTOMERS_CUSTOMERS_INACTIVE',2),(367,344,'IMAGE_DELETE',0),(371,294,'TEXT_ALL_UNSAVED_CARTS',16),(372,294,'TEXT_UNSAVED_CARTS',0),(374,57,'BOX_SIC_CREATE',1000),(375,45,'BOX_MODULES_SHIPPING_ONLINE',1),(376,45,'BOX_MODULES_SHIPPING_OFFLINE',2),(398,330,'BOX_MODULES_CONNECTORS_OSCLINK',5),(445,319,'IMAGE_EDIT',0),(446,107,'IMAGE_EDIT',0),(447,344,'IMAGE_EDIT',0),(452,0,'TEXT_GDPR',0),(453,294,'IMAGE_EDIT',0),(454,240,'TEXT_APPLY_FOR_ALL',1),(455,57,'BOX_ERROR_LOG_VIEWER',6),(456,1,'BOX_CUSTOMERS_TMP_ORDERS',4),(457,0,'FILE_UPLOAD',0),(458,319,'T_SUPER_LOGIN',7);
/*!40000 ALTER TABLE `access_control_list` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `access_levels`
--

DROP TABLE IF EXISTS `access_levels`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `access_levels` (
  `access_levels_id` int(11) NOT NULL AUTO_INCREMENT,
  `access_levels_name` varchar(64) NOT NULL DEFAULT '',
  `access_levels_persmissions` text NOT NULL,
  `messages` tinyint(1) NOT NULL DEFAULT '1',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`access_levels_id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `access_levels`
--

LOCK TABLES `access_levels` WRITE;
/*!40000 ALTER TABLE `access_levels` DISABLE KEYS */;
INSERT INTO `access_levels` VALUES (1,'TOP Administrator','350,1,10,307,308,11,314,362,12,344,367,447,2,13,199,14,16,129,130,135,17,149,19,3,23,131,326,4,25,31,32,33,34,75,27,28,29,30,155,5,35,36,38,6,39,40,41,42,170,7,44,209,210,45,375,376,211,46,85,144,226,330,398,8,169,48,191,9,49,172,173,174,175,176,202,203,178,179,180,181,183,184,18,185,187,238,262,269,270,272,280,281,306,192,206,207,208,50,61,62,194,204,205,82,83,84,162,51,53,54,63,64,86,145,293,55,65,66,67,56,68,69,57,70,71,78,126,72,374,58,201,233,287,288,235,291,59,292,60,240,101,102,242,111,112,113,114,115,116,117,118,119,120,121,122,156,360,103,104,105,106,107,446,109,110,47,76,77,154,43,73,74,319,445,320,322,323,324,325,294,453,372,295,297,298,300,301,302,303,304,305,315,316,317,318,371,309,310,311,312,313,454,455,456,457,458',1,0);
/*!40000 ALTER TABLE `access_levels` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `address_book`
--

DROP TABLE IF EXISTS `address_book`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `address_book` (
  `address_book_id` int(11) NOT NULL AUTO_INCREMENT,
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `entry_gender` char(4) NOT NULL DEFAULT '',
  `entry_company` varchar(32) DEFAULT NULL,
  `entry_firstname` varchar(32) NOT NULL DEFAULT '',
  `entry_lastname` varchar(32) NOT NULL DEFAULT '',
  `entry_street_address` varchar(64) NOT NULL DEFAULT '',
  `entry_suburb` varchar(32) DEFAULT NULL,
  `entry_postcode` varchar(10) NOT NULL DEFAULT '',
  `entry_city` varchar(32) NOT NULL DEFAULT '',
  `entry_state` varchar(32) DEFAULT NULL,
  `entry_country_id` int(11) NOT NULL DEFAULT '0',
  `entry_zone_id` int(11) NOT NULL DEFAULT '0',
  `entry_company_vat` varchar(128) NOT NULL DEFAULT '',
  `entry_telephone` varchar(32) NOT NULL DEFAULT '',
  `_api_time_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `entry_company_vat_date` date DEFAULT NULL,
  `entry_company_vat_status` int(4) NOT NULL DEFAULT '0',
  `entry_customs_number` varchar(50) DEFAULT NULL,
  `entry_customs_number_status` int(1) NOT NULL DEFAULT '0',
  `entry_customs_number_date` date DEFAULT NULL,
  `entry_email_address` varchar(96) NOT NULL DEFAULT '',
  `drop_ship` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`address_book_id`),
  KEY `idx_address_book_customers_id` (`customers_id`)
) ENGINE=InnoDB AUTO_INCREMENT=53 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `address_book`
--

LOCK TABLES `address_book` WRITE;
/*!40000 ALTER TABLE `address_book` DISABLE KEYS */;
INSERT INTO `address_book` VALUES (1,1,'','','Abraham','Dalton','A205, Castle Exchange','41 Broad Street','NG1 3AP','Nottingham','',222,220,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(2,2,'','','Mandy','Cross','30A Ospringe Road','','NW5 2JB','London','',222,243,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(3,3,'','','Christian','Fairbairn','8 Lucky Lane','','EX2 4UJ','Exeter','',222,195,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(4,4,'','','Delmar','Masters','4 Serpells Meadow','Polyphant','PL15 7PR','Launceston','',222,192,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(5,5,'','','Priscilla','Platt','Greek Orthodox Church','3 Recorder Road','NR1 1NR','Norwich','',222,216,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(6,6,'','','Grover','O\'Shaughnessy','Gowanlea','14 Needless Road','PH2 0LE','Perth','Perth and Kinross',222,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(7,7,'','','Laurie','O’Shea','Strathdonan','High Street','IV30 1QP','Elgin','',222,261,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(8,8,'','','Carol','Tailor','2 Ffordd Dorfil','','LL41 3YH','Blaenau Ffestiniog','',222,283,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(9,9,'','','Jeffrey','MacKay','7 Meadow Road','','SY7 9QY','Craven Arms','',222,223,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(10,10,'','','Lester','Rake','7 Dillwyn Street','','SA15 1BT','Llanelli','Sir Gaerfyrddin',222,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(11,11,'','','Marcus','Snider','48 Coventry Street','','CV47 0EP','Southam','',222,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(12,12,'','','Jason','dinAlt','100 E Jefferson St','','40422','Danville','',223,27,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(13,13,'','','Philip','Miller','36111','','3463 Manch','Montgomery','',223,1,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(14,14,'','','Todd','Walker','2601 Gladlane Dr','','36111','Montgomery','',223,1,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(15,15,'','','Anabella','Lopez','1522 Woodlawn Ave','','46203','Indianapolis','',223,24,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(16,16,'','','Dolores','Gutierrez','7035 SE Gladstone St','','97206','Portland','',223,49,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(17,17,'','','Forrest','Parker','18234 Poplar Rd','','33967','Fort Myers','',223,18,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(18,18,'','','Grace','Wilson','601 Mill Ave','','R0C 0A0','Arborg','',38,68,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(19,19,'','','Madison','Tremblay','169 Brebeuf Crescent','','T9K 1W6','Fort McMurray','',38,66,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(20,20,'','','Daan','De Vries','Duurstedelaan 106','','3525 AT','Utrecht','Utrecht',150,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(21,21,'','','Lotte','Van Dijk','Jan Steenstraat 24','','3817 PJ','Amersfoort','Utrecht',150,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(22,22,'','','Ulrich','Stellmacher','Richard-Lehmann-Straße 33','','04275','Leipzig','Saxony',81,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(23,23,'','','Brunhild','Kruger','Inselstraße 6','','39418','Staßfurt','Saxony-Anhalt',81,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(24,24,'','','Carlos','Esteban','Calle San José, 7B','','23003','Jaén','',195,155,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(25,25,'','','Maria Jose','Velazquez','Calle Alegría, 12','','33209','Gijón','',195,135,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(26,26,'','','Vassilios','Vassiliadis','Evripidou 29','','241 00','Kalamata','Peloponnese',84,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(27,27,'','','Maria','Gonzalez','R. Duque de Caxias','1 - Santa Terezinha','77808-390','Araguaína','Tocantins',30,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(28,28,'','','Alice','Silva','Estados Unidos 3359','','C1228ABG C','Buenos Aires','',10,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(29,29,'','','Matias','Gomes','Nicaragua 2260','','11800','Montevideo','Montevideo',225,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(30,30,'','','Sebastian','Pereira','Jirón Vizcardo y Guzmán 394','','Lima 15034','Lima','Lima',167,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(31,31,'','','Sophia','Fernandes','Carrera 9b #10-2','','10-114','Popayán','Cauca',47,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(32,32,'','','Isidora','Ruiz','U.E. Monseñor Nicolas Navarro','','6001','Barcelona','Anzoátegui',229,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(33,33,'','','Kamila','Garcia','Paseo Carlos Lopez','','0710','Las Tablas','Los Santos',164,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(34,34,'','','Drishya','Kulkarni','Éndrejksari Nagar','','516360','Proddatur','Andhra Pradesh',99,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(35,35,'','','Classen','Tasnim','7 Joseph Nduli St','','4001','Durban','KwaZulu-Natal',193,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(36,36,'','','Zanldi','Erasmus','24 Mooney St','','6506','Mossel Bay','Western Cape',193,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(37,37,'','','Yair','Ramon','Ge\'ula St 27','','33197','Haifa','',104,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(38,38,'','','Banafrit','Elmanhaly','30, Rue Ahmed Orabi','Al-Mohandessine','12411','GIZA','GIZA',63,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(39,38,'','','Banafrit','Elmanhaly','30، غم و اندوه احمد','آل مهندسین','12411','جیزه','جیزه',63,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(40,39,'','','Fadwa','Toukan','Habitat Abou Nosseir Ruelle 5','Al Mohazab Al Halabi 27¨CT-T2','11937','Amman',' Amman Governorate',108,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(41,39,'','','Fadwa','Toukan','5 آل احزاب آل حلبی ','27 جتی-تی2 آل احزاب آل حلبی','11937','امان','عمان) استان)',108,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(42,40,'','','Daniel','Jensen','2-3 Bowman St','','5264','Meningie','South Australia',13,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(43,41,'','','Slim','Harris','3 Island View Cres','','5211','Encounter Bay','South Australia',13,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(44,42,'','','Kate','Kelly','LOT 108 Magpie Rise','','6338','Bremer Bay','Western Australia',13,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(45,43,'','','Li','Chong','184 Ban Qiao Lu','','225700','Xinghua Shi','Jiangsu Sheng',44,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(46,44,'','','Tan','Mok','Huang He Zhong Lu','','466000','Chuanhui Qu','Henan Sheng',44,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(47,45,'','','Chan','Ngiem','1 Yong An Lu','','443700','Xingshan Xian','Hubei Sheng',44,0,'','','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(48,46,'','','Tsuguho','Kawahara','86 Park Avenue','','IV27 0XS','LAXFORD BRIDGE','',222,315,'','123','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(49,47,'','','Hirari','Senda','10 Hull Road','','BB12 5YD','PADIHAM','',222,201,'','1234567890','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(50,47,'','','12','34','9101112','','5678','131415','',222,304,'','54564654','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(51,48,'','','Uki-chan','Kawahara-chan','414 Peachfield Road','','SU9 4SC','CELLARHEADS','',222,304,'','2 Billing','[[regtime]]',NULL,0,NULL,0,NULL,'',0),(52,48,'','','Uki','Kawahara','41 Peachfield Road','','ST9 4SB','CELLARHEAD','',222,237,'','1 Shipping','[[regtime]]',NULL,0,NULL,0,NULL,'',0);
/*!40000 ALTER TABLE `address_book` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `address_format`
--

DROP TABLE IF EXISTS `address_format`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `address_format` (
  `address_format_id` int(11) NOT NULL AUTO_INCREMENT,
  `address_format` varchar(255) NOT NULL DEFAULT '',
  `address_summary` varchar(48) NOT NULL DEFAULT '',
  `address_format_title` varchar(64) DEFAULT NULL,
  PRIMARY KEY (`address_format_id`)
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `address_format`
--

LOCK TABLES `address_format` WRITE;
/*!40000 ALTER TABLE `address_format` DISABLE KEYS */;
INSERT INTO `address_format` VALUES (1,'[[\"company\",\"reg_number\"],[\"firstname\",\"lastname\"],[\"street_address\",\"suburb\"],[\"postcode\",\"city\"],[\"state\",\"country\"],[\"telephone\"]]','$city / $country','Untitled Format 1'),(2,'[[\"company\",\"reg_number\"],[\"firstname\",\"lastname\"],[\"street_address\",\"suburb\"],[\"postcode\",\"city\",\"state\"],[\"country\"],[\"telephone\"]]','$city, $state / $country','Untitled Format 2'),(3,'[[\"company\",\"reg_number\"],[\"firstname\",\"lastname\"],[\"street_address\",\"suburb\"],[\"city\"],[\"postcode\",\"state\",\"country\"],[\"telephone\"]]','$state / $country','Untitled Format 3'),(4,'[[\"company\",\"reg_number\"],[\"firstname\",\"lastname\"],[\"street_address\",\"suburb\"],[\"postcode\",\"city\"],[\"country\"],[\"telephone\"]]','$postcode / $country','Untitled Format 4'),(5,'[[\"company\",\"reg_number\"],[\"firstname\",\"lastname\"],[\"street_address\",\"suburb\"],[\"postcode\",\"city\"],[\"country\"],[\"telephone\"]]','$city / $country','Untitled Format 5'),(6,'[[\"company\",\"reg_number\"],[\"firstname\",\"lastname\"],[\"street_address\",\"suburb\"],[\"state\",\"city\"],[\"postcode\"],[\"country\"],[\"telephone\"]]','$city / $country','Untitled Format 6');
/*!40000 ALTER TABLE `address_format` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin`
--

DROP TABLE IF EXISTS `admin`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin` (
  `admin_id` int(11) NOT NULL AUTO_INCREMENT,
  `admin_groups_id` int(11) DEFAULT NULL,
  `admin_firstname` varchar(32) NOT NULL DEFAULT '',
  `admin_lastname` varchar(32) DEFAULT NULL,
  `admin_email_address` varchar(96) NOT NULL DEFAULT '',
  `admin_email_token` varchar(255) NOT NULL DEFAULT '',
  `admin_phone_number` varchar(32) NOT NULL DEFAULT '',
  `admin_password` varchar(255) NOT NULL,
  `admin_two_step_auth` varchar(16) NOT NULL DEFAULT '',
  `admin_created` datetime DEFAULT NULL,
  `admin_modified` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `admin_logdate` datetime DEFAULT NULL,
  `admin_lognum` int(11) NOT NULL DEFAULT '0',
  `individual_id` varchar(32) NOT NULL DEFAULT '',
  `avatar` varchar(255) NOT NULL DEFAULT '',
  `login_failture` int(11) NOT NULL DEFAULT '0',
  `login_failture_ip` varchar(32) DEFAULT NULL,
  `login_failture_date` datetime DEFAULT NULL,
  `access_levels_id` int(11) NOT NULL DEFAULT '0',
  `admin_persmissions` text,
  `additional_info` text NOT NULL,
  `reset_ip` varchar(32) DEFAULT NULL,
  `reset_date` datetime DEFAULT NULL,
  `languages` varchar(2) NOT NULL DEFAULT 'en',
  `admin_username` varchar(64) NOT NULL DEFAULT '',
  `pin` varchar(8) DEFAULT NULL,
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `device_hash` varchar(32) NOT NULL DEFAULT '',
  `pos_platform_id` int(11) NOT NULL DEFAULT '0',
  `pos_currency_id` int(11) NOT NULL DEFAULT '0',
  `frontend_translation` int(2) NOT NULL DEFAULT '0',
  `password_last_update` datetime DEFAULT NULL,
  `token` varchar(255) NOT NULL DEFAULT '',
  `token_date` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `disposable` int(1) NOT NULL DEFAULT '0',
  `storage_key` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`admin_id`),
  UNIQUE KEY `admin_email_address` (`admin_email_address`),
  KEY `pos_platform_id` (`pos_platform_id`),
  KEY `pos_currency_id` (`pos_currency_id`),
  KEY `admin_device_hash_idx` (`device_hash`)
) ENGINE=InnoDB AUTO_INCREMENT=91 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin`
--

LOCK TABLES `admin` WRITE;
/*!40000 ALTER TABLE `admin` DISABLE KEYS */;
INSERT INTO `admin` VALUES (28,NULL,'[[admin_fname]]','[[admin_lname]]','[[admin_email]]','[[admin_email_token]]','','[[admin_pass]]','','[[regtime]]','[[regtime]]',NULL,0,'','',0,'',NULL,1,NULL,'a:3:{s:14:\"shown_language\";a:11:{i:20;i:1;i:29;i:17;i:30;i:15;i:31;s:1:\"3\";i:32;s:2:\"10\";i:33;s:2:\"11\";i:34;s:2:\"12\";i:35;s:2:\"13\";i:36;s:2:\"26\";i:37;s:2:\"28\";i:38;s:2:\"29\";}s:19:\"searchable_language\";a:11:{i:0;i:3;i:1;s:1:\"1\";i:2;s:2:\"15\";i:3;s:2:\"12\";i:4;s:2:\"10\";i:5;s:2:\"11\";i:6;s:2:\"13\";i:7;s:2:\"17\";i:8;s:2:\"26\";i:9;s:2:\"29\";i:10;s:2:\"28\";}s:10:\"key_entity\";a:2:{i:3;i:0;i:4;s:1:\"1\";}}','','2017-12-05 14:58:42','en','[[admin_username]]',NULL,0,'',0,0,0,NULL,'','0000-00-00 00:00:00',0,'');
/*!40000 ALTER TABLE `admin` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_boxes`
--

DROP TABLE IF EXISTS `admin_boxes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_boxes` (
  `box_id` int(11) NOT NULL AUTO_INCREMENT,
  `parent_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `acl_check` varchar(255) NOT NULL DEFAULT '',
  `config_check` varchar(255) NOT NULL DEFAULT '',
  `box_type` int(4) NOT NULL DEFAULT '0',
  `path` varchar(255) NOT NULL DEFAULT '',
  `title` varchar(255) NOT NULL DEFAULT '',
  `filename` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`box_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_boxes`
--

LOCK TABLES `admin_boxes` WRITE;
/*!40000 ALTER TABLE `admin_boxes` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_boxes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_device`
--

DROP TABLE IF EXISTS `admin_device`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_device` (
  `ad_device_id` varchar(32) COLLATE utf8_unicode_ci NOT NULL,
  `ad_admin_id` int(11) NOT NULL,
  `ad_date_login` datetime DEFAULT NULL,
  `ad_login_count` int(10) unsigned NOT NULL DEFAULT '0',
  `ad_date_add` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `ad_is_blocked` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`ad_device_id`,`ad_admin_id`),
  KEY `ad_device_id` (`ad_device_id`),
  KEY `ad_admin_id` (`ad_admin_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_device`
--

LOCK TABLES `admin_device` WRITE;
/*!40000 ALTER TABLE `admin_device` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_device` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_filters`
--

DROP TABLE IF EXISTS `admin_filters`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_filters` (
  `filter_type` varchar(32) NOT NULL,
  `filter_data` text,
  PRIMARY KEY (`filter_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_filters`
--

LOCK TABLES `admin_filters` WRITE;
/*!40000 ALTER TABLE `admin_filters` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_filters` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_login`
--

DROP TABLE IF EXISTS `admin_login`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_login` (
  `al_admin_id` int(11) NOT NULL,
  `al_computer_id` varchar(32) COLLATE utf8_unicode_ci NOT NULL,
  `al_security_key` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `al_expire` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `al_create` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`al_admin_id`,`al_computer_id`),
  KEY `al_admin_id` (`al_admin_id`),
  KEY `al_computer_id` (`al_computer_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_login`
--

LOCK TABLES `admin_login` WRITE;
/*!40000 ALTER TABLE `admin_login` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_login` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_login_expire`
--

DROP TABLE IF EXISTS `admin_login_expire`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_login_expire` (
  `ale_id` int(10) unsigned NOT NULL,
  `ale_language_id` int(10) unsigned NOT NULL,
  `ale_title` varchar(64) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `ale_expire_minutes` int(10) unsigned NOT NULL DEFAULT '0',
  `ale_order` tinyint(3) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`ale_id`,`ale_language_id`),
  KEY `ale_id` (`ale_id`),
  KEY `ale_language_id` (`ale_language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_login_expire`
--

LOCK TABLES `admin_login_expire` WRITE;
/*!40000 ALTER TABLE `admin_login_expire` DISABLE KEYS */;
INSERT INTO `admin_login_expire` VALUES (1,1,'One session',0,1),(1,3,'One session',0,1),(1,10,'One session',0,1),(1,11,'One session',0,1),(1,12,'One session',0,1),(1,13,'One session',0,1),(1,15,'One session',0,1),(1,17,'One session',0,1),(1,26,'One session',0,1),(1,28,'One session',0,1),(1,29,'One session',0,1),(2,1,'3 hours',180,2),(2,3,'3 hours',180,2),(2,10,'3 hours',180,2),(2,11,'3 hours',180,2),(2,12,'3 hours',180,2),(2,13,'3 hours',180,2),(2,15,'3 hours',180,2),(2,17,'3 hours',180,2),(2,26,'3 hours',180,2),(2,28,'3 hours',180,2),(2,29,'3 hours',180,2),(3,1,'6 hours',360,3),(3,3,'6 hours',360,3),(3,10,'6 hours',360,3),(3,11,'6 hours',360,3),(3,12,'6 hours',360,3),(3,13,'6 hours',360,3),(3,15,'6 hours',360,3),(3,17,'6 hours',360,3),(3,26,'6 hours',360,3),(3,28,'6 hours',360,3),(3,29,'6 hours',360,3),(4,1,'10 hours',600,4),(4,3,'10 hours',600,4),(4,10,'10 hours',600,4),(4,11,'10 hours',600,4),(4,12,'10 hours',600,4),(4,13,'10 hours',600,4),(4,15,'10 hours',600,4),(4,17,'10 hours',600,4),(4,26,'10 hours',600,4),(4,28,'10 hours',600,4),(4,29,'10 hours',600,4),(5,1,'1 week',10080,5),(5,3,'1 week',10080,5),(5,10,'1 week',10080,5),(5,11,'1 week',10080,5),(5,12,'1 week',10080,5),(5,13,'1 week',10080,5),(5,15,'1 week',10080,5),(5,17,'1 week',10080,5),(5,26,'1 week',10080,5),(5,28,'1 week',10080,5),(5,29,'1 week',10080,5),(6,1,'1 month',43200,6),(6,3,'1 month',43200,6),(6,10,'1 month',43200,6),(6,11,'1 month',43200,6),(6,12,'1 month',43200,6),(6,13,'1 month',43200,6),(6,15,'1 month',43200,6),(6,17,'1 month',43200,6),(6,26,'1 month',43200,6),(6,28,'1 month',43200,6),(6,29,'1 month',43200,6);
/*!40000 ALTER TABLE `admin_login_expire` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_login_log`
--

DROP TABLE IF EXISTS `admin_login_log`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_login_log` (
  `all_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `all_event` tinyint(1) NOT NULL DEFAULT '0',
  `all_device_id` varchar(32) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `all_ip` varchar(45) COLLATE utf8_unicode_ci DEFAULT NULL,
  `all_agent` text COLLATE utf8_unicode_ci NOT NULL,
  `all_user` varchar(64) COLLATE utf8_unicode_ci DEFAULT NULL,
  `all_date` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `all_user_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`all_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_login_log`
--

LOCK TABLES `admin_login_log` WRITE;
/*!40000 ALTER TABLE `admin_login_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_login_log` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_login_session`
--

DROP TABLE IF EXISTS `admin_login_session`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_login_session` (
  `als_admin_id` int(11) NOT NULL,
  `als_device_id` varchar(32) COLLATE utf8_unicode_ci NOT NULL,
  `als_date_activity` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `als_date_login` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`als_admin_id`,`als_device_id`),
  KEY `als_admin_id` (`als_admin_id`),
  KEY `als_device_id` (`als_device_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_login_session`
--

LOCK TABLES `admin_login_session` WRITE;
/*!40000 ALTER TABLE `admin_login_session` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_login_session` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_login_session_logoff`
--

DROP TABLE IF EXISTS `admin_login_session_logoff`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_login_session_logoff` (
  `alsl_hash` varchar(32) COLLATE utf8_unicode_ci NOT NULL,
  `alsl_admin_id` int(11) NOT NULL DEFAULT '0',
  `alsl_device_id` varchar(32) COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `alsl_date_expire` datetime DEFAULT NULL,
  PRIMARY KEY (`alsl_hash`),
  KEY `alsl_admin_id` (`alsl_admin_id`),
  KEY `alsl_device_id` (`alsl_device_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_login_session_logoff`
--

LOCK TABLES `admin_login_session_logoff` WRITE;
/*!40000 ALTER TABLE `admin_login_session_logoff` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_login_session_logoff` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_messages`
--

DROP TABLE IF EXISTS `admin_messages`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_messages` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `class` varchar(255) DEFAULT NULL,
  `message` text,
  `status` varchar(64) DEFAULT NULL,
  `type` varchar(32) DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_messages`
--

LOCK TABLES `admin_messages` WRITE;
/*!40000 ALTER TABLE `admin_messages` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_messages` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_old_passwords`
--

DROP TABLE IF EXISTS `admin_old_passwords`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_old_passwords` (
  `pass_id` int(11) NOT NULL AUTO_INCREMENT,
  `admin_id` int(11) NOT NULL DEFAULT '0',
  `password` varchar(255) NOT NULL,
  `date_added` datetime DEFAULT NULL,
  PRIMARY KEY (`pass_id`),
  KEY `idx_op` (`admin_id`,`pass_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_old_passwords`
--

LOCK TABLES `admin_old_passwords` WRITE;
/*!40000 ALTER TABLE `admin_old_passwords` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_old_passwords` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_password_forgot_log`
--

DROP TABLE IF EXISTS `admin_password_forgot_log`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_password_forgot_log` (
  `apflDeviceId` varchar(64) NOT NULL,
  `apflDateCreate` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`apflDeviceId`,`apflDateCreate`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_password_forgot_log`
--

LOCK TABLES `admin_password_forgot_log` WRITE;
/*!40000 ALTER TABLE `admin_password_forgot_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_password_forgot_log` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_platforms`
--

DROP TABLE IF EXISTS `admin_platforms`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_platforms` (
  `admin_id` int(11) NOT NULL,
  `platform_id` int(11) NOT NULL,
  PRIMARY KEY (`admin_id`,`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_platforms`
--

LOCK TABLES `admin_platforms` WRITE;
/*!40000 ALTER TABLE `admin_platforms` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_platforms` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_shopping_carts`
--

DROP TABLE IF EXISTS `admin_shopping_carts`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_shopping_carts` (
  `admin_id` int(11) NOT NULL,
  `basket_id` int(11) NOT NULL,
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `order_id` int(11) NOT NULL DEFAULT '0',
  `status` int(11) NOT NULL DEFAULT '0',
  `customer_basket` blob NOT NULL,
  `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `cart_type` varchar(10) NOT NULL DEFAULT '',
  `checkout_details` blob NOT NULL,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`admin_id`,`basket_id`,`customers_id`),
  KEY `admin_id` (`admin_id`),
  KEY `idx_ascs_platform_id` (`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_shopping_carts`
--

LOCK TABLES `admin_shopping_carts` WRITE;
/*!40000 ALTER TABLE `admin_shopping_carts` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_shopping_carts` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_suppliers`
--

DROP TABLE IF EXISTS `admin_suppliers`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_suppliers` (
  `admin_id` int(11) NOT NULL,
  `suppliers_id` int(11) NOT NULL,
  PRIMARY KEY (`admin_id`,`suppliers_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_suppliers`
--

LOCK TABLES `admin_suppliers` WRITE;
/*!40000 ALTER TABLE `admin_suppliers` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_suppliers` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_templates`
--

DROP TABLE IF EXISTS `admin_templates`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_templates` (
  `admin_template_id` int(11) NOT NULL AUTO_INCREMENT,
  `access_levels_id` int(11) NOT NULL DEFAULT '0',
  `page` varchar(255) DEFAULT NULL,
  `template` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`admin_template_id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_templates`
--

LOCK TABLES `admin_templates` WRITE;
/*!40000 ALTER TABLE `admin_templates` DISABLE KEYS */;
INSERT INTO `admin_templates` VALUES (1,1,'backendOrder','');
/*!40000 ALTER TABLE `admin_templates` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `admin_warehouses`
--

DROP TABLE IF EXISTS `admin_warehouses`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `admin_warehouses` (
  `admin_id` int(11) NOT NULL,
  `warehouse_id` int(11) NOT NULL,
  PRIMARY KEY (`admin_id`,`warehouse_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `admin_warehouses`
--

LOCK TABLES `admin_warehouses` WRITE;
/*!40000 ALTER TABLE `admin_warehouses` DISABLE KEYS */;
/*!40000 ALTER TABLE `admin_warehouses` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `amazon_payment_orders`
--

DROP TABLE IF EXISTS `amazon_payment_orders`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `amazon_payment_orders` (
  `amazon_order_id` varchar(64) NOT NULL DEFAULT '',
  `amazon_status` varchar(64) NOT NULL DEFAULT '',
  `amazon_auth_id` varchar(64) NOT NULL DEFAULT '',
  `amazon_auth_status` varchar(64) NOT NULL DEFAULT '',
  `amazon_capture_id` varchar(64) NOT NULL DEFAULT '',
  `amazon_capture_status` varchar(64) NOT NULL DEFAULT '',
  `amazon_refund_id` varchar(64) NOT NULL DEFAULT '',
  `amazon_refund_status` varchar(64) NOT NULL DEFAULT '',
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `cart` text,
  `custom_data` text,
  `address_full` tinyint(1) NOT NULL DEFAULT '0',
  `amazon_ack` tinyint(1) NOT NULL DEFAULT '0',
  `amazon_ack_sendtime` datetime DEFAULT NULL,
  `date_created` datetime DEFAULT NULL,
  PRIMARY KEY (`amazon_order_id`),
  KEY `orders_id` (`orders_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `amazon_payment_orders`
--

LOCK TABLES `amazon_payment_orders` WRITE;
/*!40000 ALTER TABLE `amazon_payment_orders` DISABLE KEYS */;
/*!40000 ALTER TABLE `amazon_payment_orders` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `banners`
--

DROP TABLE IF EXISTS `banners`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `banners` (
  `banners_id` int(11) NOT NULL AUTO_INCREMENT,
  `group_id` int(1) NOT NULL DEFAULT '0',
  `expires_impressions` int(7) DEFAULT '0',
  `expires_date` datetime DEFAULT NULL,
  `date_scheduled` datetime DEFAULT NULL,
  `date_added` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `date_status_change` datetime DEFAULT NULL,
  `status` int(1) NOT NULL DEFAULT '1',
  `affiliate_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(7) NOT NULL DEFAULT '0',
  `banner_type` varchar(255) NOT NULL DEFAULT '',
  `nofollow` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`banners_id`)
) ENGINE=InnoDB AUTO_INCREMENT=247 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `banners`
--

LOCK TABLES `banners` WRITE;
/*!40000 ALTER TABLE `banners` DISABLE KEYS */;
INSERT INTO `banners` VALUES (41,1,0,NULL,NULL,'2016-10-17 17:06:32','2023-03-01 11:55:13',1,0,0,'slider;sliceDown;1000',0),(66,8,0,NULL,NULL,'2018-01-10 13:22:36',NULL,1,0,0,'banner',0),(67,8,0,NULL,NULL,'2018-01-10 13:22:39',NULL,1,0,0,'banner',0),(68,8,0,NULL,NULL,'2018-01-10 13:23:06',NULL,1,0,0,'banner',0),(69,8,0,NULL,NULL,'2018-01-10 13:23:08',NULL,1,0,0,'banner',0),(70,8,0,NULL,NULL,'2018-01-10 13:23:08',NULL,1,0,0,'banner',0),(71,8,0,NULL,NULL,'2018-01-10 13:23:31',NULL,1,0,0,'banner',0),(72,8,0,NULL,NULL,'2018-01-10 13:23:31',NULL,1,0,0,'banner',0),(73,8,0,NULL,NULL,'2018-01-10 13:23:32',NULL,1,0,0,'banner',0),(74,8,0,NULL,NULL,'2018-01-10 13:23:32',NULL,1,0,0,'banner',0),(75,8,0,NULL,NULL,'2018-01-10 13:23:32',NULL,1,0,0,'banner',0),(76,8,0,NULL,NULL,'2018-01-10 13:23:39',NULL,1,0,0,'banner',0),(77,8,0,NULL,NULL,'2018-01-10 13:23:41',NULL,1,0,0,'banner',0),(78,8,0,NULL,NULL,'2018-01-10 13:23:41',NULL,1,0,0,'banner',0),(79,8,0,NULL,NULL,'2018-01-10 13:24:14',NULL,1,0,1,'banner',0),(80,8,0,NULL,NULL,'2018-01-10 13:24:16',NULL,1,0,1,'banner',0),(81,8,0,NULL,NULL,'2018-01-10 13:24:16',NULL,1,0,1,'banner',0),(82,8,0,NULL,NULL,'2018-01-10 13:24:17',NULL,1,0,1,'banner',0),(83,8,0,NULL,NULL,'2018-01-10 13:24:17',NULL,1,0,1,'banner',0),(84,8,0,NULL,NULL,'2018-01-10 13:24:17',NULL,1,0,1,'banner',0),(85,8,0,NULL,NULL,'2018-01-10 13:24:17',NULL,1,0,1,'banner',0),(86,8,0,NULL,NULL,'2018-01-10 13:24:17',NULL,1,0,1,'banner',0),(87,8,0,NULL,NULL,'2018-01-10 14:19:40',NULL,0,0,0,'banner',0),(96,11,0,NULL,NULL,'2021-12-23 11:32:25',NULL,1,0,0,'',0),(97,11,0,NULL,NULL,'2021-12-23 11:32:25',NULL,1,0,0,'',0),(98,11,0,NULL,NULL,'2021-12-23 11:32:25',NULL,1,0,0,'',0),(107,3,0,NULL,NULL,'2021-12-23 13:33:40','2022-01-19 16:16:48',0,0,0,'slider;sliceDown;1000',0),(109,12,0,NULL,NULL,'2021-12-23 13:42:38','2023-02-24 17:25:45',1,0,0,'',0),(110,12,0,NULL,NULL,'2021-12-23 13:44:10','2023-02-24 17:25:55',1,0,0,'',0),(111,11,0,NULL,NULL,'2021-12-23 13:45:03','2023-02-24 17:24:59',1,0,0,'',0),(112,11,0,NULL,NULL,'2021-12-23 13:46:28','2023-02-24 17:25:08',1,0,0,'',0),(113,11,0,NULL,NULL,'2021-12-23 13:47:51','2023-02-24 17:25:17',1,0,0,'',0),(116,12,0,NULL,NULL,'2021-12-23 13:55:54','2023-02-24 17:26:04',1,0,0,'',0),(117,12,0,NULL,NULL,'2021-12-23 13:58:12','2023-02-24 17:28:15',1,0,0,'',0),(118,12,0,NULL,NULL,'2021-12-23 13:59:29','2023-02-24 17:28:26',1,0,0,'',0),(120,13,0,NULL,NULL,'2022-02-18 14:31:01','2023-03-01 11:49:34',1,0,0,'',0),(121,13,0,NULL,NULL,'2022-02-18 14:31:01','2023-03-01 11:50:25',1,0,0,'',0),(122,14,0,NULL,NULL,'2022-02-18 14:31:01','2023-03-01 11:53:57',1,0,0,'',0),(124,15,0,NULL,NULL,'2022-02-18 14:31:01','2023-03-01 11:54:26',1,0,0,'',0),(125,16,0,NULL,NULL,'2022-02-18 14:31:01','2023-09-20 13:25:55',1,0,0,'',0),(126,16,0,NULL,NULL,'2022-02-18 14:31:01','2023-09-20 13:32:31',1,0,0,'',0),(127,16,0,NULL,NULL,'2022-02-18 14:31:01','2023-09-20 13:32:06',1,0,0,'',0),(128,17,0,NULL,NULL,'2022-02-18 14:31:01','2023-03-01 11:51:16',1,0,0,'',0),(129,17,0,NULL,NULL,'2022-02-18 14:31:01','2023-03-01 11:51:47',1,0,0,'',0),(130,18,0,NULL,NULL,'2022-02-18 14:46:57','2023-02-27 09:39:31',1,0,0,'',0),(131,19,0,NULL,NULL,'2022-02-18 14:46:57',NULL,1,0,0,'',0),(132,19,0,NULL,NULL,'2022-02-18 14:46:57',NULL,1,0,0,'',0),(133,20,0,NULL,NULL,'2022-02-18 14:46:57',NULL,1,0,0,'',0),(134,21,0,NULL,NULL,'2022-04-12 11:05:12','2023-02-27 19:32:36',1,0,0,'',0),(135,21,0,NULL,NULL,'2022-04-12 11:07:00','2023-02-27 19:33:19',1,0,0,'',0),(136,3,0,NULL,NULL,'2022-04-13 11:05:42','2023-02-26 14:15:29',1,0,0,'',0),(137,4,0,NULL,NULL,'2022-04-13 17:29:40','2023-03-01 11:53:19',1,0,0,'',0),(140,22,0,NULL,NULL,'2022-04-15 16:53:52',NULL,0,0,0,'',0),(141,23,0,NULL,NULL,'2022-04-18 09:13:00','2022-04-18 09:21:09',0,0,0,'',0),(142,23,0,NULL,NULL,'2022-04-18 09:13:56','2022-04-18 10:06:57',0,0,0,'',0),(143,24,0,NULL,NULL,'2022-04-25 11:59:04','2022-04-25 12:04:14',0,0,0,'banner',0),(144,25,0,NULL,NULL,'2022-04-25 12:39:42',NULL,0,0,0,'',0),(145,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,0,0,0,'',0),(146,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,1,0,1,'slider;sliceDown;1000',0),(147,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,0,0,0,'slider;sliceDown;1000',0),(148,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,0,0,0,'slider;sliceDown;1000',0),(149,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,0,0,0,'slider;sliceDown;1000',0),(150,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,1,0,0,'',0),(151,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,0,0,0,'',0),(152,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,0,0,0,'',0),(153,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,1,0,0,'',0),(154,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,0,0,0,'',0),(155,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,0,0,0,'',0),(156,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,0,0,0,'',0),(157,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,0,0,2,'',0),(158,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,1,0,3,'',0),(159,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,0,0,2,'',0),(160,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,0,0,0,'',0),(161,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,1,0,1,'',0),(162,0,0,NULL,NULL,'2023-09-11 14:03:09',NULL,1,0,0,'slider;sliceDown;1000',0),(163,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,0,0,0,'',0),(164,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,1,0,1,'slider;sliceDown;1000',0),(165,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,0,0,0,'slider;sliceDown;1000',0),(166,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,0,0,0,'slider;sliceDown;1000',0),(167,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,0,0,0,'slider;sliceDown;1000',0),(168,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,1,0,0,'',0),(169,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,0,0,0,'',0),(170,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,0,0,0,'',0),(171,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,1,0,0,'',0),(172,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,0,0,0,'',0),(173,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,0,0,0,'',0),(174,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,0,0,0,'',0),(175,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,0,0,2,'',0),(176,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,1,0,3,'',0),(177,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,0,0,2,'',0),(178,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,0,0,0,'',0),(179,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,1,0,1,'',0),(180,0,0,NULL,NULL,'2023-09-11 14:03:40',NULL,1,0,0,'slider;sliceDown;1000',0),(181,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,0,0,0,'',0),(182,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,1,0,1,'slider;sliceDown;1000',0),(183,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,0,0,0,'slider;sliceDown;1000',0),(184,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,0,0,0,'slider;sliceDown;1000',0),(185,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,0,0,0,'slider;sliceDown;1000',0),(186,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,1,0,0,'',0),(187,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,0,0,0,'',0),(188,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,0,0,0,'',0),(189,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,1,0,0,'',0),(190,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,0,0,0,'',0),(191,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,0,0,0,'',0),(192,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,0,0,0,'',0),(193,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,0,0,2,'',0),(194,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,1,0,3,'',0),(195,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,0,0,2,'',0),(196,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,0,0,0,'',0),(197,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,1,0,1,'',0),(198,0,0,NULL,NULL,'2023-09-11 14:18:09',NULL,1,0,0,'slider;sliceDown;1000',0),(199,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,0,0,0,'',0),(200,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,1,0,1,'slider;sliceDown;1000',0),(201,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,0,0,0,'slider;sliceDown;1000',0),(202,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,0,0,0,'slider;sliceDown;1000',0),(203,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,0,0,0,'slider;sliceDown;1000',0),(204,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,1,0,0,'',0),(205,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,0,0,0,'',0),(206,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,0,0,0,'',0),(207,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,1,0,0,'',0),(208,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,0,0,0,'',0),(209,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,0,0,0,'',0),(210,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,0,0,0,'',0),(211,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,0,0,2,'',0),(212,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,1,0,3,'',0),(213,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,0,0,2,'',0),(214,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,0,0,0,'',0),(215,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,1,0,1,'',0),(216,0,0,NULL,NULL,'2023-09-11 14:20:29',NULL,1,0,0,'slider;sliceDown;1000',0),(217,0,0,NULL,NULL,'2023-09-19 13:25:49',NULL,0,0,0,'slider;sliceDown;1000',0),(218,0,0,NULL,NULL,'2023-09-19 13:25:49',NULL,0,0,0,'slider;sliceDown;1000',0),(219,0,0,NULL,NULL,'2023-09-19 13:25:49',NULL,0,0,0,'slider;sliceDown;1000',0),(220,0,0,NULL,NULL,'2023-09-19 13:25:49',NULL,0,0,0,'',0),(221,0,0,NULL,NULL,'2023-09-19 13:25:49',NULL,0,0,2,'',0),(222,0,0,NULL,NULL,'2023-09-19 13:25:49',NULL,0,0,0,'',0),(223,0,0,NULL,NULL,'2023-09-19 13:42:53',NULL,0,0,0,'slider;sliceDown;1000',0),(224,0,0,NULL,NULL,'2023-09-19 13:42:53',NULL,0,0,0,'slider;sliceDown;1000',0),(225,0,0,NULL,NULL,'2023-09-19 13:42:53',NULL,0,0,0,'slider;sliceDown;1000',0),(226,0,0,NULL,NULL,'2023-09-19 13:42:53',NULL,0,0,0,'',0),(227,0,0,NULL,NULL,'2023-09-19 13:42:53',NULL,0,0,2,'',0),(228,0,0,NULL,NULL,'2023-09-19 13:42:53',NULL,0,0,0,'',0),(229,0,0,NULL,NULL,'2023-09-19 13:46:08',NULL,0,0,0,'slider;sliceDown;1000',0),(230,0,0,NULL,NULL,'2023-09-19 13:46:08',NULL,0,0,0,'slider;sliceDown;1000',0),(231,0,0,NULL,NULL,'2023-09-19 13:46:08',NULL,0,0,0,'slider;sliceDown;1000',0),(232,0,0,NULL,NULL,'2023-09-19 13:46:08',NULL,0,0,0,'',0),(233,0,0,NULL,NULL,'2023-09-19 13:46:08',NULL,0,0,2,'',0),(234,0,0,NULL,NULL,'2023-09-19 13:46:08',NULL,0,0,0,'',0),(235,0,0,NULL,NULL,'2023-09-21 11:52:55',NULL,0,0,0,'slider;sliceDown;1000',0),(236,0,0,NULL,NULL,'2023-09-21 11:52:55',NULL,0,0,0,'slider;sliceDown;1000',0),(237,0,0,NULL,NULL,'2023-09-21 11:52:55',NULL,0,0,0,'slider;sliceDown;1000',0),(238,0,0,NULL,NULL,'2023-09-21 11:52:55',NULL,0,0,0,'',0),(239,0,0,NULL,NULL,'2023-09-21 11:52:55',NULL,0,0,2,'',0),(240,0,0,NULL,NULL,'2023-09-21 11:52:55',NULL,0,0,0,'',0),(241,0,0,NULL,NULL,'2023-09-21 11:54:34',NULL,0,0,0,'slider;sliceDown;1000',0),(242,0,0,NULL,NULL,'2023-09-21 11:54:34',NULL,0,0,0,'slider;sliceDown;1000',0),(243,0,0,NULL,NULL,'2023-09-21 11:54:34',NULL,0,0,0,'slider;sliceDown;1000',0),(244,0,0,NULL,NULL,'2023-09-21 11:54:34',NULL,0,0,0,'',0),(245,0,0,NULL,NULL,'2023-09-21 11:54:34',NULL,0,0,2,'',0),(246,0,0,NULL,NULL,'2023-09-21 11:54:34',NULL,0,0,0,'',0);
/*!40000 ALTER TABLE `banners` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `banners_groups`
--

DROP TABLE IF EXISTS `banners_groups`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `banners_groups` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `banners_group` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=26 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `banners_groups`
--

LOCK TABLES `banners_groups` WRITE;
/*!40000 ALTER TABLE `banners_groups` DISABLE KEYS */;
INSERT INTO `banners_groups` VALUES (1,'home'),(2,'smartMiddle'),(3,'home-f'),(4,'home-print'),(8,'1_one'),(9,'12'),(11,'Shop_by_co'),(12,'payment'),(13,'double-pri'),(14,'home-botto'),(15,'middle-pri'),(16,'triple-lin'),(17,'bottom-dou'),(18,'home-deal'),(19,'horizontal'),(20,'vertical'),(21,'furnLowPri'),(22,'smartBotto'),(23,'smartDoubl'),(24,'smartTop'),(25,'smartMiddl');
/*!40000 ALTER TABLE `banners_groups` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `banners_groups_images`
--

DROP TABLE IF EXISTS `banners_groups_images`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `banners_groups_images` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `banners_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `image_width` int(11) NOT NULL DEFAULT '0',
  `image` varchar(255) NOT NULL DEFAULT '',
  `svg` text NOT NULL,
  `fit` varchar(32) NOT NULL DEFAULT '',
  `position` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `banners_groups_images`
--

LOCK TABLES `banners_groups_images` WRITE;
/*!40000 ALTER TABLE `banners_groups_images` DISABLE KEYS */;
INSERT INTO `banners_groups_images` VALUES (1,107,1,600,'banners/107/banner[600].jpg','','',''),(2,107,1,1200,'banners/107/banner[1200].jpg','','',''),(3,41,1,600,'banners/41/banner_4[600].jpg','','',''),(4,41,1,1200,'banners/41/banner_4[1200].jpg','','',''),(5,136,1,768,'banners/136/topMobileFurniture.jpg','','',''),(6,137,1,768,'banners/137/printMobile.jpg','','','');
/*!40000 ALTER TABLE `banners_groups_images` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `banners_groups_sizes`
--

DROP TABLE IF EXISTS `banners_groups_sizes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `banners_groups_sizes` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `group_id` int(11) NOT NULL DEFAULT '0',
  `width_from` int(11) NOT NULL DEFAULT '0',
  `width_to` int(11) NOT NULL DEFAULT '0',
  `image_width` int(11) NOT NULL DEFAULT '0',
  `image_height` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `banners_groups_sizes`
--

LOCK TABLES `banners_groups_sizes` WRITE;
/*!40000 ALTER TABLE `banners_groups_sizes` DISABLE KEYS */;
INSERT INTO `banners_groups_sizes` VALUES (1,1,320,700,600,0),(2,1,701,1200,1200,0),(4,2,0,768,768,0),(5,3,0,768,768,0),(6,4,0,768,768,0);
/*!40000 ALTER TABLE `banners_groups_sizes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `banners_history`
--

DROP TABLE IF EXISTS `banners_history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `banners_history` (
  `banners_history_id` int(11) NOT NULL AUTO_INCREMENT,
  `banners_id` int(11) NOT NULL DEFAULT '0',
  `banners_shown` int(5) NOT NULL DEFAULT '0',
  `banners_clicked` int(5) NOT NULL DEFAULT '0',
  `banners_history_date` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (`banners_history_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `banners_history`
--

LOCK TABLES `banners_history` WRITE;
/*!40000 ALTER TABLE `banners_history` DISABLE KEYS */;
/*!40000 ALTER TABLE `banners_history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `banners_languages`
--

DROP TABLE IF EXISTS `banners_languages`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `banners_languages` (
  `blang_id` int(11) NOT NULL AUTO_INCREMENT,
  `banners_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `banners_title` varchar(255) NOT NULL DEFAULT '',
  `banners_url` varchar(255) NOT NULL DEFAULT '',
  `banners_image` varchar(255) NOT NULL DEFAULT '',
  `banners_html_text` text,
  `language_id` int(11) NOT NULL DEFAULT '1',
  `target` int(5) NOT NULL DEFAULT '0',
  `banner_display` int(11) NOT NULL DEFAULT '0',
  `text_position` int(11) NOT NULL DEFAULT '0',
  `svg` text NOT NULL,
  PRIMARY KEY (`blang_id`),
  UNIQUE KEY `language_banners_platform` (`language_id`,`banners_id`,`platform_id`)
) ENGINE=InnoDB AUTO_INCREMENT=490 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `banners_languages`
--

LOCK TABLES `banners_languages` WRITE;
/*!40000 ALTER TABLE `banners_languages` DISABLE KEYS */;
INSERT INTO `banners_languages` VALUES (37,41,0,'Banner 4','catalog/sales','banners/41/banner_4.jpg','',1,0,0,0,''),(335,107,0,'Banner 4','veronica-4-piece-queen-bedroom-suite','banners/107/banner.jpg','',1,0,0,0,''),(349,109,0,'Amex','','banners/109/amex.png','',1,0,0,0,''),(350,110,0,'Bank deposit','','banners/110/bd.png','',1,0,0,0,''),(351,111,0,'Bedroom Silverstrike','','banners/111/dining-triple.jpg','<div class=\"content\">\r\n<div class=\"title\">Bedroom <span>Silverstrike</span></div>\r\n\r\n<div class=\"bannerButton\"><a href=\"mattress\">Shop now</a></div>\r\n</div>\r\n',1,0,0,7,''),(352,112,0,'Dining','','banners/112/lounge-triple.jpg','<div class=\"content\">\r\n<div class=\"title\">Dining <span>Galgary</span></div>\r\n\r\n<div class=\"bannerButton\"><a href=\"mattress\">Shop now</a></div>\r\n</div>\r\n',1,0,0,7,''),(353,113,0,'Lounge Chelsea','','banners/113/bedroom-triple.jpg','<div class=\"content\">\r\n<div class=\"title\">Lounge <span>Chelsea</span></div>\r\n\r\n<div class=\"bannerButton\"><a href=\"mattress\">Shop now</a></div>\r\n</div>\r\n',1,0,0,7,''),(356,116,0,'Mastercard','','banners/116/mc.png','',1,0,0,0,''),(357,117,0,'Paypal','','banners/117/paypal.png','',1,0,0,0,''),(358,118,0,'Visa','','banners/118/visa.png','',1,0,0,0,''),(360,120,0,'Automatic two-sided printing','epson','banners/120/auto-two-side.jpg','<div class=\"title\">Automatic two-sided printing</div>\r\n\r\n<div class=\"descr\">AirPrint, Separate color cartridges, Tank System</div>\r\n\r\n<div><a class=\"btn-2\" href=\"epson\">Shop now</a></div>\r\n',1,0,0,1,''),(361,121,0,'Copying & Scanning','canon','banners/121/copy-scan.jpg','<div class=\"title\">Copying &amp; Scanning</div>\r\n\r\n<div class=\"descr\">Automatic two-sided printing</div>\r\n\r\n<div><a class=\"btn-2\" href=\"canon\">Shop now</a></div>\r\n',1,0,0,1,''),(362,122,0,'Automatic duplex scanning','epson','banners/122/auto-duplex.jpg','<div class=\"wrapper\">\r\n<div class=\"title\">Automatic duplex scanning</div>\r\n\r\n<div class=\"descr\">Automatic two-sided printing (duplex), Borderless Printing, Fax, Copying &amp; scanning</div>\r\n\r\n<div><a class=\"btn-1\" href=\"epson\">See all range</a></div>\r\n\r\n<div class=\"icon-box\">\r\n<div class=\"copy\">Copy</div>\r\n\r\n<div class=\"fax\">Fax</div>\r\n\r\n<div class=\"print\">Print</div>\r\n\r\n<div class=\"scan\">Scan</div>\r\n</div>\r\n</div>\r\n',1,0,0,3,''),(367,124,0,'Canon imagePRO GRAF','canon','banners/124/banner-middle.jpg','<div class=\"title\">Canon ImagePRO GRAF TM-300 with Stand</div>\r\n\r\n<div class=\"descr\">Separate colour cartridges, Photo printing</div>\r\n\r\n<div><a class=\"btn-1\" href=\"canon\">See all range</a></div>\r\n',1,0,0,5,''),(368,125,0,'Next business day','','banners/125/next-business-day.png','<div>Next business day<br />\r\nNormal delivery</div>\r\n\r\n<div class=\"link\"><a href=\"next-business-day\">Read Shipping &amp; Deliveries</a></div>\r\n',1,0,0,9,''),(369,126,0,'Terms & Conditions','','banners/126/terms-cond.png','<div>Terms &amp; Conditions<br />\r\nConsumer terms of sale</div>\r\n\r\n<div class=\"link\"><a href=\"terms-conditions\">Read our Terms</a></div>\r\n',1,0,0,9,''),(370,127,0,'Returns & Exchanges','','banners/127/policy.png','<div>Returns &amp; Exchanges<br />\r\n14 days Return policy</div>\r\n\r\n<div class=\"link\"><a href=\"returns-exchanges\">Read Returns &amp; Exchanges</a></div>\r\n',1,0,0,9,''),(371,128,0,'Printer Consumables','canon','banners/128/printer-cons.jpg','<div class=\"title\">Printer Consumables</div>\r\n\r\n<div><a class=\"btn-2\" href=\"canon\">Shop now</a></div>\r\n',1,0,0,1,''),(372,129,0,'Toners and Cartridges','brother','banners/129/toners.jpg','<div class=\"title\">Toners and Cartridges</div>\r\n\r\n<div><a class=\"btn-2\" href=\"brother\">Shop now</a></div>\r\n',1,0,0,1,''),(373,130,0,'1000\'s of products at best prices','','banners/130/main-banner.jpg','b2b supermarket',1,0,0,7,''),(374,131,0,'Office refresh','','banners/131/office.jpg','<div class=\"text\">Office refresh?</br>No problem! </div>',1,0,2,3,''),(375,132,0,'Clever solutions','','banners/132/refr.jpg','<div class=\"text\">Clever solutions</br>for a tidy workplace</div>',1,0,2,3,''),(376,133,0,'Flooring for every environment','','banners/133/floor.jpg','<div class=\"text\">Flooring for every environment</div>',1,0,2,1,''),(377,134,0,'Bedroom furniture','bedroom-suites','banners/134/lowest-right.jpg','<div class=\"ybg\">\r\n<div class=\"mark\"><img src=\"themes/furniture/img/furn-mark.webp\" /></div>\r\n\r\n<div class=\"title\">Lowest priced</div>\r\n\r\n<div class=\"descr\">bedroom furniture</div>\r\n\r\n<div class=\"bannerButton\"><a class=\"btn\" href=\"bedroom-suites\">Shop Bedroom</a></div>\r\n</div>\r\n',1,0,0,5,''),(378,135,0,'Dining furniture','outdoor','banners/135/lowest-left.jpg','<div class=\"ybg\">\r\n<div class=\"mark\"><img src=\"themes/furniture/img/furn-mark.webp\" /></div>\r\n\r\n<div class=\"title\">Lowest priced</div>\r\n\r\n<div class=\"descr\">dining furniture</div>\r\n\r\n<div class=\"bannerButton\"><a class=\"btn\" href=\"outdoor\">Shop Dining</a></div>\r\n</div>\r\n',1,0,0,5,''),(379,136,0,'Clearance','','banners/136/topBanner.jpg','<div class=\"content\">\r\n<div class=\"topBox\"><span class=\"left\">Clearance</span> <span class=\"right\">Collection</span></div>\r\n\r\n<div class=\"bottomBox\">\r\n<div class=\"wrapper\">\r\n<div class=\"title\">High-design aesthetic <span>at a price that&rsquo;s just your style</span></div>\r\n\r\n<div class=\"buttonBox\"><a class=\"btn\" href=\"clearance\">Shop now</a></div>\r\n</div>\r\n</div>\r\n</div>\r\n',1,0,0,5,''),(380,137,0,'Monthly Special Offers Print','catalog/sales','banners/137/topBanner.jpg','<div class=\"content\">\r\n<div class=\"title\">Monthly Special Offers</div>\r\n\r\n<div class=\"descr\">Each month we recommend a selection of devices from our extensive product range</div>\r\n\r\n<div class=\"buttonBox\"><a class=\"btn\" href=\"catalog/sales\">See this month&#39;s picks</a>\r\n\r\n<div class=\"ourPick\"><span class=\"top\">Our Pick</span> <span class=\"bottom\">of the month</span></div>\r\n</div>\r\n</div>\r\n',1,0,0,3,''),(383,140,0,'Smart bottom','','banners/140/bottomBanner.jpg','',1,0,0,0,''),(384,141,0,'Smartwatches','','banners/141/watch1.png','<div class=\"content\">\r\n <div class=\"title\">Smartwatches</div>\r\n <div class=\"descr\"><a href=\"\">Shop now</a></div>\r\n</div>',1,0,2,5,''),(385,142,0,'Trackers','','banners/142/tracker.png','<div class=\"content\">\r\n <div class=\"title\">Trackers</div>\r\n <div class=\"descr\"><a href=\"\">Shop now</a></div>\r\n</div>',1,0,2,5,''),(386,143,0,'Smart Watch Active','','banners/143/topImg.png','<div class=\"content\">\r\n <div class=\"title\">Smart Watch Active </div>\r\n <div class=\"descr\">One Step Ahead</div>\r\n <div class=\"bannerPrice\"><span class=\"current\">£ 39.99 </span><span class=\"old\">£49.99</span></div> \r\n</div>',1,0,2,1,''),(387,144,0,'Smart Band Pro','','banners/144/lefRight.png','<div class=\"content\">\r\n <div class=\"title\">Smart Band Pro</div>\r\n <div class=\"descr\">Get fit, start now</div>\r\n <div class=\"bannerPrice\"><span class=\"current\">£ 47.99 </span><span class=\"old\">£59.99</span></div> \r\n</div>',1,0,2,4,''),(388,145,0,'Blog','','','<div class=\"blue-title\">Blog</div>',1,0,2,4,''),(389,146,0,'Main banner','citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','','',1,0,0,0,''),(390,147,0,'Banner 5','','','',1,0,0,0,''),(391,148,0,'Banner 6','','','',1,0,0,0,''),(392,149,0,'Banner 7','','','',1,0,0,0,''),(393,150,0,'Banner 8','/nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','','<div>aaa</div>',1,0,0,0,''),(394,151,0,'Sigma Canon','/sigma-50mm-f1-4-dg-a-lens-for-canon','','',1,0,0,0,''),(395,152,0,'Inspiron 11','/dell-inspiron-11-3169-2-in-1-bali-blue-windows-10-home-64-bit-intel-m3-6y30-900mhz-2-2ghz-4gb-ram-500gb-sata-11-6-1366x768-hd-touch-dell-3-year-nbd-warranty-119071','','',1,0,0,0,''),(396,153,0,'Dont Miss','/women','','Spring collection!',1,0,0,0,''),(397,154,0,'garden','/garden','','This is a sample text',1,0,2,0,''),(398,155,0,'Beko','/beko-bric21000x-built-in-electric-single-oven-stainless-steel','','',1,0,0,0,''),(399,156,0,'Nail Polishes','','','',1,0,0,0,''),(400,157,0,'Citizen Eco-Drive','/watch','','',1,0,0,0,''),(401,158,0,'Men\'s Chronograph Watch','/men-s','','',1,0,0,0,''),(402,159,0,'Women\'s Leather Cuff Band Watch','/women-s','','',1,0,0,0,''),(403,160,0,'security seal','','','<a href=\"https://seal.beyondsecurity.com/vulnerability-scanner-verification/www.trueloaded.co.uk\"><img src=\"https://seal.beyondsecurity.com/verification-images/www.trueloaded.co.uk/vulnerability-scanner-2.gif\" alt=\"Website Security Test\" border=\"0\" /></a>',1,0,1,0,''),(404,161,0,'Shop closed','','','Shop closed from December, 24th to January, 2nd',1,0,1,0,''),(405,162,0,'Banner 657','catalog/product?products_id=372','','',1,0,0,0,'<svg viewBox=\"0 0 1903 500\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\">\n <g class=\"layer\">\n <title>Layer 1</title>\n <image height=\"500\" id=\"svg_1\" width=\"1903\" x=\"-41\" xlink:href=\"https://dev.trueloaded.co.uk/images/banners/41/banner_4-1.jpg\" y=\"34\"/>\n <rect fill=\"#FF0000\" height=\"109\" id=\"svg_2\" stroke=\"#000000\" stroke-width=\"5\" width=\"390\" x=\"404.5\" y=\"86.5\"/>\n <rect fill=\"#FF0000\" height=\"13\" id=\"svg_3\" stroke=\"#000000\" stroke-width=\"5\" width=\"415\" x=\"467.50385\" y=\"373.00389\"/>\n <text fill=\"#000000\" font-family=\"serif\" font-size=\"24\" id=\"svg_4\" stroke=\"#000000\" stroke-width=\"0\" text-anchor=\"middle\" x=\"509.50385\" xml:space=\"preserve\" y=\"375.00389\">ertqw43r5</text>\n </g>\n</svg>'),(406,163,0,'Blog','','','<div class=\"blue-title\">Blog</div>',1,0,2,4,''),(407,164,0,'Main banner','citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','','',1,0,0,0,''),(408,165,0,'Banner 5','','','',1,0,0,0,''),(409,166,0,'Banner 6','','','',1,0,0,0,''),(410,167,0,'Banner 7','','','',1,0,0,0,''),(411,168,0,'Banner 8','/nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','','<div>aaa</div>',1,0,0,0,''),(412,169,0,'Sigma Canon','/sigma-50mm-f1-4-dg-a-lens-for-canon','','',1,0,0,0,''),(413,170,0,'Inspiron 11','/dell-inspiron-11-3169-2-in-1-bali-blue-windows-10-home-64-bit-intel-m3-6y30-900mhz-2-2ghz-4gb-ram-500gb-sata-11-6-1366x768-hd-touch-dell-3-year-nbd-warranty-119071','','',1,0,0,0,''),(414,171,0,'Dont Miss','/women','','Spring collection!',1,0,0,0,''),(415,172,0,'garden','/garden','','This is a sample text',1,0,2,0,''),(416,173,0,'Beko','/beko-bric21000x-built-in-electric-single-oven-stainless-steel','','',1,0,0,0,''),(417,174,0,'Nail Polishes','','','',1,0,0,0,''),(418,175,0,'Citizen Eco-Drive','/watch','','',1,0,0,0,''),(419,176,0,'Men\'s Chronograph Watch','/men-s','','',1,0,0,0,''),(420,177,0,'Women\'s Leather Cuff Band Watch','/women-s','','',1,0,0,0,''),(421,178,0,'security seal','','','<a href=\"https://seal.beyondsecurity.com/vulnerability-scanner-verification/www.trueloaded.co.uk\"><img src=\"https://seal.beyondsecurity.com/verification-images/www.trueloaded.co.uk/vulnerability-scanner-2.gif\" alt=\"Website Security Test\" border=\"0\" /></a>',1,0,1,0,''),(422,179,0,'Shop closed','','','Shop closed from December, 24th to January, 2nd',1,0,1,0,''),(423,180,0,'Banner 657','catalog/product?products_id=372','','',1,0,0,0,'<svg viewBox=\"0 0 1903 500\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\">\n <g class=\"layer\">\n <title>Layer 1</title>\n <image height=\"500\" id=\"svg_1\" width=\"1903\" x=\"-41\" xlink:href=\"https://dev.trueloaded.co.uk/images/banners/41/banner_4-1.jpg\" y=\"34\"/>\n <rect fill=\"#FF0000\" height=\"109\" id=\"svg_2\" stroke=\"#000000\" stroke-width=\"5\" width=\"390\" x=\"404.5\" y=\"86.5\"/>\n <rect fill=\"#FF0000\" height=\"13\" id=\"svg_3\" stroke=\"#000000\" stroke-width=\"5\" width=\"415\" x=\"467.50385\" y=\"373.00389\"/>\n <text fill=\"#000000\" font-family=\"serif\" font-size=\"24\" id=\"svg_4\" stroke=\"#000000\" stroke-width=\"0\" text-anchor=\"middle\" x=\"509.50385\" xml:space=\"preserve\" y=\"375.00389\">ertqw43r5</text>\n </g>\n</svg>'),(424,181,0,'Blog','','','<div class=\"blue-title\">Blog</div>',1,0,2,4,''),(425,182,0,'Main banner','citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','','',1,0,0,0,''),(426,183,0,'Banner 5','','','',1,0,0,0,''),(427,184,0,'Banner 6','','','',1,0,0,0,''),(428,185,0,'Banner 7','','','',1,0,0,0,''),(429,186,0,'Banner 8','/nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','','<div>aaa</div>',1,0,0,0,''),(430,187,0,'Sigma Canon','/sigma-50mm-f1-4-dg-a-lens-for-canon','','',1,0,0,0,''),(431,188,0,'Inspiron 11','/dell-inspiron-11-3169-2-in-1-bali-blue-windows-10-home-64-bit-intel-m3-6y30-900mhz-2-2ghz-4gb-ram-500gb-sata-11-6-1366x768-hd-touch-dell-3-year-nbd-warranty-119071','','',1,0,0,0,''),(432,189,0,'Dont Miss','/women','','Spring collection!',1,0,0,0,''),(433,190,0,'garden','/garden','','This is a sample text',1,0,2,0,''),(434,191,0,'Beko','/beko-bric21000x-built-in-electric-single-oven-stainless-steel','','',1,0,0,0,''),(435,192,0,'Nail Polishes','','','',1,0,0,0,''),(436,193,0,'Citizen Eco-Drive','/watch','','',1,0,0,0,''),(437,194,0,'Men\'s Chronograph Watch','/men-s','','',1,0,0,0,''),(438,195,0,'Women\'s Leather Cuff Band Watch','/women-s','','',1,0,0,0,''),(439,196,0,'security seal','','','<a href=\"https://seal.beyondsecurity.com/vulnerability-scanner-verification/www.trueloaded.co.uk\"><img src=\"https://seal.beyondsecurity.com/verification-images/www.trueloaded.co.uk/vulnerability-scanner-2.gif\" alt=\"Website Security Test\" border=\"0\" /></a>',1,0,1,0,''),(440,197,0,'Shop closed','','','Shop closed from December, 24th to January, 2nd',1,0,1,0,''),(441,198,0,'Banner 657','catalog/product?products_id=372','','',1,0,0,0,'<svg viewBox=\"0 0 1903 500\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\">\n <g class=\"layer\">\n <title>Layer 1</title>\n <image height=\"500\" id=\"svg_1\" width=\"1903\" x=\"-41\" xlink:href=\"https://dev.trueloaded.co.uk/images/banners/41/banner_4-1.jpg\" y=\"34\"/>\n <rect fill=\"#FF0000\" height=\"109\" id=\"svg_2\" stroke=\"#000000\" stroke-width=\"5\" width=\"390\" x=\"404.5\" y=\"86.5\"/>\n <rect fill=\"#FF0000\" height=\"13\" id=\"svg_3\" stroke=\"#000000\" stroke-width=\"5\" width=\"415\" x=\"467.50385\" y=\"373.00389\"/>\n <text fill=\"#000000\" font-family=\"serif\" font-size=\"24\" id=\"svg_4\" stroke=\"#000000\" stroke-width=\"0\" text-anchor=\"middle\" x=\"509.50385\" xml:space=\"preserve\" y=\"375.00389\">ertqw43r5</text>\n </g>\n</svg>'),(442,199,0,'Blog','','','<div class=\"blue-title\">Blog</div>',1,0,2,4,''),(443,200,0,'Main banner','citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','','',1,0,0,0,''),(444,201,0,'Banner 5','','','',1,0,0,0,''),(445,202,0,'Banner 6','','','',1,0,0,0,''),(446,203,0,'Banner 7','','','',1,0,0,0,''),(447,204,0,'Banner 8','/nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','','<div>aaa</div>',1,0,0,0,''),(448,205,0,'Sigma Canon','/sigma-50mm-f1-4-dg-a-lens-for-canon','','',1,0,0,0,''),(449,206,0,'Inspiron 11','/dell-inspiron-11-3169-2-in-1-bali-blue-windows-10-home-64-bit-intel-m3-6y30-900mhz-2-2ghz-4gb-ram-500gb-sata-11-6-1366x768-hd-touch-dell-3-year-nbd-warranty-119071','','',1,0,0,0,''),(450,207,0,'Dont Miss','/women','','Spring collection!',1,0,0,0,''),(451,208,0,'garden','/garden','','This is a sample text',1,0,2,0,''),(452,209,0,'Beko','/beko-bric21000x-built-in-electric-single-oven-stainless-steel','','',1,0,0,0,''),(453,210,0,'Nail Polishes','','','',1,0,0,0,''),(454,211,0,'Citizen Eco-Drive','/watch','','',1,0,0,0,''),(455,212,0,'Men\'s Chronograph Watch','/men-s','','',1,0,0,0,''),(456,213,0,'Women\'s Leather Cuff Band Watch','/women-s','','',1,0,0,0,''),(457,214,0,'security seal','','','<a href=\"https://seal.beyondsecurity.com/vulnerability-scanner-verification/www.trueloaded.co.uk\"><img src=\"https://seal.beyondsecurity.com/verification-images/www.trueloaded.co.uk/vulnerability-scanner-2.gif\" alt=\"Website Security Test\" border=\"0\" /></a>',1,0,1,0,''),(458,215,0,'Shop closed','','','Shop closed from December, 24th to January, 2nd',1,0,1,0,''),(459,216,0,'Banner 657','catalog/product?products_id=372','','',1,0,0,0,'<svg viewBox=\"0 0 1903 500\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\">\n <g class=\"layer\">\n <title>Layer 1</title>\n <image height=\"500\" id=\"svg_1\" width=\"1903\" x=\"-41\" xlink:href=\"https://dev.trueloaded.co.uk/images/banners/41/banner_4-1.jpg\" y=\"34\"/>\n <rect fill=\"#FF0000\" height=\"109\" id=\"svg_2\" stroke=\"#000000\" stroke-width=\"5\" width=\"390\" x=\"404.5\" y=\"86.5\"/>\n <rect fill=\"#FF0000\" height=\"13\" id=\"svg_3\" stroke=\"#000000\" stroke-width=\"5\" width=\"415\" x=\"467.50385\" y=\"373.00389\"/>\n <text fill=\"#000000\" font-family=\"serif\" font-size=\"24\" id=\"svg_4\" stroke=\"#000000\" stroke-width=\"0\" text-anchor=\"middle\" x=\"509.50385\" xml:space=\"preserve\" y=\"375.00389\">ertqw43r5</text>\n </g>\n</svg>'),(460,217,0,'Banner 5','','banners/217/theme2-banner.jpg','',1,0,0,0,''),(461,218,0,'Banner 6','','banners/218/banner-6.jpg','',1,0,0,0,''),(462,219,0,'Banner 7','','banners/219/banner-7.jpg','',1,0,0,0,''),(463,220,0,'Beko','/beko-bric21000x-built-in-electric-single-oven-stainless-steel','banners/220/banner2.jpg','',1,0,0,0,''),(464,221,0,'Women\'s Leather Cuff Band Watch','/women-s','banners/221/banner-7.jpg','',1,0,0,0,''),(465,222,0,'Blog','','','<div class=\"blue-title\">Blog</div>',1,0,2,4,''),(466,223,0,'Banner 5','','banners/223/theme2-banner.jpg','',1,0,0,0,''),(467,224,0,'Banner 6','','banners/224/banner-6.jpg','',1,0,0,0,''),(468,225,0,'Banner 7','','banners/225/banner-7.jpg','',1,0,0,0,''),(469,226,0,'Beko','/beko-bric21000x-built-in-electric-single-oven-stainless-steel','banners/226/banner2.jpg','',1,0,0,0,''),(470,227,0,'Women\'s Leather Cuff Band Watch','/women-s','banners/227/banner-7.jpg','',1,0,0,0,''),(471,228,0,'Blog','','','<div class=\"blue-title\">Blog</div>',1,0,2,4,''),(472,229,0,'Banner 5','','banners/229/theme2-banner.jpg','',1,0,0,0,''),(473,230,0,'Banner 6','','banners/230/banner-6.jpg','',1,0,0,0,''),(474,231,0,'Banner 7','','banners/231/banner-7.jpg','',1,0,0,0,''),(475,232,0,'Beko','/beko-bric21000x-built-in-electric-single-oven-stainless-steel','banners/232/banner2.jpg','',1,0,0,0,''),(476,233,0,'Women\'s Leather Cuff Band Watch','/women-s','banners/233/banner-7.jpg','',1,0,0,0,''),(477,234,0,'Blog','','','<div class=\"blue-title\">Blog</div>',1,0,2,4,''),(478,235,0,'Banner 5','','banners/235/theme2-banner.jpg','',1,0,0,0,''),(479,236,0,'Banner 6','','banners/236/banner-6.jpg','',1,0,0,0,''),(480,237,0,'Banner 7','','banners/237/banner-7.jpg','',1,0,0,0,''),(481,238,0,'Beko','/beko-bric21000x-built-in-electric-single-oven-stainless-steel','banners/238/banner2.jpg','',1,0,0,0,''),(482,239,0,'Women\'s Leather Cuff Band Watch','/women-s','banners/239/banner-7.jpg','',1,0,0,0,''),(483,240,0,'Blog','','','<div class=\"blue-title\">Blog</div>',1,0,2,4,''),(484,241,0,'Banner 5','','banners/241/theme2-banner.jpg','',1,0,0,0,''),(485,242,0,'Banner 6','','banners/242/banner-6.jpg','',1,0,0,0,''),(486,243,0,'Banner 7','','banners/243/banner-7.jpg','',1,0,0,0,''),(487,244,0,'Beko','/beko-bric21000x-built-in-electric-single-oven-stainless-steel','banners/244/banner2.jpg','',1,0,0,0,''),(488,245,0,'Women\'s Leather Cuff Band Watch','/women-s','banners/245/banner-7.jpg','',1,0,0,0,''),(489,246,0,'Blog','','','<div class=\"blue-title\">Blog</div>',1,0,2,4,'');
/*!40000 ALTER TABLE `banners_languages` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `banners_languages_backup`
--

DROP TABLE IF EXISTS `banners_languages_backup`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `banners_languages_backup` (
  `blang_id` int(11) NOT NULL AUTO_INCREMENT,
  `banners_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `banners_title` varchar(64) NOT NULL DEFAULT '',
  `banners_url` varchar(255) NOT NULL DEFAULT '',
  `banners_image` varchar(64) NOT NULL DEFAULT '',
  `banners_html_text` text,
  `language_id` int(11) NOT NULL DEFAULT '1',
  PRIMARY KEY (`blang_id`)
) ENGINE=InnoDB AUTO_INCREMENT=36 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `banners_languages_backup`
--

LOCK TABLES `banners_languages_backup` WRITE;
/*!40000 ALTER TABLE `banners_languages_backup` DISABLE KEYS */;
INSERT INTO `banners_languages_backup` VALUES (26,37,1,'Main banner','citizen-bj8050-08e-professional-diver-s-eco-drive-men-s-rubber-b','main-1-2.jpg','',1),(27,37,1,'Main banner','','main.jpg','',3),(28,38,1,'Main banner 1','http://www.trueloaded.co.uk/nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','mainYellow-1.jpg','',1),(29,38,1,'Main banner 1','','mainYellow.jpg','',3),(32,37,2,'Main banner','citizen-bj8050-08e-professional-diver-s-eco-drive-men-s-rubber-b','main-1-3.jpg','',1),(33,38,2,'Main banner 1','http://www.trueloaded.co.uk/nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','mainYellow.jpg','',1),(34,37,3,'Main banner','citizen-bj8050-08e-professional-diver-s-eco-drive-men-s-rubber-b','main-1-4.jpg','',1),(35,39,1,'','','eyelash 5.jpg','',1);
/*!40000 ALTER TABLE `banners_languages_backup` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `banners_to_platform`
--

DROP TABLE IF EXISTS `banners_to_platform`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `banners_to_platform` (
  `banners_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  UNIQUE KEY `banners_id` (`banners_id`,`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `banners_to_platform`
--

LOCK TABLES `banners_to_platform` WRITE;
/*!40000 ALTER TABLE `banners_to_platform` DISABLE KEYS */;
INSERT INTO `banners_to_platform` VALUES (41,1),(41,8),(109,7),(109,9),(110,7),(110,9),(111,7),(112,7),(113,7),(116,7),(116,9),(117,7),(117,9),(118,7),(118,9),(120,10),(121,10),(122,10),(124,10),(125,10),(126,10),(127,10),(128,10),(129,10),(130,9),(131,9),(132,9),(133,9),(134,7),(135,7),(136,7),(137,10),(140,8),(141,8),(142,8),(143,8),(144,8);
/*!40000 ALTER TABLE `banners_to_platform` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `categories`
--

DROP TABLE IF EXISTS `categories`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `categories` (
  `categories_id` int(11) NOT NULL AUTO_INCREMENT,
  `categories_image` varchar(128) DEFAULT NULL,
  `categories_image_2` varchar(128) NOT NULL DEFAULT '',
  `parent_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(3) DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `categories_status` tinyint(4) NOT NULL DEFAULT '1',
  `manual_control_status` tinyint(1) NOT NULL DEFAULT '1',
  `previous_status` tinyint(4) DEFAULT NULL,
  `last_xml_import` datetime DEFAULT NULL,
  `last_xml_export` datetime DEFAULT NULL,
  `categories_level` int(11) NOT NULL DEFAULT '0',
  `categories_left` int(11) NOT NULL DEFAULT '0',
  `categories_right` int(11) NOT NULL DEFAULT '0',
  `categories_seo_page_name` varchar(255) NOT NULL DEFAULT '',
  `categories_old_seo_page_name` varchar(255) NOT NULL DEFAULT '',
  `show_on_home` tinyint(1) NOT NULL DEFAULT '1',
  `ep_holbi_soap_disable_update` tinyint(1) NOT NULL DEFAULT '0',
  `created_by_platform_id` int(11) NOT NULL DEFAULT '0',
  `created_by_department_id` int(11) NOT NULL DEFAULT '0',
  `maps_id` int(11) NOT NULL DEFAULT '0',
  `categories_image_3` varchar(128) NOT NULL DEFAULT '',
  `default_sort_order` varchar(5) NOT NULL DEFAULT '',
  `categories_image_4` varchar(128) NOT NULL DEFAULT '',
  `stock_limit` int(11) NOT NULL DEFAULT '-1',
  `banners_group` varchar(256) NOT NULL DEFAULT '',
  PRIMARY KEY (`categories_id`),
  KEY `idx_categories_parent_id` (`parent_id`),
  KEY `idx_date_added` (`date_added`),
  KEY `idx_categories_old_seo_page_name` (`categories_old_seo_page_name`),
  KEY `idx_tree` (`categories_status`,`categories_left`,`categories_right`),
  KEY `categories_left` (`categories_left`),
  KEY `categories_right` (`categories_right`)
) ENGINE=InnoDB AUTO_INCREMENT=19 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `categories`
--

LOCK TABLES `categories` WRITE;
/*!40000 ALTER TABLE `categories` DISABLE KEYS */;
INSERT INTO `categories` VALUES (1,'categories/1/gallery/category-watch-image.jpg','',0,4,'2022-07-22 21:06:46','2022-07-23 14:03:59',1,1,NULL,NULL,NULL,1,30,37,'','',1,0,0,0,0,'categories/1/homepage/category-watch-image.jpg','','',-1,'0'),(2,'categories/2/gallery/womens-watch-category-image.jpg','',1,0,'2022-07-22 21:06:46','2022-07-23 14:03:32',1,1,NULL,NULL,NULL,2,31,32,'','',1,0,0,0,0,'categories/2/homepage/womens-watch-category-image.jpg','','',-1,'0'),(3,'categories/3/gallery/img_for_all.webp','',1,1,'2022-07-22 21:06:46','2022-07-23 14:03:40',1,1,NULL,NULL,NULL,2,33,34,'','',1,0,0,0,0,'categories/3/homepage/img_for_all.webp','','',-1,'0'),(4,'categories/4/gallery/mens-watches-category-image.jpg','',1,2,'2022-07-22 21:06:46','2022-07-23 14:03:49',1,1,NULL,NULL,NULL,2,35,36,'','',1,0,0,0,0,'categories/4/homepage/mens-watches-category-image.jpg','','',-1,'0'),(5,'','',0,1,'2022-07-22 21:06:51','2022-07-23 14:04:17',1,1,NULL,NULL,NULL,1,10,17,'','',0,0,0,0,0,'','','',-1,'0'),(6,'','',5,0,'2022-07-22 21:06:51','2022-07-23 14:07:27',1,1,NULL,NULL,NULL,2,11,12,'','',0,0,0,0,0,'','','',-1,'0'),(7,'','',5,0,'2022-07-22 21:06:51','2022-07-23 14:07:35',1,1,NULL,NULL,NULL,2,13,14,'','',0,0,0,0,0,'','','',-1,'0'),(8,'','',5,0,'2022-07-22 21:06:51','2022-07-23 14:07:44',1,1,NULL,NULL,NULL,2,15,16,'','',0,0,0,0,0,'','','',-1,'0'),(9,'','',0,0,'2022-07-22 21:06:55','2022-07-23 14:04:25',1,1,NULL,NULL,NULL,1,2,9,'','',0,0,0,0,0,'','','',-1,'0'),(10,'','',9,0,'2022-07-22 21:06:55','2022-07-23 14:09:20',1,1,NULL,NULL,NULL,2,3,4,'','',0,0,0,0,0,'','','',-1,'0'),(11,'','',9,1,'2022-07-22 21:06:55','2022-07-23 14:09:28',1,1,NULL,NULL,NULL,2,5,6,'','',0,0,0,0,0,'','','',-1,'0'),(12,'','',9,2,'2022-07-22 21:06:55','2022-07-23 14:09:36',1,1,NULL,NULL,NULL,2,7,8,'','',0,0,0,0,0,'','','',-1,'0'),(13,'categories/13/gallery/furniture.jpg','',0,3,'2022-07-22 21:07:00','2022-07-23 14:04:08',1,1,NULL,NULL,NULL,1,18,29,'','',0,0,0,0,0,'','','',-1,'0'),(14,'categories/14/gallery/accessories.webp','',13,0,'2022-07-22 21:07:00','2022-07-23 14:02:45',1,1,NULL,NULL,NULL,2,19,20,'','',0,0,0,0,0,'','','',-1,'0'),(15,'categories/15/gallery/bedroom suites.webp','',13,0,'2022-07-22 21:07:00','2022-07-23 14:02:54',1,1,NULL,NULL,NULL,2,21,22,'','',0,0,0,0,0,'','','',-1,'0'),(16,'categories/16/gallery/clearance.png','',13,0,'2022-07-22 21:07:00','2022-07-23 14:03:02',1,1,NULL,NULL,NULL,2,23,24,'','',0,0,0,0,0,'','','',-1,'0'),(17,'categories/17/gallery/mattress.webp','',13,0,'2022-07-22 21:07:00','2022-07-23 14:03:12',1,1,NULL,NULL,NULL,2,25,26,'','',0,0,0,0,0,'','','',-1,'0'),(18,'categories/18/gallery/outdoor.webp','',13,0,'2022-07-22 21:07:00','2022-07-23 14:03:20',1,1,NULL,NULL,NULL,2,27,28,'','',0,0,0,0,0,'','','',-1,'0');
/*!40000 ALTER TABLE `categories` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `categories_cache`
--

DROP TABLE IF EXISTS `categories_cache`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `categories_cache` (
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `groups_id` int(11) NOT NULL DEFAULT '0',
  `products` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`categories_id`,`platform_id`,`groups_id`),
  KEY `idx_categories_cache` (`categories_id`,`platform_id`,`groups_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `categories_cache`
--

LOCK TABLES `categories_cache` WRITE;
/*!40000 ALTER TABLE `categories_cache` DISABLE KEYS */;
/*!40000 ALTER TABLE `categories_cache` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `categories_description`
--

DROP TABLE IF EXISTS `categories_description`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `categories_description` (
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '1',
  `categories_name` varchar(255) NOT NULL DEFAULT '',
  `categories_heading_title` varchar(255) DEFAULT NULL,
  `categories_description` text,
  `categories_head_title_tag` varchar(125) NOT NULL DEFAULT '',
  `categories_head_desc_tag` text NOT NULL,
  `categories_head_keywords_tag` text NOT NULL,
  `affiliate_id` int(11) NOT NULL DEFAULT '0',
  `categories_seo_page_name` varchar(255) NOT NULL DEFAULT '',
  `noindex_option` int(11) NOT NULL DEFAULT '0',
  `nofollow_option` int(11) NOT NULL DEFAULT '0',
  `rel_canonical` varchar(255) NOT NULL DEFAULT '',
  `categories_h1_tag` varchar(255) NOT NULL DEFAULT '',
  `categories_h2_tag` text NOT NULL,
  `categories_h3_tag` text NOT NULL,
  `categories_image_alt_tag_mask` varchar(255) NOT NULL DEFAULT '',
  `categories_image_title_tag_mask` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`categories_id`,`language_id`,`affiliate_id`),
  KEY `idx_categories_name` (`categories_name`),
  KEY `idx_language_id` (`language_id`),
  KEY `idx_affiliate_id` (`affiliate_id`),
  KEY `categories_seo_page_name` (`categories_seo_page_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `categories_description`
--

LOCK TABLES `categories_description` WRITE;
/*!40000 ALTER TABLE `categories_description` DISABLE KEYS */;
INSERT INTO `categories_description` VALUES (1,1,'Watch',NULL,'&amp;amp;amp;lt;a href=&amp;amp;amp;quot;/images/Sale_1-2.jpg&amp;amp;amp;quot; target=&amp;amp;amp;quot;_blank&amp;amp;amp;quot;&amp;amp;amp;gt;test&amp;amp;amp;lt;/a&amp;amp;amp;gt;','','','',0,'watch-catalog',0,0,'','','','','',''),(2,1,'For her',NULL,'','Women\'s watch collection','Women&amp;amp;amp;amp;amp;#039;s watch collection for stylich lady,','',0,'women-s',0,0,'','','','','',''),(3,1,'For all',NULL,'','','','',0,'for-all',0,0,'','','','','',''),(4,1,'For him',NULL,'Men watch','','','',0,'men-s',0,0,'','Men\'s watch','','','',''),(5,1,'Supermarket',NULL,'','','','',0,'supermarket',0,0,'','','','','',''),(6,1,'Chairs',NULL,'','','','',0,'chair',0,0,'','','','','',''),(7,1,'Computer Workstations',NULL,'','','','',0,'computer-workstations',0,0,'','','','','',''),(8,1,'Tables',NULL,'','','','',0,'tables',0,0,'','','','','',''),(9,1,'Printshop',NULL,'','','','',0,'printshop',0,0,'','','','','',''),(10,1,'Epson',NULL,'','','','',0,'epson',0,0,'','','','','',''),(11,1,'Canon',NULL,'','','','',0,'canon',0,0,'','','','','',''),(12,1,'Brother',NULL,'','','','',0,'brother',0,0,'','','','','',''),(13,1,'Furniture',NULL,'','','','',0,'furniture-catalog',0,0,'','','','','',''),(14,1,'Accessories',NULL,'','','','',0,'accessories',0,0,'','','','','',''),(15,1,'Bedroom suites',NULL,'','','','',0,'bedroom-suites',0,0,'','','','','',''),(16,1,'Clearance',NULL,'','','','',0,'clearance',0,0,'','','','','',''),(17,1,'Mattress',NULL,'','','','',0,'mattress',0,0,'','','','','',''),(18,1,'Outdoor',NULL,'','','','',0,'outdoor',0,0,'','','','','','');
/*!40000 ALTER TABLE `categories_description` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `categories_images`
--

DROP TABLE IF EXISTS `categories_images`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `categories_images` (
  `categories_images_id` int(11) NOT NULL AUTO_INCREMENT,
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `image` varchar(256) NOT NULL DEFAULT '',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `image_types_id` int(11) NOT NULL DEFAULT '0',
  `position` varchar(64) NOT NULL DEFAULT '',
  `fit` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`categories_images_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `categories_images`
--

LOCK TABLES `categories_images` WRITE;
/*!40000 ALTER TABLE `categories_images` DISABLE KEYS */;
/*!40000 ALTER TABLE `categories_images` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `categories_platform_settings`
--

DROP TABLE IF EXISTS `categories_platform_settings`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `categories_platform_settings` (
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `categories_image` varchar(255) NOT NULL DEFAULT '',
  `categories_image_2` varchar(255) NOT NULL DEFAULT '',
  `show_on_home` int(1) NOT NULL DEFAULT '0',
  `maps_id` int(11) NOT NULL DEFAULT '0',
  `categories_image_3` varchar(128) NOT NULL DEFAULT '',
  `categories_image_4` varchar(128) NOT NULL DEFAULT '',
  UNIQUE KEY `idx_categories_id` (`categories_id`,`platform_id`),
  KEY `idx_platform_id` (`platform_id`,`show_on_home`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `categories_platform_settings`
--

LOCK TABLES `categories_platform_settings` WRITE;
/*!40000 ALTER TABLE `categories_platform_settings` DISABLE KEYS */;
/*!40000 ALTER TABLE `categories_platform_settings` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `categories_product_to_template`
--

DROP TABLE IF EXISTS `categories_product_to_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `categories_product_to_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `theme_name` varchar(256) NOT NULL DEFAULT '',
  `template_name` varchar(256) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `categories_product_to_template`
--

LOCK TABLES `categories_product_to_template` WRITE;
/*!40000 ALTER TABLE `categories_product_to_template` DISABLE KEYS */;
/*!40000 ALTER TABLE `categories_product_to_template` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `categories_to_template`
--

DROP TABLE IF EXISTS `categories_to_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `categories_to_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `theme_name` varchar(256) NOT NULL DEFAULT '',
  `template_name` varchar(256) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `categories_to_template`
--

LOCK TABLES `categories_to_template` WRITE;
/*!40000 ALTER TABLE `categories_to_template` DISABLE KEYS */;
/*!40000 ALTER TABLE `categories_to_template` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `categories_upsell`
--

DROP TABLE IF EXISTS `categories_upsell`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `categories_upsell` (
  `categories_upsell_id` int(11) NOT NULL AUTO_INCREMENT,
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `upsell_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`categories_upsell_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `categories_upsell`
--

LOCK TABLES `categories_upsell` WRITE;
/*!40000 ALTER TABLE `categories_upsell` DISABLE KEYS */;
/*!40000 ALTER TABLE `categories_upsell` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cats_products_upsell`
--

DROP TABLE IF EXISTS `cats_products_upsell`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `cats_products_upsell` (
  `cats_products_upsell_id` int(11) NOT NULL AUTO_INCREMENT,
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `upsell_products_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`cats_products_upsell_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cats_products_upsell`
--

LOCK TABLES `cats_products_upsell` WRITE;
/*!40000 ALTER TABLE `cats_products_upsell` DISABLE KEYS */;
/*!40000 ALTER TABLE `cats_products_upsell` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cats_products_xsell`
--

DROP TABLE IF EXISTS `cats_products_xsell`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `cats_products_xsell` (
  `cats_products_xsell_id` int(11) NOT NULL AUTO_INCREMENT,
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `xsell_products_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `xsell_type_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`cats_products_xsell_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cats_products_xsell`
--

LOCK TABLES `cats_products_xsell` WRITE;
/*!40000 ALTER TABLE `cats_products_xsell` DISABLE KEYS */;
/*!40000 ALTER TABLE `cats_products_xsell` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cities`
--

DROP TABLE IF EXISTS `cities`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `cities` (
  `city_id` int(11) NOT NULL AUTO_INCREMENT,
  `city_country_id` int(11) NOT NULL DEFAULT '0',
  `city_zone_id` int(11) NOT NULL DEFAULT '0',
  `city_code` varchar(32) NOT NULL DEFAULT '',
  `city_name` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`city_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cities`
--

LOCK TABLES `cities` WRITE;
/*!40000 ALTER TABLE `cities` DISABLE KEYS */;
/*!40000 ALTER TABLE `cities` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cloud_printers`
--

DROP TABLE IF EXISTS `cloud_printers`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `cloud_printers` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `service_id` int(11) NOT NULL DEFAULT '0',
  `cloud_printer_id` varchar(128) DEFAULT NULL,
  `cloud_printer_name` varchar(128) DEFAULT NULL,
  `status` int(11) NOT NULL DEFAULT '0',
  `date_added` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `idx_service` (`service_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cloud_printers`
--

LOCK TABLES `cloud_printers` WRITE;
/*!40000 ALTER TABLE `cloud_printers` DISABLE KEYS */;
/*!40000 ALTER TABLE `cloud_printers` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cloud_printers_documents`
--

DROP TABLE IF EXISTS `cloud_printers_documents`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `cloud_printers_documents` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `printer_id` int(11) DEFAULT NULL,
  `document_name` varchar(128) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cloud_printers_documents`
--

LOCK TABLES `cloud_printers_documents` WRITE;
/*!40000 ALTER TABLE `cloud_printers_documents` DISABLE KEYS */;
/*!40000 ALTER TABLE `cloud_printers_documents` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cloud_services`
--

DROP TABLE IF EXISTS `cloud_services`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `cloud_services` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `service` varchar(128) DEFAULT NULL,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `key` text,
  `date_added` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `idx_platform` (`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cloud_services`
--

LOCK TABLES `cloud_services` WRITE;
/*!40000 ALTER TABLE `cloud_services` DISABLE KEYS */;
/*!40000 ALTER TABLE `cloud_services` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `configuration`
--

DROP TABLE IF EXISTS `configuration`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `configuration` (
  `configuration_id` int(11) NOT NULL AUTO_INCREMENT,
  `configuration_title` varchar(64) NOT NULL DEFAULT '',
  `configuration_key` varchar(64) NOT NULL DEFAULT '',
  `configuration_value` varchar(2048) NOT NULL DEFAULT '',
  `configuration_description` varchar(255) NOT NULL DEFAULT '',
  `configuration_group_id` varchar(128) NOT NULL DEFAULT '',
  `sort_order` int(5) DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `date_added` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `use_function` varchar(255) DEFAULT NULL,
  `set_function` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`configuration_id`)
) ENGINE=InnoDB AUTO_INCREMENT=4777 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `configuration`
--

LOCK TABLES `configuration` WRITE;
/*!40000 ALTER TABLE `configuration` DISABLE KEYS */;
INSERT INTO `configuration` VALUES (9,'Switch To Default Language Currency','USE_DEFAULT_LANGUAGE_CURRENCY','false','Automatically switch to the language\'s currency when it is changed','BOX_CONFIGURATION_MYSTORE',10,'2018-01-11 15:27:55','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(11,'Use Search-Engine Safe URLs (still in development)','SEARCH_ENGINE_FRIENDLY_URLS','true','Use search-engine safe urls for all site links','',12,'2017-10-10 17:29:59','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(14,'Default Search Operator','ADVANCED_SEARCH_DEFAULT_OPERATOR','and','Default search operators','BOX_CONFIGURATION_MYSTORE',17,'2016-08-22 13:34:54','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'and\', \'or\'),'),(15,'Store Address and Phone','STORE_NAME_ADDRESS','Sergey Holbi\nstreet Holbi, Holbi TEST\nLondon\nFairford\nGLS\n61111\nUnited Kingdom','This is the Store Name, Address and Phone used on printable documents and displayed online','BOX_CONFIGURATION_TRASH',18,'2016-07-11 14:05:42','2003-07-17 10:29:22',NULL,'tep_cfg_textarea('),(17,'Tax Decimal Places','TAX_DECIMAL_PLACES','0','Pad the tax value this amount of decimal places','BOX_CONFIGURATION_MYSTORE',20,'2016-08-22 13:47:07','2003-07-17 10:29:22',NULL,NULL),(18,'Display Prices with Tax','DISPLAY_PRICE_WITH_TAX','true','Display prices with tax included (true) or add the tax at the end (false)','BOX_CONFIGURATION_MYSTORE',21,'2017-01-25 17:23:34','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(19,'First Name','ENTRY_FIRST_NAME_MIN_LENGTH','2','Minimum length of first name','BOX_CONFIGURATION_MINIMUM_VALUES',1,'2016-08-25 10:54:48','2003-07-17 10:29:22',NULL,NULL),(20,'Last Name','ENTRY_LAST_NAME_MIN_LENGTH','2','Minimum length of last name','BOX_CONFIGURATION_MINIMUM_VALUES',2,'2016-08-25 10:55:20','2003-07-17 10:29:22',NULL,NULL),(21,'Date of Birth','ENTRY_DOB_MIN_LENGTH','10','Minimum length of date of birth','BOX_CONFIGURATION_TRASH',3,'2006-07-21 14:41:56','2003-07-17 10:29:22',NULL,NULL),(22,'E-Mail Address','ENTRY_EMAIL_ADDRESS_MIN_LENGTH','6','Minimum length of e-mail address','BOX_CONFIGURATION_MINIMUM_VALUES',4,'2016-08-25 10:54:21','2003-07-17 10:29:22',NULL,NULL),(23,'Street Address','ENTRY_STREET_ADDRESS_MIN_LENGTH','5','Minimum length of street address','BOX_CONFIGURATION_MINIMUM_VALUES',5,'2016-08-25 10:57:13','2003-07-17 10:29:22',NULL,NULL),(25,'Post Code','ENTRY_POSTCODE_MIN_LENGTH','4','Minimum length of post code','BOX_CONFIGURATION_MINIMUM_VALUES',7,'2016-08-25 10:56:17','2003-07-17 10:29:22',NULL,NULL),(26,'City','ENTRY_CITY_MIN_LENGTH','3','Minimum length of city','BOX_CONFIGURATION_MINIMUM_VALUES',8,'2016-08-25 10:53:44','2003-07-17 10:29:22',NULL,NULL),(27,'State','ENTRY_STATE_MIN_LENGTH','2','Minimum length of state','BOX_CONFIGURATION_MINIMUM_VALUES',9,'2016-08-25 10:56:50','2003-07-17 10:29:22',NULL,NULL),(28,'Telephone Number','ENTRY_TELEPHONE_MIN_LENGTH','3','Minimum length of telephone number','BOX_CONFIGURATION_MINIMUM_VALUES',10,'2016-08-25 10:57:58','2003-07-17 10:29:22',NULL,NULL),(29,'Password Length','ENTRY_PASSWORD_MIN_LENGTH','12','Minimum length of password','BOX_CONFIGURATION_CUSTOMER_DETAILS',104,'2018-02-20 14:47:29','2003-07-17 10:29:22',NULL,NULL),(32,'Review Text','REVIEW_TEXT_MIN_LENGTH','50','Minimum length of review text','BOX_CONFIGURATION_TRASH',14,NULL,'2003-07-17 10:29:22',NULL,NULL),(35,'Address Book Entries','MAX_ADDRESS_BOOK_ENTRIES','5','Maximum address book entries a customer is allowed to have','BOX_CONFIGURATION_CUSTOMER_DETAILS',0,'2018-02-20 14:58:17','2003-07-17 10:29:22',NULL,NULL),(37,'Page Links','MAX_DISPLAY_PAGE_LINKS','6','Number of \'number\' links use for page-sets','BOX_CONFIGURATION_MAXIMUM_VALUES',3,'2016-09-09 17:12:59','2003-07-17 10:29:22',NULL,NULL),(39,'New Products Module','MAX_DISPLAY_NEW_PRODUCTS','8','Maximum number of new products to display in a category','BOX_CONFIGURATION_MAXIMUM_VALUES',5,'2016-10-27 15:42:51','2003-07-17 10:29:22',NULL,NULL),(44,'New Reviews','MAX_DISPLAY_NEW_REVIEWS','6','Maximum number of new reviews to display','BOX_CONFIGURATION_MAXIMUM_VALUES',9,'2016-08-25 11:04:07','2003-07-17 10:29:22',NULL,NULL),(45,'Selection of Random Reviews','MAX_RANDOM_SELECT_REVIEWS','2','How many records to select from to choose one random product review','BOX_CONFIGURATION_MAXIMUM_VALUES',10,'2016-08-25 11:09:34','2003-07-17 10:29:22',NULL,NULL),(53,'Order History','MAX_DISPLAY_ORDER_HISTORY','10','Maximum number of orders to display in the order history page','BOX_CONFIGURATION_MAXIMUM_VALUES',18,'2016-09-09 16:57:56','2003-07-17 10:29:22',NULL,NULL),(54,'Small Image Width','SMALL_IMAGE_WIDTH','210','The pixel width of small images','BOX_CONFIGURATION_TRASH',1,'2004-01-02 11:13:05','2003-07-17 10:29:22',NULL,NULL),(55,'Small Image Height','SMALL_IMAGE_HEIGHT','210','The pixel height of small images','BOX_CONFIGURATION_TRASH',2,'2004-01-02 11:13:01','2003-07-17 10:29:22',NULL,NULL),(60,'Calculate Image Size','CONFIG_CALCULATE_IMAGE_SIZE','true','Calculate the size of images?','BOX_CONFIGURATION_TRASH',7,'2006-03-24 17:59:28','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(61,'Image Required','IMAGE_REQUIRED','true','Enable to display broken images. Good for development.','BOX_CONFIGURATION_TRASH',8,'2004-10-13 00:17:21','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(62,'Gender','ACCOUNT_GENDER','visible','Display gender in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2017-08-02 14:22:31','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(63,'Date of Birth','ACCOUNT_DOB','disabled','Display date of birth in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2021-11-05 15:58:43','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(64,'Company','ACCOUNT_COMPANY','visible','Display company in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2017-06-21 14:05:13','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(65,'Suburb','ACCOUNT_SUBURB','visible','Display suburb in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2017-03-30 10:11:58','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(66,'State','ACCOUNT_STATE','visible','Display state in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2017-03-20 17:05:42','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'required\', \'required_register\'),'),(84,'Default Currency','DEFAULT_CURRENCY','GBP','Default Currency','BOX_CONFIGURATION_MODULE',0,'2003-09-06 22:01:21','2003-07-17 10:29:22',NULL,NULL),(85,'Default Language','DEFAULT_LANGUAGE','en','Default Language','BOX_CONFIGURATION_MODULE',0,NULL,'2003-07-17 10:29:22',NULL,NULL),(86,'Default Order Status For New Orders','DEFAULT_ORDERS_STATUS_ID','1','When a new order is created, this order status will be assigned to it.','BOX_CONFIGURATION_MODULE',0,'2006-07-27 15:07:56','2003-07-17 10:29:22',NULL,NULL),(100,'Enter the Maximum Package Weight you will ship','SHIPPING_MAX_WEIGHT','500','Carriers have a max weight limit for a single package. This is a common one for all.','BOX_CONFIGURATION_SHIPPING_PACKAGING',3,'2019-10-22 11:50:24','2003-07-17 10:29:22',NULL,NULL),(101,'Package Tare weight','SHIPPING_BOX_WEIGHT','0','What is the weight of typical packaging of small to medium packages?','BOX_CONFIGURATION_SHIPPING_PACKAGING',4,'2019-10-22 11:50:12','2003-07-17 10:29:22',NULL,NULL),(102,'Larger packages - percentage increase','SHIPPING_BOX_PADDING','0','For 10% enter 10','BOX_CONFIGURATION_SHIPPING_PACKAGING',5,'2018-02-20 15:03:33','2003-07-17 10:29:22',NULL,NULL),(103,'Display Product Image','PRODUCT_LIST_IMAGE','1','Do you want to display the Product Image?','TEXT_LISTING_PRODUCTS',1,'2018-02-20 15:04:59','2003-07-17 10:29:22',NULL,NULL),(104,'Display Product Manufaturer Name','PRODUCT_LIST_MANUFACTURER','0','Do you want to display the Product Manufacturer Name?','TEXT_LISTING_PRODUCTS',2,'2016-08-25 12:12:40','2003-07-17 10:29:22',NULL,NULL),(105,'Display Product Model','PRODUCT_LIST_MODEL','3','Do you want to display the Product Model?','TEXT_LISTING_PRODUCTS',3,'2016-08-25 12:13:08','2003-07-17 10:29:22',NULL,NULL),(106,'Display Product Name','PRODUCT_LIST_NAME','2','Do you want to display the Product Name?','TEXT_LISTING_PRODUCTS',4,'2016-08-25 12:13:47','2003-07-17 10:29:22',NULL,NULL),(107,'Display Product Price','PRODUCT_LIST_PRICE','5','Do you want to display the Product Price','TEXT_LISTING_PRODUCTS',5,'2016-08-25 12:14:14','2003-07-17 10:29:22',NULL,NULL),(108,'Display Product Quantity','PRODUCT_LIST_QUANTITY','0','Do you want to display the Product Quantity?','TEXT_LISTING_PRODUCTS',6,'2016-08-25 12:14:43','2003-07-17 10:29:22',NULL,NULL),(109,'Display Product Weight','PRODUCT_LIST_WEIGHT','0','Do you want to display the Product Weight?','TEXT_LISTING_PRODUCTS',7,'2016-08-25 12:15:41','2003-07-17 10:29:22',NULL,NULL),(110,'Display Buy Now column','PRODUCT_LIST_BUY_NOW','9','Do you want to display the Buy Now column?','TEXT_LISTING_PRODUCTS',8,'2016-08-25 12:11:42','2003-07-17 10:29:22',NULL,NULL),(114,'Subtract stock','STOCK_LIMITED','true','Subtract product in stock by product orders','TEXT_STOCK',2,'2017-03-15 15:46:15','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(116,'Mark product out of stock','STOCK_MARK_PRODUCT_OUT_OF_STOCK','***','Display something on screen so customer can see which product has insufficient stock','TEXT_STOCK',4,'2016-08-25 12:19:01','2003-07-17 10:29:22',NULL,NULL),(117,'Stock Re-order level','STOCK_REORDER_LEVEL','5','Define when stock needs to be re-ordered','TEXT_STOCK',5,'2018-02-20 15:06:57','2003-07-17 10:29:22',NULL,NULL),(118,'Store Page Parse Time','STORE_PAGE_PARSE_TIME','false','Store the time it takes to parse a page','BOX_CONFIGURATION_LOGGING',1,'2006-11-21 20:55:17','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(119,'Log Destination','STORE_PAGE_PARSE_TIME_LOG','/var/www/html/turbo/images/page_parse_time.log','Directory and filename of the page parse time log','BOX_CONFIGURATION_LOGGING',2,'2006-09-28 19:50:43','2003-07-17 10:29:22',NULL,NULL),(120,'Log Date Format','STORE_PARSE_DATE_TIME_FORMAT','%d/%m/%Y %H:%M:%S','The date format','BOX_CONFIGURATION_LOGGING',3,NULL,'2003-07-17 10:29:22',NULL,NULL),(121,'Display The Page Parse Time','DISPLAY_PAGE_PARSE_TIME','false','Display the page parse time (store page parse time must be enabled)','BOX_CONFIGURATION_LOGGING',4,'2006-11-21 20:55:24','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(122,'Store Database Queries','STORE_DB_TRANSACTIONS','false','Store the database queries in the page parse time log (PHP4 only)','BOX_CONFIGURATION_LOGGING',5,'2006-11-21 20:55:21','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(123,'Use Cache','USE_CACHE','false','Use caching features','BOX_CONFIGURATION_CACHE',1,'2004-10-17 02:44:17','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(124,'Cache Directory','DIR_FS_CACHE','/tmp/','The directory where the cached files are saved','BOX_CONFIGURATION_CACHE',2,'2003-07-17 10:42:27','2003-07-17 10:29:22',NULL,NULL),(125,'E-Mail Transport Method','EMAIL_TRANSPORT','sendmail','Defines if this server uses a local connection to sendmail or uses an SMTP connection via TCP/IP. Servers running on Windows and MacOS should change this setting to SMTP.','BOX_CONFIGURATION_E_MAIL_OPTIONS',1,'2019-10-22 10:50:04','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'sendmail\', \'smtp\'),'),(126,'E-Mail Linefeeds','EMAIL_LINEFEED','LF','Defines the character sequence used to separate mail headers.','BOX_CONFIGURATION_E_MAIL_OPTIONS',2,'2016-08-25 12:20:28','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'LF\', \'CRLF\'),'),(127,'Use MIME HTML When Sending Emails','EMAIL_USE_HTML','true','Send e-mails in HTML format','BOX_CONFIGURATION_E_MAIL_OPTIONS',3,'2018-02-20 15:09:12','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(128,'Verify E-Mail Addresses Through DNS','ENTRY_EMAIL_ADDRESS_CHECK','false','Verify e-mail address through a DNS server','BOX_CONFIGURATION_E_MAIL_OPTIONS',4,'2016-08-25 12:22:10','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(129,'Send E-Mails','SEND_EMAILS','true','Send out e-mails','BOX_CONFIGURATION_E_MAIL_OPTIONS',5,'2016-08-25 12:21:20','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(130,'Enable download','DOWNLOAD_ENABLED','true','Enable the products download functions.','BOX_CONFIGURATION_DOWNLOAD',1,'2017-09-20 15:56:16','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(131,'Download by redirect','DOWNLOAD_BY_REDIRECT','false','Use browser redirection for download. Disable on non-Unix systems.','BOX_CONFIGURATION_DOWNLOAD',2,'2003-12-23 22:27:01','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(132,'Expiry delay (days)','DOWNLOAD_MAX_DAYS','7','Set number of days before the download link expires. 0 means no limit.','BOX_CONFIGURATION_DOWNLOAD',3,'2016-08-25 12:24:40','2003-07-17 10:29:22',NULL,''),(133,'Maximum number of downloads','DOWNLOAD_MAX_COUNT','5','Set the maximum number of downloads. 0 means no download authorized.','BOX_CONFIGURATION_DOWNLOAD',4,'2016-08-25 12:25:09','2003-07-17 10:29:22',NULL,''),(136,'Session Directory','SESSION_WRITE_DIRECTORY','/tmp','If sessions are file based, store them in this directory.','BOX_CONFIGURATION_SESSIONS',1,'2016-08-25 12:33:18','2003-07-17 10:29:22',NULL,NULL),(137,'Force Cookie Use','SESSION_FORCE_COOKIE_USE','False','Force the use of sessions when cookies are only enabled.','BOX_CONFIGURATION_SESSIONS',2,'2016-08-25 12:32:04','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(138,'Check SSL Session ID','SESSION_CHECK_SSL_SESSION_ID','False','Validate the SSL_SESSION_ID on every secure HTTPS page request.','BOX_CONFIGURATION_SESSIONS',3,'2016-08-25 12:31:09','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(139,'Check User Agent','SESSION_CHECK_USER_AGENT','False','Validate the clients browser user agent on every page request.','BOX_CONFIGURATION_SESSIONS',4,'2016-08-25 12:31:35','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(140,'Check IP Address','SESSION_CHECK_IP_ADDRESS','False','Validate the clients IP address on every page request.','BOX_CONFIGURATION_SESSIONS',5,'2016-08-25 12:30:44','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(141,'Prevent Spider Sessions','SESSION_BLOCK_SPIDERS','True','Prevent known spiders from starting a session.','BOX_CONFIGURATION_SESSIONS',6,'2018-02-20 15:13:33','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(142,'Recreate Session','SESSION_RECREATE','False','Recreate the session to generate a new session ID when the customer logs on or creates an account (PHP >=4.1 needed).','BOX_CONFIGURATION_SESSIONS',7,'2016-08-25 12:32:54','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(235,'Product Featured Maximum Display','MAX_DISPLAY_FEATURED_PRODUCTS','4','Amount of products to display on main page','BOX_CONFIGURATION_MAXIMUM_VALUES',170,'2018-02-20 14:54:49','2003-08-14 00:25:08',NULL,NULL),(998,'Shipping Estimator','SHOW_SHIPPING_ESTIMATOR','true','Show Shipping Estimator on Shopping Cart','BOX_CONFIGURATION_SHIPPING_PACKAGING',102,'2018-02-20 15:00:47','2003-08-14 00:24:04',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(1124,'Downloads Controller Update Status Value','DOWNLOADS_ORDERS_STATUS_UPDATED_VALUE','4','What orders_status resets the Download days and Max Downloads - Default is 4','BOX_CONFIGURATION_DOWNLOAD',90,'2016-08-25 12:23:48','0000-00-00 00:00:00',NULL,NULL),(1125,'Downloads Controller Download on hold message','DOWNLOADS_CONTROLLER_ON_HOLD_MSG','<BR><font color=\"FF0000\">NOTE: Downloads are not available until payment has been confirmed</font>','Downloads Controller Download on hold message','BOX_CONFIGURATION_DOWNLOAD',91,'2016-08-25 12:22:36','0000-00-00 00:00:00',NULL,NULL),(1126,'Downloads Controller Order Status Value','DOWNLOADS_CONTROLLER_ORDERS_STATUS','4','Downloads Controller Order Status Value - Default=2','BOX_CONFIGURATION_DOWNLOAD',92,'2017-09-20 16:07:31','0000-00-00 00:00:00',NULL,'tep_cfg_select_download_status('),(1507,'Display Product Short Description','PRODUCT_LIST_SHORT_DESRIPTION','4','Do you want to display the Product Short description?','TEXT_LISTING_PRODUCTS',7,'2016-08-25 12:15:13','2003-07-17 10:29:22',NULL,NULL),(1574,'Button image type','BUTTON_IMAGE_TYPE','png','Type of images to use for buttons','BOX_CONFIGURATION_TRASH',100,'2005-03-10 14:52:58','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'png\', \'gif\'),'),(1578,'Company VAT-ID','ACCOUNT_COMPANY_VAT','visible','Display VAT-ID in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2022-06-01 16:44:43','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(3437,'Store Page Parse to special IP-address','STORE_PAGE_PARSE_IP','*','\'*\' means any ip-address','BOX_CONFIGURATION_LOGGING',6,'2008-02-26 18:39:08','2008-02-26 18:39:08',NULL,NULL),(3611,'Image resize','IMAGE_RESIZE','GD','Select utility or lib for image resizing','BOX_CONFIGURATION_TRASH',100673,'2014-10-17 13:15:16','2014-04-21 11:00:46',NULL,'tep_cfg_select_option(array(\'disable\', \'GD\', \'ImageMagick\'),'),(3612,'Convert utility','CONVERT_UTILITY','/path/to/convert','Full path to convert utility','BOX_CONFIGURATION_TRASH',100674,NULL,'2014-04-21 11:00:46',NULL,NULL),(3614,'SEO URL Parts - Products Model','SEARCH_ENGINE_UNHIDE','True','SHOW Products Model as a part of SEO URL?','',14,NULL,'2004-10-12 23:47:19',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(3615,'SEO URL Parts - Language Code','SEO_URL_PARTS_LANGUAGE','True','Show Language Code as a part of SEO URL?','BOX_CONFIGURATION_SEO_OPTIONS',11,'2018-02-20 15:23:13','2004-10-12 23:30:44',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(3622,'Use products properties?','PRODUCTS_PROPERTIES','True','Do you wish customers use products_properties module?','',14,NULL,'2004-11-10 00:21:49',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(3624,'Show totals on checkout page','ONE_PAGE_SHOW_TOTALS','false','Show totals on checkout page.','BOX_CONFIGURATION_ONEPAGE_CHECKOUT',2,'2014-04-21 11:00:47','2014-04-21 11:00:47',NULL,'tep_cfg_select_option(array(\'false\', \'true\'),'),(3625,'Create account options','ONE_PAGE_CREATE_ACCOUNT','false','false - create w random pass (def)<br>pass - can type own pass<br>onebuy - show checkbox <b>Create account</b> + pass','BOX_CONFIGURATION_ONEPAGE_CHECKOUT',4,'2014-04-21 11:00:47','2014-04-21 11:00:47',NULL,'tep_cfg_select_option(array(\'false\', \'onebuy\'),'),(3632,'Wide search type','MSEARCH_ENABLE','Like','Please choose wide search type','BOX_CONFIGURATION_WIDE_SEACH',0,'2022-01-04 13:19:52','2004-10-25 01:17:20',NULL,'tep_cfg_select_option(array(\'none\',\'Like\',\'Soundex\', \'Fulltext\'),'),(3633,'Use highlighting?','MSEARCH_HIGHLIGHT_ENABLE','true','Enable highlighting for search results?','BOX_CONFIGURATION_WIDE_SEACH',1,'2019-10-21 16:41:22','2004-10-25 01:17:20',NULL,'tep_cfg_select_option(array(\'true\',\'false\'),'),(3634,'Higlighting background color','MSEARCH_HIGHLIGHT_BGCOLOR','#FAE000','Colour of the highlighted words','BOX_CONFIGURATION_WIDE_SEACH',2,'2019-10-21 16:49:20','2005-11-23 11:54:45',NULL,NULL),(3635,'Minimum word length','MSEARCH_WORD_LENGTH','2','Minimal length of the word, that will be included in search','BOX_CONFIGURATION_WIDE_SEACH',5,'2019-10-21 16:49:28','2005-11-23 11:54:45',NULL,NULL),(3663,'WYSIWYG editor: popup or inline','WYSIWYG_EDITOR_POPUP_INLINE','inline','WYSIWYG editor: popup or inline','',17,'2017-05-15 15:45:45','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'popup\', \'inline\'),'),(3666,'Store Phone','STORE_PHONE','08000112569','Store Phone','BOX_CONFIGURATION_TRASH',18,NULL,'2014-04-21 11:00:48',NULL,NULL),(3673,'Search results - 1024','SEARCH_RESULTS_1','8','Search results - 1024','BOX_CONFIGURATION_TRASH',NULL,'2016-03-02 13:00:44','0000-00-00 00:00:00',NULL,NULL),(3681,'Installed Modules','','','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-09-14 10:58:22','2016-02-03 11:55:17',NULL,NULL),(3704,'Default visitor group','DEFAULT_USER_GROUP','1','The default user group for non logged user.','BOX_CONFIGURATION_CUSTOMER_DETAILS',3,'2019-10-21 17:07:07','2003-07-17 13:48:39',NULL,'tep_cfg_select_user_GROUP ('),(3705,'Default user group','DEFAULT_USER_LOGIN_GROUP','1','The default user group for new customers.','BOX_CONFIGURATION_CUSTOMER_DETAILS',1,'2019-10-21 17:07:04','2003-07-17 13:48:39',NULL,'tep_cfg_select_user_GROUP ('),(3706,'Customer can choose group','ENABLE_CUSTOMER_GROUP_CHOOSE','False','Customer can choose group during registration.','BOX_CONFIGURATION_CUSTOMER_DETAILS',4,'2019-10-21 17:07:11','2003-07-17 13:48:39',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(3729,'Use market prices?','USE_MARKET_PRICES','False','Do you wish customers use market prices?','',14,'2017-11-29 17:12:51','2004-11-01 18:20:24',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(3878,'Tracking Number URL','TRACKING_NUMBER_URL','http://www.17track.net/en/track?nums=','Tracking Number URL','',NULL,NULL,'0000-00-00 00:00:00',NULL,NULL),(3903,'HTTP Status Checker','HTTP_STATUS_CHECKER','https://httpstatus.io/?url=','HTTP Status Checker','BOX_CONFIGURATION_MYSTORE',300,'2016-08-22 13:45:07','0000-00-00 00:00:00',NULL,NULL),(4060,'Show Google Maps','SHOW_GOOGLE_MAPS','false','Show Google Maps on dashboard','BOX_CONFIGURATION_MYSTORE',200,'2016-09-09 16:36:01','0000-00-00 00:00:00',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4127,'Google Base fields','GOOGLE_BASE_FIELD_LIST','title','','',NULL,'2017-11-28 13:40:46','2016-10-22 00:00:00',NULL,NULL),(4146,'Maximum products in orders list','MAX_PRODUCTS_IN_ORDERS','3','Maximum products in orders list','BOX_CONFIGURATION_MYSTORE',200,'2016-11-16 13:02:59','0000-00-00 00:00:00',NULL,NULL),(4372,'Use auto giveaway','USE_AUTO_GIVEAWAY','false','Allow add giveaway product to shopping cart automatically','BOX_CONFIGURATION_MYSTORE',19,'2017-09-28 11:41:38','2003-08-02 13:42:39',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4373,'Purchase out of stock products','PURCHASE_OFF_STOCK','false','Purchase out of stock products','TEXT_STOCK',1,'2018-02-27 12:53:46','2017-01-10 17:42:39',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4376,'Firstname','ACCOUNT_FIRSTNAME','required_register','Display firstname in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2017-09-07 15:37:53','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4377,'Lastname','ACCOUNT_LASTNAME','required_register','Display lastname in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2017-09-07 15:39:08','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4378,'Telephone','ACCOUNT_TELEPHONE','visible','Display telephone in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2017-08-02 14:21:59','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4379,'Landline','ACCOUNT_LANDLINE','disabled','Display landline in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2017-08-02 14:22:06','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4380,'Postcode','ACCOUNT_POSTCODE','required','Display postcode in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2017-02-09 16:39:05','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4381,'Street address','ACCOUNT_STREET_ADDRESS','required','Display street address in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2017-09-07 15:42:00','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4382,'City','ACCOUNT_CITY','required','Display city in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2017-09-07 15:40:31','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4383,'Country','ACCOUNT_COUNTRY','required','Display country in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',5,'2017-09-07 15:39:58','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4384,'Landline Number','ENTRY_LANDLINE_MIN_LENGTH','3','Minimum length of landline number','BOX_CONFIGURATION_MINIMUM_VALUES',10,'2017-09-07 15:33:45','2003-07-17 10:29:22',NULL,NULL),(4385,'Demo Store','DEMO_STORE','false','Enable Demo Mode','BOX_CONFIGURATION_MYSTORE',19,'2019-10-21 15:17:05','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4389,'New Order Status manually paid part amount','ORDER_STATUS_PART_AMOUNT','100007','Update Order to this status after paid part amount manually','BOX_CONFIGURATION_EDIT_ORDER_SETTINGS',2,'2017-04-06 16:09:49','2017-04-06 16:09:49','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses('),(4390,'New Order Status manually paid full amount','ORDER_STATUS_FULL_AMOUNT','100006','Update Order to this status after paid full amount manually','BOX_CONFIGURATION_EDIT_ORDER_SETTINGS',3,'2018-02-20 15:16:07','2017-04-06 16:09:49','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses('),(4391,'Search in Description','SEARCH_IN_DESCRIPTION','False','Search in Description','BOX_CONFIGURATION_WIDE_SEACH',7,'2022-01-04 13:10:20','2017-04-10 19:15:51',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4422,'Server Time zone','TIMEZONE_SERVER','Europe/London','','BOX_CONFIGURATION_MYSTORE',1,'2017-05-19 04:48:05','2017-05-19 09:46:13',NULL,'time_zones_select('),(4423,'Google Base products platform','GOOGLE_BASE_PRODUCTS_PLATFORM_ID','6','','',NULL,NULL,'2017-05-22 13:12:01',NULL,NULL),(4424,'Google Base Google Shop platform','GOOGLE_BASE_SHOP_PLATFORM_ID','','','',NULL,NULL,'2017-05-22 13:12:01',NULL,NULL),(4428,'SEO URL - Use Full Categories Path','SEO_URL_FULL_CATEGORIES_PATH','False','SEO URL - Show Full Categories Path or only Current Category?','BOX_CONFIGURATION_MYSTORE',7777,'2017-09-14 11:00:45','2017-06-13 16:35:08',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4447,'Minimal Daily Orders','DAYLI_MINIMAL_ORDERS','5','Minimal quanity orders for daily report','',1,'2017-07-24 11:30:48','2017-07-24 11:30:48',NULL,NULL),(4451,'Show products on orders list','SHOW_PRODUCTS_ON_ORDER_LIST','False','Show products on order list','BOX_CONFIGURATION_MYSTORE',8,'2017-08-03 10:51:54','2017-08-03 18:20:24',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4452,'Enable Temporary Stock?','TEMPORARY_STOCK_ENABLE','true','Allocate temporary stock (subtract available stock) when the product is added to the shopping cart (for certain period).','TEXT_STOCK',33,'2017-08-22 12:34:48','2017-08-19 16:12:32',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4453,'Temporary Stock Period','TEMPORARY_STOCK_PERIOD','30','Period of inactivity (in minutes) during which (if the product was not ordered), the temporary stock will be released (added back to available stock).','TEXT_STOCK',34,'2017-09-27 16:35:18','2017-08-19 16:12:32',NULL,NULL),(4456,'Order Complete Statuses','ORDER_COMPLETE_STATUSES','4, 3, 1','Order Complete Statuses','BOX_CONFIGURATION_EDIT_ORDER_SETTINGS',999,'2017-10-12 14:59:23','2017-10-12 14:54:18','cfg_true_get_order_status','tep_cfg_select_multioption_order_statuses('),(4458,'Copy Source from site','USE_SOUCRCE_DURING_COPY','allow','Copy Source from site','BOX_CONFIGURATION_MYSTORE',2999,'2018-01-18 11:41:10','2017-10-23 14:33:06',NULL,'tep_cfg_select_option(array(\'allow\', \'allow_source\', \'disallow\'),'),(4459,'Use hreflang meta-tag','USE_HREFLANG_METATAG','True','Enable hreflang meta-tag?','BOX_CONFIGURATION_SEO_OPTIONS',7,'0000-00-00 00:00:00','0000-00-00 00:00:00',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4460,'Products Price Qty Round','PRODUCTS_PRICE_QTY_ROUND','false','Round up price before multiplying by products quantity (true) or round up price after multiplying by products quantity (false)','BOX_CONFIGURATION_MYSTORE',21,'2017-12-21 16:32:22','2017-12-19 18:19:12',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4468,'Pin','ACCOUNT_PIN','visible','Display Pin Code in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',100,NULL,'2018-01-30 11:13:33',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4470,'SEO URL Parts - Currency Code','SEO_URL_PARTS_CURRENCY','True','Show Currency Code as a part of SEO URL?','BOX_CONFIGURATION_SEO_OPTIONS',11,'2018-02-27 14:26:59','2018-02-20 18:20:57',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), '),(4474,'Display Product Popularity','PRODUCT_LIST_POPULARITY','10','Display Product Popularity','TEXT_LISTING_PRODUCTS',NULL,NULL,'0000-00-00 00:00:00',NULL,NULL),(4475,'Products popularity caclucalting days','POPULARITY_DAYS','30','Products popularity caclucalting days','BOX_CONFIGURATION_MYSTORE',NULL,NULL,'0000-00-00 00:00:00',NULL,NULL),(4477,'PDF Invoice','ATTACH_PDF_INVOICE','False','Attach PDF invoice','BOX_CONFIGURATION_MYSTORE',1400,'2017-05-29 14:44:02','2004-11-23 00:40:08',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4478,'PDF Invoice Attach Order Statuses','ATTACH_PDF_STATUS','3','Attach PDF invoice if Order Statuses is the following','BOX_CONFIGURATION_MYSTORE',14001,'0000-00-00 00:00:00','2018-04-04 17:33:39','cfg_true_get_order_status','tep_cfg_select_multioption_order_statuses('),(4480,'Dashboard Exclude Order Statuses','DASHBOARD_EXCLUDE_ORDER_STATUSES','5, 100001','Exclude the following Order Statuses from Dashboard','BOX_CONFIGURATION_MYSTORE',14007,'0000-00-00 00:00:00','2018-04-19 13:37:13','cfg_true_get_order_status','tep_cfg_select_multioption_order_statuses('),(4481,'Database revision','MIGRATIONS_DB_REVISION','63473','The current version of the database','',NULL,NULL,'0000-00-00 00:00:00',NULL,NULL),(4485,'Development mode','DEVELOPMENT_MODE','False','Enable development site mode?','BOX_CONFIGURATION_MYSTORE',11100,NULL,'2018-05-18 11:52:04',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4486,'Development mode - authentication username','DEVELOPMENT_MODE_USERNAME','protect','Basic authentication username','BOX_CONFIGURATION_MYSTORE',11110,NULL,'2018-05-18 11:52:04',NULL,NULL),(4487,'Development mode - authentication password','DEVELOPMENT_MODE_PASSWORD','2170288237','Basic authentication password','BOX_CONFIGURATION_MYSTORE',11111,NULL,'2018-05-18 11:52:04',NULL,NULL),(4488,'Title tag maximum length','META_TITLE_MAX_TAG_LENGTH','75','Title recommended length should be 75 characters or less','BOX_CONFIGURATION_SEO_OPTIONS',211,NULL,'2018-05-18 11:52:04',NULL,NULL),(4492,'Password Forgotten Mode','PASSWORD_FORGOTTEN_MODE','reset','Resert or invite to type new','BOX_CONFIGURATION_CUSTOMER_DETAILS',105,NULL,'2018-06-13 16:11:24',NULL,'tep_cfg_select_option(array(\'reset\', \'invite\'),'),(4498,'Save menu data like one input','MENU_DATA_LIKE_ONE_INPUT','False','Use if the menu is too large and max_input_vars is not enough','',215,NULL,'2018-06-21 10:52:56',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4500,'Catalog speed up design','CATALOG_SPEED_UP_DESIGN','200','','BOX_CONFIGURATION_MYSTORE',NULL,NULL,'0000-00-00 00:00:00',NULL,NULL),(4501,'Currency edit maximum precision','MAX_CURRENCY_EDIT_PRECISION','6','Number of decimal places for edit fields','BOX_CONFIGURATION_MAXIMUM_VALUES',270,NULL,'0000-00-00 00:00:00',NULL,NULL),(4502,'Price rule priority','SUPPLIER_PRICE_RULE_PRIORITY','Category,Brand,Supplier','','BOX_CATALOG_SUPPIERS',1,NULL,'2018-09-18 17:45:41',NULL,'cfg_supplier_price_rule_priority('),(4505,'Automatically Product Price selection','SUPPLIER_PRICE_SELECTION','Cheapest, In stock','','BOX_CATALOG_SUPPIERS',1,NULL,'2018-10-02 11:38:34',NULL,'cfg_supplier_price_select('),(4506,'Use Platform Prices Settings','PLATFORM_OWN_PRICE','false','Enable PLatform Prices Settings','BOX_CONFIGURATION_MYSTORE',101,NULL,'2018-11-05 17:30:32',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4508,'Use comment template?','COMMENT_TEMPLATE_STATUS','True','','BOX_CONFIGURATION_MYSTORE',14,NULL,'2018-11-05 17:30:33',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4509,'GDPR compliance','ACCOUNT_GDPR','true','Enable GDPR. Field date of birth required.','BOX_CONFIGURATION_CUSTOMER_DETAILS',0,'2019-10-21 17:07:00','2018-11-01 10:29:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4518,'Price selection mode','SUPPLIER_UPDATE_PRICE_MODE','Manual','','BOX_CATALOG_SUPPIERS',1,NULL,'2018-12-17 14:14:56',NULL,'cfg_supplier_price_selection_mode('),(4519,'Send BCC copy of all email to','ALL_EMAIL_BCC_COPY','','','BOX_CONFIGURATION_E_MAIL_OPTIONS',5,NULL,'2018-12-17 16:15:05',NULL,NULL),(4520,'Hide Discount coupon widget','HIDE_DISCOUNT_COUPON_WIDGET','false','','BOX_CONFIGURATION_MYSTORE',100,'2018-12-17 16:15:05','2018-12-17 16:15:05',NULL,'tep_cfg_select_option(array(\"false\", \"true\"),'),(4521,'Gender','SHIPPING_GENDER','disabled','Display gender in the customers account','BOX_SHIPPING_CUSTOMER_DETAILS',5,'2022-06-24 18:04:44','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4522,'Company','SHIPPING_COMPANY','disabled','Display company in the customers account','BOX_SHIPPING_CUSTOMER_DETAILS',5,'2022-06-24 18:04:52','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4523,'Suburb','SHIPPING_SUBURB','disabled','Display suburb in the customers account','BOX_SHIPPING_CUSTOMER_DETAILS',5,'2022-06-24 18:05:01','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4524,'State','SHIPPING_STATE','disabled','Display state in the customers account','BOX_SHIPPING_CUSTOMER_DETAILS',5,'2022-06-24 18:05:06','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'required\', \'required_register\'),'),(4525,'Company VAT-ID','SHIPPING_COMPANY_VAT','disabled','Display VAT-ID in the customers account','BOX_SHIPPING_CUSTOMER_DETAILS',5,'2022-06-24 18:05:10','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4526,'Firstname','SHIPPING_FIRSTNAME','required_register','Display firstname in the customers account','BOX_SHIPPING_CUSTOMER_DETAILS',5,'2017-09-07 15:37:53','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4527,'Lastname','SHIPPING_LASTNAME','required_register','Display lastname in the customers account','BOX_SHIPPING_CUSTOMER_DETAILS',5,'2017-09-07 15:39:08','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4528,'Postcode','SHIPPING_POSTCODE','required','Display postcode in the customers account','BOX_SHIPPING_CUSTOMER_DETAILS',5,'2017-02-09 16:39:05','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4529,'Street address','SHIPPING_STREET_ADDRESS','required','Display street address in the customers account','BOX_SHIPPING_CUSTOMER_DETAILS',5,'2017-09-07 15:42:00','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4530,'City','SHIPPING_CITY','required','Display city in the customers account','BOX_SHIPPING_CUSTOMER_DETAILS',5,'2017-09-07 15:40:31','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4531,'Country','SHIPPING_COUNTRY','required','Display country in the customers account','BOX_SHIPPING_CUSTOMER_DETAILS',5,'2017-09-07 15:39:58','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4536,'Gender','BILLING_GENDER','disabled','Display gender in the customers account','BOX_BILLING_CUSTOMER_DETAILS',5,'2022-06-24 18:06:37','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4537,'Company','BILLING_COMPANY','disabled','Display company in the customers account','BOX_BILLING_CUSTOMER_DETAILS',5,'2022-06-24 18:06:43','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4538,'Suburb','BILLING_SUBURB','disabled','Display suburb in the customers account','BOX_BILLING_CUSTOMER_DETAILS',5,'2022-06-24 18:06:48','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4539,'State','BILLING_STATE','disabled','Display state in the customers account','BOX_BILLING_CUSTOMER_DETAILS',5,'2022-06-24 18:06:54','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'required\', \'required_register\'),'),(4540,'Company VAT-ID','BILLING_COMPANY_VAT','disabled','Display VAT-ID in the customers account','BOX_BILLING_CUSTOMER_DETAILS',5,'2022-06-24 18:06:59','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4541,'Firstname','BILLING_FIRSTNAME','required_register','Display firstname in the customers account','BOX_BILLING_CUSTOMER_DETAILS',5,'2017-09-07 15:37:53','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4542,'Lastname','BILLING_LASTNAME','required_register','Display lastname in the customers account','BOX_BILLING_CUSTOMER_DETAILS',5,'2017-09-07 15:39:08','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4543,'Postcode','BILLING_POSTCODE','required','Display postcode in the customers account','BOX_BILLING_CUSTOMER_DETAILS',5,'2017-02-09 16:39:05','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4544,'Street address','BILLING_STREET_ADDRESS','required','Display street address in the customers account','BOX_BILLING_CUSTOMER_DETAILS',5,'2017-09-07 15:42:00','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4545,'City','BILLING_CITY','required','Display city in the customers account','BOX_BILLING_CUSTOMER_DETAILS',5,'2017-09-07 15:40:31','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4546,'Country','BILLING_COUNTRY','required','Display country in the customers account','BOX_BILLING_CUSTOMER_DETAILS',5,'2017-09-07 15:39:58','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4552,'Assigned shipping','SHIPPING_UNSELECTED','unselected','Assign cheapest shipping or use unselected by default','BOX_CONFIGURATION_EDIT_ORDER_SETTINGS',6,'2019-03-27 16:25:08','2019-01-15 15:47:21',NULL,'tep_cfg_select_option(array(\'unselected\', \'cheapest\'),'),(4553,'Assigned payment','PAYMENT_UNSELECTED','unselected','Assign default payment or use unselected','BOX_CONFIGURATION_EDIT_ORDER_SETTINGS',7,'2019-03-27 16:25:05','2019-01-15 15:47:21',NULL,'tep_cfg_select_option(array(\'unselected\', \'default\'),'),(4554,'Email','ACCOUNT_EMAIL','required_register','Display email in the customers account','BOX_CONFIGURATION_CUSTOMER_DETAILS',8,'2017-02-07 16:54:44','2003-07-17 10:29:22',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4555,'Preferred cheapest','PREFERRED_CHEAPEST_TYPE','delivery','Preferred cheapest from Delivery or Pickup','BOX_CONFIGURATION_SHIPPING_PACKAGING',100,'2019-10-22 10:47:37','2019-01-15 15:47:22',NULL,'tep_cfg_select_option(array(\'delivery\', \'pickup\'),'),(4557,'Orders Not Processed Filter Statuses','ORDERS_NOT_PROCESSED_ORDER_STATUSES','2, 100007, 100026, 100006, 100009','Filter Only the selected Order Statuses','BOX_CONFIGURATION_MYSTORE',14007,NULL,'2019-01-22 17:02:24','cfg_true_get_order_status','tep_cfg_select_multioption_order_statuses('),(4558,'Stock Re-order quantity','STOCK_REORDER_QUANTITY','10','Define quantity of stock needs to be re-ordered','TEXT_STOCK',5,'2019-10-22 10:49:47','2019-02-08 13:43:58',NULL,NULL),(4559,'Domain','CPANEL_PARENT_DOMAIN','','Control panel domain','BOX_CONFIGURATION_PANEL',0,'2016-08-25 10:53:44','2003-07-17 10:29:22',NULL,NULL),(4560,'Config path','CPANEL_PARENT_PATH','','Control panel script path','BOX_CONFIGURATION_PANEL',1,'2016-08-25 10:53:44','2003-07-17 10:29:22',NULL,NULL),(4561,'SVN','CPANEL_SVN_LINK','','Control panel svn link','BOX_CONFIGURATION_PANEL',2,'2016-08-25 10:53:44','2003-07-17 10:29:22',NULL,NULL),(4562,'Control panel','CPANEL_TYPE','cPanel','Used web hosting control panel','BOX_CONFIGURATION_PANEL',3,NULL,'2016-08-25 10:53:44',NULL,'tep_cfg_select_option(array(\'cPanel\', \'Virtualmin\'),'),(4563,'User prefix','CPANEL_USER_PREFIX','user','Used user name for department creation','BOX_CONFIGURATION_PANEL',3,NULL,'2016-08-25 10:53:44',NULL,NULL),(4567,'First Shipping Selected (rather cheapest)','DEFAULT_SHIPPING_BY_SORT_ORDER','False','First shipping module in list is selected by default (rather cheapest)','BOX_CONFIGURATION_SHIPPING_PACKAGING',70,'2019-10-22 10:47:55','2019-02-03 18:20:24',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4568,'Order cancellation Status on temporary allocation expiration','ORDER_STATUS_TEMPORARY_ALLOCATION_EXPIRED','0','Set selected Order Status when temporary stock allocation has expired','BOX_CONFIGURATION_EDIT_ORDER_SETTINGS',10,'2019-03-13 19:47:44','2019-03-13 19:47:44','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses('),(4569,'Temporary allocation expiration (hours)','ORDER_STATUS_TEMPORARY_ALLOCATION_EXPIRED_DURATION','72','Order\'s temporary allocated stock will be considered as expired after (hours)','BOX_CONFIGURATION_EDIT_ORDER_SETTINGS',11,'2019-03-13 19:47:44','2019-03-13 19:47:44','',''),(4570,'Use Reminder?','EMAIL_REMINDER_AFTER_YEAR','False','Reminder after 12 months','BOX_CONFIGURATION_E_MAIL_OPTIONS',14,'2019-03-27 15:19:14','2018-12-18 18:20:24',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4571,'Activate listing sub products?','LISTING_SUB_PRODUCT','False','','',NULL,'2022-01-04 11:58:46','2019-04-09 09:12:43',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4573,'Default Order Status For Online Payments','DEFAULT_ONLINE_PAYMENT_ORDERS_STATUS_ID','1','Default Order Status For Online Payments','BOX_CONFIGURATION_MYSTORE',1,NULL,'2019-05-03 13:03:38',NULL,NULL),(4574,'SMTP Mailer','SMTP_MAILER','None','SMTP Mailer','BOX_CONFIGURATION_E_MAIL_OPTIONS',6,'2019-10-22 10:50:21','0000-00-00 00:00:00','','tep_cfg_select_option(array(\'None\', \'Mandrill\',\'Swiftmailer\'),'),(4575,'SMTP Mailer Mandrill ApiKey','MANDRILL_APIKEY','','SMTP Mailer Mandrill ApiKey','BOX_CONFIGURATION_E_MAIL_OPTIONS',7,'2019-10-22 10:50:26','0000-00-00 00:00:00','',''),(4576,'Skip confirmation page','SKIP_CHECKOUT','True','Disable checkout confirmation page?','BOX_CONFIGURATION_MYSTORE',0,'2022-01-14 15:01:53','2019-04-22 18:20:24',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4577,'Backend internal product name','BACKEND_PRODUCT_NAME_FORMAT','','Use internal product name on','BOX_CONFIGURATION_MYSTORE',3245,NULL,'2019-05-14 14:03:48','getBackendProductName','setBackendProductName('),(4578,'Disable inventory images (edit product too slow)','ADMIN_TOO_MANY_IMAGES','20','Disable inventory image module (admin) if more than NN images are uploaded ','BOX_CONFIGURATION_MAXIMUM_VALUES',3245,NULL,'2019-05-20 14:50:39','',''),(4580,'Show child product stock on bundle assigned products list','BUNDLE_CHILD_NAME_SHOW_STOCK','False','Add child product stock to child product name on bundle assigned products list','TEXT_LISTING_PRODUCTS',1000,NULL,'0000-00-00 00:00:00',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4581,'Show child product SKU on bundle assigned products list','BUNDLE_CHILD_NAME_SHOW_SKU','False','Add child product SKU to child product name on bundle assigned products list','TEXT_LISTING_PRODUCTS',1010,NULL,'0000-00-00 00:00:00',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4582,'Customer Basket Share','SHOPPING_CART_SHARE','True','Share customer basket between frontends','BOX_CONFIGURATION_MYSTORE',35,NULL,'2019-07-10 16:14:48',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4586,'Prices with back calculated tax','PRICE_WITH_BACK_TAX','False','Use product prices with back calculated tax','BOX_CONFIGURATION_MYSTORE',22,NULL,'0000-00-00 00:00:00',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4587,'Search suggest blocks','SEARCH_SUGGEST_BLOCKS_ORDER','Products, Manufacturers, Information','Display search suggest blocks in following sort order','BOX_CONFIGURATION_WIDE_SEACH',36,'2022-01-04 11:59:17','2019-08-20 16:10:21',NULL,'cfgMultiSortable(array(\'Products\', \'Manufacturers\', \'Information\', \'Categories\'),'),(4588,'Allow save tokens (OpenSSL is required)','USE_TOKENS_IN_PAYMENT_METHODS','False','Switching it off will clean up all saved tokens in the system','BOX_BILLING_CUSTOMER_DETAILS',35,NULL,'2019-08-20 16:10:21',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4589,'Google Base gtin fields','GOOGLE_BASE_GTIN_CONFIG','upc,ean,-isbn','','',NULL,NULL,'2019-09-19 14:47:31',NULL,NULL),(4590,'Round tax per row','TAX_ROUND_PER_ROW','False','On total tax calculation round each row (product) before sum','BOX_CONFIGURATION_MYSTORE',NULL,NULL,'2019-09-19 14:47:32',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4591,'2-step backend authorization','ADMIN_TWO_STEP_AUTH_ENABLED','false','Enable 2-step backend authorization for administrators?','BOX_CONFIGURATION_MYSTORE',0,'2019-09-19 16:47:43','2019-09-19 16:47:43',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4592,'2-step backend authorization service','ADMIN_TWO_STEP_AUTH_SERVICE','email','<span style=\"color:red\">Double check SMS service settings before using it. You won\'t be able to access admin panel if it\'s wrong.</span>','BOX_CONFIGURATION_MYSTORE',0,'2019-09-19 16:47:43','2019-09-19 16:47:43',NULL,'tep_cfg_select_option(array(\'email\', \'sms\'),'),(4593,'Multi-sessions are allowed?','ADMIN_MULTI_SESSION_ENABLED','true','Allow multiple active logins for same administrator from different devices?','',0,'2019-09-19 16:47:44','2019-09-19 16:47:44',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4594,'2-step backend authorization SMS service','ADMIN_TWO_STEP_AUTH_SERVICE_SMS','','2-step backend authorization SMS with security key should be delivered by?','BOX_CONFIGURATION_MYSTORE',0,'2019-09-19 16:47:44','2019-09-19 16:47:44',NULL,'tep_cfg_select_option(\\common\\extensions\\SmsService\\SmsService::getServiceValidConfigurationList(),'),(4595,'SMTP Host','SMTP_HOST','','Define Host for SMTP connection','BOX_CONFIGURATION_E_MAIL_OPTIONS',8,'2019-10-22 10:50:31','0000-00-00 00:00:00','',''),(4596,'SMTP Port','SMTP_PORT','','Define Port for SMTP connection','BOX_CONFIGURATION_E_MAIL_OPTIONS',9,'2019-10-22 10:50:36','0000-00-00 00:00:00','',''),(4597,'SMTP Username','SMTP_USERNAME','','Define Username for SMTP connection','BOX_CONFIGURATION_E_MAIL_OPTIONS',10,'2019-10-22 10:50:40','0000-00-00 00:00:00','',''),(4598,'SMTP Password','SMTP_PASSWORD','','Define Password for SMTP connection','BOX_CONFIGURATION_E_MAIL_OPTIONS',11,'2019-10-22 10:50:45','0000-00-00 00:00:00','',''),(4602,'Show \"Please select\" option in product attributes','PRODUCTS_ATTRIBUTES_SHOW_SELECT','False','Show \"Please select\" option in product attributes','TEXT_LISTING_PRODUCTS',NULL,NULL,'2019-10-03 17:56:22',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4608,'Volume Weight Coefficient','VOLUME_WEIGHT_COEFFICIENT','4000','Volume Weight Coefficient','BOX_CONFIGURATION_SHIPPING_PACKAGING',0,NULL,'2019-11-12 15:25:02',NULL,NULL),(4612,'Product activity stat view coefficient','PRODUCTS_ACTIVITY_VIEW_COEFFICIENT','0','Product activity stat marketing: view coefficient','BOX_CONFIGURATION_MYSTORE',1000,NULL,'2019-12-06 15:06:24',NULL,NULL),(4613,'Product activity stat view min','PRODUCTS_ACTIVITY_VIEW_MIN','0','Product activity stat marketing: view min value','BOX_CONFIGURATION_MYSTORE',1001,NULL,'2019-12-06 15:06:24',NULL,NULL),(4614,'Product activity stat view max','PRODUCTS_ACTIVITY_VIEW_MAX','0','Product activity stat marketing: view max value','BOX_CONFIGURATION_MYSTORE',1002,NULL,'2019-12-06 15:06:24',NULL,NULL),(4615,'Product activity stat in cart coefficient','PRODUCTS_ACTIVITY_CART_COEFFICIENT','0','Product activity stat marketing: in cart coefficient','BOX_CONFIGURATION_MYSTORE',1003,NULL,'2019-12-06 15:06:24',NULL,NULL),(4616,'Product activity stat in cart min','PRODUCTS_ACTIVITY_CART_MIN','0','Product activity stat marketing: in cart min value','BOX_CONFIGURATION_MYSTORE',1003,NULL,'2019-12-06 15:06:24',NULL,NULL),(4617,'Product activity stat in cart max','PRODUCTS_ACTIVITY_CART_MAX','0','Product activity stat marketing: in cart max value','BOX_CONFIGURATION_MYSTORE',1005,NULL,'2019-12-06 15:06:24',NULL,NULL),(4622,'Allow redirect customer to language locale?','ALLOW_LOCALE_REDIRECT','Browser','Allow redirect customer to language locale?','',NULL,NULL,'2019-12-23 16:00:47',NULL,'tep_cfg_select_option(array(\'Browser\', \'Ip\', \'Disable\'),'),(4623,'Display Both Prices','DISPLAY_BOTH_PRICES','False','Display Both Prices with and without Tax','BOX_CONFIGURATION_MYSTORE',100,NULL,'2020-01-10 18:06:21','','tep_cfg_select_option(array(\'True\', \'False\'),'),(4624,'Billing address is shown first','BILLING_FIRST','False','Billing address is shown first on checkout, so \"same as\" appears on shipping address','BOX_CONFIGURATION_MYSTORE',101,NULL,'2020-01-10 18:06:21','','tep_cfg_select_option(array(\'True\', \'False\'),'),(4625,'Product listing default sort order','PRODUCT_LISTING_DEFAULT_SORT_ORDER','','Product listing default sort order','TEXT_LISTING_PRODUCTS',101,NULL,'2020-01-10 18:06:21','getListingSortOrder','setListingSortOrder('),(4630,'Display review rating title','DISPLAY_REVIEW_RATING_TITLE','False','Display review rating title next to stars','BOX_CONFIGURATION_MYSTORE',NULL,NULL,'2020-02-17 10:39:57',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4631,'Telephone','SHIPPING_TELEPHONE','disabled','Display telephone in the account shipping details','BOX_SHIPPING_CUSTOMER_DETAILS',36,NULL,'2020-02-18 18:34:20',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4632,'Telephone','BILLING_TELEPHONE','disabled','Display telephone in the account billing details','BOX_BILLING_CUSTOMER_DETAILS',36,NULL,'2020-02-18 18:34:20',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\'),'),(4634,'Meta description length','META_DESCRIPTION_TAG_LENGTH','160','Meta description length','BOX_CONFIGURATION_SEO_OPTIONS',220,NULL,'2020-03-24 19:20:14',NULL,NULL),(4635,'H tags set inline and clear styles','SEO_H_TAG_INLINE','False','h2, h3, h4, h5, h6 tags set inline and clear styles','BOX_CONFIGURATION_SEO_OPTIONS',230,NULL,'2020-04-08 13:48:17',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4636,'Google shopping product type','JSONLD_PRODUCT_TYPE','Product','Google shopping product type','BOX_CONFIGURATION_SEO_OPTIONS',240,NULL,'2020-04-14 12:13:05',NULL,'tep_cfg_select_option(array(\'Product\', \'Service\'),'),(4637,'Require strong password','PASSWORD_STRONG_REQUIRED','ULN','Password must contain at least (ULN - UpperCase, LowerCase, Number; ULNS - UpperCase, LowerCase, Number, SpecialChar):','BOX_CONFIGURATION_CUSTOMER_DETAILS',106,NULL,'0000-00-00 00:00:00','','tep_cfg_select_option(array(\'None\', \'ULN\', \'ULNS\'),'),(4638,'Product image field color','PRODUCT_IMAGE_FIELD_COLOR','','if you set this value then product pictures will be generated of a certain size and empty fields on the sides are filled with this color','BOX_CONFIGURATION_MYSTORE',1420,NULL,'2020-04-20 18:41:11',NULL,'tep_cfg_color('),(4639,'Filter display mode - Brand','BRANDS_FILTER_DISPLAY_MODE','boxes','Show brands (manufacturers) filter as','TEXT_LISTING_PRODUCTS',888,NULL,'2020-04-20 18:41:12','','tep_cfg_select_option(array(\'boxes\', \'radio\', \'pulldown\'),'),(4640,'Filter display mode - Categories','CATEGORIES_FILTER_DISPLAY_MODE','boxes','Show categories filter as','TEXT_LISTING_PRODUCTS',888,NULL,'2020-04-20 18:41:12','','tep_cfg_select_option(array(\'boxes\', \'radio\', \'pulldown\'),'),(4641,'Filter display mode - Attributes','ATTRIBUTES_FILTER_DISPLAY_MODE','boxes','Show attributes filter as','TEXT_LISTING_PRODUCTS',888,NULL,'2020-04-20 18:41:12','','tep_cfg_select_option(array(\'boxes\', \'radio\', \'pulldown\'),'),(4642,'Backend theme name','BACKEND_THEME_NAME','backend','Backend theme name','BOX_CONFIGURATION_MYSTORE',1430,NULL,'2020-06-03 20:56:17','',''),(4643,'Allow use credit amount','ALLOW_CUSTOMER_CREDIT_AMOUNT','true','Allow use credit amount for customers','BOX_CONFIGURATION_CUSTOMER_DETAILS',4,NULL,'2020-07-06 11:33:21','','tep_cfg_select_option(array(\'true\', \'false\'),'),(4644,'Mark products as new, days','NEW_MARK_UNTIL_DAYS','0','Mark product as new for NN days after adding','BOX_CONFIGURATION_MYSTORE',230,NULL,'2020-07-06 11:33:21',NULL,NULL),(4645,'Password Length','ADMIN_PASSWORD_MIN_LENGTH','12','Minimum length of password','BOX_CONFIGURATION_ADMIN',10,NULL,'2020-07-21 12:05:45',NULL,NULL),(4646,'Require strong password','ADMIN_PASSWORD_STRONG','ULN','Password must contain at least (ULN - UpperCase, LowerCase, Number; ULNS - UpperCase, LowerCase, Number, SpecialChar):','BOX_CONFIGURATION_ADMIN',20,NULL,'2020-07-21 12:05:45',NULL,'tep_cfg_select_option(array(\'None\', \'ULN\', \'ULNS\'),'),(4647,'Password expiration','ADMIN_PASSWORD_EXPIRE','Never','Required change password after:','BOX_CONFIGURATION_ADMIN',30,NULL,'2020-07-21 12:05:45',NULL,'tep_cfg_select_option(array(\'Never\', \'1 Week\', \'2 Weeks\', \'1 Month\', \'3 Months\', \'6 Months\'),'),(4648,'Ban easy password','ADMIN_PASSWORD_BAN_EASY','True','Check known passwords list','BOX_CONFIGURATION_ADMIN',40,NULL,'2020-07-21 12:05:45',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4649,'Ban use of the same password','ADMIN_PASSWORD_USE_SAME','True','Do not allow old passwords to be used.','BOX_CONFIGURATION_ADMIN',50,NULL,'2020-07-21 12:05:45',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4651,'PayPal Partner program keyword','PAYPAL_PARTNER_KEYWORD','!aSGj9np1_NxxHkdF','PayPal Partner program keyword (do not change)','BOX_CONFIGURATION_MYSTORE',1000,NULL,'2020-09-08 10:04:37',NULL,NULL),(4653,'Popularity - \"New product\" weight','POPULARITY_WEIGHT_NEW_PRODUCT','5','Add to Product Popularity if it\'s marked as new','TEXT_LISTING_PRODUCTS',5000,NULL,'2020-10-19 11:54:11',NULL,NULL),(4654,'Popularity - purchased last 7 days weight','POPULARITY_WEIGHT_PUCHASE_WEEK','1','Multiple purchased q-ty (last 7 days)','TEXT_LISTING_PRODUCTS',5001,NULL,'2020-10-19 11:54:11',NULL,NULL),(4655,'Popularity - purchased last month weight','POPULARITY_WEIGHT_PUCHASE_MONTH','0.5','Multiple purchased q-ty (last month)','TEXT_LISTING_PRODUCTS',5002,NULL,'2020-10-19 11:54:11',NULL,NULL),(4656,'Popularity - purchased all time weight','POPULARITY_WEIGHT_PUCHASE','0.02','Multiple purchased q-ty (all time)','TEXT_LISTING_PRODUCTS',5003,NULL,'2020-10-19 11:54:11',NULL,NULL),(4657,'Popularity - q-ty added to wishlist weight','POPULARITY_WEIGHT_WISHLIST','2','Multiple q-ty added to wishlist','TEXT_LISTING_PRODUCTS',5004,NULL,'2020-10-19 11:54:11',NULL,NULL),(4658,'Popularity - view last 7 days weight','POPULARITY_WEIGHT_VIEW_WEEK','0.02','Multiple number of views (last 7 days)','TEXT_LISTING_PRODUCTS',5005,NULL,'2020-10-19 11:54:11',NULL,NULL),(4659,'Popularity - view last 30 days weight','POPULARITY_WEIGHT_VIEW_MONTH','0.01','Multiple number of views (last 30 days)','TEXT_LISTING_PRODUCTS',5006,NULL,'2020-10-19 11:54:11',NULL,NULL),(4660,'Popularity - view weight','POPULARITY_WEIGHT_VIEW','0.001','Multiple number of views (lifetime)','TEXT_LISTING_PRODUCTS',5007,NULL,'2020-10-19 11:54:11',NULL,NULL),(4661,'Request fields for forgot password','RESET_PASSWORD_FIELDS','firstname','Additional fields to ask before reset password','BOX_CONFIGURATION_ADMIN',10,'2021-12-24 14:31:10','2020-10-19 11:54:11','','cfgMultiSortable(array(\'firstname\', \'lastname\',\'username\',\'phone\'),'),(4662,'Packing slips Summary','PACKING_SLIPS_SUMMARY','False','Add summary products listing to Packing slips','BOX_CONFIGURATION_SHIPPING_PACKAGING',0,'2020-10-27 10:26:10','2020-10-27 10:26:10','','tep_cfg_select_option(array(\'True\', \'False\'),'),(4663,'Session name postfix','SESSION_NAME_POSTFIX','Sale Channel Id','','BOX_CONFIGURATION_SESSIONS',NULL,'2022-01-21 10:03:03','2020-11-02 15:11:03',NULL,'tep_cfg_select_option(array(\'None\', \'Sale Channel Id\'),'),(4664,'Switch on/off featured status by cron','EXPIRE_FEATURED_BY_CRON','False','Switch on/off featured status by cron (rather page visit). Please ensure the cron is set up.','BOX_CONFIGURATION_MYSTORE',10,NULL,'2020-11-02 15:11:03',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4665,'Switch on/off specials status by cron','EXPIRE_SPECIALS_BY_CRON','False','Switch on/off specials status by cron (rather page visit). Please ensure the cron is set up.','BOX_CONFIGURATION_MYSTORE',10,NULL,'2020-11-02 15:11:03',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4666,'Anonimize orders on customer delete','ANONIMIZE_ORDERS_ON_CUSTOMER_DELETE','False','Anonimize orders on customer delete','BOX_CONFIGURATION_CUSTOMER_DETAILS',501,NULL,'2020-11-12 09:41:38',NULL,'tep_cfg_select_option(array(\'False\', \'True\'),'),(4667,'Dont allow customer to delete account himself','GDPR_CUSTOMER_DELETE_BY_REQUEST','True','Delete account by request only (in admin)','BOX_CONFIGURATION_CUSTOMER_DETAILS',501,NULL,'2020-11-12 09:41:38',NULL,'tep_cfg_select_option(array(\'False\', \'True\'),'),(4668,'GDPR Open orders statuses','GDPR_CUSTOMER_DELETE_OPEN_ORDER_STATUSES','','Don\'t allow delete account if exists order in the following statuses','BOX_CONFIGURATION_CUSTOMER_DETAILS',501,NULL,'2020-11-12 09:41:38','cfg_true_get_order_status','tep_cfg_select_multioption_order_statuses('),(4669,'SEO URL - Sales Only Filter Key','SEO_URL_SALES_ONLY_FILTER_KEY','sales-only','SEO URL - Sales Only Filter Key','BOX_CONFIGURATION_MYSTORE',7778,NULL,'2020-11-12 09:41:38',NULL,NULL),(4670,'Password Forgotten Mode','ADMIN_PASSWORD_FORGOTTEN_MODE','invite','Resert or invite to type new','BOX_CONFIGURATION_ADMIN',15,NULL,'2020-11-12 09:41:38',NULL,'tep_cfg_select_option(array(\'reset\', \'invite\'),'),(4671,'Top Text','TOP_TEXT_SWITCHER','False','Top Text Enable','BOX_CONFIGURATION_MYSTORE',4,NULL,'2020-11-24 07:22:18',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4673,'Preferred use ReCaptcha','PREFERRED_USE_RECAPTCHA','False','Preferred use ReCaptcha instead standard Captcha','BOX_CONFIGURATION_MYSTORE',199,'2022-07-19 14:43:25','2021-01-05 09:34:53',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4674,'Send .webp images in emails','USE_WEBP_IN_EMAILS','False','Send .webp images in emails (check if enough mail agents supports it)','BOX_CONFIGURATION_E_MAIL_OPTIONS',501,NULL,'2021-01-05 09:34:53',NULL,'tep_cfg_select_option(array(\'False\', \'True\'),'),(4675,'Offer update start sales date automatically','ALLOW_SALES_UPDATE_DATES','False','If new sales period intersects with existing allow to offer change start/end date of old sale (danger)','BOX_CONFIGURATION_MYSTORE',7778,NULL,'2021-01-12 07:55:10',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4676,'Multi tax rates in admin','ONLY_TOP_PRIORITY_TAX','True','Gross price in admin will be calculated only based on top prio tax rate','BOX_CONFIGURATION_MYSTORE',7778,NULL,'2021-02-23 07:18:13',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4677,'Promote sale prices','SALES_DEFAULT_PROMO_TYPE','None','Show discount value next to sale price as percent or fixed discount','TEXT_LISTING_PRODUCTS',7778,NULL,'2021-02-23 07:18:13',NULL,'tep_cfg_select_option(array(\'None\', \'Percent\', \'Fixed\'),'),(4678,'Hide Products in Top Category','HIDE_PRODUCTS_IN_TOP_CATEGORY','None','Hide products in top category: All - ignore other categories, Only - doesn\'t exist in other categories','TEXT_LISTING_PRODUCTS',2,NULL,'2021-02-23 07:18:13',NULL,'tep_cfg_select_option(array(\'None\', \'All\', \'Only\'),'),(4679,'Use product seo name in image src path','SEO_IMAGE_URL_PARTS_NAME','True','','BOX_CONFIGURATION_SEO_OPTIONS',35,NULL,'2021-02-26 11:23:57',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4680,'Default file export format','EXPORT_DEFAULT_FILE_TYPE','CSV','','BOX_CONFIGURATION_MYSTORE',10,NULL,'2021-03-10 12:53:22',NULL,'tep_cfg_select_option(array(\'CSV\', \'XLSX\'),'),(4682,'Out of stock level','ADDITIONAL_STOCK_LIMIT','0','Set out of stock level limit','TEXT_STOCK',10,NULL,'2021-04-08 10:27:00',NULL,''),(4683,'Calculate TAX by shipping or billing address','TAX_ADDRESS_OPTION','0','Calculate TAX by shipping or billing address','BOX_CONFIGURATION_MYSTORE',10,NULL,'2021-04-08 10:27:01','getTaxAddressBy','setTaxAddressBy('),(4684,'Maximum order price','MAX_ORDER_PRICE','10000000','Set order subtotal price limit','BOX_CONFIGURATION_MAXIMUM_VALUES',10,NULL,'2021-04-08 10:27:01',NULL,''),(4685,'Maximum order product price','MAX_PRODUCT_PRICE','1000000','Set order product price limit','BOX_CONFIGURATION_MAXIMUM_VALUES',10,NULL,'2021-04-08 10:27:01',NULL,''),(4687,'Sale prices (max q-ty limited) use temporary stock','USE_TEMP_STOCK_ON_SPECIALS_CAP','True','Recommended. Allow to avoid overselling, but sale price could be allocated for bots (and unavailable for other). Temporary stock should be enabled.','TEXT_STOCK',10,NULL,'2021-04-14 13:28:57',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4688,'Import/export - import all sheets in file types','EP_MULTI_SHEETS','xlsx','During import process all sheets in files of the following types.','BOX_CONFIGURATION_MYSTORE',10,NULL,'2021-04-27 16:37:06',NULL,'tep_cfg_select_multioption(array(\'xlsx\'),'),(4689,'Allow several sales on same date/time','SALE_STRICT_DATE','False','Allow several sales on same date/time - quite difficult to track','BOX_CONFIGURATION_MYSTORE',7779,NULL,'2021-04-27 16:37:06',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4691,'Design boxes cache','DESIGN_BOXES_CACHE','json','Design boxes cache','BOX_CONFIGURATION_MYSTORE',100,NULL,'2021-05-26 10:25:23',NULL,'tep_cfg_select_option(array(\'json\', \'serialize\'),'),(4692,'Use product date available for inventory','INVENTORY_DATE_AVAILABLE_BY_PRODUCT','False','Check date available for inventory in main product details','TEXT_STOCK',777,NULL,'2021-05-31 16:32:12',NULL,'tep_cfg_select_option(array(\'False\', \'True\'),'),(4693,'Display customs number (EORI etc) in the address details','SHIPPING_CUSTOMS_NUMBER','disabled','Display customs number (EORI etc) in the address details','BOX_SHIPPING_CUSTOMER_DETAILS',201,'2022-06-24 18:05:33','2021-06-23 12:06:55',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\', \'required_company\'),'),(4694,'Display customs number (EORI etc) in the address details','BILLING_CUSTOMS_NUMBER','disabled','Display customs number (EORI etc) in the address details','BOX_BILLING_CUSTOMER_DETAILS',201,'2022-06-24 18:07:15','2021-06-23 12:06:55',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\', \'required_company\'),'),(4695,'Display customs number (EORI etc) in the address details','ACCOUNT_CUSTOMS_NUMBER','visible','Display customs number (EORI etc) in the address details','BOX_CONFIGURATION_CUSTOMER_DETAILS',201,NULL,'2021-06-23 12:06:55',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\', \'required_company\'),'),(4696,'Calculate different tax by country (EU - IOSS)','ALLOW_SEVERAL_TAX_COUNTRIES','False','Allow calculate different tax by country and total (UK IOSS, EU orders below 150gbp are taxableand and have country specific rates)','BOX_CONFIGURATION_MYSTORE',100,NULL,'2021-07-16 14:55:25',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4699,'Action on out of stock','ACTION_ON_OUT_OF_STOCK','False','Default Action on out of stock','TEXT_STOCK',NULL,NULL,'2021-08-17 10:37:26',NULL,'tep_cfg_select_option(array(\'Notify back in stock\', \'Contact form\'),'),(4700,'2-step backend authorization mask','ADMIN_TWO_STEP_AUTH_MASK','NN-NN-NN-NN','Security key mask. Use \"N\" or \"n\" for random number, \"a\" for random lowercase letter, \"A\" for random uppercase letter, \"?\" for any valid random symbol. Mask should include at least 2 random symbols. Default is \"NN-NN-NN-NN\".','BOX_CONFIGURATION_MYSTORE',0,NULL,'2021-08-26 14:21:55',NULL,NULL),(4701,'2-step backend authorization simple mask for email','ADMIN_TWO_STEP_AUTH_MASK_SIMPLE_EMAIL','False','Should system simplify security key mask for email? Enabling this option will remove all separator symbols from security key sent by email.','BOX_CONFIGURATION_MYSTORE',0,NULL,'2021-08-26 14:21:55',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4702,'Show bestsellers sold in last NN days','BESTSELLERS_SOLD_LAST_DAYS','','Leave empty for no restriction','TEXT_LISTING_PRODUCTS',101,NULL,'2021-08-31 11:16:27',NULL,NULL),(4703,'Show status filter on the admin orders','ADMIN_ORDERS_QUICK_STATUS_FILTER','False','Always show extra status filter','BOX_CONFIGURATION_MYSTORE',101,NULL,'2021-08-31 11:16:27',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4704,'Google Base attributes fields','GOOGLE_BASE_ATTRIBUTES_CONFIG','','','0',NULL,NULL,'2021-09-08 12:01:03',NULL,NULL),(4708,'Default Order Status For Online Payment Success','DEFAULT_ONLINE_PAYMENT_SUCCESS_ORDERS_STATUS_ID','100006','Default Order Status For Online Payment Success','1',1,NULL,'2021-11-16 13:55:46',NULL,NULL),(4709,'Shipping surcharge 1st product of any variations','SHIPPING_SURCHARGE_ONE_TIME','False','Shipping surcharge is applicable to 1st product if several purchased (inc. varations)','BOX_CONFIGURATION_SHIPPING_PACKAGING',1001,NULL,'2022-01-13 13:13:34',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4710,'Shipping surcharge 1st product','SHIPPING_SURCHARGE_ONE_TIME_VARIATION','False','Shipping surcharge is applicable to 1st variation of the products','BOX_CONFIGURATION_SHIPPING_PACKAGING',1002,NULL,'2022-01-13 13:13:34',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4711,'Shipping surcharge to 1st product in cart','SHIPPING_SURCHARGE_ONE_TIME_CART','False','Shipping surcharge is applicable to one product in cart (max)','BOX_CONFIGURATION_SHIPPING_PACKAGING',1003,NULL,'2022-01-13 13:13:34',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4712,'Shipping surcharge to free methods','SHIPPING_SURCHARGE_FREE_METHODS','True','Shipping surcharge is applicable to free methods','BOX_CONFIGURATION_SHIPPING_PACKAGING',1003,NULL,'2022-01-13 13:13:34',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4714,'Change product status on category on/off','FORCE_DISABLE_ENABLE_CATEGORY_PRODUCTS','No','','BOX_CONFIGURATION_MYSTORE',NULL,NULL,'2022-01-13 13:13:34',NULL,'tep_cfg_select_option(array(\'Yes\', \'No\'),'),(4715,'POS order printable document (from theme)','POS_INVOICE_PDF','','POS order printable document - create in Design / Themes first','BOX_CONFIGURATION_MYSTORE',100,NULL,'2022-01-13 13:13:34',NULL,NULL),(4716,'Show extension info','SHOW_EXTENSION_INFO','False','Show (i) link to extension on rendered admin pages','BOX_CONFIGURATION_ADMIN',0,NULL,'2022-05-16 13:20:17',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4717,'Strict access - Status','STRICT_ACCESS_STATUS','False','Strict access to the login portal','BOX_CONFIGURATION_ADMIN',100,NULL,'2022-05-16 13:20:18',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4718,'Strict access - Allowed IPs','STRICT_ACCESS_ALLOWED_IP','127.0.0.1','Comma separated list of allowed IP addresses','BOX_CONFIGURATION_ADMIN',110,NULL,'2022-05-16 13:20:18',NULL,''),(4719,'Hide (rather opacity) main checkout button','EXPRESS_PAYMENTS_HIDE_CHECKOUT','True','Hide (rather opacity) main checkout button when express payment is selectedat checkout','BOX_CONFIGURATION_MYSTORE',1000,NULL,'2022-06-24 08:01:03','','tep_cfg_select_option(array(\'True\', \'False\'),'),(4722,'RSS feed news','RSS_FEED_NEWS','https://www.oscommerce.com/blog/rss','RSS feed news','RSS',7800,'2022-07-18 15:18:39','2022-07-14 18:34:21',NULL,NULL),(4723,'RSS feed new applications','RSS_FEED_NEW_APPLICATIONS','https://app.oscommerce.com/catalog/products-new/rss','RSS feed new applications','RSS',7801,'2022-07-18 15:13:49','2022-07-14 18:34:21',NULL,NULL),(4724,'RSS feed featured applications','RSS_FEED_FEATURED_APPLICATIONS','https://app.oscommerce.com/catalog/featured-products/rss','RSS feed featured applications','RSS',7802,'2022-07-18 15:12:21','2022-07-14 18:34:21',NULL,NULL),(4725,'Link to News page','RSS_FEED_NEWS_LINK','https://www.oscommerce.com/blog','Link to all News page','RSS',7800,'2022-07-20 13:44:44','2022-07-14 18:34:25',NULL,NULL),(4726,'Link to New applications page','RSS_FEED_NEW_APPLICATIONS_LINK','https://app.oscommerce.com/catalog/products-new','Link to New applications page','RSS',7801,'2022-07-20 13:48:49','2022-07-14 18:34:25',NULL,NULL),(4727,'Link to Featured applications page','RSS_FEED_FEATURED_APPLICATIONS_LINK','https://app.oscommerce.com/catalog/featured-products','Link to Featured applications page','RSS',7802,'2022-07-20 13:47:51','2022-07-14 18:34:25',NULL,NULL),(4728,'Max items to show','RSS_FEED_MAX_ITEMS','10','Max items to show','RSS',7807,NULL,'2022-07-15 16:05:43',NULL,NULL),(4729,'Facebook link','RSS_FEED_FACEBOOK','https://www.facebook.com/osCommerce/','Facebook link','RSS',7808,NULL,'2022-07-20 12:59:00',NULL,NULL),(4730,'Twitter link','RSS_FEED_TWITTER','https://twitter.com/osCommerce','Twitter link','RSS',7809,NULL,'2022-07-20 12:59:00',NULL,NULL),(4731,'LinkedIn link','RSS_FEED_LINKEDIN','https://www.linkedin.com/company/oscommerce','LinkedIn link','RSS',7810,'2022-07-20 13:55:16','2022-07-20 12:59:00',NULL,NULL),(4732,'Subscribe link','RSS_FEED_SUBSCRIBE','https://oscommerce.us1.list-manage.com/subscribe?u=8034c4fa2bcb139b4fc4861cd&id=b428c4d027','Subscribe link','RSS',7811,'2022-07-20 13:53:21','2022-07-20 12:59:00',NULL,NULL),(4733,'Github link','RSS_FEED_GITHUB','https://github.com/osCommerce/osCommerce-V4','Github link','RSS',7812,'2022-07-20 13:51:23','2022-07-20 12:59:00',NULL,NULL),(4737,'SMTP Encryption','SMTP_ENCRYPTION','','SMTP Encryption','BOX_CONFIGURATION_E_MAIL_OPTIONS',12,NULL,'2022-08-08 11:22:10',NULL,'multiOption(\'dropdown\', [\'\'=>\'Regular\', \'tls\'=>\'Secure to regular port (STARTTLS)\', \'ssl\'=>\'Secure to dedicated port (TLS)\'], '),(4738,'Show ISBN','SHOW_ISBN','False','Show ISBN','TEXT_STOCK',50,NULL,'2022-09-21 13:30:28',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4739,'Admin stock auto refresh box','STOCK_ADMIN_AUTO_REFRESH','30','Refresh Stock info on edit product page (seconds). Min value 5. Disabled if less.','TEXT_STOCK',10,NULL,'2022-09-21 13:30:28',NULL,''),(4740,'Admin stock refresh on click','STOCK_ADMIN_REFRESH_ON_CLICK','True','Refresh Stock info on click on any stock-related link','TEXT_STOCK',10,NULL,'2022-09-21 13:30:28','','tep_cfg_select_option(array(\'True\', \'False\'),'),(4741,'Force hide languages in admin','FORCE_HIDE_ADMIN_LANGUAGE','True','Force hide languages marked as hidden in admin','BOX_CONFIGURATION_MYSTORE',10001,NULL,'2022-10-26 14:02:48',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4742,'Force logoff GUEST customer after successful checkout','AUTO_LOGOFF_GUEST_ON_SUCCESS','False','Force logoff GUEST customer after successful checkout ','BOX_CONFIGURATION_CUSTOMER_DETAILS',10001,NULL,'2022-10-26 14:02:49',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4743,'Checkout button pay with card','CHECKOUT_BTN_TEXT','True','Checkout button pay with card','BOX_CONFIGURATION_MYSTORE',35,NULL,'2022-10-26 14:02:49',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4744,'Password recovery token expiration time (minutes)','FORGOTTEN_PASSWORD_TOKEN_EXPIRE_MIN','5','Forgotten administrator password recovery token expiration time (minutes)','BOX_CONFIGURATION_MYSTORE',100,NULL,'2022-10-26 14:02:49',NULL,NULL),(4745,'Trigger recalculate shipping','TRIGGER_RECALCULATE_FIELDS','postcode, state, city, country','','BOX_SHIPPING_CUSTOMER_DETAILS',3245,NULL,'2022-12-07 14:12:07','getCheckoutRecalculateFields','setCheckoutRecalculateFields('),(4746,'POS restrict access - Status','POS_STRICT_ACCESS_STATUS','TRUE','Restrict access to the POS by IP','BOX_CONFIGURATION_ADMIN',100,NULL,'2022-12-07 14:12:07',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4747,'POS restrict access - Allowed IPs','POS_STRICT_ACCESS_ALLOWED_IP','127.0.0.1','Comma separated list of allowed IP addresses (subnet is allowed also)','BOX_CONFIGURATION_ADMIN',110,NULL,'2022-12-07 14:12:07',NULL,''),(4748,'Round product price excl tax','PRODUCTS_PRICE_EXC_ROUND','false','On subtotal, total and tax calculation round product price excl tax before adding tax','BOX_CONFIGURATION_MYSTORE',NULL,NULL,'2023-02-22 13:14:23',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4749,'Captcha on customer login','CAPTCHA_ON_CUSTOMER_LOGIN','True','Captcha on customer login','BOX_CONFIGURATION_CUSTOMER_DETAILS',200,NULL,'2023-02-22 13:14:29',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4750,'Captcha on create account','CAPTCHA_ON_CREATE_ACCOUNT','True','Captcha on create account','BOX_CONFIGURATION_CUSTOMER_DETAILS',200,NULL,'2023-02-22 13:14:29',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4751,'2-Level Attribute Selection Condition','CONDITION_2LEVEL_ATTRIBUTE_SELECTION','0','Use 2-level attribute selection if the number of attribute values more than X.','TEXT_LISTING_PRODUCTS',0,NULL,'2023-05-02 06:46:48',NULL,NULL),(4752,'Skip shopping cart page','SKIP_CART_PAGE','False','','BOX_CONFIGURATION_MYSTORE',NULL,NULL,'2023-05-02 06:46:48',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4753,'Enable OTP admin login','ADMIN_LOGIN_OTP_ENABLE','False','Enable a one-time password to log into admin area. Admin Members will no longer have static passwords.','BOX_CONFIGURATION_MYSTORE',NULL,NULL,'2023-05-02 06:46:48',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4754,'Email verification before registration','FLAG_EMAIL_VERIFICATION','False','Check email address with help sending code','BOX_CONFIGURATION_CUSTOMER_DETAILS',201,NULL,'2023-05-02 06:46:51',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4755,'Default weight unit','WEIGHT_UNIT_DEFAULT','KG','Default weight unit','BOX_CONFIGURATION_SHIPPING_PACKAGING',100,'2023-10-04 19:58:01','2023-10-04 19:58:01',NULL,'tep_cfg_select_option(array(\'KG\', \'LB\'),'),(4756,'Email address','SHIPPING_EMAIL_ADDRESS','visible','Display customs email address in the address details','BOX_SHIPPING_CUSTOMER_DETAILS',40,NULL,'2023-10-04 19:58:07',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\', \'required_company\'),'),(4757,'Email address','BILLING_EMAIL_ADDRESS','visible','Display customs email address in the address details','BOX_BILLING_CUSTOMER_DETAILS',40,NULL,'2023-10-04 19:58:07',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\', \'required_company\'),'),(4758,'Address book email','ACCOUNT_EMAIL_ADDRESS','visible','Display customs email address in the address details','BOX_CONFIGURATION_CUSTOMER_DETAILS',40,NULL,'2023-10-04 19:58:07',NULL,'tep_cfg_select_option(array(\'disabled\', \'visible\', \'visible_register\', \'required\', \'required_register\', \'required_company\'),'),(4759,'Show ASIN','SHOW_ASIN','True','Show ASIN','TEXT_STOCK',50,NULL,'2023-10-04 19:58:09',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4760,'Show EAN','SHOW_EAN','True','Show EAN','TEXT_STOCK',50,NULL,'2023-10-04 19:58:09',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4761,'Show UPC','SHOW_UPC','True','Show UPC','TEXT_STOCK',50,NULL,'2023-10-04 19:58:09',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4762,'Backend minimum word length','BACKEND_MSEARCH_WORD_LENGTH','2','Minimal length of the word for backend, that will be included in search','BOX_CONFIGURATION_WIDE_SEACH',10,NULL,'2023-10-04 19:58:09',NULL,NULL),(4763,'Backend show product data','BACKEND_SEARCH_AGREGATE_PRODUCT_DATA','Standard','Which data additionaly showed on found product(related on search speed)','BOX_CONFIGURATION_WIDE_SEACH',15,NULL,'2023-10-04 19:58:09',NULL,'tep_cfg_select_option(array(\'Standard\', \'Simplified\',\'List\'),'),(4764,'Define custom debug constants','DEFINE_DBG_CONST','','Define custom debug constants for subsystems and extensions (\",\" as separator)','',100,'2023-10-04 19:58:09','2023-10-04 19:58:09',NULL,NULL),(4765,'Show fields on search on add product in edit order ','BACKEND_SEARCH_SHOW_DATA','Image, SKU, Price','Which fields of products should be shown on search','BOX_CONFIGURATION_WIDE_SEACH',11,NULL,'2023-10-04 19:58:09',NULL,'tep_cfg_select_multioption(array(\'Image\', \'SKU\',\'Price\',\'Stock\'),'),(4766,'Search cross all languages','BACKEND_SEARCH_ON_ALL_LANGUAGES','False','Search cross all languages (result showed on one active language)','BOX_CONFIGURATION_WIDE_SEACH',15,NULL,'2023-10-04 19:58:09',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4767,'CSS version for the admin aria','BACKEND_CSS_VERSION','30','It is used to update the CSS cache in the user\'s browser.','BOX_CONFIGURATION_MYSTORE',100,NULL,'2023-10-04 19:59:28',NULL,NULL),(4768,'Tax selection','BACKEND_TAX_RATES_OR_CLASSES','CLASSES','Source for tax selection','BOX_CONFIGURATION_EDIT_ORDER_SETTINGS',100,'2023-10-04 19:59:28','2023-10-04 19:59:28',NULL,'tep_cfg_select_option(array(\'CLASSES\', \'RATES\'),'),(4769,'Virtual Gift Card Model','VIRTUAL_GIFT_CARD_MODEL','VIRTUAL_GIFT_CARD','Virtual Gift Card Model','TEXT_LISTING_PRODUCTS',777,'2024-04-22 18:50:47','2024-04-22 18:50:47',NULL,NULL),(4770,'Add Comments From Re-Ordered Order','ADD_COMMENT_FROM_REORDERED','true','Add comments from re-ordered order.','BOX_CONFIGURATION_MYSTORE',77777,'2024-04-22 18:50:56','2024-04-22 18:50:56',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4771,'Multi-sessions are allowed?','MULTI_SESSION_ENABLED','false','Allow multiple active logins for same customer?','BOX_CONFIGURATION_SESSIONS',10,'2024-04-22 18:50:56','2024-04-22 18:50:56',NULL,'tep_cfg_select_option(array(\'true\', \'false\'),'),(4772,'Maximum Attribute Length to Show','MAX_SHOW_ATTRIBUTE_LENGTH','20','Maximum attribute length to show on order page.','BOX_CONFIGURATION_MAXIMUM_VALUES',777,'2024-04-22 18:50:56','2024-04-22 18:50:56',NULL,NULL),(4773,'Show credit note reports','CREDIT_NOTE_AVAILABLE','False','','',200,'2024-04-22 18:50:56','2024-04-22 18:50:56',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),'),(4774,'Social Logins New Account Country','SOCIALS_NEW_ACCOUNT_COUNTRY','Platform','Set the country for new accounts created via Social Logins (Googla, Facebook etc).','BOX_CONFIGURATION_CUSTOMER_DETAILS',77777,'2024-04-22 18:50:56','2024-04-22 18:50:56',NULL,'tep_cfg_select_option(array(\'Platform\', \'Empty\'),'),(4775,'Date of installation','INSTALLED_DATE','[[regtime]]','','',NULL,NULL,'[[regtime]]',NULL,NULL),(4776,'Date of last update','UPDATED_DATE','','','',NULL,NULL,'[[regtime]]',NULL,NULL);
/*!40000 ALTER TABLE `configuration` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `configuration_group`
--

DROP TABLE IF EXISTS `configuration_group`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `configuration_group` (
  `configuration_group_id` int(11) NOT NULL AUTO_INCREMENT,
  `configuration_group_title` varchar(64) NOT NULL DEFAULT '',
  `configuration_group_description` varchar(255) NOT NULL DEFAULT '',
  `sort_order` int(5) DEFAULT NULL,
  `visible` int(1) DEFAULT '1',
  PRIMARY KEY (`configuration_group_id`)
) ENGINE=InnoDB AUTO_INCREMENT=100685 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `configuration_group`
--

LOCK TABLES `configuration_group` WRITE;
/*!40000 ALTER TABLE `configuration_group` DISABLE KEYS */;
INSERT INTO `configuration_group` VALUES (1,'My Store','General information about my store',1,1),(2,'Minimum Values','The minimum values for functions / data',2,1),(3,'Maximum Values','The maximum values for functions / data',3,1),(5,'Customer Details','Customer account configuration',6,1),(6,'Module Options','Hidden from configuration',6,0),(7,'Shipping/Packaging','Shipping options available at my store',7,1),(8,'Product Listing','Product Listing configuration options',8,1),(9,'Stock','Stock configuration options',9,1),(10,'Logging','Logging configuration options',10,0),(11,'Cache','Caching configuration options',11,0),(12,'E-Mail Options','General setting for E-Mail transport and HTML E-Mails',12,1),(13,'Download','Downloadable products options',13,0),(15,'Sessions','Session options',16,1),(20,'Edit Order Settings','Edit Order Settings',20,1),(26,'Control panel','Edit control panel settings',20,0),(99,'Dynamic MoPics','The options which configure Dynamic MoPics.',18,0),(333,'Wide search','Wide search settings',5,1),(601,'Faqdesk Listing Settings','Faqdesk Listing Page configuration options',600,0),(602,'Faqdesk Frontpage Settings','Faqdesk Front Page configuration options',600,0),(603,'Faqdesk Reviews Settings','Faqdesk Reviews configuration options',600,0),(604,'Faqdesk Sticky Settings','Faqdesk Reviews configuration options',600,0),(701,'One Page Checkout Options','',200,0),(900,'Affiliate Program','Options for the Affiliate Program',17,1),(1000,'Rechnungen','Angaben für das Impressum und die Rechnungslegung',1,0),(1128,'SEO Options','SEO Options',27,1),(5002,'Newsdesk configuration options','Newsdesk configuration options',500,0),(5004,'Newsdesk Sticky Settings','Newsdesk Sticky configuration options',500,0),(6501,'Recover Cart Sales','Recover Cart Sales (RCS) Configuration Values',15,1),(26229,'Page Cache Settings','Settings for the page cache contribution',20,0),(100672,'Links','Links Manager configuration options',99,0),(100673,'Trustpilot Settings','Trustpilot settings',20,0),(100674,'Exact Online','Exact Online',5555,0),(100675,'SMS Updates Configuration','SMS Updates Configuration for CardBoardFish',100,1),(100676,'Bonus programs','Bonus programs',100,1),(100677,'Refer Friend Settings','Refer Friend Settings',101,1),(100678,'Reports','Reports',101,1),(100679,'Promotion Settings','Promotion Settings',30,0),(100680,'PCA Predict','PCA Predict',7,1),(100681,'Suppliers','Suppliers settings',21,1),(100683,'Shipping Customer Details','Shipping Customer Details',6,1),(100684,'Billing Customer Details','Billing Customer Details',6,1);
/*!40000 ALTER TABLE `configuration_group` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `configuration_group_trash`
--

DROP TABLE IF EXISTS `configuration_group_trash`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `configuration_group_trash` (
  `configuration_group_id` int(11) NOT NULL,
  `configuration_group_title` varchar(64) NOT NULL DEFAULT '',
  `configuration_group_description` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`configuration_group_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `configuration_group_trash`
--

LOCK TABLES `configuration_group_trash` WRITE;
/*!40000 ALTER TABLE `configuration_group_trash` DISABLE KEYS */;
INSERT INTO `configuration_group_trash` VALUES (404,'Trash group','Trash group');
/*!40000 ALTER TABLE `configuration_group_trash` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `configuration_trash`
--

DROP TABLE IF EXISTS `configuration_trash`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `configuration_trash` (
  `configuration_id` int(11) NOT NULL,
  `configuration_title` varchar(64) NOT NULL DEFAULT '',
  `configuration_key` varchar(64) NOT NULL DEFAULT '',
  `configuration_value` varchar(2048) NOT NULL DEFAULT '',
  `configuration_description` varchar(255) NOT NULL DEFAULT '',
  `configuration_group_id` varchar(128) NOT NULL DEFAULT '',
  `sort_order` int(5) DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `date_added` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `use_function` varchar(255) DEFAULT NULL,
  `set_function` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`configuration_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `configuration_trash`
--

LOCK TABLES `configuration_trash` WRITE;
/*!40000 ALTER TABLE `configuration_trash` DISABLE KEYS */;
INSERT INTO `configuration_trash` VALUES (4621,'Show google map on order process','SHOW_MAP_ORDER_PROCESS','True','Show google map on order process','BOX_CONFIGURATION_MYSTORE',NULL,NULL,'2019-12-23 16:00:47',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),');
/*!40000 ALTER TABLE `configuration_trash` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connector_osclink_configuration`
--

DROP TABLE IF EXISTS `connector_osclink_configuration`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `connector_osclink_configuration` (
  `cmc_key` varchar(128) NOT NULL,
  `cmc_value` varchar(250) NOT NULL DEFAULT '',
  `cmc_upd_date` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `cmc_upd_admin` int(10) unsigned NOT NULL,
  PRIMARY KEY (`cmc_key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connector_osclink_configuration`
--

LOCK TABLES `connector_osclink_configuration` WRITE;
/*!40000 ALTER TABLE `connector_osclink_configuration` DISABLE KEYS */;
INSERT INTO `connector_osclink_configuration` VALUES ('api_key','','2024-04-23 17:21:14',1),('api_method','bearer','2022-07-20 18:49:09',1),('api_platform','7','2022-07-20 18:50:07',1),('api_status_map','{\"100007\":1,\"2\":2,\"3\":3,\"100006\":4}','2022-07-20 18:50:07',1),('api_url','','2024-04-23 17:21:10',1);
/*!40000 ALTER TABLE `connector_osclink_configuration` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connector_osclink_entity`
--

DROP TABLE IF EXISTS `connector_osclink_entity`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `connector_osclink_entity` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `project_id` int(11) unsigned NOT NULL,
  `entity_name` varchar(128) NOT NULL,
  PRIMARY KEY (`id`),
  KEY `project_id` (`project_id`),
  KEY `entity_name` (`entity_name`)
) ENGINE=InnoDB AUTO_INCREMENT=21 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connector_osclink_entity`
--

LOCK TABLES `connector_osclink_entity` WRITE;
/*!40000 ALTER TABLE `connector_osclink_entity` DISABLE KEYS */;
INSERT INTO `connector_osclink_entity` VALUES (1,1,'@order_status');
/*!40000 ALTER TABLE `connector_osclink_entity` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `connector_osclink_mapping`
--

DROP TABLE IF EXISTS `connector_osclink_mapping`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `connector_osclink_mapping` (
  `entity_id` int(11) unsigned NOT NULL,
  `external_id` int(11) unsigned NOT NULL,
  `internal_id` int(11) unsigned NOT NULL,
  PRIMARY KEY (`entity_id`,`external_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `connector_osclink_mapping`
--

LOCK TABLES `connector_osclink_mapping` WRITE;
/*!40000 ALTER TABLE `connector_osclink_mapping` DISABLE KEYS */;
INSERT INTO `connector_osclink_mapping` VALUES (1,1,100007),(1,2,2),(1,3,3),(1,4,100006);
/*!40000 ALTER TABLE `connector_osclink_mapping` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `counter`
--

DROP TABLE IF EXISTS `counter`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `counter` (
  `startdate` char(8) DEFAULT NULL,
  `counter` int(12) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `counter`
--

LOCK TABLES `counter` WRITE;
/*!40000 ALTER TABLE `counter` DISABLE KEYS */;
INSERT INTO `counter` VALUES ('20031126',17959);
/*!40000 ALTER TABLE `counter` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `counter_history`
--

DROP TABLE IF EXISTS `counter_history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `counter_history` (
  `month` char(8) DEFAULT NULL,
  `counter` int(12) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `counter_history`
--

LOCK TABLES `counter_history` WRITE;
/*!40000 ALTER TABLE `counter_history` DISABLE KEYS */;
/*!40000 ALTER TABLE `counter_history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `countries`
--

DROP TABLE IF EXISTS `countries`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `countries` (
  `countries_id` int(11) NOT NULL AUTO_INCREMENT,
  `countries_name` varchar(64) NOT NULL DEFAULT '',
  `countries_iso_code_2` char(2) NOT NULL DEFAULT '',
  `countries_iso_code_3` char(3) NOT NULL DEFAULT '',
  `address_format_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `status` tinyint(4) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `lat` float(15,7) NOT NULL DEFAULT '0.0000000',
  `lng` float(15,7) NOT NULL DEFAULT '0.0000000',
  `zoom` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `vat_code_type` int(4) NOT NULL DEFAULT '0',
  `vat_code_prefix` varchar(5) NOT NULL DEFAULT '',
  `vat_code_chars` varchar(10) NOT NULL DEFAULT '',
  `dialling_prefix` varchar(20) DEFAULT NULL,
  `currency_code` varchar(3) NOT NULL DEFAULT '',
  PRIMARY KEY (`countries_id`,`language_id`),
  KEY `IDX_COUNTRIES_NAME` (`countries_name`)
) ENGINE=InnoDB AUTO_INCREMENT=243 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `countries`
--

LOCK TABLES `countries` WRITE;
/*!40000 ALTER TABLE `countries` DISABLE KEYS */;
INSERT INTO `countries` VALUES (1,'Afghanistan','AF','AFG',4,1,1,1,33.8616409,63.2130127,6.0000,0,'','7','+93',''),(2,'Albania','AL','ALB',6,1,1,1,41.1495399,19.0395603,8.0000,0,'','0','+355',''),(3,'Algeria','DZ','DZA',1,1,1,1,27.9656487,-2.8258660,6.0000,0,'','0','+213',''),(4,'American Samoa','AS','ASM',1,1,1,1,-14.3058434,-170.7662201,12.0000,0,'','0','+1-684',''),(5,'Andorra','AD','AND',1,1,1,1,42.5423737,1.5276325,12.0000,0,'','0','+376',''),(6,'Angola','AO','AGO',1,1,1,1,-11.1691065,13.3838463,6.0000,0,'','0','+244',''),(7,'Anguilla','AI','AIA',1,1,1,1,18.2241268,-63.1290092,12.0000,0,'','0','+1-264',''),(8,'Antarctica','AQ','ATA',1,1,1,1,-65.9717712,-53.0746040,3.0000,0,'','0','+672',''),(9,'Antigua and Barbuda','AG','ATG',1,1,1,1,17.0870895,-61.8534889,12.0000,0,'','0','+1-268',''),(10,'Argentina','AR','ARG',5,1,1,1,-36.9932976,-81.5907516,4.0000,0,'','0','+54',''),(11,'Armenia','AM','ARM',1,1,1,1,40.0673180,43.9197044,8.0000,0,'','0','+374',''),(12,'Aruba','AW','ABW',1,1,1,1,12.5177231,-70.0357208,12.0000,0,'','0','+297',''),(13,'Australia','AU','AUS',5,1,1,1,-24.9932842,115.2326736,4.0000,0,'','0','+61',''),(14,'Austria','AT','AUT',5,1,1,1,47.6928635,12.2247705,8.0000,1,'AT','9','+43',''),(15,'Azerbaijan','AZ','AZE',1,1,1,1,40.1489716,46.5711708,8.0000,0,'','0','+994',''),(16,'Bahamas','BS','BHS',1,1,1,1,24.0754013,-78.8370743,7.0000,0,'','0','+1-242',''),(17,'Bahrain','BH','BHR',1,1,1,1,25.9437733,50.3213158,10.0000,0,'','0','+973',''),(18,'Bangladesh','BD','BGD',1,1,1,1,23.6792011,88.1007767,7.0000,0,'','0','+880',''),(19,'Barbados','BB','BRB',1,1,1,1,13.1902905,-59.6056023,12.0000,0,'','0','+1-246',''),(20,'Belarus','BY','BLR',1,1,1,1,53.6992607,25.7354565,7.0000,0,'','0','+375',''),(21,'Belgium','BE','BEL',5,1,1,1,50.4974442,3.3558123,8.0000,0,'BE','9','+32',''),(22,'Belize','BZ','BLZ',1,1,1,1,17.1903076,-89.4808502,8.0000,0,'','0','+501',''),(23,'Benin','BJ','BEN',1,1,1,1,9.3200073,0.0660098,7.0000,0,'','0','+229',''),(24,'Bermuda','BM','BMU',1,1,1,1,32.3191452,-64.8374634,12.0000,0,'','0','+1-441',''),(25,'Bhutan','BT','BTN',1,1,1,1,27.5315151,89.8754196,9.0000,0,'','0','+975',''),(26,'Bolivia','BO','BOL',1,1,1,1,-16.2257156,-68.0434494,6.0000,0,'','0','+591',''),(27,'Bosnia and Herzegowina','BA','BIH',1,1,1,1,43.9130402,16.5511494,8.0000,0,'','0','+387',''),(28,'Botswana','BW','BWA',1,1,1,1,-22.3223114,22.4436436,7.0000,0,'','0','+267',''),(29,'Bouvet Island','BV','BVT',1,1,1,1,-54.4204597,3.3245614,13.0000,0,'','0',NULL,''),(30,'Brazil','BR','BRA',1,1,1,1,-14.0488291,-62.2091293,5.0000,0,'','0','+55',''),(31,'British Indian Ocean Territory','IO','IOT',1,1,1,1,-7.3344474,72.3542099,12.0000,0,'','0','+246',''),(32,'Brunei Darussalam','BN','BRN',1,1,1,1,4.5248795,114.4394379,10.0000,0,'','0','+673',''),(33,'Bulgaria','BG','BGR',1,1,1,1,42.7218933,24.3622913,8.0000,0,'','0','+359',''),(34,'Burkina Faso','BF','BFA',1,1,1,1,12.2435150,-3.7995522,7.0000,0,'','0','+226',''),(35,'Burundi','BI','BDI',1,1,1,1,-3.3879967,29.3648224,9.0000,0,'','0','+257',''),(36,'Cambodia','KH','KHM',1,1,1,1,12.3005047,103.8594055,8.0000,0,'','0','+855',''),(37,'Cameroon','CM','CMR',1,1,1,1,7.3581438,7.8490391,6.0000,0,'','0','+237',''),(38,'Canada','CA','CAN',5,1,1,1,54.7233582,-113.7178268,4.0000,0,'','0','+1',''),(39,'Cape Verde','CV','CPV',1,1,1,1,15.1204300,-23.7452564,11.0000,0,'','0','+238',''),(40,'Cayman Islands','KY','CYM',1,1,1,1,19.3300247,-81.3224716,12.0000,0,'','0','+1-345',''),(41,'Central African Republic','CF','CAF',1,1,1,1,6.6198339,18.6927605,7.0000,0,'','0','+236',''),(42,'Chad','TD','TCD',1,1,1,1,15.4114695,14.2403336,6.0000,0,'','0','+235',''),(43,'Chile','CL','CHL',1,1,1,1,-35.3323555,-89.0748749,4.0000,0,'','0','+56',''),(44,'China','CN','CHN',5,1,1,1,34.5328255,86.0856781,4.0000,0,'','0','+86',''),(45,'Christmas Island','CX','CXR',1,1,1,1,-10.4912815,105.5880051,13.0000,0,'','0','+61',''),(46,'Cocos (Keeling) Islands','CC','CCK',1,1,1,1,-12.1706495,96.8242416,14.0000,0,'','0','+61',''),(47,'Colombia','CO','COL',1,1,1,1,4.1147389,-77.4260712,6.0000,0,'','0','+57',''),(48,'Comoros','KM','COM',1,1,1,1,-11.6516104,43.2371178,11.0000,0,'','0','+269',''),(49,'Congo','CG','COG',1,1,1,1,-0.6545858,12.6543570,7.0000,0,'','0','+242',''),(50,'Cook Islands','CK','COK',1,1,1,1,-21.2357330,-159.7948761,14.0000,0,'','0','+682',''),(51,'Costa Rica','CR','CRI',1,1,1,1,9.6310892,-85.3753967,8.0000,0,'','0','+506',''),(52,'Cote D\'Ivoire','CI','CIV',1,1,1,1,7.5452666,-7.7914782,7.0000,0,'','0','+225',''),(53,'Croatia','HR','HRV',1,1,1,1,44.4534607,14.2262344,7.0000,0,'','0','+385',''),(54,'Cuba','CU','CUB',1,1,1,1,21.5414314,-81.7857056,7.0000,0,'','0','+53',''),(55,'Cyprus','CY','CYP',1,1,1,1,35.1695824,32.8765602,9.0000,1,'CY','9','+357',''),(56,'Czech Republic','CZ','CZE',5,1,1,1,49.8001289,14.3539705,8.0000,0,'CZ','8','+420',''),(57,'Denmark','DK','DNK',5,1,1,1,56.1382561,8.1908808,7.0000,0,'DK','8','+45',''),(58,'Djibouti','DJ','DJI',1,1,1,1,11.8235750,42.0280952,9.0000,0,'','0','+253',''),(59,'Dominica','DM','DMA',1,1,1,1,15.4240446,-61.5001984,11.0000,0,'','0','+1-767',''),(60,'Dominican Republic','DO','DOM',1,1,1,1,18.7014751,-70.7252045,9.0000,0,'','0','+1-809',''),(61,'East Timor','TP','TMP',1,1,1,1,-8.7929859,125.5769577,9.0000,0,'','0','+670',''),(62,'Ecuador','EC','ECU',1,1,1,1,-1.7860259,-80.3808289,7.0000,0,'','0','+593',''),(63,'Egypt','EG','EGY',1,1,1,1,26.7746429,26.3032970,6.0000,0,'','0','+20',''),(64,'El Salvador','SV','SLV',1,1,1,1,13.8036928,-89.4657822,9.0000,0,'','0','+503',''),(65,'Equatorial Guinea','GQ','GNQ',1,1,1,1,1.6208092,9.7573347,9.0000,0,'','0','+240',''),(66,'Eritrea','ER','ERI',1,1,1,1,15.1817675,37.5443420,7.0000,0,'','0','+291',''),(67,'Estonia','EE','EST',5,1,1,1,58.6012878,23.8664074,8.0000,0,'EE','9','+372',''),(68,'Ethiopia','ET','ETH',1,1,1,1,9.1323709,36.0039825,6.0000,0,'','0','+251',''),(69,'Falkland Islands (Malvinas)','FK','FLK',1,1,1,1,-51.7282791,-60.0778770,9.0000,0,'','0','+500',''),(70,'Faroe Islands','FO','FRO',1,1,1,1,61.8920975,-7.5333366,9.0000,0,'','0','+298',''),(71,'Fiji','FJ','FJI',1,1,1,1,-17.4567280,178.1371460,8.0000,0,'','0','+679',''),(72,'Finland','FI','FIN',5,1,1,1,64.6547699,17.1376495,5.0000,0,'FI','8','+358',''),(73,'France','FR','FRA',5,1,1,1,46.1355095,-2.2776463,6.0000,1,'FR','11','+33',''),(74,'France, Metropolitan','FX','FXX',1,1,1,1,46.1355095,-2.2776463,6.0000,0,'','0',NULL,''),(75,'French Guiana','GF','GUF',1,1,1,1,3.9327409,-54.2087936,8.0000,0,'','0','+594',''),(76,'French Polynesia','PF','PYF',1,1,1,1,-17.6863613,-149.5128632,11.0000,0,'','0','+689',''),(77,'French Southern Territories','TF','ATF',1,1,1,1,-49.1284027,69.0189590,9.0000,0,'','0',NULL,''),(78,'Gabon','GA','GAB',1,1,1,1,-0.8152207,9.3690386,7.0000,0,'','0','+241',''),(79,'Gambia','GM','GMB',1,1,1,1,13.4321756,-15.8636971,9.0000,0,'','0','+220',''),(80,'Georgia','GE','GEO',1,1,1,1,42.3173561,42.2503433,8.0000,0,'','0','+995',''),(81,'Germany','DE','DEU',5,1,1,1,51.0851746,5.9693384,6.0000,0,'DE','9','+49',''),(82,'Ghana','GH','GHA',1,1,1,1,7.9563746,-3.2745852,7.0000,0,'','0','+233',''),(83,'Gibraltar','GI','GIB',1,1,1,1,36.1320114,-5.3704271,14.0000,0,'','0','+350',''),(84,'Greece','GR','GRC',1,1,1,1,38.2578621,23.5673122,7.1000,0,'EL','9','+30',''),(85,'Greenland','GL','GRL',1,1,1,1,67.4847260,-74.8970413,3.0000,0,'','0','+299',''),(86,'Grenada','GD','GRD',1,1,1,1,12.1101274,-61.7635918,12.0000,0,'','0','+1-473',''),(87,'Guadeloupe','GP','GLP',1,1,1,1,16.1736965,-61.6859474,10.0000,0,'','0','+590',''),(88,'Guam','GU','GUM',1,1,1,1,13.4489965,144.6474152,11.0000,0,'','0','+1-671',''),(89,'Guatemala','GT','GTM',1,1,1,1,15.7776403,-91.3524780,8.0000,0,'','0','+502',''),(90,'Guinea','GN','GIN',1,1,1,1,9.9307137,-13.6019363,7.0000,0,'','0','+224',''),(91,'Guinea-bissau','GW','GNB',1,1,1,1,11.7742558,-15.7312746,9.0000,0,'','0','+245',''),(92,'Guyana','GY','GUY',1,1,1,1,4.8574491,-61.1969643,7.0000,0,'','0','+592',''),(93,'Haiti','HT','HTI',1,1,1,1,19.0561619,-73.6116791,9.0000,0,'','0','+509',''),(94,'Heard and Mc Donald Islands','HM','HMD',1,1,1,1,-53.0764160,73.3735809,11.0000,0,'','0',NULL,''),(95,'Honduras','HN','HND',1,1,1,1,14.7505054,-87.3632050,8.0000,0,'','0','+504',''),(96,'Hong Kong','HK','HKG',1,1,1,1,22.3579350,113.9809265,11.0000,0,'','0','+852',''),(97,'Hungary','HU','HUN',1,1,1,1,47.1575623,18.3847847,8.0000,0,'HU','8','+36',''),(98,'Iceland','IS','ISL',5,1,1,1,64.9168243,-21.2562580,7.0000,0,'','0','+354',''),(99,'India','IN','IND',5,1,1,1,20.9129887,73.7575912,5.0000,0,'','0','+91',''),(100,'Indonesia','ID','IDN',1,1,1,1,-2.4952903,108.9778900,5.0000,0,'','0','+62',''),(101,'Iran (Islamic Republic of)','IR','IRN',1,1,1,1,32.3503532,49.1919632,6.0000,0,'','0','+98',''),(102,'Iraq','IQ','IRQ',1,1,1,1,33.2053986,41.4415131,7.0000,0,'','0','+964',''),(103,'Ireland','IE','IRL',5,1,1,1,53.4098091,-10.5711317,7.0000,1,'IE','8','+353',''),(104,'Israel','IL','ISR',5,1,1,1,31.4091911,33.9606934,8.0000,0,'','0','+972',''),(105,'Italy','IT','ITA',5,1,1,1,41.2135963,13.3134737,6.0000,0,'IT','11','+39',''),(106,'Jamaica','JM','JAM',1,1,1,1,18.1160126,-77.8364487,9.0000,0,'','0','+1-876',''),(107,'Japan','JP','JPN',1,1,1,1,34.4720154,125.3783951,5.0000,0,'','0','+81',''),(108,'Jordan','JO','JOR',1,1,1,1,31.2773438,36.0086250,8.0000,0,'','0','+962',''),(109,'Kazakhstan','KZ','KAZ',1,1,1,1,47.6695290,57.9371567,5.0000,0,'','0','+7',''),(110,'Kenya','KE','KEN',1,1,1,1,0.1822441,35.6643486,7.0000,0,'','0','+254',''),(111,'Kiribati','KI','KIR',1,1,1,1,1.8712209,-157.5031128,11.0000,0,'','0','+686',''),(112,'Korea, Democratic People\'s Republic of','KP','PRK',1,1,1,1,0.0000000,0.0000000,0.0000,0,'','0','+850',''),(113,'Korea, Republic of','KR','KOR',5,1,1,1,37.9311371,123.1767197,6.0000,0,'','0','+82',''),(114,'Kuwait','KW','KWT',1,1,1,1,29.3141041,46.9313164,9.0000,0,'','0','+965',''),(115,'Kyrgyzstan','KG','KGZ',1,1,1,1,41.2051773,72.4959259,7.0000,0,'','0','+996',''),(116,'Lao People\'s Democratic Republic','LA','LAO',1,1,1,1,18.1984806,101.6452255,7.0000,0,'','0','+856',''),(117,'Latvia','LV','LVA',1,1,1,1,56.8766556,23.4848728,8.0000,0,'LV','11','+371',''),(118,'Lebanon','LB','LBN',1,1,1,1,33.8734283,35.3033218,9.0000,0,'','0','+961',''),(119,'Lesotho','LS','LSO',1,1,1,1,-29.6208191,27.6730499,9.0000,0,'','0','+266',''),(120,'Liberia','LR','LBR',1,1,1,1,6.4352088,-10.5436602,8.0000,0,'','0','+231',''),(121,'Libyan Arab Jamahiriya','LY','LBY',1,1,1,1,26.2738247,12.7765188,6.0000,0,'','0','+218',''),(122,'Liechtenstein','LI','LIE',1,1,1,1,47.1595650,9.4135532,11.0000,0,'','0','+423',''),(123,'Lithuania','LT','LTU',5,1,1,1,55.1700287,22.7739086,8.0000,0,'LT','9','+370',''),(124,'Luxembourg','LU','LUX',5,1,1,1,49.8154068,5.8531446,10.0000,0,'LU','8','+352',''),(125,'Macau','MO','MAC',1,1,1,1,22.1634922,113.5284424,13.0000,0,'','0','+853',''),(126,'Macedonia, The Former Yugoslav Republic of','MK','MKD',1,1,1,1,41.1166382,21.1149616,8.0000,0,'','0','+389',''),(127,'Madagascar','MG','MDG',1,1,1,1,-18.7151146,42.3406868,6.0000,0,'','0','+261',''),(128,'Malawi','MW','MWI',1,1,1,1,-13.2332220,32.0517349,7.0000,0,'','0','+265',''),(129,'Malaysia','MY','MYS',5,1,1,1,4.1389165,105.1222153,6.0000,0,'','0','+60',''),(130,'Maldives','MV','MDV',1,1,1,1,1.9774170,73.4660721,12.0000,0,'','0','+960',''),(131,'Mali','ML','MLI',1,1,1,1,17.5342121,-8.4802933,6.0000,0,'','0','+223',''),(132,'Malta','MT','MLT',1,1,1,1,35.9444275,14.3399429,11.0000,0,'MT','8','+356',''),(133,'Marshall Islands','MH','MHL',1,1,1,1,6.0686250,171.8492889,11.0000,0,'','0','+692',''),(134,'Martinique','MQ','MTQ',1,1,1,1,14.6339722,-61.1599083,11.0000,0,'','0','+596',''),(135,'Mauritania','MR','MRT',1,1,1,1,20.9698639,-15.4450579,6.0000,0,'','0','+222',''),(136,'Mauritius','MU','MUS',1,1,1,1,-20.2005157,56.5543442,8.0000,0,'','0','+230',''),(137,'Mayotte','YT','MYT',1,1,1,1,-12.8205976,45.0189896,11.0000,0,'','0','+262',''),(138,'Mexico','MX','MEX',1,1,1,1,23.3863049,-111.5563431,5.0000,0,'','0','+52',''),(139,'Micronesia, Federated States of','FM','FSM',1,1,1,1,6.8876467,158.1450348,12.0000,0,'','0','+691',''),(140,'Moldova, Republic of','MD','MDA',1,1,1,1,46.9758301,27.2687168,8.0000,0,'','0','+373',''),(141,'Monaco','MC','MCO',1,1,1,1,43.7383385,7.4157033,15.0000,0,'','0','+377',''),(142,'Mongolia','MN','MNG',1,1,1,1,46.5283623,94.8647385,5.0000,0,'','0','+976',''),(143,'Montserrat','MS','MSR',1,1,1,1,16.7494526,-62.2278671,13.0000,0,'','0','+1-664',''),(144,'Morocco','MA','MAR',1,1,1,1,31.7798328,-9.3280344,7.0000,0,'','0','+212',''),(145,'Mozambique','MZ','MOZ',1,1,1,1,-18.6058178,31.0335407,6.0000,0,'','0','+258',''),(146,'Myanmar','MM','MMR',1,1,1,1,19.0294437,92.1767654,6.0000,0,'','0','+95',''),(147,'Namibia','NA','NAM',1,1,1,1,-22.8936405,14.0001917,6.0000,0,'','0','+264',''),(148,'Nauru','NR','NRU',1,1,1,1,-0.5283715,166.9167328,14.0000,0,'','0','+674',''),(149,'Nepal','NP','NPL',1,1,1,1,28.3839169,81.8865433,7.0000,0,'','0','+977',''),(150,'Netherlands','NL','NLD',5,1,1,1,52.2093658,4.1584530,8.0000,1,'NL','12','+31',''),(151,'Netherlands Antilles','AN','ANT',1,1,1,1,12.1685343,-68.3782196,12.0000,0,'','0','+599',''),(152,'New Caledonia','NC','NCL',1,1,1,1,-21.2044659,164.7305450,8.0000,0,'','0','+687',''),(153,'New Zealand','NZ','NZL',5,1,1,1,-43.0136032,163.4825134,5.0000,0,'','0','+64',''),(154,'Nicaragua','NI','NIC',1,1,1,1,12.8694620,-86.2624130,8.0000,0,'','0','+505',''),(155,'Niger','NE','NER',1,1,1,1,17.5568523,3.5858376,6.0000,0,'','0','+227',''),(156,'Nigeria','NG','NGA',1,1,1,1,9.0763350,6.4334841,7.0000,0,'','0','+234',''),(157,'Niue','NU','NIU',1,1,1,1,-19.0538788,-169.9320984,12.0000,0,'','0','+683',''),(158,'Norfolk Island','NF','NFK',1,1,1,1,-29.0346260,167.9220123,13.0000,0,'','0','+672',''),(159,'Northern Mariana Islands','MP','MNP',1,1,1,1,15.1067133,145.5661621,11.0000,0,'','0','+1-670',''),(160,'Norway','NO','NOR',5,1,1,1,64.3119049,8.9585018,5.0000,0,'','0','+47',''),(161,'Oman','OM','OMN',1,1,1,1,21.4779568,51.4259109,6.0000,0,'','0','+968',''),(162,'Pakistan','PK','PAK',1,1,1,1,30.3255138,64.8606720,6.0000,0,'','0','+92',''),(163,'Palau','PW','PLW',1,1,1,1,7.3669419,134.1539612,10.0000,0,'','0','+680',''),(164,'Panama','PA','PAN',1,1,1,1,8.4266472,-81.2265930,8.0000,0,'','0','+507',''),(165,'Papua New Guinea','PG','PNG',1,1,1,1,-6.2345257,144.4682007,6.0000,0,'','0','+675',''),(166,'Paraguay','PY','PRY',1,1,1,1,-23.3694382,-60.6940308,7.0000,0,'','0','+595',''),(167,'Peru','PE','PER',1,1,1,1,-9.1565142,-79.4857712,6.0000,0,'','0','+51',''),(168,'Philippines','PH','PHL',1,1,1,1,11.6736164,118.1263733,6.0000,0,'','0','+63',''),(169,'Pitcairn','PN','PCN',1,1,1,1,-24.3766632,-128.3592529,13.0000,0,'','0','+64',''),(170,'Poland','PL','POL',5,1,1,1,51.9009895,16.8921185,7.0000,0,'PL','10','+48',''),(171,'Portugal','PT','PRT',5,1,1,1,39.5398674,-10.0965986,7.0000,0,'PT','9','+351',''),(172,'Puerto Rico','PR','PRI',1,1,1,1,18.1992130,-66.9131165,9.0000,0,'','0','+1-787',''),(173,'Qatar','QA','QAT',1,1,1,1,25.3272877,50.6362190,9.0000,0,'','0','+974',''),(174,'Reunion','RE','REU',1,1,1,1,-21.1303101,55.3863945,11.0000,0,'','0','+262',''),(175,'Romania','RO','ROM',1,1,1,1,45.9238319,22.7668324,7.0000,0,'','0','+40',''),(176,'Russian Federation','RU','RUS',1,1,1,1,49.8154221,68.8280487,3.0000,0,'','0','+7',''),(177,'Rwanda','RW','RWA',1,1,1,1,-1.9421910,29.3199863,9.0000,0,'','0','+250',''),(178,'Saint Kitts and Nevis','KN','KNA',1,1,1,1,17.2563705,17.2563705,11.0000,0,'','0','+1-869',''),(179,'Saint Lucia','LC','LCA',1,1,1,1,13.9098177,-61.1164665,11.0000,0,'','0','+1-758',''),(180,'Saint Vincent and the Grenadines','VC','VCT',1,1,1,1,13.2529755,-61.2672043,12.0000,0,'','0','+1-784',''),(181,'Samoa','WS','WSM',1,1,1,1,-13.7573099,-172.3849487,10.0000,0,'','0','+685',''),(182,'San Marino','SM','SMR',1,1,1,1,43.9429359,12.4250736,13.0000,0,'','0','+378',''),(183,'Sao Tome and Principe','ST','STP',1,1,1,1,0.2000378,6.4704800,11.0000,0,'','0','+239',''),(184,'Saudi Arabia','SA','SAU',1,1,1,1,24.2109337,40.6146622,6.0000,0,'','0','+966',''),(185,'Senegal','SN','SEN',1,1,1,1,14.5001726,-15.5604429,8.0000,0,'','0','+221',''),(186,'Seychelles','SC','SYC',1,1,1,1,-4.6836295,55.3794365,12.0000,0,'','0','+248',''),(187,'Sierra Leone','SL','SLE',1,1,1,1,8.4507780,-12.9082880,8.0000,0,'','0','+232',''),(188,'Singapore','SG','SGP',4,1,1,1,1.3149014,103.7769775,12.0000,0,'','0','+65',''),(189,'Slovakia (Slovak Republic)','SK','SVK',1,1,1,1,48.6688576,18.5750942,8.0000,0,'SK','9','+421',''),(190,'Slovenia','SI','SVN',1,1,1,1,46.1487503,14.4256067,9.0000,0,'SI','8','+386',''),(191,'Solomon Islands','SB','SLB',1,1,1,1,-9.2139683,156.9434814,7.0000,0,'','0','+677',''),(192,'Somalia','SO','SOM',1,1,1,1,5.1584358,41.7078094,6.0000,0,'','0','+252',''),(193,'South Africa','ZA','ZAF',1,1,1,1,-28.3958130,20.1809998,6.0000,0,'','0','+27',''),(194,'South Georgia and the South Sandwich Islands','GS','SGS',1,1,1,1,-54.4360695,-37.5472755,9.0000,0,'','0','+500',''),(195,'Spain','ES','ESP',5,1,1,1,40.1301613,-8.2016420,6.0000,0,'ES','9','+34',''),(196,'Sri Lanka','LK','LKA',1,1,1,1,7.8784561,79.5791092,8.0000,0,'','0','+94',''),(197,'St. Helena','SH','SHN',1,1,1,1,-15.9619837,-5.7484388,13.0000,0,'','0','+290',''),(198,'St. Pierre and Miquelon','PM','SPM',1,1,1,1,46.9468384,-56.4023666,11.0000,0,'','0','+508',''),(199,'Sudan','SD','SDN',1,1,1,1,15.7505217,25.7044716,6.0000,0,'','0','+249',''),(200,'Suriname','SR','SUR',1,1,1,1,3.9252872,-57.1320000,8.0000,0,'','0','+597',''),(201,'Svalbard and Jan Mayen Islands','SJ','SJM',1,1,1,1,78.5045013,13.0720978,5.0000,0,'','0','+47',''),(202,'Swaziland','SZ','SWZ',1,1,1,1,-26.5153370,30.9023495,9.0000,0,'','0','+268',''),(203,'Sweden','SE','SWE',5,1,1,1,61.9190712,8.6290922,5.0000,0,'SE','12','+46',''),(204,'Switzerland','CH','CHE',5,1,1,1,46.8095970,7.1032281,8.0000,0,'','0','+41',''),(205,'Syrian Arab Republic','SY','SYR',1,1,1,1,34.7988434,36.8032799,7.0000,0,'','0','+963',''),(206,'Taiwan','TW','TWN',1,1,1,1,23.5561352,119.8999252,8.0000,0,'','0','+886',''),(207,'Tajikistan','TJ','TJK',1,1,1,1,38.8410072,69.0050125,7.0000,0,'','0','+992',''),(208,'Tanzania, United Republic of','TZ','TZA',1,1,1,1,-6.3424382,30.3968410,6.0000,0,'','0','+255',''),(209,'Thailand','TH','THA',1,1,1,1,13.0108509,96.9948807,6.0000,0,'','0','+66',''),(210,'Togo','TG','TGO',1,1,1,1,0.0000000,0.0000000,0.0000,0,'','0','+228',''),(211,'Tokelau','TK','TKL',1,1,1,1,0.0000000,0.0000000,0.0000,0,'','0','+690',''),(212,'Tonga','TO','TON',1,1,1,1,-21.2414112,-175.2686310,11.0000,0,'','0','+676',''),(213,'Trinidad and Tobago','TT','TTO',1,1,1,1,10.4437017,-61.7004623,10.0000,0,'','0','+1-868',''),(214,'Tunisia','TN','TUN',1,1,1,1,33.7774353,7.3175435,7.0000,0,'','0','+216',''),(215,'Turkey','TR','TUR',1,1,1,1,38.8798676,30.7526493,6.0000,0,'','0','+90',''),(216,'Turkmenistan','TM','TKM',1,1,1,1,38.9466095,57.3346291,7.0000,0,'','0','+993',''),(217,'Turks and Caicos Islands','TC','TCA',1,1,1,1,21.7085915,-72.2523041,10.0000,0,'','0','+1-649',''),(218,'Tuvalu','TV','TUV',1,1,1,1,-7.4783778,178.6624146,14.0000,0,'','0','+688',''),(219,'Uganda','UG','UGA',1,1,1,1,1.3726031,30.0592270,7.0000,0,'','0','+256',''),(220,'Ukraine','UA','UKR',1,1,1,1,49.1221161,32.2989693,6.0000,0,'','0','+380',''),(221,'United Arab Emirates','AE','ARE',1,1,1,1,24.3489666,52.8184738,8.0000,0,'','0','+971',''),(222,'United Kingdom','GB','GBR',6,1,1,1,55.2873650,0.9266682,6.0000,0,'GB','9','+44',''),(223,'United States','US','USA',2,1,1,1,37.2756996,-104.6555176,5.0000,0,'','0','+1',''),(224,'United States Minor Outlying Islands','UM','UMI',1,1,1,1,19.2954140,166.6105347,14.0000,0,'','0','+1',''),(225,'Uruguay','UY','URY',1,1,1,1,-32.5337715,-58.0547409,7.0000,0,'','0','+598',''),(226,'Uzbekistan','UZ','UZB',1,1,1,1,41.3021622,60.0853233,6.0000,0,'','0','+998',''),(227,'Vanuatu','VU','VUT',1,1,1,1,-15.4437485,166.4742279,8.0000,0,'','0','+678',''),(228,'Vatican City State (Holy See)','VA','VAT',1,1,1,1,41.9038200,12.4498730,17.0000,0,'','0','+379',''),(229,'Venezuela','VE','VEN',1,1,1,1,6.6477470,-71.1104889,6.0000,0,'','0','+58',''),(230,'Viet Nam','VN','VNM',1,1,1,1,15.8672028,101.3118744,6.0000,0,'','0','+84',''),(231,'Virgin Islands (British)','VG','VGB',1,1,1,1,18.4183636,-64.7255173,11.0000,0,'','0','+1-284',''),(232,'Virgin Islands (U.S.)','VI','VIR',1,1,1,1,18.0672302,-65.0188675,10.0000,0,'','0','+1-340',''),(233,'Wallis and Futuna Islands','WF','WLF',1,1,1,1,-14.3012953,-178.1258850,13.0000,0,'','0','+681',''),(234,'Western Sahara','EH','ESH',1,1,1,1,24.2073250,-15.1296377,7.0000,0,'','0','+212',''),(235,'Yemen','YE','YEM',1,1,1,1,15.5478525,45.9312286,7.0000,0,'','0','+967',''),(237,'Zaire','ZR','ZAR',1,1,1,1,-4.0101647,17.2542477,6.0000,0,'','0','+243',''),(238,'Zambia','ZM','ZMB',1,1,1,1,-13.1252708,25.6103764,7.0000,0,'','0','+260',''),(239,'Zimbabwe','ZW','ZWE',1,1,1,1,-18.9971066,26.9091663,7.0000,0,'','0','+263',''),(240,'Isle of Man','IM','IMN',1,1,1,0,54.2311897,-4.7095847,11.0000,0,'0','0','+44-1624',''),(241,'Guernsey','GG','GGY',1,1,1,0,49.4630585,-2.6231315,13.0000,0,'0','0','+44-1481',''),(242,'Jersey','JE','JEY',1,1,1,0,49.2111053,-2.2026720,12.0000,0,'0','0','+44-1534','');
/*!40000 ALTER TABLE `countries` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `coupon_email_track`
--

DROP TABLE IF EXISTS `coupon_email_track`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `coupon_email_track` (
  `unique_id` int(11) NOT NULL AUTO_INCREMENT,
  `coupon_id` int(11) NOT NULL DEFAULT '0',
  `customer_id_sent` int(11) NOT NULL DEFAULT '0',
  `basket_id` int(11) NOT NULL DEFAULT '0',
  `sent_firstname` varchar(32) DEFAULT NULL,
  `sent_lastname` varchar(32) DEFAULT NULL,
  `emailed_to` varchar(32) DEFAULT NULL,
  `date_sent` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (`unique_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `coupon_email_track`
--

LOCK TABLES `coupon_email_track` WRITE;
/*!40000 ALTER TABLE `coupon_email_track` DISABLE KEYS */;
/*!40000 ALTER TABLE `coupon_email_track` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `coupon_gv_customer`
--

DROP TABLE IF EXISTS `coupon_gv_customer`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `coupon_gv_customer` (
  `customer_id` int(5) NOT NULL DEFAULT '0',
  `amount` decimal(8,4) NOT NULL DEFAULT '0.0000',
  `currency` char(3) NOT NULL DEFAULT 'GBP',
  PRIMARY KEY (`customer_id`),
  KEY `customer_id` (`customer_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `coupon_gv_customer`
--

LOCK TABLES `coupon_gv_customer` WRITE;
/*!40000 ALTER TABLE `coupon_gv_customer` DISABLE KEYS */;
/*!40000 ALTER TABLE `coupon_gv_customer` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `coupon_gv_queue`
--

DROP TABLE IF EXISTS `coupon_gv_queue`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `coupon_gv_queue` (
  `unique_id` int(5) NOT NULL AUTO_INCREMENT,
  `customer_id` int(5) NOT NULL DEFAULT '0',
  `order_id` int(5) NOT NULL DEFAULT '0',
  `amount` decimal(8,4) NOT NULL DEFAULT '0.0000',
  `currency` char(3) NOT NULL DEFAULT 'GBP',
  `date_created` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `ipaddr` varchar(32) NOT NULL DEFAULT '',
  `release_flag` char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (`unique_id`),
  KEY `uid` (`unique_id`,`customer_id`,`order_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `coupon_gv_queue`
--

LOCK TABLES `coupon_gv_queue` WRITE;
/*!40000 ALTER TABLE `coupon_gv_queue` DISABLE KEYS */;
/*!40000 ALTER TABLE `coupon_gv_queue` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `coupon_redeem_track`
--

DROP TABLE IF EXISTS `coupon_redeem_track`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `coupon_redeem_track` (
  `unique_id` int(11) NOT NULL AUTO_INCREMENT,
  `coupon_id` int(11) NOT NULL DEFAULT '0',
  `customer_id` int(11) NOT NULL DEFAULT '0',
  `redeem_date` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `redeem_ip` varchar(32) NOT NULL DEFAULT '',
  `order_id` int(11) NOT NULL DEFAULT '0',
  `spend_flag` int(1) DEFAULT '0',
  `spend_amount` decimal(15,2) DEFAULT '0.00',
  PRIMARY KEY (`unique_id`),
  KEY `coupon_redeem_track_customer_idx` (`coupon_id`,`customer_id`),
  KEY `coupon_redeem_track_orders_idx` (`order_id`,`coupon_id`),
  KEY `idx_coupon_id` (`coupon_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `coupon_redeem_track`
--

LOCK TABLES `coupon_redeem_track` WRITE;
/*!40000 ALTER TABLE `coupon_redeem_track` DISABLE KEYS */;
/*!40000 ALTER TABLE `coupon_redeem_track` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `coupon_refer_queue`
--

DROP TABLE IF EXISTS `coupon_refer_queue`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `coupon_refer_queue` (
  `rq_id` int(11) NOT NULL AUTO_INCREMENT,
  `rq_code` varchar(64) NOT NULL DEFAULT '',
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `customers_email` varchar(96) NOT NULL DEFAULT '',
  `friend_customers_id` int(11) NOT NULL DEFAULT '0',
  `friend_customers_email` varchar(96) NOT NULL DEFAULT '',
  `rq_status` tinyint(1) NOT NULL DEFAULT '0',
  `rq_version` varchar(32) NOT NULL DEFAULT 'gift',
  `rq_amount` decimal(10,4) NOT NULL DEFAULT '0.0000',
  `rq_amount_type` char(1) NOT NULL DEFAULT 'G',
  `rq_promo_info` text NOT NULL,
  `rq_release_orders_id` int(11) NOT NULL DEFAULT '0',
  `rq_send_date` datetime DEFAULT NULL,
  `rq_release_date` datetime DEFAULT NULL,
  PRIMARY KEY (`rq_id`),
  KEY `rq_code` (`rq_code`),
  KEY `friend_customers_id` (`friend_customers_id`,`rq_status`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `coupon_refer_queue`
--

LOCK TABLES `coupon_refer_queue` WRITE;
/*!40000 ALTER TABLE `coupon_refer_queue` DISABLE KEYS */;
/*!40000 ALTER TABLE `coupon_refer_queue` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `coupons`
--

DROP TABLE IF EXISTS `coupons`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `coupons` (
  `coupon_id` int(11) NOT NULL AUTO_INCREMENT,
  `coupon_type` char(1) NOT NULL DEFAULT 'F',
  `free_shipping` int(1) NOT NULL DEFAULT '0',
  `coupon_code` varchar(32) NOT NULL DEFAULT '',
  `coupon_amount` decimal(8,4) NOT NULL DEFAULT '0.0000',
  `coupon_currency` char(3) NOT NULL DEFAULT 'GBP',
  `coupon_minimum_order` decimal(8,4) NOT NULL DEFAULT '0.0000',
  `coupon_start_date` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `coupon_expire_date` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `uses_per_coupon` int(5) NOT NULL DEFAULT '1',
  `uses_per_user` int(5) NOT NULL DEFAULT '0',
  `uses_per_shipping` tinyint(4) NOT NULL DEFAULT '0',
  `restrict_to_products` varchar(255) DEFAULT NULL,
  `restrict_to_categories` varchar(255) DEFAULT NULL,
  `restrict_to_customers` text,
  `coupon_active` char(1) NOT NULL DEFAULT 'Y',
  `date_created` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `date_modified` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `coupon_for_recovery_email` tinyint(4) NOT NULL DEFAULT '0',
  `tax_class_id` tinyint(4) NOT NULL DEFAULT '0',
  `flag_with_tax` tinyint(4) NOT NULL DEFAULT '0',
  `restrict_to_countries` varchar(255) DEFAULT NULL,
  `exclude_products` varchar(1024) NOT NULL DEFAULT '',
  `exclude_categories` varchar(1024) NOT NULL DEFAULT '',
  `disable_for_special` int(1) NOT NULL DEFAULT '0',
  `products_max_allowed_qty` varchar(4) NOT NULL DEFAULT '',
  `products_id_per_coupon` varchar(4) NOT NULL DEFAULT '',
  `spend_partly` int(1) DEFAULT '0',
  `check_platforms` int(1) NOT NULL DEFAULT '0',
  `single_per_order` int(1) NOT NULL DEFAULT '0',
  `pos_only` int(1) NOT NULL DEFAULT '0',
  `coupon_groups` varchar(2048) NOT NULL DEFAULT '',
  `restrict_to_manufacturers` text NOT NULL,
  `coupon_amount_maximum` decimal(15,2) NOT NULL,
  PRIMARY KEY (`coupon_id`),
  KEY `coupons_coupon_code_idx` (`coupon_code`),
  KEY `idx_pos_coupon` (`pos_only`),
  KEY `idx_coupon_active` (`coupon_active`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `coupons`
--

LOCK TABLES `coupons` WRITE;
/*!40000 ALTER TABLE `coupons` DISABLE KEYS */;
/*!40000 ALTER TABLE `coupons` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `coupons_customercodes_list`
--

DROP TABLE IF EXISTS `coupons_customercodes_list`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `coupons_customercodes_list` (
  `customercode_id` int(11) NOT NULL AUTO_INCREMENT,
  `coupon_id` int(11) NOT NULL DEFAULT '0',
  `coupon_code` varchar(32) NOT NULL DEFAULT '',
  `only_for_customer` varchar(255) NOT NULL DEFAULT '',
  `date_added` datetime DEFAULT NULL,
  PRIMARY KEY (`customercode_id`),
  UNIQUE KEY `idx-record_unique` (`coupon_id`,`coupon_code`,`only_for_customer`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `coupons_customercodes_list`
--

LOCK TABLES `coupons_customercodes_list` WRITE;
/*!40000 ALTER TABLE `coupons_customercodes_list` DISABLE KEYS */;
/*!40000 ALTER TABLE `coupons_customercodes_list` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `coupons_description`
--

DROP TABLE IF EXISTS `coupons_description`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `coupons_description` (
  `coupon_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `coupon_name` varchar(32) NOT NULL DEFAULT '',
  `coupon_description` text,
  UNIQUE KEY `language_coupon` (`language_id`,`coupon_id`),
  KEY `coupon_id` (`coupon_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `coupons_description`
--

LOCK TABLES `coupons_description` WRITE;
/*!40000 ALTER TABLE `coupons_description` DISABLE KEYS */;
/*!40000 ALTER TABLE `coupons_description` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `coupons_to_platform`
--

DROP TABLE IF EXISTS `coupons_to_platform`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `coupons_to_platform` (
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `coupon_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`platform_id`,`coupon_id`),
  KEY `idx_promo_id` (`coupon_id`),
  CONSTRAINT `fk_coupon_id` FOREIGN KEY (`coupon_id`) REFERENCES `coupons` (`coupon_id`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT `fk_coupon_platform_id` FOREIGN KEY (`platform_id`) REFERENCES `platforms` (`platform_id`) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `coupons_to_platform`
--

LOCK TABLES `coupons_to_platform` WRITE;
/*!40000 ALTER TABLE `coupons_to_platform` DISABLE KEYS */;
/*!40000 ALTER TABLE `coupons_to_platform` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `currencies`
--

DROP TABLE IF EXISTS `currencies`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `currencies` (
  `currencies_id` int(11) NOT NULL AUTO_INCREMENT,
  `title` varchar(32) NOT NULL DEFAULT '',
  `code` char(3) NOT NULL DEFAULT '',
  `symbol_left` varchar(12) DEFAULT NULL,
  `symbol_right` varchar(12) DEFAULT NULL,
  `decimal_point` char(1) DEFAULT NULL,
  `thousands_point` char(1) DEFAULT NULL,
  `decimal_places` char(1) DEFAULT NULL,
  `value` float(13,8) DEFAULT NULL,
  `last_updated` datetime DEFAULT NULL,
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `status` tinyint(4) DEFAULT '1',
  `nominals` varchar(50) DEFAULT NULL,
  `code_number` varchar(5) NOT NULL DEFAULT '',
  PRIMARY KEY (`currencies_id`)
) ENGINE=InnoDB AUTO_INCREMENT=16 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `currencies`
--

LOCK TABLES `currencies` WRITE;
/*!40000 ALTER TABLE `currencies` DISABLE KEYS */;
INSERT INTO `currencies` VALUES (2,'Euro','EUR','€','','.',',','2',1.13334000,'2018-03-16 12:10:22',2,1,'5,10,20,50,100','978'),(11,'USD','USD','$','','.',',','2',1.39695001,'2018-03-16 12:10:21',3,1,'5,10,20,50,100','840'),(15,'British Pound','GBP','£','','.',',','2',1.00000000,'2018-03-16 12:10:22',1,1,'5,10,20,50','826');
/*!40000 ALTER TABLE `currencies` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `currently_viewing`
--

DROP TABLE IF EXISTS `currently_viewing`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `currently_viewing` (
  `products_id` int(11) NOT NULL DEFAULT '0',
  `customers_ip` varchar(255) NOT NULL DEFAULT '',
  `last_click` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  UNIQUE KEY `idx_products_id` (`products_id`,`customers_ip`),
  KEY `idx_last_click` (`last_click`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `currently_viewing`
--

LOCK TABLES `currently_viewing` WRITE;
/*!40000 ALTER TABLE `currently_viewing` DISABLE KEYS */;
INSERT INTO `currently_viewing` VALUES (22,'bcc9c2de2d53e1e0a16e21b6152ce922','2022-07-25 13:21:51');
/*!40000 ALTER TABLE `currently_viewing` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers`
--

DROP TABLE IF EXISTS `customers`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers` (
  `customers_id` int(11) NOT NULL AUTO_INCREMENT,
  `customers_gender` char(4) NOT NULL DEFAULT '',
  `customers_firstname` varchar(32) NOT NULL DEFAULT '',
  `customers_lastname` varchar(32) NOT NULL DEFAULT '',
  `customers_dob` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `dob_flag` tinyint(1) NOT NULL DEFAULT '0',
  `customers_email_address` varchar(96) NOT NULL DEFAULT '',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `departments_id` int(11) NOT NULL DEFAULT '0',
  `customers_default_address_id` int(11) NOT NULL DEFAULT '0',
  `customers_telephone` varchar(32) NOT NULL DEFAULT '',
  `customers_landline` varchar(32) NOT NULL DEFAULT '',
  `customers_fax` varchar(32) DEFAULT NULL,
  `customers_password` varchar(255) NOT NULL DEFAULT '',
  `customers_newsletter` char(1) DEFAULT NULL,
  `customers_selected_template` varchar(64) NOT NULL DEFAULT '',
  `admin_id` int(11) NOT NULL DEFAULT '0',
  `customers_alt_email_address` varchar(96) DEFAULT NULL,
  `customers_alt_telephone` varchar(32) DEFAULT NULL,
  `customers_cell` varchar(32) DEFAULT NULL,
  `customers_owc_member` int(11) NOT NULL DEFAULT '0',
  `customers_type_id` int(11) NOT NULL DEFAULT '0',
  `customers_bonus_points` int(11) NOT NULL DEFAULT '0',
  `customers_credit_avail` decimal(10,4) NOT NULL DEFAULT '0.0000',
  `affiliate_id` int(11) NOT NULL DEFAULT '0',
  `groups_id` int(10) unsigned NOT NULL DEFAULT '0',
  `customers_status` tinyint(1) NOT NULL DEFAULT '1',
  `last_xml_import` datetime DEFAULT NULL,
  `last_xml_export` datetime DEFAULT NULL,
  `opc_temp_account` int(11) NOT NULL DEFAULT '0',
  `customers_company` varchar(32) NOT NULL DEFAULT '',
  `dnu_customers_company_vat` varchar(128) NOT NULL DEFAULT '' COMMENT 'not visible in admin, cant be changed so renamed',
  `credit_amount` decimal(11,2) NOT NULL DEFAULT '0.00',
  `sap_servers_id` int(11) NOT NULL DEFAULT '0',
  `customers_currency_id` int(11) NOT NULL DEFAULT '15',
  `customers_cardcode` varchar(32) NOT NULL DEFAULT '',
  `currency_switcher` int(1) NOT NULL DEFAULT '0',
  `erp_customer_id` int(11) NOT NULL DEFAULT '0',
  `erp_customer_code` varchar(32) DEFAULT NULL,
  `trustpilot_disabled` tinyint(1) NOT NULL DEFAULT '0',
  `pin` varchar(8) NOT NULL DEFAULT '',
  `_api_time_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `payerreference` varchar(255) NOT NULL DEFAULT '',
  `language_id` int(11) NOT NULL DEFAULT '1',
  `auth_key` varchar(32) NOT NULL DEFAULT '',
  `can_use_drop_ship` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`customers_id`),
  KEY `customers_email_address` (`customers_email_address`(8),`customers_status`)
) ENGINE=InnoDB AUTO_INCREMENT=49 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers`
--

LOCK TABLES `customers` WRITE;
/*!40000 ALTER TABLE `customers` DISABLE KEYS */;
INSERT INTO `customers` VALUES (1,'','Abraham','Dalton','1976-05-20 00:00:00',0,'Abraham.Dalton@holbi.co.uk',1,0,1,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(2,'','Mandy','Cross','1992-09-17 00:00:00',0,'Mandy.Cross@holbi.co.uk',1,0,2,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(3,'','Christian','Fairbairn','1986-11-11 00:00:00',0,'Christian.Fairbairn@holbi.co.uk',1,0,3,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(4,'','Delmar','Masters','1992-11-27 00:00:00',0,'Delmar.Masters@holbi.co.uk',1,0,4,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(5,'','Priscilla','Platt','1969-03-18 00:00:00',0,'Priscilla.Platt@holbi.co.uk',1,0,5,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(6,'','Grover','O\'Shaughnessy','0000-00-00 00:00:00',0,'Grover.OShaughnessy@holbi.co.uk',1,0,6,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(7,'','Laurie','O’Shea','1994-12-14 00:00:00',0,'Laurie.OShea@holbi.co.uk',1,0,7,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(8,'','Carol','Tailor','1996-07-24 00:00:00',0,'Carol.Tailor@holbi.co.uk',1,0,8,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(9,'','Jeffrey','MacKay','1988-02-17 00:00:00',0,'Jeffrey.MacKay@holbi.co.uk',1,0,9,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(10,'','Lester','Rake','1977-04-30 00:00:00',0,'Lester.Rake@holbi.co.uk',1,0,10,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(11,'','Marcus','Snider','1967-09-01 00:00:00',0,'Marcus.Snider@holbi.co.uk',1,0,11,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(12,'','Jason','dinAlt','1958-03-20 00:00:00',0,'Jason.dinAlt@holbi.co.uk',1,0,12,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(13,'','Philip','Miller','1981-01-28 00:00:00',0,'Philip.Miller@holbi.co.uk',1,0,13,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(14,'','Todd','Walker','1956-04-17 00:00:00',0,'Todd.Walker@holbi.co.uk',1,0,14,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(15,'','Anabella','Lopez','1987-10-09 00:00:00',0,'Anabella.Lopez@holbi.co.uk',1,0,15,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(16,'','Dolores','Gutierrez','1973-06-30 00:00:00',0,'DoloresGutierrez@holbi.co.uk',1,0,16,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(17,'','Forrest','Parker','1996-04-09 00:00:00',0,'Forrest.Parker@holbi.co.uk',1,0,17,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(18,'','Grace','Wilson','1998-06-10 00:00:00',0,'Grace.Wilson@holbi.co.uk',1,0,18,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(19,'','Madison','Tremblay','1979-11-08 00:00:00',0,'Madison.Tremblay@holbi.co.uk',1,0,19,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(20,'','Daan','De Vries','1990-10-19 00:00:00',0,'Daan.DeVries@holbi.co.uk',1,0,20,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(21,'','Lotte','Van Dijk','1986-06-18 00:00:00',0,'Lotte.VanDijk@holbi.co.uk',1,0,21,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(22,'','Ulrich','Stellmacher','1982-07-26 00:00:00',0,'Ulrich.Stellmacher@holbi.co.uk',1,0,22,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(23,'','Brunhild','Kruger','1979-04-17 00:00:00',0,'Brunhild.Kruger@holbi.co.uk',1,0,23,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(24,'','Carlos','Esteban','1991-03-25 00:00:00',0,'Carlos.Esteban@holbi.co.uk',1,0,24,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(25,'','Maria Jose','Velazquez','1977-08-18 00:00:00',0,'MariaJose.Velazquez@holbi.co.uk',1,0,25,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(26,'','Vassilios','Vassiliadis','1967-06-29 00:00:00',0,'Vassilios.Vassiliadis@holbi.co.uk',1,0,26,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(27,'','Maria','Gonzalez','1997-07-14 00:00:00',0,'Maria.Gonzalez@holbi.co.uk',1,0,27,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(28,'','Alice','Silva','1999-06-15 00:00:00',0,'Alice.Silva@holbi.co.uk',1,0,28,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(29,'','Matias','Gomes','1989-09-22 00:00:00',0,'Matias.Gomes@holbi.co.uk',1,0,29,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(30,'','Sebastian','Pereira','1974-07-26 00:00:00',0,'Sebastian.Pereira@holbi.co.uk',1,0,30,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(31,'','Sophia','Fernandes','1998-06-20 00:00:00',0,'Sophia.Fernandes@holbi.co.uk',1,0,31,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(32,'','Isidora','Ruiz','1981-12-02 00:00:00',0,'Isidora.Ruiz@holbi.co.uk',1,0,32,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(33,'','Kamila','Garcia','1996-06-27 00:00:00',0,'Kamila.Garcia@holbi.co.uk',1,0,33,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(34,'','Drishya','Kulkarni','1987-06-10 00:00:00',0,'Drishya.Kulkarni@holbi.co.uk',1,0,34,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(35,'','Classen','Tasnim','1989-02-14 00:00:00',0,'Classen.Tasnim@holbi.co.uk',1,0,35,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(36,'','Zanldi','Erasmus','1995-09-08 00:00:00',0,'Zanldi.Erasmus@holbi.co.uk',1,0,36,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(37,'','Yair','Ramon','1992-03-04 00:00:00',0,'Yair.Ramon@holbi.co.uk',1,0,37,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(38,'','Banafrit','Elmanhaly','1976-05-04 00:00:00',0,'Banafrit.Elmanhaly@holbi.co.uk',1,0,38,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(39,'','Fadwa','Toukan','1988-12-21 00:00:00',0,'Fadwa.Toukan@holbi.co.uk',1,0,40,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(40,'','Daniel','Jensen','1988-09-16 00:00:00',0,'Daniel.Jensen@holbi.co.uk',1,0,42,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(41,'','Slim','Harris','1979-04-17 00:00:00',0,'Slim.Harris@holbi.co.uk',1,0,43,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(42,'','Kate','Kelly','1997-07-10 00:00:00',0,'Kate.Kelly@holbi.co.uk',1,0,44,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(43,'','Li','Chong','1973-07-25 00:00:00',0,'Li.Chong@holbi.co.uk',1,0,45,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(44,'','Tan','Mok','1991-06-13 00:00:00',0,'Tan.Mok@holbi.co.uk',1,0,46,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(45,'','Chan','Ngiem','1986-06-18 00:00:00',0,'Chan.Ngiem@holbi.co.uk',1,0,47,'','',NULL,'','','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(46,'','Tsuguho','Kawahara','0000-00-00 00:00:00',0,'TsuguhoKawahara@holbi.co.uk',1,0,48,'','',NULL,'','1','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(47,'','Hirari','Senda','2000-03-01 00:00:00',0,'HirariSenda@holbi.co.uk',1,0,49,'','',NULL,'','0','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0),(48,'','Uki-chan','Kawahara-chan','0000-00-00 00:00:00',0,'UkiKawahara@holbi.co.uk',1,0,51,'','',NULL,'','1','',0,NULL,NULL,NULL,0,0,0,0.0000,0,1,1,NULL,NULL,0,'','',0.00,0,15,'',0,0,'',0,'','[[regtime]]','',1,'',0);
/*!40000 ALTER TABLE `customers` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers_basket`
--

DROP TABLE IF EXISTS `customers_basket`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers_basket` (
  `customers_basket_id` int(11) NOT NULL AUTO_INCREMENT,
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `basket_id` int(11) NOT NULL DEFAULT '0',
  `multi_email_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `currency` char(3) NOT NULL DEFAULT '',
  `products_id` tinytext NOT NULL,
  `customers_basket_quantity` int(2) NOT NULL DEFAULT '0',
  `final_price` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `customers_basket_date_added` varchar(8) DEFAULT NULL,
  `is_giveaway` tinyint(1) NOT NULL DEFAULT '0',
  `is_pack` int(11) NOT NULL DEFAULT '0',
  `unit` int(11) NOT NULL DEFAULT '0',
  `pack_unit` int(11) NOT NULL DEFAULT '0',
  `packaging` int(11) NOT NULL DEFAULT '0',
  `gaw_id` int(11) NOT NULL DEFAULT '0',
  `is_temlplate` tinyint(1) NOT NULL DEFAULT '0',
  `parent_product` tinytext NOT NULL,
  `elements` text NOT NULL,
  `relation_type` varchar(32) NOT NULL DEFAULT '',
  `props` text NOT NULL,
  PRIMARY KEY (`customers_basket_id`),
  KEY `customers_id` (`customers_id`),
  KEY `customers_id_2` (`customers_id`,`basket_id`),
  KEY `platform_id` (`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers_basket`
--

LOCK TABLES `customers_basket` WRITE;
/*!40000 ALTER TABLE `customers_basket` DISABLE KEYS */;
/*!40000 ALTER TABLE `customers_basket` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers_basket_attributes`
--

DROP TABLE IF EXISTS `customers_basket_attributes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers_basket_attributes` (
  `customers_basket_attributes_id` int(11) NOT NULL AUTO_INCREMENT,
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `basket_id` int(11) DEFAULT '0',
  `multi_email_id` int(11) NOT NULL DEFAULT '0',
  `products_id` tinytext NOT NULL,
  `products_options_id` varchar(32) NOT NULL DEFAULT '0',
  `products_options_value_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`customers_basket_attributes_id`),
  KEY `customers_id` (`customers_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers_basket_attributes`
--

LOCK TABLES `customers_basket_attributes` WRITE;
/*!40000 ALTER TABLE `customers_basket_attributes` DISABLE KEYS */;
/*!40000 ALTER TABLE `customers_basket_attributes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers_credit_history`
--

DROP TABLE IF EXISTS `customers_credit_history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers_credit_history` (
  `customers_credit_history_id` int(11) NOT NULL AUTO_INCREMENT,
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `credit_prefix` varchar(1) NOT NULL DEFAULT '',
  `credit_amount` decimal(11,2) NOT NULL DEFAULT '0.00',
  `currency` char(3) NOT NULL DEFAULT '',
  `currency_value` decimal(14,6) NOT NULL DEFAULT '0.000000',
  `customer_notified` tinyint(1) NOT NULL DEFAULT '0',
  `comments` mediumtext NOT NULL,
  `date_added` datetime DEFAULT NULL,
  `admin_id` int(11) NOT NULL DEFAULT '0',
  `credit_type` tinyint(4) DEFAULT '0',
  PRIMARY KEY (`customers_credit_history_id`),
  KEY `customers_credit_history_customers_id_idx` (`customers_id`,`credit_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers_credit_history`
--

LOCK TABLES `customers_credit_history` WRITE;
/*!40000 ALTER TABLE `customers_credit_history` DISABLE KEYS */;
/*!40000 ALTER TABLE `customers_credit_history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers_email_validation`
--

DROP TABLE IF EXISTS `customers_email_validation`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers_email_validation` (
  `cev_id` int(11) NOT NULL AUTO_INCREMENT,
  `cev_email` varchar(64) NOT NULL,
  `cev_code` varchar(64) NOT NULL,
  PRIMARY KEY (`cev_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers_email_validation`
--

LOCK TABLES `customers_email_validation` WRITE;
/*!40000 ALTER TABLE `customers_email_validation` DISABLE KEYS */;
/*!40000 ALTER TABLE `customers_email_validation` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers_emails`
--

DROP TABLE IF EXISTS `customers_emails`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers_emails` (
  `customers_id` int(11) NOT NULL,
  `customers_email` varchar(150) NOT NULL,
  PRIMARY KEY (`customers_id`,`customers_email`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers_emails`
--

LOCK TABLES `customers_emails` WRITE;
/*!40000 ALTER TABLE `customers_emails` DISABLE KEYS */;
/*!40000 ALTER TABLE `customers_emails` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers_errors`
--

DROP TABLE IF EXISTS `customers_errors`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers_errors` (
  `customers_errors_id` int(11) NOT NULL AUTO_INCREMENT,
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `basket_id` int(11) NOT NULL DEFAULT '0',
  `error_entity` varchar(32) DEFAULT NULL,
  `error_title` varchar(128) NOT NULL DEFAULT '',
  `error_message` varchar(255) DEFAULT NULL,
  `error_date` datetime DEFAULT NULL,
  PRIMARY KEY (`customers_errors_id`),
  KEY `customers_id` (`customers_id`,`basket_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers_errors`
--

LOCK TABLES `customers_errors` WRITE;
/*!40000 ALTER TABLE `customers_errors` DISABLE KEYS */;
/*!40000 ALTER TABLE `customers_errors` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers_external_ids`
--

DROP TABLE IF EXISTS `customers_external_ids`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers_external_ids` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `system_name` varchar(127) NOT NULL DEFAULT '',
  `external_id` varchar(256) NOT NULL DEFAULT '',
  `date_added` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unq_cid_system` (`customers_id`,`system_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers_external_ids`
--

LOCK TABLES `customers_external_ids` WRITE;
/*!40000 ALTER TABLE `customers_external_ids` DISABLE KEYS */;
/*!40000 ALTER TABLE `customers_external_ids` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers_info`
--

DROP TABLE IF EXISTS `customers_info`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers_info` (
  `customers_info_id` int(11) NOT NULL DEFAULT '0',
  `customers_info_date_of_last_logon` datetime DEFAULT NULL,
  `customers_info_number_of_logons` int(5) DEFAULT NULL,
  `customers_info_date_account_created` datetime DEFAULT NULL,
  `customers_info_date_account_last_modified` datetime DEFAULT NULL,
  `global_product_notifications` int(1) DEFAULT '0',
  `time_long` datetime DEFAULT NULL,
  `token` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`customers_info_id`),
  KEY `customers_info_date_account_created` (`customers_info_date_account_created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers_info`
--

LOCK TABLES `customers_info` WRITE;
/*!40000 ALTER TABLE `customers_info` DISABLE KEYS */;
INSERT INTO `customers_info` VALUES (1,NULL,NULL,'2016-05-31 12:10:54',NULL,1,NULL,''),(2,NULL,NULL,'2016-05-31 14:44:09',NULL,1,NULL,''),(3,NULL,NULL,'2016-05-31 14:48:04',NULL,1,NULL,''),(4,NULL,NULL,'2016-05-31 14:51:31',NULL,1,NULL,''),(5,NULL,NULL,'2016-05-31 14:53:48',NULL,1,NULL,''),(6,NULL,NULL,'2016-05-31 14:56:09',NULL,1,NULL,''),(7,NULL,NULL,'2016-05-31 14:59:13',NULL,1,NULL,''),(8,NULL,NULL,'2016-05-31 15:27:32',NULL,1,NULL,''),(9,NULL,NULL,'2016-05-31 15:29:09',NULL,1,NULL,''),(10,NULL,NULL,'2016-05-31 15:31:20',NULL,1,NULL,''),(11,NULL,NULL,'2016-05-31 15:33:52',NULL,1,NULL,''),(12,NULL,NULL,'2016-05-31 15:59:37',NULL,1,NULL,''),(13,NULL,NULL,'2016-05-31 16:03:49',NULL,1,NULL,''),(14,NULL,NULL,'2016-05-31 16:15:39',NULL,1,NULL,''),(15,NULL,NULL,'2016-05-31 16:19:30',NULL,1,NULL,''),(16,NULL,NULL,'2016-05-31 16:22:49',NULL,1,NULL,''),(17,NULL,NULL,'2016-05-31 16:25:03',NULL,1,NULL,''),(18,NULL,NULL,'2016-05-31 16:36:48',NULL,1,NULL,''),(19,NULL,NULL,'2016-06-01 10:58:24',NULL,1,NULL,''),(20,NULL,NULL,'2016-06-01 11:05:17',NULL,1,NULL,''),(21,NULL,NULL,'2016-06-01 11:08:19',NULL,1,NULL,''),(22,NULL,NULL,'2016-06-01 14:12:12',NULL,1,NULL,''),(23,NULL,NULL,'2016-06-01 14:17:32',NULL,1,NULL,''),(24,NULL,NULL,'2016-06-01 14:21:18',NULL,1,NULL,''),(25,NULL,NULL,'2016-06-01 15:02:53',NULL,1,NULL,''),(26,NULL,NULL,'2016-06-01 15:06:01',NULL,1,NULL,''),(27,NULL,NULL,'2016-06-01 15:09:39',NULL,1,NULL,''),(28,NULL,NULL,'2016-06-01 15:22:16',NULL,1,NULL,''),(29,NULL,NULL,'2016-06-01 15:26:44',NULL,1,NULL,''),(30,NULL,NULL,'2016-06-01 15:34:12',NULL,1,NULL,''),(31,NULL,NULL,'2016-06-01 15:41:26',NULL,1,NULL,''),(32,NULL,NULL,'2016-06-01 15:45:10',NULL,1,NULL,''),(33,NULL,NULL,'2016-06-01 15:56:26',NULL,1,NULL,''),(34,NULL,NULL,'2016-06-01 16:01:36',NULL,1,NULL,''),(35,NULL,NULL,'2016-06-01 16:39:43',NULL,1,NULL,''),(36,NULL,NULL,'2016-06-01 16:43:13',NULL,1,NULL,''),(37,NULL,NULL,'2016-06-01 16:46:42',NULL,1,NULL,''),(38,NULL,NULL,'2016-06-01 16:56:46',NULL,1,NULL,''),(39,NULL,NULL,'2016-06-01 17:08:51',NULL,1,NULL,''),(40,NULL,NULL,'2016-06-02 14:42:30',NULL,1,NULL,''),(41,NULL,NULL,'2016-06-02 14:44:17',NULL,1,NULL,''),(42,NULL,NULL,'2016-06-02 14:46:20',NULL,1,NULL,''),(43,NULL,NULL,'2016-06-02 16:29:45',NULL,1,NULL,''),(44,NULL,NULL,'2016-06-02 16:31:49',NULL,1,NULL,''),(45,NULL,NULL,'2016-06-02 16:34:15',NULL,1,NULL,''),(46,NULL,NULL,'2020-02-21 10:34:45',NULL,1,NULL,''),(47,NULL,NULL,'2020-02-21 10:41:53',NULL,1,NULL,''),(48,NULL,NULL,'2020-02-21 12:05:23',NULL,1,NULL,'');
/*!40000 ALTER TABLE `customers_info` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers_loyalty_history`
--

DROP TABLE IF EXISTS `customers_loyalty_history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers_loyalty_history` (
  `loyalty_history_id` int(11) NOT NULL AUTO_INCREMENT,
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `loyalty_state` enum('new','merged','count','dispatched','dispatch') NOT NULL DEFAULT 'new',
  `loyalty_parent_history_id` int(11) NOT NULL DEFAULT '0',
  `loyalty_points` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `loyalty_point_rate` decimal(14,6) NOT NULL DEFAULT '0.000000',
  `dispatch_history_id` int(11) NOT NULL DEFAULT '0',
  `coupon_id` int(11) NOT NULL DEFAULT '0',
  `public_comment` text NOT NULL,
  `internal_comment` text NOT NULL,
  `date_added` datetime DEFAULT NULL,
  PRIMARY KEY (`loyalty_history_id`),
  KEY `customers_id` (`customers_id`,`loyalty_state`),
  KEY `loyalty_state` (`loyalty_state`,`orders_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers_loyalty_history`
--

LOCK TABLES `customers_loyalty_history` WRITE;
/*!40000 ALTER TABLE `customers_loyalty_history` DISABLE KEYS */;
/*!40000 ALTER TABLE `customers_loyalty_history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers_phones`
--

DROP TABLE IF EXISTS `customers_phones`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers_phones` (
  `customers_id` int(11) NOT NULL,
  `customers_phone` varchar(150) NOT NULL,
  PRIMARY KEY (`customers_id`,`customers_phone`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers_phones`
--

LOCK TABLES `customers_phones` WRITE;
/*!40000 ALTER TABLE `customers_phones` DISABLE KEYS */;
/*!40000 ALTER TABLE `customers_phones` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers_temporary_guest`
--

DROP TABLE IF EXISTS `customers_temporary_guest`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers_temporary_guest` (
  `customers_id` int(11) NOT NULL AUTO_INCREMENT,
  `expiration` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`customers_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers_temporary_guest`
--

LOCK TABLES `customers_temporary_guest` WRITE;
/*!40000 ALTER TABLE `customers_temporary_guest` DISABLE KEYS */;
/*!40000 ALTER TABLE `customers_temporary_guest` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `customers_to_lists`
--

DROP TABLE IF EXISTS `customers_to_lists`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `customers_to_lists` (
  `subscribers_lists_id` int(11) NOT NULL DEFAULT '0',
  `customers_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`subscribers_lists_id`,`customers_id`),
  KEY `idx_customers_id` (`customers_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `customers_to_lists`
--

LOCK TABLES `customers_to_lists` WRITE;
/*!40000 ALTER TABLE `customers_to_lists` DISABLE KEYS */;
/*!40000 ALTER TABLE `customers_to_lists` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `data_storage`
--

DROP TABLE IF EXISTS `data_storage`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `data_storage` (
  `pointer` varchar(255) NOT NULL,
  `data` text,
  `date_modified` datetime DEFAULT NULL,
  PRIMARY KEY (`pointer`),
  KEY `idx_pointer` (`pointer`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `data_storage`
--

LOCK TABLES `data_storage` WRITE;
/*!40000 ALTER TABLE `data_storage` DISABLE KEYS */;
/*!40000 ALTER TABLE `data_storage` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `departments`
--

DROP TABLE IF EXISTS `departments`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `departments` (
  `departments_id` int(11) NOT NULL AUTO_INCREMENT,
  `departments_http_server` varchar(128) NOT NULL DEFAULT '',
  `departments_https_server` varchar(128) NOT NULL DEFAULT '',
  `departments_enable_ssl` tinyint(1) NOT NULL DEFAULT '0',
  `departments_http_catalog` varchar(128) DEFAULT '/',
  `departments_https_catalog` varchar(128) DEFAULT '/',
  `departments_design_template_name` varchar(128) NOT NULL DEFAULT '',
  `departments_template_monster_template_id` varchar(64) NOT NULL DEFAULT '',
  `departments_custom_design_requirements` text,
  `departments_custom_design_artwork` tinyint(1) NOT NULL DEFAULT '0',
  `departments_store_name` varchar(128) NOT NULL DEFAULT '',
  `departments_firstname` varchar(32) NOT NULL DEFAULT '',
  `departments_lastname` varchar(32) NOT NULL DEFAULT '',
  `departments_email_address` varchar(96) NOT NULL DEFAULT '',
  `departments_country_id` int(11) NOT NULL DEFAULT '0',
  `departments_address` varchar(255) NOT NULL DEFAULT '',
  `departments_street_address` varchar(64) NOT NULL DEFAULT '',
  `departments_suburb` varchar(32) NOT NULL DEFAULT '',
  `departments_postcode` varchar(10) NOT NULL DEFAULT '',
  `departments_city` varchar(32) NOT NULL DEFAULT '',
  `departments_state` varchar(32) NOT NULL DEFAULT '',
  `departments_zone_id` int(11) NOT NULL DEFAULT '0',
  `departments_telephone` varchar(32) NOT NULL DEFAULT '',
  `departments_password` varchar(40) NOT NULL DEFAULT '',
  `departments_password_plain` varchar(64) NOT NULL DEFAULT '',
  `departments_monthly_price` decimal(12,2) NOT NULL DEFAULT '0.00',
  `departments_setup_price` decimal(12,2) NOT NULL DEFAULT '0.00',
  `departments_commission_percentage` decimal(12,2) NOT NULL DEFAULT '0.00',
  `packages_id` int(11) NOT NULL DEFAULT '0',
  `departments_already_registered_domain` tinyint(1) NOT NULL DEFAULT '0',
  `departments_registered_uk_vat` tinyint(1) NOT NULL DEFAULT '0',
  `departments_status` tinyint(1) NOT NULL DEFAULT '0',
  `departments_modified` datetime DEFAULT NULL,
  `departments_created` datetime DEFAULT NULL,
  `departments_ftp_host` varchar(64) NOT NULL DEFAULT '',
  `departments_ftp_path` varchar(128) NOT NULL DEFAULT '',
  `departments_ftp_username` varchar(64) NOT NULL DEFAULT '',
  `departments_ftp_password` varchar(64) NOT NULL DEFAULT '',
  `departments_ftp_pasv` tinyint(1) NOT NULL DEFAULT '1',
  `departments_ftp_port` varchar(16) NOT NULL DEFAULT '',
  `departments_ftp_type` enum('ftp','sftp') NOT NULL DEFAULT 'ftp',
  `departments_paypal_subscription_code` text,
  `departments_paypal_subscription_show` tinyint(1) NOT NULL DEFAULT '0',
  `departments_db_server_host` varchar(255) NOT NULL DEFAULT '',
  `departments_db_server_username` varchar(255) NOT NULL DEFAULT '',
  `departments_db_server_password` varchar(255) NOT NULL DEFAULT '',
  `departments_db_database` varchar(255) NOT NULL DEFAULT '',
  `departments_db_use_pconnect` varchar(255) NOT NULL DEFAULT 'false',
  `departments_db_store_sessions` varchar(255) NOT NULL DEFAULT '',
  `departments_default_language` varchar(255) DEFAULT NULL,
  `departments_default_currency` varchar(255) DEFAULT NULL,
  `api_key` varchar(48) NOT NULL DEFAULT '',
  `project_code` text,
  `api_categories_allow_create` tinyint(1) NOT NULL DEFAULT '1',
  `api_categories_allow_update` tinyint(1) NOT NULL DEFAULT '1',
  `locked` tinyint(1) NOT NULL DEFAULT '1',
  `departments_sort_order` int(11) NOT NULL DEFAULT '0',
  `api_products_allow_create` tinyint(1) NOT NULL DEFAULT '1',
  `api_products_allow_update` tinyint(1) NOT NULL DEFAULT '1',
  `api_outgoing_price_formula` varchar(1024) NOT NULL DEFAULT '',
  `api_outgoing_price_discount` decimal(8,2) NOT NULL DEFAULT '0.00',
  `api_outgoing_price_surcharge` decimal(8,2) NOT NULL DEFAULT '0.00',
  `api_outgoing_price_margin` decimal(8,2) NOT NULL DEFAULT '0.00',
  `alias` text NOT NULL,
  `keep_alive` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`departments_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `departments`
--

LOCK TABLES `departments` WRITE;
/*!40000 ALTER TABLE `departments` DISABLE KEYS */;
/*!40000 ALTER TABLE `departments` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `departments_categories`
--

DROP TABLE IF EXISTS `departments_categories`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `departments_categories` (
  `departments_id` int(11) NOT NULL,
  `categories_id` int(11) NOT NULL,
  PRIMARY KEY (`categories_id`,`departments_id`),
  KEY `departments_id` (`departments_id`,`categories_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `departments_categories`
--

LOCK TABLES `departments_categories` WRITE;
/*!40000 ALTER TABLE `departments_categories` DISABLE KEYS */;
/*!40000 ALTER TABLE `departments_categories` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `departments_categories_price_formula`
--

DROP TABLE IF EXISTS `departments_categories_price_formula`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `departments_categories_price_formula` (
  `departments_id` int(11) NOT NULL DEFAULT '0',
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `formula` varchar(1024) NOT NULL DEFAULT '',
  `discount` decimal(8,2) NOT NULL DEFAULT '0.00',
  `surcharge` decimal(8,2) NOT NULL DEFAULT '0.00',
  `margin` decimal(8,2) NOT NULL DEFAULT '0.00',
  UNIQUE KEY `departments_id` (`departments_id`,`categories_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `departments_categories_price_formula`
--

LOCK TABLES `departments_categories_price_formula` WRITE;
/*!40000 ALTER TABLE `departments_categories_price_formula` DISABLE KEYS */;
/*!40000 ALTER TABLE `departments_categories_price_formula` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `departments_external_platforms`
--

DROP TABLE IF EXISTS `departments_external_platforms`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `departments_external_platforms` (
  `departments_id` int(11) NOT NULL,
  `platform_id` int(11) NOT NULL,
  `platform_name` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`departments_id`,`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `departments_external_platforms`
--

LOCK TABLES `departments_external_platforms` WRITE;
/*!40000 ALTER TABLE `departments_external_platforms` DISABLE KEYS */;
/*!40000 ALTER TABLE `departments_external_platforms` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `departments_products`
--

DROP TABLE IF EXISTS `departments_products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `departments_products` (
  `departments_id` int(11) NOT NULL,
  `products_id` int(11) NOT NULL,
  PRIMARY KEY (`products_id`,`departments_id`),
  KEY `departments_id` (`departments_id`,`products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `departments_products`
--

LOCK TABLES `departments_products` WRITE;
/*!40000 ALTER TABLE `departments_products` DISABLE KEYS */;
/*!40000 ALTER TABLE `departments_products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `design_backups`
--

DROP TABLE IF EXISTS `design_backups`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `design_backups` (
  `backup_id` int(11) NOT NULL AUTO_INCREMENT,
  `date_added` datetime DEFAULT NULL,
  `theme_name` varchar(128) CHARACTER SET latin1 COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `comments` text,
  PRIMARY KEY (`backup_id`),
  KEY `id` (`backup_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `design_backups`
--

LOCK TABLES `design_backups` WRITE;
/*!40000 ALTER TABLE `design_backups` DISABLE KEYS */;
/*!40000 ALTER TABLE `design_backups` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `design_boxes`
--

DROP TABLE IF EXISTS `design_boxes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `design_boxes` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `microtime` varchar(32) NOT NULL,
  `theme_name` varchar(128) CHARACTER SET latin1 COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `block_name` varchar(128) CHARACTER SET latin1 COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `widget_name` text,
  `widget_params` text,
  `sort_order` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `design_boxes_microtime` (`microtime`),
  KEY `idx_theme_name_block_name` (`theme_name`,`block_name`)
) ENGINE=InnoDB AUTO_INCREMENT=194598 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `design_boxes`
--

LOCK TABLES `design_boxes` WRITE;
/*!40000 ALTER TABLE `design_boxes` DISABLE KEYS */;
INSERT INTO `design_boxes` VALUES (2926,'94814','watch-mobile','404','Html_box','',1),(3023,'94911','watch-mobile','account','BlockBox','',1),(3024,'94912','watch-mobile','block-3023','BlockBox','',1),(3025,'94913','watch-mobile','block-3024','WidgetsAria','',1),(3026,'94914','watch-mobile','block-3024-2','Html_box','',3),(3027,'94915','watch-mobile','block-3024-2','account\\OrdersHistory','',4),(3028,'94916','watch-mobile','block-3024-2','Html_box','',1),(3029,'94917','watch-mobile','block-3024-2','BlockBox','',2),(3030,'94918','watch-mobile','block-3029','Html_box','',1),(3031,'94919','watch-mobile','block-3029','account\\LastOrder','',2),(3032,'94920','watch-mobile','block-3029-2','Html_box','',1),(3033,'94921','watch-mobile','block-3029-2','account\\AccountLink','',3),(3034,'94922','watch-mobile','block-3029-2','account\\OrderCount','',2),(3035,'94923','watch-mobile','block-3029-3','Html_box','',1),(3036,'94924','watch-mobile','block-3029-3','account\\TotalOrdered','',2),(3037,'94925','watch-mobile','block-3029-4','Html_box','',1),(3038,'94926','watch-mobile','block-3029-4','account\\AccountLink','',3),(3039,'94927','watch-mobile','block-3029-4','account\\CreditAmount','',2),(3040,'94928','watch-mobile','block-3029-5','account\\AccountLink','',3),(3041,'94929','watch-mobile','block-3029-5','account\\PointsEarnt','',2),(3042,'94930','watch-mobile','block-3029-5','Html_box','',1),(3043,'94931','watch-mobile','block-3024-2','BlockBox','',5),(3044,'94932','watch-mobile','block-3043','account\\GiftCards','',6),(3045,'94933','watch-mobile','block-3043','Html_box','',1),(3046,'94934','watch-mobile','block-3024-2','Html_box','',5),(3047,'94935','watch-mobile','account-menu','BlockBox','',1),(3048,'94936','watch-mobile','block-3047','BlockBox','account-side',1),(3049,'94937','watch-mobile','block-3048','Html_box','',16),(3050,'94938','watch-mobile','block-3048','account\\AccountLink','',18),(3051,'94939','watch-mobile','block-3048','account\\AccountLink','',1),(3052,'94940','watch-mobile','block-3048','Html_box','',2),(3053,'94941','watch-mobile','block-3048','account\\AccountLink','',17),(3054,'94942','watch-mobile','block-3048','account\\AccountLink','',4),(3055,'94943','watch-mobile','block-3048','account\\AccountLink','',11),(3056,'94944','watch-mobile','block-3048','Html_box','',6),(3057,'94945','watch-mobile','block-3048','account\\AccountLink','',8),(3058,'94946','watch-mobile','block-3048','account\\AccountLink','',7),(3059,'94947','watch-mobile','block-3048','account\\AccountLink','',14),(3060,'94948','watch-mobile','block-3048','account\\AccountLink','',5),(3061,'94949','watch-mobile','block-3048','account\\AccountLink','',12),(3062,'94950','watch-mobile','block-3048','account\\AccountLink','',9),(3063,'94951','watch-mobile','block-3048','Html_box','',10),(3064,'94952','watch-mobile','block-3048','account\\AccountLink','',15),(3065,'94953','watch-mobile','account_edit','BlockBox','',1),(3066,'94954','watch-mobile','block-3065','BlockBox','',1),(3067,'94955','watch-mobile','block-3066','WidgetsAria','',1),(3068,'94956','watch-mobile','block-3066-2','account\\AccountEdit','',2),(3069,'94957','watch-mobile','block-3066-2','Html_box','',1),(3070,'94958','watch-mobile','block-3066-2','account\\AccountLink','',3),(3071,'94959','watch-mobile','address_book','BlockBox','',1),(3072,'94960','watch-mobile','block-3071','BlockBox','',1),(3073,'94961','watch-mobile','block-3072','WidgetsAria','',1),(3074,'94962','watch-mobile','block-3072-2','account\\AddressBook','',3),(3075,'94963','watch-mobile','block-3072-2','Html_box','',1),(3076,'94964','watch-mobile','address_book_process','BlockBox','',1),(3077,'94965','watch-mobile','block-3076','BlockBox','',1),(3078,'94966','watch-mobile','block-3077','WidgetsAria','',1),(3079,'94967','watch-mobile','block-3077-2','account\\EditAddress','',2),(3080,'94968','watch-mobile','block-3077-2','Html_box','',1),(3081,'94969','watch-mobile','block-3077-2','account\\AccountLink','',3),(3082,'94970','watch-mobile','b2b','BlockBox','listing-item',1),(3083,'94971','watch-mobile','block-3082','BlockBox','',1),(3084,'94972','watch-mobile','block-3083','productListing\\image','',1),(3085,'94973','watch-mobile','block-3083-2','productListing\\model','',5),(3086,'94974','watch-mobile','block-3083-2','productListing\\attributes','',3),(3087,'94975','watch-mobile','block-3083-2','BlockBox','',4),(3088,'94976','watch-mobile','block-3087','BlockBox','',1),(3089,'94977','watch-mobile','block-3088','productListing\\price','',1),(3090,'94978','watch-mobile','block-3088-2','productListing\\bonusPoints','',1),(3091,'94979','watch-mobile','block-3087-2','productListing\\qtyInput','',1),(3092,'94980','watch-mobile','block-3083-2','productListing\\description','',6),(3093,'94981','watch-mobile','block-3083-2','BlockBox','',2),(3094,'94982','watch-mobile','block-3093','productListing\\stock','',1),(3095,'94983','watch-mobile','block-3093-2','productListing\\rating','',1),(3096,'94984','watch-mobile','block-3083-2','productListing\\name','',1),(3097,'94985','watch-mobile','batch','BlockBox','',1),(3098,'94986','watch-mobile','block-3097','productListing\\attributes','',5),(3099,'94987','watch-mobile','block-3097','productListing\\price','',6),(3100,'94988','watch-mobile','block-3097','productListing\\name','',4),(3101,'94989','watch-mobile','block-3097','productListing\\image','',2),(3102,'94990','watch-mobile','block-3097','batchSelect','',1),(3103,'94991','watch-mobile','batch_selected','BlockBox','',1),(3104,'94992','watch-mobile','block-3103','BlockBox','',13),(3105,'94993','watch-mobile','block-3104','productListing\\image','',1),(3106,'94994','watch-mobile','block-3104-2','batchRemove','',1),(3107,'94995','watch-mobile','block-3104-2','productListing\\price','',3),(3108,'94996','watch-mobile','block-3104-2','productListing\\name','',2),(3109,'94997','watch-mobile','bbbbb','BlockBox','',1),(3110,'94998','watch-mobile','block-3109','BlockBox','',2),(3111,'94999','watch-mobile','block-3110','Filters','',1),(3112,'95000','watch-mobile','block-3110-2','BlockBox','',6),(3113,'95001','watch-mobile','block-3112','catalog\\CountsItems','',1),(3114,'95002','watch-mobile','block-3112-2','catalog\\Paging','',1),(3115,'95003','watch-mobile','block-3110-2','catalog\\Image','',1),(3116,'95004','watch-mobile','block-3110-2','Listing','',5),(3117,'95005','watch-mobile','block-3110-2','catalog\\ImageMapCategory','',3),(3118,'95006','watch-mobile','block-3110-2','BlockBox','',4),(3119,'95007','watch-mobile','block-3118','catalog\\ListingLook','',1),(3120,'95008','watch-mobile','block-3118','catalog\\CompareButton','',2),(3121,'95009','watch-mobile','block-3118','catalog\\ItemsOnPage','',4),(3122,'95010','watch-mobile','block-3118','catalog\\Sorting','',3),(3123,'95011','watch-mobile','block-3110-2','Categories','',2),(3124,'95012','watch-mobile','block-3109','catalog\\Title','',1),(3125,'75559','watch-mobile','blog','BlockBox','',1),(3126,'75560','watch-mobile','block-3125','BlockBox','',1),(3127,'75561','watch-mobile','block-3126','BlogContent','',1),(3128,'75562','watch-mobile','block-3126-2','BlogSidebar','',1),(3129,'113643','watch-mobile','blogsidebar','BlockBox','',1),(3130,'113644','watch-mobile','block-3129','Blog\\widget\\RecentPosts','',4),(3131,'113645','watch-mobile','block-3129','Blog\\widget\\TagCloud','',2),(3132,'113646','watch-mobile','block-3129','Blog\\widget\\CategoriesList','',1),(3133,'113647','watch-mobile','block-3129','Blog\\widget\\MostPopularPosts','',3),(3134,'115968','watch-mobile','cart','BlockBox','',2),(3135,'115969','watch-mobile','block-3134','BlockBox','',4),(3136,'115970','watch-mobile','block-3135','Html_box','',1),(3137,'115971','watch-mobile','block-3135','cart\\UpSell','6',2),(3138,'115972','watch-mobile','block-3134','BlockBox','',1),(3139,'115973','watch-mobile','block-3138','cart\\Products','',3),(3140,'115974','watch-mobile','block-3138','BlockBox','',2),(3141,'115976','watch-mobile','block-3140','MultiCart\\SaveCart','',2),(3142,'115977','watch-mobile','block-3140-2','MultiCart\\Actions','',1),(3143,'115975','watch-mobile','block-3138','MultiCart\\CartSwitcher','',1),(3144,'115978','watch-mobile','block-3134','BlockBox','',3),(3145,'115979','watch-mobile','block-3144','cart\\GiveAway','',2),(3146,'115980','watch-mobile','block-3144','Html_box','',1),(3147,'115981','watch-mobile','block-3134','BlockBox','',2),(3148,'115982','watch-mobile','block-3147','Html_box','',1),(3149,'115983','watch-mobile','block-3147','BlockBox','',2),(3150,'115984','watch-mobile','block-3149','cart\\DiscountCoupon','',1),(3151,'115985','watch-mobile','block-3149','cart\\CreditAmount','',2),(3152,'115986','watch-mobile','block-3149','cart\\BonusPoints','',3),(3153,'115987','watch-mobile','block-3134','BlockBox','',5),(3154,'115988','watch-mobile','block-3153','Html_box','',1),(3155,'115989','watch-mobile','block-3153','cart\\ShippingEstimator','',2),(3156,'115990','watch-mobile','block-3134','BlockBox','',7),(3157,'115991','watch-mobile','block-3156','BlockBox','',2),(3158,'115992','watch-mobile','block-3157','Image','',4),(3159,'115993','watch-mobile','block-3157','cart\\CheckoutBtn','',2),(3160,'115994','watch-mobile','block-3157','cart\\OrderTotal','',1),(3161,'115995','watch-mobile','block-3134','Html_box','',6),(3162,'113648','watch-mobile','cart2','BlockBox','',2),(3163,'113649','watch-mobile','block-3162','cart\\CartTabs','',2),(3164,'113650','watch-mobile','block-3163','BlockBox','',1),(3165,'113651','watch-mobile','block-3164','BlockBox','',4),(3166,'113652','watch-mobile','block-3165','cart\\UpSell','6',2),(3167,'113653','watch-mobile','block-3165','Html_box','',1),(3168,'113654','watch-mobile','block-3164','BlockBox','',1),(3169,'113655','watch-mobile','block-3168','cart\\Products','',3),(3170,'113656','watch-mobile','block-3168','BlockBox','',2),(3171,'113657','watch-mobile','block-3170','MultiCart\\CartSwitcher','',1),(3172,'113658','watch-mobile','block-3170','MultiCart\\SaveCart','',2),(3173,'113659','watch-mobile','block-3170-2','MultiCart\\Actions','',1),(3174,'113660','watch-mobile','block-3164','BlockBox','',3),(3175,'113661','watch-mobile','block-3174','cart\\GiveAway','',2),(3176,'113662','watch-mobile','block-3174','Html_box','',1),(3177,'113663','watch-mobile','block-3164','BlockBox','',2),(3178,'113664','watch-mobile','block-3177','Html_box','',1),(3179,'113665','watch-mobile','block-3177','BlockBox','',2),(3180,'113666','watch-mobile','block-3179','cart\\DiscountCoupon','',1),(3181,'113667','watch-mobile','block-3179-2','cart\\CreditAmount','',1),(3182,'113668','watch-mobile','block-3179-3','cart\\BonusPoints','',1),(3183,'113669','watch-mobile','block-3164','BlockBox','',5),(3184,'113670','watch-mobile','block-3183','Html_box','',1),(3185,'113671','watch-mobile','block-3183','cart\\ShippingEstimator','',2),(3186,'113672','watch-mobile','block-3164-2','BlockBox','',1),(3187,'113673','watch-mobile','block-3186','Html_box','',1),(3188,'113674','watch-mobile','block-3186','BlockBox','',2),(3189,'113675','watch-mobile','block-3188','Image','',4),(3190,'113676','watch-mobile','block-3188','cart\\CheckoutBtn','',2),(3191,'113677','watch-mobile','block-3188','cart\\OrderTotal','',1),(3192,'75585','watch-mobile','categories','BlockBox','catalog-features',1),(3193,'75586','watch-mobile','block-3192','catalog\\Title','',1),(3194,'75587','watch-mobile','block-3192','Categories','',2),(3195,'75588','watch-mobile','categories','BlockBox','catalog-content',2),(3196,'75589','watch-mobile','block-3195','Listing','',3),(3197,'75590','watch-mobile','block-3195','BlockBox','',1),(3198,'75591','watch-mobile','block-3197','catalog\\Sorting','',1),(3199,'75592','watch-mobile','block-3197-2','catalog\\CountsItems','',1),(3200,'75593','watch-mobile','block-3195','catalog\\Paging','',2),(3201,'75594','watch-mobile','category','ListingFunctionality','',2),(3202,'75595','watch-mobile','category','Categories','',1),(3203,'75596','watch-mobile','category','PagingBar','',5),(3204,'75597','watch-mobile','category','PagingBar','',3),(3205,'75598','watch-mobile','category','Listing','',4),(3206,'113678','watch-mobile','category_2','BlockBox','',1),(3207,'113679','watch-mobile','block-3206','catalog\\Title','',1),(3208,'113680','watch-mobile','block-3206','BlockBox','',2),(3209,'113681','watch-mobile','block-3208','Filters','',1),(3210,'113682','watch-mobile','block-3208-2','catalog\\Image','',1),(3211,'113683','watch-mobile','block-3208-2','Listing','',5),(3212,'113684','watch-mobile','block-3208-2','BlockBox','',4),(3213,'113685','watch-mobile','block-3212','catalog\\Sorting','',3),(3214,'113686','watch-mobile','block-3212','catalog\\ItemsOnPage','',4),(3215,'113687','watch-mobile','block-3212','catalog\\CompareButton','',2),(3216,'113688','watch-mobile','block-3212','catalog\\ListingLook','',1),(3217,'113689','watch-mobile','block-3208-2','catalog\\ImageMapCategory','',3),(3218,'113690','watch-mobile','block-3208-2','Categories','',2),(3219,'113691','watch-mobile','block-3208-2','BlockBox','',6),(3220,'113692','watch-mobile','block-3219','catalog\\CountsItems','',1),(3221,'113693','watch-mobile','block-3219-2','catalog\\Paging','',1),(3222,'113694','watch-mobile','category_no_filters','BlockBox','',1),(3223,'113695','watch-mobile','block-3222','catalog\\B2bAddButton','',7),(3224,'113696','watch-mobile','block-3222','BlockBox','',6),(3225,'113697','watch-mobile','block-3224','catalog\\CountsItems','',1),(3226,'113698','watch-mobile','block-3224-2','catalog\\Paging','',1),(3227,'113699','watch-mobile','block-3222','Listing','',5),(3228,'113700','watch-mobile','block-3222','catalog\\Image','',2),(3229,'113701','watch-mobile','block-3222','BlockBox','',4),(3230,'113702','watch-mobile','block-3229','catalog\\ListingLook','',1),(3231,'113703','watch-mobile','block-3229','catalog\\CompareButton','',2),(3232,'113704','watch-mobile','block-3229','HeaderStock','',5),(3233,'113705','watch-mobile','block-3229','catalog\\ItemsOnPage','',4),(3234,'113706','watch-mobile','block-3229','catalog\\Sorting','',3),(3235,'113707','watch-mobile','block-3222','Categories','',3),(3236,'113708','watch-mobile','block-3222','catalog\\Title','',1),(3281,'113753','watch-mobile','checkout_confirmation','BlockBox','',1),(3282,'113754','watch-mobile','block-3281','checkout\\ConfirmBtn','',4),(3283,'113755','watch-mobile','block-3281','cart\\Products','',7),(3284,'113756','watch-mobile','block-3281','BlockBox','',2),(3285,'113757','watch-mobile','block-3284','BlockBox','',1),(3286,'113758','watch-mobile','block-3285','Html_box','',1),(3287,'113759','watch-mobile','block-3285','checkout\\ShippingAddressConfirm','',3),(3288,'113760','watch-mobile','block-3284','BlockBox','',2),(3289,'113761','watch-mobile','block-3288','Html_box','',1),(3290,'113762','watch-mobile','block-3288','checkout\\BillingAddressConfirm','',3),(3291,'113763','watch-mobile','block-3281','checkout\\ConfirmBtn','',9),(3292,'113764','watch-mobile','block-3281','BlockBox','',3),(3293,'113765','watch-mobile','block-3292','BlockBox','',1),(3294,'113766','watch-mobile','block-3293','Html_box','',1),(3295,'113767','watch-mobile','block-3293','checkout\\ShippingConfirm','',3),(3296,'113768','watch-mobile','block-3292','BlockBox','',2),(3297,'113769','watch-mobile','block-3296','checkout\\PaymentMethodConfirm','',3),(3298,'113770','watch-mobile','block-3296','Html_box','',1),(3299,'113771','watch-mobile','block-3281','checkout\\EditBtn','',6),(3300,'113772','watch-mobile','block-3281','checkout\\Totals','',8),(3301,'113773','watch-mobile','block-3281','Html_box','',5),(3302,'113774','watch-mobile','checkout_confirmation_no_shipping_q','BlockBox','',1),(3303,'113775','watch-mobile','block-3302','checkout\\Totals','',5),(3304,'113776','watch-mobile','block-3302','checkout\\ConfirmBtn','',6),(3305,'113777','watch-mobile','block-3302','BlockBox','',1),(3306,'113778','watch-mobile','block-3305','BlockBox','',1),(3307,'113779','watch-mobile','block-3306','Html_box','',1),(3308,'113780','watch-mobile','block-3306','checkout\\BillingAddressConfirm','',3),(3309,'113781','watch-mobile','block-3305-2','BlockBox','',1),(3310,'113782','watch-mobile','block-3309','Html_box','',1),(3311,'113783','watch-mobile','block-3309','checkout\\PaymentMethodConfirm','',3),(3312,'113784','watch-mobile','block-3302','Html_box','',3),(3313,'113785','watch-mobile','block-3302','quote\\Products','',4),(3314,'113786','watch-mobile','block-3302','checkout\\ConfirmBtn','',2),(3315,'113787','watch-mobile','checkout_confirmation_no_shipping','BlockBox','',1),(3316,'113788','watch-mobile','block-3315','Html_box','',5),(3317,'113789','watch-mobile','block-3315','checkout\\ConfirmBtn','',4),(3318,'113790','watch-mobile','block-3315','cart\\Products','',7),(3319,'113791','watch-mobile','block-3315','checkout\\Totals','',8),(3320,'113792','watch-mobile','block-3315','checkout\\ConfirmBtn','',9),(3321,'113793','watch-mobile','block-3315','BlockBox','',2),(3322,'113794','watch-mobile','block-3321','BlockBox','',1),(3323,'113795','watch-mobile','block-3322','checkout\\BillingAddressConfirm','',3),(3324,'113796','watch-mobile','block-3322','Html_box','',1),(3325,'113797','watch-mobile','block-3321-2','BlockBox','',1),(3326,'113798','watch-mobile','block-3325','Html_box','',1),(3327,'113799','watch-mobile','block-3325','checkout\\PaymentMethodConfirm','',3),(3328,'113800','watch-mobile','checkout_confirmation_q','BlockBox','',1),(3329,'113801','watch-mobile','block-3328','BlockBox','',2),(3330,'113802','watch-mobile','block-3329','BlockBox','',1),(3331,'113803','watch-mobile','block-3330','checkout\\ShippingConfirm','',3),(3332,'113804','watch-mobile','block-3330','Html_box','',1),(3333,'113805','watch-mobile','block-3329-2','BlockBox','',1),(3334,'113806','watch-mobile','block-3333','Html_box','',1),(3335,'113807','watch-mobile','block-3333','checkout\\PaymentMethodConfirm','',3),(3336,'113808','watch-mobile','block-3328','checkout\\ConfirmBtn','',8),(3337,'113809','watch-mobile','block-3328','checkout\\ConfirmBtn','',3),(3338,'113810','watch-mobile','block-3328','checkout\\EditBtn','',5),(3339,'113811','watch-mobile','block-3328','quote\\Products','',6),(3340,'113812','watch-mobile','block-3328','Html_box','',4),(3341,'113813','watch-mobile','block-3328','checkout\\Totals','',7),(3342,'113814','watch-mobile','block-3328','BlockBox','',1),(3343,'113815','watch-mobile','block-3342','BlockBox','',1),(3344,'113816','watch-mobile','block-3343','checkout\\ShippingAddressConfirm','',3),(3345,'113817','watch-mobile','block-3343','Html_box','',1),(3346,'113818','watch-mobile','block-3342-2','BlockBox','',1),(3347,'113819','watch-mobile','block-3346','Html_box','',1),(3348,'113820','watch-mobile','block-3346','checkout\\BillingAddressConfirm','',3),(3349,'113821','watch-mobile','checkout_confirmation_title','Html_box','',1),(3350,'113822','watch-mobile','checkout_confirmation_title_g','Html_box','',1),(3351,'113823','watch-mobile','checkout_confirmation_title_no_shipping_g','Html_box','',1),(3352,'113824','watch-mobile','checkout_confirmation_title_no_shipping','Html_box','',1),(3353,'113825','watch-mobile','checkout_confirmation_title_q','Html_box','',1),(3354,'113826','watch-mobile','checkout_confirmation_title_s','Html_box','',1),(3355,'113827','watch-mobile','checkout_delivery','BlockBox','',1),(3356,'113828','watch-mobile','block-3355','BlockBox','',1),(3359,'113831','watch-mobile','block-3355','BlockBox','',2),(3360,'113832','watch-mobile','block-3359','Neighbour\\Checkout','',4),(3361,'113833','watch-mobile','block-3359','Html_box','',1),(3362,'113834','watch-mobile','block-3359','checkout\\Shipping','',2),(3363,'113835','watch-mobile','block-3359','DelayedDespatch\\Checkout','',3),(3364,'113836','watch-mobile','checkout_delivery','BlockBox','',2),(3365,'113837','watch-mobile','block-3364','BlockBox','',1),(3366,'113838','watch-mobile','block-3365','Html_box','',1),(3367,'113839','watch-mobile','block-3365','checkout\\ContactInformation','',2),(3368,'113840','watch-mobile','block-3364','BlockBox','',2),(3369,'113841','watch-mobile','block-3368','Html_box','',1),(3370,'113842','watch-mobile','block-3368','checkout\\Comments','',2),(3371,'113843','watch-mobile','checkout_delivery','BlockBox','',3),(3372,'113844','watch-mobile','block-3371','Html_box','',1),(3373,'113845','watch-mobile','block-3371','checkout\\ContinueBtn','',2),(3374,'113846','watch-mobile','checkout_delivery_g','BlockBox','',1),(3375,'113847','watch-mobile','block-3374','BlockBox','',1),(3376,'113848','watch-mobile','block-3375','checkout\\ShippingAddress','',2),(3377,'113849','watch-mobile','block-3375','Html_box','',1),(3378,'113850','watch-mobile','block-3374-2','BlockBox','',1),(3379,'113851','watch-mobile','block-3378','Html_box','',1),(3380,'113852','watch-mobile','block-3378','Neighbour\\Checkout','',4),(3381,'113853','watch-mobile','block-3378','checkout\\Shipping','',2),(3382,'113854','watch-mobile','block-3378','DelayedDespatch\\Checkout','',3),(3383,'113855','watch-mobile','checkout_delivery_g','BlockBox','',3),(3384,'113856','watch-mobile','block-3383','Html_box','',1),(3385,'113857','watch-mobile','block-3383-2','checkout\\ContinueBtn','',1),(3386,'113858','watch-mobile','checkout_delivery_g','BlockBox','',2),(3387,'113859','watch-mobile','block-3386','BlockBox','',1),(3388,'113860','watch-mobile','block-3387','checkout\\ContactInformation','',2),(3389,'113861','watch-mobile','block-3387','Html_box','',1),(3390,'113862','watch-mobile','block-3386-2','BlockBox','',1),(3391,'113863','watch-mobile','block-3390','checkout\\Comments','',2),(3392,'113864','watch-mobile','block-3390','Html_box','',1),(3393,'113865','watch-mobile','checkout_delivery_no_shipping','BlockBox','',2),(3394,'113866','watch-mobile','block-3393','Html_box','',1),(3395,'113867','watch-mobile','block-3393-2','checkout\\ContinueBtn','',1),(3396,'113868','watch-mobile','checkout_delivery_no_shipping','BlockBox','',1),(3397,'113869','watch-mobile','block-3396','BlockBox','',1),(3398,'113870','watch-mobile','block-3397','checkout\\ContactInformation','',2),(3399,'113871','watch-mobile','block-3396-2','BlockBox','',1),(3400,'113872','watch-mobile','block-3399','checkout\\Comments','',2),(3401,'113873','watch-mobile','block-3399','Html_box','',1),(3402,'113874','watch-mobile','checkout_delivery_no_shipping_g','BlockBox','',1),(3403,'113875','watch-mobile','block-3402','BlockBox','',1),(3404,'113876','watch-mobile','block-3403','checkout\\ContactInformation','',2),(3405,'113877','watch-mobile','block-3402-2','BlockBox','',1),(3406,'113878','watch-mobile','block-3405','Html_box','',1),(3407,'113879','watch-mobile','block-3405','checkout\\Comments','',2),(3408,'113880','watch-mobile','checkout_delivery_no_shipping_g','BlockBox','',2),(3409,'113881','watch-mobile','block-3408','Html_box','',1),(3410,'113882','watch-mobile','block-3408-2','checkout\\ContinueBtn','',1),(3411,'113883','watch-mobile','checkout_delivery_title','Html_box','',1),(3412,'113884','watch-mobile','checkout_delivery_title_g','Html_box','',1),(3413,'113885','watch-mobile','checkout_delivery_title_no_shipping_g','Html_box','',1),(3414,'113886','watch-mobile','checkout_delivery_title_no_shipping','Html_box','',1),(3415,'113887','watch-mobile','checkout_delivery_title_q','Html_box','',1),(3416,'113888','watch-mobile','checkout_delivery_title_s','Html_box','',1),(3417,'113889','watch-mobile','checkout_free_s','BlockBox','',1),(3418,'113890','watch-mobile','block-3417','BlockBox','',2),(3419,'113891','watch-mobile','block-3418','BlockBox','',2),(3420,'113892','watch-mobile','block-3419','BlockBox','',2),(3421,'113893','watch-mobile','block-3420','Neighbour\\Checkout','',4),(3422,'113894','watch-mobile','block-3420','BlockBox','',3),(3423,'113895','watch-mobile','block-3422','BlockBox','',1),(3424,'113896','watch-mobile','block-3423','checkout\\ShippingAddress','',2),(3425,'113897','watch-mobile','block-3423','Html_box','',3),(3426,'113898','watch-mobile','block-3423','checkout\\ContactInformation','',4),(3427,'113899','watch-mobile','block-3422','BlockBox','',2),(3428,'113900','watch-mobile','block-3427','DelayedDespatch\\Checkout','',3),(3429,'113901','watch-mobile','block-3420','Html_box','',1),(3430,'113902','watch-mobile','block-3420','BlockBox','',2),(3431,'113903','watch-mobile','block-3430','checkout\\ShippingChoice','',1),(3432,'113904','watch-mobile','block-3419','BlockBox','',3),(3433,'113905','watch-mobile','block-3432','Html_box','',1),(3434,'113906','watch-mobile','block-3432','checkout\\Comments','',2),(3435,'113908','watch-mobile','block-3419','BlockBox','',4),(3436,'113909','watch-mobile','block-3435','checkout\\CreateAccount','',3),(3437,'113910','watch-mobile','block-3435','sample\\Products','',1),(3438,'113911','watch-mobile','block-3419','BlockBox','',5),(3439,'113912','watch-mobile','block-3438','checkout\\ContinueBtn','',1),(3440,'113913','watch-mobile','block-3438','Html_box','',3),(3441,'116002','watch-mobile','block-3438','checkout\\Terms','',2),(3442,'113914','watch-mobile','checkout_no_shipping','BlockBox','',1),(3443,'113915','watch-mobile','block-3442','BlockBox','',2),(3444,'113916','watch-mobile','block-3443','BlockBox','',1),(3445,'113917','watch-mobile','block-3444','BlockBox','',5),(3446,'113918','watch-mobile','block-3445','Html_box','',1),(3447,'113919','watch-mobile','block-3445','checkout\\Comments','',2),(3448,'113920','watch-mobile','block-3444','BlockBox','',4),(3449,'113921','watch-mobile','block-3448','BlockBox','',2),(3450,'113922','watch-mobile','block-3449','CouponsAndVauchers\\Checkout','',1),(3451,'113923','watch-mobile','block-3449-2','checkout\\BonusPoints','',2),(3452,'113924','watch-mobile','block-3449-2','checkout\\CreditAmount','',1),(3453,'113925','watch-mobile','block-3448','Html_box','',1),(3454,'113926','watch-mobile','block-3444','BlockBox','',3),(3455,'113927','watch-mobile','block-3454','BlockBox','',2),(3456,'113928','watch-mobile','block-3455','Html_box','',1),(3457,'113929','watch-mobile','block-3455','checkout\\BillingAddress','',2),(3458,'113930','watch-mobile','block-3455-2','BlockBox','',1),(3459,'113931','watch-mobile','block-3458','Html_box','',1),(3460,'113932','watch-mobile','block-3458','checkout\\PaymentMethod','',2),(3461,'113933','watch-mobile','block-3454','Html_box','',1),(3462,'113934','watch-mobile','block-3444','BlockBox','',6),(3463,'113935','watch-mobile','block-3462','cart\\Products','',1),(3464,'113936','watch-mobile','block-3462','checkout\\CreateAccount','',2),(3465,'113937','watch-mobile','block-3443-2','BlockBox','',1),(3466,'113938','watch-mobile','block-3465','checkout\\Terms','',4),(3467,'113939','watch-mobile','block-3465','checkout\\ContinueBtn','',3),(3468,'113940','watch-mobile','block-3465','checkout\\Totals','',2),(3469,'113941','watch-mobile','block-3465','Html_box','',5),(3470,'113942','watch-mobile','block-3465','Html_box','',1),(3471,'113943','watch-mobile','checkout_no_shipping_g','BlockBox','',1),(3472,'113944','watch-mobile','block-3471','quote\\Products','',3),(3473,'113945','watch-mobile','block-3471','BlockBox','',1),(3474,'113946','watch-mobile','block-3473','BlockBox','',1),(3475,'113947','watch-mobile','block-3474','checkout\\BillingAddress','',2),(3476,'113948','watch-mobile','block-3474','Html_box','',1),(3477,'113949','watch-mobile','block-3473-2','BlockBox','',1),(3478,'113950','watch-mobile','block-3477','checkout\\CreditAmount','',3),(3479,'113951','watch-mobile','block-3477','Html_box','',1),(3480,'113952','watch-mobile','block-3477','checkout\\PaymentMethod','',2),(3481,'113953','watch-mobile','block-3477','CouponsAndVauchers\\Checkout','',5),(3482,'113954','watch-mobile','block-3477','checkout\\BonusPoints','',4),(3483,'113955','watch-mobile','block-3471','BlockBox','',2),(3484,'113956','watch-mobile','block-3483','BlockBox','',1),(3485,'113957','watch-mobile','block-3484','Html_box','',1),(3486,'113958','watch-mobile','block-3484','checkout\\ContactInformation','',2),(3487,'113959','watch-mobile','block-3483-2','BlockBox','',1),(3488,'113960','watch-mobile','block-3487','Html_box','',1),(3489,'113961','watch-mobile','block-3487','checkout\\Comments','',2),(3490,'113962','watch-mobile','block-3471','BlockBox','',6),(3491,'113963','watch-mobile','block-3490','Html_box','',1),(3492,'113964','watch-mobile','block-3490-2','checkout\\ContinueBtn','',1),(3493,'113965','watch-mobile','block-3471','checkout\\Totals','',5),(3494,'113966','watch-mobile','checkout_no_shipping_q','BlockBox','',1),(3495,'113967','watch-mobile','block-3494','BlockBox','',2),(3496,'113968','watch-mobile','block-3495','BlockBox','',2),(3497,'113969','watch-mobile','block-3496','BlockBox','',3),(3498,'113970','watch-mobile','block-3497','BlockBox','',2),(3499,'113971','watch-mobile','block-3498','checkout\\BillingAddress','',2),(3500,'113972','watch-mobile','block-3498','Html_box','',1),(3501,'113973','watch-mobile','block-3498-2','BlockBox','',1),(3502,'113974','watch-mobile','block-3501','Html_box','',1),(3503,'113975','watch-mobile','block-3501','checkout\\PaymentMethod','',2),(3504,'113976','watch-mobile','block-3497','Html_box','',1),(3505,'113977','watch-mobile','block-3496','BlockBox','',6),(3506,'113978','watch-mobile','block-3505','checkout\\CreateAccount','',3),(3507,'113979','watch-mobile','block-3505','quote\\Products','',2),(3508,'113980','watch-mobile','block-3496','BlockBox','',5),(3509,'113981','watch-mobile','block-3508','checkout\\Comments','',2),(3510,'113982','watch-mobile','block-3508','Html_box','',1),(3511,'113983','watch-mobile','block-3496','checkout\\Gdpr','',1),(3512,'113984','watch-mobile','block-3495-2','BlockBox','',1),(3513,'113985','watch-mobile','block-3512','Html_box','',4),(3514,'113986','watch-mobile','block-3512','checkout\\Totals','',2),(3515,'113987','watch-mobile','block-3512','checkout\\ContinueBtn','',3),(3516,'113988','watch-mobile','block-3512','Html_box','',1),(3517,'113989','watch-mobile','checkout_payment','BlockBox','',2),(3518,'113990','watch-mobile','block-3517','Html_box','',1),(3519,'113991','watch-mobile','block-3517','checkout\\ContinueBtn','',2),(3520,'113992','watch-mobile','checkout_payment','BlockBox','',1),(3521,'113993','watch-mobile','block-3520','BlockBox','',1),(3522,'113994','watch-mobile','block-3521','checkout\\BillingAddress','',2),(3523,'113995','watch-mobile','block-3521','Html_box','',1),(3524,'113996','watch-mobile','block-3520','BlockBox','',2),(3525,'113997','watch-mobile','block-3524','checkout\\PaymentMethod','',2),(3526,'113998','watch-mobile','block-3524','Html_box','',1),(3527,'113999','watch-mobile','block-3524','checkout\\CreditAmount','',3),(3528,'114000','watch-mobile','block-3524','CouponsAndVauchers\\Checkout','',5),(3529,'114001','watch-mobile','block-3524','checkout\\BonusPoints','',4),(3530,'114002','watch-mobile','checkout_payment_g','BlockBox','',1),(3531,'114003','watch-mobile','block-3530','BlockBox','',1),(3532,'114004','watch-mobile','block-3531','Html_box','',1),(3533,'114005','watch-mobile','block-3531','checkout\\BillingAddress','',2),(3534,'114006','watch-mobile','block-3530-2','BlockBox','',1),(3535,'114007','watch-mobile','block-3534','checkout\\BonusPoints','',4),(3536,'114008','watch-mobile','block-3534','Html_box','',1),(3537,'114009','watch-mobile','block-3534','CouponsAndVauchers\\Checkout','',5),(3538,'114010','watch-mobile','block-3534','checkout\\CreditAmount','',3),(3539,'114011','watch-mobile','block-3534','checkout\\PaymentMethod','',2),(3540,'114012','watch-mobile','checkout_payment_g','BlockBox','',2),(3541,'114013','watch-mobile','block-3540','Html_box','',1),(3542,'114014','watch-mobile','block-3540-2','checkout\\ContinueBtn','',1),(3543,'114015','watch-mobile','checkout_payment_no_shipping','BlockBox','',1),(3544,'114016','watch-mobile','block-3543','BlockBox','',1),(3545,'114017','watch-mobile','block-3544','Html_box','',1),(3546,'114018','watch-mobile','block-3544','checkout\\BillingAddress','',2),(3547,'114019','watch-mobile','block-3543-2','BlockBox','',1),(3548,'114020','watch-mobile','block-3547','Html_box','',1),(3549,'114021','watch-mobile','block-3547','checkout\\PaymentMethod','',2),(3550,'114022','watch-mobile','block-3547','checkout\\CreditAmount','',3),(3551,'114023','watch-mobile','block-3547','CouponsAndVauchers\\Checkout','',5),(3552,'114024','watch-mobile','block-3547','checkout\\BonusPoints','',4),(3553,'114025','watch-mobile','checkout_payment_no_shipping','BlockBox','',2),(3554,'114026','watch-mobile','block-3553','Html_box','',1),(3555,'114027','watch-mobile','block-3553-2','checkout\\ContinueBtn','',1),(3556,'114028','watch-mobile','checkout_payment_no_shipping_g','BlockBox','',2),(3557,'114029','watch-mobile','block-3556','Html_box','',1),(3558,'114030','watch-mobile','block-3556-2','checkout\\ContinueBtn','',1),(3559,'114031','watch-mobile','checkout_payment_no_shipping_g','BlockBox','',1),(3560,'114032','watch-mobile','block-3559','BlockBox','',1),(3561,'114033','watch-mobile','block-3560','checkout\\BillingAddress','',2),(3562,'114034','watch-mobile','block-3560','Html_box','',1),(3563,'114035','watch-mobile','block-3559-2','BlockBox','',1),(3564,'114036','watch-mobile','block-3563','checkout\\PaymentMethod','',2),(3565,'114037','watch-mobile','block-3563','Html_box','',1),(3566,'114038','watch-mobile','block-3563','checkout\\CreditAmount','',3),(3567,'114039','watch-mobile','block-3563','CouponsAndVauchers\\Checkout','',5),(3568,'114040','watch-mobile','block-3563','checkout\\BonusPoints','',4),(3569,'114041','watch-mobile','checkout_payment_title','Html_box','',1),(3570,'114042','watch-mobile','checkout_payment_title_g','Html_box','',1),(3571,'114043','watch-mobile','checkout_payment_title_no_shipping','Html_box','',1),(3572,'114044','watch-mobile','checkout_payment_title_no_shipping_g','Html_box','',1),(3573,'114045','watch-mobile','checkout_payment_title_q','Html_box','',1),(3574,'114046','watch-mobile','checkout_payment_title_s','Html_box','',1),(3575,'114047','watch-mobile','checkout_q','BlockBox','',1),(3576,'114048','watch-mobile','block-3575','BlockBox','',2),(3577,'114049','watch-mobile','block-3576','BlockBox','',2),(3578,'114050','watch-mobile','block-3577','BlockBox','',3),(3579,'114051','watch-mobile','block-3578','BlockBox','',2),(3580,'114052','watch-mobile','block-3579','checkout\\BillingAddress','',2),(3581,'114053','watch-mobile','block-3579','Html_box','',1),(3582,'114054','watch-mobile','block-3579','BlockBox','',3),(3583,'114055','watch-mobile','block-3582','Html_box','',1),(3584,'114056','watch-mobile','block-3582','checkout\\PaymentMethod','',2),(3585,'114057','watch-mobile','block-3578','Html_box','',1),(3586,'114058','watch-mobile','block-3577','BlockBox','',4),(3587,'114059','watch-mobile','block-3586','Html_box','',1),(3588,'114060','watch-mobile','block-3586','checkout\\Comments','',2),(3589,'114062','watch-mobile','block-3577','BlockBox','',2),(3590,'114063','watch-mobile','block-3589','BlockBox','',3),(3591,'114064','watch-mobile','block-3590','BlockBox','',1),(3592,'114065','watch-mobile','block-3591','Html_box','',3),(3593,'114066','watch-mobile','block-3591','checkout\\ShippingAddress','',2),(3594,'114067','watch-mobile','block-3591','checkout\\ContactInformation','',4),(3595,'114068','watch-mobile','block-3590','BlockBox','',2),(3596,'114069','watch-mobile','block-3595','DelayedDespatch\\Checkout','',3),(3597,'114070','watch-mobile','block-3595','Html_box','',1),(3598,'114071','watch-mobile','block-3595','checkout\\Shipping','',2),(3599,'114072','watch-mobile','block-3589','Html_box','',1),(3600,'114073','watch-mobile','block-3589','Neighbour\\Checkout','',4),(3601,'114074','watch-mobile','block-3589','BlockBox','',2),(3602,'114075','watch-mobile','block-3601','checkout\\ShippingChoice','',1),(3603,'114076','watch-mobile','block-3577','BlockBox','',5),(3604,'114077','watch-mobile','block-3603','quote\\Products','',2),(3605,'114078','watch-mobile','block-3603','checkout\\CreateAccount','',3),(3606,'114079','watch-mobile','block-3577','BlockBox','',6),(3607,'114080','watch-mobile','block-3606','checkout\\ContinueBtn','',3),(3608,'114081','watch-mobile','block-3606','checkout\\Totals','',2),(3609,'114082','watch-mobile','block-3606','Html_box','',5),(3610,'114083','watch-mobile','block-3606','Html_box','',1),(3611,'116000','watch-mobile','block-3606','checkout\\Terms','',4),(3612,'114084','watch-mobile','checkout_s','BlockBox','',1),(3613,'114085','watch-mobile','block-3612','BlockBox','',2),(3614,'114086','watch-mobile','block-3613','BlockBox','',2),(3615,'114093','watch-mobile','block-3614','BlockBox','',3),(3616,'114094','watch-mobile','block-3615','Html_box','',1),(3617,'114095','watch-mobile','block-3615','BlockBox','',2),(3618,'114096','watch-mobile','block-3617','checkout\\BillingAddress','',2),(3619,'114097','watch-mobile','block-3617','Html_box','',1),(3620,'114098','watch-mobile','block-3617','BlockBox','',3),(3621,'114099','watch-mobile','block-3620','checkout\\PaymentMethod','',2),(3622,'114100','watch-mobile','block-3620','Html_box','',1),(3623,'114101','watch-mobile','block-3614','BlockBox','',5),(3624,'114102','watch-mobile','block-3623','checkout\\Comments','',2),(3625,'114103','watch-mobile','block-3623','Html_box','',1),(3626,'114104','watch-mobile','block-3614','BlockBox','',2),(3627,'114105','watch-mobile','block-3626','BlockBox','',2),(3628,'114106','watch-mobile','block-3627','checkout\\ShippingChoice','',1),(3629,'114107','watch-mobile','block-3626','Html_box','',1),(3630,'114108','watch-mobile','block-3626','BlockBox','',3),(3631,'114109','watch-mobile','block-3630','BlockBox','',1),(3632,'114110','watch-mobile','block-3631','checkout\\ShippingAddress','',2),(3633,'114111','watch-mobile','block-3631','Html_box','',3),(3634,'114112','watch-mobile','block-3631','checkout\\ContactInformation','',4),(3635,'114113','watch-mobile','block-3630','BlockBox','',2),(3636,'114114','watch-mobile','block-3635','DelayedDespatch\\Checkout','',3),(3637,'114115','watch-mobile','block-3635','Html_box','',1),(3638,'114116','watch-mobile','block-3635','checkout\\Shipping','',2),(3639,'114117','watch-mobile','block-3626','Neighbour\\Checkout','',4),(3640,'114118','watch-mobile','block-3614','BlockBox','',6),(3641,'114119','watch-mobile','block-3640','checkout\\CreateAccount','',3),(3642,'114120','watch-mobile','block-3640','sample\\Products','',1),(3643,'114122','watch-mobile','block-3614','BlockBox','',7),(3644,'114123','watch-mobile','block-3643','Html_box','',1),(3645,'114124','watch-mobile','block-3643','checkout\\ContinueBtn','',3),(3646,'114125','watch-mobile','block-3643','Html_box','',5),(3647,'114126','watch-mobile','block-3643','checkout\\Totals','',2),(3648,'116001','watch-mobile','block-3643','checkout\\Terms','',4),(3649,'114127','watch-mobile','checkout_step_bottom','cart\\Products','',2),(3650,'114128','watch-mobile','checkout_step_bottom','checkout\\Totals','',3),(3651,'114129','watch-mobile','checkout_step_bottom','Html_box','',1),(3652,'114130','watch-mobile','checkout_step_bottom_g','checkout\\Totals','',3),(3653,'114131','watch-mobile','checkout_step_bottom_g','quote\\Products','',2),(3654,'114132','watch-mobile','checkout_step_bottom_g','Html_box','',1),(3655,'114133','watch-mobile','checkout_step_bottom_no_shipping_g','Html_box','',1),(3656,'114134','watch-mobile','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(3657,'114135','watch-mobile','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(3658,'114136','watch-mobile','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(3659,'114137','watch-mobile','checkout_step_bottom_no_shipping','Html_box','',1),(3660,'114138','watch-mobile','checkout_step_bottom_no_shipping','cart\\Products','',2),(3661,'114139','watch-mobile','communication','BlockBox','',1),(3662,'114140','watch-mobile','block-3661','Html_box','',2),(3663,'114141','watch-mobile','block-3661','Communication\\Topic','',3),(3664,'114142','watch-mobile','block-3661','Communication\\NewTopicButton','',1),(3665,'114143','watch-mobile','compare','BlockBox','',1),(3666,'114144','watch-mobile','block-3665','catalog\\Compare','',1),(3667,'114145','watch-mobile','compare_products','BlockBox','',2),(3668,'114146','watch-mobile','block-3667','productListing\\rating','',4),(3669,'114147','watch-mobile','block-3667','productListing\\model','',5),(3670,'114148','watch-mobile','block-3667','productListing\\compare','',1),(3671,'114149','watch-mobile','block-3667','BlockBox','',2),(3672,'114150','watch-mobile','block-3671','productListing\\image','',1),(3673,'114151','watch-mobile','block-3671-2','productListing\\name','',2),(3674,'114152','watch-mobile','block-3667','BlockBox','',3),(3675,'114153','watch-mobile','block-3674','productListing\\price','',1),(3676,'114154','watch-mobile','block-3674-2','productListing\\buyButton','',1),(3677,'114155','watch-mobile','confirmation','BlockBox','',1),(3678,'114156','watch-mobile','block-3677','BlockBox','',2),(3679,'114157','watch-mobile','block-3678','UploadCustomerId\\UploadCustomerIdForm','',1),(3680,'114158','watch-mobile','block-3678','BlockBox','',2),(3681,'114159','watch-mobile','block-3680','BlockBox','',1),(3682,'114160','watch-mobile','block-3681','BlockBox','',1),(3683,'114161','watch-mobile','block-3682','checkout\\ShippingAddressConfirm','',4),(3684,'114162','watch-mobile','block-3682','Html_box','',1),(3685,'114163','watch-mobile','block-3682','Html_box','',2),(3686,'114164','watch-mobile','block-3682','checkout\\ContactConfirm','',11),(3687,'114165','watch-mobile','block-3682','checkout\\EditBtn','',3),(3688,'114166','watch-mobile','block-3682','Html_box','',5),(3689,'114167','watch-mobile','block-3682','DelayedDespatch\\CheckoutConfirm','',8),(3690,'114168','watch-mobile','block-3682','checkout\\EditBtn','',10),(3691,'114169','watch-mobile','block-3682','checkout\\EditBtn','',6),(3692,'114170','watch-mobile','block-3682','Html_box','',9),(3693,'114171','watch-mobile','block-3682','checkout\\ShippingConfirm','',7),(3694,'114172','watch-mobile','block-3681','BlockBox','',2),(3695,'114173','watch-mobile','block-3694','Html_box','',2),(3696,'114174','watch-mobile','block-3694','checkout\\BillingAddressConfirm','',4),(3697,'114175','watch-mobile','block-3694','Html_box','',5),(3698,'114176','watch-mobile','block-3694','checkout\\PaymentMethodConfirm','',7),(3699,'114177','watch-mobile','block-3694','Html_box','',1),(3700,'114178','watch-mobile','block-3694','checkout\\EditBtn','',3),(3701,'114179','watch-mobile','block-3694','checkout\\EditBtn','',6),(3702,'114180','watch-mobile','block-3680','BlockBox','',3),(3703,'114181','watch-mobile','block-3702','Html_box','',1),(3704,'114182','watch-mobile','block-3702','checkout\\EditBtn','',2),(3705,'114183','watch-mobile','block-3702','cart\\Products','',3),(3706,'114184','watch-mobile','block-3680','BlockBox','',2),(3707,'114185','watch-mobile','block-3706','Html_box','',1),(3708,'114186','watch-mobile','block-3706','checkout\\CommentsConfirm','',3),(3709,'114187','watch-mobile','block-3706','checkout\\EditBtn','',2),(3710,'114188','watch-mobile','block-3680','BlockBox','',4),(3711,'114189','watch-mobile','block-3710','checkout\\Totals','',2),(3712,'114190','watch-mobile','block-3710','Html_box','',1),(3713,'114191','watch-mobile','block-3710','checkout\\ConfirmBtn','',3),(3714,'114192','watch-mobile','block-3677','Html_box','',1),(3715,'114193','watch-mobile','confirmation_free_s','BlockBox','',1),(3716,'114194','watch-mobile','block-3715','Html_box','',1),(3717,'114195','watch-mobile','block-3715','BlockBox','',2),(3718,'114196','watch-mobile','block-3717','BlockBox','',1),(3719,'114197','watch-mobile','block-3718','BlockBox','',1),(3720,'114198','watch-mobile','block-3719','BlockBox','',1),(3721,'114199','watch-mobile','block-3720','checkout\\EditBtn','',6),(3722,'114200','watch-mobile','block-3720','checkout\\ShippingAddressConfirm','',4),(3723,'114201','watch-mobile','block-3720','Html_box','',2),(3724,'114202','watch-mobile','block-3720','checkout\\ShippingConfirm','',7),(3725,'114203','watch-mobile','block-3720','checkout\\EditBtn','',3),(3726,'114204','watch-mobile','block-3720','Html_box','',5),(3727,'114205','watch-mobile','block-3719','BlockBox','',2),(3728,'114206','watch-mobile','block-3727','Html_box','',1),(3729,'114207','watch-mobile','block-3727','checkout\\EditBtn','',2),(3730,'114208','watch-mobile','block-3727','DelayedDespatch\\CheckoutConfirm','',4),(3731,'114209','watch-mobile','block-3727','checkout\\ContactConfirm','',3),(3732,'114210','watch-mobile','block-3718','BlockBox','',2),(3733,'114211','watch-mobile','block-3732','checkout\\CommentsConfirm','',3),(3734,'114212','watch-mobile','block-3732','checkout\\EditBtn','',2),(3735,'114213','watch-mobile','block-3732','Html_box','',1),(3736,'114214','watch-mobile','block-3718','BlockBox','',3),(3737,'114215','watch-mobile','block-3736','sample\\Products','',2),(3738,'114216','watch-mobile','block-3736','Html_box','',1),(3739,'114217','watch-mobile','block-3736','checkout\\EditBtn','',3),(3740,'114218','watch-mobile','block-3718','BlockBox','',4),(3741,'114219','watch-mobile','block-3740','checkout\\ConfirmBtn','',3),(3742,'114220','watch-mobile','confirmation_no_shipping','BlockBox','',1),(3743,'114221','watch-mobile','block-3742','Html_box','',1),(3744,'114222','watch-mobile','block-3742','BlockBox','',2),(3745,'114223','watch-mobile','block-3744','BlockBox','',1),(3746,'114224','watch-mobile','block-3745','BlockBox','',3),(3747,'114225','watch-mobile','block-3746','checkout\\EditBtn','',2),(3748,'114226','watch-mobile','block-3746','Html_box','',1),(3749,'114227','watch-mobile','block-3746','cart\\Products','',3),(3750,'114228','watch-mobile','block-3745','BlockBox','',2),(3751,'114229','watch-mobile','block-3750','checkout\\EditBtn','',2),(3752,'114230','watch-mobile','block-3750','checkout\\CommentsConfirm','',3),(3753,'114231','watch-mobile','block-3750','Html_box','',1),(3754,'114232','watch-mobile','block-3745','BlockBox','',1),(3755,'114233','watch-mobile','block-3754','BlockBox','',1),(3756,'114234','watch-mobile','block-3755','Html_box','',9),(3757,'114235','watch-mobile','block-3755','checkout\\ContactConfirm','',11),(3758,'114236','watch-mobile','block-3755','checkout\\EditBtn','',10),(3759,'114237','watch-mobile','block-3754-2','BlockBox','',1),(3760,'114238','watch-mobile','block-3759','checkout\\EditBtn','',3),(3761,'114239','watch-mobile','block-3759','Html_box','',2),(3762,'114240','watch-mobile','block-3759','Html_box','',1),(3763,'114241','watch-mobile','block-3759','Html_box','',5),(3764,'114242','watch-mobile','block-3759','checkout\\BillingAddressConfirm','',4),(3765,'114243','watch-mobile','block-3759','checkout\\PaymentMethodConfirm','',7),(3766,'114244','watch-mobile','block-3759','checkout\\EditBtn','',6),(3767,'114245','watch-mobile','block-3744-2','BlockBox','',1),(3768,'114246','watch-mobile','block-3767','checkout\\ConfirmBtn','',3),(3769,'114247','watch-mobile','block-3767','checkout\\Totals','',2),(3770,'114248','watch-mobile','block-3767','Html_box','',1),(3771,'114249','watch-mobile','confirmation_no_shipping_q','BlockBox','',2),(3772,'114250','watch-mobile','block-3771','BlockBox','',2),(3773,'114251','watch-mobile','block-3772','BlockBox','',1),(3774,'114252','watch-mobile','block-3773','BlockBox','',3),(3775,'114253','watch-mobile','block-3774','quote\\Products','',3),(3776,'114254','watch-mobile','block-3774','checkout\\EditBtn','',2),(3777,'114255','watch-mobile','block-3774','Html_box','',1),(3778,'114256','watch-mobile','block-3773','BlockBox','',1),(3779,'114257','watch-mobile','block-3778','BlockBox','',1),(3780,'114258','watch-mobile','block-3779','checkout\\EditBtn','',2),(3781,'114259','watch-mobile','block-3779','Html_box','',1),(3782,'114260','watch-mobile','block-3779','Html_box','',4),(3783,'114261','watch-mobile','block-3779','checkout\\PaymentMethodConfirm','',3),(3784,'114262','watch-mobile','block-3779','checkout\\EditBtn','',5),(3785,'114263','watch-mobile','block-3779','checkout\\ContactConfirm','',6),(3786,'114264','watch-mobile','block-3778-2','BlockBox','',1),(3787,'114265','watch-mobile','block-3786','Html_box','',2),(3788,'114266','watch-mobile','block-3786','checkout\\EditBtn','',3),(3789,'114267','watch-mobile','block-3786','checkout\\BillingAddressConfirm','',4),(3790,'114268','watch-mobile','block-3773','BlockBox','',2),(3791,'114269','watch-mobile','block-3790','checkout\\CommentsConfirm','',3),(3792,'114270','watch-mobile','block-3790','Html_box','',1),(3793,'114271','watch-mobile','block-3790','checkout\\EditBtn','',2),(3794,'114272','watch-mobile','block-3772-2','BlockBox','',1),(3795,'114273','watch-mobile','block-3794','Html_box','',1),(3796,'114274','watch-mobile','block-3794','checkout\\Totals','',2),(3797,'114275','watch-mobile','block-3794','checkout\\ConfirmBtn','',3),(3798,'114276','watch-mobile','block-3771','Html_box','',1),(3799,'114277','watch-mobile','confirmation_q','BlockBox','',1),(3800,'114278','watch-mobile','block-3799','Html_box','',1),(3801,'114279','watch-mobile','block-3799','BlockBox','',2),(3802,'114280','watch-mobile','block-3801','BlockBox','',1),(3803,'114281','watch-mobile','block-3802','BlockBox','',3),(3804,'114282','watch-mobile','block-3803','checkout\\EditBtn','',2),(3805,'114283','watch-mobile','block-3803','Html_box','',1),(3806,'114284','watch-mobile','block-3803','quote\\Products','',3),(3807,'114285','watch-mobile','block-3802','BlockBox','',2),(3808,'114286','watch-mobile','block-3807','checkout\\EditBtn','',2),(3809,'114287','watch-mobile','block-3807','checkout\\CommentsConfirm','',3),(3810,'114288','watch-mobile','block-3807','Html_box','',1),(3811,'114289','watch-mobile','block-3802','BlockBox','',1),(3812,'114290','watch-mobile','block-3811','BlockBox','',1),(3813,'114291','watch-mobile','block-3812','Html_box','',5),(3814,'114292','watch-mobile','block-3812','Html_box','',9),(3815,'114293','watch-mobile','block-3812','checkout\\EditBtn','',6),(3816,'114294','watch-mobile','block-3812','checkout\\ShippingConfirm','',7),(3817,'114295','watch-mobile','block-3812','checkout\\EditBtn','',3),(3818,'114296','watch-mobile','block-3812','DelayedDespatch\\CheckoutConfirm','',8),(3819,'114297','watch-mobile','block-3812','checkout\\ShippingAddressConfirm','',4),(3820,'114298','watch-mobile','block-3812','checkout\\ContactConfirm','',11),(3821,'114299','watch-mobile','block-3812','checkout\\EditBtn','',10),(3822,'114300','watch-mobile','block-3812','Html_box','',2),(3823,'114301','watch-mobile','block-3812','Html_box','',1),(3824,'114302','watch-mobile','block-3811','BlockBox','',2),(3825,'114303','watch-mobile','block-3824','Html_box','',1),(3826,'114304','watch-mobile','block-3824','Html_box','',2),(3827,'114305','watch-mobile','block-3824','checkout\\PaymentMethodConfirm','',7),(3828,'114306','watch-mobile','block-3824','Html_box','',5),(3829,'114307','watch-mobile','block-3824','checkout\\BillingAddressConfirm','',4),(3830,'114308','watch-mobile','block-3824','checkout\\EditBtn','',6),(3831,'114309','watch-mobile','block-3824','checkout\\EditBtn','',3),(3832,'114310','watch-mobile','block-3802','BlockBox','',4),(3833,'114311','watch-mobile','block-3832','checkout\\ConfirmBtn','',3),(3834,'114312','watch-mobile','block-3832','Html_box','',1),(3835,'114313','watch-mobile','block-3832','checkout\\Totals','',2),(3836,'114314','watch-mobile','confirmation_s','BlockBox','',1),(3837,'114315','watch-mobile','block-3836','Html_box','',1),(3838,'114316','watch-mobile','block-3836','BlockBox','',2),(3839,'114317','watch-mobile','block-3838','BlockBox','',1),(3840,'114318','watch-mobile','block-3839','BlockBox','',2),(3841,'114319','watch-mobile','block-3840','checkout\\CommentsConfirm','',3),(3842,'114320','watch-mobile','block-3840','checkout\\EditBtn','',2),(3843,'114321','watch-mobile','block-3840','Html_box','',1),(3844,'114322','watch-mobile','block-3839','BlockBox','',3),(3845,'114323','watch-mobile','block-3844','sample\\Products','',2),(3846,'114324','watch-mobile','block-3844','Html_box','',1),(3847,'114325','watch-mobile','block-3844','checkout\\EditBtn','',3),(3848,'114326','watch-mobile','block-3839','BlockBox','',1),(3849,'114327','watch-mobile','block-3848','BlockBox','',1),(3850,'114328','watch-mobile','block-3849','Html_box','',9),(3851,'114329','watch-mobile','block-3849','checkout\\ContactConfirm','',11),(3852,'114330','watch-mobile','block-3849','checkout\\EditBtn','',6),(3853,'114331','watch-mobile','block-3849','checkout\\EditBtn','',10),(3854,'114332','watch-mobile','block-3849','Html_box','',1),(3855,'114333','watch-mobile','block-3849','DelayedDespatch\\CheckoutConfirm','',8),(3856,'114334','watch-mobile','block-3849','checkout\\EditBtn','',3),(3857,'114335','watch-mobile','block-3849','checkout\\ShippingAddressConfirm','',4),(3858,'114336','watch-mobile','block-3849','Html_box','',5),(3859,'114337','watch-mobile','block-3849','Html_box','',2),(3860,'114338','watch-mobile','block-3849','checkout\\ShippingConfirm','',7),(3861,'114339','watch-mobile','block-3848','BlockBox','',2),(3862,'114340','watch-mobile','block-3861','Html_box','',5),(3863,'114341','watch-mobile','block-3861','Html_box','',1),(3864,'114342','watch-mobile','block-3861','checkout\\EditBtn','',6),(3865,'114343','watch-mobile','block-3861','checkout\\BillingAddressConfirm','',4),(3866,'114344','watch-mobile','block-3861','checkout\\EditBtn','',3),(3867,'114345','watch-mobile','block-3861','Html_box','',2),(3868,'114346','watch-mobile','block-3861','checkout\\PaymentMethodConfirm','',7),(3869,'114347','watch-mobile','block-3839','BlockBox','',4),(3870,'114348','watch-mobile','block-3869','checkout\\Totals','',2),(3871,'114349','watch-mobile','block-3869','Html_box','',1),(3872,'114350','watch-mobile','block-3869','checkout\\ConfirmBtn','',3),(3873,'75599','watch-mobile','contact','BlockBox','',1),(3874,'75600','watch-mobile','block-3873','BlockBox','',4),(3875,'75601','watch-mobile','block-3874','contact\\Map','',1),(3876,'75602','watch-mobile','block-3874-2','contact\\StreetView','',1),(3877,'75603','watch-mobile','block-3873','BlockBox','',3),(3878,'75604','watch-mobile','block-3877','contact\\ContactForm','',1),(3879,'75605','watch-mobile','block-3877-2','contact\\Contacts','',1),(3880,'75606','watch-mobile','block-3873','info\\Title','',1),(3881,'114351','watch-mobile','created_success','BlockBox','',1),(3882,'114352','watch-mobile','block-3881','Html_box','',2),(3883,'114353','watch-mobile','block-3881','Html_box','',1),(3884,'114354','watch-mobile','credit_note','invoice\\Container','',1),(3885,'114355','watch-mobile','block-3884','BlockBox','',2),(3886,'114356','watch-mobile','block-3885','BlockBox','',8),(3887,'114357','watch-mobile','block-3886','BlockBox','',1),(3888,'114358','watch-mobile','block-3887','Text','',1),(3889,'114359','watch-mobile','block-3887','invoice\\ShippingMethod','',2),(3890,'114360','watch-mobile','block-3886-2','BlockBox','',1),(3891,'114361','watch-mobile','block-3890','invoice\\ShippingMethod','',2),(3892,'114362','watch-mobile','block-3890','Text','',1),(3893,'114363','watch-mobile','block-3885','BlockBox','',7),(3894,'114364','watch-mobile','block-3893','BlockBox','',1),(3895,'114365','watch-mobile','block-3894','invoice\\BillingAddress','',2),(3896,'114366','watch-mobile','block-3894','Text','',1),(3897,'114367','watch-mobile','block-3893-2','BlockBox','',1),(3898,'114368','watch-mobile','block-3897','Text','',5),(3899,'114369','watch-mobile','block-3897','invoice\\CustomerName','',2),(3900,'114370','watch-mobile','block-3897','invoice\\CustomerEmail','',6),(3901,'114371','watch-mobile','block-3897','Text','',3),(3902,'114372','watch-mobile','block-3897','Text','',1),(3903,'114373','watch-mobile','block-3897','invoice\\CustomerPhone','',4),(3904,'114374','watch-mobile','block-3885-2','invoice\\PaymentDate','',3),(3905,'114375','watch-mobile','block-3885-2','Text','',2),(3906,'114376','watch-mobile','block-3885-2','invoice\\OrderId','',1),(3907,'114377','watch-mobile','block-3884','BlockBox','',4),(3908,'114378','watch-mobile','block-3907','BlockBox','',1),(3909,'114379','watch-mobile','block-3908','Text','',1),(3910,'114380','watch-mobile','block-3908','invoice\\ShippingAddress','',2),(3911,'114381','watch-mobile','block-3907-2','BlockBox','',1),(3912,'114382','watch-mobile','block-3884','BlockBox','',1),(3913,'114383','watch-mobile','block-3912','Logo','',1),(3914,'114384','watch-mobile','block-3912-2','BlockBox','',1),(3915,'114385','watch-mobile','block-3914','invoice\\StoreAddress','',1),(3916,'114386','watch-mobile','block-3912-2','BlockBox','',3),(3917,'114387','watch-mobile','block-3916','Text','',1),(3918,'114388','watch-mobile','block-3916-2','invoice\\StoreEmail','',1),(3919,'114389','watch-mobile','block-3912-2','BlockBox','',2),(3920,'114390','watch-mobile','block-3919','Text','',1),(3921,'114391','watch-mobile','block-3919-2','invoice\\StorePhone','',1),(3922,'114392','watch-mobile','block-3912-2','BlockBox','',4),(3923,'114393','watch-mobile','block-3922','Text','',1),(3924,'114394','watch-mobile','block-3922-2','invoice\\StoreSite','',1),(3925,'114395','watch-mobile','block-3884','invoice\\Products','',3),(3926,'114396','watch-mobile','block-3884','BlockBox','',5),(3927,'114397','watch-mobile','block-3926','invoice\\StoreAddress','',8),(3928,'114398','watch-mobile','block-3926','Text','',1),(3929,'114399','watch-mobile','block-3926-2','Text','',2),(3930,'114400','watch-mobile','block-3926-2','Logo','',1),(3931,'114401','watch-mobile','block-3926-3','BlockBox','',2),(3932,'114402','watch-mobile','block-3931','Text','',1),(3933,'114403','watch-mobile','block-3931-2','invoice\\StorePhone','',1),(3934,'114404','watch-mobile','block-3926-3','BlockBox','',3),(3935,'114405','watch-mobile','block-3934','Text','',1),(3936,'114406','watch-mobile','block-3934-2','invoice\\StoreEmail','',1),(3937,'114407','watch-mobile','block-3926-3','Text','',1),(3938,'75607','watch-mobile','delivery-location','DeliveryLocation\\LocationProducts','',8),(3939,'75608','watch-mobile','delivery-location','DeliveryLocation\\LocationLongDescription','',5),(3940,'75609','watch-mobile','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(3941,'75610','watch-mobile','delivery-location','DeliveryLocation\\LocationDescription','',3),(3942,'75611','watch-mobile','delivery-location','DeliveryLocation\\FeaturedList','',6),(3943,'75612','watch-mobile','delivery-location','DeliveryLocation\\LocationList','',7),(3944,'75613','watch-mobile','delivery-location','DeliveryLocation\\LocationTitle','',2),(3945,'75614','watch-mobile','delivery-location-default','DeliveryLocation\\TopLocationList','',2),(3946,'75615','watch-mobile','delivery-location-default','Heading','',1),(3947,'114408','watch-mobile','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(3948,'114409','watch-mobile','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(3949,'114410','watch-mobile','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(3950,'114411','watch-mobile','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(3951,'114412','watch-mobile','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(3952,'114413','watch-mobile','delivery_loc_2','DeliveryLocation\\LocationList','',7),(3953,'114414','watch-mobile','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(3954,'75616','watch-mobile','email','email\\Content','',3),(3955,'75617','watch-mobile','email','email\\BlockBox','',1),(3956,'75618','watch-mobile','block-3955','Logo','',1),(3957,'75619','watch-mobile','email','Copyright','',7),(3958,'75620','watch-mobile','email','email\\BlockBox','',4),(3959,'75621','watch-mobile','email','Text','',5),(3960,'75622','watch-mobile','email','email\\BlockBox','',2),(3961,'75623','watch-mobile','block-3960','email\\Title','',1),(3962,'75624','watch-mobile','block-3960-2','email\\Date','',1),(3963,'114415','watch-mobile','email_2','email\\BlockBox','',1),(3964,'114416','watch-mobile','block-3963','email\\BlockBox','',1),(3965,'114417','watch-mobile','block-3964','email\\Content','',3),(3966,'114418','watch-mobile','block-3964','email\\BlockBox','',2),(3967,'114419','watch-mobile','block-3966','email\\Title','',1),(3968,'114420','watch-mobile','block-3966-2','email\\Date','',1),(3969,'114421','watch-mobile','block-3964','Copyright','',4),(3970,'114422','watch-mobile','block-3964','Logo','',1),(3971,'114423','watch-mobile','email_3','email\\BlockBox','',1),(3972,'114424','watch-mobile','block-3971','email\\BlockBox','',1),(3973,'114425','watch-mobile','block-3972','Logo','',1),(3974,'114426','watch-mobile','block-3972','Copyright','',3),(3975,'114427','watch-mobile','block-3972','email\\BlockBox','',2),(3976,'114428','watch-mobile','block-3975','email\\BlockBox','',1),(3977,'114429','watch-mobile','block-3976','email\\Title','',1),(3978,'114430','watch-mobile','block-3976-2','email\\Date','',1),(3979,'114431','watch-mobile','block-3975','email\\Content','',2),(3980,'114432','watch-mobile','email_4','email\\BlockBox','',1),(3981,'114433','watch-mobile','block-3980','email\\BlockBox','',1),(3982,'114434','watch-mobile','block-3981','email\\BlockBox','',1),(3983,'114435','watch-mobile','block-3982','email\\Content','',2),(3984,'114436','watch-mobile','block-3982','email\\BlockBox','',1),(3985,'114437','watch-mobile','block-3984','Logo','',1),(3986,'114438','watch-mobile','block-3984-2','email\\Title','',1),(3987,'114439','watch-mobile','block-3984-2','email\\Date','',2),(3988,'114440','watch-mobile','block-3981','Copyright','',2),(3989,'75625','watch-mobile','footer','BlockBox','footer-content',1),(3990,'75628','watch-mobile','block-3989','BlockBox','',4),(3991,'75629','watch-mobile','block-3990','Text','',1),(3992,'75630','watch-mobile','block-3990','Menu','footer3',2),(3993,'75632','watch-mobile','block-3989','Copyright','',10),(3994,'75633','watch-mobile','block-3989','BlockBox','',2),(3995,'75634','watch-mobile','block-3994','Menu','footer2',2),(3996,'75635','watch-mobile','block-3994','Text','',1),(3997,'75636','watch-mobile','block-3989','BlockBox','',3),(3998,'75637','watch-mobile','block-3997','Text','',1),(3999,'75638','watch-mobile','block-3997','Menu','footer1',2),(4000,'75640','watch-mobile','block-3989','BlockBox','',1),(4001,'75641','watch-mobile','block-4000','Contacts','',2),(4002,'75642','watch-mobile','block-4000','Text','',1),(4003,'114441','watch-mobile','for_menu','BlockBox','',1),(4004,'114442','watch-mobile','block-4003','Html_box','',1),(4005,'114443','watch-mobile','block-4003-2','Languages','',1),(4006,'114444','watch-mobile','for_menu','BlockBox','',3),(4007,'114445','watch-mobile','block-4006','Html_box','',1),(4008,'114446','watch-mobile','block-4006-2','Currencies','',1),(4009,'75650','watch-mobile','gift','BlockBox','',1),(4010,'75651','watch-mobile','block-4009','BlockBox','',3),(4011,'75652','watch-mobile','block-4010','BlockBox','',1),(4012,'75653','watch-mobile','block-4011','BlockBox','',1),(4013,'75654','watch-mobile','block-4012','BlockBox','',9),(4014,'75655','watch-mobile','block-4013','Text','',1),(4015,'75656','watch-mobile','block-4013','invoice\\StoreEmail','',3),(4016,'75657','watch-mobile','block-4013','invoice\\StorePhone','',2),(4017,'75658','watch-mobile','block-4012','Text','',6),(4018,'75659','watch-mobile','block-4012','Text','',4),(4019,'75660','watch-mobile','block-4012','Text','',7),(4020,'75661','watch-mobile','block-4012','Text','',2),(4021,'75662','watch-mobile','block-4012','BlockBox','',8),(4022,'75663','watch-mobile','block-4021','Text','',1),(4023,'75664','watch-mobile','block-4021-2','gift\\CodeView','',1),(4024,'75665','watch-mobile','block-4012','gift\\MessageView','',5),(4025,'75666','watch-mobile','block-4012','gift\\AmountView','',3),(4026,'75667','watch-mobile','block-4012','Text','',1),(4027,'75668','watch-mobile','block-4010-2','gift\\Form','',2),(4028,'75669','watch-mobile','block-4010-2','Text','',1),(4029,'75670','watch-mobile','block-4009','info\\Title','',1),(4030,'114447','watch-mobile','gift_card','BlockBox','',1),(4031,'114448','watch-mobile','block-4030','Text','',9),(4032,'114449','watch-mobile','block-4030','Text','',4),(4033,'114450','watch-mobile','block-4030','Logo','',1),(4034,'114451','watch-mobile','block-4030','Image','',2),(4035,'114452','watch-mobile','block-4030','Text','',6),(4036,'114453','watch-mobile','block-4030','gift\\AmountView','',5),(4037,'114454','watch-mobile','block-4030','gift\\MessageView','',7),(4038,'114455','watch-mobile','block-4030','BlockBox','',10),(4039,'114456','watch-mobile','block-4038','Text','',1),(4040,'114457','watch-mobile','block-4038-2','gift\\CodeView','',1),(4041,'114458','watch-mobile','block-4030','Text','',3),(4042,'114459','watch-mobile','block-4030','Text','',8),(4043,'114460','watch-mobile','block-4030','BlockBox','',11),(4044,'114461','watch-mobile','block-4043','invoice\\StorePhone','',2),(4045,'114462','watch-mobile','block-4043','Text','',1),(4046,'114463','watch-mobile','block-4043','invoice\\StoreEmail','',3),(4047,'114464','watch-mobile','gift_card_2','BlockBox','',1),(4048,'114465','watch-mobile','block-4047','Text','',1),(4049,'114466','watch-mobile','block-4047','Text','',2),(4050,'114467','watch-mobile','block-4047','Text','',6),(4051,'114468','watch-mobile','block-4047','gift\\MessageView','',5),(4052,'114469','watch-mobile','block-4047','Text','',7),(4053,'114470','watch-mobile','block-4047','Text','',4),(4054,'114471','watch-mobile','block-4047','BlockBox','',9),(4055,'114472','watch-mobile','block-4054','invoice\\StorePhone','',2),(4056,'114473','watch-mobile','block-4054','Text','',1),(4057,'114474','watch-mobile','block-4054','invoice\\StoreEmail','',3),(4058,'114475','watch-mobile','block-4047','BlockBox','',8),(4059,'114476','watch-mobile','block-4058','Text','',1),(4060,'114477','watch-mobile','block-4058-2','gift\\CodeView','',1),(4061,'114478','watch-mobile','block-4047','gift\\AmountView','',3),(4062,'114479','watch-mobile','gift_card_2_pdf','BlockBox','',1),(4063,'114480','watch-mobile','block-4062','BlockBox','',12),(4064,'114481','watch-mobile','block-4063','invoice\\StoreEmail','',4),(4065,'114482','watch-mobile','block-4063','invoice\\StorePhone','',3),(4066,'114483','watch-mobile','block-4063','Html_box','',1),(4067,'114484','watch-mobile','block-4062','BlockBox','',11),(4068,'114485','watch-mobile','block-4067','Html_box','',1),(4069,'114486','watch-mobile','block-4067-2','gift\\CodeViewPdf','',1),(4070,'114487','watch-mobile','block-4062','BlockBox','',1),(4071,'114488','watch-mobile','block-4070','Text','',4),(4072,'114489','watch-mobile','block-4070','Html_box','',1),(4073,'114490','watch-mobile','block-4070','Html_box','',2),(4074,'114491','watch-mobile','block-4070','gift\\AmountViewPdf','',3),(4075,'114492','watch-mobile','block-4070','gift\\MessageViewPdf','',5),(4076,'114493','watch-mobile','block-4070','Html_box','',7),(4077,'114494','watch-mobile','block-4070','Html_box','',6),(4078,'114495','watch-mobile','gift_card_2_pdf','Import','',1),(4079,'114496','watch-mobile','gift_card_pdf','BlockBox','',1),(4080,'114497','watch-mobile','block-4079','BlockBox','',12),(4081,'114498','watch-mobile','block-4080','invoice\\StoreEmail','',4),(4082,'114499','watch-mobile','block-4080','invoice\\StorePhone','',3),(4083,'114500','watch-mobile','block-4080','Html_box','',1),(4084,'114501','watch-mobile','block-4079','BlockBox','',11),(4085,'114502','watch-mobile','block-4084','Html_box','',1),(4086,'114503','watch-mobile','block-4084-2','gift\\CodeViewPdf','',1),(4087,'114504','watch-mobile','block-4079','BlockBox','',1),(4088,'114505','watch-mobile','block-4087','Text','',4),(4089,'114506','watch-mobile','block-4087','Html_box','',1),(4090,'114507','watch-mobile','block-4087','Html_box','',2),(4091,'114508','watch-mobile','block-4087','gift\\AmountViewPdf','',3),(4092,'114509','watch-mobile','block-4087','gift\\MessageViewPdf','',5),(4093,'114510','watch-mobile','block-4087','Html_box','',7),(4094,'114511','watch-mobile','block-4087','Html_box','',6),(4095,'114512','watch-mobile','gift_card_pdf','Import','',1),(4096,'114513','watch-mobile','gift_certificate','BlockBox','',1),(4097,'114514','watch-mobile','block-4096','account\\ApplyCertificate','',2),(4098,'114515','watch-mobile','block-4096','Html_box','',1),(4099,'114516','watch-mobile','gigt_card_3','BlockBox','',1),(4100,'114517','watch-mobile','block-4099','Text','',7),(4101,'114518','watch-mobile','block-4099','Text','',4),(4102,'114519','watch-mobile','block-4099','gift\\AmountView','',3),(4103,'114520','watch-mobile','block-4099','Text','',2),(4104,'114521','watch-mobile','block-4099','gift\\MessageView','',5),(4105,'114522','watch-mobile','block-4099','Text','',1),(4106,'114523','watch-mobile','block-4099','BlockBox','',9),(4107,'114524','watch-mobile','block-4106','invoice\\StoreEmail','',3),(4108,'114525','watch-mobile','block-4106','invoice\\StorePhone','',2),(4109,'114526','watch-mobile','block-4106','Text','',1),(4110,'114527','watch-mobile','block-4099','Text','',6),(4111,'114528','watch-mobile','block-4099','BlockBox','',8),(4112,'114529','watch-mobile','block-4111','Text','',1),(4113,'114530','watch-mobile','block-4111-2','gift\\CodeView','',1),(4114,'114531','watch-mobile','gigt_card_3_pdf','BlockBox','',1),(4115,'114532','watch-mobile','block-4114','BlockBox','',12),(4116,'114533','watch-mobile','block-4115','invoice\\StoreEmail','',4),(4117,'114534','watch-mobile','block-4115','invoice\\StorePhone','',3),(4118,'114535','watch-mobile','block-4115','Html_box','',1),(4119,'114536','watch-mobile','block-4114','BlockBox','',11),(4120,'114537','watch-mobile','block-4119','Html_box','',1),(4121,'114538','watch-mobile','block-4119-2','gift\\CodeViewPdf','',1),(4122,'114539','watch-mobile','block-4114','BlockBox','',1),(4123,'114540','watch-mobile','block-4122','Text','',4),(4124,'114541','watch-mobile','block-4122','Html_box','',1),(4125,'114542','watch-mobile','block-4122','Html_box','',2),(4126,'114543','watch-mobile','block-4122','gift\\AmountViewPdf','',3),(4127,'114544','watch-mobile','block-4122','gift\\MessageViewPdf','',5),(4128,'114545','watch-mobile','block-4122','Html_box','',7),(4129,'114546','watch-mobile','block-4122','Html_box','',6),(4130,'75671','watch-mobile','header','Logo','',2),(4131,'75672','watch-mobile','header','catalog\\Paging','',3),(4132,'75681','watch-mobile','header','BlockBox','header-content',3),(4133,'75682','watch-mobile','block-4132','Menu','Categories',1),(4134,'75683','watch-mobile','block-4132-2','Search','',1),(4135,'75684','watch-mobile','block-4132-3','Account','',1),(4136,'75685','watch-mobile','block-4132-4','Cart','',1),(4137,'75686','watch-mobile','info','BlockBox','',1),(4138,'75687','watch-mobile','block-4137','info\\Content','',3),(4139,'75688','watch-mobile','block-4137','info\\Title','',2),(4140,'75689','watch-mobile','invoice','invoice\\Container','',1),(4141,'75690','watch-mobile','block-4140','BlockBox','',4),(4142,'75691','watch-mobile','block-4141','BlockBox','',1),(4143,'75692','watch-mobile','block-4142','invoice\\ShippingAddress','',2),(4144,'75693','watch-mobile','block-4142','Text','',1),(4145,'75694','watch-mobile','block-4141-2','BlockBox','',1),(4146,'75695','watch-mobile','block-4145','invoice\\Totals','',1),(4147,'75696','watch-mobile','block-4140','invoice\\Products','',3),(4148,'75697','watch-mobile','block-4140','BlockBox','',1),(4149,'75698','watch-mobile','block-4148','Logo','',1),(4150,'75699','watch-mobile','block-4148-2','BlockBox','',2),(4151,'75700','watch-mobile','block-4150','Text','',1),(4152,'75701','watch-mobile','block-4150-2','invoice\\StorePhone','',1),(4153,'75702','watch-mobile','block-4148-2','BlockBox','',1),(4154,'75703','watch-mobile','block-4153','invoice\\StoreAddress','',1),(4155,'75704','watch-mobile','block-4148-2','BlockBox','',4),(4156,'75705','watch-mobile','block-4155','Text','',1),(4157,'75706','watch-mobile','block-4155-2','invoice\\StoreSite','',1),(4158,'75707','watch-mobile','block-4148-2','BlockBox','',3),(4159,'75708','watch-mobile','block-4158','Text','',1),(4160,'75709','watch-mobile','block-4158-2','invoice\\StoreEmail','',1),(4161,'75710','watch-mobile','block-4140','BlockBox','',5),(4162,'75711','watch-mobile','block-4161','Text','',1),(4163,'75712','watch-mobile','block-4161','invoice\\StoreAddress','',8),(4164,'75713','watch-mobile','block-4161-2','Text','',2),(4165,'75714','watch-mobile','block-4161-2','Logo','',1),(4166,'75715','watch-mobile','block-4161-3','BlockBox','',3),(4167,'75716','watch-mobile','block-4166','Text','',1),(4168,'75717','watch-mobile','block-4166-2','invoice\\StoreEmail','',1),(4169,'75718','watch-mobile','block-4161-3','BlockBox','',2),(4170,'75719','watch-mobile','block-4169','Text','',1),(4171,'75720','watch-mobile','block-4169-2','invoice\\StorePhone','',1),(4172,'75721','watch-mobile','block-4161-3','Text','',1),(4173,'75722','watch-mobile','block-4140','BlockBox','',2),(4174,'75723','watch-mobile','block-4173','BlockBox','',8),(4175,'75724','watch-mobile','block-4174','BlockBox','',1),(4176,'75725','watch-mobile','block-4175','Text','',1),(4177,'75726','watch-mobile','block-4175','invoice\\ShippingMethod','',2),(4178,'75727','watch-mobile','block-4174-2','BlockBox','',1),(4179,'75728','watch-mobile','block-4178','invoice\\ShippingMethod','',2),(4180,'75729','watch-mobile','block-4178','Text','',1),(4181,'75730','watch-mobile','block-4173','BlockBox','',7),(4182,'75731','watch-mobile','block-4181','BlockBox','',1),(4183,'75732','watch-mobile','block-4182','Text','',1),(4184,'75733','watch-mobile','block-4182','invoice\\BillingAddress','',2),(4185,'75734','watch-mobile','block-4181-2','BlockBox','',1),(4186,'75735','watch-mobile','block-4185','invoice\\CustomerPhone','',4),(4187,'75736','watch-mobile','block-4185','Text','',1),(4188,'75737','watch-mobile','block-4185','invoice\\CustomerName','',2),(4189,'75738','watch-mobile','block-4185','Text','',3),(4190,'75739','watch-mobile','block-4185','Text','',5),(4191,'75740','watch-mobile','block-4185','invoice\\CustomerEmail','',6),(4192,'75741','watch-mobile','block-4173-2','invoice\\PaymentMethod','',5),(4193,'75742','watch-mobile','block-4173-2','invoice\\PaymentDate','',3),(4194,'75743','watch-mobile','block-4173-2','invoice\\OrderId','',1),(4195,'75744','watch-mobile','block-4173-2','invoice\\OrderBarcode','',6),(4196,'75745','watch-mobile','block-4173-2','Text','',2),(4197,'75746','watch-mobile','block-4173-2','Text','',4),(4198,'94802','watch-mobile','login_account','BlockBox','',1),(4199,'94803','watch-mobile','block-4198','Tabs','',2),(4200,'94804','watch-mobile','block-4199-1','login\\Returning','',1),(4201,'94809','watch-mobile','block-4199-2','login\\Register','',2),(4202,'94810','watch-mobile','block-4198','BlockBox','',1),(4203,'94811','watch-mobile','block-4202','Html_box','',3),(4204,'94812','watch-mobile','block-4202','Html_box','',1),(4205,'94813','watch-mobile','block-4202','login\\Socials','',2),(4206,'114547','watch-mobile','login_checkout','BlockBox','',1),(4207,'114548','watch-mobile','block-4206','BlockBox','',1),(4208,'114549','watch-mobile','block-4207','Html_box','',2),(4209,'114550','watch-mobile','block-4207','checkout\\CreateBtn','',5),(4210,'114551','watch-mobile','block-4207','checkout\\GuestBtn','',3),(4211,'114552','watch-mobile','block-4207','Html_box','',4),(4212,'114553','watch-mobile','block-4207','BlockBox','',6),(4213,'114554','watch-mobile','block-4212','Html_box','',1),(4214,'114555','watch-mobile','block-4212','login\\Socials','',2),(4215,'114556','watch-mobile','block-4207','login\\Returning','',1),(4216,'114557','watch-mobile','block-4207','Html_box','',1),(4217,'114558','watch-mobile','login_checkout2','BlockBox','',1),(4218,'114559','watch-mobile','block-4217','Html_box','',1),(4219,'114560','watch-mobile','block-4217','Html_box','',3),(4220,'114561','watch-mobile','block-4217','login\\Socials','',2),(4221,'114562','watch-mobile','block-4217','Tabs','',4),(4222,'114563','watch-mobile','block-4221-1','BlockBox','',1),(4223,'114564','watch-mobile','block-4222','Html_box','',1),(4224,'114565','watch-mobile','block-4222-2','BlockBox','',1),(4225,'114566','watch-mobile','block-4224','Html_box','',2),(4226,'114567','watch-mobile','block-4224','login\\Guest','',1),(4227,'114568','watch-mobile','block-4221-2','login\\Returning','',1),(4228,'114569','watch-mobile','block-4221-3','BlockBox','',1),(4229,'114570','watch-mobile','block-4228','Html_box','',1),(4230,'114571','watch-mobile','block-4228-2','BlockBox','',1),(4231,'114572','watch-mobile','block-4230','login\\Register','',1),(4232,'114573','watch-mobile','block-4230','Html_box','',2),(4233,'114574','watch-mobile','login_checkout2_q','BlockBox','',1),(4234,'114575','watch-mobile','block-4233','login\\Socials','',2),(4235,'114576','watch-mobile','block-4233','Html_box','',1),(4236,'114577','watch-mobile','block-4233','Html_box','',3),(4237,'114578','watch-mobile','block-4233','Tabs','',4),(4238,'114579','watch-mobile','block-4237-1','BlockBox','',1),(4239,'114580','watch-mobile','block-4238','Html_box','',1),(4240,'114581','watch-mobile','block-4238-2','quote\\FastOrder','',1),(4241,'114582','watch-mobile','block-4237-2','login\\Returning','',1),(4242,'114583','watch-mobile','block-4237-3','BlockBox','',1),(4243,'114584','watch-mobile','block-4242','Html_box','',1),(4244,'114585','watch-mobile','block-4242','Import','',2),(4245,'114586','watch-mobile','block-4242-2','BlockBox','',1),(4246,'114587','watch-mobile','block-4245','Html_box','',2),(4247,'114588','watch-mobile','block-4245','login\\Register','',1),(4248,'114589','watch-mobile','login_checkout2_s','BlockBox','',1),(4249,'114590','watch-mobile','block-4248','Html_box','',1),(4250,'114591','watch-mobile','block-4248','Tabs','',4),(4251,'114592','watch-mobile','block-4250-1','BlockBox','',1),(4252,'114593','watch-mobile','block-4251','Html_box','',1),(4253,'114594','watch-mobile','block-4251-2','quote\\FastOrder','',1),(4254,'114595','watch-mobile','block-4250-2','login\\Returning','',1),(4255,'114596','watch-mobile','block-4250-3','BlockBox','',1),(4256,'114597','watch-mobile','block-4255','Html_box','',1),(4257,'114598','watch-mobile','block-4255-2','BlockBox','',1),(4258,'114599','watch-mobile','block-4257','Html_box','',2),(4259,'114600','watch-mobile','block-4257','login\\Register','',1),(4260,'114601','watch-mobile','block-4248','login\\Socials','',2),(4261,'114602','watch-mobile','block-4248','Html_box','',3),(4262,'114603','watch-mobile','login_checkout_q','BlockBox','',1),(4263,'114604','watch-mobile','block-4262','BlockBox','',1),(4264,'114605','watch-mobile','block-4263','checkout\\CreateBtn','',5),(4265,'114606','watch-mobile','block-4263','checkout\\GuestBtn','',2),(4266,'114607','watch-mobile','block-4263','Html_box','',1),(4267,'114608','watch-mobile','block-4263','Html_box','',4),(4268,'114609','watch-mobile','block-4263','BlockBox','',6),(4269,'114610','watch-mobile','block-4268','login\\Socials','',2),(4270,'114611','watch-mobile','block-4268','Html_box','',1),(4271,'114612','watch-mobile','block-4263-2','login\\Returning','',2),(4272,'114613','watch-mobile','block-4263-2','Html_box','',1),(4273,'114614','watch-mobile','login_checkout_s','BlockBox','',1),(4274,'114615','watch-mobile','block-4273','BlockBox','',1),(4275,'114616','watch-mobile','block-4274','BlockBox','',5),(4276,'114617','watch-mobile','block-4275','Html_box','',1),(4277,'114618','watch-mobile','block-4275','login\\Socials','',2),(4278,'114619','watch-mobile','block-4274','Html_box','',3),(4279,'114620','watch-mobile','block-4274','checkout\\CreateBtn','',4),(4280,'114621','watch-mobile','block-4274','Html_box','',1),(4281,'114622','watch-mobile','block-4274','checkout\\GuestBtn','',2),(4282,'114623','watch-mobile','block-4274-2','Html_box','',1),(4283,'114624','watch-mobile','block-4274-2','login\\Returning','',2),(4284,'114625','watch-mobile','logoff','BlockBox','',1),(4285,'114626','watch-mobile','block-4284','Html_box','',1),(4286,'114627','watch-mobile','logoff_forever','BlockBox','',1),(4287,'114628','watch-mobile','block-4286','Html_box','',1),(4288,'75747','watch-mobile','main','BlockBox','main-content',5),(4289,'75748','watch-mobile','block-4288','TopCategories','',1),(4290,'75749','watch-mobile','block-4288','PromoCode','',2),(4291,'75750','watch-mobile','block-4288','Tabs','',3),(4292,'75751','watch-mobile','block-4291-1','NewProducts','4',1),(4293,'75752','watch-mobile','block-4291-2','SpecialsProducts','4',1),(4294,'75753','watch-mobile','block-4291-3','FeaturedProducts','4',1),(4295,'75754','watch-mobile','main','Heading','',2),(4296,'75755','watch-mobile','main','BlockBox','',6),(4297,'75756','watch-mobile','block-4296','BlockBox','',1),(4298,'75757','watch-mobile','block-4297','Bestsellers','10',1),(4299,'75758','watch-mobile','block-4297-2','Reviews','4',1),(4300,'114629','watch-mobile','manufacturers','BlockBox','',1),(4301,'114630','watch-mobile','block-4300','Html_box','',1),(4302,'114631','watch-mobile','block-4300','Brands','',2),(4303,'114632','watch-mobile','messages-index','BlockBox','',1),(4304,'114633','watch-mobile','block-4303','BlockBox','',1),(4305,'114634','watch-mobile','block-4304','BlockBox','',1),(4306,'114635','watch-mobile','block-4305','Messages\\Sidebar','',1),(4307,'114636','watch-mobile','block-4304-2','Messages\\Listing','',1),(4308,'114637','watch-mobile','messages-new','BlockBox','',1),(4309,'114638','watch-mobile','block-4308','BlockBox','',1),(4310,'114639','watch-mobile','block-4309','Messages\\Sidebar','',1),(4311,'114640','watch-mobile','block-4309-2','Messages\\NewMessage','',1),(4312,'114641','watch-mobile','messages-view','BlockBox','',1),(4313,'114642','watch-mobile','block-4312','BlockBox','',1),(4314,'114643','watch-mobile','block-4313','Messages\\Sidebar','',1),(4315,'114644','watch-mobile','block-4313-2','Messages\\Message','',1),(4316,'114645','watch-mobile','my_password','BlockBox','',1),(4317,'114646','watch-mobile','block-4316','BlockBox','',1),(4318,'114647','watch-mobile','block-4317','WidgetsAria','',1),(4319,'114648','watch-mobile','block-4317-2','account\\ChangePassword','',2),(4320,'114649','watch-mobile','block-4317-2','Html_box','',1),(4321,'114650','watch-mobile','block-4317-2','account\\AccountLink','',3),(4322,'114651','watch-mobile','need_login','BlockBox','',1),(4323,'114652','watch-mobile','block-4322','BlockBox','',1),(4324,'114653','watch-mobile','block-4322','Tabs','',2),(4325,'114654','watch-mobile','block-4324-1','login\\Returning','',1),(4326,'114655','watch-mobile','block-4324-2','BlockBox','',1),(4327,'114656','watch-mobile','block-4326','Html_box','',1),(4328,'114657','watch-mobile','block-4326-2','BlockBox','',1),(4329,'114658','watch-mobile','block-4328','login\\Register','',1),(4330,'114659','watch-mobile','block-4328','Html_box','',2),(4331,'114660','watch-mobile','new-topic','BlockBox','',1),(4332,'114661','watch-mobile','block-4331','Communication\\NewTopic','',3),(4333,'114662','watch-mobile','block-4331','Html_box','',1),(4334,'114663','watch-mobile','block-4331','Breadcrumb','',2),(4335,'114664','watch-mobile','nnnn','BlockBox','',1),(4336,'114665','watch-mobile','block-4335','catalog\\Title','',1),(4337,'114666','watch-mobile','block-4335','BlockBox','',2),(4338,'114667','watch-mobile','block-4337','Filters','',1),(4339,'114668','watch-mobile','block-4337-2','Listing','',5),(4340,'114669','watch-mobile','block-4337-2','catalog\\Image','',1),(4341,'114670','watch-mobile','block-4337-2','BlockBox','',6),(4342,'114671','watch-mobile','block-4341','catalog\\CountsItems','',1),(4343,'114672','watch-mobile','block-4341-2','catalog\\Paging','',1),(4344,'114673','watch-mobile','block-4337-2','catalog\\ImageMapCategory','',3),(4345,'114674','watch-mobile','block-4337-2','Categories','',2),(4346,'114675','watch-mobile','block-4337-2','BlockBox','',4),(4347,'114676','watch-mobile','block-4346','catalog\\ListingLook','',1),(4348,'114677','watch-mobile','block-4346','catalog\\ItemsOnPage','',4),(4349,'114678','watch-mobile','block-4346','catalog\\CompareButton','',2),(4350,'114679','watch-mobile','block-4346','catalog\\Sorting','',3),(4351,'114680','watch-mobile','no-logged','BlockBox','',1),(4352,'114681','watch-mobile','block-4351','Html_box','',1),(4353,'114682','watch-mobile','block-4351','Communication\\NewTopic','',2),(4354,'114683','watch-mobile','no_filters','BlockBox','',1),(4355,'114684','watch-mobile','block-4354','BlockBox','',2),(4356,'114685','watch-mobile','block-4355','catalog\\Image','',1),(4357,'114686','watch-mobile','block-4355','BlockBox','',2),(4358,'114687','watch-mobile','block-4357','catalog\\Sorting','',3),(4359,'114688','watch-mobile','block-4357','catalog\\ItemsOnPage','',4),(4360,'114689','watch-mobile','block-4357','HeaderStock','',5),(4361,'114690','watch-mobile','block-4357','catalog\\CompareButton','',2),(4362,'114691','watch-mobile','block-4357','catalog\\ListingLook','',1),(4363,'114692','watch-mobile','block-4354','BlockBox','',4),(4364,'114693','watch-mobile','block-4363','catalog\\CountsItems','',1),(4365,'114694','watch-mobile','block-4363-2','catalog\\Paging','',1),(4366,'114695','watch-mobile','block-4354','catalog\\B2bAddButton','',5),(4367,'114696','watch-mobile','block-4354','catalog\\Title','',1),(4368,'114697','watch-mobile','block-4354','Listing','',3),(4369,'114698','watch-mobile','order_history','BlockBox','',1),(4370,'114699','watch-mobile','block-4369','BlockBox','',1),(4371,'114700','watch-mobile','block-4370','WidgetsAria','',1),(4372,'114701','watch-mobile','block-4370-2','account\\OrdersHistory','',2),(4373,'114702','watch-mobile','block-4370-2','Html_box','',1),(4374,'114703','watch-mobile','order_history_info','BlockBox','',1),(4375,'114704','watch-mobile','block-4374','BlockBox','',1),(4376,'114705','watch-mobile','block-4375','WidgetsAria','',1),(4377,'114706','watch-mobile','block-4375-2','account\\OrderReorderButton','',2),(4378,'114707','watch-mobile','block-4375-2','BlockBox','',7),(4379,'114708','watch-mobile','block-4378','BlockBox','',3),(4380,'114709','watch-mobile','block-4379','account\\AccountLink','',3),(4381,'114710','watch-mobile','block-4379','Html_box','',1),(4382,'114711','watch-mobile','block-4379','account\\OrderTracking','',2),(4383,'114712','watch-mobile','block-4378','BlockBox','',2),(4384,'114713','watch-mobile','block-4383','Html_box','',1),(4385,'114714','watch-mobile','block-4383','account\\OrderData','',2),(4386,'114715','watch-mobile','block-4378','BlockBox','',1),(4387,'114716','watch-mobile','block-4386','account\\OrderData','',2),(4388,'114717','watch-mobile','block-4386','Html_box','',1),(4389,'114718','watch-mobile','block-4378-2','BlockBox','',1),(4390,'114719','watch-mobile','block-4389','Html_box','',1),(4391,'114720','watch-mobile','block-4389','account\\OrderData','',2),(4392,'114721','watch-mobile','block-4378-2','BlockBox','',2),(4393,'114722','watch-mobile','block-4392','Html_box','',1),(4394,'114723','watch-mobile','block-4392','account\\OrderData','',2),(4395,'114724','watch-mobile','block-4378-3','BlockBox','',1),(4396,'114725','watch-mobile','block-4395','Html_box','',1),(4397,'114726','watch-mobile','block-4395','account\\OrderData','',2),(4398,'114727','watch-mobile','block-4378-3','BlockBox','',2),(4399,'114728','watch-mobile','block-4398','Html_box','',1),(4400,'114729','watch-mobile','block-4398','account\\OrderData','',2),(4401,'114730','watch-mobile','block-4375-2','account\\OrderDownload','',6),(4402,'114731','watch-mobile','block-4375-2','account\\OrderProducts','',9),(4403,'114732','watch-mobile','block-4375-2','Html_box','',11),(4404,'114733','watch-mobile','block-4375-2','account\\OrderHeading','',1),(4405,'114734','watch-mobile','block-4375-2','account\\OrderHistory','',12),(4406,'114735','watch-mobile','block-4375-2','account\\OrderCancelAndReorder','',4),(4407,'114736','watch-mobile','block-4375-2','Html_box','',8),(4408,'114737','watch-mobile','block-4375-2','account\\OrderSubTotals','',10),(4409,'114738','watch-mobile','block-4375-2','account\\OrderPayButton','',5),(4410,'114739','watch-mobile','block-4375-2','account\\OrderInvoiceButton','',3),(4411,'114740','watch-mobile','block-4375-2','BlockBox','',13),(4412,'114741','watch-mobile','block-4411','account\\AccountLink','',1),(4413,'114742','watch-mobile','block-4411-2','account\\OrderInvoiceButton','',1),(4414,'114743','watch-mobile','order_pay','BlockBox','',1),(4415,'114744','watch-mobile','block-4414','BlockBox','',1),(4416,'114745','watch-mobile','block-4415','WidgetsAria','',1),(4417,'114746','watch-mobile','block-4415-2','account\\OrderSubTotals','',5),(4418,'114747','watch-mobile','block-4415-2','account\\OrderHeading','',1),(4419,'114748','watch-mobile','block-4415-2','Html_box','',3),(4420,'114749','watch-mobile','block-4415-2','UpdateAndPay\\PayForm','',6),(4421,'114750','watch-mobile','block-4415-2','BlockBox','',2),(4422,'114751','watch-mobile','block-4421','BlockBox','',4),(4423,'114752','watch-mobile','block-4422','Html_box','',1),(4424,'114753','watch-mobile','block-4422','account\\OrderData','',2),(4425,'114754','watch-mobile','block-4421','BlockBox','',1),(4426,'114755','watch-mobile','block-4425','Html_box','',1),(4427,'114756','watch-mobile','block-4425','account\\OrderData','',2),(4428,'114757','watch-mobile','block-4421-2','BlockBox','',2),(4429,'114758','watch-mobile','block-4428','account\\OrderData','',2),(4430,'114759','watch-mobile','block-4428','Html_box','',1),(4431,'114760','watch-mobile','block-4421-2','BlockBox','',1),(4432,'114761','watch-mobile','block-4431','Html_box','',1),(4433,'114762','watch-mobile','block-4431','account\\OrderData','',2),(4434,'114763','watch-mobile','block-4421-3','BlockBox','',2),(4435,'114764','watch-mobile','block-4434','Html_box','',1),(4436,'114765','watch-mobile','block-4434','account\\OrderData','',2),(4437,'114766','watch-mobile','block-4421-3','BlockBox','',1),(4438,'114767','watch-mobile','block-4437','account\\OrderData','',2),(4439,'114768','watch-mobile','block-4437','Html_box','',1),(4440,'114769','watch-mobile','block-4415-2','account\\OrderProducts','',4),(4441,'75759','watch-mobile','packingslip','invoice\\Container','',2),(4442,'75760','watch-mobile','block-4441','packingslip\\Products','',3),(4443,'75761','watch-mobile','block-4441','BlockBox','',2),(4444,'75762','watch-mobile','block-4443','BlockBox','',2),(4445,'75763','watch-mobile','block-4444','BlockBox','',1),(4446,'75764','watch-mobile','block-4445','Text','',1),(4447,'75765','watch-mobile','block-4445','invoice\\ShippingAddress','',2),(4448,'75766','watch-mobile','block-4444-2','BlockBox','',1),(4449,'75767','watch-mobile','block-4448','invoice\\CustomerEmail','',6),(4450,'75768','watch-mobile','block-4448','invoice\\CustomerName','',2),(4451,'75769','watch-mobile','block-4448','invoice\\CustomerPhone','',4),(4452,'75770','watch-mobile','block-4448','Text','',5),(4453,'75771','watch-mobile','block-4448','Text','',1),(4454,'75772','watch-mobile','block-4448','Text','',3),(4455,'75773','watch-mobile','block-4443','BlockBox','',3),(4456,'75774','watch-mobile','block-4455','BlockBox','',1),(4457,'75775','watch-mobile','block-4456','invoice\\ShippingMethod','',2),(4458,'75776','watch-mobile','block-4456','Text','',1),(4459,'75777','watch-mobile','block-4455-2','BlockBox','',1),(4460,'75778','watch-mobile','block-4459','Text','',1),(4461,'75779','watch-mobile','block-4459','invoice\\ShippingMethod','',2),(4462,'75780','watch-mobile','block-4443-2','invoice\\AddressQrcode','',1),(4463,'75781','watch-mobile','block-4441','BlockBox','',4),(4464,'75782','watch-mobile','block-4463','Text','',1),(4465,'75783','watch-mobile','block-4463','invoice\\StoreAddress','',2),(4466,'75784','watch-mobile','block-4441','BlockBox','',1),(4467,'75785','watch-mobile','block-4466','Logo','',1),(4468,'75786','watch-mobile','block-4466-2','BlockBox','',1),(4469,'75787','watch-mobile','block-4468','invoice\\StoreAddress','',1),(4470,'75788','watch-mobile','block-4466-2','BlockBox','',2),(4471,'75789','watch-mobile','block-4470','Text','',2),(4472,'75790','watch-mobile','block-4470-2','invoice\\StorePhone','',1),(4473,'75791','watch-mobile','block-4466-2','BlockBox','',4),(4474,'75792','watch-mobile','block-4473','Text','',2),(4475,'75793','watch-mobile','block-4473-2','invoice\\StoreSite','',1),(4476,'75794','watch-mobile','block-4466-2','BlockBox','',3),(4477,'75795','watch-mobile','block-4476','Text','',2),(4478,'75796','watch-mobile','block-4476-2','invoice\\StoreEmail','',1),(4479,'114770','watch-mobile','password_forgotten','BlockBox','',1),(4480,'114771','watch-mobile','block-4479','Html_box','',1),(4481,'114772','watch-mobile','block-4479','BlockBox','',2),(4482,'114773','watch-mobile','block-4481-2','login\\PasswordForgotten','',2),(4483,'114774','watch-mobile','block-4481-2','Html_box','',1),(4484,'75797','watch-mobile','pdf','invoice\\Container','',1),(4485,'75798','watch-mobile','block-4484','BlockBox','',1),(4486,'75799','watch-mobile','block-4485','BlockBox','',1),(4487,'75800','watch-mobile','block-4486','BlockBox','',2),(4488,'75801','watch-mobile','block-4487','pdf\\ProductElement','',1),(4489,'75802','watch-mobile','block-4487-2','pdf\\ProductElement','',2),(4490,'75803','watch-mobile','block-4487-2','pdf\\ProductElement','',1),(4491,'75804','watch-mobile','block-4486','BlockBox','',1),(4492,'75805','watch-mobile','block-4491','pdf\\ProductElement','',1),(4493,'75806','watch-mobile','block-4485-2','BlockBox','',1),(4494,'75807','watch-mobile','block-4493','BlockBox','',1),(4495,'75808','watch-mobile','block-4494','pdf\\ProductElement','',1),(4496,'75809','watch-mobile','block-4493','BlockBox','',2),(4497,'75810','watch-mobile','block-4496','pdf\\ProductElement','',1),(4498,'75811','watch-mobile','block-4496-2','pdf\\ProductElement','',2),(4499,'75812','watch-mobile','block-4496-2','pdf\\ProductElement','',1),(4500,'75813','watch-mobile','pdf_category','pdf\\CategoryName','',2),(4501,'75814','watch-mobile','pdf_category','pdf\\CategoryImage','',1),(4502,'75815','watch-mobile','pdf_cover','invoice\\Container','',1),(4503,'75816','watch-mobile','block-4502','Logo','',1),(4504,'75817','watch-mobile','block-4502','Text','',3),(4505,'75818','watch-mobile','pdf_footer','BlockBox','',1),(4506,'75819','watch-mobile','block-4505-2','pdf\\PageNumber','',1),(4507,'75820','watch-mobile','pdf_header','pdf\\CategoryName','',1),(4508,'114775','watch-mobile','personal_catalog','BlockBox','',1),(4509,'114776','watch-mobile','block-4508','BlockBox','',1),(4510,'114777','watch-mobile','block-4509','WidgetsAria','',1),(4511,'114778','watch-mobile','block-4509-2','Html_box','',1),(4512,'114779','watch-mobile','block-4509-2','account\\PersonalCatalog','',2),(4513,'114780','watch-mobile','points_earnt_history','BlockBox','',1),(4514,'114781','watch-mobile','block-4513','Html_box','',1),(4515,'114782','watch-mobile','block-4513','account\\PointsEarntHistory','',2),(4516,'114783','watch-mobile','posts','BlockBox','',1),(4517,'114784','watch-mobile','block-4516','Breadcrumb','',2),(4518,'114785','watch-mobile','block-4516','Communication\\Post','',3),(4519,'114786','watch-mobile','block-4516','Html_box','',1),(4520,'75821','watch-mobile','product','BlockBox','',1),(4521,'75822','watch-mobile','block-4520','BlockBox','',5),(4522,'75823','watch-mobile','block-4521','product\\Stock','',2),(4523,'75824','watch-mobile','block-4521','product\\Price','',1),(4524,'75825','watch-mobile','block-4521-2','product\\Quantity','',1),(4525,'75826','watch-mobile','block-4520','product\\Bundle','',6),(4526,'75827','watch-mobile','block-4520','product\\Video','',3),(4527,'75828','watch-mobile','block-4520','product\\Documents','',16),(4528,'75829','watch-mobile','block-4520','product\\Buttons','',7),(4529,'75830','watch-mobile','block-4520','product\\Images','',2),(4530,'75831','watch-mobile','block-4520','product\\Name','',1),(4531,'75832','watch-mobile','block-4520','BlockBox','',8),(4532,'75833','watch-mobile','block-4531','product\\WishlistButton','',1),(4533,'75834','watch-mobile','block-4531','product\\PersonalCatalogButton','',2),(4534,'75835','watch-mobile','block-4531','product\\WeddingRegistryButton','',3),(4535,'75836','watch-mobile','block-4520','product\\BonusPoints','',9),(4536,'75837','watch-mobile','block-4520','product\\CrossSell','',13),(4537,'75838','watch-mobile','block-4520','product\\AlsoPurchased','10',11),(4538,'75839','watch-mobile','block-4520','product\\InBundles','',14),(4539,'75840','watch-mobile','block-4520','Tabs','',12),(4540,'75841','watch-mobile','block-4539-1','product\\Description','',1),(4541,'75842','watch-mobile','block-4539-1','product\\Properties','',2),(4542,'75843','watch-mobile','block-4539-2','product\\Reviews','',1),(4543,'75844','watch-mobile','block-4520','product\\Attributes','',4),(4544,'75845','watch-mobile','block-4520','product\\Configurator','',10),(4545,'75846','watch-mobile','block-4520','ViewedProducts','',15),(4546,'75847','watch-mobile','product-bottom','product\\Properties','',1),(4547,'75848','watch-mobile','product-tabs','product\\Reviews','',2),(4548,'75849','watch-mobile','product-tabs','product\\Description','',1),(4549,'75850','watch-mobile','product-top-left','product\\Images','',1),(4550,'75851','watch-mobile','product-top-right','product\\Attributes','',3),(4551,'75852','watch-mobile','product-top-right','product\\Buttons','',6),(4552,'75853','watch-mobile','product-top-right','product\\Quantity','',6),(4553,'75854','watch-mobile','product-top-right','product\\Quantity','',5),(4554,'75855','watch-mobile','product-top-right','product\\Name','',1),(4555,'75856','watch-mobile','product-top-right','product\\Price','',2),(4556,'75888','watch-mobile','productListing','BlockBox','listing-item',1),(4557,'75890','watch-mobile','block-4556','productListing\\model','',7),(4558,'75891','watch-mobile','block-4556','productListing\\bonusPoints','',6),(4559,'75892','watch-mobile','block-4556','productListing\\description','',5),(4560,'75893','watch-mobile','block-4556','productListing\\buyButton','',9),(4561,'75894','watch-mobile','block-4556','productListing\\rating','',3),(4562,'75895','watch-mobile','block-4556','productListing\\image','',1),(4563,'75896','watch-mobile','block-4556','BlockBox','',8),(4564,'75897','watch-mobile','block-4563','productListing\\price','',1),(4565,'75898','watch-mobile','block-4563-2','productListing\\qtyInput','',1),(4566,'75899','watch-mobile','block-4556','productListing\\name','',4),(4567,'75900','watch-mobile','block-4556','productListing\\stock','',2),(4568,'75857','watch-mobile','products','BlockBox','catalog-content',1),(4569,'75858','watch-mobile','block-4568','Filters','',3),(4570,'75859','watch-mobile','block-4568','catalog\\Paging','',5),(4571,'75860','watch-mobile','block-4568','catalog\\Title','',1),(4572,'75861','watch-mobile','block-4568','catalog\\Image','',2),(4573,'75862','watch-mobile','block-4568','BlockBox','catalog-features',4),(4574,'75863','watch-mobile','block-4573','catalog\\Sorting','',1),(4575,'75864','watch-mobile','block-4573-2','catalog\\CountsItems','',1),(4576,'75865','watch-mobile','block-4568','Listing','',7),(4577,'114787','watch-mobile','products-list','packingslip\\AllProductsList','',2),(4578,'114788','watch-mobile','promotions','BlockBox','',1),(4579,'114789','watch-mobile','block-4578','promotions\\PromoList','',2),(4580,'114790','watch-mobile','block-4578','Html_box','',1),(4581,'114791','watch-mobile','purchase','invoice\\Container','',1),(4582,'114792','watch-mobile','block-4581','BlockBox','',4),(4583,'114793','watch-mobile','block-4582','BlockBox','',1),(4584,'114794','watch-mobile','block-4583','Text','',1),(4585,'114795','watch-mobile','block-4583','invoice\\ShippingAddress','',2),(4586,'114796','watch-mobile','block-4581','BlockBox','',2),(4587,'114797','watch-mobile','block-4586','BlockBox','',7),(4588,'114798','watch-mobile','block-4587','BlockBox','',1),(4589,'114799','watch-mobile','block-4588','Text','',1),(4590,'114800','watch-mobile','block-4588','invoice\\BillingAddress','',2),(4591,'114801','watch-mobile','block-4587-2','BlockBox','',1),(4592,'114802','watch-mobile','block-4591','Text','',1),(4593,'114803','watch-mobile','block-4591','Text','',3),(4594,'114804','watch-mobile','block-4591','Text','',5),(4595,'114805','watch-mobile','block-4591','invoice\\CustomerName','',2),(4596,'114806','watch-mobile','block-4591','invoice\\CustomerPhone','',4),(4597,'114807','watch-mobile','block-4591','invoice\\CustomerEmail','',6),(4598,'114808','watch-mobile','block-4586-2','Text','',2),(4599,'114809','watch-mobile','block-4586-2','invoice\\PaymentDate','',3),(4600,'114810','watch-mobile','block-4586-2','invoice\\OrderId','',1),(4601,'114811','watch-mobile','block-4581','BlockBox','',1),(4602,'114812','watch-mobile','block-4601','Logo','',1),(4603,'114813','watch-mobile','block-4601-2','BlockBox','',1),(4604,'114814','watch-mobile','block-4603','invoice\\StoreAddress','',1),(4605,'114815','watch-mobile','block-4601-2','BlockBox','',3),(4606,'114816','watch-mobile','block-4605','Text','',1),(4607,'114817','watch-mobile','block-4605-2','invoice\\StoreEmail','',1),(4608,'114818','watch-mobile','block-4601-2','BlockBox','',4),(4609,'114819','watch-mobile','block-4608','Text','',1),(4610,'114820','watch-mobile','block-4608-2','invoice\\StoreSite','',1),(4611,'114821','watch-mobile','block-4601-2','BlockBox','',2),(4612,'114822','watch-mobile','block-4611','Text','',1),(4613,'114823','watch-mobile','block-4611-2','invoice\\StorePhone','',1),(4614,'114824','watch-mobile','block-4581','BlockBox','',5),(4615,'114825','watch-mobile','block-4614','invoice\\StoreAddress','',8),(4616,'114826','watch-mobile','block-4614','Text','',1),(4617,'114827','watch-mobile','block-4614-2','Text','',2),(4618,'114828','watch-mobile','block-4614-2','Logo','',1),(4619,'114829','watch-mobile','block-4614-3','BlockBox','',2),(4620,'114830','watch-mobile','block-4619','Text','',1),(4621,'114831','watch-mobile','block-4619-2','invoice\\StorePhone','',1),(4622,'114832','watch-mobile','block-4614-3','Text','',1),(4623,'114833','watch-mobile','block-4614-3','BlockBox','',3),(4624,'114834','watch-mobile','block-4623','Text','',1),(4625,'114835','watch-mobile','block-4623-2','invoice\\StoreEmail','',1),(4626,'114836','watch-mobile','block-4581','invoice\\Products','',3),(4627,'114837','watch-mobile','quotations','BlockBox','',1),(4628,'114838','watch-mobile','block-4627','BlockBox','',1),(4629,'114839','watch-mobile','block-4628','WidgetsAria','',1),(4630,'114840','watch-mobile','block-4628-2','Html_box','',1),(4631,'114841','watch-mobile','block-4628-2','Quotations\\QuotationsHistory','',2),(4632,'114842','watch-mobile','quotation_info','BlockBox','',1),(4633,'114843','watch-mobile','block-4632','BlockBox','',1),(4634,'114844','watch-mobile','block-4633','WidgetsAria','',1),(4635,'114845','watch-mobile','block-4633-2','Quotations\\QuotationHistory','',10),(4636,'114846','watch-mobile','block-4633-2','Quotations\\QuotationProducts','',7),(4637,'114847','watch-mobile','block-4633-2','Html_box','',9),(4638,'114848','watch-mobile','block-4633-2','Html_box','',6),(4639,'114849','watch-mobile','block-4633-2','Quotations\\QuotationSubTotal','',8),(4640,'114850','watch-mobile','block-4633-2','Html_box','',4),(4641,'114851','watch-mobile','block-4633-2','BlockBox','',12),(4642,'114852','watch-mobile','block-4641','account\\AccountLink','',1),(4643,'114853','watch-mobile','block-4633-2','BlockBox','',5),(4644,'114854','watch-mobile','block-4643','BlockBox','',4),(4645,'114855','watch-mobile','block-4644','Html_box','',1),(4646,'114856','watch-mobile','block-4644','Quotations\\QuotationData','',2),(4647,'114857','watch-mobile','block-4643','BlockBox','',1),(4648,'114858','watch-mobile','block-4647','Quotations\\QuotationData','',2),(4649,'114859','watch-mobile','block-4647','Html_box','',1),(4650,'114860','watch-mobile','block-4643-2','BlockBox','',2),(4651,'114861','watch-mobile','block-4650','Html_box','',1),(4652,'114862','watch-mobile','block-4650','Quotations\\QuotationData','',2),(4653,'114863','watch-mobile','block-4643-2','BlockBox','',1),(4654,'114864','watch-mobile','block-4653','Html_box','',1),(4655,'114865','watch-mobile','block-4653','Quotations\\QuotationData','',2),(4656,'114866','watch-mobile','block-4643-3','BlockBox','',1),(4657,'114867','watch-mobile','block-4656','Html_box','',1),(4658,'114868','watch-mobile','block-4656','Quotations\\QuotationData','',2),(4659,'114869','watch-mobile','block-4643-3','BlockBox','',2),(4660,'114870','watch-mobile','block-4659','Quotations\\QuotationData','',2),(4661,'114871','watch-mobile','block-4659','Html_box','',1),(4662,'75866','watch-mobile','quote','quote\\CheckoutBtn','',3),(4663,'75867','watch-mobile','quote','quote\\Products','',2),(4664,'75868','watch-mobile','quote','Text','',1),(4665,'114872','watch-mobile','review','BlockBox','',1),(4666,'114873','watch-mobile','block-4665','BlockBox','',1),(4667,'114874','watch-mobile','block-4666','WidgetsAria','',1),(4668,'114875','watch-mobile','block-4666-2','Html_box','',1),(4669,'114876','watch-mobile','block-4666-2','account\\Reviews','',2),(4670,'114877','watch-mobile','reviews','BlockBox','',1),(4671,'114878','watch-mobile','block-4670','reviews\\Content','',2),(4672,'114879','watch-mobile','block-4670','reviews\\Heading','',1),(4673,'114880','watch-mobile','rma_document','invoice\\Container','',1),(4674,'114881','watch-mobile','block-4673','BlockBox','',3),(4675,'114882','watch-mobile','block-4674','BlockBox','',1),(4676,'114883','watch-mobile','block-4675','BlockBox','',1),(4677,'114884','watch-mobile','block-4676','BlockBox','',6),(4678,'114885','watch-mobile','block-4677','Html_box','',1),(4679,'114886','watch-mobile','block-4676','BlockBox','',3),(4680,'114887','watch-mobile','block-4679','Html_box','',1),(4681,'114888','watch-mobile','block-4679-2','Html_box','',1),(4682,'114889','watch-mobile','block-4676','BlockBox','',1),(4683,'114890','watch-mobile','block-4682','Html_box','',1),(4684,'114891','watch-mobile','block-4676','BlockBox','',2),(4685,'114892','watch-mobile','block-4684','Html_box','',1),(4686,'114893','watch-mobile','block-4684-2','Html_box','',1),(4687,'114894','watch-mobile','block-4676','BlockBox','',4),(4688,'114895','watch-mobile','block-4687','Html_box','',1),(4689,'114896','watch-mobile','block-4687-2','Html_box','',1),(4690,'114897','watch-mobile','block-4676','BlockBox','',5),(4691,'114898','watch-mobile','block-4690','Html_box','',1),(4692,'114899','watch-mobile','block-4690-2','Html_box','',1),(4693,'114900','watch-mobile','block-4690-2','invoice\\StoreAddress','',2),(4694,'114901','watch-mobile','block-4675-2','BlockBox','',3),(4695,'114902','watch-mobile','block-4694','Html_box','',1),(4696,'114903','watch-mobile','block-4694-2','Html_box','',1),(4697,'114904','watch-mobile','block-4694-3','BlockBox','',1),(4698,'114905','watch-mobile','block-4697','Html_box','',1),(4699,'114906','watch-mobile','block-4697-2','Html_box','',1),(4700,'114907','watch-mobile','block-4675-2','BlockBox','',4),(4701,'114908','watch-mobile','block-4700','Html_box','',1),(4702,'114909','watch-mobile','block-4700-2','Html_box','',1),(4703,'114910','watch-mobile','block-4700-3','BlockBox','',1),(4704,'114911','watch-mobile','block-4703','Html_box','',1),(4705,'114912','watch-mobile','block-4703-2','Html_box','',1),(4706,'114913','watch-mobile','block-4675-2','BlockBox','',2),(4707,'114914','watch-mobile','block-4706','Html_box','',1),(4708,'114915','watch-mobile','block-4706','Html_box','',2),(4709,'114916','watch-mobile','block-4706','Html_box','',3),(4710,'114917','watch-mobile','block-4706','Html_box','',4),(4711,'114918','watch-mobile','block-4706','Html_box','',5),(4712,'114919','watch-mobile','block-4675-2','BlockBox','',1),(4713,'114920','watch-mobile','block-4712','BlockBox','',1),(4714,'114921','watch-mobile','block-4713','BlockBox','',1),(4715,'114922','watch-mobile','block-4714','Rma\\DocumentData','',2),(4716,'114923','watch-mobile','block-4714-3','BlockBox','',1),(4717,'114924','watch-mobile','block-4716','Html_box','',1),(4718,'114925','watch-mobile','block-4716-2','Rma\\DocumentData','',1),(4719,'114926','watch-mobile','block-4713','BlockBox','',2),(4720,'114927','watch-mobile','block-4719-2','invoice\\StoreAddress','',1),(4721,'114928','watch-mobile','block-4673','BlockBox','',2),(4722,'114929','watch-mobile','block-4721','Rma\\Products','',2),(4723,'114930','watch-mobile','block-4721','Html_box','',1),(4724,'114931','watch-mobile','block-4673','BlockBox','',1),(4725,'114932','watch-mobile','block-4724','BlockBox','',1),(4726,'114933','watch-mobile','block-4725','BlockBox','',1),(4727,'114934','watch-mobile','block-4726','Html_box','',2),(4728,'114935','watch-mobile','block-4726','Html_box','',1),(4729,'114936','watch-mobile','block-4725','BlockBox','',3),(4730,'114937','watch-mobile','block-4729','Html_box','',1),(4731,'114938','watch-mobile','block-4729-2','Html_box','',1),(4732,'114939','watch-mobile','block-4725','BlockBox','',2),(4733,'114940','watch-mobile','block-4732','Html_box','',1),(4734,'114941','watch-mobile','block-4732-2','Html_box','',1),(4735,'114942','watch-mobile','block-4725','BlockBox','',4),(4736,'114943','watch-mobile','block-4735','Html_box','',1),(4737,'114944','watch-mobile','block-4735-2','Html_box','',1),(4738,'114945','watch-mobile','block-4725','BlockBox','',5),(4739,'114946','watch-mobile','block-4738','Html_box','',1),(4740,'114947','watch-mobile','block-4738-2','Html_box','',1),(4741,'114948','watch-mobile','block-4724-2','BlockBox','',3),(4742,'114949','watch-mobile','block-4741','BlockBox','',1),(4743,'114950','watch-mobile','block-4742','Html_box','',1),(4744,'114951','watch-mobile','block-4742-2','Rma\\DocumentData','',1),(4745,'114952','watch-mobile','block-4741-2','BlockBox','',1),(4746,'114953','watch-mobile','block-4745','Html_box','',1),(4747,'114954','watch-mobile','block-4745-2','Rma\\DocumentData','',1),(4748,'114955','watch-mobile','block-4724-2','BlockBox','',2),(4749,'114956','watch-mobile','block-4748','BlockBox','',1),(4750,'114957','watch-mobile','block-4749','BlockBox','',1),(4751,'114958','watch-mobile','block-4750','Html_box','',1),(4752,'114959','watch-mobile','block-4750-2','Rma\\DocumentData','',1),(4753,'114960','watch-mobile','block-4749-2','BlockBox','',1),(4754,'114961','watch-mobile','block-4753','Html_box','',1),(4755,'114962','watch-mobile','block-4753-2','Rma\\DocumentData','',1),(4756,'114963','watch-mobile','block-4748','BlockBox','',2),(4757,'114964','watch-mobile','block-4756','Html_box','',1),(4758,'114965','watch-mobile','block-4756-2','Rma\\DocumentData','',1),(4759,'114966','watch-mobile','block-4748','BlockBox','',3),(4760,'114967','watch-mobile','block-4759','BlockBox','',1),(4761,'114968','watch-mobile','block-4760','Html_box','',1),(4762,'114969','watch-mobile','block-4760-2','Rma\\DocumentData','',1),(4763,'114970','watch-mobile','block-4759-2','BlockBox','',1),(4764,'114971','watch-mobile','block-4763','Html_box','',1),(4765,'114972','watch-mobile','block-4763-2','Rma\\DocumentData','',1),(4766,'114973','watch-mobile','block-4748','BlockBox','',4),(4767,'114974','watch-mobile','block-4766','BlockBox','',1),(4768,'114975','watch-mobile','block-4767','Html_box','',1),(4769,'114976','watch-mobile','block-4767-2','Rma\\DocumentData','',1),(4770,'114977','watch-mobile','block-4766-2','BlockBox','',1),(4771,'114978','watch-mobile','block-4770','Html_box','',1),(4772,'114979','watch-mobile','block-4770-2','Rma\\DocumentData','',1),(4773,'114980','watch-mobile','block-4748','BlockBox','',5),(4774,'114981','watch-mobile','block-4773','BlockBox','',1),(4775,'114982','watch-mobile','block-4774','Html_box','',1),(4776,'114983','watch-mobile','block-4774-2','Rma\\DocumentData','',1),(4777,'114984','watch-mobile','block-4773-2','BlockBox','',1),(4778,'114985','watch-mobile','block-4777','Html_box','',1),(4779,'114986','watch-mobile','block-4777-2','Rma\\DocumentData','',1),(4780,'114987','watch-mobile','block-4724-2','BlockBox','',1),(4781,'114988','watch-mobile','block-4780','Logo','',1),(4782,'114989','watch-mobile','block-4780','Html_box','',2),(4783,'114990','watch-mobile','rows','BlockBox','listing-item',1),(4784,'114991','watch-mobile','block-4783','BlockBox','',2),(4785,'114992','watch-mobile','block-4784','BlockBox','',2),(4786,'114993','watch-mobile','block-4785','BlockBox','',3),(4787,'114994','watch-mobile','block-4786','productListing\\rating','',1),(4788,'114995','watch-mobile','block-4786','productListing\\ratingCounts','',2),(4789,'114996','watch-mobile','block-4785','productListing\\bonusPoints','',1),(4790,'114997','watch-mobile','block-4785','productListing\\image','',2),(4791,'114998','watch-mobile','block-4785-2','productListing\\model','',3),(4792,'114999','watch-mobile','block-4785-2','productListing\\name','',1),(4793,'115000','watch-mobile','block-4785-2','productListing\\description','',2),(4794,'115001','watch-mobile','block-4785-2','productListing\\attributes','',4),(4795,'115002','watch-mobile','block-4784-2','BlockBox','',1),(4796,'115003','watch-mobile','block-4795','productListing\\stock','',1),(4797,'115004','watch-mobile','block-4795','productListing\\price','',2),(4798,'115005','watch-mobile','block-4795','productListing\\wishlistButton','',6),(4799,'115006','watch-mobile','block-4795','productListing\\qtyInput','',3),(4800,'115007','watch-mobile','block-4795','productListing\\compare','',5),(4801,'115008','watch-mobile','block-4795','productListing\\buyButton','',4),(4802,'75869','watch-mobile','sample','BlockBox','',1),(4803,'75870','watch-mobile','block-4802','sample\\Products','',2),(4804,'75871','watch-mobile','block-4802','sample\\CheckoutBtn','',3),(4805,'75872','watch-mobile','block-4802','Text','',1),(4806,'115009','watch-mobile','samples','BlockBox','',1),(4807,'115010','watch-mobile','block-4806','BlockBox','',1),(4808,'115011','watch-mobile','block-4807','WidgetsAria','',1),(4809,'115012','watch-mobile','block-4807-2','Html_box','',1),(4810,'115013','watch-mobile','block-4807-2','Samples\\SamplesHistory','',2),(4811,'115014','watch-mobile','sample_info','BlockBox','',1),(4812,'115015','watch-mobile','block-4811','BlockBox','',1),(4813,'115016','watch-mobile','block-4812','WidgetsAria','',1),(4814,'115017','watch-mobile','block-4812-2','Html_box','',6),(4815,'115018','watch-mobile','block-4812-2','BlockBox','',2),(4816,'115019','watch-mobile','block-4815','BlockBox','',4),(4817,'115020','watch-mobile','block-4816','Html_box','',1),(4818,'115021','watch-mobile','block-4816','Samples\\SampleData','',2),(4819,'115022','watch-mobile','block-4815','BlockBox','',1),(4820,'115023','watch-mobile','block-4819','Samples\\SampleData','',2),(4821,'115024','watch-mobile','block-4819','Html_box','',1),(4822,'115025','watch-mobile','block-4815-2','BlockBox','',1),(4823,'115026','watch-mobile','block-4822','Html_box','',1),(4824,'115027','watch-mobile','block-4822','Samples\\SampleData','',2),(4825,'115028','watch-mobile','block-4815-2','BlockBox','',2),(4826,'115029','watch-mobile','block-4825','Samples\\SampleData','',2),(4827,'115030','watch-mobile','block-4825','Html_box','',1),(4828,'115031','watch-mobile','block-4815-3','BlockBox','',1),(4829,'115032','watch-mobile','block-4828','Html_box','',1),(4830,'115033','watch-mobile','block-4828','Samples\\SampleData','',2),(4831,'115034','watch-mobile','block-4815-3','BlockBox','',2),(4832,'115035','watch-mobile','block-4831','Samples\\SampleData','',2),(4833,'115036','watch-mobile','block-4831','Html_box','',1),(4834,'115037','watch-mobile','block-4812-2','Html_box','',3),(4835,'115038','watch-mobile','block-4812-2','Samples\\SampleProducts','',4),(4836,'115039','watch-mobile','block-4812-2','Samples\\SampleSubTotal','',5),(4837,'115040','watch-mobile','block-4812-2','BlockBox','',8),(4838,'115041','watch-mobile','block-4837','account\\AccountLink','',1),(4839,'115042','watch-mobile','block-4812-2','Samples\\SampleHistory','',7),(4840,'115043','watch-mobile','block-4812-2','Html_box','',1),(4841,'115715','watch-mobile','sample_info','BlockBox','',1),(4842,'115716','watch-mobile','block-4841','BlockBox','',1),(4843,'115717','watch-mobile','block-4842','WidgetsAria','',1),(4844,'115718','watch-mobile','block-4842-2','Html_box','',3),(4845,'115719','watch-mobile','block-4842-2','account\\OrdersHistory','',4),(4846,'115720','watch-mobile','block-4842-2','Html_box','',1),(4847,'115721','watch-mobile','block-4842-2','BlockBox','',2),(4848,'115722','watch-mobile','block-4847','Html_box','',1),(4849,'115723','watch-mobile','block-4847','account\\LastOrder','',2),(4850,'115724','watch-mobile','block-4847-2','Html_box','',1),(4851,'115725','watch-mobile','block-4847-2','account\\AccountLink','',3),(4852,'115726','watch-mobile','block-4847-2','account\\OrderCount','',2),(4853,'115727','watch-mobile','block-4847-3','Html_box','',1),(4854,'115728','watch-mobile','block-4847-3','account\\TotalOrdered','',2),(4855,'115729','watch-mobile','block-4847-4','Html_box','',1),(4856,'115730','watch-mobile','block-4847-4','account\\AccountLink','',3),(4857,'115731','watch-mobile','block-4847-4','account\\CreditAmount','',2),(4858,'115732','watch-mobile','block-4847-5','account\\AccountLink','',3),(4859,'115733','watch-mobile','block-4847-5','account\\PointsEarnt','',2),(4860,'115734','watch-mobile','block-4847-5','Html_box','',1),(4861,'115735','watch-mobile','block-4842-2','BlockBox','',5),(4862,'115736','watch-mobile','block-4861','account\\GiftCards','',6),(4863,'115737','watch-mobile','block-4861','Html_box','',1),(4864,'115738','watch-mobile','block-4842-2','Html_box','',5),(4865,'115044','watch-mobile','sitemap','BlockBox','',1),(4866,'115045','watch-mobile','block-4865','BlockBox','',2),(4867,'115046','watch-mobile','block-4866','Menu','Account box',6),(4868,'115047','watch-mobile','block-4866','sitemap\\InfoPages','',2),(4869,'115048','watch-mobile','block-4866','Html_box','',5),(4870,'115049','watch-mobile','block-4866','sitemap\\Categories','',4),(4871,'115050','watch-mobile','block-4866','Html_box','',3),(4872,'115051','watch-mobile','block-4866','Html_box','',1),(4873,'115052','watch-mobile','block-4866-2','Html_box','',1),(4874,'115053','watch-mobile','block-4866-2','sitemap\\DeliveryLocation','',2),(4875,'115054','watch-mobile','block-4865','Html_box','',1),(4876,'115055','watch-mobile','subscribe','BlockBox','',1),(4877,'115056','watch-mobile','block-4876','subscribers\\SubscribeForm','',2),(4878,'115057','watch-mobile','block-4876','Html_box','',1),(4879,'115058','watch-mobile','block-4876','Html_box','',3),(4880,'115059','watch-mobile','block-4876','subscribers\\UnsubscribeForm','',4),(4881,'115060','watch-mobile','subscribed','BlockBox','',1),(4882,'115061','watch-mobile','block-4881','Html_box','',1),(4883,'115062','watch-mobile','subscription','BlockBox','',2),(4884,'115063','watch-mobile','block-4883','BlockBox','',1),(4885,'115064','watch-mobile','block-4884','WidgetsAria','',1),(4886,'115065','watch-mobile','block-4884-2','Html_box','',2),(4887,'115066','watch-mobile','block-4884-2','Html_box','',3),(4888,'115067','watch-mobile','block-4884-2','account\\Subscription','',4),(4889,'75873','watch-mobile','success','BlockBox','',1),(4890,'75874','watch-mobile','block-4889','BlockBox','',1),(4891,'75875','watch-mobile','block-4890','Text','',2),(4892,'75876','watch-mobile','block-4890','BlockBox','',3),(4893,'75877','watch-mobile','block-4892','Html','',3),(4894,'75878','watch-mobile','block-4892-2','success\\PrintBtn','',1),(4895,'75879','watch-mobile','block-4892-3','success\\ContinueBtn','',1),(4896,'115068','watch-mobile','success_q','BlockBox','',1),(4897,'115069','watch-mobile','block-4896','BlockBox','',1),(4898,'115070','watch-mobile','block-4897','BlockBox','',2),(4899,'115071','watch-mobile','block-4898','success\\PrintBtn','',1),(4900,'115072','watch-mobile','block-4898','success\\ContinueBtn','',2),(4901,'115073','watch-mobile','block-4897','Html_box','',1),(4905,'115074','watch-mobile','ticket','invoice\\Container','',1),(4906,'115075','watch-mobile','block-4905','BlockBox','',1),(4907,'115076','watch-mobile','block-4906-2','BlockBox','',1),(4908,'115077','watch-mobile','block-4907','invoice\\StoreAddress','',1),(4909,'115078','watch-mobile','block-4906-2','BlockBox','',2),(4910,'115079','watch-mobile','block-4909','Text','',1),(4911,'115080','watch-mobile','block-4909-2','invoice\\StorePhone','',1),(4912,'115081','watch-mobile','block-4906-2','BlockBox','',4),(4913,'115082','watch-mobile','block-4912','Text','',1),(4914,'115083','watch-mobile','block-4912-2','invoice\\StoreSite','',1),(4915,'115084','watch-mobile','block-4906-2','BlockBox','',3),(4916,'115085','watch-mobile','block-4915','Text','',1),(4917,'115086','watch-mobile','block-4915-2','invoice\\StoreEmail','',1),(4918,'115087','watch-mobile','block-4905','BlockBox','',2),(4919,'115088','watch-mobile','block-4918','BlockBox','',7),(4920,'115089','watch-mobile','block-4919','BlockBox','',1),(4921,'115090','watch-mobile','block-4920','Text','',1),(4922,'115091','watch-mobile','block-4920','invoice\\BillingAddress','',2),(4923,'115092','watch-mobile','block-4919-2','BlockBox','',1),(4924,'115093','watch-mobile','block-4923','Text','',3),(4925,'115094','watch-mobile','block-4923','Text','',5),(4926,'115095','watch-mobile','block-4923','Text','',1),(4927,'115096','watch-mobile','block-4923','invoice\\CustomerPhone','',4),(4928,'115097','watch-mobile','block-4923','invoice\\CustomerName','',2),(4929,'115098','watch-mobile','block-4923','invoice\\CustomerEmail','',6),(4930,'115099','watch-mobile','block-4918','BlockBox','',8),(4931,'115100','watch-mobile','block-4930','BlockBox','',1),(4932,'115101','watch-mobile','block-4931','Text','',1),(4933,'115102','watch-mobile','block-4931','invoice\\ShippingMethod','',2),(4934,'115103','watch-mobile','block-4930-2','BlockBox','',1),(4935,'115104','watch-mobile','block-4934','invoice\\ShippingMethod','',2),(4936,'115105','watch-mobile','block-4934','Text','',1),(4937,'115106','watch-mobile','block-4918-2','Text','',2),(4938,'115107','watch-mobile','block-4918-2','invoice\\OrderBarcode','',6),(4939,'115108','watch-mobile','block-4918-2','Text','',4),(4940,'115109','watch-mobile','block-4918-2','invoice\\OrderId','',1),(4941,'115110','watch-mobile','block-4918-2','invoice\\PaymentDate','',3),(4942,'115111','watch-mobile','block-4918-2','invoice\\PaymentMethod','',5),(4943,'115112','watch-mobile','block-4905','BlockBox','',5),(4944,'115113','watch-mobile','block-4943','Text','',1),(4945,'115114','watch-mobile','block-4943','invoice\\StoreAddress','',8),(4946,'115115','watch-mobile','block-4943-2','Logo','',1),(4947,'115116','watch-mobile','block-4943-2','Text','',2),(4948,'115117','watch-mobile','block-4943-3','BlockBox','',2),(4949,'115118','watch-mobile','block-4948','Text','',1),(4950,'115119','watch-mobile','block-4948-2','invoice\\StorePhone','',1),(4951,'115120','watch-mobile','block-4943-3','Text','',1),(4952,'115121','watch-mobile','block-4943-3','BlockBox','',3),(4953,'115122','watch-mobile','block-4952','Text','',1),(4954,'115123','watch-mobile','block-4952-2','invoice\\StoreEmail','',1),(4955,'115124','watch-mobile','block-4905','invoice\\Products','',3),(4956,'115125','watch-mobile','block-4905','BlockBox','',4),(4957,'115126','watch-mobile','block-4956','BlockBox','',1),(4958,'115127','watch-mobile','block-4957','invoice\\ShippingAddress','',2),(4959,'115128','watch-mobile','block-4957','Text','',1),(4960,'115129','watch-mobile','block-4956-2','BlockBox','',1),(4961,'115130','watch-mobile','block-4960','invoice\\Totals','',1),(4962,'115131','watch-mobile','tl_blog_category','BlockBox','',1),(4963,'115132','watch-mobile','block-4962','BlockBox','',1),(4964,'115133','watch-mobile','block-4963','BlockBox','',1),(4965,'115134','watch-mobile','block-4964','Blog\\widget\\PostListing','',1),(4966,'115135','watch-mobile','block-4964','catalog\\Paging','',2),(4967,'115136','watch-mobile','block-4963-2','WidgetsAria','',1),(4968,'115137','watch-mobile','tl_blog_index','BlockBox','',2),(4969,'115138','watch-mobile','block-4968','BlockBox','',2),(4970,'115139','watch-mobile','block-4969','BlockBox','',1),(4971,'115140','watch-mobile','block-4970','Blog\\widget\\PostListing','',1),(4972,'115141','watch-mobile','block-4970','catalog\\Paging','',2),(4973,'115142','watch-mobile','block-4969-2','WidgetsAria','',1),(4974,'115143','watch-mobile','block-4968','Banner','',1),(4975,'115144','watch-mobile','tl_blog_post','BlockBox','',1),(4976,'115145','watch-mobile','block-4975','BlockBox','',3),(4977,'115146','watch-mobile','block-4976','Blog\\widget\\PostTags','',2),(4978,'115147','watch-mobile','block-4976','BlockBox','',3),(4979,'115148','watch-mobile','block-4978','Html_box','',1),(4980,'115149','watch-mobile','block-4978','Blog\\widget\\PostLinkedProducts','',2),(4981,'115150','watch-mobile','block-4976','BlockBox','',1),(4982,'115151','watch-mobile','block-4981','Blog\\widget\\PostTitle','',3),(4983,'115152','watch-mobile','block-4981','Blog\\widget\\PostImage','',1),(4984,'115153','watch-mobile','block-4981','Blog\\widget\\PostDescription','',4),(4985,'115154','watch-mobile','block-4981','BlockBox','',5),(4986,'115155','watch-mobile','block-4985','Blog\\widget\\PostViewed','',1),(4987,'115156','watch-mobile','block-4981','Blog\\widget\\PostDate','',2),(4988,'115157','watch-mobile','block-4976-2','WidgetsAria','',1),(4989,'115158','watch-mobile','tl_blog_tags','BlockBox','',1),(4990,'115159','watch-mobile','block-4989','BlockBox','',1),(4991,'115160','watch-mobile','block-4990','BlockBox','',1),(4992,'115161','watch-mobile','block-4991','Blog\\widget\\PostListing','',1),(4993,'115162','watch-mobile','block-4991','catalog\\Paging','',2),(4994,'115163','watch-mobile','block-4990-2','WidgetsAria','',1),(4995,'115164','watch-mobile','tracking_numbers','BlockBox','',1),(4996,'115165','watch-mobile','block-4995','account\\OrderTracking','',2),(4997,'115166','watch-mobile','block-4995','Html_box','',1),(4998,'115167','watch-mobile','trade_form','BlockBox','',1),(4999,'115168','watch-mobile','block-4998','BlockBox','',3),(5000,'115169','watch-mobile','block-4999','BlockBox','',1),(5001,'115170','watch-mobile','block-5000','account\\CustomerAdditionalField','',2),(5002,'115171','watch-mobile','block-5000','account\\CustomerAdditionalField','',1),(5003,'115172','watch-mobile','block-4998','BlockBox','',14),(5004,'115173','watch-mobile','block-5003','account\\BackButton','',1),(5005,'115174','watch-mobile','block-5003-2','account\\PdfButton','',2),(5006,'115175','watch-mobile','block-5003-2','account\\SaveButton','',1),(5007,'115176','watch-mobile','block-4998','BlockBox','',13),(5008,'115177','watch-mobile','block-5007','BlockBox','',1),(5009,'115178','watch-mobile','block-5008','account\\CustomerAdditionalField','',1),(5010,'115179','watch-mobile','block-5007-2','BlockBox','',1),(5011,'115180','watch-mobile','block-5010','account\\CustomerAdditionalField','',1),(5012,'115181','watch-mobile','block-4998','Html_box','',10),(5013,'115182','watch-mobile','block-4998','Html_box','',8),(5014,'115183','watch-mobile','block-4998','Html_box','',12),(5015,'115184','watch-mobile','block-4998','BlockBox','',11),(5016,'115185','watch-mobile','block-5015','BlockBox','',1),(5017,'115186','watch-mobile','block-5016','account\\CustomerAdditionalField','',4),(5018,'115187','watch-mobile','block-5016','account\\CustomerAdditionalField','',2),(5019,'115188','watch-mobile','block-5016','Html_box','',1),(5020,'115189','watch-mobile','block-5016','account\\CustomerAdditionalField','',3),(5021,'115190','watch-mobile','block-5015-2','BlockBox','',1),(5022,'115191','watch-mobile','block-5021','Html_box','',1),(5023,'115192','watch-mobile','block-5021','account\\CustomerAdditionalField','',3),(5024,'115193','watch-mobile','block-5021','account\\CustomerAdditionalField','',2),(5025,'115194','watch-mobile','block-5021','account\\CustomerAdditionalField','',4),(5026,'115195','watch-mobile','block-4998','BlockBox','',5),(5027,'115196','watch-mobile','block-5026','BlockBox','',1),(5028,'115197','watch-mobile','block-5027','account\\CustomerAdditionalField','',2),(5029,'115198','watch-mobile','block-5027','account\\CustomerAdditionalField','',1),(5030,'115199','watch-mobile','block-4998','BlockBox','',4),(5031,'115200','watch-mobile','block-5030','BlockBox','',1),(5032,'115201','watch-mobile','block-5031','account\\AddressesList','',2),(5033,'115202','watch-mobile','block-5031','Html_box','',1),(5034,'115203','watch-mobile','block-5031','account\\CustomerAdditionalField','',5),(5035,'115204','watch-mobile','block-5031','BlockBox','',3),(5036,'115205','watch-mobile','block-5035','account\\CustomerAdditionalField','',1),(5037,'115206','watch-mobile','block-5031','BlockBox','',4),(5038,'115207','watch-mobile','block-5037','BlockBox','',1),(5039,'115208','watch-mobile','block-5038','account\\CustomerAdditionalField','',1),(5040,'115209','watch-mobile','block-5038','account\\CustomerAdditionalField','',4),(5041,'115210','watch-mobile','block-5038','account\\CustomerAdditionalField','',2),(5042,'115211','watch-mobile','block-5038','account\\CustomerAdditionalField','',3),(5043,'115212','watch-mobile','block-5037-2','BlockBox','',1),(5044,'115213','watch-mobile','block-5043','account\\CustomerAdditionalField','',4),(5045,'115214','watch-mobile','block-5043','account\\CustomerAdditionalField','',3),(5046,'115215','watch-mobile','block-5043','account\\CustomerAdditionalField','',2),(5047,'115216','watch-mobile','block-5043','account\\CustomerAdditionalField','',1),(5048,'115217','watch-mobile','block-5030-2','BlockBox','',1),(5049,'115218','watch-mobile','block-5048','account\\AddressesList','',2),(5050,'115219','watch-mobile','block-5048','BlockBox','',3),(5051,'115220','watch-mobile','block-5050','BlockBox','',1),(5052,'115221','watch-mobile','block-5051','account\\CustomerAdditionalField','',1),(5053,'115222','watch-mobile','block-5051','account\\CustomerAdditionalField','',2),(5054,'115223','watch-mobile','block-5050-2','BlockBox','',1),(5055,'115224','watch-mobile','block-5054','account\\CustomerAdditionalField','',1),(5056,'115225','watch-mobile','block-5048','BlockBox','',4),(5057,'115226','watch-mobile','block-5056','BlockBox','',1),(5058,'115227','watch-mobile','block-5057','account\\CustomerAdditionalField','',2),(5059,'115228','watch-mobile','block-5057','account\\CustomerAdditionalField','',1),(5060,'115229','watch-mobile','block-5057','account\\CustomerAdditionalField','',3),(5061,'115230','watch-mobile','block-5056-2','BlockBox','',1),(5062,'115231','watch-mobile','block-5061','account\\CustomerAdditionalField','',2),(5063,'115232','watch-mobile','block-5061','account\\CustomerAdditionalField','',1),(5064,'115233','watch-mobile','block-5061','account\\CustomerAdditionalField','',3),(5065,'115234','watch-mobile','block-5048','Html_box','',1),(5066,'115235','watch-mobile','block-4998','BlockBox','',9),(5067,'115236','watch-mobile','block-5066','BlockBox','',1),(5068,'115237','watch-mobile','block-5067','account\\CustomerAdditionalField','',1),(5069,'115238','watch-mobile','block-5067','account\\CustomerAdditionalField','',2),(5070,'115239','watch-mobile','block-5066-2','BlockBox','',1),(5071,'115240','watch-mobile','block-5070','account\\CustomerAdditionalField','',1),(5072,'115241','watch-mobile','block-4998','Html_box','',2),(5073,'115242','watch-mobile','block-4998','BlockBox','',7),(5074,'115243','watch-mobile','block-5073','BlockBox','',1),(5075,'115244','watch-mobile','block-5074','account\\CustomerAdditionalField','',1),(5076,'115245','watch-mobile','block-5074','account\\CustomerAdditionalField','',2),(5077,'115246','watch-mobile','block-5073-2','BlockBox','',1),(5078,'115247','watch-mobile','block-5077','account\\CustomerAdditionalField','',1),(5079,'115248','watch-mobile','block-5077','account\\CustomerAdditionalField','',2),(5080,'115249','watch-mobile','block-4998','Html_box','',1),(5081,'115250','watch-mobile','block-4998','Html_box','',6),(5082,'115251','watch-mobile','trade_form_pdf','BlockBox','',1),(5083,'115252','watch-mobile','block-5082','BlockBox','',14),(5084,'115253','watch-mobile','block-5083','Html_box','',1),(5085,'115254','watch-mobile','block-5083-2','account\\CustomerAdditionalField','',1),(5086,'115255','watch-mobile','block-5082','BlockBox','',6),(5087,'115256','watch-mobile','block-5086','Html_box','',1),(5088,'115257','watch-mobile','block-5086-2','account\\CombinedField','',2),(5089,'115258','watch-mobile','block-5082','BlockBox','',13),(5090,'115259','watch-mobile','block-5089','Html_box','',1),(5091,'115260','watch-mobile','block-5089-2','account\\CustomerAdditionalField','',1),(5092,'115261','watch-mobile','block-5082','BlockBox','',12),(5093,'115262','watch-mobile','block-5092','Html_box','',1),(5094,'115263','watch-mobile','block-5092-2','account\\CombinedField','',2),(5095,'115264','watch-mobile','block-5082','BlockBox','',11),(5096,'115265','watch-mobile','block-5095','Html_box','',1),(5097,'115266','watch-mobile','block-5095-2','account\\CombinedField','',1),(5098,'115267','watch-mobile','block-5082','BlockBox','',9),(5099,'115268','watch-mobile','block-5098','Html_box','',1),(5100,'115269','watch-mobile','block-5098-2','account\\CustomerAdditionalField','',1),(5101,'115270','watch-mobile','block-5082','BlockBox','',8),(5102,'115271','watch-mobile','block-5101','Html_box','',1),(5103,'115272','watch-mobile','block-5101-2','BlockBox','',1),(5104,'115273','watch-mobile','block-5103','account\\CustomerAdditionalField','',1),(5105,'115274','watch-mobile','block-5103-2','BlockBox','',1),(5106,'115275','watch-mobile','block-5105','Html_box','',2),(5107,'115276','watch-mobile','block-5105-2','account\\CustomerAdditionalField','',1),(5108,'115277','watch-mobile','block-5082','BlockBox','',3),(5109,'115278','watch-mobile','block-5108','Html_box','',1),(5110,'115279','watch-mobile','block-5082','BlockBox','',1),(5111,'115280','watch-mobile','block-5110','Contacts','',1),(5112,'115281','watch-mobile','block-5110-2','Html_box','',1),(5113,'115282','watch-mobile','block-5082','BlockBox','',4),(5114,'115283','watch-mobile','block-5113-2','BlockBox','',1),(5115,'115284','watch-mobile','block-5114','BlockBox','',1),(5116,'115285','watch-mobile','block-5115','Html_box','',2),(5117,'115286','watch-mobile','block-5115-2','account\\CustomerAdditionalField','',1),(5118,'115287','watch-mobile','block-5114-2','BlockBox','',1),(5119,'115288','watch-mobile','block-5118','Html_box','',1),(5120,'115289','watch-mobile','block-5118-2','account\\CustomerAdditionalField','',1),(5121,'115290','watch-mobile','block-5082','BlockBox','',2),(5122,'115291','watch-mobile','block-5121','Contacts','',1),(5123,'115292','watch-mobile','block-5082','BlockBox','',7),(5124,'115293','watch-mobile','block-5123','Html_box','',1),(5125,'115294','watch-mobile','block-5123-2','account\\CustomerAdditionalField','',1),(5126,'115295','watch-mobile','block-5082','BlockBox','',5),(5127,'115296','watch-mobile','block-5126','Html_box','',1),(5128,'115297','watch-mobile','block-5126-2','account\\CustomerAdditionalField','',1),(5129,'115298','watch-mobile','block-5082','BlockBox','',10),(5130,'115299','watch-mobile','block-5129','Html_box','',1),(5131,'115300','watch-mobile','block-5129-2','account\\CustomerAdditionalField','',1),(5132,'115301','watch-mobile','block-5082','BlockBox','',18),(5133,'115302','watch-mobile','block-5132','Html_box','',1),(5134,'115303','watch-mobile','block-5132-2','account\\CustomerAdditionalField','',1),(5135,'115304','watch-mobile','block-5082','BlockBox','',15),(5136,'115305','watch-mobile','block-5135','Html_box','',1),(5137,'115306','watch-mobile','block-5082','BlockBox','',17),(5138,'115307','watch-mobile','block-5137','Html_box','',1),(5139,'115308','watch-mobile','block-5082','BlockBox','',20),(5140,'115309','watch-mobile','block-5139','Html_box','',1),(5141,'115310','watch-mobile','block-5139-2','account\\CustomerAdditionalField','',1),(5142,'115311','watch-mobile','block-5082','BlockBox','',19),(5143,'115312','watch-mobile','block-5142','Html_box','',1),(5144,'115313','watch-mobile','block-5142-2','account\\CustomerAdditionalField','',1),(5145,'115314','watch-mobile','block-5082','BlockBox','',16),(5146,'115315','watch-mobile','block-5145','Html_box','',1),(5147,'115316','watch-mobile','block-5145-2','BlockBox','',1),(5148,'115317','watch-mobile','block-5147','account\\CustomerAdditionalField','',1),(5149,'115318','watch-mobile','block-5147-2','Html_box','',1),(5150,'115319','watch-mobile','block-5147-3','account\\CustomerAdditionalField','',1),(5151,'115320','watch-mobile','block-5145-3','BlockBox','',1),(5152,'115321','watch-mobile','block-5082','BlockBox','',23),(5153,'115322','watch-mobile','block-5152','Html_box','',1),(5154,'115323','watch-mobile','block-5152-2','account\\CustomerAdditionalField','',1),(5155,'115324','watch-mobile','block-5082','BlockBox','',21),(5156,'115325','watch-mobile','block-5155','Html_box','',1),(5157,'115326','watch-mobile','block-5082','BlockBox','',26),(5158,'115327','watch-mobile','block-5157','Html_box','',1),(5159,'115328','watch-mobile','block-5082','BlockBox','',24),(5160,'115329','watch-mobile','block-5159','Html_box','',1),(5161,'115330','watch-mobile','block-5159-2','account\\CustomerAdditionalField','',1),(5162,'115331','watch-mobile','block-5082','BlockBox','',25),(5163,'115332','watch-mobile','block-5162','Html_box','',1),(5164,'115333','watch-mobile','block-5082','BlockBox','',22),(5165,'115334','watch-mobile','block-5164','Html_box','',1),(5166,'115335','watch-mobile','block-5164-2','account\\CustomerAdditionalField','',1),(5167,'115336','watch-mobile','block-5082','BlockBox','',27),(5168,'115337','watch-mobile','block-5167','Html_box','',1),(5169,'115338','watch-mobile','block-5167-2','Html_box','',1),(5170,'115339','watch-mobile','block-5167-3','Html_box','',1),(5171,'115340','watch-mobile','block-5167-4','Html_box','',1),(5172,'115341','watch-mobile','block-5082','BlockBox','',28),(5173,'115342','watch-mobile','block-5172','Html_box','',1),(5174,'115343','watch-mobile','block-5172-2','account\\CustomerAdditionalField','',1),(5175,'115344','watch-mobile','block-5172-3','Html_box','',1),(5176,'115345','watch-mobile','block-5172-4','account\\CustomerAdditionalField','',1),(5177,'115346','watch-mobile','block-5082','BlockBox','',29),(5178,'115347','watch-mobile','block-5177','Html_box','',1),(5179,'115348','watch-mobile','unsubscribed','BlockBox','',1),(5180,'115349','watch-mobile','block-5179','Html_box','',1),(5181,'115350','watch-mobile','update-and-pay-order_confirmation','BlockBox','',1),(5182,'115351','watch-mobile','block-5181','BlockBox','',3),(5183,'115352','watch-mobile','block-5182','BlockBox','',1),(5184,'115353','watch-mobile','block-5183','BlockBox','',1),(5185,'115354','watch-mobile','block-5184','BlockBox','',1),(5186,'115355','watch-mobile','block-5185','Html_box','',4),(5187,'115356','watch-mobile','block-5185','Html_box','',2),(5188,'115357','watch-mobile','block-5185','Html_box','',1),(5189,'115358','watch-mobile','block-5185','order\\ShippingMethod','',5),(5190,'115359','watch-mobile','block-5185','order\\DeliveryAddress','',3),(5191,'115360','watch-mobile','block-5185','order\\Telephone','',8),(5192,'115361','watch-mobile','block-5185','order\\Email','',9),(5193,'115362','watch-mobile','block-5185','order\\Name','',7),(5194,'115363','watch-mobile','block-5185','Html_box','',6),(5195,'115364','watch-mobile','block-5184-2','BlockBox','',1),(5196,'115365','watch-mobile','block-5195','order\\BillingAddress','',3),(5197,'115366','watch-mobile','block-5195','UpdateAndPay\\PayConfirm','',5),(5198,'115367','watch-mobile','block-5195','Html_box','',1),(5199,'115368','watch-mobile','block-5195','Html_box','',2),(5200,'115369','watch-mobile','block-5195','Html_box','',4),(5201,'115370','watch-mobile','block-5183','BlockBox','',3),(5202,'115371','watch-mobile','block-5201','order\\Products','',2),(5203,'115372','watch-mobile','block-5201','Html_box','',1),(5204,'115373','watch-mobile','block-5182-2','BlockBox','',1),(5205,'115374','watch-mobile','block-5204','Html_box','',1),(5206,'115375','watch-mobile','block-5204','checkout\\ContinueBtn','',3),(5207,'115376','watch-mobile','block-5204','order\\Totals','',2),(5208,'115377','watch-mobile','block-5181','account\\OrderHeading','',1),(5209,'115378','watch-mobile','update-and-pay-order_pay','BlockBox','',1),(5210,'115379','watch-mobile','block-5209','BlockBox','',3),(5211,'115380','watch-mobile','block-5210','BlockBox','',1),(5212,'115381','watch-mobile','block-5211','BlockBox','',3),(5213,'115382','watch-mobile','block-5212','Html_box','',1),(5214,'115383','watch-mobile','block-5212','order\\Products','',2),(5215,'115384','watch-mobile','block-5211','BlockBox','',1),(5216,'115385','watch-mobile','block-5215','BlockBox','',1),(5217,'115386','watch-mobile','block-5216','order\\Name','',7),(5218,'115387','watch-mobile','block-5216','order\\Email','',9),(5219,'115388','watch-mobile','block-5216','order\\DeliveryAddress','',3),(5220,'115389','watch-mobile','block-5216','Html_box','',6),(5221,'115390','watch-mobile','block-5216','order\\Telephone','',8),(5222,'115391','watch-mobile','block-5216','Html_box','',2),(5223,'115392','watch-mobile','block-5216','order\\ShippingMethod','',5),(5224,'115393','watch-mobile','block-5216','Html_box','',4),(5225,'115394','watch-mobile','block-5216','Html_box','',1),(5226,'115395','watch-mobile','block-5215-2','BlockBox','',1),(5227,'115396','watch-mobile','block-5226','Html_box','',2),(5228,'115397','watch-mobile','block-5226','Html_box','',1),(5229,'115398','watch-mobile','block-5226','Html_box','',4),(5230,'115399','watch-mobile','block-5226','order\\BillingAddress','',3),(5231,'115400','watch-mobile','block-5226','UpdateAndPay\\PayForm','',5),(5232,'115401','watch-mobile','block-5210-2','BlockBox','',1),(5233,'115402','watch-mobile','block-5232','order\\Totals','',2),(5234,'115403','watch-mobile','block-5232','Html_box','',1),(5235,'115404','watch-mobile','block-5232','checkout\\ContinueBtn','',3),(5236,'115405','watch-mobile','block-5209','account\\OrderHeading','',1),(5237,'115406','watch-mobile','wedding_index','BlockBox','',1),(5238,'115407','watch-mobile','block-5237','BlockBox','',1),(5239,'115408','watch-mobile','block-5238','WeddingRegistry\\widgets\\ViewCreateRegistryWidget','',2),(5240,'115409','watch-mobile','block-5238','WeddingRegistry\\widgets\\SearchRegistryButton','',3),(5241,'115410','watch-mobile','block-5238','Heading','',1),(5242,'115411','watch-mobile','wedding_manage','BlockBox','',2),(5243,'115412','watch-mobile','block-5242','WeddingRegistry\\widgets\\Photos','',1),(5244,'115413','watch-mobile','block-5242-2','WeddingRegistry\\widgets\\ManageNames','',1),(5245,'115414','watch-mobile','block-5242-2','BlockBox','',3),(5246,'115415','watch-mobile','block-5245','WeddingRegistry\\widgets\\EditLink','',1),(5247,'115416','watch-mobile','block-5245','WeddingRegistry\\widgets\\DeleteLink','',2),(5248,'115417','watch-mobile','block-5245','WeddingRegistry\\widgets\\ShareLink','',3),(5249,'115418','watch-mobile','block-5242-2','WeddingRegistry\\widgets\\ManageDate','',2),(5250,'115419','watch-mobile','block-5242-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(5251,'115420','watch-mobile','wedding_manage','WeddingRegistry\\widgets\\ManageBanner','',1),(5252,'115421','watch-mobile','wedding_manage','WeddingRegistry\\widgets\\AddItemsLink','',3),(5253,'115422','watch-mobile','wedding_manage','WeddingRegistry\\widgets\\Products','',4),(5257,'115423','watch-mobile','wedding_search','BlockBox','',1),(5258,'115424','watch-mobile','block-5257','WeddingRegistry\\widgets\\SearchList','',2),(5259,'115425','watch-mobile','block-5257','WeddingRegistry\\widgets\\SearchPaging','',3),(5260,'115426','watch-mobile','block-5257','BlockBox','',1),(5261,'115427','watch-mobile','block-5260','BlockBox','',1),(5262,'115428','watch-mobile','block-5261','WeddingRegistry\\widgets\\SearchForm','',2),(5263,'115429','watch-mobile','block-5261','Html_box','',1),(5264,'115430','watch-mobile','wedding_share','BlockBox','',1),(5265,'115431','watch-mobile','block-5264','BlockBox','',4),(5266,'115432','watch-mobile','block-5265-2','Html_box','',3),(5267,'115433','watch-mobile','block-5265-2','Html_box','',1),(5268,'115434','watch-mobile','block-5265-2','WeddingRegistry\\widgets\\ShareUrl','',2),(5269,'115435','watch-mobile','block-5265-2','WeddingRegistry\\widgets\\InviteList','',4),(5270,'115436','watch-mobile','block-5264','WeddingRegistry\\widgets\\ManageBanner','',1),(5271,'115437','watch-mobile','block-5264','WeddingRegistry\\widgets\\Photos','',2),(5272,'115438','watch-mobile','block-5264','Html_box','',3),(5273,'115439','watch-mobile','wedding_success','Html_box','',1),(5274,'115440','watch-mobile','wedding_success','WeddingRegistry\\widgets\\BackButton','',2),(5275,'115441','watch-mobile','wedding_update','BlockBox','',2),(5276,'115442','watch-mobile','block-5275','BlockBox','',1),(5277,'115443','watch-mobile','block-5276','Html_box','',5),(5278,'115444','watch-mobile','block-5276','Html_box','',3),(5279,'115445','watch-mobile','block-5276','WeddingRegistry\\widgets\\Details','',4),(5280,'115446','watch-mobile','block-5276','WeddingRegistry\\widgets\\Names','',2),(5281,'115447','watch-mobile','block-5276','Html_box','',1),(5282,'115448','watch-mobile','block-5276','WeddingRegistry\\widgets\\ShareRegistry','',6),(5283,'115449','watch-mobile','block-5275-2','BlockBox','',1),(5284,'115450','watch-mobile','block-5283','WeddingRegistry\\widgets\\ShippingDetails','',2),(5285,'115451','watch-mobile','block-5283','Html_box','',1),(5286,'115452','watch-mobile','block-5283','Html_box','',5),(5287,'115453','watch-mobile','block-5283','WeddingRegistry\\widgets\\Photos','',6),(5288,'115454','watch-mobile','block-5283','Html_box','',3),(5289,'115455','watch-mobile','block-5283','WeddingRegistry\\widgets\\InformationText','',4),(5290,'115456','watch-mobile','wedding_update','Html_box','',1),(5291,'115457','watch-mobile','wedding_update','BlockBox','',3),(5292,'115458','watch-mobile','block-5291','WeddingRegistry\\widgets\\BackButton','',1),(5293,'115459','watch-mobile','block-5291-2','WeddingRegistry\\widgets\\SaveButton','',1),(5294,'115460','watch-mobile','wedding_view','WeddingRegistry\\widgets\\ManageBanner','',1),(5295,'115461','watch-mobile','wedding_view','BlockBox','',2),(5296,'115462','watch-mobile','block-5295','WeddingRegistry\\widgets\\Photos','',1),(5297,'115463','watch-mobile','block-5295-2','WeddingRegistry\\widgets\\ManageDate','',2),(5298,'115464','watch-mobile','block-5295-2','WeddingRegistry\\widgets\\ManageNames','',1),(5299,'115465','watch-mobile','block-5295-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(5300,'115466','watch-mobile','wedding_view','WeddingRegistry\\widgets\\Products','',6),(5301,'115467','watch-mobile','wishlist','BlockBox','',1),(5302,'115468','watch-mobile','block-5301','BlockBox','',1),(5303,'115469','watch-mobile','block-5302','WidgetsAria','',1),(5304,'115470','watch-mobile','block-5302-2','Html_box','',1),(5305,'115471','watch-mobile','block-5302-2','account\\Wishlist','',2),(5306,'115472','watch-mobile','wishlist-cart','BlockBox','',1),(5307,'115473','watch-mobile','block-5306','cart\\CartTabs','',1),(5308,'115474','watch-mobile','block-5307','account\\Wishlist','',1),(12909,'118459','printshop-mobile','404','Html_box','',1),(13006,'118556','printshop-mobile','account','BlockBox','',1),(13007,'118557','printshop-mobile','block-13006','BlockBox','',1),(13008,'118558','printshop-mobile','block-13007','WidgetsAria','',1),(13009,'118559','printshop-mobile','block-13007-2','Html_box','',3),(13010,'118560','printshop-mobile','block-13007-2','account\\OrdersHistory','',4),(13011,'118561','printshop-mobile','block-13007-2','Html_box','',1),(13012,'118562','printshop-mobile','block-13007-2','BlockBox','',2),(13013,'118563','printshop-mobile','block-13012','Html_box','',1),(13014,'118564','printshop-mobile','block-13012','account\\LastOrder','',2),(13015,'118565','printshop-mobile','block-13012-2','Html_box','',1),(13016,'118566','printshop-mobile','block-13012-2','account\\AccountLink','',3),(13017,'118567','printshop-mobile','block-13012-2','account\\OrderCount','',2),(13018,'118568','printshop-mobile','block-13012-3','Html_box','',1),(13019,'118569','printshop-mobile','block-13012-3','account\\TotalOrdered','',2),(13020,'118570','printshop-mobile','block-13012-4','Html_box','',1),(13021,'118571','printshop-mobile','block-13012-4','account\\AccountLink','',3),(13022,'118572','printshop-mobile','block-13012-4','account\\CreditAmount','',2),(13023,'118573','printshop-mobile','block-13012-5','account\\AccountLink','',3),(13024,'118574','printshop-mobile','block-13012-5','account\\PointsEarnt','',2),(13025,'118575','printshop-mobile','block-13012-5','Html_box','',1),(13026,'118576','printshop-mobile','block-13007-2','BlockBox','',5),(13027,'118577','printshop-mobile','block-13026','account\\GiftCards','',6),(13028,'118578','printshop-mobile','block-13026','Html_box','',1),(13029,'118579','printshop-mobile','block-13007-2','Html_box','',5),(13030,'118580','printshop-mobile','account-menu','BlockBox','',1),(13031,'118581','printshop-mobile','block-13030','BlockBox','',1),(13032,'118582','printshop-mobile','block-13031','Html_box','',16),(13033,'118583','printshop-mobile','block-13031','account\\AccountLink','',18),(13034,'118584','printshop-mobile','block-13031','account\\AccountLink','',1),(13035,'118585','printshop-mobile','block-13031','Html_box','',2),(13036,'118586','printshop-mobile','block-13031','account\\AccountLink','',17),(13037,'118587','printshop-mobile','block-13031','account\\AccountLink','',4),(13038,'118588','printshop-mobile','block-13031','account\\AccountLink','',11),(13039,'118589','printshop-mobile','block-13031','Html_box','',6),(13040,'118590','printshop-mobile','block-13031','account\\AccountLink','',8),(13041,'118591','printshop-mobile','block-13031','account\\AccountLink','',7),(13042,'118592','printshop-mobile','block-13031','account\\AccountLink','',14),(13043,'118593','printshop-mobile','block-13031','account\\AccountLink','',5),(13044,'118594','printshop-mobile','block-13031','account\\AccountLink','',12),(13045,'118595','printshop-mobile','block-13031','account\\AccountLink','',9),(13046,'118596','printshop-mobile','block-13031','Html_box','',10),(13047,'118597','printshop-mobile','block-13031','account\\AccountLink','',15),(13048,'118598','printshop-mobile','account_edit','BlockBox','',1),(13049,'118599','printshop-mobile','block-13048','BlockBox','',1),(13050,'118600','printshop-mobile','block-13049','WidgetsAria','',1),(13051,'118601','printshop-mobile','block-13049-2','account\\AccountEdit','',2),(13052,'118602','printshop-mobile','block-13049-2','Html_box','',1),(13053,'118603','printshop-mobile','block-13049-2','account\\AccountLink','',3),(13054,'118604','printshop-mobile','address_book','BlockBox','',1),(13055,'118605','printshop-mobile','block-13054','BlockBox','',1),(13056,'118606','printshop-mobile','block-13055','WidgetsAria','',1),(13057,'118607','printshop-mobile','block-13055-2','account\\AddressBook','',3),(13058,'118608','printshop-mobile','block-13055-2','Html_box','',1),(13059,'118609','printshop-mobile','address_book_process','BlockBox','',1),(13060,'118610','printshop-mobile','block-13059','BlockBox','',1),(13061,'118611','printshop-mobile','block-13060','WidgetsAria','',1),(13062,'118612','printshop-mobile','block-13060-2','account\\EditAddress','',2),(13063,'118613','printshop-mobile','block-13060-2','Html_box','',1),(13064,'118614','printshop-mobile','block-13060-2','account\\AccountLink','',3),(13065,'118615','printshop-mobile','b2b','BlockBox','',1),(13066,'118616','printshop-mobile','block-13065','BlockBox','',1),(13067,'118617','printshop-mobile','block-13066','productListing\\image','',1),(13068,'118618','printshop-mobile','block-13066-2','productListing\\model','',5),(13069,'118619','printshop-mobile','block-13066-2','productListing\\attributes','',3),(13070,'118620','printshop-mobile','block-13066-2','BlockBox','',4),(13071,'118621','printshop-mobile','block-13070','BlockBox','',1),(13072,'118622','printshop-mobile','block-13071','productListing\\price','',1),(13073,'118623','printshop-mobile','block-13071-2','productListing\\bonusPoints','',1),(13074,'118624','printshop-mobile','block-13070-2','productListing\\qtyInput','',1),(13075,'118625','printshop-mobile','block-13066-2','productListing\\description','',6),(13076,'118626','printshop-mobile','block-13066-2','BlockBox','',2),(13077,'118627','printshop-mobile','block-13076','productListing\\stock','',1),(13078,'118628','printshop-mobile','block-13076-2','productListing\\rating','',1),(13079,'118629','printshop-mobile','block-13066-2','productListing\\name','',1),(13080,'118630','printshop-mobile','batch','BlockBox','',1),(13081,'118631','printshop-mobile','block-13080','productListing\\attributes','',5),(13082,'118632','printshop-mobile','block-13080','productListing\\price','',6),(13083,'118633','printshop-mobile','block-13080','productListing\\name','',4),(13084,'118634','printshop-mobile','block-13080','productListing\\image','',2),(13085,'118635','printshop-mobile','block-13080','batchSelect','',1),(13086,'118636','printshop-mobile','batch_selected','BlockBox','',1),(13087,'118637','printshop-mobile','block-13086','BlockBox','',13),(13088,'118638','printshop-mobile','block-13087','productListing\\image','',1),(13089,'118639','printshop-mobile','block-13087-2','batchRemove','',1),(13090,'118640','printshop-mobile','block-13087-2','productListing\\price','',3),(13091,'118641','printshop-mobile','block-13087-2','productListing\\name','',2),(13092,'118642','printshop-mobile','bbbbb','BlockBox','',1),(13093,'118643','printshop-mobile','block-13092','BlockBox','',2),(13094,'118644','printshop-mobile','block-13093','Filters','',1),(13095,'118645','printshop-mobile','block-13093-2','BlockBox','',6),(13096,'118646','printshop-mobile','block-13095','catalog\\CountsItems','',1),(13097,'118647','printshop-mobile','block-13095-2','catalog\\Paging','',1),(13098,'118648','printshop-mobile','block-13093-2','catalog\\Image','',1),(13099,'118649','printshop-mobile','block-13093-2','Listing','',5),(13100,'118650','printshop-mobile','block-13093-2','catalog\\ImageMapCategory','',3),(13101,'118651','printshop-mobile','block-13093-2','BlockBox','',4),(13102,'118652','printshop-mobile','block-13101','catalog\\ListingLook','',1),(13103,'118653','printshop-mobile','block-13101','catalog\\CompareButton','',2),(13104,'118654','printshop-mobile','block-13101','catalog\\ItemsOnPage','',4),(13105,'118655','printshop-mobile','block-13101','catalog\\Sorting','',3),(13106,'118656','printshop-mobile','block-13093-2','Categories','',2),(13107,'118657','printshop-mobile','block-13092','catalog\\Title','',1),(13108,'118658','printshop-mobile','blog','BlockBox','',1),(13109,'118659','printshop-mobile','block-13108','BlockBox','',1),(13110,'118660','printshop-mobile','block-13109','BlogContent','',1),(13111,'118661','printshop-mobile','block-13109-2','BlogSidebar','',1),(13112,'118662','printshop-mobile','blogsidebar','BlockBox','',1),(13113,'118663','printshop-mobile','block-13112','Blog\\widget\\RecentPosts','',4),(13114,'118664','printshop-mobile','block-13112','Blog\\widget\\TagCloud','',2),(13115,'118665','printshop-mobile','block-13112','Blog\\widget\\CategoriesList','',1),(13116,'118666','printshop-mobile','block-13112','Blog\\widget\\MostPopularPosts','',3),(13117,'118667','printshop-mobile','cart','BlockBox','',2),(13118,'118668','printshop-mobile','block-13117','BlockBox','',4),(13119,'118669','printshop-mobile','block-13118','Html_box','',1),(13120,'118670','printshop-mobile','block-13118','cart\\UpSell','6',2),(13121,'118671','printshop-mobile','block-13117','BlockBox','',1),(13122,'118672','printshop-mobile','block-13121','cart\\Products','',3),(13123,'118673','printshop-mobile','block-13121','BlockBox','',2),(13124,'118674','printshop-mobile','block-13123','MultiCart\\SaveCart','',2),(13125,'118675','printshop-mobile','block-13123-2','MultiCart\\Actions','',1),(13126,'118676','printshop-mobile','block-13121','MultiCart\\CartSwitcher','',1),(13127,'118677','printshop-mobile','block-13117','BlockBox','',3),(13128,'118678','printshop-mobile','block-13127','cart\\GiveAway','',2),(13129,'118679','printshop-mobile','block-13127','Html_box','',1),(13130,'118680','printshop-mobile','block-13117','BlockBox','',2),(13131,'118681','printshop-mobile','block-13130','Html_box','',1),(13132,'118682','printshop-mobile','block-13130','BlockBox','',2),(13133,'118683','printshop-mobile','block-13132','cart\\DiscountCoupon','',1),(13134,'118684','printshop-mobile','block-13132','cart\\CreditAmount','',2),(13135,'118685','printshop-mobile','block-13132','cart\\BonusPoints','',3),(13136,'118686','printshop-mobile','block-13117','BlockBox','',5),(13137,'118687','printshop-mobile','block-13136','Html_box','',1),(13138,'118688','printshop-mobile','block-13136','cart\\ShippingEstimator','',2),(13139,'118689','printshop-mobile','block-13117','BlockBox','',7),(13140,'118690','printshop-mobile','block-13139','BlockBox','',2),(13141,'118691','printshop-mobile','block-13140','Image','',4),(13142,'118692','printshop-mobile','block-13140','cart\\CheckoutBtn','',2),(13143,'118693','printshop-mobile','block-13140','cart\\OrderTotal','',1),(13144,'118694','printshop-mobile','block-13117','Html_box','',6),(13145,'118695','printshop-mobile','cart2','BlockBox','',2),(13146,'118696','printshop-mobile','block-13145','cart\\CartTabs','',2),(13147,'118697','printshop-mobile','block-13146','BlockBox','',1),(13148,'118698','printshop-mobile','block-13147','BlockBox','',4),(13149,'118699','printshop-mobile','block-13148','cart\\UpSell','6',2),(13150,'118700','printshop-mobile','block-13148','Html_box','',1),(13151,'118701','printshop-mobile','block-13147','BlockBox','',1),(13152,'118702','printshop-mobile','block-13151','cart\\Products','',3),(13153,'118703','printshop-mobile','block-13151','BlockBox','',2),(13154,'118704','printshop-mobile','block-13153','MultiCart\\CartSwitcher','',1),(13155,'118705','printshop-mobile','block-13153','MultiCart\\SaveCart','',2),(13156,'118706','printshop-mobile','block-13153-2','MultiCart\\Actions','',1),(13157,'118707','printshop-mobile','block-13147','BlockBox','',3),(13158,'118708','printshop-mobile','block-13157','cart\\GiveAway','',2),(13159,'118709','printshop-mobile','block-13157','Html_box','',1),(13160,'118710','printshop-mobile','block-13147','BlockBox','',2),(13161,'118711','printshop-mobile','block-13160','Html_box','',1),(13162,'118712','printshop-mobile','block-13160','BlockBox','',2),(13163,'118713','printshop-mobile','block-13162','cart\\DiscountCoupon','',1),(13164,'118714','printshop-mobile','block-13162-2','cart\\CreditAmount','',1),(13165,'118715','printshop-mobile','block-13162-3','cart\\BonusPoints','',1),(13166,'118716','printshop-mobile','block-13147','BlockBox','',5),(13167,'118717','printshop-mobile','block-13166','Html_box','',1),(13168,'118718','printshop-mobile','block-13166','cart\\ShippingEstimator','',2),(13169,'118719','printshop-mobile','block-13147-2','BlockBox','',1),(13170,'118720','printshop-mobile','block-13169','Html_box','',1),(13171,'118721','printshop-mobile','block-13169','BlockBox','',2),(13172,'118722','printshop-mobile','block-13171','Image','',4),(13173,'118723','printshop-mobile','block-13171','cart\\CheckoutBtn','',2),(13174,'118724','printshop-mobile','block-13171','cart\\OrderTotal','',1),(13175,'118725','printshop-mobile','categories','BlockBox','',1),(13176,'118726','printshop-mobile','block-13175','catalog\\Title','',1),(13177,'118727','printshop-mobile','block-13175','Categories','',2),(13178,'118728','printshop-mobile','categories','BlockBox','',2),(13179,'118729','printshop-mobile','block-13178','Listing','',3),(13180,'118730','printshop-mobile','block-13178','BlockBox','',1),(13181,'118731','printshop-mobile','block-13180','catalog\\Sorting','',1),(13182,'118732','printshop-mobile','block-13180-2','catalog\\CountsItems','',1),(13183,'118733','printshop-mobile','block-13178','catalog\\Paging','',2),(13184,'118734','printshop-mobile','category','ListingFunctionality','',2),(13185,'118735','printshop-mobile','category','Categories','',1),(13186,'118736','printshop-mobile','category','PagingBar','',5),(13187,'118737','printshop-mobile','category','PagingBar','',3),(13188,'118738','printshop-mobile','category','Listing','',4),(13189,'118739','printshop-mobile','category_2','BlockBox','',1),(13190,'118740','printshop-mobile','block-13189','catalog\\Title','',1),(13191,'118741','printshop-mobile','block-13189','BlockBox','',2),(13192,'118742','printshop-mobile','block-13191','Filters','',1),(13193,'118743','printshop-mobile','block-13191-2','catalog\\Image','',1),(13194,'118744','printshop-mobile','block-13191-2','Listing','',5),(13195,'118745','printshop-mobile','block-13191-2','BlockBox','',4),(13196,'118746','printshop-mobile','block-13195','catalog\\Sorting','',3),(13197,'118747','printshop-mobile','block-13195','catalog\\ItemsOnPage','',4),(13198,'118748','printshop-mobile','block-13195','catalog\\CompareButton','',2),(13199,'118749','printshop-mobile','block-13195','catalog\\ListingLook','',1),(13200,'118750','printshop-mobile','block-13191-2','catalog\\ImageMapCategory','',3),(13201,'118751','printshop-mobile','block-13191-2','Categories','',2),(13202,'118752','printshop-mobile','block-13191-2','BlockBox','',6),(13203,'118753','printshop-mobile','block-13202','catalog\\CountsItems','',1),(13204,'118754','printshop-mobile','block-13202-2','catalog\\Paging','',1),(13205,'118755','printshop-mobile','category_no_filters','BlockBox','',1),(13206,'118756','printshop-mobile','block-13205','catalog\\B2bAddButton','',7),(13207,'118757','printshop-mobile','block-13205','BlockBox','',6),(13208,'118758','printshop-mobile','block-13207','catalog\\CountsItems','',1),(13209,'118759','printshop-mobile','block-13207-2','catalog\\Paging','',1),(13210,'118760','printshop-mobile','block-13205','Listing','',5),(13211,'118761','printshop-mobile','block-13205','catalog\\Image','',2),(13212,'118762','printshop-mobile','block-13205','BlockBox','',4),(13213,'118763','printshop-mobile','block-13212','catalog\\ListingLook','',1),(13214,'118764','printshop-mobile','block-13212','catalog\\CompareButton','',2),(13215,'118765','printshop-mobile','block-13212','HeaderStock','',5),(13216,'118766','printshop-mobile','block-13212','catalog\\ItemsOnPage','',4),(13217,'118767','printshop-mobile','block-13212','catalog\\Sorting','',3),(13218,'118768','printshop-mobile','block-13205','Categories','',3),(13219,'118769','printshop-mobile','block-13205','catalog\\Title','',1),(13220,'118770','printshop-mobile','checkout','BlockBox','',1),(13221,'118771','printshop-mobile','block-13220','BlockBox','',1),(13222,'118772','printshop-mobile','block-13221','BlockBox','',2),(13223,'118773','printshop-mobile','block-13222','BlockBox','',3),(13224,'118774','printshop-mobile','block-13223','BlockBox','',2),(13225,'118775','printshop-mobile','block-13224','checkout\\BillingAddress','',2),(13226,'118776','printshop-mobile','block-13224','Html_box','',1),(13227,'118777','printshop-mobile','block-13224-2','BlockBox','',1),(13228,'118778','printshop-mobile','block-13227','Html_box','',1),(13229,'118779','printshop-mobile','block-13227','checkout\\PaymentMethod','',2),(13230,'118780','printshop-mobile','block-13223','Html_box','',1),(13231,'118781','printshop-mobile','block-13222','BlockBox','',6),(13232,'118782','printshop-mobile','block-13231','checkout\\CreateAccount','',2),(13233,'118783','printshop-mobile','block-13231','cart\\Products','',1),(13234,'118784','printshop-mobile','block-13222','BlockBox','',2),(13235,'118785','printshop-mobile','block-13234','Html_box','',1),(13236,'118786','printshop-mobile','block-13234','BlockBox','',3),(13237,'118787','printshop-mobile','block-13236','BlockBox','',1),(13238,'118788','printshop-mobile','block-13237','checkout\\ContactInformation','',4),(13239,'118789','printshop-mobile','block-13237','UploadCustomerId\\UploadCustomerIdForm','',4),(13240,'118790','printshop-mobile','block-13237','checkout\\ShippingAddress','',2),(13241,'118791','printshop-mobile','block-13237','Html_box','',3),(13242,'118792','printshop-mobile','block-13234','BlockBox','',4),(13243,'118793','printshop-mobile','block-13242','Html_box','',1),(13244,'118794','printshop-mobile','block-13242','DelayedDespatch\\Checkout','',3),(13245,'118795','printshop-mobile','block-13242','checkout\\Shipping','',2),(13246,'118796','printshop-mobile','block-13234','Neighbour\\Checkout','',5),(13247,'118797','printshop-mobile','block-13234','BlockBox','',2),(13248,'118798','printshop-mobile','block-13247','checkout\\ShippingChoice','',1),(13249,'118799','printshop-mobile','block-13222','BlockBox','',4),(13250,'118800','printshop-mobile','block-13249','Html_box','',1),(13251,'118801','printshop-mobile','block-13249','BlockBox','',2),(13252,'118802','printshop-mobile','block-13251','CouponsAndVauchers\\Checkout','',1),(13253,'118803','printshop-mobile','block-13251-2','checkout\\BonusPoints','',2),(13254,'118804','printshop-mobile','block-13251-2','checkout\\CreditAmount','',1),(13255,'118805','printshop-mobile','block-13222','BlockBox','',5),(13256,'118806','printshop-mobile','block-13255','checkout\\Comments','',2),(13257,'118807','printshop-mobile','block-13255','Html_box','',1),(13258,'118808','printshop-mobile','block-13220','BlockBox','',2),(13259,'118809','printshop-mobile','block-13258','checkout\\Totals','',2),(13260,'118810','printshop-mobile','block-13258','checkout\\ContinueBtn','',3),(13261,'118811','printshop-mobile','block-13258','Html_box','',1),(13262,'118812','printshop-mobile','block-13258','checkout\\Terms','',4),(13263,'118813','printshop-mobile','block-13258','Html_box','',5),(13264,'118814','printshop-mobile','checkout_confirmation','BlockBox','',1),(13265,'118815','printshop-mobile','block-13264','checkout\\ConfirmBtn','',4),(13266,'118816','printshop-mobile','block-13264','cart\\Products','',7),(13267,'118817','printshop-mobile','block-13264','BlockBox','',2),(13268,'118818','printshop-mobile','block-13267','BlockBox','',1),(13269,'118819','printshop-mobile','block-13268','Html_box','',1),(13270,'118820','printshop-mobile','block-13268','checkout\\ShippingAddressConfirm','',3),(13271,'118821','printshop-mobile','block-13267-2','BlockBox','',1),(13272,'118822','printshop-mobile','block-13271','Html_box','',1),(13273,'118823','printshop-mobile','block-13271','checkout\\BillingAddressConfirm','',3),(13274,'118824','printshop-mobile','block-13264','checkout\\ConfirmBtn','',9),(13275,'118825','printshop-mobile','block-13264','BlockBox','',3),(13276,'118826','printshop-mobile','block-13275','BlockBox','',1),(13277,'118827','printshop-mobile','block-13276','Html_box','',1),(13278,'118828','printshop-mobile','block-13276','checkout\\ShippingConfirm','',3),(13279,'118829','printshop-mobile','block-13275-2','BlockBox','',1),(13280,'118830','printshop-mobile','block-13279','checkout\\PaymentMethodConfirm','',3),(13281,'118831','printshop-mobile','block-13279','Html_box','',1),(13282,'118832','printshop-mobile','block-13264','checkout\\EditBtn','',6),(13283,'118833','printshop-mobile','block-13264','checkout\\Totals','',8),(13284,'118834','printshop-mobile','block-13264','Html_box','',5),(13285,'118835','printshop-mobile','checkout_confirmation_no_shipping_q','BlockBox','',1),(13286,'118836','printshop-mobile','block-13285','checkout\\Totals','',5),(13287,'118837','printshop-mobile','block-13285','checkout\\ConfirmBtn','',6),(13288,'118838','printshop-mobile','block-13285','BlockBox','',1),(13289,'118839','printshop-mobile','block-13288','BlockBox','',1),(13290,'118840','printshop-mobile','block-13289','Html_box','',1),(13291,'118841','printshop-mobile','block-13289','checkout\\BillingAddressConfirm','',3),(13292,'118842','printshop-mobile','block-13288-2','BlockBox','',1),(13293,'118843','printshop-mobile','block-13292','Html_box','',1),(13294,'118844','printshop-mobile','block-13292','checkout\\PaymentMethodConfirm','',3),(13295,'118845','printshop-mobile','block-13285','Html_box','',3),(13296,'118846','printshop-mobile','block-13285','quote\\Products','',4),(13297,'118847','printshop-mobile','block-13285','checkout\\ConfirmBtn','',2),(13298,'118848','printshop-mobile','checkout_confirmation_no_shipping','BlockBox','',1),(13299,'118849','printshop-mobile','block-13298','Html_box','',5),(13300,'118850','printshop-mobile','block-13298','checkout\\ConfirmBtn','',4),(13301,'118851','printshop-mobile','block-13298','cart\\Products','',7),(13302,'118852','printshop-mobile','block-13298','checkout\\Totals','',8),(13303,'118853','printshop-mobile','block-13298','checkout\\ConfirmBtn','',9),(13304,'118854','printshop-mobile','block-13298','BlockBox','',2),(13305,'118855','printshop-mobile','block-13304','BlockBox','',1),(13306,'118856','printshop-mobile','block-13305','checkout\\BillingAddressConfirm','',3),(13307,'118857','printshop-mobile','block-13305','Html_box','',1),(13308,'118858','printshop-mobile','block-13304-2','BlockBox','',1),(13309,'118859','printshop-mobile','block-13308','Html_box','',1),(13310,'118860','printshop-mobile','block-13308','checkout\\PaymentMethodConfirm','',3),(13311,'118861','printshop-mobile','checkout_confirmation_q','BlockBox','',1),(13312,'118862','printshop-mobile','block-13311','BlockBox','',2),(13313,'118863','printshop-mobile','block-13312','BlockBox','',1),(13314,'118864','printshop-mobile','block-13313','checkout\\ShippingConfirm','',3),(13315,'118865','printshop-mobile','block-13313','Html_box','',1),(13316,'118866','printshop-mobile','block-13312-2','BlockBox','',1),(13317,'118867','printshop-mobile','block-13316','Html_box','',1),(13318,'118868','printshop-mobile','block-13316','checkout\\PaymentMethodConfirm','',3),(13319,'118869','printshop-mobile','block-13311','checkout\\ConfirmBtn','',8),(13320,'118870','printshop-mobile','block-13311','checkout\\ConfirmBtn','',3),(13321,'118871','printshop-mobile','block-13311','checkout\\EditBtn','',5),(13322,'118872','printshop-mobile','block-13311','quote\\Products','',6),(13323,'118873','printshop-mobile','block-13311','Html_box','',4),(13324,'118874','printshop-mobile','block-13311','checkout\\Totals','',7),(13325,'118875','printshop-mobile','block-13311','BlockBox','',1),(13326,'118876','printshop-mobile','block-13325','BlockBox','',1),(13327,'118877','printshop-mobile','block-13326','checkout\\ShippingAddressConfirm','',3),(13328,'118878','printshop-mobile','block-13326','Html_box','',1),(13329,'118879','printshop-mobile','block-13325-2','BlockBox','',1),(13330,'118880','printshop-mobile','block-13329','Html_box','',1),(13331,'118881','printshop-mobile','block-13329','checkout\\BillingAddressConfirm','',3),(13332,'118882','printshop-mobile','checkout_confirmation_title','Html_box','',1),(13333,'118883','printshop-mobile','checkout_confirmation_title_g','Html_box','',1),(13334,'118884','printshop-mobile','checkout_confirmation_title_no_shipping_g','Html_box','',1),(13335,'118885','printshop-mobile','checkout_confirmation_title_no_shipping','Html_box','',1),(13336,'118886','printshop-mobile','checkout_confirmation_title_q','Html_box','',1),(13337,'118887','printshop-mobile','checkout_confirmation_title_s','Html_box','',1),(13338,'118888','printshop-mobile','checkout_delivery','BlockBox','',1),(13339,'118889','printshop-mobile','block-13338','BlockBox','',1),(13340,'118890','printshop-mobile','block-13339','checkout\\ShippingAddress','',2),(13341,'118891','printshop-mobile','block-13339','Html_box','',1),(13342,'118892','printshop-mobile','block-13338-2','BlockBox','',1),(13343,'118893','printshop-mobile','block-13342','Neighbour\\Checkout','',4),(13344,'118894','printshop-mobile','block-13342','Html_box','',1),(13345,'118895','printshop-mobile','block-13342','checkout\\Shipping','',2),(13346,'118896','printshop-mobile','block-13342','DelayedDespatch\\Checkout','',3),(13347,'118897','printshop-mobile','checkout_delivery','BlockBox','',2),(13348,'118898','printshop-mobile','block-13347','BlockBox','',1),(13349,'118899','printshop-mobile','block-13348','Html_box','',1),(13350,'118900','printshop-mobile','block-13348','checkout\\ContactInformation','',2),(13351,'118901','printshop-mobile','block-13347-2','BlockBox','',1),(13352,'118902','printshop-mobile','block-13351','Html_box','',1),(13353,'118903','printshop-mobile','block-13351','checkout\\Comments','',2),(13354,'118904','printshop-mobile','checkout_delivery','BlockBox','',3),(13355,'118905','printshop-mobile','block-13354','Html_box','',1),(13356,'118906','printshop-mobile','block-13354-2','checkout\\ContinueBtn','',1),(13357,'118907','printshop-mobile','checkout_delivery_g','BlockBox','',1),(13358,'118908','printshop-mobile','block-13357','BlockBox','',1),(13359,'118909','printshop-mobile','block-13358','checkout\\ShippingAddress','',2),(13360,'118910','printshop-mobile','block-13358','Html_box','',1),(13361,'118911','printshop-mobile','block-13357-2','BlockBox','',1),(13362,'118912','printshop-mobile','block-13361','Html_box','',1),(13363,'118913','printshop-mobile','block-13361','Neighbour\\Checkout','',4),(13364,'118914','printshop-mobile','block-13361','checkout\\Shipping','',2),(13365,'118915','printshop-mobile','block-13361','DelayedDespatch\\Checkout','',3),(13366,'118916','printshop-mobile','checkout_delivery_g','BlockBox','',3),(13367,'118917','printshop-mobile','block-13366','Html_box','',1),(13368,'118918','printshop-mobile','block-13366-2','checkout\\ContinueBtn','',1),(13369,'118919','printshop-mobile','checkout_delivery_g','BlockBox','',2),(13370,'118920','printshop-mobile','block-13369','BlockBox','',1),(13371,'118921','printshop-mobile','block-13370','checkout\\ContactInformation','',2),(13372,'118922','printshop-mobile','block-13370','Html_box','',1),(13373,'118923','printshop-mobile','block-13369-2','BlockBox','',1),(13374,'118924','printshop-mobile','block-13373','checkout\\Comments','',2),(13375,'118925','printshop-mobile','block-13373','Html_box','',1),(13376,'118926','printshop-mobile','checkout_delivery_no_shipping','BlockBox','',2),(13377,'118927','printshop-mobile','block-13376','Html_box','',1),(13378,'118928','printshop-mobile','block-13376-2','checkout\\ContinueBtn','',1),(13379,'118929','printshop-mobile','checkout_delivery_no_shipping','BlockBox','',1),(13380,'118930','printshop-mobile','block-13379','BlockBox','',1),(13381,'118931','printshop-mobile','block-13380','checkout\\ContactInformation','',2),(13382,'118932','printshop-mobile','block-13379-2','BlockBox','',1),(13383,'118933','printshop-mobile','block-13382','checkout\\Comments','',2),(13384,'118934','printshop-mobile','block-13382','Html_box','',1),(13385,'118935','printshop-mobile','checkout_delivery_no_shipping_g','BlockBox','',1),(13386,'118936','printshop-mobile','block-13385','BlockBox','',1),(13387,'118937','printshop-mobile','block-13386','checkout\\ContactInformation','',2),(13388,'118938','printshop-mobile','block-13385-2','BlockBox','',1),(13389,'118939','printshop-mobile','block-13388','Html_box','',1),(13390,'118940','printshop-mobile','block-13388','checkout\\Comments','',2),(13391,'118941','printshop-mobile','checkout_delivery_no_shipping_g','BlockBox','',2),(13392,'118942','printshop-mobile','block-13391','Html_box','',1),(13393,'118943','printshop-mobile','block-13391-2','checkout\\ContinueBtn','',1),(13394,'118944','printshop-mobile','checkout_delivery_title','Html_box','',1),(13395,'118945','printshop-mobile','checkout_delivery_title_g','Html_box','',1),(13396,'118946','printshop-mobile','checkout_delivery_title_no_shipping_g','Html_box','',1),(13397,'118947','printshop-mobile','checkout_delivery_title_no_shipping','Html_box','',1),(13398,'118948','printshop-mobile','checkout_delivery_title_q','Html_box','',1),(13399,'118949','printshop-mobile','checkout_delivery_title_s','Html_box','',1),(13400,'118950','printshop-mobile','checkout_free_s','BlockBox','',1),(13401,'118951','printshop-mobile','block-13400','BlockBox','',2),(13402,'118952','printshop-mobile','block-13401','BlockBox','',2),(13403,'118953','printshop-mobile','block-13402','BlockBox','',2),(13404,'118954','printshop-mobile','block-13403','Neighbour\\Checkout','',4),(13405,'118955','printshop-mobile','block-13403','BlockBox','',3),(13406,'118956','printshop-mobile','block-13405','BlockBox','',1),(13407,'118957','printshop-mobile','block-13406','checkout\\ShippingAddress','',2),(13408,'118958','printshop-mobile','block-13406','Html_box','',3),(13409,'118959','printshop-mobile','block-13406','checkout\\ContactInformation','',4),(13410,'118960','printshop-mobile','block-13405-2','BlockBox','',1),(13411,'118961','printshop-mobile','block-13410','DelayedDespatch\\Checkout','',3),(13412,'118962','printshop-mobile','block-13403','Html_box','',1),(13413,'118963','printshop-mobile','block-13403','BlockBox','',2),(13414,'118964','printshop-mobile','block-13413','checkout\\ShippingChoice','',1),(13415,'118965','printshop-mobile','block-13402','BlockBox','',5),(13416,'118966','printshop-mobile','block-13415','Html_box','',1),(13417,'118967','printshop-mobile','block-13415','checkout\\Comments','',2),(13418,'118968','printshop-mobile','block-13402','checkout\\Gdpr','',1),(13419,'118969','printshop-mobile','block-13402','BlockBox','',6),(13420,'118970','printshop-mobile','block-13419','checkout\\CreateAccount','',3),(13421,'118971','printshop-mobile','block-13419','sample\\Products','',1),(13422,'118972','printshop-mobile','block-13401-2','BlockBox','',1),(13423,'118973','printshop-mobile','block-13422','checkout\\ContinueBtn','',3),(13424,'118974','printshop-mobile','block-13422','Html_box','',4),(13425,'118975','printshop-mobile','checkout_no_shipping','BlockBox','',1),(13426,'118976','printshop-mobile','block-13425','BlockBox','',2),(13427,'118977','printshop-mobile','block-13426','BlockBox','',1),(13428,'118978','printshop-mobile','block-13427','BlockBox','',5),(13429,'118979','printshop-mobile','block-13428','Html_box','',1),(13430,'118980','printshop-mobile','block-13428','checkout\\Comments','',2),(13431,'118981','printshop-mobile','block-13427','BlockBox','',4),(13432,'118982','printshop-mobile','block-13431','BlockBox','',2),(13433,'118983','printshop-mobile','block-13432','CouponsAndVauchers\\Checkout','',1),(13434,'118984','printshop-mobile','block-13432-2','checkout\\BonusPoints','',2),(13435,'118985','printshop-mobile','block-13432-2','checkout\\CreditAmount','',1),(13436,'118986','printshop-mobile','block-13431','Html_box','',1),(13437,'118987','printshop-mobile','block-13427','BlockBox','',3),(13438,'118988','printshop-mobile','block-13437','BlockBox','',2),(13439,'118989','printshop-mobile','block-13438','Html_box','',1),(13440,'118990','printshop-mobile','block-13438','checkout\\BillingAddress','',2),(13441,'118991','printshop-mobile','block-13438-2','BlockBox','',1),(13442,'118992','printshop-mobile','block-13441','Html_box','',1),(13443,'118993','printshop-mobile','block-13441','checkout\\PaymentMethod','',2),(13444,'118994','printshop-mobile','block-13437','Html_box','',1),(13445,'118995','printshop-mobile','block-13427','BlockBox','',6),(13446,'118996','printshop-mobile','block-13445','cart\\Products','',1),(13447,'118997','printshop-mobile','block-13445','checkout\\CreateAccount','',2),(13448,'118998','printshop-mobile','block-13426-2','BlockBox','',1),(13449,'118999','printshop-mobile','block-13448','checkout\\Terms','',4),(13450,'119000','printshop-mobile','block-13448','checkout\\ContinueBtn','',3),(13451,'119001','printshop-mobile','block-13448','checkout\\Totals','',2),(13452,'119002','printshop-mobile','block-13448','Html_box','',5),(13453,'119003','printshop-mobile','block-13448','Html_box','',1),(13454,'119004','printshop-mobile','checkout_no_shipping_g','BlockBox','',1),(13455,'119005','printshop-mobile','block-13454','quote\\Products','',3),(13456,'119006','printshop-mobile','block-13454','BlockBox','',1),(13457,'119007','printshop-mobile','block-13456','BlockBox','',1),(13458,'119008','printshop-mobile','block-13457','checkout\\BillingAddress','',2),(13459,'119009','printshop-mobile','block-13457','Html_box','',1),(13460,'119010','printshop-mobile','block-13456-2','BlockBox','',1),(13461,'119011','printshop-mobile','block-13460','checkout\\CreditAmount','',3),(13462,'119012','printshop-mobile','block-13460','Html_box','',1),(13463,'119013','printshop-mobile','block-13460','checkout\\PaymentMethod','',2),(13464,'119014','printshop-mobile','block-13460','CouponsAndVauchers\\Checkout','',5),(13465,'119015','printshop-mobile','block-13460','checkout\\BonusPoints','',4),(13466,'119016','printshop-mobile','block-13454','BlockBox','',2),(13467,'119017','printshop-mobile','block-13466','BlockBox','',1),(13468,'119018','printshop-mobile','block-13467','Html_box','',1),(13469,'119019','printshop-mobile','block-13467','checkout\\ContactInformation','',2),(13470,'119020','printshop-mobile','block-13466-2','BlockBox','',1),(13471,'119021','printshop-mobile','block-13470','Html_box','',1),(13472,'119022','printshop-mobile','block-13470','checkout\\Comments','',2),(13473,'119023','printshop-mobile','block-13454','BlockBox','',6),(13474,'119024','printshop-mobile','block-13473','Html_box','',1),(13475,'119025','printshop-mobile','block-13473-2','checkout\\ContinueBtn','',1),(13476,'119026','printshop-mobile','block-13454','checkout\\Totals','',5),(13477,'119027','printshop-mobile','checkout_no_shipping_q','BlockBox','',1),(13478,'119028','printshop-mobile','block-13477','BlockBox','',2),(13479,'119029','printshop-mobile','block-13478','BlockBox','',2),(13480,'119030','printshop-mobile','block-13479','BlockBox','',3),(13481,'119031','printshop-mobile','block-13480','BlockBox','',2),(13482,'119032','printshop-mobile','block-13481','checkout\\BillingAddress','',2),(13483,'119033','printshop-mobile','block-13481','Html_box','',1),(13484,'119034','printshop-mobile','block-13481-2','BlockBox','',1),(13485,'119035','printshop-mobile','block-13484','Html_box','',1),(13486,'119036','printshop-mobile','block-13484','checkout\\PaymentMethod','',2),(13487,'119037','printshop-mobile','block-13480','Html_box','',1),(13488,'119038','printshop-mobile','block-13479','BlockBox','',6),(13489,'119039','printshop-mobile','block-13488','checkout\\CreateAccount','',3),(13490,'119040','printshop-mobile','block-13488','quote\\Products','',2),(13491,'119041','printshop-mobile','block-13479','BlockBox','',5),(13492,'119042','printshop-mobile','block-13491','checkout\\Comments','',2),(13493,'119043','printshop-mobile','block-13491','Html_box','',1),(13494,'119044','printshop-mobile','block-13479','checkout\\Gdpr','',1),(13495,'119045','printshop-mobile','block-13478-2','BlockBox','',1),(13496,'119046','printshop-mobile','block-13495','Html_box','',4),(13497,'119047','printshop-mobile','block-13495','checkout\\Totals','',2),(13498,'119048','printshop-mobile','block-13495','checkout\\ContinueBtn','',3),(13499,'119049','printshop-mobile','block-13495','Html_box','',1),(13500,'119050','printshop-mobile','checkout_payment','BlockBox','',2),(13501,'119051','printshop-mobile','block-13500','Html_box','',1),(13502,'119052','printshop-mobile','block-13500-2','checkout\\ContinueBtn','',1),(13503,'119053','printshop-mobile','checkout_payment','BlockBox','',1),(13504,'119054','printshop-mobile','block-13503','BlockBox','',1),(13505,'119055','printshop-mobile','block-13504','checkout\\BillingAddress','',2),(13506,'119056','printshop-mobile','block-13504','Html_box','',1),(13507,'119057','printshop-mobile','block-13503-2','BlockBox','',1),(13508,'119058','printshop-mobile','block-13507','checkout\\PaymentMethod','',2),(13509,'119059','printshop-mobile','block-13507','Html_box','',1),(13510,'119060','printshop-mobile','block-13507','checkout\\CreditAmount','',3),(13511,'119061','printshop-mobile','block-13507','CouponsAndVauchers\\Checkout','',5),(13512,'119062','printshop-mobile','block-13507','checkout\\BonusPoints','',4),(13513,'119063','printshop-mobile','checkout_payment_g','BlockBox','',1),(13514,'119064','printshop-mobile','block-13513','BlockBox','',1),(13515,'119065','printshop-mobile','block-13514','Html_box','',1),(13516,'119066','printshop-mobile','block-13514','checkout\\BillingAddress','',2),(13517,'119067','printshop-mobile','block-13513-2','BlockBox','',1),(13518,'119068','printshop-mobile','block-13517','checkout\\BonusPoints','',4),(13519,'119069','printshop-mobile','block-13517','Html_box','',1),(13520,'119070','printshop-mobile','block-13517','CouponsAndVauchers\\Checkout','',5),(13521,'119071','printshop-mobile','block-13517','checkout\\CreditAmount','',3),(13522,'119072','printshop-mobile','block-13517','checkout\\PaymentMethod','',2),(13523,'119073','printshop-mobile','checkout_payment_g','BlockBox','',2),(13524,'119074','printshop-mobile','block-13523','Html_box','',1),(13525,'119075','printshop-mobile','block-13523-2','checkout\\ContinueBtn','',1),(13526,'119076','printshop-mobile','checkout_payment_no_shipping','BlockBox','',1),(13527,'119077','printshop-mobile','block-13526','BlockBox','',1),(13528,'119078','printshop-mobile','block-13527','Html_box','',1),(13529,'119079','printshop-mobile','block-13527','checkout\\BillingAddress','',2),(13530,'119080','printshop-mobile','block-13526-2','BlockBox','',1),(13531,'119081','printshop-mobile','block-13530','Html_box','',1),(13532,'119082','printshop-mobile','block-13530','checkout\\PaymentMethod','',2),(13533,'119083','printshop-mobile','block-13530','checkout\\CreditAmount','',3),(13534,'119084','printshop-mobile','block-13530','CouponsAndVauchers\\Checkout','',5),(13535,'119085','printshop-mobile','block-13530','checkout\\BonusPoints','',4),(13536,'119086','printshop-mobile','checkout_payment_no_shipping','BlockBox','',2),(13537,'119087','printshop-mobile','block-13536','Html_box','',1),(13538,'119088','printshop-mobile','block-13536-2','checkout\\ContinueBtn','',1),(13539,'119089','printshop-mobile','checkout_payment_no_shipping_g','BlockBox','',2),(13540,'119090','printshop-mobile','block-13539','Html_box','',1),(13541,'119091','printshop-mobile','block-13539-2','checkout\\ContinueBtn','',1),(13542,'119092','printshop-mobile','checkout_payment_no_shipping_g','BlockBox','',1),(13543,'119093','printshop-mobile','block-13542','BlockBox','',1),(13544,'119094','printshop-mobile','block-13543','checkout\\BillingAddress','',2),(13545,'119095','printshop-mobile','block-13543','Html_box','',1),(13546,'119096','printshop-mobile','block-13542-2','BlockBox','',1),(13547,'119097','printshop-mobile','block-13546','checkout\\PaymentMethod','',2),(13548,'119098','printshop-mobile','block-13546','Html_box','',1),(13549,'119099','printshop-mobile','block-13546','checkout\\CreditAmount','',3),(13550,'119100','printshop-mobile','block-13546','CouponsAndVauchers\\Checkout','',5),(13551,'119101','printshop-mobile','block-13546','checkout\\BonusPoints','',4),(13552,'119102','printshop-mobile','checkout_payment_title','Html_box','',1),(13553,'119103','printshop-mobile','checkout_payment_title_g','Html_box','',1),(13554,'119104','printshop-mobile','checkout_payment_title_no_shipping','Html_box','',1),(13555,'119105','printshop-mobile','checkout_payment_title_no_shipping_g','Html_box','',1),(13556,'119106','printshop-mobile','checkout_payment_title_q','Html_box','',1),(13557,'119107','printshop-mobile','checkout_payment_title_s','Html_box','',1),(13558,'119108','printshop-mobile','checkout_q','BlockBox','',1),(13559,'119109','printshop-mobile','block-13558','BlockBox','',2),(13560,'119110','printshop-mobile','block-13559','BlockBox','',2),(13561,'119111','printshop-mobile','block-13560','BlockBox','',3),(13562,'119112','printshop-mobile','block-13561','BlockBox','',2),(13563,'119113','printshop-mobile','block-13562','checkout\\BillingAddress','',2),(13564,'119114','printshop-mobile','block-13562','Html_box','',1),(13565,'119115','printshop-mobile','block-13562-2','BlockBox','',1),(13566,'119116','printshop-mobile','block-13565','Html_box','',1),(13567,'119117','printshop-mobile','block-13565','checkout\\PaymentMethod','',2),(13568,'119118','printshop-mobile','block-13561','Html_box','',1),(13569,'119119','printshop-mobile','block-13560','BlockBox','',5),(13570,'119120','printshop-mobile','block-13569','Html_box','',1),(13571,'119121','printshop-mobile','block-13569','checkout\\Comments','',2),(13572,'119122','printshop-mobile','block-13560','checkout\\Gdpr','',1),(13573,'119123','printshop-mobile','block-13560','BlockBox','',2),(13574,'119124','printshop-mobile','block-13573','BlockBox','',3),(13575,'119125','printshop-mobile','block-13574','BlockBox','',1),(13576,'119126','printshop-mobile','block-13575','Html_box','',3),(13577,'119127','printshop-mobile','block-13575','checkout\\ShippingAddress','',2),(13578,'119128','printshop-mobile','block-13575','checkout\\ContactInformation','',4),(13579,'119129','printshop-mobile','block-13574-2','BlockBox','',1),(13580,'119130','printshop-mobile','block-13579','DelayedDespatch\\Checkout','',3),(13581,'119131','printshop-mobile','block-13579','Html_box','',1),(13582,'119132','printshop-mobile','block-13579','checkout\\Shipping','',2),(13583,'119133','printshop-mobile','block-13573','Html_box','',1),(13584,'119134','printshop-mobile','block-13573','Neighbour\\Checkout','',4),(13585,'119135','printshop-mobile','block-13573','BlockBox','',2),(13586,'119136','printshop-mobile','block-13585','checkout\\ShippingChoice','',1),(13587,'119137','printshop-mobile','block-13560','BlockBox','',6),(13588,'119138','printshop-mobile','block-13587','quote\\Products','',2),(13589,'119139','printshop-mobile','block-13587','checkout\\CreateAccount','',3),(13590,'119140','printshop-mobile','block-13559-2','BlockBox','',1),(13591,'119141','printshop-mobile','block-13590','checkout\\ContinueBtn','',3),(13592,'119142','printshop-mobile','block-13590','checkout\\Totals','',2),(13593,'119143','printshop-mobile','block-13590','Html_box','',4),(13594,'119144','printshop-mobile','block-13590','Html_box','',1),(13595,'119145','printshop-mobile','checkout_s','BlockBox','',1),(13596,'119146','printshop-mobile','block-13595','BlockBox','',2),(13597,'119147','printshop-mobile','block-13596','BlockBox','',2),(13598,'119148','printshop-mobile','block-13597','BlockBox','',4),(13599,'119149','printshop-mobile','block-13598','BlockBox','',2),(13600,'119150','printshop-mobile','block-13599','CouponsAndVauchers\\Checkout','',1),(13601,'119151','printshop-mobile','block-13599-2','checkout\\CreditAmount','',1),(13602,'119152','printshop-mobile','block-13599-2','checkout\\BonusPoints','',2),(13603,'119153','printshop-mobile','block-13598','Html_box','',1),(13604,'119154','printshop-mobile','block-13597','BlockBox','',3),(13605,'119155','printshop-mobile','block-13604','Html_box','',1),(13606,'119156','printshop-mobile','block-13604','BlockBox','',2),(13607,'119157','printshop-mobile','block-13606','checkout\\BillingAddress','',2),(13608,'119158','printshop-mobile','block-13606','Html_box','',1),(13609,'119159','printshop-mobile','block-13606-2','BlockBox','',1),(13610,'119160','printshop-mobile','block-13609','checkout\\PaymentMethod','',2),(13611,'119161','printshop-mobile','block-13609','Html_box','',1),(13612,'119162','printshop-mobile','block-13597','BlockBox','',5),(13613,'119163','printshop-mobile','block-13612','checkout\\Comments','',2),(13614,'119164','printshop-mobile','block-13612','Html_box','',1),(13615,'119165','printshop-mobile','block-13597','BlockBox','',2),(13616,'119166','printshop-mobile','block-13615','BlockBox','',2),(13617,'119167','printshop-mobile','block-13616','checkout\\ShippingChoice','',1),(13618,'119168','printshop-mobile','block-13615','Html_box','',1),(13619,'119169','printshop-mobile','block-13615','BlockBox','',3),(13620,'119170','printshop-mobile','block-13619','BlockBox','',1),(13621,'119171','printshop-mobile','block-13620','checkout\\ShippingAddress','',2),(13622,'119172','printshop-mobile','block-13620','Html_box','',3),(13623,'119173','printshop-mobile','block-13620','checkout\\ContactInformation','',4),(13624,'119174','printshop-mobile','block-13619-2','BlockBox','',1),(13625,'119175','printshop-mobile','block-13624','DelayedDespatch\\Checkout','',3),(13626,'119176','printshop-mobile','block-13624','Html_box','',1),(13627,'119177','printshop-mobile','block-13624','checkout\\Shipping','',2),(13628,'119178','printshop-mobile','block-13615','Neighbour\\Checkout','',4),(13629,'119179','printshop-mobile','block-13597','BlockBox','',6),(13630,'119180','printshop-mobile','block-13629','checkout\\CreateAccount','',3),(13631,'119181','printshop-mobile','block-13629','sample\\Products','',1),(13632,'119182','printshop-mobile','block-13597','checkout\\Gdpr','',1),(13633,'119183','printshop-mobile','block-13596-2','BlockBox','',1),(13634,'119184','printshop-mobile','block-13633','Html_box','',1),(13635,'119185','printshop-mobile','block-13633','checkout\\ContinueBtn','',3),(13636,'119186','printshop-mobile','block-13633','Html_box','',4),(13637,'119187','printshop-mobile','block-13633','checkout\\Totals','',2),(13638,'119188','printshop-mobile','checkout_step_bottom','cart\\Products','',2),(13639,'119189','printshop-mobile','checkout_step_bottom','checkout\\Totals','',3),(13640,'119190','printshop-mobile','checkout_step_bottom','Html_box','',1),(13641,'119191','printshop-mobile','checkout_step_bottom_g','checkout\\Totals','',3),(13642,'119192','printshop-mobile','checkout_step_bottom_g','quote\\Products','',2),(13643,'119193','printshop-mobile','checkout_step_bottom_g','Html_box','',1),(13644,'119194','printshop-mobile','checkout_step_bottom_no_shipping_g','Html_box','',1),(13645,'119195','printshop-mobile','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(13646,'119196','printshop-mobile','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(13647,'119197','printshop-mobile','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(13648,'119198','printshop-mobile','checkout_step_bottom_no_shipping','Html_box','',1),(13649,'119199','printshop-mobile','checkout_step_bottom_no_shipping','cart\\Products','',2),(13650,'119200','printshop-mobile','communication','BlockBox','',1),(13651,'119201','printshop-mobile','block-13650','Html_box','',2),(13652,'119202','printshop-mobile','block-13650','Communication\\Topic','',3),(13653,'119203','printshop-mobile','block-13650','Communication\\NewTopicButton','',1),(13654,'119204','printshop-mobile','compare','BlockBox','',1),(13655,'119205','printshop-mobile','block-13654','catalog\\Compare','',1),(13656,'119206','printshop-mobile','compare_products','BlockBox','',2),(13657,'119207','printshop-mobile','block-13656','productListing\\rating','',4),(13658,'119208','printshop-mobile','block-13656','productListing\\model','',5),(13659,'119209','printshop-mobile','block-13656','productListing\\compare','',1),(13660,'119210','printshop-mobile','block-13656','BlockBox','',2),(13661,'119211','printshop-mobile','block-13660','productListing\\image','',1),(13662,'119212','printshop-mobile','block-13660-2','productListing\\name','',2),(13663,'119213','printshop-mobile','block-13656','BlockBox','',3),(13664,'119214','printshop-mobile','block-13663','productListing\\price','',1),(13665,'119215','printshop-mobile','block-13663-2','productListing\\buyButton','',1),(13666,'119216','printshop-mobile','confirmation','BlockBox','',1),(13667,'119217','printshop-mobile','block-13666','BlockBox','',2),(13668,'119218','printshop-mobile','block-13667','UploadCustomerId\\UploadCustomerIdForm','',1),(13669,'119219','printshop-mobile','block-13667','BlockBox','',2),(13670,'119220','printshop-mobile','block-13669','BlockBox','',1),(13671,'119221','printshop-mobile','block-13670','BlockBox','',1),(13672,'119222','printshop-mobile','block-13671','checkout\\ShippingAddressConfirm','',4),(13673,'119223','printshop-mobile','block-13671','Html_box','',1),(13674,'119224','printshop-mobile','block-13671','Html_box','',2),(13675,'119225','printshop-mobile','block-13671','checkout\\ContactConfirm','',11),(13676,'119226','printshop-mobile','block-13671','checkout\\EditBtn','',3),(13677,'119227','printshop-mobile','block-13671','Html_box','',5),(13678,'119228','printshop-mobile','block-13671','DelayedDespatch\\CheckoutConfirm','',8),(13679,'119229','printshop-mobile','block-13671','checkout\\EditBtn','',10),(13680,'119230','printshop-mobile','block-13671','checkout\\EditBtn','',6),(13681,'119231','printshop-mobile','block-13671','Html_box','',9),(13682,'119232','printshop-mobile','block-13671','checkout\\ShippingConfirm','',7),(13683,'119233','printshop-mobile','block-13670','BlockBox','',2),(13684,'119234','printshop-mobile','block-13683','Html_box','',2),(13685,'119235','printshop-mobile','block-13683','checkout\\BillingAddressConfirm','',4),(13686,'119236','printshop-mobile','block-13683','Html_box','',5),(13687,'119237','printshop-mobile','block-13683','checkout\\PaymentMethodConfirm','',7),(13688,'119238','printshop-mobile','block-13683','Html_box','',1),(13689,'119239','printshop-mobile','block-13683','checkout\\EditBtn','',3),(13690,'119240','printshop-mobile','block-13683','checkout\\EditBtn','',6),(13691,'119241','printshop-mobile','block-13669','BlockBox','',3),(13692,'119242','printshop-mobile','block-13691','Html_box','',1),(13693,'119243','printshop-mobile','block-13691','checkout\\EditBtn','',2),(13694,'119244','printshop-mobile','block-13691','cart\\Products','',3),(13695,'119245','printshop-mobile','block-13669','BlockBox','',2),(13696,'119246','printshop-mobile','block-13695','Html_box','',1),(13697,'119247','printshop-mobile','block-13695','checkout\\CommentsConfirm','',3),(13698,'119248','printshop-mobile','block-13695','checkout\\EditBtn','',2),(13699,'119249','printshop-mobile','block-13669','BlockBox','',4),(13700,'119250','printshop-mobile','block-13699','checkout\\Totals','',2),(13701,'119251','printshop-mobile','block-13699','Html_box','',1),(13702,'119252','printshop-mobile','block-13699','checkout\\ConfirmBtn','',3),(13703,'119253','printshop-mobile','block-13666','Html_box','',1),(13704,'119254','printshop-mobile','confirmation_free_s','BlockBox','',1),(13705,'119255','printshop-mobile','block-13704','Html_box','',1),(13706,'119256','printshop-mobile','block-13704','BlockBox','',2),(13707,'119257','printshop-mobile','block-13706','BlockBox','',1),(13708,'119258','printshop-mobile','block-13707','BlockBox','',1),(13709,'119259','printshop-mobile','block-13708','BlockBox','',1),(13710,'119260','printshop-mobile','block-13709','checkout\\EditBtn','',6),(13711,'119261','printshop-mobile','block-13709','checkout\\ShippingAddressConfirm','',4),(13712,'119262','printshop-mobile','block-13709','Html_box','',2),(13713,'119263','printshop-mobile','block-13709','checkout\\ShippingConfirm','',7),(13714,'119264','printshop-mobile','block-13709','checkout\\EditBtn','',3),(13715,'119265','printshop-mobile','block-13709','Html_box','',5),(13716,'119266','printshop-mobile','block-13708-2','BlockBox','',1),(13717,'119267','printshop-mobile','block-13716','Html_box','',1),(13718,'119268','printshop-mobile','block-13716','checkout\\EditBtn','',2),(13719,'119269','printshop-mobile','block-13716','DelayedDespatch\\CheckoutConfirm','',4),(13720,'119270','printshop-mobile','block-13716','checkout\\ContactConfirm','',3),(13721,'119271','printshop-mobile','block-13707','BlockBox','',2),(13722,'119272','printshop-mobile','block-13721','checkout\\CommentsConfirm','',3),(13723,'119273','printshop-mobile','block-13721','checkout\\EditBtn','',2),(13724,'119274','printshop-mobile','block-13721','Html_box','',1),(13725,'119275','printshop-mobile','block-13707','BlockBox','',3),(13726,'119276','printshop-mobile','block-13725','sample\\Products','',2),(13727,'119277','printshop-mobile','block-13725','Html_box','',1),(13728,'119278','printshop-mobile','block-13725','checkout\\EditBtn','',3),(13729,'119279','printshop-mobile','block-13706-2','BlockBox','',1),(13730,'119280','printshop-mobile','block-13729','checkout\\ConfirmBtn','',3),(13731,'119281','printshop-mobile','confirmation_no_shipping','BlockBox','',1),(13732,'119282','printshop-mobile','block-13731','Html_box','',1),(13733,'119283','printshop-mobile','block-13731','BlockBox','',2),(13734,'119284','printshop-mobile','block-13733','BlockBox','',1),(13735,'119285','printshop-mobile','block-13734','BlockBox','',3),(13736,'119286','printshop-mobile','block-13735','checkout\\EditBtn','',2),(13737,'119287','printshop-mobile','block-13735','Html_box','',1),(13738,'119288','printshop-mobile','block-13735','cart\\Products','',3),(13739,'119289','printshop-mobile','block-13734','BlockBox','',2),(13740,'119290','printshop-mobile','block-13739','checkout\\EditBtn','',2),(13741,'119291','printshop-mobile','block-13739','checkout\\CommentsConfirm','',3),(13742,'119292','printshop-mobile','block-13739','Html_box','',1),(13743,'119293','printshop-mobile','block-13734','BlockBox','',1),(13744,'119294','printshop-mobile','block-13743','BlockBox','',1),(13745,'119295','printshop-mobile','block-13744','Html_box','',9),(13746,'119296','printshop-mobile','block-13744','checkout\\ContactConfirm','',11),(13747,'119297','printshop-mobile','block-13744','checkout\\EditBtn','',10),(13748,'119298','printshop-mobile','block-13743-2','BlockBox','',1),(13749,'119299','printshop-mobile','block-13748','checkout\\EditBtn','',3),(13750,'119300','printshop-mobile','block-13748','Html_box','',2),(13751,'119301','printshop-mobile','block-13748','Html_box','',1),(13752,'119302','printshop-mobile','block-13748','Html_box','',5),(13753,'119303','printshop-mobile','block-13748','checkout\\BillingAddressConfirm','',4),(13754,'119304','printshop-mobile','block-13748','checkout\\PaymentMethodConfirm','',7),(13755,'119305','printshop-mobile','block-13748','checkout\\EditBtn','',6),(13756,'119306','printshop-mobile','block-13733-2','BlockBox','',1),(13757,'119307','printshop-mobile','block-13756','checkout\\ConfirmBtn','',3),(13758,'119308','printshop-mobile','block-13756','checkout\\Totals','',2),(13759,'119309','printshop-mobile','block-13756','Html_box','',1),(13760,'119310','printshop-mobile','confirmation_no_shipping_q','BlockBox','',2),(13761,'119311','printshop-mobile','block-13760','BlockBox','',2),(13762,'119312','printshop-mobile','block-13761','BlockBox','',1),(13763,'119313','printshop-mobile','block-13762','BlockBox','',3),(13764,'119314','printshop-mobile','block-13763','quote\\Products','',3),(13765,'119315','printshop-mobile','block-13763','checkout\\EditBtn','',2),(13766,'119316','printshop-mobile','block-13763','Html_box','',1),(13767,'119317','printshop-mobile','block-13762','BlockBox','',1),(13768,'119318','printshop-mobile','block-13767','BlockBox','',1),(13769,'119319','printshop-mobile','block-13768','checkout\\EditBtn','',2),(13770,'119320','printshop-mobile','block-13768','Html_box','',1),(13771,'119321','printshop-mobile','block-13768','Html_box','',4),(13772,'119322','printshop-mobile','block-13768','checkout\\PaymentMethodConfirm','',3),(13773,'119323','printshop-mobile','block-13768','checkout\\EditBtn','',5),(13774,'119324','printshop-mobile','block-13768','checkout\\ContactConfirm','',6),(13775,'119325','printshop-mobile','block-13767-2','BlockBox','',1),(13776,'119326','printshop-mobile','block-13775','Html_box','',2),(13777,'119327','printshop-mobile','block-13775','checkout\\EditBtn','',3),(13778,'119328','printshop-mobile','block-13775','checkout\\BillingAddressConfirm','',4),(13779,'119329','printshop-mobile','block-13762','BlockBox','',2),(13780,'119330','printshop-mobile','block-13779','checkout\\CommentsConfirm','',3),(13781,'119331','printshop-mobile','block-13779','Html_box','',1),(13782,'119332','printshop-mobile','block-13779','checkout\\EditBtn','',2),(13783,'119333','printshop-mobile','block-13761-2','BlockBox','',1),(13784,'119334','printshop-mobile','block-13783','Html_box','',1),(13785,'119335','printshop-mobile','block-13783','checkout\\Totals','',2),(13786,'119336','printshop-mobile','block-13783','checkout\\ConfirmBtn','',3),(13787,'119337','printshop-mobile','block-13760','Html_box','',1),(13788,'119338','printshop-mobile','confirmation_q','BlockBox','',1),(13789,'119339','printshop-mobile','block-13788','Html_box','',1),(13790,'119340','printshop-mobile','block-13788','BlockBox','',2),(13791,'119341','printshop-mobile','block-13790','BlockBox','',1),(13792,'119342','printshop-mobile','block-13791','BlockBox','',3),(13793,'119343','printshop-mobile','block-13792','checkout\\EditBtn','',2),(13794,'119344','printshop-mobile','block-13792','Html_box','',1),(13795,'119345','printshop-mobile','block-13792','quote\\Products','',3),(13796,'119346','printshop-mobile','block-13791','BlockBox','',2),(13797,'119347','printshop-mobile','block-13796','checkout\\EditBtn','',2),(13798,'119348','printshop-mobile','block-13796','checkout\\CommentsConfirm','',3),(13799,'119349','printshop-mobile','block-13796','Html_box','',1),(13800,'119350','printshop-mobile','block-13791','BlockBox','',1),(13801,'119351','printshop-mobile','block-13800','BlockBox','',1),(13802,'119352','printshop-mobile','block-13801','Html_box','',5),(13803,'119353','printshop-mobile','block-13801','Html_box','',9),(13804,'119354','printshop-mobile','block-13801','checkout\\EditBtn','',6),(13805,'119355','printshop-mobile','block-13801','checkout\\ShippingConfirm','',7),(13806,'119356','printshop-mobile','block-13801','checkout\\EditBtn','',3),(13807,'119357','printshop-mobile','block-13801','DelayedDespatch\\CheckoutConfirm','',8),(13808,'119358','printshop-mobile','block-13801','checkout\\ShippingAddressConfirm','',4),(13809,'119359','printshop-mobile','block-13801','checkout\\ContactConfirm','',11),(13810,'119360','printshop-mobile','block-13801','checkout\\EditBtn','',10),(13811,'119361','printshop-mobile','block-13801','Html_box','',2),(13812,'119362','printshop-mobile','block-13801','Html_box','',1),(13813,'119363','printshop-mobile','block-13800-2','BlockBox','',1),(13814,'119364','printshop-mobile','block-13813','Html_box','',1),(13815,'119365','printshop-mobile','block-13813','Html_box','',2),(13816,'119366','printshop-mobile','block-13813','checkout\\PaymentMethodConfirm','',7),(13817,'119367','printshop-mobile','block-13813','Html_box','',5),(13818,'119368','printshop-mobile','block-13813','checkout\\BillingAddressConfirm','',4),(13819,'119369','printshop-mobile','block-13813','checkout\\EditBtn','',6),(13820,'119370','printshop-mobile','block-13813','checkout\\EditBtn','',3),(13821,'119371','printshop-mobile','block-13790-2','BlockBox','',1),(13822,'119372','printshop-mobile','block-13821','checkout\\ConfirmBtn','',3),(13823,'119373','printshop-mobile','block-13821','Html_box','',1),(13824,'119374','printshop-mobile','block-13821','checkout\\Totals','',2),(13825,'119375','printshop-mobile','confirmation_s','BlockBox','',1),(13826,'119376','printshop-mobile','block-13825','Html_box','',1),(13827,'119377','printshop-mobile','block-13825','BlockBox','',2),(13828,'119378','printshop-mobile','block-13827','BlockBox','',1),(13829,'119379','printshop-mobile','block-13828','BlockBox','',2),(13830,'119380','printshop-mobile','block-13829','checkout\\CommentsConfirm','',3),(13831,'119381','printshop-mobile','block-13829','checkout\\EditBtn','',2),(13832,'119382','printshop-mobile','block-13829','Html_box','',1),(13833,'119383','printshop-mobile','block-13828','BlockBox','',3),(13834,'119384','printshop-mobile','block-13833','sample\\Products','',2),(13835,'119385','printshop-mobile','block-13833','Html_box','',1),(13836,'119386','printshop-mobile','block-13833','checkout\\EditBtn','',3),(13837,'119387','printshop-mobile','block-13828','BlockBox','',1),(13838,'119388','printshop-mobile','block-13837','BlockBox','',1),(13839,'119389','printshop-mobile','block-13838','Html_box','',9),(13840,'119390','printshop-mobile','block-13838','checkout\\ContactConfirm','',11),(13841,'119391','printshop-mobile','block-13838','checkout\\EditBtn','',6),(13842,'119392','printshop-mobile','block-13838','checkout\\EditBtn','',10),(13843,'119393','printshop-mobile','block-13838','Html_box','',1),(13844,'119394','printshop-mobile','block-13838','DelayedDespatch\\CheckoutConfirm','',8),(13845,'119395','printshop-mobile','block-13838','checkout\\EditBtn','',3),(13846,'119396','printshop-mobile','block-13838','checkout\\ShippingAddressConfirm','',4),(13847,'119397','printshop-mobile','block-13838','Html_box','',5),(13848,'119398','printshop-mobile','block-13838','Html_box','',2),(13849,'119399','printshop-mobile','block-13838','checkout\\ShippingConfirm','',7),(13850,'119400','printshop-mobile','block-13837-2','BlockBox','',1),(13851,'119401','printshop-mobile','block-13850','Html_box','',5),(13852,'119402','printshop-mobile','block-13850','Html_box','',1),(13853,'119403','printshop-mobile','block-13850','checkout\\EditBtn','',6),(13854,'119404','printshop-mobile','block-13850','checkout\\BillingAddressConfirm','',4),(13855,'119405','printshop-mobile','block-13850','checkout\\EditBtn','',3),(13856,'119406','printshop-mobile','block-13850','Html_box','',2),(13857,'119407','printshop-mobile','block-13850','checkout\\PaymentMethodConfirm','',7),(13858,'119408','printshop-mobile','block-13827-2','BlockBox','',1),(13859,'119409','printshop-mobile','block-13858','checkout\\Totals','',2),(13860,'119410','printshop-mobile','block-13858','Html_box','',1),(13861,'119411','printshop-mobile','block-13858','checkout\\ConfirmBtn','',3),(13862,'119412','printshop-mobile','contact','BlockBox','',1),(13863,'119413','printshop-mobile','block-13862','BlockBox','',4),(13864,'119414','printshop-mobile','block-13863','contact\\Map','',1),(13865,'119415','printshop-mobile','block-13863-2','contact\\StreetView','',1),(13866,'119416','printshop-mobile','block-13862','BlockBox','',3),(13867,'119417','printshop-mobile','block-13866','contact\\ContactForm','',1),(13868,'119418','printshop-mobile','block-13866-2','contact\\Contacts','',1),(13869,'119419','printshop-mobile','block-13862','info\\Title','',1),(13870,'119420','printshop-mobile','created_success','BlockBox','',1),(13871,'119421','printshop-mobile','block-13870','Html_box','',2),(13872,'119422','printshop-mobile','block-13870','Html_box','',1),(13873,'119423','printshop-mobile','credit_note','invoice\\Container','',1),(13874,'119424','printshop-mobile','block-13873','BlockBox','',2),(13875,'119425','printshop-mobile','block-13874','BlockBox','',8),(13876,'119426','printshop-mobile','block-13875','BlockBox','',1),(13877,'119427','printshop-mobile','block-13876','Text','',1),(13878,'119428','printshop-mobile','block-13876','invoice\\ShippingMethod','',2),(13879,'119429','printshop-mobile','block-13875-2','BlockBox','',1),(13880,'119430','printshop-mobile','block-13879','invoice\\ShippingMethod','',2),(13881,'119431','printshop-mobile','block-13879','Text','',1),(13882,'119432','printshop-mobile','block-13874','BlockBox','',7),(13883,'119433','printshop-mobile','block-13882','BlockBox','',1),(13884,'119434','printshop-mobile','block-13883','invoice\\BillingAddress','',2),(13885,'119435','printshop-mobile','block-13883','Text','',1),(13886,'119436','printshop-mobile','block-13882-2','BlockBox','',1),(13887,'119437','printshop-mobile','block-13886','Text','',5),(13888,'119438','printshop-mobile','block-13886','invoice\\CustomerName','',2),(13889,'119439','printshop-mobile','block-13886','invoice\\CustomerEmail','',6),(13890,'119440','printshop-mobile','block-13886','Text','',3),(13891,'119441','printshop-mobile','block-13886','Text','',1),(13892,'119442','printshop-mobile','block-13886','invoice\\CustomerPhone','',4),(13893,'119443','printshop-mobile','block-13874-2','invoice\\PaymentDate','',3),(13894,'119444','printshop-mobile','block-13874-2','Text','',2),(13895,'119445','printshop-mobile','block-13874-2','invoice\\OrderId','',1),(13896,'119446','printshop-mobile','block-13873','BlockBox','',4),(13897,'119447','printshop-mobile','block-13896','BlockBox','',1),(13898,'119448','printshop-mobile','block-13897','Text','',1),(13899,'119449','printshop-mobile','block-13897','invoice\\ShippingAddress','',2),(13900,'119450','printshop-mobile','block-13896-2','BlockBox','',1),(13901,'119451','printshop-mobile','block-13873','BlockBox','',1),(13902,'119452','printshop-mobile','block-13901','Logo','',1),(13903,'119453','printshop-mobile','block-13901-2','BlockBox','',1),(13904,'119454','printshop-mobile','block-13903','invoice\\StoreAddress','',1),(13905,'119455','printshop-mobile','block-13901-2','BlockBox','',3),(13906,'119456','printshop-mobile','block-13905','Text','',1),(13907,'119457','printshop-mobile','block-13905-2','invoice\\StoreEmail','',1),(13908,'119458','printshop-mobile','block-13901-2','BlockBox','',2),(13909,'119459','printshop-mobile','block-13908','Text','',1),(13910,'119460','printshop-mobile','block-13908-2','invoice\\StorePhone','',1),(13911,'119461','printshop-mobile','block-13901-2','BlockBox','',4),(13912,'119462','printshop-mobile','block-13911','Text','',1),(13913,'119463','printshop-mobile','block-13911-2','invoice\\StoreSite','',1),(13914,'119464','printshop-mobile','block-13873','invoice\\Products','',3),(13915,'119465','printshop-mobile','block-13873','BlockBox','',5),(13916,'119466','printshop-mobile','block-13915','invoice\\StoreAddress','',8),(13917,'119467','printshop-mobile','block-13915','Text','',1),(13918,'119468','printshop-mobile','block-13915-2','Text','',2),(13919,'119469','printshop-mobile','block-13915-2','Logo','',1),(13920,'119470','printshop-mobile','block-13915-3','BlockBox','',2),(13921,'119471','printshop-mobile','block-13920','Text','',1),(13922,'119472','printshop-mobile','block-13920-2','invoice\\StorePhone','',1),(13923,'119473','printshop-mobile','block-13915-3','BlockBox','',3),(13924,'119474','printshop-mobile','block-13923','Text','',1),(13925,'119475','printshop-mobile','block-13923-2','invoice\\StoreEmail','',1),(13926,'119476','printshop-mobile','block-13915-3','Text','',1),(13927,'119477','printshop-mobile','delivery-location','DeliveryLocation\\LocationProducts','',8),(13928,'119478','printshop-mobile','delivery-location','DeliveryLocation\\LocationLongDescription','',5),(13929,'119479','printshop-mobile','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(13930,'119480','printshop-mobile','delivery-location','DeliveryLocation\\LocationDescription','',3),(13931,'119481','printshop-mobile','delivery-location','DeliveryLocation\\FeaturedList','',6),(13932,'119482','printshop-mobile','delivery-location','DeliveryLocation\\LocationList','',7),(13933,'119483','printshop-mobile','delivery-location','DeliveryLocation\\LocationTitle','',2),(13934,'119484','printshop-mobile','delivery-location-default','DeliveryLocation\\TopLocationList','',2),(13935,'119485','printshop-mobile','delivery-location-default','Heading','',1),(13936,'119486','printshop-mobile','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(13937,'119487','printshop-mobile','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(13938,'119488','printshop-mobile','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(13939,'119489','printshop-mobile','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(13940,'119490','printshop-mobile','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(13941,'119491','printshop-mobile','delivery_loc_2','DeliveryLocation\\LocationList','',7),(13942,'119492','printshop-mobile','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(13943,'119493','printshop-mobile','email','email\\Content','',3),(13944,'119494','printshop-mobile','email','email\\BlockBox','',1),(13945,'119495','printshop-mobile','block-13944','Logo','logo-2.png',1),(13946,'119496','printshop-mobile','email','Copyright','',7),(13947,'119497','printshop-mobile','email','email\\BlockBox','',4),(13948,'119498','printshop-mobile','email','Text','',5),(13949,'119499','printshop-mobile','email','email\\BlockBox','',2),(13950,'119500','printshop-mobile','block-13949','email\\Title','',1),(13951,'119501','printshop-mobile','block-13949-2','email\\Date','',1),(13952,'119502','printshop-mobile','email_2','email\\BlockBox','',1),(13953,'119503','printshop-mobile','block-13952','email\\BlockBox','',1),(13954,'119504','printshop-mobile','block-13953','email\\Content','',3),(13955,'119505','printshop-mobile','block-13953','email\\BlockBox','',2),(13956,'119506','printshop-mobile','block-13955','email\\Title','',1),(13957,'119507','printshop-mobile','block-13955-2','email\\Date','',1),(13958,'119508','printshop-mobile','block-13953','Copyright','',4),(13959,'119509','printshop-mobile','block-13953','Logo','',1),(13960,'119510','printshop-mobile','email_3','email\\BlockBox','',1),(13961,'119511','printshop-mobile','block-13960','email\\BlockBox','',1),(13962,'119512','printshop-mobile','block-13961','Logo','',1),(13963,'119513','printshop-mobile','block-13961','Copyright','',3),(13964,'119514','printshop-mobile','block-13961','email\\BlockBox','',2),(13965,'119515','printshop-mobile','block-13964','email\\BlockBox','',1),(13966,'119516','printshop-mobile','block-13965','email\\Title','',1),(13967,'119517','printshop-mobile','block-13965-2','email\\Date','',1),(13968,'119518','printshop-mobile','block-13964','email\\Content','',2),(13969,'119519','printshop-mobile','email_4','email\\BlockBox','',1),(13970,'119520','printshop-mobile','block-13969','email\\BlockBox','',1),(13971,'119521','printshop-mobile','block-13970','email\\BlockBox','',1),(13972,'119522','printshop-mobile','block-13971','email\\Content','',2),(13973,'119523','printshop-mobile','block-13971','email\\BlockBox','',1),(13974,'119524','printshop-mobile','block-13973','Logo','',1),(13975,'119525','printshop-mobile','block-13973-2','email\\Title','',1),(13976,'119526','printshop-mobile','block-13973-2','email\\Date','',2),(13977,'119527','printshop-mobile','block-13970','Copyright','',2),(13978,'119528','printshop-mobile','footer','BlockBox','',1),(13979,'119529','printshop-mobile','block-13978','BlockBox','',4),(13980,'119530','printshop-mobile','block-13979','Text','',1),(13981,'119531','printshop-mobile','block-13979','Menu','footer3',2),(13982,'119532','printshop-mobile','block-13978','Copyright','',10),(13983,'119533','printshop-mobile','block-13978','BlockBox','',2),(13984,'119534','printshop-mobile','block-13983','Menu','footer2',2),(13985,'119535','printshop-mobile','block-13983','Text','',1),(13986,'119536','printshop-mobile','block-13978','BlockBox','',3),(13987,'119537','printshop-mobile','block-13986','Text','',1),(13988,'119538','printshop-mobile','block-13986','Menu','footer1',2),(13989,'119539','printshop-mobile','block-13978','BlockBox','',1),(13990,'119540','printshop-mobile','block-13989','Contacts','',2),(13991,'119541','printshop-mobile','block-13989','Text','',1),(13992,'119542','printshop-mobile','for_menu','BlockBox','',1),(13993,'119543','printshop-mobile','block-13992','Html_box','',1),(13994,'119544','printshop-mobile','block-13992-2','Languages','',1),(13995,'119545','printshop-mobile','for_menu','BlockBox','',3),(13996,'119546','printshop-mobile','block-13995','Html_box','',1),(13997,'119547','printshop-mobile','block-13995-2','Currencies','',1),(13998,'119548','printshop-mobile','gift','BlockBox','',1),(13999,'119549','printshop-mobile','block-13998','BlockBox','',3),(14000,'119550','printshop-mobile','block-13999','BlockBox','',1),(14001,'119551','printshop-mobile','block-14000','BlockBox','',1),(14002,'119552','printshop-mobile','block-14001','BlockBox','',9),(14003,'119553','printshop-mobile','block-14002','Text','',1),(14004,'119554','printshop-mobile','block-14002','invoice\\StoreEmail','',3),(14005,'119555','printshop-mobile','block-14002','invoice\\StorePhone','',2),(14006,'119556','printshop-mobile','block-14001','Text','',6),(14007,'119557','printshop-mobile','block-14001','Text','',4),(14008,'119558','printshop-mobile','block-14001','Text','',7),(14009,'119559','printshop-mobile','block-14001','Text','',2),(14010,'119560','printshop-mobile','block-14001','BlockBox','',8),(14011,'119561','printshop-mobile','block-14010','Text','',1),(14012,'119562','printshop-mobile','block-14010-2','gift\\CodeView','',1),(14013,'119563','printshop-mobile','block-14001','gift\\MessageView','',5),(14014,'119564','printshop-mobile','block-14001','gift\\AmountView','',3),(14015,'119565','printshop-mobile','block-14001','Text','',1),(14016,'119566','printshop-mobile','block-13999-2','gift\\Form','',2),(14017,'119567','printshop-mobile','block-13999-2','Text','',1),(14018,'119568','printshop-mobile','block-13998','info\\Title','',1),(14019,'119569','printshop-mobile','gift_card','BlockBox','',1),(14020,'119570','printshop-mobile','block-14019','Text','',9),(14021,'119571','printshop-mobile','block-14019','Text','',4),(14022,'119572','printshop-mobile','block-14019','Logo','',1),(14023,'119573','printshop-mobile','block-14019','Image','',2),(14024,'119574','printshop-mobile','block-14019','Text','',6),(14025,'119575','printshop-mobile','block-14019','gift\\AmountView','',5),(14026,'119576','printshop-mobile','block-14019','gift\\MessageView','',7),(14027,'119577','printshop-mobile','block-14019','BlockBox','',10),(14028,'119578','printshop-mobile','block-14027','Text','',1),(14029,'119579','printshop-mobile','block-14027-2','gift\\CodeView','',1),(14030,'119580','printshop-mobile','block-14019','Text','',3),(14031,'119581','printshop-mobile','block-14019','Text','',8),(14032,'119582','printshop-mobile','block-14019','BlockBox','',11),(14033,'119583','printshop-mobile','block-14032','invoice\\StorePhone','',2),(14034,'119584','printshop-mobile','block-14032','Text','',1),(14035,'119585','printshop-mobile','block-14032','invoice\\StoreEmail','',3),(14036,'119586','printshop-mobile','gift_card_2','BlockBox','',1),(14037,'119587','printshop-mobile','block-14036','Text','',1),(14038,'119588','printshop-mobile','block-14036','Text','',2),(14039,'119589','printshop-mobile','block-14036','Text','',6),(14040,'119590','printshop-mobile','block-14036','gift\\MessageView','',5),(14041,'119591','printshop-mobile','block-14036','Text','',7),(14042,'119592','printshop-mobile','block-14036','Text','',4),(14043,'119593','printshop-mobile','block-14036','BlockBox','',9),(14044,'119594','printshop-mobile','block-14043','invoice\\StorePhone','',2),(14045,'119595','printshop-mobile','block-14043','Text','',1),(14046,'119596','printshop-mobile','block-14043','invoice\\StoreEmail','',3),(14047,'119597','printshop-mobile','block-14036','BlockBox','',8),(14048,'119598','printshop-mobile','block-14047','Text','',1),(14049,'119599','printshop-mobile','block-14047-2','gift\\CodeView','',1),(14050,'119600','printshop-mobile','block-14036','gift\\AmountView','',3),(14051,'119601','printshop-mobile','gift_card_2_pdf','BlockBox','',1),(14052,'119602','printshop-mobile','block-14051','BlockBox','',12),(14053,'119603','printshop-mobile','block-14052','invoice\\StoreEmail','',4),(14054,'119604','printshop-mobile','block-14052','invoice\\StorePhone','',3),(14055,'119605','printshop-mobile','block-14052','Html_box','',1),(14056,'119606','printshop-mobile','block-14051','BlockBox','',11),(14057,'119607','printshop-mobile','block-14056','Html_box','',1),(14058,'119608','printshop-mobile','block-14056-2','gift\\CodeViewPdf','',1),(14059,'119609','printshop-mobile','block-14051','BlockBox','',1),(14060,'119610','printshop-mobile','block-14059','Text','',4),(14061,'119611','printshop-mobile','block-14059','Html_box','',1),(14062,'119612','printshop-mobile','block-14059','Html_box','',2),(14063,'119613','printshop-mobile','block-14059','gift\\AmountViewPdf','',3),(14064,'119614','printshop-mobile','block-14059','gift\\MessageViewPdf','',5),(14065,'119615','printshop-mobile','block-14059','Html_box','',7),(14066,'119616','printshop-mobile','block-14059','Html_box','',6),(14067,'119617','printshop-mobile','gift_card_2_pdf','Import','',1),(14068,'119618','printshop-mobile','gift_card_pdf','BlockBox','',1),(14069,'119619','printshop-mobile','block-14068','BlockBox','',12),(14070,'119620','printshop-mobile','block-14069','invoice\\StoreEmail','',4),(14071,'119621','printshop-mobile','block-14069','invoice\\StorePhone','',3),(14072,'119622','printshop-mobile','block-14069','Html_box','',1),(14073,'119623','printshop-mobile','block-14068','BlockBox','',11),(14074,'119624','printshop-mobile','block-14073','Html_box','',1),(14075,'119625','printshop-mobile','block-14073-2','gift\\CodeViewPdf','',1),(14076,'119626','printshop-mobile','block-14068','BlockBox','',1),(14077,'119627','printshop-mobile','block-14076','Text','',4),(14078,'119628','printshop-mobile','block-14076','Html_box','',1),(14079,'119629','printshop-mobile','block-14076','Html_box','',2),(14080,'119630','printshop-mobile','block-14076','gift\\AmountViewPdf','',3),(14081,'119631','printshop-mobile','block-14076','gift\\MessageViewPdf','',5),(14082,'119632','printshop-mobile','block-14076','Html_box','',7),(14083,'119633','printshop-mobile','block-14076','Html_box','',6),(14084,'119634','printshop-mobile','gift_card_pdf','Import','',1),(14085,'119635','printshop-mobile','gift_certificate','BlockBox','',1),(14086,'119636','printshop-mobile','block-14085','account\\ApplyCertificate','',2),(14087,'119637','printshop-mobile','block-14085','Html_box','',1),(14088,'119638','printshop-mobile','gigt_card_3','BlockBox','',1),(14089,'119639','printshop-mobile','block-14088','Text','',7),(14090,'119640','printshop-mobile','block-14088','Text','',4),(14091,'119641','printshop-mobile','block-14088','gift\\AmountView','',3),(14092,'119642','printshop-mobile','block-14088','Text','',2),(14093,'119643','printshop-mobile','block-14088','gift\\MessageView','',5),(14094,'119644','printshop-mobile','block-14088','Text','',1),(14095,'119645','printshop-mobile','block-14088','BlockBox','',9),(14096,'119646','printshop-mobile','block-14095','invoice\\StoreEmail','',3),(14097,'119647','printshop-mobile','block-14095','invoice\\StorePhone','',2),(14098,'119648','printshop-mobile','block-14095','Text','',1),(14099,'119649','printshop-mobile','block-14088','Text','',6),(14100,'119650','printshop-mobile','block-14088','BlockBox','',8),(14101,'119651','printshop-mobile','block-14100','Text','',1),(14102,'119652','printshop-mobile','block-14100-2','gift\\CodeView','',1),(14103,'119653','printshop-mobile','gigt_card_3_pdf','BlockBox','',1),(14104,'119654','printshop-mobile','block-14103','BlockBox','',12),(14105,'119655','printshop-mobile','block-14104','invoice\\StoreEmail','',4),(14106,'119656','printshop-mobile','block-14104','invoice\\StorePhone','',3),(14107,'119657','printshop-mobile','block-14104','Html_box','',1),(14108,'119658','printshop-mobile','block-14103','BlockBox','',11),(14109,'119659','printshop-mobile','block-14108','Html_box','',1),(14110,'119660','printshop-mobile','block-14108-2','gift\\CodeViewPdf','',1),(14111,'119661','printshop-mobile','block-14103','BlockBox','',1),(14112,'119662','printshop-mobile','block-14111','Text','',4),(14113,'119663','printshop-mobile','block-14111','Html_box','',1),(14114,'119664','printshop-mobile','block-14111','Html_box','',2),(14115,'119665','printshop-mobile','block-14111','gift\\AmountViewPdf','',3),(14116,'119666','printshop-mobile','block-14111','gift\\MessageViewPdf','',5),(14117,'119667','printshop-mobile','block-14111','Html_box','',7),(14118,'119668','printshop-mobile','block-14111','Html_box','',6),(14119,'119669','printshop-mobile','header','Logo','',2),(14120,'119670','printshop-mobile','header','catalog\\Paging','',3),(14121,'119671','printshop-mobile','header','BlockBox','',1),(14122,'119672','printshop-mobile','block-14121','Text','',1),(14123,'119673','printshop-mobile','block-14121','BlockBox','',2),(14124,'119674','printshop-mobile','block-14123','Text','',2),(14125,'119675','printshop-mobile','block-14123','Image','',1),(14126,'119676','printshop-mobile','block-14123-2','BlockBox','',1),(14127,'119677','printshop-mobile','block-14126','Html_box','',2),(14128,'119678','printshop-mobile','block-14126-2','Html_box','',2),(14129,'119679','printshop-mobile','header','BlockBox','',3),(14130,'119680','printshop-mobile','block-14129','Menu','Categories',1),(14131,'119681','printshop-mobile','block-14129-2','Search','',1),(14132,'119682','printshop-mobile','block-14129-3','Account','',1),(14133,'119683','printshop-mobile','block-14129-4','Cart','',1),(14134,'119684','printshop-mobile','info','BlockBox','',1),(14135,'119685','printshop-mobile','block-14134','info\\Content','',3),(14136,'119686','printshop-mobile','block-14134','info\\Title','',2),(14137,'119687','printshop-mobile','invoice','invoice\\Container','',1),(14138,'119688','printshop-mobile','block-14137','BlockBox','',4),(14139,'119689','printshop-mobile','block-14138','BlockBox','',1),(14140,'119690','printshop-mobile','block-14139','invoice\\ShippingAddress','',2),(14141,'119691','printshop-mobile','block-14139','Text','',1),(14142,'119692','printshop-mobile','block-14138-2','BlockBox','',1),(14143,'119693','printshop-mobile','block-14142','invoice\\Totals','',1),(14144,'119694','printshop-mobile','block-14137','invoice\\Products','',3),(14145,'119695','printshop-mobile','block-14137','BlockBox','',1),(14146,'119696','printshop-mobile','block-14145','Logo','',1),(14147,'119697','printshop-mobile','block-14145-2','BlockBox','',2),(14148,'119698','printshop-mobile','block-14147','Text','',1),(14149,'119699','printshop-mobile','block-14147-2','invoice\\StorePhone','',1),(14150,'119700','printshop-mobile','block-14145-2','BlockBox','',1),(14151,'119701','printshop-mobile','block-14150','invoice\\StoreAddress','',1),(14152,'119702','printshop-mobile','block-14145-2','BlockBox','',4),(14153,'119703','printshop-mobile','block-14152','Text','',1),(14154,'119704','printshop-mobile','block-14152-2','invoice\\StoreSite','',1),(14155,'119705','printshop-mobile','block-14145-2','BlockBox','',3),(14156,'119706','printshop-mobile','block-14155','Text','',1),(14157,'119707','printshop-mobile','block-14155-2','invoice\\StoreEmail','',1),(14158,'119708','printshop-mobile','block-14137','BlockBox','',5),(14159,'119709','printshop-mobile','block-14158','Text','',1),(14160,'119710','printshop-mobile','block-14158','invoice\\StoreAddress','',8),(14161,'119711','printshop-mobile','block-14158-2','Text','',2),(14162,'119712','printshop-mobile','block-14158-2','Logo','',1),(14163,'119713','printshop-mobile','block-14158-3','BlockBox','',3),(14164,'119714','printshop-mobile','block-14163','Text','',1),(14165,'119715','printshop-mobile','block-14163-2','invoice\\StoreEmail','',1),(14166,'119716','printshop-mobile','block-14158-3','BlockBox','',2),(14167,'119717','printshop-mobile','block-14166','Text','',1),(14168,'119718','printshop-mobile','block-14166-2','invoice\\StorePhone','',1),(14169,'119719','printshop-mobile','block-14158-3','Text','',1),(14170,'119720','printshop-mobile','block-14137','BlockBox','',2),(14171,'119721','printshop-mobile','block-14170','BlockBox','',8),(14172,'119722','printshop-mobile','block-14171','BlockBox','',1),(14173,'119723','printshop-mobile','block-14172','Text','',1),(14174,'119724','printshop-mobile','block-14172','invoice\\ShippingMethod','',2),(14175,'119725','printshop-mobile','block-14171-2','BlockBox','',1),(14176,'119726','printshop-mobile','block-14175','invoice\\ShippingMethod','',2),(14177,'119727','printshop-mobile','block-14175','Text','',1),(14178,'119728','printshop-mobile','block-14170','BlockBox','',7),(14179,'119729','printshop-mobile','block-14178','BlockBox','',1),(14180,'119730','printshop-mobile','block-14179','Text','',1),(14181,'119731','printshop-mobile','block-14179','invoice\\BillingAddress','',2),(14182,'119732','printshop-mobile','block-14178-2','BlockBox','',1),(14183,'119733','printshop-mobile','block-14182','invoice\\CustomerPhone','',4),(14184,'119734','printshop-mobile','block-14182','Text','',1),(14185,'119735','printshop-mobile','block-14182','invoice\\CustomerName','',2),(14186,'119736','printshop-mobile','block-14182','Text','',3),(14187,'119737','printshop-mobile','block-14182','Text','',5),(14188,'119738','printshop-mobile','block-14182','invoice\\CustomerEmail','',6),(14189,'119739','printshop-mobile','block-14170-2','invoice\\PaymentMethod','',5),(14190,'119740','printshop-mobile','block-14170-2','invoice\\PaymentDate','',3),(14191,'119741','printshop-mobile','block-14170-2','invoice\\OrderId','',1),(14192,'119742','printshop-mobile','block-14170-2','invoice\\OrderBarcode','',6),(14193,'119743','printshop-mobile','block-14170-2','Text','',2),(14194,'119744','printshop-mobile','block-14170-2','Text','',4),(14195,'119745','printshop-mobile','login_account','BlockBox','',1),(14196,'119746','printshop-mobile','block-14195','Tabs','',2),(14197,'119747','printshop-mobile','block-14196-1','login\\Returning','',1),(14198,'119748','printshop-mobile','block-14196-2','login\\Register','',2),(14199,'119749','printshop-mobile','block-14195','BlockBox','',1),(14200,'119750','printshop-mobile','block-14199','Html_box','',3),(14201,'119751','printshop-mobile','block-14199','Html_box','',1),(14202,'119752','printshop-mobile','block-14199','login\\Socials','',2),(14203,'119753','printshop-mobile','login_checkout','BlockBox','',1),(14204,'119754','printshop-mobile','block-14203','BlockBox','',1),(14205,'119755','printshop-mobile','block-14204','Html_box','',2),(14206,'119756','printshop-mobile','block-14204','checkout\\CreateBtn','',5),(14207,'119757','printshop-mobile','block-14204','checkout\\GuestBtn','',3),(14208,'119758','printshop-mobile','block-14204','Html_box','',4),(14209,'119759','printshop-mobile','block-14204','BlockBox','',6),(14210,'119760','printshop-mobile','block-14209','Html_box','',1),(14211,'119761','printshop-mobile','block-14209','login\\Socials','',2),(14212,'119762','printshop-mobile','block-14204','login\\Returning','',1),(14213,'119763','printshop-mobile','block-14204','Html_box','',1),(14214,'119764','printshop-mobile','login_checkout2','BlockBox','',1),(14215,'119765','printshop-mobile','block-14214','Html_box','',1),(14216,'119766','printshop-mobile','block-14214','Html_box','',3),(14217,'119767','printshop-mobile','block-14214','login\\Socials','',2),(14218,'119768','printshop-mobile','block-14214','Tabs','',4),(14219,'119769','printshop-mobile','block-14218-1','BlockBox','',1),(14220,'119770','printshop-mobile','block-14219','Html_box','',1),(14221,'119771','printshop-mobile','block-14219-2','BlockBox','',1),(14222,'119772','printshop-mobile','block-14221','Html_box','',2),(14223,'119773','printshop-mobile','block-14221','login\\Guest','',1),(14224,'119774','printshop-mobile','block-14218-2','login\\Returning','',1),(14225,'119775','printshop-mobile','block-14218-3','BlockBox','',1),(14226,'119776','printshop-mobile','block-14225','Html_box','',1),(14227,'119777','printshop-mobile','block-14225-2','BlockBox','',1),(14228,'119778','printshop-mobile','block-14227','login\\Register','',1),(14229,'119779','printshop-mobile','block-14227','Html_box','',2),(14230,'119780','printshop-mobile','login_checkout2_q','BlockBox','',1),(14231,'119781','printshop-mobile','block-14230','login\\Socials','',2),(14232,'119782','printshop-mobile','block-14230','Html_box','',1),(14233,'119783','printshop-mobile','block-14230','Html_box','',3),(14234,'119784','printshop-mobile','block-14230','Tabs','',4),(14235,'119785','printshop-mobile','block-14234-1','BlockBox','',1),(14236,'119786','printshop-mobile','block-14235','Html_box','',1),(14237,'119787','printshop-mobile','block-14235-2','quote\\FastOrder','',1),(14238,'119788','printshop-mobile','block-14234-2','login\\Returning','',1),(14239,'119789','printshop-mobile','block-14234-3','BlockBox','',1),(14240,'119790','printshop-mobile','block-14239','Html_box','',1),(14241,'119791','printshop-mobile','block-14239','Import','',2),(14242,'119792','printshop-mobile','block-14239-2','BlockBox','',1),(14243,'119793','printshop-mobile','block-14242','Html_box','',2),(14244,'119794','printshop-mobile','block-14242','login\\Register','',1),(14245,'119795','printshop-mobile','login_checkout2_s','BlockBox','',1),(14246,'119796','printshop-mobile','block-14245','Html_box','',1),(14247,'119797','printshop-mobile','block-14245','Tabs','',4),(14248,'119798','printshop-mobile','block-14247-1','BlockBox','',1),(14249,'119799','printshop-mobile','block-14248','Html_box','',1),(14250,'119800','printshop-mobile','block-14248-2','quote\\FastOrder','',1),(14251,'119801','printshop-mobile','block-14247-2','login\\Returning','',1),(14252,'119802','printshop-mobile','block-14247-3','BlockBox','',1),(14253,'119803','printshop-mobile','block-14252','Html_box','',1),(14254,'119804','printshop-mobile','block-14252-2','BlockBox','',1),(14255,'119805','printshop-mobile','block-14254','Html_box','',2),(14256,'119806','printshop-mobile','block-14254','login\\Register','',1),(14257,'119807','printshop-mobile','block-14245','login\\Socials','',2),(14258,'119808','printshop-mobile','block-14245','Html_box','',3),(14259,'119809','printshop-mobile','login_checkout_q','BlockBox','',1),(14260,'119810','printshop-mobile','block-14259','BlockBox','',1),(14261,'119811','printshop-mobile','block-14260','checkout\\CreateBtn','',5),(14262,'119812','printshop-mobile','block-14260','checkout\\GuestBtn','',2),(14263,'119813','printshop-mobile','block-14260','Html_box','',1),(14264,'119814','printshop-mobile','block-14260','Html_box','',4),(14265,'119815','printshop-mobile','block-14260','BlockBox','',6),(14266,'119816','printshop-mobile','block-14265','login\\Socials','',2),(14267,'119817','printshop-mobile','block-14265','Html_box','',1),(14268,'119818','printshop-mobile','block-14260-2','login\\Returning','',2),(14269,'119819','printshop-mobile','block-14260-2','Html_box','',1),(14270,'119820','printshop-mobile','login_checkout_s','BlockBox','',1),(14271,'119821','printshop-mobile','block-14270','BlockBox','',1),(14272,'119822','printshop-mobile','block-14271','BlockBox','',5),(14273,'119823','printshop-mobile','block-14272','Html_box','',1),(14274,'119824','printshop-mobile','block-14272','login\\Socials','',2),(14275,'119825','printshop-mobile','block-14271','Html_box','',3),(14276,'119826','printshop-mobile','block-14271','checkout\\CreateBtn','',4),(14277,'119827','printshop-mobile','block-14271','Html_box','',1),(14278,'119828','printshop-mobile','block-14271','checkout\\GuestBtn','',2),(14279,'119829','printshop-mobile','block-14271-2','Html_box','',1),(14280,'119830','printshop-mobile','block-14271-2','login\\Returning','',2),(14281,'119831','printshop-mobile','logoff','BlockBox','',1),(14282,'119832','printshop-mobile','block-14281','Html_box','',1),(14283,'119833','printshop-mobile','logoff_forever','BlockBox','',1),(14284,'119834','printshop-mobile','block-14283','Html_box','',1),(14285,'119835','printshop-mobile','main','BlockBox','',5),(14286,'119836','printshop-mobile','block-14285','TopCategories','',1),(14287,'119837','printshop-mobile','block-14285','PromoCode','',2),(14288,'119838','printshop-mobile','block-14285','Tabs','',3),(14289,'119839','printshop-mobile','block-14288-1','NewProducts','4',1),(14290,'119840','printshop-mobile','block-14288-2','SpecialsProducts','4',1),(14291,'119841','printshop-mobile','block-14288-3','FeaturedProducts','4',1),(14292,'119842','printshop-mobile','main','Heading','',2),(14293,'119843','printshop-mobile','main','BlockBox','',6),(14294,'119844','printshop-mobile','block-14293','BlockBox','',1),(14295,'119845','printshop-mobile','block-14294','Bestsellers','10',1),(14296,'119846','printshop-mobile','block-14294-2','Reviews','4',1),(14297,'119847','printshop-mobile','manufacturers','BlockBox','',1),(14298,'119848','printshop-mobile','block-14297','Html_box','',1),(14299,'119849','printshop-mobile','block-14297','Brands','',2),(14300,'119850','printshop-mobile','messages-index','BlockBox','',1),(14301,'119851','printshop-mobile','block-14300','BlockBox','',1),(14302,'119852','printshop-mobile','block-14301','BlockBox','',1),(14303,'119853','printshop-mobile','block-14302','Messages\\Sidebar','',1),(14304,'119854','printshop-mobile','block-14301-2','Messages\\Listing','',1),(14305,'119855','printshop-mobile','messages-new','BlockBox','',1),(14306,'119856','printshop-mobile','block-14305','BlockBox','',1),(14307,'119857','printshop-mobile','block-14306','Messages\\Sidebar','',1),(14308,'119858','printshop-mobile','block-14306-2','Messages\\NewMessage','',1),(14309,'119859','printshop-mobile','messages-view','BlockBox','',1),(14310,'119860','printshop-mobile','block-14309','BlockBox','',1),(14311,'119861','printshop-mobile','block-14310','Messages\\Sidebar','',1),(14312,'119862','printshop-mobile','block-14310-2','Messages\\Message','',1),(14313,'119863','printshop-mobile','my_password','BlockBox','',1),(14314,'119864','printshop-mobile','block-14313','BlockBox','',1),(14315,'119865','printshop-mobile','block-14314','WidgetsAria','',1),(14316,'119866','printshop-mobile','block-14314-2','account\\ChangePassword','',2),(14317,'119867','printshop-mobile','block-14314-2','Html_box','',1),(14318,'119868','printshop-mobile','block-14314-2','account\\AccountLink','',3),(14319,'119869','printshop-mobile','need_login','BlockBox','',1),(14320,'119870','printshop-mobile','block-14319','BlockBox','',1),(14321,'119871','printshop-mobile','block-14319','Tabs','',2),(14322,'119872','printshop-mobile','block-14321-1','login\\Returning','',1),(14323,'119873','printshop-mobile','block-14321-2','BlockBox','',1),(14324,'119874','printshop-mobile','block-14323','Html_box','',1),(14325,'119875','printshop-mobile','block-14323-2','BlockBox','',1),(14326,'119876','printshop-mobile','block-14325','login\\Register','',1),(14327,'119877','printshop-mobile','block-14325','Html_box','',2),(14328,'119878','printshop-mobile','new-topic','BlockBox','',1),(14329,'119879','printshop-mobile','block-14328','Communication\\NewTopic','',3),(14330,'119880','printshop-mobile','block-14328','Html_box','',1),(14331,'119881','printshop-mobile','block-14328','Breadcrumb','',2),(14332,'119882','printshop-mobile','nnnn','BlockBox','',1),(14333,'119883','printshop-mobile','block-14332','catalog\\Title','',1),(14334,'119884','printshop-mobile','block-14332','BlockBox','',2),(14335,'119885','printshop-mobile','block-14334','Filters','',1),(14336,'119886','printshop-mobile','block-14334-2','Listing','',5),(14337,'119887','printshop-mobile','block-14334-2','catalog\\Image','',1),(14338,'119888','printshop-mobile','block-14334-2','BlockBox','',6),(14339,'119889','printshop-mobile','block-14338','catalog\\CountsItems','',1),(14340,'119890','printshop-mobile','block-14338-2','catalog\\Paging','',1),(14341,'119891','printshop-mobile','block-14334-2','catalog\\ImageMapCategory','',3),(14342,'119892','printshop-mobile','block-14334-2','Categories','',2),(14343,'119893','printshop-mobile','block-14334-2','BlockBox','',4),(14344,'119894','printshop-mobile','block-14343','catalog\\ListingLook','',1),(14345,'119895','printshop-mobile','block-14343','catalog\\ItemsOnPage','',4),(14346,'119896','printshop-mobile','block-14343','catalog\\CompareButton','',2),(14347,'119897','printshop-mobile','block-14343','catalog\\Sorting','',3),(14348,'119898','printshop-mobile','no-logged','BlockBox','',1),(14349,'119899','printshop-mobile','block-14348','Html_box','',1),(14350,'119900','printshop-mobile','block-14348','Communication\\NewTopic','',2),(14351,'119901','printshop-mobile','no_filters','BlockBox','',1),(14352,'119902','printshop-mobile','block-14351','BlockBox','',2),(14353,'119903','printshop-mobile','block-14352','catalog\\Image','',1),(14354,'119904','printshop-mobile','block-14352','BlockBox','',2),(14355,'119905','printshop-mobile','block-14354','catalog\\Sorting','',3),(14356,'119906','printshop-mobile','block-14354','catalog\\ItemsOnPage','',4),(14357,'119907','printshop-mobile','block-14354','HeaderStock','',5),(14358,'119908','printshop-mobile','block-14354','catalog\\CompareButton','',2),(14359,'119909','printshop-mobile','block-14354','catalog\\ListingLook','',1),(14360,'119910','printshop-mobile','block-14351','BlockBox','',4),(14361,'119911','printshop-mobile','block-14360','catalog\\CountsItems','',1),(14362,'119912','printshop-mobile','block-14360-2','catalog\\Paging','',1),(14363,'119913','printshop-mobile','block-14351','catalog\\B2bAddButton','',5),(14364,'119914','printshop-mobile','block-14351','catalog\\Title','',1),(14365,'119915','printshop-mobile','block-14351','Listing','',3),(14366,'119916','printshop-mobile','order_history','BlockBox','',1),(14367,'119917','printshop-mobile','block-14366','BlockBox','',1),(14368,'119918','printshop-mobile','block-14367','WidgetsAria','',1),(14369,'119919','printshop-mobile','block-14367-2','account\\OrdersHistory','',2),(14370,'119920','printshop-mobile','block-14367-2','Html_box','',1),(14371,'119921','printshop-mobile','order_history_info','BlockBox','',1),(14372,'119922','printshop-mobile','block-14371','BlockBox','',1),(14373,'119923','printshop-mobile','block-14372','WidgetsAria','',1),(14374,'119924','printshop-mobile','block-14372-2','account\\OrderReorderButton','',2),(14375,'119925','printshop-mobile','block-14372-2','BlockBox','',7),(14376,'119926','printshop-mobile','block-14375','BlockBox','',3),(14377,'119927','printshop-mobile','block-14376','account\\AccountLink','',3),(14378,'119928','printshop-mobile','block-14376','Html_box','',1),(14379,'119929','printshop-mobile','block-14376','account\\OrderTracking','',2),(14380,'119930','printshop-mobile','block-14375','BlockBox','',2),(14381,'119931','printshop-mobile','block-14380','Html_box','',1),(14382,'119932','printshop-mobile','block-14380','account\\OrderData','',2),(14383,'119933','printshop-mobile','block-14375','BlockBox','',1),(14384,'119934','printshop-mobile','block-14383','account\\OrderData','',2),(14385,'119935','printshop-mobile','block-14383','Html_box','',1),(14386,'119936','printshop-mobile','block-14375-2','BlockBox','',1),(14387,'119937','printshop-mobile','block-14386','Html_box','',1),(14388,'119938','printshop-mobile','block-14386','account\\OrderData','',2),(14389,'119939','printshop-mobile','block-14375-2','BlockBox','',2),(14390,'119940','printshop-mobile','block-14389','Html_box','',1),(14391,'119941','printshop-mobile','block-14389','account\\OrderData','',2),(14392,'119942','printshop-mobile','block-14375-3','BlockBox','',1),(14393,'119943','printshop-mobile','block-14392','Html_box','',1),(14394,'119944','printshop-mobile','block-14392','account\\OrderData','',2),(14395,'119945','printshop-mobile','block-14375-3','BlockBox','',2),(14396,'119946','printshop-mobile','block-14395','Html_box','',1),(14397,'119947','printshop-mobile','block-14395','account\\OrderData','',2),(14398,'119948','printshop-mobile','block-14372-2','account\\OrderDownload','',6),(14399,'119949','printshop-mobile','block-14372-2','account\\OrderProducts','',9),(14400,'119950','printshop-mobile','block-14372-2','Html_box','',11),(14401,'119951','printshop-mobile','block-14372-2','account\\OrderHeading','',1),(14402,'119952','printshop-mobile','block-14372-2','account\\OrderHistory','',12),(14403,'119953','printshop-mobile','block-14372-2','account\\OrderCancelAndReorder','',4),(14404,'119954','printshop-mobile','block-14372-2','Html_box','',8),(14405,'119955','printshop-mobile','block-14372-2','account\\OrderSubTotals','',10),(14406,'119956','printshop-mobile','block-14372-2','account\\OrderPayButton','',5),(14407,'119957','printshop-mobile','block-14372-2','account\\OrderInvoiceButton','',3),(14408,'119958','printshop-mobile','block-14372-2','BlockBox','',13),(14409,'119959','printshop-mobile','block-14408','account\\AccountLink','',1),(14410,'119960','printshop-mobile','block-14408-2','account\\OrderInvoiceButton','',1),(14411,'119961','printshop-mobile','order_pay','BlockBox','',1),(14412,'119962','printshop-mobile','block-14411','BlockBox','',1),(14413,'119963','printshop-mobile','block-14412','WidgetsAria','',1),(14414,'119964','printshop-mobile','block-14412-2','account\\OrderSubTotals','',5),(14415,'119965','printshop-mobile','block-14412-2','account\\OrderHeading','',1),(14416,'119966','printshop-mobile','block-14412-2','Html_box','',3),(14417,'119967','printshop-mobile','block-14412-2','UpdateAndPay\\PayForm','',6),(14418,'119968','printshop-mobile','block-14412-2','BlockBox','',2),(14419,'119969','printshop-mobile','block-14418','BlockBox','',4),(14420,'119970','printshop-mobile','block-14419','Html_box','',1),(14421,'119971','printshop-mobile','block-14419','account\\OrderData','',2),(14422,'119972','printshop-mobile','block-14418','BlockBox','',1),(14423,'119973','printshop-mobile','block-14422','Html_box','',1),(14424,'119974','printshop-mobile','block-14422','account\\OrderData','',2),(14425,'119975','printshop-mobile','block-14418-2','BlockBox','',2),(14426,'119976','printshop-mobile','block-14425','account\\OrderData','',2),(14427,'119977','printshop-mobile','block-14425','Html_box','',1),(14428,'119978','printshop-mobile','block-14418-2','BlockBox','',1),(14429,'119979','printshop-mobile','block-14428','Html_box','',1),(14430,'119980','printshop-mobile','block-14428','account\\OrderData','',2),(14431,'119981','printshop-mobile','block-14418-3','BlockBox','',2),(14432,'119982','printshop-mobile','block-14431','Html_box','',1),(14433,'119983','printshop-mobile','block-14431','account\\OrderData','',2),(14434,'119984','printshop-mobile','block-14418-3','BlockBox','',1),(14435,'119985','printshop-mobile','block-14434','account\\OrderData','',2),(14436,'119986','printshop-mobile','block-14434','Html_box','',1),(14437,'119987','printshop-mobile','block-14412-2','account\\OrderProducts','',4),(14438,'119988','printshop-mobile','packingslip','invoice\\Container','',2),(14439,'119989','printshop-mobile','block-14438','packingslip\\Products','',3),(14440,'119990','printshop-mobile','block-14438','BlockBox','',2),(14441,'119991','printshop-mobile','block-14440','BlockBox','',2),(14442,'119992','printshop-mobile','block-14441','BlockBox','',1),(14443,'119993','printshop-mobile','block-14442','Text','',1),(14444,'119994','printshop-mobile','block-14442','invoice\\ShippingAddress','',2),(14445,'119995','printshop-mobile','block-14441-2','BlockBox','',1),(14446,'119996','printshop-mobile','block-14445','invoice\\CustomerEmail','',6),(14447,'119997','printshop-mobile','block-14445','invoice\\CustomerName','',2),(14448,'119998','printshop-mobile','block-14445','invoice\\CustomerPhone','',4),(14449,'119999','printshop-mobile','block-14445','Text','',5),(14450,'120000','printshop-mobile','block-14445','Text','',1),(14451,'120001','printshop-mobile','block-14445','Text','',3),(14452,'120002','printshop-mobile','block-14440','BlockBox','',3),(14453,'120003','printshop-mobile','block-14452','BlockBox','',1),(14454,'120004','printshop-mobile','block-14453','invoice\\ShippingMethod','',2),(14455,'120005','printshop-mobile','block-14453','Text','',1),(14456,'120006','printshop-mobile','block-14452-2','BlockBox','',1),(14457,'120007','printshop-mobile','block-14456','Text','',1),(14458,'120008','printshop-mobile','block-14456','invoice\\ShippingMethod','',2),(14459,'120009','printshop-mobile','block-14440-2','invoice\\AddressQrcode','',1),(14460,'120010','printshop-mobile','block-14438','BlockBox','',4),(14461,'120011','printshop-mobile','block-14460','Text','',1),(14462,'120012','printshop-mobile','block-14460','invoice\\StoreAddress','',2),(14463,'120013','printshop-mobile','block-14438','BlockBox','',1),(14464,'120014','printshop-mobile','block-14463','Logo','',1),(14465,'120015','printshop-mobile','block-14463-2','BlockBox','',1),(14466,'120016','printshop-mobile','block-14465','invoice\\StoreAddress','',1),(14467,'120017','printshop-mobile','block-14463-2','BlockBox','',2),(14468,'120018','printshop-mobile','block-14467','Text','',2),(14469,'120019','printshop-mobile','block-14467-2','invoice\\StorePhone','',1),(14470,'120020','printshop-mobile','block-14463-2','BlockBox','',4),(14471,'120021','printshop-mobile','block-14470','Text','',2),(14472,'120022','printshop-mobile','block-14470-2','invoice\\StoreSite','',1),(14473,'120023','printshop-mobile','block-14463-2','BlockBox','',3),(14474,'120024','printshop-mobile','block-14473','Text','',2),(14475,'120025','printshop-mobile','block-14473-2','invoice\\StoreEmail','',1),(14476,'120026','printshop-mobile','password_forgotten','BlockBox','',1),(14477,'120027','printshop-mobile','block-14476','Html_box','',1),(14478,'120028','printshop-mobile','block-14476','BlockBox','',2),(14479,'120029','printshop-mobile','block-14478-2','login\\PasswordForgotten','',2),(14480,'120030','printshop-mobile','block-14478-2','Html_box','',1),(14481,'120031','printshop-mobile','pdf','invoice\\Container','',1),(14482,'120032','printshop-mobile','block-14481','BlockBox','',1),(14483,'120033','printshop-mobile','block-14482','BlockBox','',1),(14484,'120034','printshop-mobile','block-14483','BlockBox','',2),(14485,'120035','printshop-mobile','block-14484','pdf\\ProductElement','',1),(14486,'120036','printshop-mobile','block-14484-2','pdf\\ProductElement','',2),(14487,'120037','printshop-mobile','block-14484-2','pdf\\ProductElement','',1),(14488,'120038','printshop-mobile','block-14483','BlockBox','',1),(14489,'120039','printshop-mobile','block-14488','pdf\\ProductElement','',1),(14490,'120040','printshop-mobile','block-14482-2','BlockBox','',1),(14491,'120041','printshop-mobile','block-14490','BlockBox','',1),(14492,'120042','printshop-mobile','block-14491','pdf\\ProductElement','',1),(14493,'120043','printshop-mobile','block-14490','BlockBox','',2),(14494,'120044','printshop-mobile','block-14493','pdf\\ProductElement','',1),(14495,'120045','printshop-mobile','block-14493-2','pdf\\ProductElement','',2),(14496,'120046','printshop-mobile','block-14493-2','pdf\\ProductElement','',1),(14497,'120047','printshop-mobile','pdf_category','pdf\\CategoryName','',2),(14498,'120048','printshop-mobile','pdf_category','pdf\\CategoryImage','',1),(14499,'120049','printshop-mobile','pdf_cover','invoice\\Container','',1),(14500,'120050','printshop-mobile','block-14499','Logo','',1),(14501,'120051','printshop-mobile','block-14499','Text','',3),(14502,'120052','printshop-mobile','pdf_footer','BlockBox','',1),(14503,'120053','printshop-mobile','block-14502-2','pdf\\PageNumber','',1),(14504,'120054','printshop-mobile','pdf_header','pdf\\CategoryName','',1),(14505,'120055','printshop-mobile','personal_catalog','BlockBox','',1),(14506,'120056','printshop-mobile','block-14505','BlockBox','',1),(14507,'120057','printshop-mobile','block-14506','WidgetsAria','',1),(14508,'120058','printshop-mobile','block-14506-2','Html_box','',1),(14509,'120059','printshop-mobile','block-14506-2','account\\PersonalCatalog','',2),(14510,'120060','printshop-mobile','points_earnt_history','BlockBox','',1),(14511,'120061','printshop-mobile','block-14510','Html_box','',1),(14512,'120062','printshop-mobile','block-14510','account\\PointsEarntHistory','',2),(14513,'120063','printshop-mobile','posts','BlockBox','',1),(14514,'120064','printshop-mobile','block-14513','Breadcrumb','',2),(14515,'120065','printshop-mobile','block-14513','Communication\\Post','',3),(14516,'120066','printshop-mobile','block-14513','Html_box','',1),(14517,'120067','printshop-mobile','product','BlockBox','',1),(14518,'120068','printshop-mobile','block-14517','BlockBox','',5),(14519,'120069','printshop-mobile','block-14518','product\\Stock','',2),(14520,'120070','printshop-mobile','block-14518','product\\Price','',1),(14521,'120071','printshop-mobile','block-14518-2','product\\Quantity','',1),(14522,'120072','printshop-mobile','block-14517','product\\Bundle','',6),(14523,'120073','printshop-mobile','block-14517','product\\Video','',3),(14524,'120074','printshop-mobile','block-14517','product\\Documents','',16),(14525,'120075','printshop-mobile','block-14517','product\\Buttons','',7),(14526,'120076','printshop-mobile','block-14517','product\\Images','',2),(14527,'120077','printshop-mobile','block-14517','product\\Name','',1),(14528,'120078','printshop-mobile','block-14517','BlockBox','',8),(14529,'120079','printshop-mobile','block-14528','product\\WishlistButton','',1),(14530,'120080','printshop-mobile','block-14528','product\\PersonalCatalogButton','',2),(14531,'120081','printshop-mobile','block-14528','product\\WeddingRegistryButton','',3),(14532,'120082','printshop-mobile','block-14517','product\\BonusPoints','',9),(14533,'120083','printshop-mobile','block-14517','product\\CrossSell','',13),(14534,'120084','printshop-mobile','block-14517','product\\AlsoPurchased','10',11),(14535,'120085','printshop-mobile','block-14517','product\\InBundles','',14),(14536,'120086','printshop-mobile','block-14517','Tabs','',12),(14537,'120087','printshop-mobile','block-14536-1','product\\Description','',1),(14538,'120088','printshop-mobile','block-14536-1','product\\Properties','',2),(14539,'120089','printshop-mobile','block-14536-2','product\\Reviews','',1),(14540,'120090','printshop-mobile','block-14517','product\\Attributes','',4),(14541,'120091','printshop-mobile','block-14517','product\\Configurator','',10),(14542,'120092','printshop-mobile','block-14517','ViewedProducts','',15),(14543,'120093','printshop-mobile','product-bottom','product\\Properties','',1),(14544,'120094','printshop-mobile','product-tabs','product\\Reviews','',2),(14545,'120095','printshop-mobile','product-tabs','product\\Description','',1),(14546,'120096','printshop-mobile','product-top-left','product\\Images','',1),(14547,'120097','printshop-mobile','product-top-right','product\\Attributes','',3),(14548,'120098','printshop-mobile','product-top-right','product\\Buttons','',6),(14549,'120099','printshop-mobile','product-top-right','product\\Quantity','',6),(14550,'120100','printshop-mobile','product-top-right','product\\Quantity','',5),(14551,'120101','printshop-mobile','product-top-right','product\\Name','',1),(14552,'120102','printshop-mobile','product-top-right','product\\Price','',2),(14553,'120103','printshop-mobile','productListing','BlockBox','',1),(14554,'120104','printshop-mobile','block-14553','productListing\\model','',7),(14555,'120105','printshop-mobile','block-14553','productListing\\bonusPoints','',6),(14556,'120106','printshop-mobile','block-14553','productListing\\description','',5),(14557,'120107','printshop-mobile','block-14553','productListing\\buyButton','',9),(14558,'120108','printshop-mobile','block-14553','productListing\\rating','',3),(14559,'120109','printshop-mobile','block-14553','productListing\\image','',1),(14560,'120110','printshop-mobile','block-14553','BlockBox','',8),(14561,'120111','printshop-mobile','block-14560','productListing\\price','',1),(14562,'120112','printshop-mobile','block-14560-2','productListing\\qtyInput','',1),(14563,'120113','printshop-mobile','block-14553','productListing\\name','',4),(14564,'120114','printshop-mobile','block-14553','productListing\\stock','',2),(14565,'120115','printshop-mobile','products','BlockBox','',1),(14566,'120116','printshop-mobile','block-14565','Filters','',3),(14567,'120117','printshop-mobile','block-14565','catalog\\Paging','',5),(14568,'120118','printshop-mobile','block-14565','catalog\\Title','',1),(14569,'120119','printshop-mobile','block-14565','catalog\\Image','',2),(14570,'120120','printshop-mobile','block-14565','BlockBox','',4),(14571,'120121','printshop-mobile','block-14570','catalog\\Sorting','',1),(14572,'120122','printshop-mobile','block-14570-2','catalog\\CountsItems','',1),(14573,'120123','printshop-mobile','block-14565','Listing','',7),(14574,'120124','printshop-mobile','products-list','packingslip\\AllProductsList','',2),(14575,'120125','printshop-mobile','promotions','BlockBox','',1),(14576,'120126','printshop-mobile','block-14575','promotions\\PromoList','',2),(14577,'120127','printshop-mobile','block-14575','Html_box','',1),(14578,'120128','printshop-mobile','purchase','invoice\\Container','',1),(14579,'120129','printshop-mobile','block-14578','BlockBox','',4),(14580,'120130','printshop-mobile','block-14579','BlockBox','',1),(14581,'120131','printshop-mobile','block-14580','Text','',1),(14582,'120132','printshop-mobile','block-14580','invoice\\ShippingAddress','',2),(14583,'120133','printshop-mobile','block-14578','BlockBox','',2),(14584,'120134','printshop-mobile','block-14583','BlockBox','',7),(14585,'120135','printshop-mobile','block-14584','BlockBox','',1),(14586,'120136','printshop-mobile','block-14585','Text','',1),(14587,'120137','printshop-mobile','block-14585','invoice\\BillingAddress','',2),(14588,'120138','printshop-mobile','block-14584-2','BlockBox','',1),(14589,'120139','printshop-mobile','block-14588','Text','',1),(14590,'120140','printshop-mobile','block-14588','Text','',3),(14591,'120141','printshop-mobile','block-14588','Text','',5),(14592,'120142','printshop-mobile','block-14588','invoice\\CustomerName','',2),(14593,'120143','printshop-mobile','block-14588','invoice\\CustomerPhone','',4),(14594,'120144','printshop-mobile','block-14588','invoice\\CustomerEmail','',6),(14595,'120145','printshop-mobile','block-14583-2','Text','',2),(14596,'120146','printshop-mobile','block-14583-2','invoice\\PaymentDate','',3),(14597,'120147','printshop-mobile','block-14583-2','invoice\\OrderId','',1),(14598,'120148','printshop-mobile','block-14578','BlockBox','',1),(14599,'120149','printshop-mobile','block-14598','Logo','',1),(14600,'120150','printshop-mobile','block-14598-2','BlockBox','',1),(14601,'120151','printshop-mobile','block-14600','invoice\\StoreAddress','',1),(14602,'120152','printshop-mobile','block-14598-2','BlockBox','',3),(14603,'120153','printshop-mobile','block-14602','Text','',1),(14604,'120154','printshop-mobile','block-14602-2','invoice\\StoreEmail','',1),(14605,'120155','printshop-mobile','block-14598-2','BlockBox','',4),(14606,'120156','printshop-mobile','block-14605','Text','',1),(14607,'120157','printshop-mobile','block-14605-2','invoice\\StoreSite','',1),(14608,'120158','printshop-mobile','block-14598-2','BlockBox','',2),(14609,'120159','printshop-mobile','block-14608','Text','',1),(14610,'120160','printshop-mobile','block-14608-2','invoice\\StorePhone','',1),(14611,'120161','printshop-mobile','block-14578','BlockBox','',5),(14612,'120162','printshop-mobile','block-14611','invoice\\StoreAddress','',8),(14613,'120163','printshop-mobile','block-14611','Text','',1),(14614,'120164','printshop-mobile','block-14611-2','Text','',2),(14615,'120165','printshop-mobile','block-14611-2','Logo','',1),(14616,'120166','printshop-mobile','block-14611-3','BlockBox','',2),(14617,'120167','printshop-mobile','block-14616','Text','',1),(14618,'120168','printshop-mobile','block-14616-2','invoice\\StorePhone','',1),(14619,'120169','printshop-mobile','block-14611-3','Text','',1),(14620,'120170','printshop-mobile','block-14611-3','BlockBox','',3),(14621,'120171','printshop-mobile','block-14620','Text','',1),(14622,'120172','printshop-mobile','block-14620-2','invoice\\StoreEmail','',1),(14623,'120173','printshop-mobile','block-14578','invoice\\Products','',3),(14624,'120174','printshop-mobile','quotations','BlockBox','',1),(14625,'120175','printshop-mobile','block-14624','BlockBox','',1),(14626,'120176','printshop-mobile','block-14625','WidgetsAria','',1),(14627,'120177','printshop-mobile','block-14625-2','Html_box','',1),(14628,'120178','printshop-mobile','block-14625-2','Quotations\\QuotationsHistory','',2),(14629,'120179','printshop-mobile','quotation_info','BlockBox','',1),(14630,'120180','printshop-mobile','block-14629','BlockBox','',1),(14631,'120181','printshop-mobile','block-14630','WidgetsAria','',1),(14632,'120182','printshop-mobile','block-14630-2','Quotations\\QuotationHistory','',10),(14633,'120183','printshop-mobile','block-14630-2','Quotations\\QuotationProducts','',7),(14634,'120184','printshop-mobile','block-14630-2','Html_box','',9),(14635,'120185','printshop-mobile','block-14630-2','Html_box','',6),(14636,'120186','printshop-mobile','block-14630-2','Quotations\\QuotationSubTotal','',8),(14637,'120187','printshop-mobile','block-14630-2','Html_box','',4),(14638,'120188','printshop-mobile','block-14630-2','BlockBox','',12),(14639,'120189','printshop-mobile','block-14638','account\\AccountLink','',1),(14640,'120190','printshop-mobile','block-14630-2','BlockBox','',5),(14641,'120191','printshop-mobile','block-14640','BlockBox','',4),(14642,'120192','printshop-mobile','block-14641','Html_box','',1),(14643,'120193','printshop-mobile','block-14641','Quotations\\QuotationData','',2),(14644,'120194','printshop-mobile','block-14640','BlockBox','',1),(14645,'120195','printshop-mobile','block-14644','Quotations\\QuotationData','',2),(14646,'120196','printshop-mobile','block-14644','Html_box','',1),(14647,'120197','printshop-mobile','block-14640-2','BlockBox','',2),(14648,'120198','printshop-mobile','block-14647','Html_box','',1),(14649,'120199','printshop-mobile','block-14647','Quotations\\QuotationData','',2),(14650,'120200','printshop-mobile','block-14640-2','BlockBox','',1),(14651,'120201','printshop-mobile','block-14650','Html_box','',1),(14652,'120202','printshop-mobile','block-14650','Quotations\\QuotationData','',2),(14653,'120203','printshop-mobile','block-14640-3','BlockBox','',1),(14654,'120204','printshop-mobile','block-14653','Html_box','',1),(14655,'120205','printshop-mobile','block-14653','Quotations\\QuotationData','',2),(14656,'120206','printshop-mobile','block-14640-3','BlockBox','',2),(14657,'120207','printshop-mobile','block-14656','Quotations\\QuotationData','',2),(14658,'120208','printshop-mobile','block-14656','Html_box','',1),(14659,'120209','printshop-mobile','quote','quote\\CheckoutBtn','',3),(14660,'120210','printshop-mobile','quote','quote\\Products','',2),(14661,'120211','printshop-mobile','quote','Text','',1),(14662,'120212','printshop-mobile','review','BlockBox','',1),(14663,'120213','printshop-mobile','block-14662','BlockBox','',1),(14664,'120214','printshop-mobile','block-14663','WidgetsAria','',1),(14665,'120215','printshop-mobile','block-14663-2','Html_box','',1),(14666,'120216','printshop-mobile','block-14663-2','account\\Reviews','',2),(14667,'120217','printshop-mobile','reviews','BlockBox','',1),(14668,'120218','printshop-mobile','block-14667','reviews\\Content','',2),(14669,'120219','printshop-mobile','block-14667','reviews\\Heading','',1),(14670,'120220','printshop-mobile','rma_document','invoice\\Container','',1),(14671,'120221','printshop-mobile','block-14670','BlockBox','',3),(14672,'120222','printshop-mobile','block-14671','BlockBox','',1),(14673,'120223','printshop-mobile','block-14672','BlockBox','',1),(14674,'120224','printshop-mobile','block-14673','BlockBox','',6),(14675,'120225','printshop-mobile','block-14674','Html_box','',1),(14676,'120226','printshop-mobile','block-14673','BlockBox','',3),(14677,'120227','printshop-mobile','block-14676','Html_box','',1),(14678,'120228','printshop-mobile','block-14676-2','Html_box','',1),(14679,'120229','printshop-mobile','block-14673','BlockBox','',1),(14680,'120230','printshop-mobile','block-14679','Html_box','',1),(14681,'120231','printshop-mobile','block-14673','BlockBox','',2),(14682,'120232','printshop-mobile','block-14681','Html_box','',1),(14683,'120233','printshop-mobile','block-14681-2','Html_box','',1),(14684,'120234','printshop-mobile','block-14673','BlockBox','',4),(14685,'120235','printshop-mobile','block-14684','Html_box','',1),(14686,'120236','printshop-mobile','block-14684-2','Html_box','',1),(14687,'120237','printshop-mobile','block-14673','BlockBox','',5),(14688,'120238','printshop-mobile','block-14687','Html_box','',1),(14689,'120239','printshop-mobile','block-14687-2','Html_box','',1),(14690,'120240','printshop-mobile','block-14687-2','invoice\\StoreAddress','',2),(14691,'120241','printshop-mobile','block-14672-2','BlockBox','',3),(14692,'120242','printshop-mobile','block-14691','Html_box','',1),(14693,'120243','printshop-mobile','block-14691-2','Html_box','',1),(14694,'120244','printshop-mobile','block-14691-3','BlockBox','',1),(14695,'120245','printshop-mobile','block-14694','Html_box','',1),(14696,'120246','printshop-mobile','block-14694-2','Html_box','',1),(14697,'120247','printshop-mobile','block-14672-2','BlockBox','',4),(14698,'120248','printshop-mobile','block-14697','Html_box','',1),(14699,'120249','printshop-mobile','block-14697-2','Html_box','',1),(14700,'120250','printshop-mobile','block-14697-3','BlockBox','',1),(14701,'120251','printshop-mobile','block-14700','Html_box','',1),(14702,'120252','printshop-mobile','block-14700-2','Html_box','',1),(14703,'120253','printshop-mobile','block-14672-2','BlockBox','',2),(14704,'120254','printshop-mobile','block-14703','Html_box','',1),(14705,'120255','printshop-mobile','block-14703','Html_box','',2),(14706,'120256','printshop-mobile','block-14703','Html_box','',3),(14707,'120257','printshop-mobile','block-14703','Html_box','',4),(14708,'120258','printshop-mobile','block-14703','Html_box','',5),(14709,'120259','printshop-mobile','block-14672-2','BlockBox','',1),(14710,'120260','printshop-mobile','block-14709','BlockBox','',1),(14711,'120261','printshop-mobile','block-14710','BlockBox','',1),(14712,'120262','printshop-mobile','block-14711','Rma\\DocumentData','',2),(14713,'120263','printshop-mobile','block-14711-3','BlockBox','',1),(14714,'120264','printshop-mobile','block-14713','Html_box','',1),(14715,'120265','printshop-mobile','block-14713-2','Rma\\DocumentData','',1),(14716,'120266','printshop-mobile','block-14710','BlockBox','',2),(14717,'120267','printshop-mobile','block-14716-2','invoice\\StoreAddress','',1),(14718,'120268','printshop-mobile','block-14670','BlockBox','',2),(14719,'120269','printshop-mobile','block-14718','Rma\\Products','',2),(14720,'120270','printshop-mobile','block-14718','Html_box','',1),(14721,'120271','printshop-mobile','block-14670','BlockBox','',1),(14722,'120272','printshop-mobile','block-14721','BlockBox','',1),(14723,'120273','printshop-mobile','block-14722','BlockBox','',1),(14724,'120274','printshop-mobile','block-14723','Html_box','',2),(14725,'120275','printshop-mobile','block-14723','Html_box','',1),(14726,'120276','printshop-mobile','block-14722','BlockBox','',3),(14727,'120277','printshop-mobile','block-14726','Html_box','',1),(14728,'120278','printshop-mobile','block-14726-2','Html_box','',1),(14729,'120279','printshop-mobile','block-14722','BlockBox','',2),(14730,'120280','printshop-mobile','block-14729','Html_box','',1),(14731,'120281','printshop-mobile','block-14729-2','Html_box','',1),(14732,'120282','printshop-mobile','block-14722','BlockBox','',4),(14733,'120283','printshop-mobile','block-14732','Html_box','',1),(14734,'120284','printshop-mobile','block-14732-2','Html_box','',1),(14735,'120285','printshop-mobile','block-14722','BlockBox','',5),(14736,'120286','printshop-mobile','block-14735','Html_box','',1),(14737,'120287','printshop-mobile','block-14735-2','Html_box','',1),(14738,'120288','printshop-mobile','block-14721-2','BlockBox','',3),(14739,'120289','printshop-mobile','block-14738','BlockBox','',1),(14740,'120290','printshop-mobile','block-14739','Html_box','',1),(14741,'120291','printshop-mobile','block-14739-2','Rma\\DocumentData','',1),(14742,'120292','printshop-mobile','block-14738-2','BlockBox','',1),(14743,'120293','printshop-mobile','block-14742','Html_box','',1),(14744,'120294','printshop-mobile','block-14742-2','Rma\\DocumentData','',1),(14745,'120295','printshop-mobile','block-14721-2','BlockBox','',2),(14746,'120296','printshop-mobile','block-14745','BlockBox','',1),(14747,'120297','printshop-mobile','block-14746','BlockBox','',1),(14748,'120298','printshop-mobile','block-14747','Html_box','',1),(14749,'120299','printshop-mobile','block-14747-2','Rma\\DocumentData','',1),(14750,'120300','printshop-mobile','block-14746-2','BlockBox','',1),(14751,'120301','printshop-mobile','block-14750','Html_box','',1),(14752,'120302','printshop-mobile','block-14750-2','Rma\\DocumentData','',1),(14753,'120303','printshop-mobile','block-14745','BlockBox','',2),(14754,'120304','printshop-mobile','block-14753','Html_box','',1),(14755,'120305','printshop-mobile','block-14753-2','Rma\\DocumentData','',1),(14756,'120306','printshop-mobile','block-14745','BlockBox','',3),(14757,'120307','printshop-mobile','block-14756','BlockBox','',1),(14758,'120308','printshop-mobile','block-14757','Html_box','',1),(14759,'120309','printshop-mobile','block-14757-2','Rma\\DocumentData','',1),(14760,'120310','printshop-mobile','block-14756-2','BlockBox','',1),(14761,'120311','printshop-mobile','block-14760','Html_box','',1),(14762,'120312','printshop-mobile','block-14760-2','Rma\\DocumentData','',1),(14763,'120313','printshop-mobile','block-14745','BlockBox','',4),(14764,'120314','printshop-mobile','block-14763','BlockBox','',1),(14765,'120315','printshop-mobile','block-14764','Html_box','',1),(14766,'120316','printshop-mobile','block-14764-2','Rma\\DocumentData','',1),(14767,'120317','printshop-mobile','block-14763-2','BlockBox','',1),(14768,'120318','printshop-mobile','block-14767','Html_box','',1),(14769,'120319','printshop-mobile','block-14767-2','Rma\\DocumentData','',1),(14770,'120320','printshop-mobile','block-14745','BlockBox','',5),(14771,'120321','printshop-mobile','block-14770','BlockBox','',1),(14772,'120322','printshop-mobile','block-14771','Html_box','',1),(14773,'120323','printshop-mobile','block-14771-2','Rma\\DocumentData','',1),(14774,'120324','printshop-mobile','block-14770-2','BlockBox','',1),(14775,'120325','printshop-mobile','block-14774','Html_box','',1),(14776,'120326','printshop-mobile','block-14774-2','Rma\\DocumentData','',1),(14777,'120327','printshop-mobile','block-14721-2','BlockBox','',1),(14778,'120328','printshop-mobile','block-14777','Logo','',1),(14779,'120329','printshop-mobile','block-14777','Html_box','',2),(14780,'120330','printshop-mobile','rows','BlockBox','',1),(14781,'120331','printshop-mobile','block-14780','BlockBox','',2),(14782,'120332','printshop-mobile','block-14781','BlockBox','',2),(14783,'120333','printshop-mobile','block-14782','BlockBox','',3),(14784,'120334','printshop-mobile','block-14783','productListing\\rating','',1),(14785,'120335','printshop-mobile','block-14783','productListing\\ratingCounts','',2),(14786,'120336','printshop-mobile','block-14782','productListing\\bonusPoints','',1),(14787,'120337','printshop-mobile','block-14782','productListing\\image','',2),(14788,'120338','printshop-mobile','block-14782-2','productListing\\model','',3),(14789,'120339','printshop-mobile','block-14782-2','productListing\\name','',1),(14790,'120340','printshop-mobile','block-14782-2','productListing\\description','',2),(14791,'120341','printshop-mobile','block-14782-2','productListing\\attributes','',4),(14792,'120342','printshop-mobile','block-14781-2','BlockBox','',1),(14793,'120343','printshop-mobile','block-14792','productListing\\stock','',1),(14794,'120344','printshop-mobile','block-14792','productListing\\price','',2),(14795,'120345','printshop-mobile','block-14792','productListing\\wishlistButton','',6),(14796,'120346','printshop-mobile','block-14792','productListing\\qtyInput','',3),(14797,'120347','printshop-mobile','block-14792','productListing\\compare','',5),(14798,'120348','printshop-mobile','block-14792','productListing\\buyButton','',4),(14799,'120349','printshop-mobile','sample','BlockBox','',1),(14800,'120350','printshop-mobile','block-14799','sample\\Products','',2),(14801,'120351','printshop-mobile','block-14799','sample\\CheckoutBtn','',3),(14802,'120352','printshop-mobile','block-14799','Text','',1),(14803,'120353','printshop-mobile','samples','BlockBox','',1),(14804,'120354','printshop-mobile','block-14803','BlockBox','',1),(14805,'120355','printshop-mobile','block-14804','WidgetsAria','',1),(14806,'120356','printshop-mobile','block-14804-2','Html_box','',1),(14807,'120357','printshop-mobile','block-14804-2','Samples\\SamplesHistory','',2),(14808,'120358','printshop-mobile','sample_info','BlockBox','',1),(14809,'120359','printshop-mobile','block-14808','BlockBox','',1),(14810,'120360','printshop-mobile','block-14809','WidgetsAria','',1),(14811,'120361','printshop-mobile','block-14809-2','Html_box','',6),(14812,'120362','printshop-mobile','block-14809-2','BlockBox','',2),(14813,'120363','printshop-mobile','block-14812','BlockBox','',4),(14814,'120364','printshop-mobile','block-14813','Html_box','',1),(14815,'120365','printshop-mobile','block-14813','Samples\\SampleData','',2),(14816,'120366','printshop-mobile','block-14812','BlockBox','',1),(14817,'120367','printshop-mobile','block-14816','Samples\\SampleData','',2),(14818,'120368','printshop-mobile','block-14816','Html_box','',1),(14819,'120369','printshop-mobile','block-14812-2','BlockBox','',1),(14820,'120370','printshop-mobile','block-14819','Html_box','',1),(14821,'120371','printshop-mobile','block-14819','Samples\\SampleData','',2),(14822,'120372','printshop-mobile','block-14812-2','BlockBox','',2),(14823,'120373','printshop-mobile','block-14822','Samples\\SampleData','',2),(14824,'120374','printshop-mobile','block-14822','Html_box','',1),(14825,'120375','printshop-mobile','block-14812-3','BlockBox','',1),(14826,'120376','printshop-mobile','block-14825','Html_box','',1),(14827,'120377','printshop-mobile','block-14825','Samples\\SampleData','',2),(14828,'120378','printshop-mobile','block-14812-3','BlockBox','',2),(14829,'120379','printshop-mobile','block-14828','Samples\\SampleData','',2),(14830,'120380','printshop-mobile','block-14828','Html_box','',1),(14831,'120381','printshop-mobile','block-14809-2','Html_box','',3),(14832,'120382','printshop-mobile','block-14809-2','Samples\\SampleProducts','',4),(14833,'120383','printshop-mobile','block-14809-2','Samples\\SampleSubTotal','',5),(14834,'120384','printshop-mobile','block-14809-2','BlockBox','',8),(14835,'120385','printshop-mobile','block-14834','account\\AccountLink','',1),(14836,'120386','printshop-mobile','block-14809-2','Samples\\SampleHistory','',7),(14837,'120387','printshop-mobile','block-14809-2','Html_box','',1),(14838,'120388','printshop-mobile','sample_info','BlockBox','',1),(14839,'120389','printshop-mobile','block-14838','BlockBox','',1),(14840,'120390','printshop-mobile','block-14839','WidgetsAria','',1),(14841,'120391','printshop-mobile','block-14839-2','Html_box','',3),(14842,'120392','printshop-mobile','block-14839-2','account\\OrdersHistory','',4),(14843,'120393','printshop-mobile','block-14839-2','Html_box','',1),(14844,'120394','printshop-mobile','block-14839-2','BlockBox','',2),(14845,'120395','printshop-mobile','block-14844','Html_box','',1),(14846,'120396','printshop-mobile','block-14844','account\\LastOrder','',2),(14847,'120397','printshop-mobile','block-14844-2','Html_box','',1),(14848,'120398','printshop-mobile','block-14844-2','account\\AccountLink','',3),(14849,'120399','printshop-mobile','block-14844-2','account\\OrderCount','',2),(14850,'120400','printshop-mobile','block-14844-3','Html_box','',1),(14851,'120401','printshop-mobile','block-14844-3','account\\TotalOrdered','',2),(14852,'120402','printshop-mobile','block-14844-4','Html_box','',1),(14853,'120403','printshop-mobile','block-14844-4','account\\AccountLink','',3),(14854,'120404','printshop-mobile','block-14844-4','account\\CreditAmount','',2),(14855,'120405','printshop-mobile','block-14844-5','account\\AccountLink','',3),(14856,'120406','printshop-mobile','block-14844-5','account\\PointsEarnt','',2),(14857,'120407','printshop-mobile','block-14844-5','Html_box','',1),(14858,'120408','printshop-mobile','block-14839-2','BlockBox','',5),(14859,'120409','printshop-mobile','block-14858','account\\GiftCards','',6),(14860,'120410','printshop-mobile','block-14858','Html_box','',1),(14861,'120411','printshop-mobile','block-14839-2','Html_box','',5),(14862,'120412','printshop-mobile','sitemap','BlockBox','',1),(14863,'120413','printshop-mobile','block-14862','BlockBox','',2),(14864,'120414','printshop-mobile','block-14863','Menu','Account box',6),(14865,'120415','printshop-mobile','block-14863','sitemap\\InfoPages','',2),(14866,'120416','printshop-mobile','block-14863','Html_box','',5),(14867,'120417','printshop-mobile','block-14863','sitemap\\Categories','',4),(14868,'120418','printshop-mobile','block-14863','Html_box','',3),(14869,'120419','printshop-mobile','block-14863','Html_box','',1),(14870,'120420','printshop-mobile','block-14863-2','Html_box','',1),(14871,'120421','printshop-mobile','block-14863-2','sitemap\\DeliveryLocation','',2),(14872,'120422','printshop-mobile','block-14862','Html_box','',1),(14873,'120423','printshop-mobile','subscribe','BlockBox','',1),(14874,'120424','printshop-mobile','block-14873','subscribers\\SubscribeForm','',2),(14875,'120425','printshop-mobile','block-14873','Html_box','',1),(14876,'120426','printshop-mobile','block-14873','Html_box','',3),(14877,'120427','printshop-mobile','block-14873','subscribers\\UnsubscribeForm','',4),(14878,'120428','printshop-mobile','subscribed','BlockBox','',1),(14879,'120429','printshop-mobile','block-14878','Html_box','',1),(14880,'120430','printshop-mobile','subscription','BlockBox','',2),(14881,'120431','printshop-mobile','block-14880','BlockBox','',1),(14882,'120432','printshop-mobile','block-14881','WidgetsAria','',1),(14883,'120433','printshop-mobile','block-14881-2','Html_box','',2),(14884,'120434','printshop-mobile','block-14881-2','Html_box','',3),(14885,'120435','printshop-mobile','block-14881-2','account\\Subscription','',4),(14886,'120436','printshop-mobile','success','BlockBox','',1),(14887,'120437','printshop-mobile','block-14886','BlockBox','',1),(14888,'120438','printshop-mobile','block-14887','Text','',2),(14889,'120439','printshop-mobile','block-14887','BlockBox','',3),(14890,'120440','printshop-mobile','block-14889','Html','',3),(14891,'120441','printshop-mobile','block-14889-2','success\\PrintBtn','',1),(14892,'120442','printshop-mobile','block-14889-3','success\\ContinueBtn','',1),(14893,'120443','printshop-mobile','success_q','BlockBox','',1),(14894,'120444','printshop-mobile','block-14893','BlockBox','',1),(14895,'120445','printshop-mobile','block-14894','BlockBox','',2),(14896,'120446','printshop-mobile','block-14895','success\\PrintBtn','',1),(14897,'120447','printshop-mobile','block-14895','success\\ContinueBtn','',2),(14898,'120448','printshop-mobile','block-14894','Html_box','',1),(14902,'120452','printshop-mobile','ticket','invoice\\Container','',1),(14903,'120453','printshop-mobile','block-14902','BlockBox','',1),(14904,'120454','printshop-mobile','block-14903-2','BlockBox','',1),(14905,'120455','printshop-mobile','block-14904','invoice\\StoreAddress','',1),(14906,'120456','printshop-mobile','block-14903-2','BlockBox','',2),(14907,'120457','printshop-mobile','block-14906','Text','',1),(14908,'120458','printshop-mobile','block-14906-2','invoice\\StorePhone','',1),(14909,'120459','printshop-mobile','block-14903-2','BlockBox','',4),(14910,'120460','printshop-mobile','block-14909','Text','',1),(14911,'120461','printshop-mobile','block-14909-2','invoice\\StoreSite','',1),(14912,'120462','printshop-mobile','block-14903-2','BlockBox','',3),(14913,'120463','printshop-mobile','block-14912','Text','',1),(14914,'120464','printshop-mobile','block-14912-2','invoice\\StoreEmail','',1),(14915,'120465','printshop-mobile','block-14902','BlockBox','',2),(14916,'120466','printshop-mobile','block-14915','BlockBox','',7),(14917,'120467','printshop-mobile','block-14916','BlockBox','',1),(14918,'120468','printshop-mobile','block-14917','Text','',1),(14919,'120469','printshop-mobile','block-14917','invoice\\BillingAddress','',2),(14920,'120470','printshop-mobile','block-14916-2','BlockBox','',1),(14921,'120471','printshop-mobile','block-14920','Text','',3),(14922,'120472','printshop-mobile','block-14920','Text','',5),(14923,'120473','printshop-mobile','block-14920','Text','',1),(14924,'120474','printshop-mobile','block-14920','invoice\\CustomerPhone','',4),(14925,'120475','printshop-mobile','block-14920','invoice\\CustomerName','',2),(14926,'120476','printshop-mobile','block-14920','invoice\\CustomerEmail','',6),(14927,'120477','printshop-mobile','block-14915','BlockBox','',8),(14928,'120478','printshop-mobile','block-14927','BlockBox','',1),(14929,'120479','printshop-mobile','block-14928','Text','',1),(14930,'120480','printshop-mobile','block-14928','invoice\\ShippingMethod','',2),(14931,'120481','printshop-mobile','block-14927-2','BlockBox','',1),(14932,'120482','printshop-mobile','block-14931','invoice\\ShippingMethod','',2),(14933,'120483','printshop-mobile','block-14931','Text','',1),(14934,'120484','printshop-mobile','block-14915-2','Text','',2),(14935,'120485','printshop-mobile','block-14915-2','invoice\\OrderBarcode','',6),(14936,'120486','printshop-mobile','block-14915-2','Text','',4),(14937,'120487','printshop-mobile','block-14915-2','invoice\\OrderId','',1),(14938,'120488','printshop-mobile','block-14915-2','invoice\\PaymentDate','',3),(14939,'120489','printshop-mobile','block-14915-2','invoice\\PaymentMethod','',5),(14940,'120490','printshop-mobile','block-14902','BlockBox','',5),(14941,'120491','printshop-mobile','block-14940','Text','',1),(14942,'120492','printshop-mobile','block-14940','invoice\\StoreAddress','',8),(14943,'120493','printshop-mobile','block-14940-2','Logo','',1),(14944,'120494','printshop-mobile','block-14940-2','Text','',2),(14945,'120495','printshop-mobile','block-14940-3','BlockBox','',2),(14946,'120496','printshop-mobile','block-14945','Text','',1),(14947,'120497','printshop-mobile','block-14945-2','invoice\\StorePhone','',1),(14948,'120498','printshop-mobile','block-14940-3','Text','',1),(14949,'120499','printshop-mobile','block-14940-3','BlockBox','',3),(14950,'120500','printshop-mobile','block-14949','Text','',1),(14951,'120501','printshop-mobile','block-14949-2','invoice\\StoreEmail','',1),(14952,'120502','printshop-mobile','block-14902','invoice\\Products','',3),(14953,'120503','printshop-mobile','block-14902','BlockBox','',4),(14954,'120504','printshop-mobile','block-14953','BlockBox','',1),(14955,'120505','printshop-mobile','block-14954','invoice\\ShippingAddress','',2),(14956,'120506','printshop-mobile','block-14954','Text','',1),(14957,'120507','printshop-mobile','block-14953-2','BlockBox','',1),(14958,'120508','printshop-mobile','block-14957','invoice\\Totals','',1),(14959,'120509','printshop-mobile','tl_blog_category','BlockBox','',1),(14960,'120510','printshop-mobile','block-14959','BlockBox','',1),(14961,'120511','printshop-mobile','block-14960','BlockBox','',1),(14962,'120512','printshop-mobile','block-14961','Blog\\widget\\PostListing','',1),(14963,'120513','printshop-mobile','block-14961','catalog\\Paging','',2),(14964,'120514','printshop-mobile','block-14960-2','WidgetsAria','',1),(14965,'120515','printshop-mobile','tl_blog_index','BlockBox','',2),(14966,'120516','printshop-mobile','block-14965','BlockBox','',2),(14967,'120517','printshop-mobile','block-14966','BlockBox','',1),(14968,'120518','printshop-mobile','block-14967','Blog\\widget\\PostListing','',1),(14969,'120519','printshop-mobile','block-14967','catalog\\Paging','',2),(14970,'120520','printshop-mobile','block-14966-2','WidgetsAria','',1),(14971,'120521','printshop-mobile','block-14965','Banner','',1),(14972,'120522','printshop-mobile','tl_blog_post','BlockBox','',1),(14973,'120523','printshop-mobile','block-14972','BlockBox','',3),(14974,'120524','printshop-mobile','block-14973','Blog\\widget\\PostTags','',2),(14975,'120525','printshop-mobile','block-14973','BlockBox','',3),(14976,'120526','printshop-mobile','block-14975','Html_box','',1),(14977,'120527','printshop-mobile','block-14975','Blog\\widget\\PostLinkedProducts','',2),(14978,'120528','printshop-mobile','block-14973','BlockBox','',1),(14979,'120529','printshop-mobile','block-14978','Blog\\widget\\PostTitle','',3),(14980,'120530','printshop-mobile','block-14978','Blog\\widget\\PostImage','',1),(14981,'120531','printshop-mobile','block-14978','Blog\\widget\\PostDescription','',4),(14982,'120532','printshop-mobile','block-14978','BlockBox','',5),(14983,'120533','printshop-mobile','block-14982','Blog\\widget\\PostViewed','',1),(14984,'120534','printshop-mobile','block-14978','Blog\\widget\\PostDate','',2),(14985,'120535','printshop-mobile','block-14973-2','WidgetsAria','',1),(14986,'120536','printshop-mobile','tl_blog_tags','BlockBox','',1),(14987,'120537','printshop-mobile','block-14986','BlockBox','',1),(14988,'120538','printshop-mobile','block-14987','BlockBox','',1),(14989,'120539','printshop-mobile','block-14988','Blog\\widget\\PostListing','',1),(14990,'120540','printshop-mobile','block-14988','catalog\\Paging','',2),(14991,'120541','printshop-mobile','block-14987-2','WidgetsAria','',1),(14992,'120542','printshop-mobile','tracking_numbers','BlockBox','',1),(14993,'120543','printshop-mobile','block-14992','account\\OrderTracking','',2),(14994,'120544','printshop-mobile','block-14992','Html_box','',1),(14995,'120545','printshop-mobile','trade_form','BlockBox','',1),(14996,'120546','printshop-mobile','block-14995','BlockBox','',3),(14997,'120547','printshop-mobile','block-14996','BlockBox','',1),(14998,'120548','printshop-mobile','block-14997','account\\CustomerAdditionalField','',2),(14999,'120549','printshop-mobile','block-14997','account\\CustomerAdditionalField','',1),(15000,'120550','printshop-mobile','block-14995','BlockBox','',14),(15001,'120551','printshop-mobile','block-15000','account\\BackButton','',1),(15002,'120552','printshop-mobile','block-15000-2','account\\PdfButton','',2),(15003,'120553','printshop-mobile','block-15000-2','account\\SaveButton','',1),(15004,'120554','printshop-mobile','block-14995','BlockBox','',13),(15005,'120555','printshop-mobile','block-15004','BlockBox','',1),(15006,'120556','printshop-mobile','block-15005','account\\CustomerAdditionalField','',1),(15007,'120557','printshop-mobile','block-15004-2','BlockBox','',1),(15008,'120558','printshop-mobile','block-15007','account\\CustomerAdditionalField','',1),(15009,'120559','printshop-mobile','block-14995','Html_box','',10),(15010,'120560','printshop-mobile','block-14995','Html_box','',8),(15011,'120561','printshop-mobile','block-14995','Html_box','',12),(15012,'120562','printshop-mobile','block-14995','BlockBox','',11),(15013,'120563','printshop-mobile','block-15012','BlockBox','',1),(15014,'120564','printshop-mobile','block-15013','account\\CustomerAdditionalField','',4),(15015,'120565','printshop-mobile','block-15013','account\\CustomerAdditionalField','',2),(15016,'120566','printshop-mobile','block-15013','Html_box','',1),(15017,'120567','printshop-mobile','block-15013','account\\CustomerAdditionalField','',3),(15018,'120568','printshop-mobile','block-15012-2','BlockBox','',1),(15019,'120569','printshop-mobile','block-15018','Html_box','',1),(15020,'120570','printshop-mobile','block-15018','account\\CustomerAdditionalField','',3),(15021,'120571','printshop-mobile','block-15018','account\\CustomerAdditionalField','',2),(15022,'120572','printshop-mobile','block-15018','account\\CustomerAdditionalField','',4),(15023,'120573','printshop-mobile','block-14995','BlockBox','',5),(15024,'120574','printshop-mobile','block-15023','BlockBox','',1),(15025,'120575','printshop-mobile','block-15024','account\\CustomerAdditionalField','',2),(15026,'120576','printshop-mobile','block-15024','account\\CustomerAdditionalField','',1),(15027,'120577','printshop-mobile','block-14995','BlockBox','',4),(15028,'120578','printshop-mobile','block-15027','BlockBox','',1),(15029,'120579','printshop-mobile','block-15028','account\\AddressesList','',2),(15030,'120580','printshop-mobile','block-15028','Html_box','',1),(15031,'120581','printshop-mobile','block-15028','account\\CustomerAdditionalField','',5),(15032,'120582','printshop-mobile','block-15028','BlockBox','',3),(15033,'120583','printshop-mobile','block-15032','account\\CustomerAdditionalField','',1),(15034,'120584','printshop-mobile','block-15028','BlockBox','',4),(15035,'120585','printshop-mobile','block-15034','BlockBox','',1),(15036,'120586','printshop-mobile','block-15035','account\\CustomerAdditionalField','',1),(15037,'120587','printshop-mobile','block-15035','account\\CustomerAdditionalField','',4),(15038,'120588','printshop-mobile','block-15035','account\\CustomerAdditionalField','',2),(15039,'120589','printshop-mobile','block-15035','account\\CustomerAdditionalField','',3),(15040,'120590','printshop-mobile','block-15034-2','BlockBox','',1),(15041,'120591','printshop-mobile','block-15040','account\\CustomerAdditionalField','',4),(15042,'120592','printshop-mobile','block-15040','account\\CustomerAdditionalField','',3),(15043,'120593','printshop-mobile','block-15040','account\\CustomerAdditionalField','',2),(15044,'120594','printshop-mobile','block-15040','account\\CustomerAdditionalField','',1),(15045,'120595','printshop-mobile','block-15027-2','BlockBox','',1),(15046,'120596','printshop-mobile','block-15045','account\\AddressesList','',2),(15047,'120597','printshop-mobile','block-15045','BlockBox','',3),(15048,'120598','printshop-mobile','block-15047','BlockBox','',1),(15049,'120599','printshop-mobile','block-15048','account\\CustomerAdditionalField','',1),(15050,'120600','printshop-mobile','block-15048','account\\CustomerAdditionalField','',2),(15051,'120601','printshop-mobile','block-15047-2','BlockBox','',1),(15052,'120602','printshop-mobile','block-15051','account\\CustomerAdditionalField','',1),(15053,'120603','printshop-mobile','block-15045','BlockBox','',4),(15054,'120604','printshop-mobile','block-15053','BlockBox','',1),(15055,'120605','printshop-mobile','block-15054','account\\CustomerAdditionalField','',2),(15056,'120606','printshop-mobile','block-15054','account\\CustomerAdditionalField','',1),(15057,'120607','printshop-mobile','block-15054','account\\CustomerAdditionalField','',3),(15058,'120608','printshop-mobile','block-15053-2','BlockBox','',1),(15059,'120609','printshop-mobile','block-15058','account\\CustomerAdditionalField','',2),(15060,'120610','printshop-mobile','block-15058','account\\CustomerAdditionalField','',1),(15061,'120611','printshop-mobile','block-15058','account\\CustomerAdditionalField','',3),(15062,'120612','printshop-mobile','block-15045','Html_box','',1),(15063,'120613','printshop-mobile','block-14995','BlockBox','',9),(15064,'120614','printshop-mobile','block-15063','BlockBox','',1),(15065,'120615','printshop-mobile','block-15064','account\\CustomerAdditionalField','',1),(15066,'120616','printshop-mobile','block-15064','account\\CustomerAdditionalField','',2),(15067,'120617','printshop-mobile','block-15063-2','BlockBox','',1),(15068,'120618','printshop-mobile','block-15067','account\\CustomerAdditionalField','',1),(15069,'120619','printshop-mobile','block-14995','Html_box','',2),(15070,'120620','printshop-mobile','block-14995','BlockBox','',7),(15071,'120621','printshop-mobile','block-15070','BlockBox','',1),(15072,'120622','printshop-mobile','block-15071','account\\CustomerAdditionalField','',1),(15073,'120623','printshop-mobile','block-15071','account\\CustomerAdditionalField','',2),(15074,'120624','printshop-mobile','block-15070-2','BlockBox','',1),(15075,'120625','printshop-mobile','block-15074','account\\CustomerAdditionalField','',1),(15076,'120626','printshop-mobile','block-15074','account\\CustomerAdditionalField','',2),(15077,'120627','printshop-mobile','block-14995','Html_box','',1),(15078,'120628','printshop-mobile','block-14995','Html_box','',6),(15079,'120629','printshop-mobile','trade_form_pdf','BlockBox','',1),(15080,'120630','printshop-mobile','block-15079','BlockBox','',14),(15081,'120631','printshop-mobile','block-15080','Html_box','',1),(15082,'120632','printshop-mobile','block-15080-2','account\\CustomerAdditionalField','',1),(15083,'120633','printshop-mobile','block-15079','BlockBox','',6),(15084,'120634','printshop-mobile','block-15083','Html_box','',1),(15085,'120635','printshop-mobile','block-15083-2','account\\CombinedField','',2),(15086,'120636','printshop-mobile','block-15079','BlockBox','',13),(15087,'120637','printshop-mobile','block-15086','Html_box','',1),(15088,'120638','printshop-mobile','block-15086-2','account\\CustomerAdditionalField','',1),(15089,'120639','printshop-mobile','block-15079','BlockBox','',12),(15090,'120640','printshop-mobile','block-15089','Html_box','',1),(15091,'120641','printshop-mobile','block-15089-2','account\\CombinedField','',2),(15092,'120642','printshop-mobile','block-15079','BlockBox','',11),(15093,'120643','printshop-mobile','block-15092','Html_box','',1),(15094,'120644','printshop-mobile','block-15092-2','account\\CombinedField','',1),(15095,'120645','printshop-mobile','block-15079','BlockBox','',9),(15096,'120646','printshop-mobile','block-15095','Html_box','',1),(15097,'120647','printshop-mobile','block-15095-2','account\\CustomerAdditionalField','',1),(15098,'120648','printshop-mobile','block-15079','BlockBox','',8),(15099,'120649','printshop-mobile','block-15098','Html_box','',1),(15100,'120650','printshop-mobile','block-15098-2','BlockBox','',1),(15101,'120651','printshop-mobile','block-15100','account\\CustomerAdditionalField','',1),(15102,'120652','printshop-mobile','block-15100-2','BlockBox','',1),(15103,'120653','printshop-mobile','block-15102','Html_box','',2),(15104,'120654','printshop-mobile','block-15102-2','account\\CustomerAdditionalField','',1),(15105,'120655','printshop-mobile','block-15079','BlockBox','',3),(15106,'120656','printshop-mobile','block-15105','Html_box','',1),(15107,'120657','printshop-mobile','block-15079','BlockBox','',1),(15108,'120658','printshop-mobile','block-15107','Contacts','',1),(15109,'120659','printshop-mobile','block-15107-2','Html_box','',1),(15110,'120660','printshop-mobile','block-15079','BlockBox','',4),(15111,'120661','printshop-mobile','block-15110-2','BlockBox','',1),(15112,'120662','printshop-mobile','block-15111','BlockBox','',1),(15113,'120663','printshop-mobile','block-15112','Html_box','',2),(15114,'120664','printshop-mobile','block-15112-2','account\\CustomerAdditionalField','',1),(15115,'120665','printshop-mobile','block-15111-2','BlockBox','',1),(15116,'120666','printshop-mobile','block-15115','Html_box','',1),(15117,'120667','printshop-mobile','block-15115-2','account\\CustomerAdditionalField','',1),(15118,'120668','printshop-mobile','block-15079','BlockBox','',2),(15119,'120669','printshop-mobile','block-15118','Contacts','',1),(15120,'120670','printshop-mobile','block-15079','BlockBox','',7),(15121,'120671','printshop-mobile','block-15120','Html_box','',1),(15122,'120672','printshop-mobile','block-15120-2','account\\CustomerAdditionalField','',1),(15123,'120673','printshop-mobile','block-15079','BlockBox','',5),(15124,'120674','printshop-mobile','block-15123','Html_box','',1),(15125,'120675','printshop-mobile','block-15123-2','account\\CustomerAdditionalField','',1),(15126,'120676','printshop-mobile','block-15079','BlockBox','',10),(15127,'120677','printshop-mobile','block-15126','Html_box','',1),(15128,'120678','printshop-mobile','block-15126-2','account\\CustomerAdditionalField','',1),(15129,'120679','printshop-mobile','block-15079','BlockBox','',18),(15130,'120680','printshop-mobile','block-15129','Html_box','',1),(15131,'120681','printshop-mobile','block-15129-2','account\\CustomerAdditionalField','',1),(15132,'120682','printshop-mobile','block-15079','BlockBox','',15),(15133,'120683','printshop-mobile','block-15132','Html_box','',1),(15134,'120684','printshop-mobile','block-15079','BlockBox','',17),(15135,'120685','printshop-mobile','block-15134','Html_box','',1),(15136,'120686','printshop-mobile','block-15079','BlockBox','',20),(15137,'120687','printshop-mobile','block-15136','Html_box','',1),(15138,'120688','printshop-mobile','block-15136-2','account\\CustomerAdditionalField','',1),(15139,'120689','printshop-mobile','block-15079','BlockBox','',19),(15140,'120690','printshop-mobile','block-15139','Html_box','',1),(15141,'120691','printshop-mobile','block-15139-2','account\\CustomerAdditionalField','',1),(15142,'120692','printshop-mobile','block-15079','BlockBox','',16),(15143,'120693','printshop-mobile','block-15142','Html_box','',1),(15144,'120694','printshop-mobile','block-15142-2','BlockBox','',1),(15145,'120695','printshop-mobile','block-15144','account\\CustomerAdditionalField','',1),(15146,'120696','printshop-mobile','block-15144-2','Html_box','',1),(15147,'120697','printshop-mobile','block-15144-3','account\\CustomerAdditionalField','',1),(15148,'120698','printshop-mobile','block-15142-3','BlockBox','',1),(15149,'120699','printshop-mobile','block-15079','BlockBox','',23),(15150,'120700','printshop-mobile','block-15149','Html_box','',1),(15151,'120701','printshop-mobile','block-15149-2','account\\CustomerAdditionalField','',1),(15152,'120702','printshop-mobile','block-15079','BlockBox','',21),(15153,'120703','printshop-mobile','block-15152','Html_box','',1),(15154,'120704','printshop-mobile','block-15079','BlockBox','',26),(15155,'120705','printshop-mobile','block-15154','Html_box','',1),(15156,'120706','printshop-mobile','block-15079','BlockBox','',24),(15157,'120707','printshop-mobile','block-15156','Html_box','',1),(15158,'120708','printshop-mobile','block-15156-2','account\\CustomerAdditionalField','',1),(15159,'120709','printshop-mobile','block-15079','BlockBox','',25),(15160,'120710','printshop-mobile','block-15159','Html_box','',1),(15161,'120711','printshop-mobile','block-15079','BlockBox','',22),(15162,'120712','printshop-mobile','block-15161','Html_box','',1),(15163,'120713','printshop-mobile','block-15161-2','account\\CustomerAdditionalField','',1),(15164,'120714','printshop-mobile','block-15079','BlockBox','',27),(15165,'120715','printshop-mobile','block-15164','Html_box','',1),(15166,'120716','printshop-mobile','block-15164-2','Html_box','',1),(15167,'120717','printshop-mobile','block-15164-3','Html_box','',1),(15168,'120718','printshop-mobile','block-15164-4','Html_box','',1),(15169,'120719','printshop-mobile','block-15079','BlockBox','',28),(15170,'120720','printshop-mobile','block-15169','Html_box','',1),(15171,'120721','printshop-mobile','block-15169-2','account\\CustomerAdditionalField','',1),(15172,'120722','printshop-mobile','block-15169-3','Html_box','',1),(15173,'120723','printshop-mobile','block-15169-4','account\\CustomerAdditionalField','',1),(15174,'120724','printshop-mobile','block-15079','BlockBox','',29),(15175,'120725','printshop-mobile','block-15174','Html_box','',1),(15176,'120726','printshop-mobile','unsubscribed','BlockBox','',1),(15177,'120727','printshop-mobile','block-15176','Html_box','',1),(15178,'120728','printshop-mobile','update-and-pay-order_confirmation','BlockBox','',1),(15179,'120729','printshop-mobile','block-15178','BlockBox','',3),(15180,'120730','printshop-mobile','block-15179','BlockBox','',1),(15181,'120731','printshop-mobile','block-15180','BlockBox','',1),(15182,'120732','printshop-mobile','block-15181','BlockBox','',1),(15183,'120733','printshop-mobile','block-15182','Html_box','',4),(15184,'120734','printshop-mobile','block-15182','Html_box','',2),(15185,'120735','printshop-mobile','block-15182','Html_box','',1),(15186,'120736','printshop-mobile','block-15182','order\\ShippingMethod','',5),(15187,'120737','printshop-mobile','block-15182','order\\DeliveryAddress','',3),(15188,'120738','printshop-mobile','block-15182','order\\Telephone','',8),(15189,'120739','printshop-mobile','block-15182','order\\Email','',9),(15190,'120740','printshop-mobile','block-15182','order\\Name','',7),(15191,'120741','printshop-mobile','block-15182','Html_box','',6),(15192,'120742','printshop-mobile','block-15181-2','BlockBox','',1),(15193,'120743','printshop-mobile','block-15192','order\\BillingAddress','',3),(15194,'120744','printshop-mobile','block-15192','UpdateAndPay\\PayConfirm','',5),(15195,'120745','printshop-mobile','block-15192','Html_box','',1),(15196,'120746','printshop-mobile','block-15192','Html_box','',2),(15197,'120747','printshop-mobile','block-15192','Html_box','',4),(15198,'120748','printshop-mobile','block-15180','BlockBox','',3),(15199,'120749','printshop-mobile','block-15198','order\\Products','',2),(15200,'120750','printshop-mobile','block-15198','Html_box','',1),(15201,'120751','printshop-mobile','block-15179-2','BlockBox','',1),(15202,'120752','printshop-mobile','block-15201','Html_box','',1),(15203,'120753','printshop-mobile','block-15201','checkout\\ContinueBtn','',3),(15204,'120754','printshop-mobile','block-15201','order\\Totals','',2),(15205,'120755','printshop-mobile','block-15178','account\\OrderHeading','',1),(15206,'120756','printshop-mobile','update-and-pay-order_pay','BlockBox','',1),(15207,'120757','printshop-mobile','block-15206','BlockBox','',3),(15208,'120758','printshop-mobile','block-15207','BlockBox','',1),(15209,'120759','printshop-mobile','block-15208','BlockBox','',3),(15210,'120760','printshop-mobile','block-15209','Html_box','',1),(15211,'120761','printshop-mobile','block-15209','order\\Products','',2),(15212,'120762','printshop-mobile','block-15208','BlockBox','',1),(15213,'120763','printshop-mobile','block-15212','BlockBox','',1),(15214,'120764','printshop-mobile','block-15213','order\\Name','',7),(15215,'120765','printshop-mobile','block-15213','order\\Email','',9),(15216,'120766','printshop-mobile','block-15213','order\\DeliveryAddress','',3),(15217,'120767','printshop-mobile','block-15213','Html_box','',6),(15218,'120768','printshop-mobile','block-15213','order\\Telephone','',8),(15219,'120769','printshop-mobile','block-15213','Html_box','',2),(15220,'120770','printshop-mobile','block-15213','order\\ShippingMethod','',5),(15221,'120771','printshop-mobile','block-15213','Html_box','',4),(15222,'120772','printshop-mobile','block-15213','Html_box','',1),(15223,'120773','printshop-mobile','block-15212-2','BlockBox','',1),(15224,'120774','printshop-mobile','block-15223','Html_box','',2),(15225,'120775','printshop-mobile','block-15223','Html_box','',1),(15226,'120776','printshop-mobile','block-15223','Html_box','',4),(15227,'120777','printshop-mobile','block-15223','order\\BillingAddress','',3),(15228,'120778','printshop-mobile','block-15223','UpdateAndPay\\PayForm','',5),(15229,'120779','printshop-mobile','block-15207-2','BlockBox','',1),(15230,'120780','printshop-mobile','block-15229','order\\Totals','',2),(15231,'120781','printshop-mobile','block-15229','Html_box','',1),(15232,'120782','printshop-mobile','block-15229','checkout\\ContinueBtn','',3),(15233,'120783','printshop-mobile','block-15206','account\\OrderHeading','',1),(15234,'120784','printshop-mobile','wedding_index','BlockBox','',1),(15235,'120785','printshop-mobile','block-15234','BlockBox','',1),(15236,'120786','printshop-mobile','block-15235','WeddingRegistry\\widgets\\ViewCreateRegistryWidget','',2),(15237,'120787','printshop-mobile','block-15235','WeddingRegistry\\widgets\\SearchRegistryButton','',3),(15238,'120788','printshop-mobile','block-15235','Heading','',1),(15239,'120789','printshop-mobile','wedding_manage','BlockBox','',2),(15240,'120790','printshop-mobile','block-15239','WeddingRegistry\\widgets\\Photos','',1),(15241,'120791','printshop-mobile','block-15239-2','WeddingRegistry\\widgets\\ManageNames','',1),(15242,'120792','printshop-mobile','block-15239-2','BlockBox','',3),(15243,'120793','printshop-mobile','block-15242','WeddingRegistry\\widgets\\EditLink','',1),(15244,'120794','printshop-mobile','block-15242','WeddingRegistry\\widgets\\DeleteLink','',2),(15245,'120795','printshop-mobile','block-15242','WeddingRegistry\\widgets\\ShareLink','',3),(15246,'120796','printshop-mobile','block-15239-2','WeddingRegistry\\widgets\\ManageDate','',2),(15247,'120797','printshop-mobile','block-15239-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(15248,'120798','printshop-mobile','wedding_manage','WeddingRegistry\\widgets\\ManageBanner','',1),(15249,'120799','printshop-mobile','wedding_manage','WeddingRegistry\\widgets\\AddItemsLink','',3),(15250,'120800','printshop-mobile','wedding_manage','WeddingRegistry\\widgets\\Products','',4),(15254,'120804','printshop-mobile','wedding_search','BlockBox','',1),(15255,'120805','printshop-mobile','block-15254','WeddingRegistry\\widgets\\SearchList','',2),(15256,'120806','printshop-mobile','block-15254','WeddingRegistry\\widgets\\SearchPaging','',3),(15257,'120807','printshop-mobile','block-15254','BlockBox','',1),(15258,'120808','printshop-mobile','block-15257','BlockBox','',1),(15259,'120809','printshop-mobile','block-15258','WeddingRegistry\\widgets\\SearchForm','',2),(15260,'120810','printshop-mobile','block-15258','Html_box','',1),(15261,'120811','printshop-mobile','wedding_share','BlockBox','',1),(15262,'120812','printshop-mobile','block-15261','BlockBox','',4),(15263,'120813','printshop-mobile','block-15262-2','Html_box','',3),(15264,'120814','printshop-mobile','block-15262-2','Html_box','',1),(15265,'120815','printshop-mobile','block-15262-2','WeddingRegistry\\widgets\\ShareUrl','',2),(15266,'120816','printshop-mobile','block-15262-2','WeddingRegistry\\widgets\\InviteList','',4),(15267,'120817','printshop-mobile','block-15261','WeddingRegistry\\widgets\\ManageBanner','',1),(15268,'120818','printshop-mobile','block-15261','WeddingRegistry\\widgets\\Photos','',2),(15269,'120819','printshop-mobile','block-15261','Html_box','',3),(15270,'120820','printshop-mobile','wedding_success','Html_box','',1),(15271,'120821','printshop-mobile','wedding_success','WeddingRegistry\\widgets\\BackButton','',2),(15272,'120822','printshop-mobile','wedding_update','BlockBox','',2),(15273,'120823','printshop-mobile','block-15272','BlockBox','',1),(15274,'120824','printshop-mobile','block-15273','Html_box','',5),(15275,'120825','printshop-mobile','block-15273','Html_box','',3),(15276,'120826','printshop-mobile','block-15273','WeddingRegistry\\widgets\\Details','',4),(15277,'120827','printshop-mobile','block-15273','WeddingRegistry\\widgets\\Names','',2),(15278,'120828','printshop-mobile','block-15273','Html_box','',1),(15279,'120829','printshop-mobile','block-15273','WeddingRegistry\\widgets\\ShareRegistry','',6),(15280,'120830','printshop-mobile','block-15272-2','BlockBox','',1),(15281,'120831','printshop-mobile','block-15280','WeddingRegistry\\widgets\\ShippingDetails','',2),(15282,'120832','printshop-mobile','block-15280','Html_box','',1),(15283,'120833','printshop-mobile','block-15280','Html_box','',5),(15284,'120834','printshop-mobile','block-15280','WeddingRegistry\\widgets\\Photos','',6),(15285,'120835','printshop-mobile','block-15280','Html_box','',3),(15286,'120836','printshop-mobile','block-15280','WeddingRegistry\\widgets\\InformationText','',4),(15287,'120837','printshop-mobile','wedding_update','Html_box','',1),(15288,'120838','printshop-mobile','wedding_update','BlockBox','',3),(15289,'120839','printshop-mobile','block-15288','WeddingRegistry\\widgets\\BackButton','',1),(15290,'120840','printshop-mobile','block-15288-2','WeddingRegistry\\widgets\\SaveButton','',1),(15291,'120841','printshop-mobile','wedding_view','WeddingRegistry\\widgets\\ManageBanner','',1),(15292,'120842','printshop-mobile','wedding_view','BlockBox','',2),(15293,'120843','printshop-mobile','block-15292','WeddingRegistry\\widgets\\Photos','',1),(15294,'120844','printshop-mobile','block-15292-2','WeddingRegistry\\widgets\\ManageDate','',2),(15295,'120845','printshop-mobile','block-15292-2','WeddingRegistry\\widgets\\ManageNames','',1),(15296,'120846','printshop-mobile','block-15292-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(15297,'120847','printshop-mobile','wedding_view','WeddingRegistry\\widgets\\Products','',6),(15298,'120848','printshop-mobile','wishlist','BlockBox','',1),(15299,'120849','printshop-mobile','block-15298','BlockBox','',1),(15300,'120850','printshop-mobile','block-15299','WidgetsAria','',1),(15301,'120851','printshop-mobile','block-15299-2','Html_box','',1),(15302,'120852','printshop-mobile','block-15299-2','account\\Wishlist','',2),(15303,'120853','printshop-mobile','wishlist-cart','BlockBox','',1),(15304,'120854','printshop-mobile','block-15303','cart\\CartTabs','',1),(15305,'120855','printshop-mobile','block-15304','account\\Wishlist','',1),(17790,'118459','deals-mobile','404','Html_box','',1),(17887,'118556','deals-mobile','account','BlockBox','',1),(17888,'118557','deals-mobile','block-17887','BlockBox','',1),(17889,'118558','deals-mobile','block-17888','WidgetsAria','',1),(17890,'118559','deals-mobile','block-17888-2','Html_box','',3),(17891,'118560','deals-mobile','block-17888-2','account\\OrdersHistory','',4),(17892,'118561','deals-mobile','block-17888-2','Html_box','',1),(17893,'118562','deals-mobile','block-17888-2','BlockBox','',2),(17894,'118563','deals-mobile','block-17893','Html_box','',1),(17895,'118564','deals-mobile','block-17893','account\\LastOrder','',2),(17896,'118565','deals-mobile','block-17893-2','Html_box','',1),(17897,'118566','deals-mobile','block-17893-2','account\\AccountLink','',3),(17898,'118567','deals-mobile','block-17893-2','account\\OrderCount','',2),(17899,'118568','deals-mobile','block-17893-3','Html_box','',1),(17900,'118569','deals-mobile','block-17893-3','account\\TotalOrdered','',2),(17901,'118570','deals-mobile','block-17893-4','Html_box','',1),(17902,'118571','deals-mobile','block-17893-4','account\\AccountLink','',3),(17903,'118572','deals-mobile','block-17893-4','account\\CreditAmount','',2),(17904,'118573','deals-mobile','block-17893-5','account\\AccountLink','',3),(17905,'118574','deals-mobile','block-17893-5','account\\PointsEarnt','',2),(17906,'118575','deals-mobile','block-17893-5','Html_box','',1),(17907,'118576','deals-mobile','block-17888-2','BlockBox','',5),(17908,'118577','deals-mobile','block-17907','account\\GiftCards','',6),(17909,'118578','deals-mobile','block-17907','Html_box','',1),(17910,'118579','deals-mobile','block-17888-2','Html_box','',5),(17911,'118580','deals-mobile','account-menu','BlockBox','',1),(17912,'118581','deals-mobile','block-17911','BlockBox','',1),(17913,'118582','deals-mobile','block-17912','Html_box','',16),(17914,'118583','deals-mobile','block-17912','account\\AccountLink','',18),(17915,'118584','deals-mobile','block-17912','account\\AccountLink','',1),(17916,'118585','deals-mobile','block-17912','Html_box','',2),(17917,'118586','deals-mobile','block-17912','account\\AccountLink','',17),(17918,'118587','deals-mobile','block-17912','account\\AccountLink','',4),(17919,'118588','deals-mobile','block-17912','account\\AccountLink','',11),(17920,'118589','deals-mobile','block-17912','Html_box','',6),(17921,'118590','deals-mobile','block-17912','account\\AccountLink','',8),(17922,'118591','deals-mobile','block-17912','account\\AccountLink','',7),(17923,'118592','deals-mobile','block-17912','account\\AccountLink','',14),(17924,'118593','deals-mobile','block-17912','account\\AccountLink','',5),(17925,'118594','deals-mobile','block-17912','account\\AccountLink','',12),(17926,'118595','deals-mobile','block-17912','account\\AccountLink','',9),(17927,'118596','deals-mobile','block-17912','Html_box','',10),(17928,'118597','deals-mobile','block-17912','account\\AccountLink','',15),(17929,'118598','deals-mobile','account_edit','BlockBox','',1),(17930,'118599','deals-mobile','block-17929','BlockBox','',1),(17931,'118600','deals-mobile','block-17930','WidgetsAria','',1),(17932,'118601','deals-mobile','block-17930-2','account\\AccountEdit','',2),(17933,'118602','deals-mobile','block-17930-2','Html_box','',1),(17934,'118603','deals-mobile','block-17930-2','account\\AccountLink','',3),(17935,'118604','deals-mobile','address_book','BlockBox','',1),(17936,'118605','deals-mobile','block-17935','BlockBox','',1),(17937,'118606','deals-mobile','block-17936','WidgetsAria','',1),(17938,'118607','deals-mobile','block-17936-2','account\\AddressBook','',3),(17939,'118608','deals-mobile','block-17936-2','Html_box','',1),(17940,'118609','deals-mobile','address_book_process','BlockBox','',1),(17941,'118610','deals-mobile','block-17940','BlockBox','',1),(17942,'118611','deals-mobile','block-17941','WidgetsAria','',1),(17943,'118612','deals-mobile','block-17941-2','account\\EditAddress','',2),(17944,'118613','deals-mobile','block-17941-2','Html_box','',1),(17945,'118614','deals-mobile','block-17941-2','account\\AccountLink','',3),(17946,'118615','deals-mobile','b2b','BlockBox','',1),(17947,'118616','deals-mobile','block-17946','BlockBox','',1),(17948,'118617','deals-mobile','block-17947','productListing\\image','',1),(17949,'118618','deals-mobile','block-17947-2','productListing\\model','',5),(17950,'118619','deals-mobile','block-17947-2','productListing\\attributes','',3),(17951,'118620','deals-mobile','block-17947-2','BlockBox','',4),(17952,'118621','deals-mobile','block-17951','BlockBox','',1),(17953,'118622','deals-mobile','block-17952','productListing\\price','',1),(17954,'118623','deals-mobile','block-17952-2','productListing\\bonusPoints','',1),(17955,'118624','deals-mobile','block-17951-2','productListing\\qtyInput','',1),(17956,'118625','deals-mobile','block-17947-2','productListing\\description','',6),(17957,'118626','deals-mobile','block-17947-2','BlockBox','',2),(17958,'118627','deals-mobile','block-17957','productListing\\stock','',1),(17959,'118628','deals-mobile','block-17957-2','productListing\\rating','',1),(17960,'118629','deals-mobile','block-17947-2','productListing\\name','',1),(17961,'118630','deals-mobile','batch','BlockBox','',1),(17962,'118631','deals-mobile','block-17961','productListing\\attributes','',5),(17963,'118632','deals-mobile','block-17961','productListing\\price','',6),(17964,'118633','deals-mobile','block-17961','productListing\\name','',4),(17965,'118634','deals-mobile','block-17961','productListing\\image','',2),(17966,'118635','deals-mobile','block-17961','batchSelect','',1),(17967,'118636','deals-mobile','batch_selected','BlockBox','',1),(17968,'118637','deals-mobile','block-17967','BlockBox','',13),(17969,'118638','deals-mobile','block-17968','productListing\\image','',1),(17970,'118639','deals-mobile','block-17968-2','batchRemove','',1),(17971,'118640','deals-mobile','block-17968-2','productListing\\price','',3),(17972,'118641','deals-mobile','block-17968-2','productListing\\name','',2),(17973,'118642','deals-mobile','bbbbb','BlockBox','',1),(17974,'118643','deals-mobile','block-17973','BlockBox','',2),(17975,'118644','deals-mobile','block-17974','Filters','',1),(17976,'118645','deals-mobile','block-17974-2','BlockBox','',6),(17977,'118646','deals-mobile','block-17976','catalog\\CountsItems','',1),(17978,'118647','deals-mobile','block-17976-2','catalog\\Paging','',1),(17979,'118648','deals-mobile','block-17974-2','catalog\\Image','',1),(17980,'118649','deals-mobile','block-17974-2','Listing','',5),(17981,'118650','deals-mobile','block-17974-2','catalog\\ImageMapCategory','',3),(17982,'118651','deals-mobile','block-17974-2','BlockBox','',4),(17983,'118652','deals-mobile','block-17982','catalog\\ListingLook','',1),(17984,'118653','deals-mobile','block-17982','catalog\\CompareButton','',2),(17985,'118654','deals-mobile','block-17982','catalog\\ItemsOnPage','',4),(17986,'118655','deals-mobile','block-17982','catalog\\Sorting','',3),(17987,'118656','deals-mobile','block-17974-2','Categories','',2),(17988,'118657','deals-mobile','block-17973','catalog\\Title','',1),(17989,'118658','deals-mobile','blog','BlockBox','',1),(17990,'118659','deals-mobile','block-17989','BlockBox','',1),(17991,'118660','deals-mobile','block-17990','BlogContent','',1),(17992,'118661','deals-mobile','block-17990-2','BlogSidebar','',1),(17993,'118662','deals-mobile','blogsidebar','BlockBox','',1),(17994,'118663','deals-mobile','block-17993','Blog\\widget\\RecentPosts','',4),(17995,'118664','deals-mobile','block-17993','Blog\\widget\\TagCloud','',2),(17996,'118665','deals-mobile','block-17993','Blog\\widget\\CategoriesList','',1),(17997,'118666','deals-mobile','block-17993','Blog\\widget\\MostPopularPosts','',3),(17998,'118667','deals-mobile','cart','BlockBox','',2),(17999,'118668','deals-mobile','block-17998','BlockBox','',4),(18000,'118669','deals-mobile','block-17999','Html_box','',1),(18001,'118670','deals-mobile','block-17999','cart\\UpSell','6',2),(18002,'118671','deals-mobile','block-17998','BlockBox','',1),(18003,'118672','deals-mobile','block-18002','cart\\Products','',3),(18004,'118673','deals-mobile','block-18002','BlockBox','',2),(18005,'118674','deals-mobile','block-18004','MultiCart\\SaveCart','',2),(18006,'118675','deals-mobile','block-18004-2','MultiCart\\Actions','',1),(18007,'118676','deals-mobile','block-18002','MultiCart\\CartSwitcher','',1),(18008,'118677','deals-mobile','block-17998','BlockBox','',3),(18009,'118678','deals-mobile','block-18008','cart\\GiveAway','',2),(18010,'118679','deals-mobile','block-18008','Html_box','',1),(18011,'118680','deals-mobile','block-17998','BlockBox','',2),(18012,'118681','deals-mobile','block-18011','Html_box','',1),(18013,'118682','deals-mobile','block-18011','BlockBox','',2),(18014,'118683','deals-mobile','block-18013','cart\\DiscountCoupon','',1),(18015,'118684','deals-mobile','block-18013','cart\\CreditAmount','',2),(18016,'118685','deals-mobile','block-18013','cart\\BonusPoints','',3),(18017,'118686','deals-mobile','block-17998','BlockBox','',5),(18018,'118687','deals-mobile','block-18017','Html_box','',1),(18019,'118688','deals-mobile','block-18017','cart\\ShippingEstimator','',2),(18020,'118689','deals-mobile','block-17998','BlockBox','',7),(18021,'118690','deals-mobile','block-18020','BlockBox','',2),(18022,'118691','deals-mobile','block-18021','Image','',4),(18023,'118692','deals-mobile','block-18021','cart\\CheckoutBtn','',2),(18024,'118693','deals-mobile','block-18021','cart\\OrderTotal','',1),(18025,'118694','deals-mobile','block-17998','Html_box','',6),(18026,'118695','deals-mobile','cart2','BlockBox','',2),(18027,'118696','deals-mobile','block-18026','cart\\CartTabs','',2),(18028,'118697','deals-mobile','block-18027','BlockBox','',1),(18029,'118698','deals-mobile','block-18028','BlockBox','',4),(18030,'118699','deals-mobile','block-18029','cart\\UpSell','6',2),(18031,'118700','deals-mobile','block-18029','Html_box','',1),(18032,'118701','deals-mobile','block-18028','BlockBox','',1),(18033,'118702','deals-mobile','block-18032','cart\\Products','',3),(18034,'118703','deals-mobile','block-18032','BlockBox','',2),(18035,'118704','deals-mobile','block-18034','MultiCart\\CartSwitcher','',1),(18036,'118705','deals-mobile','block-18034','MultiCart\\SaveCart','',2),(18037,'118706','deals-mobile','block-18034-2','MultiCart\\Actions','',1),(18038,'118707','deals-mobile','block-18028','BlockBox','',3),(18039,'118708','deals-mobile','block-18038','cart\\GiveAway','',2),(18040,'118709','deals-mobile','block-18038','Html_box','',1),(18041,'118710','deals-mobile','block-18028','BlockBox','',2),(18042,'118711','deals-mobile','block-18041','Html_box','',1),(18043,'118712','deals-mobile','block-18041','BlockBox','',2),(18044,'118713','deals-mobile','block-18043','cart\\DiscountCoupon','',1),(18045,'118714','deals-mobile','block-18043-2','cart\\CreditAmount','',1),(18046,'118715','deals-mobile','block-18043-3','cart\\BonusPoints','',1),(18047,'118716','deals-mobile','block-18028','BlockBox','',5),(18048,'118717','deals-mobile','block-18047','Html_box','',1),(18049,'118718','deals-mobile','block-18047','cart\\ShippingEstimator','',2),(18050,'118719','deals-mobile','block-18028-2','BlockBox','',1),(18051,'118720','deals-mobile','block-18050','Html_box','',1),(18052,'118721','deals-mobile','block-18050','BlockBox','',2),(18053,'118722','deals-mobile','block-18052','Image','',4),(18054,'118723','deals-mobile','block-18052','cart\\CheckoutBtn','',2),(18055,'118724','deals-mobile','block-18052','cart\\OrderTotal','',1),(18056,'118725','deals-mobile','categories','BlockBox','',1),(18057,'118726','deals-mobile','block-18056','catalog\\Title','',1),(18058,'118727','deals-mobile','block-18056','Categories','',2),(18059,'118728','deals-mobile','categories','BlockBox','',2),(18060,'118729','deals-mobile','block-18059','Listing','',3),(18061,'118730','deals-mobile','block-18059','BlockBox','',1),(18062,'118731','deals-mobile','block-18061','catalog\\Sorting','',1),(18063,'118732','deals-mobile','block-18061-2','catalog\\CountsItems','',1),(18064,'118733','deals-mobile','block-18059','catalog\\Paging','',2),(18065,'118734','deals-mobile','category','ListingFunctionality','',2),(18066,'118735','deals-mobile','category','Categories','',1),(18067,'118736','deals-mobile','category','PagingBar','',5),(18068,'118737','deals-mobile','category','PagingBar','',3),(18069,'118738','deals-mobile','category','Listing','',4),(18070,'118739','deals-mobile','category_2','BlockBox','',1),(18071,'118740','deals-mobile','block-18070','catalog\\Title','',1),(18072,'118741','deals-mobile','block-18070','BlockBox','',2),(18073,'118742','deals-mobile','block-18072','Filters','',1),(18074,'118743','deals-mobile','block-18072-2','catalog\\Image','',1),(18075,'118744','deals-mobile','block-18072-2','Listing','',5),(18076,'118745','deals-mobile','block-18072-2','BlockBox','',4),(18077,'118746','deals-mobile','block-18076','catalog\\Sorting','',3),(18078,'118747','deals-mobile','block-18076','catalog\\ItemsOnPage','',4),(18079,'118748','deals-mobile','block-18076','catalog\\CompareButton','',2),(18080,'118749','deals-mobile','block-18076','catalog\\ListingLook','',1),(18081,'118750','deals-mobile','block-18072-2','catalog\\ImageMapCategory','',3),(18082,'118751','deals-mobile','block-18072-2','Categories','',2),(18083,'118752','deals-mobile','block-18072-2','BlockBox','',6),(18084,'118753','deals-mobile','block-18083','catalog\\CountsItems','',1),(18085,'118754','deals-mobile','block-18083-2','catalog\\Paging','',1),(18086,'118755','deals-mobile','category_no_filters','BlockBox','',1),(18087,'118756','deals-mobile','block-18086','catalog\\B2bAddButton','',7),(18088,'118757','deals-mobile','block-18086','BlockBox','',6),(18089,'118758','deals-mobile','block-18088','catalog\\CountsItems','',1),(18090,'118759','deals-mobile','block-18088-2','catalog\\Paging','',1),(18091,'118760','deals-mobile','block-18086','Listing','',5),(18092,'118761','deals-mobile','block-18086','catalog\\Image','',2),(18093,'118762','deals-mobile','block-18086','BlockBox','',4),(18094,'118763','deals-mobile','block-18093','catalog\\ListingLook','',1),(18095,'118764','deals-mobile','block-18093','catalog\\CompareButton','',2),(18096,'118765','deals-mobile','block-18093','HeaderStock','',5),(18097,'118766','deals-mobile','block-18093','catalog\\ItemsOnPage','',4),(18098,'118767','deals-mobile','block-18093','catalog\\Sorting','',3),(18099,'118768','deals-mobile','block-18086','Categories','',3),(18100,'118769','deals-mobile','block-18086','catalog\\Title','',1),(18101,'118770','deals-mobile','checkout','BlockBox','',1),(18102,'118771','deals-mobile','block-18101','BlockBox','',1),(18103,'118772','deals-mobile','block-18102','BlockBox','',2),(18104,'118773','deals-mobile','block-18103','BlockBox','',3),(18105,'118774','deals-mobile','block-18104','BlockBox','',2),(18106,'118775','deals-mobile','block-18105','checkout\\BillingAddress','',2),(18107,'118776','deals-mobile','block-18105','Html_box','',1),(18108,'118777','deals-mobile','block-18105-2','BlockBox','',1),(18109,'118778','deals-mobile','block-18108','Html_box','',1),(18110,'118779','deals-mobile','block-18108','checkout\\PaymentMethod','',2),(18111,'118780','deals-mobile','block-18104','Html_box','',1),(18112,'118781','deals-mobile','block-18103','BlockBox','',6),(18113,'118782','deals-mobile','block-18112','checkout\\CreateAccount','',2),(18114,'118783','deals-mobile','block-18112','cart\\Products','',1),(18115,'118784','deals-mobile','block-18103','BlockBox','',2),(18116,'118785','deals-mobile','block-18115','Html_box','',1),(18117,'118786','deals-mobile','block-18115','BlockBox','',3),(18118,'118787','deals-mobile','block-18117','BlockBox','',1),(18119,'118788','deals-mobile','block-18118','checkout\\ContactInformation','',4),(18120,'118789','deals-mobile','block-18118','UploadCustomerId\\UploadCustomerIdForm','',4),(18121,'118790','deals-mobile','block-18118','checkout\\ShippingAddress','',2),(18122,'118791','deals-mobile','block-18118','Html_box','',3),(18123,'118792','deals-mobile','block-18115','BlockBox','',4),(18124,'118793','deals-mobile','block-18123','Html_box','',1),(18125,'118794','deals-mobile','block-18123','DelayedDespatch\\Checkout','',3),(18126,'118795','deals-mobile','block-18123','checkout\\Shipping','',2),(18127,'118796','deals-mobile','block-18115','Neighbour\\Checkout','',5),(18128,'118797','deals-mobile','block-18115','BlockBox','',2),(18129,'118798','deals-mobile','block-18128','checkout\\ShippingChoice','',1),(18130,'118799','deals-mobile','block-18103','BlockBox','',4),(18131,'118800','deals-mobile','block-18130','Html_box','',1),(18132,'118801','deals-mobile','block-18130','BlockBox','',2),(18133,'118802','deals-mobile','block-18132','CouponsAndVauchers\\Checkout','',1),(18134,'118803','deals-mobile','block-18132-2','checkout\\BonusPoints','',2),(18135,'118804','deals-mobile','block-18132-2','checkout\\CreditAmount','',1),(18136,'118805','deals-mobile','block-18103','BlockBox','',5),(18137,'118806','deals-mobile','block-18136','checkout\\Comments','',2),(18138,'118807','deals-mobile','block-18136','Html_box','',1),(18139,'118808','deals-mobile','block-18101','BlockBox','',2),(18140,'118809','deals-mobile','block-18139','checkout\\Totals','',2),(18141,'118810','deals-mobile','block-18139','checkout\\ContinueBtn','',3),(18142,'118811','deals-mobile','block-18139','Html_box','',1),(18143,'118812','deals-mobile','block-18139','checkout\\Terms','',4),(18144,'118813','deals-mobile','block-18139','Html_box','',5),(18145,'118814','deals-mobile','checkout_confirmation','BlockBox','',1),(18146,'118815','deals-mobile','block-18145','checkout\\ConfirmBtn','',4),(18147,'118816','deals-mobile','block-18145','cart\\Products','',7),(18148,'118817','deals-mobile','block-18145','BlockBox','',2),(18149,'118818','deals-mobile','block-18148','BlockBox','',1),(18150,'118819','deals-mobile','block-18149','Html_box','',1),(18151,'118820','deals-mobile','block-18149','checkout\\ShippingAddressConfirm','',3),(18152,'118821','deals-mobile','block-18148-2','BlockBox','',1),(18153,'118822','deals-mobile','block-18152','Html_box','',1),(18154,'118823','deals-mobile','block-18152','checkout\\BillingAddressConfirm','',3),(18155,'118824','deals-mobile','block-18145','checkout\\ConfirmBtn','',9),(18156,'118825','deals-mobile','block-18145','BlockBox','',3),(18157,'118826','deals-mobile','block-18156','BlockBox','',1),(18158,'118827','deals-mobile','block-18157','Html_box','',1),(18159,'118828','deals-mobile','block-18157','checkout\\ShippingConfirm','',3),(18160,'118829','deals-mobile','block-18156-2','BlockBox','',1),(18161,'118830','deals-mobile','block-18160','checkout\\PaymentMethodConfirm','',3),(18162,'118831','deals-mobile','block-18160','Html_box','',1),(18163,'118832','deals-mobile','block-18145','checkout\\EditBtn','',6),(18164,'118833','deals-mobile','block-18145','checkout\\Totals','',8),(18165,'118834','deals-mobile','block-18145','Html_box','',5),(18166,'118835','deals-mobile','checkout_confirmation_no_shipping_q','BlockBox','',1),(18167,'118836','deals-mobile','block-18166','checkout\\Totals','',5),(18168,'118837','deals-mobile','block-18166','checkout\\ConfirmBtn','',6),(18169,'118838','deals-mobile','block-18166','BlockBox','',1),(18170,'118839','deals-mobile','block-18169','BlockBox','',1),(18171,'118840','deals-mobile','block-18170','Html_box','',1),(18172,'118841','deals-mobile','block-18170','checkout\\BillingAddressConfirm','',3),(18173,'118842','deals-mobile','block-18169-2','BlockBox','',1),(18174,'118843','deals-mobile','block-18173','Html_box','',1),(18175,'118844','deals-mobile','block-18173','checkout\\PaymentMethodConfirm','',3),(18176,'118845','deals-mobile','block-18166','Html_box','',3),(18177,'118846','deals-mobile','block-18166','quote\\Products','',4),(18178,'118847','deals-mobile','block-18166','checkout\\ConfirmBtn','',2),(18179,'118848','deals-mobile','checkout_confirmation_no_shipping','BlockBox','',1),(18180,'118849','deals-mobile','block-18179','Html_box','',5),(18181,'118850','deals-mobile','block-18179','checkout\\ConfirmBtn','',4),(18182,'118851','deals-mobile','block-18179','cart\\Products','',7),(18183,'118852','deals-mobile','block-18179','checkout\\Totals','',8),(18184,'118853','deals-mobile','block-18179','checkout\\ConfirmBtn','',9),(18185,'118854','deals-mobile','block-18179','BlockBox','',2),(18186,'118855','deals-mobile','block-18185','BlockBox','',1),(18187,'118856','deals-mobile','block-18186','checkout\\BillingAddressConfirm','',3),(18188,'118857','deals-mobile','block-18186','Html_box','',1),(18189,'118858','deals-mobile','block-18185-2','BlockBox','',1),(18190,'118859','deals-mobile','block-18189','Html_box','',1),(18191,'118860','deals-mobile','block-18189','checkout\\PaymentMethodConfirm','',3),(18192,'118861','deals-mobile','checkout_confirmation_q','BlockBox','',1),(18193,'118862','deals-mobile','block-18192','BlockBox','',2),(18194,'118863','deals-mobile','block-18193','BlockBox','',1),(18195,'118864','deals-mobile','block-18194','checkout\\ShippingConfirm','',3),(18196,'118865','deals-mobile','block-18194','Html_box','',1),(18197,'118866','deals-mobile','block-18193-2','BlockBox','',1),(18198,'118867','deals-mobile','block-18197','Html_box','',1),(18199,'118868','deals-mobile','block-18197','checkout\\PaymentMethodConfirm','',3),(18200,'118869','deals-mobile','block-18192','checkout\\ConfirmBtn','',8),(18201,'118870','deals-mobile','block-18192','checkout\\ConfirmBtn','',3),(18202,'118871','deals-mobile','block-18192','checkout\\EditBtn','',5),(18203,'118872','deals-mobile','block-18192','quote\\Products','',6),(18204,'118873','deals-mobile','block-18192','Html_box','',4),(18205,'118874','deals-mobile','block-18192','checkout\\Totals','',7),(18206,'118875','deals-mobile','block-18192','BlockBox','',1),(18207,'118876','deals-mobile','block-18206','BlockBox','',1),(18208,'118877','deals-mobile','block-18207','checkout\\ShippingAddressConfirm','',3),(18209,'118878','deals-mobile','block-18207','Html_box','',1),(18210,'118879','deals-mobile','block-18206-2','BlockBox','',1),(18211,'118880','deals-mobile','block-18210','Html_box','',1),(18212,'118881','deals-mobile','block-18210','checkout\\BillingAddressConfirm','',3),(18213,'118882','deals-mobile','checkout_confirmation_title','Html_box','',1),(18214,'118883','deals-mobile','checkout_confirmation_title_g','Html_box','',1),(18215,'118884','deals-mobile','checkout_confirmation_title_no_shipping_g','Html_box','',1),(18216,'118885','deals-mobile','checkout_confirmation_title_no_shipping','Html_box','',1),(18217,'118886','deals-mobile','checkout_confirmation_title_q','Html_box','',1),(18218,'118887','deals-mobile','checkout_confirmation_title_s','Html_box','',1),(18219,'118888','deals-mobile','checkout_delivery','BlockBox','',1),(18220,'118889','deals-mobile','block-18219','BlockBox','',1),(18221,'118890','deals-mobile','block-18220','checkout\\ShippingAddress','',2),(18222,'118891','deals-mobile','block-18220','Html_box','',1),(18223,'118892','deals-mobile','block-18219-2','BlockBox','',1),(18224,'118893','deals-mobile','block-18223','Neighbour\\Checkout','',4),(18225,'118894','deals-mobile','block-18223','Html_box','',1),(18226,'118895','deals-mobile','block-18223','checkout\\Shipping','',2),(18227,'118896','deals-mobile','block-18223','DelayedDespatch\\Checkout','',3),(18228,'118897','deals-mobile','checkout_delivery','BlockBox','',2),(18229,'118898','deals-mobile','block-18228','BlockBox','',1),(18230,'118899','deals-mobile','block-18229','Html_box','',1),(18231,'118900','deals-mobile','block-18229','checkout\\ContactInformation','',2),(18232,'118901','deals-mobile','block-18228-2','BlockBox','',1),(18233,'118902','deals-mobile','block-18232','Html_box','',1),(18234,'118903','deals-mobile','block-18232','checkout\\Comments','',2),(18235,'118904','deals-mobile','checkout_delivery','BlockBox','',3),(18236,'118905','deals-mobile','block-18235','Html_box','',1),(18237,'118906','deals-mobile','block-18235-2','checkout\\ContinueBtn','',1),(18238,'118907','deals-mobile','checkout_delivery_g','BlockBox','',1),(18239,'118908','deals-mobile','block-18238','BlockBox','',1),(18240,'118909','deals-mobile','block-18239','checkout\\ShippingAddress','',2),(18241,'118910','deals-mobile','block-18239','Html_box','',1),(18242,'118911','deals-mobile','block-18238-2','BlockBox','',1),(18243,'118912','deals-mobile','block-18242','Html_box','',1),(18244,'118913','deals-mobile','block-18242','Neighbour\\Checkout','',4),(18245,'118914','deals-mobile','block-18242','checkout\\Shipping','',2),(18246,'118915','deals-mobile','block-18242','DelayedDespatch\\Checkout','',3),(18247,'118916','deals-mobile','checkout_delivery_g','BlockBox','',3),(18248,'118917','deals-mobile','block-18247','Html_box','',1),(18249,'118918','deals-mobile','block-18247-2','checkout\\ContinueBtn','',1),(18250,'118919','deals-mobile','checkout_delivery_g','BlockBox','',2),(18251,'118920','deals-mobile','block-18250','BlockBox','',1),(18252,'118921','deals-mobile','block-18251','checkout\\ContactInformation','',2),(18253,'118922','deals-mobile','block-18251','Html_box','',1),(18254,'118923','deals-mobile','block-18250-2','BlockBox','',1),(18255,'118924','deals-mobile','block-18254','checkout\\Comments','',2),(18256,'118925','deals-mobile','block-18254','Html_box','',1),(18257,'118926','deals-mobile','checkout_delivery_no_shipping','BlockBox','',2),(18258,'118927','deals-mobile','block-18257','Html_box','',1),(18259,'118928','deals-mobile','block-18257-2','checkout\\ContinueBtn','',1),(18260,'118929','deals-mobile','checkout_delivery_no_shipping','BlockBox','',1),(18261,'118930','deals-mobile','block-18260','BlockBox','',1),(18262,'118931','deals-mobile','block-18261','checkout\\ContactInformation','',2),(18263,'118932','deals-mobile','block-18260-2','BlockBox','',1),(18264,'118933','deals-mobile','block-18263','checkout\\Comments','',2),(18265,'118934','deals-mobile','block-18263','Html_box','',1),(18266,'118935','deals-mobile','checkout_delivery_no_shipping_g','BlockBox','',1),(18267,'118936','deals-mobile','block-18266','BlockBox','',1),(18268,'118937','deals-mobile','block-18267','checkout\\ContactInformation','',2),(18269,'118938','deals-mobile','block-18266-2','BlockBox','',1),(18270,'118939','deals-mobile','block-18269','Html_box','',1),(18271,'118940','deals-mobile','block-18269','checkout\\Comments','',2),(18272,'118941','deals-mobile','checkout_delivery_no_shipping_g','BlockBox','',2),(18273,'118942','deals-mobile','block-18272','Html_box','',1),(18274,'118943','deals-mobile','block-18272-2','checkout\\ContinueBtn','',1),(18275,'118944','deals-mobile','checkout_delivery_title','Html_box','',1),(18276,'118945','deals-mobile','checkout_delivery_title_g','Html_box','',1),(18277,'118946','deals-mobile','checkout_delivery_title_no_shipping_g','Html_box','',1),(18278,'118947','deals-mobile','checkout_delivery_title_no_shipping','Html_box','',1),(18279,'118948','deals-mobile','checkout_delivery_title_q','Html_box','',1),(18280,'118949','deals-mobile','checkout_delivery_title_s','Html_box','',1),(18281,'118950','deals-mobile','checkout_free_s','BlockBox','',1),(18282,'118951','deals-mobile','block-18281','BlockBox','',2),(18283,'118952','deals-mobile','block-18282','BlockBox','',2),(18284,'118953','deals-mobile','block-18283','BlockBox','',2),(18285,'118954','deals-mobile','block-18284','Neighbour\\Checkout','',4),(18286,'118955','deals-mobile','block-18284','BlockBox','',3),(18287,'118956','deals-mobile','block-18286','BlockBox','',1),(18288,'118957','deals-mobile','block-18287','checkout\\ShippingAddress','',2),(18289,'118958','deals-mobile','block-18287','Html_box','',3),(18290,'118959','deals-mobile','block-18287','checkout\\ContactInformation','',4),(18291,'118960','deals-mobile','block-18286-2','BlockBox','',1),(18292,'118961','deals-mobile','block-18291','DelayedDespatch\\Checkout','',3),(18293,'118962','deals-mobile','block-18284','Html_box','',1),(18294,'118963','deals-mobile','block-18284','BlockBox','',2),(18295,'118964','deals-mobile','block-18294','checkout\\ShippingChoice','',1),(18296,'118965','deals-mobile','block-18283','BlockBox','',5),(18297,'118966','deals-mobile','block-18296','Html_box','',1),(18298,'118967','deals-mobile','block-18296','checkout\\Comments','',2),(18299,'118968','deals-mobile','block-18283','checkout\\Gdpr','',1),(18300,'118969','deals-mobile','block-18283','BlockBox','',6),(18301,'118970','deals-mobile','block-18300','checkout\\CreateAccount','',3),(18302,'118971','deals-mobile','block-18300','sample\\Products','',1),(18303,'118972','deals-mobile','block-18282-2','BlockBox','',1),(18304,'118973','deals-mobile','block-18303','checkout\\ContinueBtn','',3),(18305,'118974','deals-mobile','block-18303','Html_box','',4),(18306,'118975','deals-mobile','checkout_no_shipping','BlockBox','',1),(18307,'118976','deals-mobile','block-18306','BlockBox','',2),(18308,'118977','deals-mobile','block-18307','BlockBox','',1),(18309,'118978','deals-mobile','block-18308','BlockBox','',5),(18310,'118979','deals-mobile','block-18309','Html_box','',1),(18311,'118980','deals-mobile','block-18309','checkout\\Comments','',2),(18312,'118981','deals-mobile','block-18308','BlockBox','',4),(18313,'118982','deals-mobile','block-18312','BlockBox','',2),(18314,'118983','deals-mobile','block-18313','CouponsAndVauchers\\Checkout','',1),(18315,'118984','deals-mobile','block-18313-2','checkout\\BonusPoints','',2),(18316,'118985','deals-mobile','block-18313-2','checkout\\CreditAmount','',1),(18317,'118986','deals-mobile','block-18312','Html_box','',1),(18318,'118987','deals-mobile','block-18308','BlockBox','',3),(18319,'118988','deals-mobile','block-18318','BlockBox','',2),(18320,'118989','deals-mobile','block-18319','Html_box','',1),(18321,'118990','deals-mobile','block-18319','checkout\\BillingAddress','',2),(18322,'118991','deals-mobile','block-18319-2','BlockBox','',1),(18323,'118992','deals-mobile','block-18322','Html_box','',1),(18324,'118993','deals-mobile','block-18322','checkout\\PaymentMethod','',2),(18325,'118994','deals-mobile','block-18318','Html_box','',1),(18326,'118995','deals-mobile','block-18308','BlockBox','',6),(18327,'118996','deals-mobile','block-18326','cart\\Products','',1),(18328,'118997','deals-mobile','block-18326','checkout\\CreateAccount','',2),(18329,'118998','deals-mobile','block-18307-2','BlockBox','',1),(18330,'118999','deals-mobile','block-18329','checkout\\Terms','',4),(18331,'119000','deals-mobile','block-18329','checkout\\ContinueBtn','',3),(18332,'119001','deals-mobile','block-18329','checkout\\Totals','',2),(18333,'119002','deals-mobile','block-18329','Html_box','',5),(18334,'119003','deals-mobile','block-18329','Html_box','',1),(18335,'119004','deals-mobile','checkout_no_shipping_g','BlockBox','',1),(18336,'119005','deals-mobile','block-18335','quote\\Products','',3),(18337,'119006','deals-mobile','block-18335','BlockBox','',1),(18338,'119007','deals-mobile','block-18337','BlockBox','',1),(18339,'119008','deals-mobile','block-18338','checkout\\BillingAddress','',2),(18340,'119009','deals-mobile','block-18338','Html_box','',1),(18341,'119010','deals-mobile','block-18337-2','BlockBox','',1),(18342,'119011','deals-mobile','block-18341','checkout\\CreditAmount','',3),(18343,'119012','deals-mobile','block-18341','Html_box','',1),(18344,'119013','deals-mobile','block-18341','checkout\\PaymentMethod','',2),(18345,'119014','deals-mobile','block-18341','CouponsAndVauchers\\Checkout','',5),(18346,'119015','deals-mobile','block-18341','checkout\\BonusPoints','',4),(18347,'119016','deals-mobile','block-18335','BlockBox','',2),(18348,'119017','deals-mobile','block-18347','BlockBox','',1),(18349,'119018','deals-mobile','block-18348','Html_box','',1),(18350,'119019','deals-mobile','block-18348','checkout\\ContactInformation','',2),(18351,'119020','deals-mobile','block-18347-2','BlockBox','',1),(18352,'119021','deals-mobile','block-18351','Html_box','',1),(18353,'119022','deals-mobile','block-18351','checkout\\Comments','',2),(18354,'119023','deals-mobile','block-18335','BlockBox','',6),(18355,'119024','deals-mobile','block-18354','Html_box','',1),(18356,'119025','deals-mobile','block-18354-2','checkout\\ContinueBtn','',1),(18357,'119026','deals-mobile','block-18335','checkout\\Totals','',5),(18358,'119027','deals-mobile','checkout_no_shipping_q','BlockBox','',1),(18359,'119028','deals-mobile','block-18358','BlockBox','',2),(18360,'119029','deals-mobile','block-18359','BlockBox','',2),(18361,'119030','deals-mobile','block-18360','BlockBox','',3),(18362,'119031','deals-mobile','block-18361','BlockBox','',2),(18363,'119032','deals-mobile','block-18362','checkout\\BillingAddress','',2),(18364,'119033','deals-mobile','block-18362','Html_box','',1),(18365,'119034','deals-mobile','block-18362-2','BlockBox','',1),(18366,'119035','deals-mobile','block-18365','Html_box','',1),(18367,'119036','deals-mobile','block-18365','checkout\\PaymentMethod','',2),(18368,'119037','deals-mobile','block-18361','Html_box','',1),(18369,'119038','deals-mobile','block-18360','BlockBox','',6),(18370,'119039','deals-mobile','block-18369','checkout\\CreateAccount','',3),(18371,'119040','deals-mobile','block-18369','quote\\Products','',2),(18372,'119041','deals-mobile','block-18360','BlockBox','',5),(18373,'119042','deals-mobile','block-18372','checkout\\Comments','',2),(18374,'119043','deals-mobile','block-18372','Html_box','',1),(18375,'119044','deals-mobile','block-18360','checkout\\Gdpr','',1),(18376,'119045','deals-mobile','block-18359-2','BlockBox','',1),(18377,'119046','deals-mobile','block-18376','Html_box','',4),(18378,'119047','deals-mobile','block-18376','checkout\\Totals','',2),(18379,'119048','deals-mobile','block-18376','checkout\\ContinueBtn','',3),(18380,'119049','deals-mobile','block-18376','Html_box','',1),(18381,'119050','deals-mobile','checkout_payment','BlockBox','',2),(18382,'119051','deals-mobile','block-18381','Html_box','',1),(18383,'119052','deals-mobile','block-18381-2','checkout\\ContinueBtn','',1),(18384,'119053','deals-mobile','checkout_payment','BlockBox','',1),(18385,'119054','deals-mobile','block-18384','BlockBox','',1),(18386,'119055','deals-mobile','block-18385','checkout\\BillingAddress','',2),(18387,'119056','deals-mobile','block-18385','Html_box','',1),(18388,'119057','deals-mobile','block-18384-2','BlockBox','',1),(18389,'119058','deals-mobile','block-18388','checkout\\PaymentMethod','',2),(18390,'119059','deals-mobile','block-18388','Html_box','',1),(18391,'119060','deals-mobile','block-18388','checkout\\CreditAmount','',3),(18392,'119061','deals-mobile','block-18388','CouponsAndVauchers\\Checkout','',5),(18393,'119062','deals-mobile','block-18388','checkout\\BonusPoints','',4),(18394,'119063','deals-mobile','checkout_payment_g','BlockBox','',1),(18395,'119064','deals-mobile','block-18394','BlockBox','',1),(18396,'119065','deals-mobile','block-18395','Html_box','',1),(18397,'119066','deals-mobile','block-18395','checkout\\BillingAddress','',2),(18398,'119067','deals-mobile','block-18394-2','BlockBox','',1),(18399,'119068','deals-mobile','block-18398','checkout\\BonusPoints','',4),(18400,'119069','deals-mobile','block-18398','Html_box','',1),(18401,'119070','deals-mobile','block-18398','CouponsAndVauchers\\Checkout','',5),(18402,'119071','deals-mobile','block-18398','checkout\\CreditAmount','',3),(18403,'119072','deals-mobile','block-18398','checkout\\PaymentMethod','',2),(18404,'119073','deals-mobile','checkout_payment_g','BlockBox','',2),(18405,'119074','deals-mobile','block-18404','Html_box','',1),(18406,'119075','deals-mobile','block-18404-2','checkout\\ContinueBtn','',1),(18407,'119076','deals-mobile','checkout_payment_no_shipping','BlockBox','',1),(18408,'119077','deals-mobile','block-18407','BlockBox','',1),(18409,'119078','deals-mobile','block-18408','Html_box','',1),(18410,'119079','deals-mobile','block-18408','checkout\\BillingAddress','',2),(18411,'119080','deals-mobile','block-18407-2','BlockBox','',1),(18412,'119081','deals-mobile','block-18411','Html_box','',1),(18413,'119082','deals-mobile','block-18411','checkout\\PaymentMethod','',2),(18414,'119083','deals-mobile','block-18411','checkout\\CreditAmount','',3),(18415,'119084','deals-mobile','block-18411','CouponsAndVauchers\\Checkout','',5),(18416,'119085','deals-mobile','block-18411','checkout\\BonusPoints','',4),(18417,'119086','deals-mobile','checkout_payment_no_shipping','BlockBox','',2),(18418,'119087','deals-mobile','block-18417','Html_box','',1),(18419,'119088','deals-mobile','block-18417-2','checkout\\ContinueBtn','',1),(18420,'119089','deals-mobile','checkout_payment_no_shipping_g','BlockBox','',2),(18421,'119090','deals-mobile','block-18420','Html_box','',1),(18422,'119091','deals-mobile','block-18420-2','checkout\\ContinueBtn','',1),(18423,'119092','deals-mobile','checkout_payment_no_shipping_g','BlockBox','',1),(18424,'119093','deals-mobile','block-18423','BlockBox','',1),(18425,'119094','deals-mobile','block-18424','checkout\\BillingAddress','',2),(18426,'119095','deals-mobile','block-18424','Html_box','',1),(18427,'119096','deals-mobile','block-18423-2','BlockBox','',1),(18428,'119097','deals-mobile','block-18427','checkout\\PaymentMethod','',2),(18429,'119098','deals-mobile','block-18427','Html_box','',1),(18430,'119099','deals-mobile','block-18427','checkout\\CreditAmount','',3),(18431,'119100','deals-mobile','block-18427','CouponsAndVauchers\\Checkout','',5),(18432,'119101','deals-mobile','block-18427','checkout\\BonusPoints','',4),(18433,'119102','deals-mobile','checkout_payment_title','Html_box','',1),(18434,'119103','deals-mobile','checkout_payment_title_g','Html_box','',1),(18435,'119104','deals-mobile','checkout_payment_title_no_shipping','Html_box','',1),(18436,'119105','deals-mobile','checkout_payment_title_no_shipping_g','Html_box','',1),(18437,'119106','deals-mobile','checkout_payment_title_q','Html_box','',1),(18438,'119107','deals-mobile','checkout_payment_title_s','Html_box','',1),(18439,'119108','deals-mobile','checkout_q','BlockBox','',1),(18440,'119109','deals-mobile','block-18439','BlockBox','',2),(18441,'119110','deals-mobile','block-18440','BlockBox','',2),(18442,'119111','deals-mobile','block-18441','BlockBox','',3),(18443,'119112','deals-mobile','block-18442','BlockBox','',2),(18444,'119113','deals-mobile','block-18443','checkout\\BillingAddress','',2),(18445,'119114','deals-mobile','block-18443','Html_box','',1),(18446,'119115','deals-mobile','block-18443-2','BlockBox','',1),(18447,'119116','deals-mobile','block-18446','Html_box','',1),(18448,'119117','deals-mobile','block-18446','checkout\\PaymentMethod','',2),(18449,'119118','deals-mobile','block-18442','Html_box','',1),(18450,'119119','deals-mobile','block-18441','BlockBox','',5),(18451,'119120','deals-mobile','block-18450','Html_box','',1),(18452,'119121','deals-mobile','block-18450','checkout\\Comments','',2),(18453,'119122','deals-mobile','block-18441','checkout\\Gdpr','',1),(18454,'119123','deals-mobile','block-18441','BlockBox','',2),(18455,'119124','deals-mobile','block-18454','BlockBox','',3),(18456,'119125','deals-mobile','block-18455','BlockBox','',1),(18457,'119126','deals-mobile','block-18456','Html_box','',3),(18458,'119127','deals-mobile','block-18456','checkout\\ShippingAddress','',2),(18459,'119128','deals-mobile','block-18456','checkout\\ContactInformation','',4),(18460,'119129','deals-mobile','block-18455-2','BlockBox','',1),(18461,'119130','deals-mobile','block-18460','DelayedDespatch\\Checkout','',3),(18462,'119131','deals-mobile','block-18460','Html_box','',1),(18463,'119132','deals-mobile','block-18460','checkout\\Shipping','',2),(18464,'119133','deals-mobile','block-18454','Html_box','',1),(18465,'119134','deals-mobile','block-18454','Neighbour\\Checkout','',4),(18466,'119135','deals-mobile','block-18454','BlockBox','',2),(18467,'119136','deals-mobile','block-18466','checkout\\ShippingChoice','',1),(18468,'119137','deals-mobile','block-18441','BlockBox','',6),(18469,'119138','deals-mobile','block-18468','quote\\Products','',2),(18470,'119139','deals-mobile','block-18468','checkout\\CreateAccount','',3),(18471,'119140','deals-mobile','block-18440-2','BlockBox','',1),(18472,'119141','deals-mobile','block-18471','checkout\\ContinueBtn','',3),(18473,'119142','deals-mobile','block-18471','checkout\\Totals','',2),(18474,'119143','deals-mobile','block-18471','Html_box','',4),(18475,'119144','deals-mobile','block-18471','Html_box','',1),(18476,'119145','deals-mobile','checkout_s','BlockBox','',1),(18477,'119146','deals-mobile','block-18476','BlockBox','',2),(18478,'119147','deals-mobile','block-18477','BlockBox','',2),(18479,'119148','deals-mobile','block-18478','BlockBox','',4),(18480,'119149','deals-mobile','block-18479','BlockBox','',2),(18481,'119150','deals-mobile','block-18480','CouponsAndVauchers\\Checkout','',1),(18482,'119151','deals-mobile','block-18480-2','checkout\\CreditAmount','',1),(18483,'119152','deals-mobile','block-18480-2','checkout\\BonusPoints','',2),(18484,'119153','deals-mobile','block-18479','Html_box','',1),(18485,'119154','deals-mobile','block-18478','BlockBox','',3),(18486,'119155','deals-mobile','block-18485','Html_box','',1),(18487,'119156','deals-mobile','block-18485','BlockBox','',2),(18488,'119157','deals-mobile','block-18487','checkout\\BillingAddress','',2),(18489,'119158','deals-mobile','block-18487','Html_box','',1),(18490,'119159','deals-mobile','block-18487-2','BlockBox','',1),(18491,'119160','deals-mobile','block-18490','checkout\\PaymentMethod','',2),(18492,'119161','deals-mobile','block-18490','Html_box','',1),(18493,'119162','deals-mobile','block-18478','BlockBox','',5),(18494,'119163','deals-mobile','block-18493','checkout\\Comments','',2),(18495,'119164','deals-mobile','block-18493','Html_box','',1),(18496,'119165','deals-mobile','block-18478','BlockBox','',2),(18497,'119166','deals-mobile','block-18496','BlockBox','',2),(18498,'119167','deals-mobile','block-18497','checkout\\ShippingChoice','',1),(18499,'119168','deals-mobile','block-18496','Html_box','',1),(18500,'119169','deals-mobile','block-18496','BlockBox','',3),(18501,'119170','deals-mobile','block-18500','BlockBox','',1),(18502,'119171','deals-mobile','block-18501','checkout\\ShippingAddress','',2),(18503,'119172','deals-mobile','block-18501','Html_box','',3),(18504,'119173','deals-mobile','block-18501','checkout\\ContactInformation','',4),(18505,'119174','deals-mobile','block-18500-2','BlockBox','',1),(18506,'119175','deals-mobile','block-18505','DelayedDespatch\\Checkout','',3),(18507,'119176','deals-mobile','block-18505','Html_box','',1),(18508,'119177','deals-mobile','block-18505','checkout\\Shipping','',2),(18509,'119178','deals-mobile','block-18496','Neighbour\\Checkout','',4),(18510,'119179','deals-mobile','block-18478','BlockBox','',6),(18511,'119180','deals-mobile','block-18510','checkout\\CreateAccount','',3),(18512,'119181','deals-mobile','block-18510','sample\\Products','',1),(18513,'119182','deals-mobile','block-18478','checkout\\Gdpr','',1),(18514,'119183','deals-mobile','block-18477-2','BlockBox','',1),(18515,'119184','deals-mobile','block-18514','Html_box','',1),(18516,'119185','deals-mobile','block-18514','checkout\\ContinueBtn','',3),(18517,'119186','deals-mobile','block-18514','Html_box','',4),(18518,'119187','deals-mobile','block-18514','checkout\\Totals','',2),(18519,'119188','deals-mobile','checkout_step_bottom','cart\\Products','',2),(18520,'119189','deals-mobile','checkout_step_bottom','checkout\\Totals','',3),(18521,'119190','deals-mobile','checkout_step_bottom','Html_box','',1),(18522,'119191','deals-mobile','checkout_step_bottom_g','checkout\\Totals','',3),(18523,'119192','deals-mobile','checkout_step_bottom_g','quote\\Products','',2),(18524,'119193','deals-mobile','checkout_step_bottom_g','Html_box','',1),(18525,'119194','deals-mobile','checkout_step_bottom_no_shipping_g','Html_box','',1),(18526,'119195','deals-mobile','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(18527,'119196','deals-mobile','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(18528,'119197','deals-mobile','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(18529,'119198','deals-mobile','checkout_step_bottom_no_shipping','Html_box','',1),(18530,'119199','deals-mobile','checkout_step_bottom_no_shipping','cart\\Products','',2),(18531,'119200','deals-mobile','communication','BlockBox','',1),(18532,'119201','deals-mobile','block-18531','Html_box','',2),(18533,'119202','deals-mobile','block-18531','Communication\\Topic','',3),(18534,'119203','deals-mobile','block-18531','Communication\\NewTopicButton','',1),(18535,'119204','deals-mobile','compare','BlockBox','',1),(18536,'119205','deals-mobile','block-18535','catalog\\Compare','',1),(18537,'119206','deals-mobile','compare_products','BlockBox','',2),(18538,'119207','deals-mobile','block-18537','productListing\\rating','',4),(18539,'119208','deals-mobile','block-18537','productListing\\model','',5),(18540,'119209','deals-mobile','block-18537','productListing\\compare','',1),(18541,'119210','deals-mobile','block-18537','BlockBox','',2),(18542,'119211','deals-mobile','block-18541','productListing\\image','',1),(18543,'119212','deals-mobile','block-18541-2','productListing\\name','',2),(18544,'119213','deals-mobile','block-18537','BlockBox','',3),(18545,'119214','deals-mobile','block-18544','productListing\\price','',1),(18546,'119215','deals-mobile','block-18544-2','productListing\\buyButton','',1),(18547,'119216','deals-mobile','confirmation','BlockBox','',1),(18548,'119217','deals-mobile','block-18547','BlockBox','',2),(18549,'119218','deals-mobile','block-18548','UploadCustomerId\\UploadCustomerIdForm','',1),(18550,'119219','deals-mobile','block-18548','BlockBox','',2),(18551,'119220','deals-mobile','block-18550','BlockBox','',1),(18552,'119221','deals-mobile','block-18551','BlockBox','',1),(18553,'119222','deals-mobile','block-18552','checkout\\ShippingAddressConfirm','',4),(18554,'119223','deals-mobile','block-18552','Html_box','',1),(18555,'119224','deals-mobile','block-18552','Html_box','',2),(18556,'119225','deals-mobile','block-18552','checkout\\ContactConfirm','',11),(18557,'119226','deals-mobile','block-18552','checkout\\EditBtn','',3),(18558,'119227','deals-mobile','block-18552','Html_box','',5),(18559,'119228','deals-mobile','block-18552','DelayedDespatch\\CheckoutConfirm','',8),(18560,'119229','deals-mobile','block-18552','checkout\\EditBtn','',10),(18561,'119230','deals-mobile','block-18552','checkout\\EditBtn','',6),(18562,'119231','deals-mobile','block-18552','Html_box','',9),(18563,'119232','deals-mobile','block-18552','checkout\\ShippingConfirm','',7),(18564,'119233','deals-mobile','block-18551','BlockBox','',2),(18565,'119234','deals-mobile','block-18564','Html_box','',2),(18566,'119235','deals-mobile','block-18564','checkout\\BillingAddressConfirm','',4),(18567,'119236','deals-mobile','block-18564','Html_box','',5),(18568,'119237','deals-mobile','block-18564','checkout\\PaymentMethodConfirm','',7),(18569,'119238','deals-mobile','block-18564','Html_box','',1),(18570,'119239','deals-mobile','block-18564','checkout\\EditBtn','',3),(18571,'119240','deals-mobile','block-18564','checkout\\EditBtn','',6),(18572,'119241','deals-mobile','block-18550','BlockBox','',3),(18573,'119242','deals-mobile','block-18572','Html_box','',1),(18574,'119243','deals-mobile','block-18572','checkout\\EditBtn','',2),(18575,'119244','deals-mobile','block-18572','cart\\Products','',3),(18576,'119245','deals-mobile','block-18550','BlockBox','',2),(18577,'119246','deals-mobile','block-18576','Html_box','',1),(18578,'119247','deals-mobile','block-18576','checkout\\CommentsConfirm','',3),(18579,'119248','deals-mobile','block-18576','checkout\\EditBtn','',2),(18580,'119249','deals-mobile','block-18550','BlockBox','',4),(18581,'119250','deals-mobile','block-18580','checkout\\Totals','',2),(18582,'119251','deals-mobile','block-18580','Html_box','',1),(18583,'119252','deals-mobile','block-18580','checkout\\ConfirmBtn','',3),(18584,'119253','deals-mobile','block-18547','Html_box','',1),(18585,'119254','deals-mobile','confirmation_free_s','BlockBox','',1),(18586,'119255','deals-mobile','block-18585','Html_box','',1),(18587,'119256','deals-mobile','block-18585','BlockBox','',2),(18588,'119257','deals-mobile','block-18587','BlockBox','',1),(18589,'119258','deals-mobile','block-18588','BlockBox','',1),(18590,'119259','deals-mobile','block-18589','BlockBox','',1),(18591,'119260','deals-mobile','block-18590','checkout\\EditBtn','',6),(18592,'119261','deals-mobile','block-18590','checkout\\ShippingAddressConfirm','',4),(18593,'119262','deals-mobile','block-18590','Html_box','',2),(18594,'119263','deals-mobile','block-18590','checkout\\ShippingConfirm','',7),(18595,'119264','deals-mobile','block-18590','checkout\\EditBtn','',3),(18596,'119265','deals-mobile','block-18590','Html_box','',5),(18597,'119266','deals-mobile','block-18589-2','BlockBox','',1),(18598,'119267','deals-mobile','block-18597','Html_box','',1),(18599,'119268','deals-mobile','block-18597','checkout\\EditBtn','',2),(18600,'119269','deals-mobile','block-18597','DelayedDespatch\\CheckoutConfirm','',4),(18601,'119270','deals-mobile','block-18597','checkout\\ContactConfirm','',3),(18602,'119271','deals-mobile','block-18588','BlockBox','',2),(18603,'119272','deals-mobile','block-18602','checkout\\CommentsConfirm','',3),(18604,'119273','deals-mobile','block-18602','checkout\\EditBtn','',2),(18605,'119274','deals-mobile','block-18602','Html_box','',1),(18606,'119275','deals-mobile','block-18588','BlockBox','',3),(18607,'119276','deals-mobile','block-18606','sample\\Products','',2),(18608,'119277','deals-mobile','block-18606','Html_box','',1),(18609,'119278','deals-mobile','block-18606','checkout\\EditBtn','',3),(18610,'119279','deals-mobile','block-18587-2','BlockBox','',1),(18611,'119280','deals-mobile','block-18610','checkout\\ConfirmBtn','',3),(18612,'119281','deals-mobile','confirmation_no_shipping','BlockBox','',1),(18613,'119282','deals-mobile','block-18612','Html_box','',1),(18614,'119283','deals-mobile','block-18612','BlockBox','',2),(18615,'119284','deals-mobile','block-18614','BlockBox','',1),(18616,'119285','deals-mobile','block-18615','BlockBox','',3),(18617,'119286','deals-mobile','block-18616','checkout\\EditBtn','',2),(18618,'119287','deals-mobile','block-18616','Html_box','',1),(18619,'119288','deals-mobile','block-18616','cart\\Products','',3),(18620,'119289','deals-mobile','block-18615','BlockBox','',2),(18621,'119290','deals-mobile','block-18620','checkout\\EditBtn','',2),(18622,'119291','deals-mobile','block-18620','checkout\\CommentsConfirm','',3),(18623,'119292','deals-mobile','block-18620','Html_box','',1),(18624,'119293','deals-mobile','block-18615','BlockBox','',1),(18625,'119294','deals-mobile','block-18624','BlockBox','',1),(18626,'119295','deals-mobile','block-18625','Html_box','',9),(18627,'119296','deals-mobile','block-18625','checkout\\ContactConfirm','',11),(18628,'119297','deals-mobile','block-18625','checkout\\EditBtn','',10),(18629,'119298','deals-mobile','block-18624-2','BlockBox','',1),(18630,'119299','deals-mobile','block-18629','checkout\\EditBtn','',3),(18631,'119300','deals-mobile','block-18629','Html_box','',2),(18632,'119301','deals-mobile','block-18629','Html_box','',1),(18633,'119302','deals-mobile','block-18629','Html_box','',5),(18634,'119303','deals-mobile','block-18629','checkout\\BillingAddressConfirm','',4),(18635,'119304','deals-mobile','block-18629','checkout\\PaymentMethodConfirm','',7),(18636,'119305','deals-mobile','block-18629','checkout\\EditBtn','',6),(18637,'119306','deals-mobile','block-18614-2','BlockBox','',1),(18638,'119307','deals-mobile','block-18637','checkout\\ConfirmBtn','',3),(18639,'119308','deals-mobile','block-18637','checkout\\Totals','',2),(18640,'119309','deals-mobile','block-18637','Html_box','',1),(18641,'119310','deals-mobile','confirmation_no_shipping_q','BlockBox','',2),(18642,'119311','deals-mobile','block-18641','BlockBox','',2),(18643,'119312','deals-mobile','block-18642','BlockBox','',1),(18644,'119313','deals-mobile','block-18643','BlockBox','',3),(18645,'119314','deals-mobile','block-18644','quote\\Products','',3),(18646,'119315','deals-mobile','block-18644','checkout\\EditBtn','',2),(18647,'119316','deals-mobile','block-18644','Html_box','',1),(18648,'119317','deals-mobile','block-18643','BlockBox','',1),(18649,'119318','deals-mobile','block-18648','BlockBox','',1),(18650,'119319','deals-mobile','block-18649','checkout\\EditBtn','',2),(18651,'119320','deals-mobile','block-18649','Html_box','',1),(18652,'119321','deals-mobile','block-18649','Html_box','',4),(18653,'119322','deals-mobile','block-18649','checkout\\PaymentMethodConfirm','',3),(18654,'119323','deals-mobile','block-18649','checkout\\EditBtn','',5),(18655,'119324','deals-mobile','block-18649','checkout\\ContactConfirm','',6),(18656,'119325','deals-mobile','block-18648-2','BlockBox','',1),(18657,'119326','deals-mobile','block-18656','Html_box','',2),(18658,'119327','deals-mobile','block-18656','checkout\\EditBtn','',3),(18659,'119328','deals-mobile','block-18656','checkout\\BillingAddressConfirm','',4),(18660,'119329','deals-mobile','block-18643','BlockBox','',2),(18661,'119330','deals-mobile','block-18660','checkout\\CommentsConfirm','',3),(18662,'119331','deals-mobile','block-18660','Html_box','',1),(18663,'119332','deals-mobile','block-18660','checkout\\EditBtn','',2),(18664,'119333','deals-mobile','block-18642-2','BlockBox','',1),(18665,'119334','deals-mobile','block-18664','Html_box','',1),(18666,'119335','deals-mobile','block-18664','checkout\\Totals','',2),(18667,'119336','deals-mobile','block-18664','checkout\\ConfirmBtn','',3),(18668,'119337','deals-mobile','block-18641','Html_box','',1),(18669,'119338','deals-mobile','confirmation_q','BlockBox','',1),(18670,'119339','deals-mobile','block-18669','Html_box','',1),(18671,'119340','deals-mobile','block-18669','BlockBox','',2),(18672,'119341','deals-mobile','block-18671','BlockBox','',1),(18673,'119342','deals-mobile','block-18672','BlockBox','',3),(18674,'119343','deals-mobile','block-18673','checkout\\EditBtn','',2),(18675,'119344','deals-mobile','block-18673','Html_box','',1),(18676,'119345','deals-mobile','block-18673','quote\\Products','',3),(18677,'119346','deals-mobile','block-18672','BlockBox','',2),(18678,'119347','deals-mobile','block-18677','checkout\\EditBtn','',2),(18679,'119348','deals-mobile','block-18677','checkout\\CommentsConfirm','',3),(18680,'119349','deals-mobile','block-18677','Html_box','',1),(18681,'119350','deals-mobile','block-18672','BlockBox','',1),(18682,'119351','deals-mobile','block-18681','BlockBox','',1),(18683,'119352','deals-mobile','block-18682','Html_box','',5),(18684,'119353','deals-mobile','block-18682','Html_box','',9),(18685,'119354','deals-mobile','block-18682','checkout\\EditBtn','',6),(18686,'119355','deals-mobile','block-18682','checkout\\ShippingConfirm','',7),(18687,'119356','deals-mobile','block-18682','checkout\\EditBtn','',3),(18688,'119357','deals-mobile','block-18682','DelayedDespatch\\CheckoutConfirm','',8),(18689,'119358','deals-mobile','block-18682','checkout\\ShippingAddressConfirm','',4),(18690,'119359','deals-mobile','block-18682','checkout\\ContactConfirm','',11),(18691,'119360','deals-mobile','block-18682','checkout\\EditBtn','',10),(18692,'119361','deals-mobile','block-18682','Html_box','',2),(18693,'119362','deals-mobile','block-18682','Html_box','',1),(18694,'119363','deals-mobile','block-18681-2','BlockBox','',1),(18695,'119364','deals-mobile','block-18694','Html_box','',1),(18696,'119365','deals-mobile','block-18694','Html_box','',2),(18697,'119366','deals-mobile','block-18694','checkout\\PaymentMethodConfirm','',7),(18698,'119367','deals-mobile','block-18694','Html_box','',5),(18699,'119368','deals-mobile','block-18694','checkout\\BillingAddressConfirm','',4),(18700,'119369','deals-mobile','block-18694','checkout\\EditBtn','',6),(18701,'119370','deals-mobile','block-18694','checkout\\EditBtn','',3),(18702,'119371','deals-mobile','block-18671-2','BlockBox','',1),(18703,'119372','deals-mobile','block-18702','checkout\\ConfirmBtn','',3),(18704,'119373','deals-mobile','block-18702','Html_box','',1),(18705,'119374','deals-mobile','block-18702','checkout\\Totals','',2),(18706,'119375','deals-mobile','confirmation_s','BlockBox','',1),(18707,'119376','deals-mobile','block-18706','Html_box','',1),(18708,'119377','deals-mobile','block-18706','BlockBox','',2),(18709,'119378','deals-mobile','block-18708','BlockBox','',1),(18710,'119379','deals-mobile','block-18709','BlockBox','',2),(18711,'119380','deals-mobile','block-18710','checkout\\CommentsConfirm','',3),(18712,'119381','deals-mobile','block-18710','checkout\\EditBtn','',2),(18713,'119382','deals-mobile','block-18710','Html_box','',1),(18714,'119383','deals-mobile','block-18709','BlockBox','',3),(18715,'119384','deals-mobile','block-18714','sample\\Products','',2),(18716,'119385','deals-mobile','block-18714','Html_box','',1),(18717,'119386','deals-mobile','block-18714','checkout\\EditBtn','',3),(18718,'119387','deals-mobile','block-18709','BlockBox','',1),(18719,'119388','deals-mobile','block-18718','BlockBox','',1),(18720,'119389','deals-mobile','block-18719','Html_box','',9),(18721,'119390','deals-mobile','block-18719','checkout\\ContactConfirm','',11),(18722,'119391','deals-mobile','block-18719','checkout\\EditBtn','',6),(18723,'119392','deals-mobile','block-18719','checkout\\EditBtn','',10),(18724,'119393','deals-mobile','block-18719','Html_box','',1),(18725,'119394','deals-mobile','block-18719','DelayedDespatch\\CheckoutConfirm','',8),(18726,'119395','deals-mobile','block-18719','checkout\\EditBtn','',3),(18727,'119396','deals-mobile','block-18719','checkout\\ShippingAddressConfirm','',4),(18728,'119397','deals-mobile','block-18719','Html_box','',5),(18729,'119398','deals-mobile','block-18719','Html_box','',2),(18730,'119399','deals-mobile','block-18719','checkout\\ShippingConfirm','',7),(18731,'119400','deals-mobile','block-18718-2','BlockBox','',1),(18732,'119401','deals-mobile','block-18731','Html_box','',5),(18733,'119402','deals-mobile','block-18731','Html_box','',1),(18734,'119403','deals-mobile','block-18731','checkout\\EditBtn','',6),(18735,'119404','deals-mobile','block-18731','checkout\\BillingAddressConfirm','',4),(18736,'119405','deals-mobile','block-18731','checkout\\EditBtn','',3),(18737,'119406','deals-mobile','block-18731','Html_box','',2),(18738,'119407','deals-mobile','block-18731','checkout\\PaymentMethodConfirm','',7),(18739,'119408','deals-mobile','block-18708-2','BlockBox','',1),(18740,'119409','deals-mobile','block-18739','checkout\\Totals','',2),(18741,'119410','deals-mobile','block-18739','Html_box','',1),(18742,'119411','deals-mobile','block-18739','checkout\\ConfirmBtn','',3),(18743,'119412','deals-mobile','contact','BlockBox','',1),(18744,'119413','deals-mobile','block-18743','BlockBox','',4),(18745,'119414','deals-mobile','block-18744','contact\\Map','',1),(18746,'119415','deals-mobile','block-18744-2','contact\\StreetView','',1),(18747,'119416','deals-mobile','block-18743','BlockBox','',3),(18748,'119417','deals-mobile','block-18747','contact\\ContactForm','',1),(18749,'119418','deals-mobile','block-18747-2','contact\\Contacts','',1),(18750,'119419','deals-mobile','block-18743','info\\Title','',1),(18751,'119420','deals-mobile','created_success','BlockBox','',1),(18752,'119421','deals-mobile','block-18751','Html_box','',2),(18753,'119422','deals-mobile','block-18751','Html_box','',1),(18754,'119423','deals-mobile','credit_note','invoice\\Container','',1),(18755,'119424','deals-mobile','block-18754','BlockBox','',2),(18756,'119425','deals-mobile','block-18755','BlockBox','',8),(18757,'119426','deals-mobile','block-18756','BlockBox','',1),(18758,'119427','deals-mobile','block-18757','Text','',1),(18759,'119428','deals-mobile','block-18757','invoice\\ShippingMethod','',2),(18760,'119429','deals-mobile','block-18756-2','BlockBox','',1),(18761,'119430','deals-mobile','block-18760','invoice\\ShippingMethod','',2),(18762,'119431','deals-mobile','block-18760','Text','',1),(18763,'119432','deals-mobile','block-18755','BlockBox','',7),(18764,'119433','deals-mobile','block-18763','BlockBox','',1),(18765,'119434','deals-mobile','block-18764','invoice\\BillingAddress','',2),(18766,'119435','deals-mobile','block-18764','Text','',1),(18767,'119436','deals-mobile','block-18763-2','BlockBox','',1),(18768,'119437','deals-mobile','block-18767','Text','',5),(18769,'119438','deals-mobile','block-18767','invoice\\CustomerName','',2),(18770,'119439','deals-mobile','block-18767','invoice\\CustomerEmail','',6),(18771,'119440','deals-mobile','block-18767','Text','',3),(18772,'119441','deals-mobile','block-18767','Text','',1),(18773,'119442','deals-mobile','block-18767','invoice\\CustomerPhone','',4),(18774,'119443','deals-mobile','block-18755-2','invoice\\PaymentDate','',3),(18775,'119444','deals-mobile','block-18755-2','Text','',2),(18776,'119445','deals-mobile','block-18755-2','invoice\\OrderId','',1),(18777,'119446','deals-mobile','block-18754','BlockBox','',4),(18778,'119447','deals-mobile','block-18777','BlockBox','',1),(18779,'119448','deals-mobile','block-18778','Text','',1),(18780,'119449','deals-mobile','block-18778','invoice\\ShippingAddress','',2),(18781,'119450','deals-mobile','block-18777-2','BlockBox','',1),(18782,'119451','deals-mobile','block-18754','BlockBox','',1),(18783,'119452','deals-mobile','block-18782','Logo','',1),(18784,'119453','deals-mobile','block-18782-2','BlockBox','',1),(18785,'119454','deals-mobile','block-18784','invoice\\StoreAddress','',1),(18786,'119455','deals-mobile','block-18782-2','BlockBox','',3),(18787,'119456','deals-mobile','block-18786','Text','',1),(18788,'119457','deals-mobile','block-18786-2','invoice\\StoreEmail','',1),(18789,'119458','deals-mobile','block-18782-2','BlockBox','',2),(18790,'119459','deals-mobile','block-18789','Text','',1),(18791,'119460','deals-mobile','block-18789-2','invoice\\StorePhone','',1),(18792,'119461','deals-mobile','block-18782-2','BlockBox','',4),(18793,'119462','deals-mobile','block-18792','Text','',1),(18794,'119463','deals-mobile','block-18792-2','invoice\\StoreSite','',1),(18795,'119464','deals-mobile','block-18754','invoice\\Products','',3),(18796,'119465','deals-mobile','block-18754','BlockBox','',5),(18797,'119466','deals-mobile','block-18796','invoice\\StoreAddress','',8),(18798,'119467','deals-mobile','block-18796','Text','',1),(18799,'119468','deals-mobile','block-18796-2','Text','',2),(18800,'119469','deals-mobile','block-18796-2','Logo','',1),(18801,'119470','deals-mobile','block-18796-3','BlockBox','',2),(18802,'119471','deals-mobile','block-18801','Text','',1),(18803,'119472','deals-mobile','block-18801-2','invoice\\StorePhone','',1),(18804,'119473','deals-mobile','block-18796-3','BlockBox','',3),(18805,'119474','deals-mobile','block-18804','Text','',1),(18806,'119475','deals-mobile','block-18804-2','invoice\\StoreEmail','',1),(18807,'119476','deals-mobile','block-18796-3','Text','',1),(18808,'119477','deals-mobile','delivery-location','DeliveryLocation\\LocationProducts','',8),(18809,'119478','deals-mobile','delivery-location','DeliveryLocation\\LocationLongDescription','',5),(18810,'119479','deals-mobile','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(18811,'119480','deals-mobile','delivery-location','DeliveryLocation\\LocationDescription','',3),(18812,'119481','deals-mobile','delivery-location','DeliveryLocation\\FeaturedList','',6),(18813,'119482','deals-mobile','delivery-location','DeliveryLocation\\LocationList','',7),(18814,'119483','deals-mobile','delivery-location','DeliveryLocation\\LocationTitle','',2),(18815,'119484','deals-mobile','delivery-location-default','DeliveryLocation\\TopLocationList','',2),(18816,'119485','deals-mobile','delivery-location-default','Heading','',1),(18817,'119486','deals-mobile','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(18818,'119487','deals-mobile','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(18819,'119488','deals-mobile','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(18820,'119489','deals-mobile','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(18821,'119490','deals-mobile','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(18822,'119491','deals-mobile','delivery_loc_2','DeliveryLocation\\LocationList','',7),(18823,'119492','deals-mobile','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(18824,'119493','deals-mobile','email','email\\Content','',3),(18825,'119494','deals-mobile','email','email\\BlockBox','',1),(18826,'119495','deals-mobile','block-18825','Logo','logo-2.png',1),(18827,'119496','deals-mobile','email','Copyright','',7),(18828,'119497','deals-mobile','email','email\\BlockBox','',4),(18829,'119498','deals-mobile','email','Text','',5),(18830,'119499','deals-mobile','email','email\\BlockBox','',2),(18831,'119500','deals-mobile','block-18830','email\\Title','',1),(18832,'119501','deals-mobile','block-18830-2','email\\Date','',1),(18833,'119502','deals-mobile','email_2','email\\BlockBox','',1),(18834,'119503','deals-mobile','block-18833','email\\BlockBox','',1),(18835,'119504','deals-mobile','block-18834','email\\Content','',3),(18836,'119505','deals-mobile','block-18834','email\\BlockBox','',2),(18837,'119506','deals-mobile','block-18836','email\\Title','',1),(18838,'119507','deals-mobile','block-18836-2','email\\Date','',1),(18839,'119508','deals-mobile','block-18834','Copyright','',4),(18840,'119509','deals-mobile','block-18834','Logo','',1),(18841,'119510','deals-mobile','email_3','email\\BlockBox','',1),(18842,'119511','deals-mobile','block-18841','email\\BlockBox','',1),(18843,'119512','deals-mobile','block-18842','Logo','',1),(18844,'119513','deals-mobile','block-18842','Copyright','',3),(18845,'119514','deals-mobile','block-18842','email\\BlockBox','',2),(18846,'119515','deals-mobile','block-18845','email\\BlockBox','',1),(18847,'119516','deals-mobile','block-18846','email\\Title','',1),(18848,'119517','deals-mobile','block-18846-2','email\\Date','',1),(18849,'119518','deals-mobile','block-18845','email\\Content','',2),(18850,'119519','deals-mobile','email_4','email\\BlockBox','',1),(18851,'119520','deals-mobile','block-18850','email\\BlockBox','',1),(18852,'119521','deals-mobile','block-18851','email\\BlockBox','',1),(18853,'119522','deals-mobile','block-18852','email\\Content','',2),(18854,'119523','deals-mobile','block-18852','email\\BlockBox','',1),(18855,'119524','deals-mobile','block-18854','Logo','',1),(18856,'119525','deals-mobile','block-18854-2','email\\Title','',1),(18857,'119526','deals-mobile','block-18854-2','email\\Date','',2),(18858,'119527','deals-mobile','block-18851','Copyright','',2),(18859,'119528','deals-mobile','footer','BlockBox','',1),(18860,'119529','deals-mobile','block-18859','BlockBox','',4),(18861,'119530','deals-mobile','block-18860','Text','',1),(18862,'119531','deals-mobile','block-18860','Menu','footer3',2),(18863,'119532','deals-mobile','block-18859','Copyright','',10),(18864,'119533','deals-mobile','block-18859','BlockBox','',2),(18865,'119534','deals-mobile','block-18864','Menu','footer2',2),(18866,'119535','deals-mobile','block-18864','Text','',1),(18867,'119536','deals-mobile','block-18859','BlockBox','',3),(18868,'119537','deals-mobile','block-18867','Text','',1),(18869,'119538','deals-mobile','block-18867','Menu','footer1',2),(18870,'119539','deals-mobile','block-18859','BlockBox','',1),(18871,'119540','deals-mobile','block-18870','Contacts','',2),(18872,'119541','deals-mobile','block-18870','Text','',1),(18873,'119542','deals-mobile','for_menu','BlockBox','',1),(18874,'119543','deals-mobile','block-18873','Html_box','',1),(18875,'119544','deals-mobile','block-18873-2','Languages','',1),(18876,'119545','deals-mobile','for_menu','BlockBox','',3),(18877,'119546','deals-mobile','block-18876','Html_box','',1),(18878,'119547','deals-mobile','block-18876-2','Currencies','',1),(18879,'119548','deals-mobile','gift','BlockBox','',1),(18880,'119549','deals-mobile','block-18879','BlockBox','',3),(18881,'119550','deals-mobile','block-18880','BlockBox','',1),(18882,'119551','deals-mobile','block-18881','BlockBox','',1),(18883,'119552','deals-mobile','block-18882','BlockBox','',9),(18884,'119553','deals-mobile','block-18883','Text','',1),(18885,'119554','deals-mobile','block-18883','invoice\\StoreEmail','',3),(18886,'119555','deals-mobile','block-18883','invoice\\StorePhone','',2),(18887,'119556','deals-mobile','block-18882','Text','',6),(18888,'119557','deals-mobile','block-18882','Text','',4),(18889,'119558','deals-mobile','block-18882','Text','',7),(18890,'119559','deals-mobile','block-18882','Text','',2),(18891,'119560','deals-mobile','block-18882','BlockBox','',8),(18892,'119561','deals-mobile','block-18891','Text','',1),(18893,'119562','deals-mobile','block-18891-2','gift\\CodeView','',1),(18894,'119563','deals-mobile','block-18882','gift\\MessageView','',5),(18895,'119564','deals-mobile','block-18882','gift\\AmountView','',3),(18896,'119565','deals-mobile','block-18882','Text','',1),(18897,'119566','deals-mobile','block-18880-2','gift\\Form','',2),(18898,'119567','deals-mobile','block-18880-2','Text','',1),(18899,'119568','deals-mobile','block-18879','info\\Title','',1),(18900,'119569','deals-mobile','gift_card','BlockBox','',1),(18901,'119570','deals-mobile','block-18900','Text','',9),(18902,'119571','deals-mobile','block-18900','Text','',4),(18903,'119572','deals-mobile','block-18900','Logo','',1),(18904,'119573','deals-mobile','block-18900','Image','',2),(18905,'119574','deals-mobile','block-18900','Text','',6),(18906,'119575','deals-mobile','block-18900','gift\\AmountView','',5),(18907,'119576','deals-mobile','block-18900','gift\\MessageView','',7),(18908,'119577','deals-mobile','block-18900','BlockBox','',10),(18909,'119578','deals-mobile','block-18908','Text','',1),(18910,'119579','deals-mobile','block-18908-2','gift\\CodeView','',1),(18911,'119580','deals-mobile','block-18900','Text','',3),(18912,'119581','deals-mobile','block-18900','Text','',8),(18913,'119582','deals-mobile','block-18900','BlockBox','',11),(18914,'119583','deals-mobile','block-18913','invoice\\StorePhone','',2),(18915,'119584','deals-mobile','block-18913','Text','',1),(18916,'119585','deals-mobile','block-18913','invoice\\StoreEmail','',3),(18917,'119586','deals-mobile','gift_card_2','BlockBox','',1),(18918,'119587','deals-mobile','block-18917','Text','',1),(18919,'119588','deals-mobile','block-18917','Text','',2),(18920,'119589','deals-mobile','block-18917','Text','',6),(18921,'119590','deals-mobile','block-18917','gift\\MessageView','',5),(18922,'119591','deals-mobile','block-18917','Text','',7),(18923,'119592','deals-mobile','block-18917','Text','',4),(18924,'119593','deals-mobile','block-18917','BlockBox','',9),(18925,'119594','deals-mobile','block-18924','invoice\\StorePhone','',2),(18926,'119595','deals-mobile','block-18924','Text','',1),(18927,'119596','deals-mobile','block-18924','invoice\\StoreEmail','',3),(18928,'119597','deals-mobile','block-18917','BlockBox','',8),(18929,'119598','deals-mobile','block-18928','Text','',1),(18930,'119599','deals-mobile','block-18928-2','gift\\CodeView','',1),(18931,'119600','deals-mobile','block-18917','gift\\AmountView','',3),(18932,'119601','deals-mobile','gift_card_2_pdf','BlockBox','',1),(18933,'119602','deals-mobile','block-18932','BlockBox','',12),(18934,'119603','deals-mobile','block-18933','invoice\\StoreEmail','',4),(18935,'119604','deals-mobile','block-18933','invoice\\StorePhone','',3),(18936,'119605','deals-mobile','block-18933','Html_box','',1),(18937,'119606','deals-mobile','block-18932','BlockBox','',11),(18938,'119607','deals-mobile','block-18937','Html_box','',1),(18939,'119608','deals-mobile','block-18937-2','gift\\CodeViewPdf','',1),(18940,'119609','deals-mobile','block-18932','BlockBox','',1),(18941,'119610','deals-mobile','block-18940','Text','',4),(18942,'119611','deals-mobile','block-18940','Html_box','',1),(18943,'119612','deals-mobile','block-18940','Html_box','',2),(18944,'119613','deals-mobile','block-18940','gift\\AmountViewPdf','',3),(18945,'119614','deals-mobile','block-18940','gift\\MessageViewPdf','',5),(18946,'119615','deals-mobile','block-18940','Html_box','',7),(18947,'119616','deals-mobile','block-18940','Html_box','',6),(18948,'119617','deals-mobile','gift_card_2_pdf','Import','',1),(18949,'119618','deals-mobile','gift_card_pdf','BlockBox','',1),(18950,'119619','deals-mobile','block-18949','BlockBox','',12),(18951,'119620','deals-mobile','block-18950','invoice\\StoreEmail','',4),(18952,'119621','deals-mobile','block-18950','invoice\\StorePhone','',3),(18953,'119622','deals-mobile','block-18950','Html_box','',1),(18954,'119623','deals-mobile','block-18949','BlockBox','',11),(18955,'119624','deals-mobile','block-18954','Html_box','',1),(18956,'119625','deals-mobile','block-18954-2','gift\\CodeViewPdf','',1),(18957,'119626','deals-mobile','block-18949','BlockBox','',1),(18958,'119627','deals-mobile','block-18957','Text','',4),(18959,'119628','deals-mobile','block-18957','Html_box','',1),(18960,'119629','deals-mobile','block-18957','Html_box','',2),(18961,'119630','deals-mobile','block-18957','gift\\AmountViewPdf','',3),(18962,'119631','deals-mobile','block-18957','gift\\MessageViewPdf','',5),(18963,'119632','deals-mobile','block-18957','Html_box','',7),(18964,'119633','deals-mobile','block-18957','Html_box','',6),(18965,'119634','deals-mobile','gift_card_pdf','Import','',1),(18966,'119635','deals-mobile','gift_certificate','BlockBox','',1),(18967,'119636','deals-mobile','block-18966','account\\ApplyCertificate','',2),(18968,'119637','deals-mobile','block-18966','Html_box','',1),(18969,'119638','deals-mobile','gigt_card_3','BlockBox','',1),(18970,'119639','deals-mobile','block-18969','Text','',7),(18971,'119640','deals-mobile','block-18969','Text','',4),(18972,'119641','deals-mobile','block-18969','gift\\AmountView','',3),(18973,'119642','deals-mobile','block-18969','Text','',2),(18974,'119643','deals-mobile','block-18969','gift\\MessageView','',5),(18975,'119644','deals-mobile','block-18969','Text','',1),(18976,'119645','deals-mobile','block-18969','BlockBox','',9),(18977,'119646','deals-mobile','block-18976','invoice\\StoreEmail','',3),(18978,'119647','deals-mobile','block-18976','invoice\\StorePhone','',2),(18979,'119648','deals-mobile','block-18976','Text','',1),(18980,'119649','deals-mobile','block-18969','Text','',6),(18981,'119650','deals-mobile','block-18969','BlockBox','',8),(18982,'119651','deals-mobile','block-18981','Text','',1),(18983,'119652','deals-mobile','block-18981-2','gift\\CodeView','',1),(18984,'119653','deals-mobile','gigt_card_3_pdf','BlockBox','',1),(18985,'119654','deals-mobile','block-18984','BlockBox','',12),(18986,'119655','deals-mobile','block-18985','invoice\\StoreEmail','',4),(18987,'119656','deals-mobile','block-18985','invoice\\StorePhone','',3),(18988,'119657','deals-mobile','block-18985','Html_box','',1),(18989,'119658','deals-mobile','block-18984','BlockBox','',11),(18990,'119659','deals-mobile','block-18989','Html_box','',1),(18991,'119660','deals-mobile','block-18989-2','gift\\CodeViewPdf','',1),(18992,'119661','deals-mobile','block-18984','BlockBox','',1),(18993,'119662','deals-mobile','block-18992','Text','',4),(18994,'119663','deals-mobile','block-18992','Html_box','',1),(18995,'119664','deals-mobile','block-18992','Html_box','',2),(18996,'119665','deals-mobile','block-18992','gift\\AmountViewPdf','',3),(18997,'119666','deals-mobile','block-18992','gift\\MessageViewPdf','',5),(18998,'119667','deals-mobile','block-18992','Html_box','',7),(18999,'119668','deals-mobile','block-18992','Html_box','',6),(19000,'119669','deals-mobile','header','Logo','',2),(19001,'119670','deals-mobile','header','catalog\\Paging','',3),(19002,'119671','deals-mobile','header','BlockBox','',1),(19003,'119672','deals-mobile','block-19002','Text','',1),(19004,'119673','deals-mobile','block-19002','BlockBox','',2),(19005,'119674','deals-mobile','block-19004','Text','',2),(19006,'119675','deals-mobile','block-19004','Image','',1),(19007,'119676','deals-mobile','block-19004-2','BlockBox','',1),(19008,'119677','deals-mobile','block-19007','Html_box','',2),(19009,'119678','deals-mobile','block-19007-2','Html_box','',2),(19010,'119679','deals-mobile','header','BlockBox','',3),(19011,'119680','deals-mobile','block-19010','Menu','Categories',1),(19012,'119681','deals-mobile','block-19010-2','Search','',1),(19013,'119682','deals-mobile','block-19010-3','Account','',1),(19014,'119683','deals-mobile','block-19010-4','Cart','',1),(19015,'119684','deals-mobile','info','BlockBox','',1),(19016,'119685','deals-mobile','block-19015','info\\Content','',3),(19017,'119686','deals-mobile','block-19015','info\\Title','',2),(19018,'119687','deals-mobile','invoice','invoice\\Container','',1),(19019,'119688','deals-mobile','block-19018','BlockBox','',4),(19020,'119689','deals-mobile','block-19019','BlockBox','',1),(19021,'119690','deals-mobile','block-19020','invoice\\ShippingAddress','',2),(19022,'119691','deals-mobile','block-19020','Text','',1),(19023,'119692','deals-mobile','block-19019-2','BlockBox','',1),(19024,'119693','deals-mobile','block-19023','invoice\\Totals','',1),(19025,'119694','deals-mobile','block-19018','invoice\\Products','',3),(19026,'119695','deals-mobile','block-19018','BlockBox','',1),(19027,'119696','deals-mobile','block-19026','Logo','',1),(19028,'119697','deals-mobile','block-19026-2','BlockBox','',2),(19029,'119698','deals-mobile','block-19028','Text','',1),(19030,'119699','deals-mobile','block-19028-2','invoice\\StorePhone','',1),(19031,'119700','deals-mobile','block-19026-2','BlockBox','',1),(19032,'119701','deals-mobile','block-19031','invoice\\StoreAddress','',1),(19033,'119702','deals-mobile','block-19026-2','BlockBox','',4),(19034,'119703','deals-mobile','block-19033','Text','',1),(19035,'119704','deals-mobile','block-19033-2','invoice\\StoreSite','',1),(19036,'119705','deals-mobile','block-19026-2','BlockBox','',3),(19037,'119706','deals-mobile','block-19036','Text','',1),(19038,'119707','deals-mobile','block-19036-2','invoice\\StoreEmail','',1),(19039,'119708','deals-mobile','block-19018','BlockBox','',5),(19040,'119709','deals-mobile','block-19039','Text','',1),(19041,'119710','deals-mobile','block-19039','invoice\\StoreAddress','',8),(19042,'119711','deals-mobile','block-19039-2','Text','',2),(19043,'119712','deals-mobile','block-19039-2','Logo','',1),(19044,'119713','deals-mobile','block-19039-3','BlockBox','',3),(19045,'119714','deals-mobile','block-19044','Text','',1),(19046,'119715','deals-mobile','block-19044-2','invoice\\StoreEmail','',1),(19047,'119716','deals-mobile','block-19039-3','BlockBox','',2),(19048,'119717','deals-mobile','block-19047','Text','',1),(19049,'119718','deals-mobile','block-19047-2','invoice\\StorePhone','',1),(19050,'119719','deals-mobile','block-19039-3','Text','',1),(19051,'119720','deals-mobile','block-19018','BlockBox','',2),(19052,'119721','deals-mobile','block-19051','BlockBox','',8),(19053,'119722','deals-mobile','block-19052','BlockBox','',1),(19054,'119723','deals-mobile','block-19053','Text','',1),(19055,'119724','deals-mobile','block-19053','invoice\\ShippingMethod','',2),(19056,'119725','deals-mobile','block-19052-2','BlockBox','',1),(19057,'119726','deals-mobile','block-19056','invoice\\ShippingMethod','',2),(19058,'119727','deals-mobile','block-19056','Text','',1),(19059,'119728','deals-mobile','block-19051','BlockBox','',7),(19060,'119729','deals-mobile','block-19059','BlockBox','',1),(19061,'119730','deals-mobile','block-19060','Text','',1),(19062,'119731','deals-mobile','block-19060','invoice\\BillingAddress','',2),(19063,'119732','deals-mobile','block-19059-2','BlockBox','',1),(19064,'119733','deals-mobile','block-19063','invoice\\CustomerPhone','',4),(19065,'119734','deals-mobile','block-19063','Text','',1),(19066,'119735','deals-mobile','block-19063','invoice\\CustomerName','',2),(19067,'119736','deals-mobile','block-19063','Text','',3),(19068,'119737','deals-mobile','block-19063','Text','',5),(19069,'119738','deals-mobile','block-19063','invoice\\CustomerEmail','',6),(19070,'119739','deals-mobile','block-19051-2','invoice\\PaymentMethod','',5),(19071,'119740','deals-mobile','block-19051-2','invoice\\PaymentDate','',3),(19072,'119741','deals-mobile','block-19051-2','invoice\\OrderId','',1),(19073,'119742','deals-mobile','block-19051-2','invoice\\OrderBarcode','',6),(19074,'119743','deals-mobile','block-19051-2','Text','',2),(19075,'119744','deals-mobile','block-19051-2','Text','',4),(19076,'119745','deals-mobile','login_account','BlockBox','',1),(19077,'119746','deals-mobile','block-19076','Tabs','',2),(19078,'119747','deals-mobile','block-19077-1','login\\Returning','',1),(19079,'119748','deals-mobile','block-19077-2','login\\Register','',2),(19080,'119749','deals-mobile','block-19076','BlockBox','',1),(19081,'119750','deals-mobile','block-19080','Html_box','',3),(19082,'119751','deals-mobile','block-19080','Html_box','',1),(19083,'119752','deals-mobile','block-19080','login\\Socials','',2),(19084,'119753','deals-mobile','login_checkout','BlockBox','',1),(19085,'119754','deals-mobile','block-19084','BlockBox','',1),(19086,'119755','deals-mobile','block-19085','Html_box','',2),(19087,'119756','deals-mobile','block-19085','checkout\\CreateBtn','',5),(19088,'119757','deals-mobile','block-19085','checkout\\GuestBtn','',3),(19089,'119758','deals-mobile','block-19085','Html_box','',4),(19090,'119759','deals-mobile','block-19085','BlockBox','',6),(19091,'119760','deals-mobile','block-19090','Html_box','',1),(19092,'119761','deals-mobile','block-19090','login\\Socials','',2),(19093,'119762','deals-mobile','block-19085','login\\Returning','',1),(19094,'119763','deals-mobile','block-19085','Html_box','',1),(19095,'119764','deals-mobile','login_checkout2','BlockBox','',1),(19096,'119765','deals-mobile','block-19095','Html_box','',1),(19097,'119766','deals-mobile','block-19095','Html_box','',3),(19098,'119767','deals-mobile','block-19095','login\\Socials','',2),(19099,'119768','deals-mobile','block-19095','Tabs','',4),(19100,'119769','deals-mobile','block-19099-1','BlockBox','',1),(19101,'119770','deals-mobile','block-19100','Html_box','',1),(19102,'119771','deals-mobile','block-19100-2','BlockBox','',1),(19103,'119772','deals-mobile','block-19102','Html_box','',2),(19104,'119773','deals-mobile','block-19102','login\\Guest','',1),(19105,'119774','deals-mobile','block-19099-2','login\\Returning','',1),(19106,'119775','deals-mobile','block-19099-3','BlockBox','',1),(19107,'119776','deals-mobile','block-19106','Html_box','',1),(19108,'119777','deals-mobile','block-19106-2','BlockBox','',1),(19109,'119778','deals-mobile','block-19108','login\\Register','',1),(19110,'119779','deals-mobile','block-19108','Html_box','',2),(19111,'119780','deals-mobile','login_checkout2_q','BlockBox','',1),(19112,'119781','deals-mobile','block-19111','login\\Socials','',2),(19113,'119782','deals-mobile','block-19111','Html_box','',1),(19114,'119783','deals-mobile','block-19111','Html_box','',3),(19115,'119784','deals-mobile','block-19111','Tabs','',4),(19116,'119785','deals-mobile','block-19115-1','BlockBox','',1),(19117,'119786','deals-mobile','block-19116','Html_box','',1),(19118,'119787','deals-mobile','block-19116-2','quote\\FastOrder','',1),(19119,'119788','deals-mobile','block-19115-2','login\\Returning','',1),(19120,'119789','deals-mobile','block-19115-3','BlockBox','',1),(19121,'119790','deals-mobile','block-19120','Html_box','',1),(19122,'119791','deals-mobile','block-19120','Import','',2),(19123,'119792','deals-mobile','block-19120-2','BlockBox','',1),(19124,'119793','deals-mobile','block-19123','Html_box','',2),(19125,'119794','deals-mobile','block-19123','login\\Register','',1),(19126,'119795','deals-mobile','login_checkout2_s','BlockBox','',1),(19127,'119796','deals-mobile','block-19126','Html_box','',1),(19128,'119797','deals-mobile','block-19126','Tabs','',4),(19129,'119798','deals-mobile','block-19128-1','BlockBox','',1),(19130,'119799','deals-mobile','block-19129','Html_box','',1),(19131,'119800','deals-mobile','block-19129-2','quote\\FastOrder','',1),(19132,'119801','deals-mobile','block-19128-2','login\\Returning','',1),(19133,'119802','deals-mobile','block-19128-3','BlockBox','',1),(19134,'119803','deals-mobile','block-19133','Html_box','',1),(19135,'119804','deals-mobile','block-19133-2','BlockBox','',1),(19136,'119805','deals-mobile','block-19135','Html_box','',2),(19137,'119806','deals-mobile','block-19135','login\\Register','',1),(19138,'119807','deals-mobile','block-19126','login\\Socials','',2),(19139,'119808','deals-mobile','block-19126','Html_box','',3),(19140,'119809','deals-mobile','login_checkout_q','BlockBox','',1),(19141,'119810','deals-mobile','block-19140','BlockBox','',1),(19142,'119811','deals-mobile','block-19141','checkout\\CreateBtn','',5),(19143,'119812','deals-mobile','block-19141','checkout\\GuestBtn','',2),(19144,'119813','deals-mobile','block-19141','Html_box','',1),(19145,'119814','deals-mobile','block-19141','Html_box','',4),(19146,'119815','deals-mobile','block-19141','BlockBox','',6),(19147,'119816','deals-mobile','block-19146','login\\Socials','',2),(19148,'119817','deals-mobile','block-19146','Html_box','',1),(19149,'119818','deals-mobile','block-19141-2','login\\Returning','',2),(19150,'119819','deals-mobile','block-19141-2','Html_box','',1),(19151,'119820','deals-mobile','login_checkout_s','BlockBox','',1),(19152,'119821','deals-mobile','block-19151','BlockBox','',1),(19153,'119822','deals-mobile','block-19152','BlockBox','',5),(19154,'119823','deals-mobile','block-19153','Html_box','',1),(19155,'119824','deals-mobile','block-19153','login\\Socials','',2),(19156,'119825','deals-mobile','block-19152','Html_box','',3),(19157,'119826','deals-mobile','block-19152','checkout\\CreateBtn','',4),(19158,'119827','deals-mobile','block-19152','Html_box','',1),(19159,'119828','deals-mobile','block-19152','checkout\\GuestBtn','',2),(19160,'119829','deals-mobile','block-19152-2','Html_box','',1),(19161,'119830','deals-mobile','block-19152-2','login\\Returning','',2),(19162,'119831','deals-mobile','logoff','BlockBox','',1),(19163,'119832','deals-mobile','block-19162','Html_box','',1),(19164,'119833','deals-mobile','logoff_forever','BlockBox','',1),(19165,'119834','deals-mobile','block-19164','Html_box','',1),(19166,'119835','deals-mobile','main','BlockBox','',5),(19167,'119836','deals-mobile','block-19166','TopCategories','',1),(19168,'119837','deals-mobile','block-19166','PromoCode','',2),(19169,'119838','deals-mobile','block-19166','Tabs','',3),(19170,'119839','deals-mobile','block-19169-1','NewProducts','4',1),(19171,'119840','deals-mobile','block-19169-2','SpecialsProducts','4',1),(19172,'119841','deals-mobile','block-19169-3','FeaturedProducts','4',1),(19173,'119842','deals-mobile','main','Heading','',2),(19174,'119843','deals-mobile','main','BlockBox','',6),(19175,'119844','deals-mobile','block-19174','BlockBox','',1),(19176,'119845','deals-mobile','block-19175','Bestsellers','10',1),(19177,'119846','deals-mobile','block-19175-2','Reviews','4',1),(19178,'119847','deals-mobile','manufacturers','BlockBox','',1),(19179,'119848','deals-mobile','block-19178','Html_box','',1),(19180,'119849','deals-mobile','block-19178','Brands','',2),(19181,'119850','deals-mobile','messages-index','BlockBox','',1),(19182,'119851','deals-mobile','block-19181','BlockBox','',1),(19183,'119852','deals-mobile','block-19182','BlockBox','',1),(19184,'119853','deals-mobile','block-19183','Messages\\Sidebar','',1),(19185,'119854','deals-mobile','block-19182-2','Messages\\Listing','',1),(19186,'119855','deals-mobile','messages-new','BlockBox','',1),(19187,'119856','deals-mobile','block-19186','BlockBox','',1),(19188,'119857','deals-mobile','block-19187','Messages\\Sidebar','',1),(19189,'119858','deals-mobile','block-19187-2','Messages\\NewMessage','',1),(19190,'119859','deals-mobile','messages-view','BlockBox','',1),(19191,'119860','deals-mobile','block-19190','BlockBox','',1),(19192,'119861','deals-mobile','block-19191','Messages\\Sidebar','',1),(19193,'119862','deals-mobile','block-19191-2','Messages\\Message','',1),(19194,'119863','deals-mobile','my_password','BlockBox','',1),(19195,'119864','deals-mobile','block-19194','BlockBox','',1),(19196,'119865','deals-mobile','block-19195','WidgetsAria','',1),(19197,'119866','deals-mobile','block-19195-2','account\\ChangePassword','',2),(19198,'119867','deals-mobile','block-19195-2','Html_box','',1),(19199,'119868','deals-mobile','block-19195-2','account\\AccountLink','',3),(19200,'119869','deals-mobile','need_login','BlockBox','',1),(19201,'119870','deals-mobile','block-19200','BlockBox','',1),(19202,'119871','deals-mobile','block-19200','Tabs','',2),(19203,'119872','deals-mobile','block-19202-1','login\\Returning','',1),(19204,'119873','deals-mobile','block-19202-2','BlockBox','',1),(19205,'119874','deals-mobile','block-19204','Html_box','',1),(19206,'119875','deals-mobile','block-19204-2','BlockBox','',1),(19207,'119876','deals-mobile','block-19206','login\\Register','',1),(19208,'119877','deals-mobile','block-19206','Html_box','',2),(19209,'119878','deals-mobile','new-topic','BlockBox','',1),(19210,'119879','deals-mobile','block-19209','Communication\\NewTopic','',3),(19211,'119880','deals-mobile','block-19209','Html_box','',1),(19212,'119881','deals-mobile','block-19209','Breadcrumb','',2),(19213,'119882','deals-mobile','nnnn','BlockBox','',1),(19214,'119883','deals-mobile','block-19213','catalog\\Title','',1),(19215,'119884','deals-mobile','block-19213','BlockBox','',2),(19216,'119885','deals-mobile','block-19215','Filters','',1),(19217,'119886','deals-mobile','block-19215-2','Listing','',5),(19218,'119887','deals-mobile','block-19215-2','catalog\\Image','',1),(19219,'119888','deals-mobile','block-19215-2','BlockBox','',6),(19220,'119889','deals-mobile','block-19219','catalog\\CountsItems','',1),(19221,'119890','deals-mobile','block-19219-2','catalog\\Paging','',1),(19222,'119891','deals-mobile','block-19215-2','catalog\\ImageMapCategory','',3),(19223,'119892','deals-mobile','block-19215-2','Categories','',2),(19224,'119893','deals-mobile','block-19215-2','BlockBox','',4),(19225,'119894','deals-mobile','block-19224','catalog\\ListingLook','',1),(19226,'119895','deals-mobile','block-19224','catalog\\ItemsOnPage','',4),(19227,'119896','deals-mobile','block-19224','catalog\\CompareButton','',2),(19228,'119897','deals-mobile','block-19224','catalog\\Sorting','',3),(19229,'119898','deals-mobile','no-logged','BlockBox','',1),(19230,'119899','deals-mobile','block-19229','Html_box','',1),(19231,'119900','deals-mobile','block-19229','Communication\\NewTopic','',2),(19232,'119901','deals-mobile','no_filters','BlockBox','',1),(19233,'119902','deals-mobile','block-19232','BlockBox','',2),(19234,'119903','deals-mobile','block-19233','catalog\\Image','',1),(19235,'119904','deals-mobile','block-19233','BlockBox','',2),(19236,'119905','deals-mobile','block-19235','catalog\\Sorting','',3),(19237,'119906','deals-mobile','block-19235','catalog\\ItemsOnPage','',4),(19238,'119907','deals-mobile','block-19235','HeaderStock','',5),(19239,'119908','deals-mobile','block-19235','catalog\\CompareButton','',2),(19240,'119909','deals-mobile','block-19235','catalog\\ListingLook','',1),(19241,'119910','deals-mobile','block-19232','BlockBox','',4),(19242,'119911','deals-mobile','block-19241','catalog\\CountsItems','',1),(19243,'119912','deals-mobile','block-19241-2','catalog\\Paging','',1),(19244,'119913','deals-mobile','block-19232','catalog\\B2bAddButton','',5),(19245,'119914','deals-mobile','block-19232','catalog\\Title','',1),(19246,'119915','deals-mobile','block-19232','Listing','',3),(19247,'119916','deals-mobile','order_history','BlockBox','',1),(19248,'119917','deals-mobile','block-19247','BlockBox','',1),(19249,'119918','deals-mobile','block-19248','WidgetsAria','',1),(19250,'119919','deals-mobile','block-19248-2','account\\OrdersHistory','',2),(19251,'119920','deals-mobile','block-19248-2','Html_box','',1),(19252,'119921','deals-mobile','order_history_info','BlockBox','',1),(19253,'119922','deals-mobile','block-19252','BlockBox','',1),(19254,'119923','deals-mobile','block-19253','WidgetsAria','',1),(19255,'119924','deals-mobile','block-19253-2','account\\OrderReorderButton','',2),(19256,'119925','deals-mobile','block-19253-2','BlockBox','',7),(19257,'119926','deals-mobile','block-19256','BlockBox','',3),(19258,'119927','deals-mobile','block-19257','account\\AccountLink','',3),(19259,'119928','deals-mobile','block-19257','Html_box','',1),(19260,'119929','deals-mobile','block-19257','account\\OrderTracking','',2),(19261,'119930','deals-mobile','block-19256','BlockBox','',2),(19262,'119931','deals-mobile','block-19261','Html_box','',1),(19263,'119932','deals-mobile','block-19261','account\\OrderData','',2),(19264,'119933','deals-mobile','block-19256','BlockBox','',1),(19265,'119934','deals-mobile','block-19264','account\\OrderData','',2),(19266,'119935','deals-mobile','block-19264','Html_box','',1),(19267,'119936','deals-mobile','block-19256-2','BlockBox','',1),(19268,'119937','deals-mobile','block-19267','Html_box','',1),(19269,'119938','deals-mobile','block-19267','account\\OrderData','',2),(19270,'119939','deals-mobile','block-19256-2','BlockBox','',2),(19271,'119940','deals-mobile','block-19270','Html_box','',1),(19272,'119941','deals-mobile','block-19270','account\\OrderData','',2),(19273,'119942','deals-mobile','block-19256-3','BlockBox','',1),(19274,'119943','deals-mobile','block-19273','Html_box','',1),(19275,'119944','deals-mobile','block-19273','account\\OrderData','',2),(19276,'119945','deals-mobile','block-19256-3','BlockBox','',2),(19277,'119946','deals-mobile','block-19276','Html_box','',1),(19278,'119947','deals-mobile','block-19276','account\\OrderData','',2),(19279,'119948','deals-mobile','block-19253-2','account\\OrderDownload','',6),(19280,'119949','deals-mobile','block-19253-2','account\\OrderProducts','',9),(19281,'119950','deals-mobile','block-19253-2','Html_box','',11),(19282,'119951','deals-mobile','block-19253-2','account\\OrderHeading','',1),(19283,'119952','deals-mobile','block-19253-2','account\\OrderHistory','',12),(19284,'119953','deals-mobile','block-19253-2','account\\OrderCancelAndReorder','',4),(19285,'119954','deals-mobile','block-19253-2','Html_box','',8),(19286,'119955','deals-mobile','block-19253-2','account\\OrderSubTotals','',10),(19287,'119956','deals-mobile','block-19253-2','account\\OrderPayButton','',5),(19288,'119957','deals-mobile','block-19253-2','account\\OrderInvoiceButton','',3),(19289,'119958','deals-mobile','block-19253-2','BlockBox','',13),(19290,'119959','deals-mobile','block-19289','account\\AccountLink','',1),(19291,'119960','deals-mobile','block-19289-2','account\\OrderInvoiceButton','',1),(19292,'119961','deals-mobile','order_pay','BlockBox','',1),(19293,'119962','deals-mobile','block-19292','BlockBox','',1),(19294,'119963','deals-mobile','block-19293','WidgetsAria','',1),(19295,'119964','deals-mobile','block-19293-2','account\\OrderSubTotals','',5),(19296,'119965','deals-mobile','block-19293-2','account\\OrderHeading','',1),(19297,'119966','deals-mobile','block-19293-2','Html_box','',3),(19298,'119967','deals-mobile','block-19293-2','UpdateAndPay\\PayForm','',6),(19299,'119968','deals-mobile','block-19293-2','BlockBox','',2),(19300,'119969','deals-mobile','block-19299','BlockBox','',4),(19301,'119970','deals-mobile','block-19300','Html_box','',1),(19302,'119971','deals-mobile','block-19300','account\\OrderData','',2),(19303,'119972','deals-mobile','block-19299','BlockBox','',1),(19304,'119973','deals-mobile','block-19303','Html_box','',1),(19305,'119974','deals-mobile','block-19303','account\\OrderData','',2),(19306,'119975','deals-mobile','block-19299-2','BlockBox','',2),(19307,'119976','deals-mobile','block-19306','account\\OrderData','',2),(19308,'119977','deals-mobile','block-19306','Html_box','',1),(19309,'119978','deals-mobile','block-19299-2','BlockBox','',1),(19310,'119979','deals-mobile','block-19309','Html_box','',1),(19311,'119980','deals-mobile','block-19309','account\\OrderData','',2),(19312,'119981','deals-mobile','block-19299-3','BlockBox','',2),(19313,'119982','deals-mobile','block-19312','Html_box','',1),(19314,'119983','deals-mobile','block-19312','account\\OrderData','',2),(19315,'119984','deals-mobile','block-19299-3','BlockBox','',1),(19316,'119985','deals-mobile','block-19315','account\\OrderData','',2),(19317,'119986','deals-mobile','block-19315','Html_box','',1),(19318,'119987','deals-mobile','block-19293-2','account\\OrderProducts','',4),(19319,'119988','deals-mobile','packingslip','invoice\\Container','',2),(19320,'119989','deals-mobile','block-19319','packingslip\\Products','',3),(19321,'119990','deals-mobile','block-19319','BlockBox','',2),(19322,'119991','deals-mobile','block-19321','BlockBox','',2),(19323,'119992','deals-mobile','block-19322','BlockBox','',1),(19324,'119993','deals-mobile','block-19323','Text','',1),(19325,'119994','deals-mobile','block-19323','invoice\\ShippingAddress','',2),(19326,'119995','deals-mobile','block-19322-2','BlockBox','',1),(19327,'119996','deals-mobile','block-19326','invoice\\CustomerEmail','',6),(19328,'119997','deals-mobile','block-19326','invoice\\CustomerName','',2),(19329,'119998','deals-mobile','block-19326','invoice\\CustomerPhone','',4),(19330,'119999','deals-mobile','block-19326','Text','',5),(19331,'120000','deals-mobile','block-19326','Text','',1),(19332,'120001','deals-mobile','block-19326','Text','',3),(19333,'120002','deals-mobile','block-19321','BlockBox','',3),(19334,'120003','deals-mobile','block-19333','BlockBox','',1),(19335,'120004','deals-mobile','block-19334','invoice\\ShippingMethod','',2),(19336,'120005','deals-mobile','block-19334','Text','',1),(19337,'120006','deals-mobile','block-19333-2','BlockBox','',1),(19338,'120007','deals-mobile','block-19337','Text','',1),(19339,'120008','deals-mobile','block-19337','invoice\\ShippingMethod','',2),(19340,'120009','deals-mobile','block-19321-2','invoice\\AddressQrcode','',1),(19341,'120010','deals-mobile','block-19319','BlockBox','',4),(19342,'120011','deals-mobile','block-19341','Text','',1),(19343,'120012','deals-mobile','block-19341','invoice\\StoreAddress','',2),(19344,'120013','deals-mobile','block-19319','BlockBox','',1),(19345,'120014','deals-mobile','block-19344','Logo','',1),(19346,'120015','deals-mobile','block-19344-2','BlockBox','',1),(19347,'120016','deals-mobile','block-19346','invoice\\StoreAddress','',1),(19348,'120017','deals-mobile','block-19344-2','BlockBox','',2),(19349,'120018','deals-mobile','block-19348','Text','',2),(19350,'120019','deals-mobile','block-19348-2','invoice\\StorePhone','',1),(19351,'120020','deals-mobile','block-19344-2','BlockBox','',4),(19352,'120021','deals-mobile','block-19351','Text','',2),(19353,'120022','deals-mobile','block-19351-2','invoice\\StoreSite','',1),(19354,'120023','deals-mobile','block-19344-2','BlockBox','',3),(19355,'120024','deals-mobile','block-19354','Text','',2),(19356,'120025','deals-mobile','block-19354-2','invoice\\StoreEmail','',1),(19357,'120026','deals-mobile','password_forgotten','BlockBox','',1),(19358,'120027','deals-mobile','block-19357','Html_box','',1),(19359,'120028','deals-mobile','block-19357','BlockBox','',2),(19360,'120029','deals-mobile','block-19359-2','login\\PasswordForgotten','',2),(19361,'120030','deals-mobile','block-19359-2','Html_box','',1),(19362,'120031','deals-mobile','pdf','invoice\\Container','',1),(19363,'120032','deals-mobile','block-19362','BlockBox','',1),(19364,'120033','deals-mobile','block-19363','BlockBox','',1),(19365,'120034','deals-mobile','block-19364','BlockBox','',2),(19366,'120035','deals-mobile','block-19365','pdf\\ProductElement','',1),(19367,'120036','deals-mobile','block-19365-2','pdf\\ProductElement','',2),(19368,'120037','deals-mobile','block-19365-2','pdf\\ProductElement','',1),(19369,'120038','deals-mobile','block-19364','BlockBox','',1),(19370,'120039','deals-mobile','block-19369','pdf\\ProductElement','',1),(19371,'120040','deals-mobile','block-19363-2','BlockBox','',1),(19372,'120041','deals-mobile','block-19371','BlockBox','',1),(19373,'120042','deals-mobile','block-19372','pdf\\ProductElement','',1),(19374,'120043','deals-mobile','block-19371','BlockBox','',2),(19375,'120044','deals-mobile','block-19374','pdf\\ProductElement','',1),(19376,'120045','deals-mobile','block-19374-2','pdf\\ProductElement','',2),(19377,'120046','deals-mobile','block-19374-2','pdf\\ProductElement','',1),(19378,'120047','deals-mobile','pdf_category','pdf\\CategoryName','',2),(19379,'120048','deals-mobile','pdf_category','pdf\\CategoryImage','',1),(19380,'120049','deals-mobile','pdf_cover','invoice\\Container','',1),(19381,'120050','deals-mobile','block-19380','Logo','',1),(19382,'120051','deals-mobile','block-19380','Text','',3),(19383,'120052','deals-mobile','pdf_footer','BlockBox','',1),(19384,'120053','deals-mobile','block-19383-2','pdf\\PageNumber','',1),(19385,'120054','deals-mobile','pdf_header','pdf\\CategoryName','',1),(19386,'120055','deals-mobile','personal_catalog','BlockBox','',1),(19387,'120056','deals-mobile','block-19386','BlockBox','',1),(19388,'120057','deals-mobile','block-19387','WidgetsAria','',1),(19389,'120058','deals-mobile','block-19387-2','Html_box','',1),(19390,'120059','deals-mobile','block-19387-2','account\\PersonalCatalog','',2),(19391,'120060','deals-mobile','points_earnt_history','BlockBox','',1),(19392,'120061','deals-mobile','block-19391','Html_box','',1),(19393,'120062','deals-mobile','block-19391','account\\PointsEarntHistory','',2),(19394,'120063','deals-mobile','posts','BlockBox','',1),(19395,'120064','deals-mobile','block-19394','Breadcrumb','',2),(19396,'120065','deals-mobile','block-19394','Communication\\Post','',3),(19397,'120066','deals-mobile','block-19394','Html_box','',1),(19398,'120067','deals-mobile','product','BlockBox','',1),(19399,'120068','deals-mobile','block-19398','BlockBox','',5),(19400,'120069','deals-mobile','block-19399','product\\Stock','',2),(19401,'120070','deals-mobile','block-19399','product\\Price','',1),(19402,'120071','deals-mobile','block-19399-2','product\\Quantity','',1),(19403,'120072','deals-mobile','block-19398','product\\Bundle','',6),(19404,'120073','deals-mobile','block-19398','product\\Video','',3),(19405,'120074','deals-mobile','block-19398','product\\Documents','',16),(19406,'120075','deals-mobile','block-19398','product\\Buttons','',7),(19407,'120076','deals-mobile','block-19398','product\\Images','',2),(19408,'120077','deals-mobile','block-19398','product\\Name','',1),(19409,'120078','deals-mobile','block-19398','BlockBox','',8),(19410,'120079','deals-mobile','block-19409','product\\WishlistButton','',1),(19411,'120080','deals-mobile','block-19409','product\\PersonalCatalogButton','',2),(19412,'120081','deals-mobile','block-19409','product\\WeddingRegistryButton','',3),(19413,'120082','deals-mobile','block-19398','product\\BonusPoints','',9),(19414,'120083','deals-mobile','block-19398','product\\CrossSell','',13),(19415,'120084','deals-mobile','block-19398','product\\AlsoPurchased','10',11),(19416,'120085','deals-mobile','block-19398','product\\InBundles','',14),(19417,'120086','deals-mobile','block-19398','Tabs','',12),(19418,'120087','deals-mobile','block-19417-1','product\\Description','',1),(19419,'120088','deals-mobile','block-19417-1','product\\Properties','',2),(19420,'120089','deals-mobile','block-19417-2','product\\Reviews','',1),(19421,'120090','deals-mobile','block-19398','product\\Attributes','',4),(19422,'120091','deals-mobile','block-19398','product\\Configurator','',10),(19423,'120092','deals-mobile','block-19398','ViewedProducts','',15),(19424,'120093','deals-mobile','product-bottom','product\\Properties','',1),(19425,'120094','deals-mobile','product-tabs','product\\Reviews','',2),(19426,'120095','deals-mobile','product-tabs','product\\Description','',1),(19427,'120096','deals-mobile','product-top-left','product\\Images','',1),(19428,'120097','deals-mobile','product-top-right','product\\Attributes','',3),(19429,'120098','deals-mobile','product-top-right','product\\Buttons','',6),(19430,'120099','deals-mobile','product-top-right','product\\Quantity','',6),(19431,'120100','deals-mobile','product-top-right','product\\Quantity','',5),(19432,'120101','deals-mobile','product-top-right','product\\Name','',1),(19433,'120102','deals-mobile','product-top-right','product\\Price','',2),(19434,'120103','deals-mobile','productListing','BlockBox','',1),(19435,'120104','deals-mobile','block-19434','productListing\\model','',7),(19436,'120105','deals-mobile','block-19434','productListing\\bonusPoints','',6),(19437,'120106','deals-mobile','block-19434','productListing\\description','',5),(19438,'120107','deals-mobile','block-19434','productListing\\buyButton','',9),(19439,'120108','deals-mobile','block-19434','productListing\\rating','',3),(19440,'120109','deals-mobile','block-19434','productListing\\image','',1),(19441,'120110','deals-mobile','block-19434','BlockBox','',8),(19442,'120111','deals-mobile','block-19441','productListing\\price','',1),(19443,'120112','deals-mobile','block-19441-2','productListing\\qtyInput','',1),(19444,'120113','deals-mobile','block-19434','productListing\\name','',4),(19445,'120114','deals-mobile','block-19434','productListing\\stock','',2),(19446,'120115','deals-mobile','products','BlockBox','',1),(19447,'120116','deals-mobile','block-19446','Filters','',3),(19448,'120117','deals-mobile','block-19446','catalog\\Paging','',5),(19449,'120118','deals-mobile','block-19446','catalog\\Title','',1),(19450,'120119','deals-mobile','block-19446','catalog\\Image','',2),(19451,'120120','deals-mobile','block-19446','BlockBox','',4),(19452,'120121','deals-mobile','block-19451','catalog\\Sorting','',1),(19453,'120122','deals-mobile','block-19451-2','catalog\\CountsItems','',1),(19454,'120123','deals-mobile','block-19446','Listing','',7),(19455,'120124','deals-mobile','products-list','packingslip\\AllProductsList','',2),(19456,'120125','deals-mobile','promotions','BlockBox','',1),(19457,'120126','deals-mobile','block-19456','promotions\\PromoList','',2),(19458,'120127','deals-mobile','block-19456','Html_box','',1),(19459,'120128','deals-mobile','purchase','invoice\\Container','',1),(19460,'120129','deals-mobile','block-19459','BlockBox','',4),(19461,'120130','deals-mobile','block-19460','BlockBox','',1),(19462,'120131','deals-mobile','block-19461','Text','',1),(19463,'120132','deals-mobile','block-19461','invoice\\ShippingAddress','',2),(19464,'120133','deals-mobile','block-19459','BlockBox','',2),(19465,'120134','deals-mobile','block-19464','BlockBox','',7),(19466,'120135','deals-mobile','block-19465','BlockBox','',1),(19467,'120136','deals-mobile','block-19466','Text','',1),(19468,'120137','deals-mobile','block-19466','invoice\\BillingAddress','',2),(19469,'120138','deals-mobile','block-19465-2','BlockBox','',1),(19470,'120139','deals-mobile','block-19469','Text','',1),(19471,'120140','deals-mobile','block-19469','Text','',3),(19472,'120141','deals-mobile','block-19469','Text','',5),(19473,'120142','deals-mobile','block-19469','invoice\\CustomerName','',2),(19474,'120143','deals-mobile','block-19469','invoice\\CustomerPhone','',4),(19475,'120144','deals-mobile','block-19469','invoice\\CustomerEmail','',6),(19476,'120145','deals-mobile','block-19464-2','Text','',2),(19477,'120146','deals-mobile','block-19464-2','invoice\\PaymentDate','',3),(19478,'120147','deals-mobile','block-19464-2','invoice\\OrderId','',1),(19479,'120148','deals-mobile','block-19459','BlockBox','',1),(19480,'120149','deals-mobile','block-19479','Logo','',1),(19481,'120150','deals-mobile','block-19479-2','BlockBox','',1),(19482,'120151','deals-mobile','block-19481','invoice\\StoreAddress','',1),(19483,'120152','deals-mobile','block-19479-2','BlockBox','',3),(19484,'120153','deals-mobile','block-19483','Text','',1),(19485,'120154','deals-mobile','block-19483-2','invoice\\StoreEmail','',1),(19486,'120155','deals-mobile','block-19479-2','BlockBox','',4),(19487,'120156','deals-mobile','block-19486','Text','',1),(19488,'120157','deals-mobile','block-19486-2','invoice\\StoreSite','',1),(19489,'120158','deals-mobile','block-19479-2','BlockBox','',2),(19490,'120159','deals-mobile','block-19489','Text','',1),(19491,'120160','deals-mobile','block-19489-2','invoice\\StorePhone','',1),(19492,'120161','deals-mobile','block-19459','BlockBox','',5),(19493,'120162','deals-mobile','block-19492','invoice\\StoreAddress','',8),(19494,'120163','deals-mobile','block-19492','Text','',1),(19495,'120164','deals-mobile','block-19492-2','Text','',2),(19496,'120165','deals-mobile','block-19492-2','Logo','',1),(19497,'120166','deals-mobile','block-19492-3','BlockBox','',2),(19498,'120167','deals-mobile','block-19497','Text','',1),(19499,'120168','deals-mobile','block-19497-2','invoice\\StorePhone','',1),(19500,'120169','deals-mobile','block-19492-3','Text','',1),(19501,'120170','deals-mobile','block-19492-3','BlockBox','',3),(19502,'120171','deals-mobile','block-19501','Text','',1),(19503,'120172','deals-mobile','block-19501-2','invoice\\StoreEmail','',1),(19504,'120173','deals-mobile','block-19459','invoice\\Products','',3),(19505,'120174','deals-mobile','quotations','BlockBox','',1),(19506,'120175','deals-mobile','block-19505','BlockBox','',1),(19507,'120176','deals-mobile','block-19506','WidgetsAria','',1),(19508,'120177','deals-mobile','block-19506-2','Html_box','',1),(19509,'120178','deals-mobile','block-19506-2','Quotations\\QuotationsHistory','',2),(19510,'120179','deals-mobile','quotation_info','BlockBox','',1),(19511,'120180','deals-mobile','block-19510','BlockBox','',1),(19512,'120181','deals-mobile','block-19511','WidgetsAria','',1),(19513,'120182','deals-mobile','block-19511-2','Quotations\\QuotationHistory','',10),(19514,'120183','deals-mobile','block-19511-2','Quotations\\QuotationProducts','',7),(19515,'120184','deals-mobile','block-19511-2','Html_box','',9),(19516,'120185','deals-mobile','block-19511-2','Html_box','',6),(19517,'120186','deals-mobile','block-19511-2','Quotations\\QuotationSubTotal','',8),(19518,'120187','deals-mobile','block-19511-2','Html_box','',4),(19519,'120188','deals-mobile','block-19511-2','BlockBox','',12),(19520,'120189','deals-mobile','block-19519','account\\AccountLink','',1),(19521,'120190','deals-mobile','block-19511-2','BlockBox','',5),(19522,'120191','deals-mobile','block-19521','BlockBox','',4),(19523,'120192','deals-mobile','block-19522','Html_box','',1),(19524,'120193','deals-mobile','block-19522','Quotations\\QuotationData','',2),(19525,'120194','deals-mobile','block-19521','BlockBox','',1),(19526,'120195','deals-mobile','block-19525','Quotations\\QuotationData','',2),(19527,'120196','deals-mobile','block-19525','Html_box','',1),(19528,'120197','deals-mobile','block-19521-2','BlockBox','',2),(19529,'120198','deals-mobile','block-19528','Html_box','',1),(19530,'120199','deals-mobile','block-19528','Quotations\\QuotationData','',2),(19531,'120200','deals-mobile','block-19521-2','BlockBox','',1),(19532,'120201','deals-mobile','block-19531','Html_box','',1),(19533,'120202','deals-mobile','block-19531','Quotations\\QuotationData','',2),(19534,'120203','deals-mobile','block-19521-3','BlockBox','',1),(19535,'120204','deals-mobile','block-19534','Html_box','',1),(19536,'120205','deals-mobile','block-19534','Quotations\\QuotationData','',2),(19537,'120206','deals-mobile','block-19521-3','BlockBox','',2),(19538,'120207','deals-mobile','block-19537','Quotations\\QuotationData','',2),(19539,'120208','deals-mobile','block-19537','Html_box','',1),(19540,'120209','deals-mobile','quote','quote\\CheckoutBtn','',3),(19541,'120210','deals-mobile','quote','quote\\Products','',2),(19542,'120211','deals-mobile','quote','Text','',1),(19543,'120212','deals-mobile','review','BlockBox','',1),(19544,'120213','deals-mobile','block-19543','BlockBox','',1),(19545,'120214','deals-mobile','block-19544','WidgetsAria','',1),(19546,'120215','deals-mobile','block-19544-2','Html_box','',1),(19547,'120216','deals-mobile','block-19544-2','account\\Reviews','',2),(19548,'120217','deals-mobile','reviews','BlockBox','',1),(19549,'120218','deals-mobile','block-19548','reviews\\Content','',2),(19550,'120219','deals-mobile','block-19548','reviews\\Heading','',1),(19551,'120220','deals-mobile','rma_document','invoice\\Container','',1),(19552,'120221','deals-mobile','block-19551','BlockBox','',3),(19553,'120222','deals-mobile','block-19552','BlockBox','',1),(19554,'120223','deals-mobile','block-19553','BlockBox','',1),(19555,'120224','deals-mobile','block-19554','BlockBox','',6),(19556,'120225','deals-mobile','block-19555','Html_box','',1),(19557,'120226','deals-mobile','block-19554','BlockBox','',3),(19558,'120227','deals-mobile','block-19557','Html_box','',1),(19559,'120228','deals-mobile','block-19557-2','Html_box','',1),(19560,'120229','deals-mobile','block-19554','BlockBox','',1),(19561,'120230','deals-mobile','block-19560','Html_box','',1),(19562,'120231','deals-mobile','block-19554','BlockBox','',2),(19563,'120232','deals-mobile','block-19562','Html_box','',1),(19564,'120233','deals-mobile','block-19562-2','Html_box','',1),(19565,'120234','deals-mobile','block-19554','BlockBox','',4),(19566,'120235','deals-mobile','block-19565','Html_box','',1),(19567,'120236','deals-mobile','block-19565-2','Html_box','',1),(19568,'120237','deals-mobile','block-19554','BlockBox','',5),(19569,'120238','deals-mobile','block-19568','Html_box','',1),(19570,'120239','deals-mobile','block-19568-2','Html_box','',1),(19571,'120240','deals-mobile','block-19568-2','invoice\\StoreAddress','',2),(19572,'120241','deals-mobile','block-19553-2','BlockBox','',3),(19573,'120242','deals-mobile','block-19572','Html_box','',1),(19574,'120243','deals-mobile','block-19572-2','Html_box','',1),(19575,'120244','deals-mobile','block-19572-3','BlockBox','',1),(19576,'120245','deals-mobile','block-19575','Html_box','',1),(19577,'120246','deals-mobile','block-19575-2','Html_box','',1),(19578,'120247','deals-mobile','block-19553-2','BlockBox','',4),(19579,'120248','deals-mobile','block-19578','Html_box','',1),(19580,'120249','deals-mobile','block-19578-2','Html_box','',1),(19581,'120250','deals-mobile','block-19578-3','BlockBox','',1),(19582,'120251','deals-mobile','block-19581','Html_box','',1),(19583,'120252','deals-mobile','block-19581-2','Html_box','',1),(19584,'120253','deals-mobile','block-19553-2','BlockBox','',2),(19585,'120254','deals-mobile','block-19584','Html_box','',1),(19586,'120255','deals-mobile','block-19584','Html_box','',2),(19587,'120256','deals-mobile','block-19584','Html_box','',3),(19588,'120257','deals-mobile','block-19584','Html_box','',4),(19589,'120258','deals-mobile','block-19584','Html_box','',5),(19590,'120259','deals-mobile','block-19553-2','BlockBox','',1),(19591,'120260','deals-mobile','block-19590','BlockBox','',1),(19592,'120261','deals-mobile','block-19591','BlockBox','',1),(19593,'120262','deals-mobile','block-19592','Rma\\DocumentData','',2),(19594,'120263','deals-mobile','block-19592-3','BlockBox','',1),(19595,'120264','deals-mobile','block-19594','Html_box','',1),(19596,'120265','deals-mobile','block-19594-2','Rma\\DocumentData','',1),(19597,'120266','deals-mobile','block-19591','BlockBox','',2),(19598,'120267','deals-mobile','block-19597-2','invoice\\StoreAddress','',1),(19599,'120268','deals-mobile','block-19551','BlockBox','',2),(19600,'120269','deals-mobile','block-19599','Rma\\Products','',2),(19601,'120270','deals-mobile','block-19599','Html_box','',1),(19602,'120271','deals-mobile','block-19551','BlockBox','',1),(19603,'120272','deals-mobile','block-19602','BlockBox','',1),(19604,'120273','deals-mobile','block-19603','BlockBox','',1),(19605,'120274','deals-mobile','block-19604','Html_box','',2),(19606,'120275','deals-mobile','block-19604','Html_box','',1),(19607,'120276','deals-mobile','block-19603','BlockBox','',3),(19608,'120277','deals-mobile','block-19607','Html_box','',1),(19609,'120278','deals-mobile','block-19607-2','Html_box','',1),(19610,'120279','deals-mobile','block-19603','BlockBox','',2),(19611,'120280','deals-mobile','block-19610','Html_box','',1),(19612,'120281','deals-mobile','block-19610-2','Html_box','',1),(19613,'120282','deals-mobile','block-19603','BlockBox','',4),(19614,'120283','deals-mobile','block-19613','Html_box','',1),(19615,'120284','deals-mobile','block-19613-2','Html_box','',1),(19616,'120285','deals-mobile','block-19603','BlockBox','',5),(19617,'120286','deals-mobile','block-19616','Html_box','',1),(19618,'120287','deals-mobile','block-19616-2','Html_box','',1),(19619,'120288','deals-mobile','block-19602-2','BlockBox','',3),(19620,'120289','deals-mobile','block-19619','BlockBox','',1),(19621,'120290','deals-mobile','block-19620','Html_box','',1),(19622,'120291','deals-mobile','block-19620-2','Rma\\DocumentData','',1),(19623,'120292','deals-mobile','block-19619-2','BlockBox','',1),(19624,'120293','deals-mobile','block-19623','Html_box','',1),(19625,'120294','deals-mobile','block-19623-2','Rma\\DocumentData','',1),(19626,'120295','deals-mobile','block-19602-2','BlockBox','',2),(19627,'120296','deals-mobile','block-19626','BlockBox','',1),(19628,'120297','deals-mobile','block-19627','BlockBox','',1),(19629,'120298','deals-mobile','block-19628','Html_box','',1),(19630,'120299','deals-mobile','block-19628-2','Rma\\DocumentData','',1),(19631,'120300','deals-mobile','block-19627-2','BlockBox','',1),(19632,'120301','deals-mobile','block-19631','Html_box','',1),(19633,'120302','deals-mobile','block-19631-2','Rma\\DocumentData','',1),(19634,'120303','deals-mobile','block-19626','BlockBox','',2),(19635,'120304','deals-mobile','block-19634','Html_box','',1),(19636,'120305','deals-mobile','block-19634-2','Rma\\DocumentData','',1),(19637,'120306','deals-mobile','block-19626','BlockBox','',3),(19638,'120307','deals-mobile','block-19637','BlockBox','',1),(19639,'120308','deals-mobile','block-19638','Html_box','',1),(19640,'120309','deals-mobile','block-19638-2','Rma\\DocumentData','',1),(19641,'120310','deals-mobile','block-19637-2','BlockBox','',1),(19642,'120311','deals-mobile','block-19641','Html_box','',1),(19643,'120312','deals-mobile','block-19641-2','Rma\\DocumentData','',1),(19644,'120313','deals-mobile','block-19626','BlockBox','',4),(19645,'120314','deals-mobile','block-19644','BlockBox','',1),(19646,'120315','deals-mobile','block-19645','Html_box','',1),(19647,'120316','deals-mobile','block-19645-2','Rma\\DocumentData','',1),(19648,'120317','deals-mobile','block-19644-2','BlockBox','',1),(19649,'120318','deals-mobile','block-19648','Html_box','',1),(19650,'120319','deals-mobile','block-19648-2','Rma\\DocumentData','',1),(19651,'120320','deals-mobile','block-19626','BlockBox','',5),(19652,'120321','deals-mobile','block-19651','BlockBox','',1),(19653,'120322','deals-mobile','block-19652','Html_box','',1),(19654,'120323','deals-mobile','block-19652-2','Rma\\DocumentData','',1),(19655,'120324','deals-mobile','block-19651-2','BlockBox','',1),(19656,'120325','deals-mobile','block-19655','Html_box','',1),(19657,'120326','deals-mobile','block-19655-2','Rma\\DocumentData','',1),(19658,'120327','deals-mobile','block-19602-2','BlockBox','',1),(19659,'120328','deals-mobile','block-19658','Logo','',1),(19660,'120329','deals-mobile','block-19658','Html_box','',2),(19661,'120330','deals-mobile','rows','BlockBox','',1),(19662,'120331','deals-mobile','block-19661','BlockBox','',2),(19663,'120332','deals-mobile','block-19662','BlockBox','',2),(19664,'120333','deals-mobile','block-19663','BlockBox','',3),(19665,'120334','deals-mobile','block-19664','productListing\\rating','',1),(19666,'120335','deals-mobile','block-19664','productListing\\ratingCounts','',2),(19667,'120336','deals-mobile','block-19663','productListing\\bonusPoints','',1),(19668,'120337','deals-mobile','block-19663','productListing\\image','',2),(19669,'120338','deals-mobile','block-19663-2','productListing\\model','',3),(19670,'120339','deals-mobile','block-19663-2','productListing\\name','',1),(19671,'120340','deals-mobile','block-19663-2','productListing\\description','',2),(19672,'120341','deals-mobile','block-19663-2','productListing\\attributes','',4),(19673,'120342','deals-mobile','block-19662-2','BlockBox','',1),(19674,'120343','deals-mobile','block-19673','productListing\\stock','',1),(19675,'120344','deals-mobile','block-19673','productListing\\price','',2),(19676,'120345','deals-mobile','block-19673','productListing\\wishlistButton','',6),(19677,'120346','deals-mobile','block-19673','productListing\\qtyInput','',3),(19678,'120347','deals-mobile','block-19673','productListing\\compare','',5),(19679,'120348','deals-mobile','block-19673','productListing\\buyButton','',4),(19680,'120349','deals-mobile','sample','BlockBox','',1),(19681,'120350','deals-mobile','block-19680','sample\\Products','',2),(19682,'120351','deals-mobile','block-19680','sample\\CheckoutBtn','',3),(19683,'120352','deals-mobile','block-19680','Text','',1),(19684,'120353','deals-mobile','samples','BlockBox','',1),(19685,'120354','deals-mobile','block-19684','BlockBox','',1),(19686,'120355','deals-mobile','block-19685','WidgetsAria','',1),(19687,'120356','deals-mobile','block-19685-2','Html_box','',1),(19688,'120357','deals-mobile','block-19685-2','Samples\\SamplesHistory','',2),(19689,'120358','deals-mobile','sample_info','BlockBox','',1),(19690,'120359','deals-mobile','block-19689','BlockBox','',1),(19691,'120360','deals-mobile','block-19690','WidgetsAria','',1),(19692,'120361','deals-mobile','block-19690-2','Html_box','',6),(19693,'120362','deals-mobile','block-19690-2','BlockBox','',2),(19694,'120363','deals-mobile','block-19693','BlockBox','',4),(19695,'120364','deals-mobile','block-19694','Html_box','',1),(19696,'120365','deals-mobile','block-19694','Samples\\SampleData','',2),(19697,'120366','deals-mobile','block-19693','BlockBox','',1),(19698,'120367','deals-mobile','block-19697','Samples\\SampleData','',2),(19699,'120368','deals-mobile','block-19697','Html_box','',1),(19700,'120369','deals-mobile','block-19693-2','BlockBox','',1),(19701,'120370','deals-mobile','block-19700','Html_box','',1),(19702,'120371','deals-mobile','block-19700','Samples\\SampleData','',2),(19703,'120372','deals-mobile','block-19693-2','BlockBox','',2),(19704,'120373','deals-mobile','block-19703','Samples\\SampleData','',2),(19705,'120374','deals-mobile','block-19703','Html_box','',1),(19706,'120375','deals-mobile','block-19693-3','BlockBox','',1),(19707,'120376','deals-mobile','block-19706','Html_box','',1),(19708,'120377','deals-mobile','block-19706','Samples\\SampleData','',2),(19709,'120378','deals-mobile','block-19693-3','BlockBox','',2),(19710,'120379','deals-mobile','block-19709','Samples\\SampleData','',2),(19711,'120380','deals-mobile','block-19709','Html_box','',1),(19712,'120381','deals-mobile','block-19690-2','Html_box','',3),(19713,'120382','deals-mobile','block-19690-2','Samples\\SampleProducts','',4),(19714,'120383','deals-mobile','block-19690-2','Samples\\SampleSubTotal','',5),(19715,'120384','deals-mobile','block-19690-2','BlockBox','',8),(19716,'120385','deals-mobile','block-19715','account\\AccountLink','',1),(19717,'120386','deals-mobile','block-19690-2','Samples\\SampleHistory','',7),(19718,'120387','deals-mobile','block-19690-2','Html_box','',1),(19719,'120388','deals-mobile','sample_info','BlockBox','',1),(19720,'120389','deals-mobile','block-19719','BlockBox','',1),(19721,'120390','deals-mobile','block-19720','WidgetsAria','',1),(19722,'120391','deals-mobile','block-19720-2','Html_box','',3),(19723,'120392','deals-mobile','block-19720-2','account\\OrdersHistory','',4),(19724,'120393','deals-mobile','block-19720-2','Html_box','',1),(19725,'120394','deals-mobile','block-19720-2','BlockBox','',2),(19726,'120395','deals-mobile','block-19725','Html_box','',1),(19727,'120396','deals-mobile','block-19725','account\\LastOrder','',2),(19728,'120397','deals-mobile','block-19725-2','Html_box','',1),(19729,'120398','deals-mobile','block-19725-2','account\\AccountLink','',3),(19730,'120399','deals-mobile','block-19725-2','account\\OrderCount','',2),(19731,'120400','deals-mobile','block-19725-3','Html_box','',1),(19732,'120401','deals-mobile','block-19725-3','account\\TotalOrdered','',2),(19733,'120402','deals-mobile','block-19725-4','Html_box','',1),(19734,'120403','deals-mobile','block-19725-4','account\\AccountLink','',3),(19735,'120404','deals-mobile','block-19725-4','account\\CreditAmount','',2),(19736,'120405','deals-mobile','block-19725-5','account\\AccountLink','',3),(19737,'120406','deals-mobile','block-19725-5','account\\PointsEarnt','',2),(19738,'120407','deals-mobile','block-19725-5','Html_box','',1),(19739,'120408','deals-mobile','block-19720-2','BlockBox','',5),(19740,'120409','deals-mobile','block-19739','account\\GiftCards','',6),(19741,'120410','deals-mobile','block-19739','Html_box','',1),(19742,'120411','deals-mobile','block-19720-2','Html_box','',5),(19743,'120412','deals-mobile','sitemap','BlockBox','',1),(19744,'120413','deals-mobile','block-19743','BlockBox','',2),(19745,'120414','deals-mobile','block-19744','Menu','Account box',6),(19746,'120415','deals-mobile','block-19744','sitemap\\InfoPages','',2),(19747,'120416','deals-mobile','block-19744','Html_box','',5),(19748,'120417','deals-mobile','block-19744','sitemap\\Categories','',4),(19749,'120418','deals-mobile','block-19744','Html_box','',3),(19750,'120419','deals-mobile','block-19744','Html_box','',1),(19751,'120420','deals-mobile','block-19744-2','Html_box','',1),(19752,'120421','deals-mobile','block-19744-2','sitemap\\DeliveryLocation','',2),(19753,'120422','deals-mobile','block-19743','Html_box','',1),(19754,'120423','deals-mobile','subscribe','BlockBox','',1),(19755,'120424','deals-mobile','block-19754','subscribers\\SubscribeForm','',2),(19756,'120425','deals-mobile','block-19754','Html_box','',1),(19757,'120426','deals-mobile','block-19754','Html_box','',3),(19758,'120427','deals-mobile','block-19754','subscribers\\UnsubscribeForm','',4),(19759,'120428','deals-mobile','subscribed','BlockBox','',1),(19760,'120429','deals-mobile','block-19759','Html_box','',1),(19761,'120430','deals-mobile','subscription','BlockBox','',2),(19762,'120431','deals-mobile','block-19761','BlockBox','',1),(19763,'120432','deals-mobile','block-19762','WidgetsAria','',1),(19764,'120433','deals-mobile','block-19762-2','Html_box','',2),(19765,'120434','deals-mobile','block-19762-2','Html_box','',3),(19766,'120435','deals-mobile','block-19762-2','account\\Subscription','',4),(19767,'120436','deals-mobile','success','BlockBox','',1),(19768,'120437','deals-mobile','block-19767','BlockBox','',1),(19769,'120438','deals-mobile','block-19768','Text','',2),(19770,'120439','deals-mobile','block-19768','BlockBox','',3),(19771,'120440','deals-mobile','block-19770','Html','',3),(19772,'120441','deals-mobile','block-19770-2','success\\PrintBtn','',1),(19773,'120442','deals-mobile','block-19770-3','success\\ContinueBtn','',1),(19774,'120443','deals-mobile','success_q','BlockBox','',1),(19775,'120444','deals-mobile','block-19774','BlockBox','',1),(19776,'120445','deals-mobile','block-19775','BlockBox','',2),(19777,'120446','deals-mobile','block-19776','success\\PrintBtn','',1),(19778,'120447','deals-mobile','block-19776','success\\ContinueBtn','',2),(19779,'120448','deals-mobile','block-19775','Html_box','',1),(19783,'120452','deals-mobile','ticket','invoice\\Container','',1),(19784,'120453','deals-mobile','block-19783','BlockBox','',1),(19785,'120454','deals-mobile','block-19784-2','BlockBox','',1),(19786,'120455','deals-mobile','block-19785','invoice\\StoreAddress','',1),(19787,'120456','deals-mobile','block-19784-2','BlockBox','',2),(19788,'120457','deals-mobile','block-19787','Text','',1),(19789,'120458','deals-mobile','block-19787-2','invoice\\StorePhone','',1),(19790,'120459','deals-mobile','block-19784-2','BlockBox','',4),(19791,'120460','deals-mobile','block-19790','Text','',1),(19792,'120461','deals-mobile','block-19790-2','invoice\\StoreSite','',1),(19793,'120462','deals-mobile','block-19784-2','BlockBox','',3),(19794,'120463','deals-mobile','block-19793','Text','',1),(19795,'120464','deals-mobile','block-19793-2','invoice\\StoreEmail','',1),(19796,'120465','deals-mobile','block-19783','BlockBox','',2),(19797,'120466','deals-mobile','block-19796','BlockBox','',7),(19798,'120467','deals-mobile','block-19797','BlockBox','',1),(19799,'120468','deals-mobile','block-19798','Text','',1),(19800,'120469','deals-mobile','block-19798','invoice\\BillingAddress','',2),(19801,'120470','deals-mobile','block-19797-2','BlockBox','',1),(19802,'120471','deals-mobile','block-19801','Text','',3),(19803,'120472','deals-mobile','block-19801','Text','',5),(19804,'120473','deals-mobile','block-19801','Text','',1),(19805,'120474','deals-mobile','block-19801','invoice\\CustomerPhone','',4),(19806,'120475','deals-mobile','block-19801','invoice\\CustomerName','',2),(19807,'120476','deals-mobile','block-19801','invoice\\CustomerEmail','',6),(19808,'120477','deals-mobile','block-19796','BlockBox','',8),(19809,'120478','deals-mobile','block-19808','BlockBox','',1),(19810,'120479','deals-mobile','block-19809','Text','',1),(19811,'120480','deals-mobile','block-19809','invoice\\ShippingMethod','',2),(19812,'120481','deals-mobile','block-19808-2','BlockBox','',1),(19813,'120482','deals-mobile','block-19812','invoice\\ShippingMethod','',2),(19814,'120483','deals-mobile','block-19812','Text','',1),(19815,'120484','deals-mobile','block-19796-2','Text','',2),(19816,'120485','deals-mobile','block-19796-2','invoice\\OrderBarcode','',6),(19817,'120486','deals-mobile','block-19796-2','Text','',4),(19818,'120487','deals-mobile','block-19796-2','invoice\\OrderId','',1),(19819,'120488','deals-mobile','block-19796-2','invoice\\PaymentDate','',3),(19820,'120489','deals-mobile','block-19796-2','invoice\\PaymentMethod','',5),(19821,'120490','deals-mobile','block-19783','BlockBox','',5),(19822,'120491','deals-mobile','block-19821','Text','',1),(19823,'120492','deals-mobile','block-19821','invoice\\StoreAddress','',8),(19824,'120493','deals-mobile','block-19821-2','Logo','',1),(19825,'120494','deals-mobile','block-19821-2','Text','',2),(19826,'120495','deals-mobile','block-19821-3','BlockBox','',2),(19827,'120496','deals-mobile','block-19826','Text','',1),(19828,'120497','deals-mobile','block-19826-2','invoice\\StorePhone','',1),(19829,'120498','deals-mobile','block-19821-3','Text','',1),(19830,'120499','deals-mobile','block-19821-3','BlockBox','',3),(19831,'120500','deals-mobile','block-19830','Text','',1),(19832,'120501','deals-mobile','block-19830-2','invoice\\StoreEmail','',1),(19833,'120502','deals-mobile','block-19783','invoice\\Products','',3),(19834,'120503','deals-mobile','block-19783','BlockBox','',4),(19835,'120504','deals-mobile','block-19834','BlockBox','',1),(19836,'120505','deals-mobile','block-19835','invoice\\ShippingAddress','',2),(19837,'120506','deals-mobile','block-19835','Text','',1),(19838,'120507','deals-mobile','block-19834-2','BlockBox','',1),(19839,'120508','deals-mobile','block-19838','invoice\\Totals','',1),(19840,'120509','deals-mobile','tl_blog_category','BlockBox','',1),(19841,'120510','deals-mobile','block-19840','BlockBox','',1),(19842,'120511','deals-mobile','block-19841','BlockBox','',1),(19843,'120512','deals-mobile','block-19842','Blog\\widget\\PostListing','',1),(19844,'120513','deals-mobile','block-19842','catalog\\Paging','',2),(19845,'120514','deals-mobile','block-19841-2','WidgetsAria','',1),(19846,'120515','deals-mobile','tl_blog_index','BlockBox','',2),(19847,'120516','deals-mobile','block-19846','BlockBox','',2),(19848,'120517','deals-mobile','block-19847','BlockBox','',1),(19849,'120518','deals-mobile','block-19848','Blog\\widget\\PostListing','',1),(19850,'120519','deals-mobile','block-19848','catalog\\Paging','',2),(19851,'120520','deals-mobile','block-19847-2','WidgetsAria','',1),(19852,'120521','deals-mobile','block-19846','Banner','',1),(19853,'120522','deals-mobile','tl_blog_post','BlockBox','',1),(19854,'120523','deals-mobile','block-19853','BlockBox','',3),(19855,'120524','deals-mobile','block-19854','Blog\\widget\\PostTags','',2),(19856,'120525','deals-mobile','block-19854','BlockBox','',3),(19857,'120526','deals-mobile','block-19856','Html_box','',1),(19858,'120527','deals-mobile','block-19856','Blog\\widget\\PostLinkedProducts','',2),(19859,'120528','deals-mobile','block-19854','BlockBox','',1),(19860,'120529','deals-mobile','block-19859','Blog\\widget\\PostTitle','',3),(19861,'120530','deals-mobile','block-19859','Blog\\widget\\PostImage','',1),(19862,'120531','deals-mobile','block-19859','Blog\\widget\\PostDescription','',4),(19863,'120532','deals-mobile','block-19859','BlockBox','',5),(19864,'120533','deals-mobile','block-19863','Blog\\widget\\PostViewed','',1),(19865,'120534','deals-mobile','block-19859','Blog\\widget\\PostDate','',2),(19866,'120535','deals-mobile','block-19854-2','WidgetsAria','',1),(19867,'120536','deals-mobile','tl_blog_tags','BlockBox','',1),(19868,'120537','deals-mobile','block-19867','BlockBox','',1),(19869,'120538','deals-mobile','block-19868','BlockBox','',1),(19870,'120539','deals-mobile','block-19869','Blog\\widget\\PostListing','',1),(19871,'120540','deals-mobile','block-19869','catalog\\Paging','',2),(19872,'120541','deals-mobile','block-19868-2','WidgetsAria','',1),(19873,'120542','deals-mobile','tracking_numbers','BlockBox','',1),(19874,'120543','deals-mobile','block-19873','account\\OrderTracking','',2),(19875,'120544','deals-mobile','block-19873','Html_box','',1),(19876,'120545','deals-mobile','trade_form','BlockBox','',1),(19877,'120546','deals-mobile','block-19876','BlockBox','',3),(19878,'120547','deals-mobile','block-19877','BlockBox','',1),(19879,'120548','deals-mobile','block-19878','account\\CustomerAdditionalField','',2),(19880,'120549','deals-mobile','block-19878','account\\CustomerAdditionalField','',1),(19881,'120550','deals-mobile','block-19876','BlockBox','',14),(19882,'120551','deals-mobile','block-19881','account\\BackButton','',1),(19883,'120552','deals-mobile','block-19881-2','account\\PdfButton','',2),(19884,'120553','deals-mobile','block-19881-2','account\\SaveButton','',1),(19885,'120554','deals-mobile','block-19876','BlockBox','',13),(19886,'120555','deals-mobile','block-19885','BlockBox','',1),(19887,'120556','deals-mobile','block-19886','account\\CustomerAdditionalField','',1),(19888,'120557','deals-mobile','block-19885-2','BlockBox','',1),(19889,'120558','deals-mobile','block-19888','account\\CustomerAdditionalField','',1),(19890,'120559','deals-mobile','block-19876','Html_box','',10),(19891,'120560','deals-mobile','block-19876','Html_box','',8),(19892,'120561','deals-mobile','block-19876','Html_box','',12),(19893,'120562','deals-mobile','block-19876','BlockBox','',11),(19894,'120563','deals-mobile','block-19893','BlockBox','',1),(19895,'120564','deals-mobile','block-19894','account\\CustomerAdditionalField','',4),(19896,'120565','deals-mobile','block-19894','account\\CustomerAdditionalField','',2),(19897,'120566','deals-mobile','block-19894','Html_box','',1),(19898,'120567','deals-mobile','block-19894','account\\CustomerAdditionalField','',3),(19899,'120568','deals-mobile','block-19893-2','BlockBox','',1),(19900,'120569','deals-mobile','block-19899','Html_box','',1),(19901,'120570','deals-mobile','block-19899','account\\CustomerAdditionalField','',3),(19902,'120571','deals-mobile','block-19899','account\\CustomerAdditionalField','',2),(19903,'120572','deals-mobile','block-19899','account\\CustomerAdditionalField','',4),(19904,'120573','deals-mobile','block-19876','BlockBox','',5),(19905,'120574','deals-mobile','block-19904','BlockBox','',1),(19906,'120575','deals-mobile','block-19905','account\\CustomerAdditionalField','',2),(19907,'120576','deals-mobile','block-19905','account\\CustomerAdditionalField','',1),(19908,'120577','deals-mobile','block-19876','BlockBox','',4),(19909,'120578','deals-mobile','block-19908','BlockBox','',1),(19910,'120579','deals-mobile','block-19909','account\\AddressesList','',2),(19911,'120580','deals-mobile','block-19909','Html_box','',1),(19912,'120581','deals-mobile','block-19909','account\\CustomerAdditionalField','',5),(19913,'120582','deals-mobile','block-19909','BlockBox','',3),(19914,'120583','deals-mobile','block-19913','account\\CustomerAdditionalField','',1),(19915,'120584','deals-mobile','block-19909','BlockBox','',4),(19916,'120585','deals-mobile','block-19915','BlockBox','',1),(19917,'120586','deals-mobile','block-19916','account\\CustomerAdditionalField','',1),(19918,'120587','deals-mobile','block-19916','account\\CustomerAdditionalField','',4),(19919,'120588','deals-mobile','block-19916','account\\CustomerAdditionalField','',2),(19920,'120589','deals-mobile','block-19916','account\\CustomerAdditionalField','',3),(19921,'120590','deals-mobile','block-19915-2','BlockBox','',1),(19922,'120591','deals-mobile','block-19921','account\\CustomerAdditionalField','',4),(19923,'120592','deals-mobile','block-19921','account\\CustomerAdditionalField','',3),(19924,'120593','deals-mobile','block-19921','account\\CustomerAdditionalField','',2),(19925,'120594','deals-mobile','block-19921','account\\CustomerAdditionalField','',1),(19926,'120595','deals-mobile','block-19908-2','BlockBox','',1),(19927,'120596','deals-mobile','block-19926','account\\AddressesList','',2),(19928,'120597','deals-mobile','block-19926','BlockBox','',3),(19929,'120598','deals-mobile','block-19928','BlockBox','',1),(19930,'120599','deals-mobile','block-19929','account\\CustomerAdditionalField','',1),(19931,'120600','deals-mobile','block-19929','account\\CustomerAdditionalField','',2),(19932,'120601','deals-mobile','block-19928-2','BlockBox','',1),(19933,'120602','deals-mobile','block-19932','account\\CustomerAdditionalField','',1),(19934,'120603','deals-mobile','block-19926','BlockBox','',4),(19935,'120604','deals-mobile','block-19934','BlockBox','',1),(19936,'120605','deals-mobile','block-19935','account\\CustomerAdditionalField','',2),(19937,'120606','deals-mobile','block-19935','account\\CustomerAdditionalField','',1),(19938,'120607','deals-mobile','block-19935','account\\CustomerAdditionalField','',3),(19939,'120608','deals-mobile','block-19934-2','BlockBox','',1),(19940,'120609','deals-mobile','block-19939','account\\CustomerAdditionalField','',2),(19941,'120610','deals-mobile','block-19939','account\\CustomerAdditionalField','',1),(19942,'120611','deals-mobile','block-19939','account\\CustomerAdditionalField','',3),(19943,'120612','deals-mobile','block-19926','Html_box','',1),(19944,'120613','deals-mobile','block-19876','BlockBox','',9),(19945,'120614','deals-mobile','block-19944','BlockBox','',1),(19946,'120615','deals-mobile','block-19945','account\\CustomerAdditionalField','',1),(19947,'120616','deals-mobile','block-19945','account\\CustomerAdditionalField','',2),(19948,'120617','deals-mobile','block-19944-2','BlockBox','',1),(19949,'120618','deals-mobile','block-19948','account\\CustomerAdditionalField','',1),(19950,'120619','deals-mobile','block-19876','Html_box','',2),(19951,'120620','deals-mobile','block-19876','BlockBox','',7),(19952,'120621','deals-mobile','block-19951','BlockBox','',1),(19953,'120622','deals-mobile','block-19952','account\\CustomerAdditionalField','',1),(19954,'120623','deals-mobile','block-19952','account\\CustomerAdditionalField','',2),(19955,'120624','deals-mobile','block-19951-2','BlockBox','',1),(19956,'120625','deals-mobile','block-19955','account\\CustomerAdditionalField','',1),(19957,'120626','deals-mobile','block-19955','account\\CustomerAdditionalField','',2),(19958,'120627','deals-mobile','block-19876','Html_box','',1),(19959,'120628','deals-mobile','block-19876','Html_box','',6),(19960,'120629','deals-mobile','trade_form_pdf','BlockBox','',1),(19961,'120630','deals-mobile','block-19960','BlockBox','',14),(19962,'120631','deals-mobile','block-19961','Html_box','',1),(19963,'120632','deals-mobile','block-19961-2','account\\CustomerAdditionalField','',1),(19964,'120633','deals-mobile','block-19960','BlockBox','',6),(19965,'120634','deals-mobile','block-19964','Html_box','',1),(19966,'120635','deals-mobile','block-19964-2','account\\CombinedField','',2),(19967,'120636','deals-mobile','block-19960','BlockBox','',13),(19968,'120637','deals-mobile','block-19967','Html_box','',1),(19969,'120638','deals-mobile','block-19967-2','account\\CustomerAdditionalField','',1),(19970,'120639','deals-mobile','block-19960','BlockBox','',12),(19971,'120640','deals-mobile','block-19970','Html_box','',1),(19972,'120641','deals-mobile','block-19970-2','account\\CombinedField','',2),(19973,'120642','deals-mobile','block-19960','BlockBox','',11),(19974,'120643','deals-mobile','block-19973','Html_box','',1),(19975,'120644','deals-mobile','block-19973-2','account\\CombinedField','',1),(19976,'120645','deals-mobile','block-19960','BlockBox','',9),(19977,'120646','deals-mobile','block-19976','Html_box','',1),(19978,'120647','deals-mobile','block-19976-2','account\\CustomerAdditionalField','',1),(19979,'120648','deals-mobile','block-19960','BlockBox','',8),(19980,'120649','deals-mobile','block-19979','Html_box','',1),(19981,'120650','deals-mobile','block-19979-2','BlockBox','',1),(19982,'120651','deals-mobile','block-19981','account\\CustomerAdditionalField','',1),(19983,'120652','deals-mobile','block-19981-2','BlockBox','',1),(19984,'120653','deals-mobile','block-19983','Html_box','',2),(19985,'120654','deals-mobile','block-19983-2','account\\CustomerAdditionalField','',1),(19986,'120655','deals-mobile','block-19960','BlockBox','',3),(19987,'120656','deals-mobile','block-19986','Html_box','',1),(19988,'120657','deals-mobile','block-19960','BlockBox','',1),(19989,'120658','deals-mobile','block-19988','Contacts','',1),(19990,'120659','deals-mobile','block-19988-2','Html_box','',1),(19991,'120660','deals-mobile','block-19960','BlockBox','',4),(19992,'120661','deals-mobile','block-19991-2','BlockBox','',1),(19993,'120662','deals-mobile','block-19992','BlockBox','',1),(19994,'120663','deals-mobile','block-19993','Html_box','',2),(19995,'120664','deals-mobile','block-19993-2','account\\CustomerAdditionalField','',1),(19996,'120665','deals-mobile','block-19992-2','BlockBox','',1),(19997,'120666','deals-mobile','block-19996','Html_box','',1),(19998,'120667','deals-mobile','block-19996-2','account\\CustomerAdditionalField','',1),(19999,'120668','deals-mobile','block-19960','BlockBox','',2),(20000,'120669','deals-mobile','block-19999','Contacts','',1),(20001,'120670','deals-mobile','block-19960','BlockBox','',7),(20002,'120671','deals-mobile','block-20001','Html_box','',1),(20003,'120672','deals-mobile','block-20001-2','account\\CustomerAdditionalField','',1),(20004,'120673','deals-mobile','block-19960','BlockBox','',5),(20005,'120674','deals-mobile','block-20004','Html_box','',1),(20006,'120675','deals-mobile','block-20004-2','account\\CustomerAdditionalField','',1),(20007,'120676','deals-mobile','block-19960','BlockBox','',10),(20008,'120677','deals-mobile','block-20007','Html_box','',1),(20009,'120678','deals-mobile','block-20007-2','account\\CustomerAdditionalField','',1),(20010,'120679','deals-mobile','block-19960','BlockBox','',18),(20011,'120680','deals-mobile','block-20010','Html_box','',1),(20012,'120681','deals-mobile','block-20010-2','account\\CustomerAdditionalField','',1),(20013,'120682','deals-mobile','block-19960','BlockBox','',15),(20014,'120683','deals-mobile','block-20013','Html_box','',1),(20015,'120684','deals-mobile','block-19960','BlockBox','',17),(20016,'120685','deals-mobile','block-20015','Html_box','',1),(20017,'120686','deals-mobile','block-19960','BlockBox','',20),(20018,'120687','deals-mobile','block-20017','Html_box','',1),(20019,'120688','deals-mobile','block-20017-2','account\\CustomerAdditionalField','',1),(20020,'120689','deals-mobile','block-19960','BlockBox','',19),(20021,'120690','deals-mobile','block-20020','Html_box','',1),(20022,'120691','deals-mobile','block-20020-2','account\\CustomerAdditionalField','',1),(20023,'120692','deals-mobile','block-19960','BlockBox','',16),(20024,'120693','deals-mobile','block-20023','Html_box','',1),(20025,'120694','deals-mobile','block-20023-2','BlockBox','',1),(20026,'120695','deals-mobile','block-20025','account\\CustomerAdditionalField','',1),(20027,'120696','deals-mobile','block-20025-2','Html_box','',1),(20028,'120697','deals-mobile','block-20025-3','account\\CustomerAdditionalField','',1),(20029,'120698','deals-mobile','block-20023-3','BlockBox','',1),(20030,'120699','deals-mobile','block-19960','BlockBox','',23),(20031,'120700','deals-mobile','block-20030','Html_box','',1),(20032,'120701','deals-mobile','block-20030-2','account\\CustomerAdditionalField','',1),(20033,'120702','deals-mobile','block-19960','BlockBox','',21),(20034,'120703','deals-mobile','block-20033','Html_box','',1),(20035,'120704','deals-mobile','block-19960','BlockBox','',26),(20036,'120705','deals-mobile','block-20035','Html_box','',1),(20037,'120706','deals-mobile','block-19960','BlockBox','',24),(20038,'120707','deals-mobile','block-20037','Html_box','',1),(20039,'120708','deals-mobile','block-20037-2','account\\CustomerAdditionalField','',1),(20040,'120709','deals-mobile','block-19960','BlockBox','',25),(20041,'120710','deals-mobile','block-20040','Html_box','',1),(20042,'120711','deals-mobile','block-19960','BlockBox','',22),(20043,'120712','deals-mobile','block-20042','Html_box','',1),(20044,'120713','deals-mobile','block-20042-2','account\\CustomerAdditionalField','',1),(20045,'120714','deals-mobile','block-19960','BlockBox','',27),(20046,'120715','deals-mobile','block-20045','Html_box','',1),(20047,'120716','deals-mobile','block-20045-2','Html_box','',1),(20048,'120717','deals-mobile','block-20045-3','Html_box','',1),(20049,'120718','deals-mobile','block-20045-4','Html_box','',1),(20050,'120719','deals-mobile','block-19960','BlockBox','',28),(20051,'120720','deals-mobile','block-20050','Html_box','',1),(20052,'120721','deals-mobile','block-20050-2','account\\CustomerAdditionalField','',1),(20053,'120722','deals-mobile','block-20050-3','Html_box','',1),(20054,'120723','deals-mobile','block-20050-4','account\\CustomerAdditionalField','',1),(20055,'120724','deals-mobile','block-19960','BlockBox','',29),(20056,'120725','deals-mobile','block-20055','Html_box','',1),(20057,'120726','deals-mobile','unsubscribed','BlockBox','',1),(20058,'120727','deals-mobile','block-20057','Html_box','',1),(20059,'120728','deals-mobile','update-and-pay-order_confirmation','BlockBox','',1),(20060,'120729','deals-mobile','block-20059','BlockBox','',3),(20061,'120730','deals-mobile','block-20060','BlockBox','',1),(20062,'120731','deals-mobile','block-20061','BlockBox','',1),(20063,'120732','deals-mobile','block-20062','BlockBox','',1),(20064,'120733','deals-mobile','block-20063','Html_box','',4),(20065,'120734','deals-mobile','block-20063','Html_box','',2),(20066,'120735','deals-mobile','block-20063','Html_box','',1),(20067,'120736','deals-mobile','block-20063','order\\ShippingMethod','',5),(20068,'120737','deals-mobile','block-20063','order\\DeliveryAddress','',3),(20069,'120738','deals-mobile','block-20063','order\\Telephone','',8),(20070,'120739','deals-mobile','block-20063','order\\Email','',9),(20071,'120740','deals-mobile','block-20063','order\\Name','',7),(20072,'120741','deals-mobile','block-20063','Html_box','',6),(20073,'120742','deals-mobile','block-20062-2','BlockBox','',1),(20074,'120743','deals-mobile','block-20073','order\\BillingAddress','',3),(20075,'120744','deals-mobile','block-20073','UpdateAndPay\\PayConfirm','',5),(20076,'120745','deals-mobile','block-20073','Html_box','',1),(20077,'120746','deals-mobile','block-20073','Html_box','',2),(20078,'120747','deals-mobile','block-20073','Html_box','',4),(20079,'120748','deals-mobile','block-20061','BlockBox','',3),(20080,'120749','deals-mobile','block-20079','order\\Products','',2),(20081,'120750','deals-mobile','block-20079','Html_box','',1),(20082,'120751','deals-mobile','block-20060-2','BlockBox','',1),(20083,'120752','deals-mobile','block-20082','Html_box','',1),(20084,'120753','deals-mobile','block-20082','checkout\\ContinueBtn','',3),(20085,'120754','deals-mobile','block-20082','order\\Totals','',2),(20086,'120755','deals-mobile','block-20059','account\\OrderHeading','',1),(20087,'120756','deals-mobile','update-and-pay-order_pay','BlockBox','',1),(20088,'120757','deals-mobile','block-20087','BlockBox','',3),(20089,'120758','deals-mobile','block-20088','BlockBox','',1),(20090,'120759','deals-mobile','block-20089','BlockBox','',3),(20091,'120760','deals-mobile','block-20090','Html_box','',1),(20092,'120761','deals-mobile','block-20090','order\\Products','',2),(20093,'120762','deals-mobile','block-20089','BlockBox','',1),(20094,'120763','deals-mobile','block-20093','BlockBox','',1),(20095,'120764','deals-mobile','block-20094','order\\Name','',7),(20096,'120765','deals-mobile','block-20094','order\\Email','',9),(20097,'120766','deals-mobile','block-20094','order\\DeliveryAddress','',3),(20098,'120767','deals-mobile','block-20094','Html_box','',6),(20099,'120768','deals-mobile','block-20094','order\\Telephone','',8),(20100,'120769','deals-mobile','block-20094','Html_box','',2),(20101,'120770','deals-mobile','block-20094','order\\ShippingMethod','',5),(20102,'120771','deals-mobile','block-20094','Html_box','',4),(20103,'120772','deals-mobile','block-20094','Html_box','',1),(20104,'120773','deals-mobile','block-20093-2','BlockBox','',1),(20105,'120774','deals-mobile','block-20104','Html_box','',2),(20106,'120775','deals-mobile','block-20104','Html_box','',1),(20107,'120776','deals-mobile','block-20104','Html_box','',4),(20108,'120777','deals-mobile','block-20104','order\\BillingAddress','',3),(20109,'120778','deals-mobile','block-20104','UpdateAndPay\\PayForm','',5),(20110,'120779','deals-mobile','block-20088-2','BlockBox','',1),(20111,'120780','deals-mobile','block-20110','order\\Totals','',2),(20112,'120781','deals-mobile','block-20110','Html_box','',1),(20113,'120782','deals-mobile','block-20110','checkout\\ContinueBtn','',3),(20114,'120783','deals-mobile','block-20087','account\\OrderHeading','',1),(20115,'120784','deals-mobile','wedding_index','BlockBox','',1),(20116,'120785','deals-mobile','block-20115','BlockBox','',1),(20117,'120786','deals-mobile','block-20116','WeddingRegistry\\widgets\\ViewCreateRegistryWidget','',2),(20118,'120787','deals-mobile','block-20116','WeddingRegistry\\widgets\\SearchRegistryButton','',3),(20119,'120788','deals-mobile','block-20116','Heading','',1),(20120,'120789','deals-mobile','wedding_manage','BlockBox','',2),(20121,'120790','deals-mobile','block-20120','WeddingRegistry\\widgets\\Photos','',1),(20122,'120791','deals-mobile','block-20120-2','WeddingRegistry\\widgets\\ManageNames','',1),(20123,'120792','deals-mobile','block-20120-2','BlockBox','',3),(20124,'120793','deals-mobile','block-20123','WeddingRegistry\\widgets\\EditLink','',1),(20125,'120794','deals-mobile','block-20123','WeddingRegistry\\widgets\\DeleteLink','',2),(20126,'120795','deals-mobile','block-20123','WeddingRegistry\\widgets\\ShareLink','',3),(20127,'120796','deals-mobile','block-20120-2','WeddingRegistry\\widgets\\ManageDate','',2),(20128,'120797','deals-mobile','block-20120-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(20129,'120798','deals-mobile','wedding_manage','WeddingRegistry\\widgets\\ManageBanner','',1),(20130,'120799','deals-mobile','wedding_manage','WeddingRegistry\\widgets\\AddItemsLink','',3),(20131,'120800','deals-mobile','wedding_manage','WeddingRegistry\\widgets\\Products','',4),(20135,'120804','deals-mobile','wedding_search','BlockBox','',1),(20136,'120805','deals-mobile','block-20135','WeddingRegistry\\widgets\\SearchList','',2),(20137,'120806','deals-mobile','block-20135','WeddingRegistry\\widgets\\SearchPaging','',3),(20138,'120807','deals-mobile','block-20135','BlockBox','',1),(20139,'120808','deals-mobile','block-20138','BlockBox','',1),(20140,'120809','deals-mobile','block-20139','WeddingRegistry\\widgets\\SearchForm','',2),(20141,'120810','deals-mobile','block-20139','Html_box','',1),(20142,'120811','deals-mobile','wedding_share','BlockBox','',1),(20143,'120812','deals-mobile','block-20142','BlockBox','',4),(20144,'120813','deals-mobile','block-20143-2','Html_box','',3),(20145,'120814','deals-mobile','block-20143-2','Html_box','',1),(20146,'120815','deals-mobile','block-20143-2','WeddingRegistry\\widgets\\ShareUrl','',2),(20147,'120816','deals-mobile','block-20143-2','WeddingRegistry\\widgets\\InviteList','',4),(20148,'120817','deals-mobile','block-20142','WeddingRegistry\\widgets\\ManageBanner','',1),(20149,'120818','deals-mobile','block-20142','WeddingRegistry\\widgets\\Photos','',2),(20150,'120819','deals-mobile','block-20142','Html_box','',3),(20151,'120820','deals-mobile','wedding_success','Html_box','',1),(20152,'120821','deals-mobile','wedding_success','WeddingRegistry\\widgets\\BackButton','',2),(20153,'120822','deals-mobile','wedding_update','BlockBox','',2),(20154,'120823','deals-mobile','block-20153','BlockBox','',1),(20155,'120824','deals-mobile','block-20154','Html_box','',5),(20156,'120825','deals-mobile','block-20154','Html_box','',3),(20157,'120826','deals-mobile','block-20154','WeddingRegistry\\widgets\\Details','',4),(20158,'120827','deals-mobile','block-20154','WeddingRegistry\\widgets\\Names','',2),(20159,'120828','deals-mobile','block-20154','Html_box','',1),(20160,'120829','deals-mobile','block-20154','WeddingRegistry\\widgets\\ShareRegistry','',6),(20161,'120830','deals-mobile','block-20153-2','BlockBox','',1),(20162,'120831','deals-mobile','block-20161','WeddingRegistry\\widgets\\ShippingDetails','',2),(20163,'120832','deals-mobile','block-20161','Html_box','',1),(20164,'120833','deals-mobile','block-20161','Html_box','',5),(20165,'120834','deals-mobile','block-20161','WeddingRegistry\\widgets\\Photos','',6),(20166,'120835','deals-mobile','block-20161','Html_box','',3),(20167,'120836','deals-mobile','block-20161','WeddingRegistry\\widgets\\InformationText','',4),(20168,'120837','deals-mobile','wedding_update','Html_box','',1),(20169,'120838','deals-mobile','wedding_update','BlockBox','',3),(20170,'120839','deals-mobile','block-20169','WeddingRegistry\\widgets\\BackButton','',1),(20171,'120840','deals-mobile','block-20169-2','WeddingRegistry\\widgets\\SaveButton','',1),(20172,'120841','deals-mobile','wedding_view','WeddingRegistry\\widgets\\ManageBanner','',1),(20173,'120842','deals-mobile','wedding_view','BlockBox','',2),(20174,'120843','deals-mobile','block-20173','WeddingRegistry\\widgets\\Photos','',1),(20175,'120844','deals-mobile','block-20173-2','WeddingRegistry\\widgets\\ManageDate','',2),(20176,'120845','deals-mobile','block-20173-2','WeddingRegistry\\widgets\\ManageNames','',1),(20177,'120846','deals-mobile','block-20173-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(20178,'120847','deals-mobile','wedding_view','WeddingRegistry\\widgets\\Products','',6),(20179,'120848','deals-mobile','wishlist','BlockBox','',1),(20180,'120849','deals-mobile','block-20179','BlockBox','',1),(20181,'120850','deals-mobile','block-20180','WidgetsAria','',1),(20182,'120851','deals-mobile','block-20180-2','Html_box','',1),(20183,'120852','deals-mobile','block-20180-2','account\\Wishlist','',2),(20184,'120853','deals-mobile','wishlist-cart','BlockBox','',1),(20185,'120854','deals-mobile','block-20184','cart\\CartTabs','',1),(20186,'120855','deals-mobile','block-20185','account\\Wishlist','',1),(31803,'1683128325.0836','watch-mobile','block-31791','BlockBox',NULL,1),(36640,'1693578529.207944','watch-mobile','checkout','BlockBox','',1),(36641,'1693578529.311699','watch-mobile','block-36640','BlockBox','',2),(36642,'1693578529.313831','watch-mobile','block-36641','BlockBox','',2),(36643,'1693578529.315461','watch-mobile','block-36642','BlockBox','',5),(36644,'1693578529.317368','watch-mobile','block-36643','checkout\\Comments','',2),(36645,'1693578529.319136','watch-mobile','block-36643','Html_box','',1),(36646,'1693578529.322437','watch-mobile','block-36642','BlockBox','',4),(36647,'1693578529.324468','watch-mobile','block-36646','Html_box','',1),(36648,'1693578529.325521','watch-mobile','block-36646','BlockBox','',2),(36649,'1693578529.326795','watch-mobile','block-36648','CouponsAndVauchers\\Checkout','',1),(36650,'1693578529.329372','watch-mobile','block-36648-2','checkout\\CreditAmount','',1),(36651,'1693578529.331582','watch-mobile','block-36648-2','checkout\\BonusPoints','',2),(36652,'1693578529.333680','watch-mobile','block-36642','BlockBox','',2),(36653,'1693578529.335514','watch-mobile','block-36652','BlockBox','',3),(36654,'1693578529.337997','watch-mobile','block-36653','checkout\\ShippingChoice','',1),(36655,'1693578529.34334','watch-mobile','block-36652','Neighbour\\Checkout','',5),(36656,'1693578529.345418','watch-mobile','block-36652','BlockBox','',4),(36657,'1693578529.346757','watch-mobile','block-36656','BlockBox','',1),(36658,'1693578529.348387','watch-mobile','block-36657','checkout\\ShippingAddress','',2),(36659,'1693578529.351498','watch-mobile','block-36657','Html_box','',3),(36660,'1693578529.352777','watch-mobile','block-36657','checkout\\ContactInformation','',4),(36661,'1693578529.354142','watch-mobile','block-36657','UploadCustomerId\\UploadCustomerIdForm','',4),(36662,'1693578529.357732','watch-mobile','block-36656-2','BlockBox','',1),(36663,'1693578529.359364','watch-mobile','block-36662','checkout\\Shipping','',2),(36664,'1693578529.360426','watch-mobile','block-36662','DelayedDespatch\\Checkout','',3),(36665,'1693578529.361979','watch-mobile','block-36662','Html_box','',1),(36666,'1693578529.363439','watch-mobile','block-36652','Html_box','',2),(36667,'1693578529.364794','watch-mobile','block-36642','cart\\Products','',6),(36668,'1693578529.368484','watch-mobile','block-36642','checkout\\CreateAccount','',7),(36669,'1693578529.371247','watch-mobile','block-36642','BlockBox','',3),(36670,'1693578529.373462','watch-mobile','block-36669','Html_box','',1),(36671,'1693578529.374453','watch-mobile','block-36669','BlockBox','',2),(36672,'1693578529.375760','watch-mobile','block-36671','Html_box','',1),(36673,'1693578529.376655','watch-mobile','block-36671','checkout\\BillingAddress','',2),(36674,'1693578529.380694','watch-mobile','block-36671-2','BlockBox','',1),(36675,'1693578529.382181','watch-mobile','block-36674','checkout\\PaymentMethod','',2),(36676,'1693578529.383416','watch-mobile','block-36674','Html_box','',1),(36677,'1693578529.384233','watch-mobile','block-36642','BlockBox','',1),(36678,'1693578529.385877','watch-mobile','block-36677','checkout\\LoginOnForm','',0),(36679,'1693578529.387150','watch-mobile','block-36677','BlockBox','',1),(36680,'1693578529.387946','watch-mobile','block-36641-2','BlockBox','',1),(36681,'1693578529.434121','watch-mobile','block-36680','Html_box','',6),(36682,'1693578529.436482','watch-mobile','block-36680','Html_box','',1),(36683,'1693578529.437493','watch-mobile','block-36680','checkout\\Terms','',5),(36684,'1693578529.439185','watch-mobile','block-36680','checkout\\Totals','',3),(36685,'1693578529.439920','watch-mobile','block-36680','checkout\\ContinueBtn','',4),(36686,'1693578529.442458','watch-mobile','block-36680','cart\\Products','',2),(53913,'116005','furniture-mobile','404','Html_box','',1),(54010,'116102','furniture-mobile','account','BlockBox','',1),(54011,'116103','furniture-mobile','block-54010','BlockBox','',1),(54012,'116104','furniture-mobile','block-54011','WidgetsAria','',1),(54032,'116105','furniture-mobile','block-54011-2','account\\OrdersHistory','',5),(54033,'116106','furniture-mobile','block-54011-2','Html_box','',4),(54034,'116109','furniture-mobile','block-54011-2','Html_box','',1),(54035,'116112','furniture-mobile','block-54011-2','BlockBox','',2),(54036,'116113','furniture-mobile','block-54035','Html_box','',1),(54037,'116114','furniture-mobile','block-54035','account\\LastOrder','',2),(54038,'116115','furniture-mobile','block-54035-2','Html_box','',1),(54039,'116116','furniture-mobile','block-54035-2','account\\OrderCount','',2),(54040,'116117','furniture-mobile','block-54035-2','account\\AccountLink','',3),(54041,'116118','furniture-mobile','block-54035-3','Html_box','',1),(54042,'116119','furniture-mobile','block-54035-3','account\\TotalOrdered','',2),(54043,'116120','furniture-mobile','block-54035-4','Html_box','',1),(54044,'116121','furniture-mobile','block-54035-4','account\\CreditAmount','',2),(54045,'116122','furniture-mobile','block-54035-4','account\\AccountLink','',3),(54046,'116123','furniture-mobile','block-54035-5','account\\AccountLink','',3),(54047,'116124','furniture-mobile','block-54035-5','account\\PointsEarnt','',2),(54048,'116125','furniture-mobile','block-54035-5','Html_box','',1),(54049,'1639675618.1808','furniture-mobile','block-54011-2','Rma\\PrintReturn','',7),(54050,'1640098458.6988','furniture-mobile','block-54011-2','account\\SpendBalance','',3),(54070,'116145','furniture-mobile','account_edit','BlockBox','',1),(54071,'116146','furniture-mobile','block-54070','BlockBox','',1),(54072,'116147','furniture-mobile','block-54071','WidgetsAria','',1),(54092,'116148','furniture-mobile','block-54071-2','account\\AccountEdit','',2),(54093,'116149','furniture-mobile','block-54071-2','Html_box','',1),(54094,'116150','furniture-mobile','address_book','BlockBox','',1),(54095,'116151','furniture-mobile','block-54094','BlockBox','',1),(54096,'116152','furniture-mobile','block-54095','WidgetsAria','',1),(54116,'116153','furniture-mobile','block-54095-2','account\\AddressBook','',3),(54117,'116154','furniture-mobile','block-54095-2','Html_box','',1),(54118,'116155','furniture-mobile','block-54095-2','Html_box','',2),(54119,'116156','furniture-mobile','address_book_process','BlockBox','',1),(54120,'116157','furniture-mobile','block-54119','BlockBox','',1),(54121,'116158','furniture-mobile','block-54120','WidgetsAria','',1),(54141,'116159','furniture-mobile','block-54120-2','Html_box','',1),(54142,'116160','furniture-mobile','block-54120-2','account\\EditAddress','',2),(54143,'117906.000001','furniture-mobile','b2b','BlockBox','listing-item',1),(54144,'117907.000001','furniture-mobile','block-54143','BlockBox','',2),(54145,'117908.000001','furniture-mobile','block-54144','BlockBox','',2),(54146,'117909.000001','furniture-mobile','block-54145','productListing\\bonusPoints','',2),(54147,'117910.000001','furniture-mobile','block-54145','productListing\\image','',1),(54148,'117914.000001','furniture-mobile','block-54145-2','productListing\\name','',1),(54149,'117915.000001','furniture-mobile','block-54145-2','productListing\\description','',2),(54150,'117916.000001','furniture-mobile','block-54145-2','productListing\\model','',4),(54151,'117917.000001','furniture-mobile','block-54145-2','productListing\\attributes','',5),(54152,'120922.000001','furniture-mobile','block-54145-2','productListing\\properties','',3),(54153,'117918.000001','furniture-mobile','block-54144-2','BlockBox','',1),(54154,'117911.000001','furniture-mobile','block-54153','BlockBox','',3),(54155,'117912.000001','furniture-mobile','block-54154','productListing\\rating','',1),(54156,'117913.000001','furniture-mobile','block-54154','productListing\\ratingCounts','',2),(54157,'117919.000001','furniture-mobile','block-54153','productListing\\qtyInput','',4),(54158,'117920.000001','furniture-mobile','block-54153','productListing\\price','',2),(54159,'117922.000001','furniture-mobile','block-54153','productListing\\buyButton','',5),(54160,'117924.000001','furniture-mobile','block-54153','productListing\\stock','',1),(54161,'120924.000001','furniture-mobile','block-54153','BlockBox','',8),(54162,'120925.000001','furniture-mobile','block-54161','productListing\\compare','',3),(54163,'120926.000001','furniture-mobile','block-54161','productListing\\personalCatalog','',2),(54164,'120927.000001','furniture-mobile','block-54161','productListing\\viewButton','',1),(54165,'116176','furniture-mobile','batch','BlockBox','',1),(54166,'116177','furniture-mobile','block-54165','productListing\\attributes','',5),(54167,'116178','furniture-mobile','block-54165','productListing\\price','',6),(54168,'116179','furniture-mobile','block-54165','productListing\\name','',4),(54169,'116180','furniture-mobile','block-54165','productListing\\image','',2),(54170,'116181','furniture-mobile','block-54165','batchSelect','',1),(54171,'116182','furniture-mobile','batch_selected','BlockBox','',1),(54172,'116183','furniture-mobile','block-54171','BlockBox','',13),(54173,'116184','furniture-mobile','block-54172','productListing\\image','',1),(54174,'116185','furniture-mobile','block-54172-2','batchRemove','',1),(54175,'116186','furniture-mobile','block-54172-2','productListing\\price','',3),(54176,'116187','furniture-mobile','block-54172-2','productListing\\name','',2),(54177,'116188','furniture-mobile','bbbbb','BlockBox','',1),(54178,'116189','furniture-mobile','block-54177','BlockBox','',2),(54179,'116190','furniture-mobile','block-54178','Filters','',1),(54180,'116191','furniture-mobile','block-54178-2','BlockBox','',6),(54181,'116192','furniture-mobile','block-54180','catalog\\CountsItems','',1),(54182,'116193','furniture-mobile','block-54180-2','catalog\\Paging','',1),(54183,'116194','furniture-mobile','block-54178-2','catalog\\Image','',1),(54184,'116195','furniture-mobile','block-54178-2','Listing','',5),(54185,'116196','furniture-mobile','block-54178-2','catalog\\ImageMapCategory','',3),(54186,'116197','furniture-mobile','block-54178-2','BlockBox','',4),(54187,'116198','furniture-mobile','block-54186','catalog\\ListingLook','',1),(54188,'116199','furniture-mobile','block-54186','catalog\\CompareButton','',2),(54189,'116200','furniture-mobile','block-54186','catalog\\ItemsOnPage','',4),(54190,'116201','furniture-mobile','block-54186','catalog\\Sorting','',3),(54191,'116202','furniture-mobile','block-54178-2','Categories','',2),(54192,'116203','furniture-mobile','block-54177','catalog\\Title','',1),(54193,'116204','furniture-mobile','blog','BlockBox','',1),(54194,'116205','furniture-mobile','block-54193','BlockBox','',1),(54195,'116206','furniture-mobile','block-54194','BlogContent','',1),(54196,'116207','furniture-mobile','block-54194-2','BlogSidebar','',1),(54201,'1683110860.800967','furniture-mobile','cart','BlockBox','',1),(54202,'1683110860.811285','furniture-mobile','block-54201','BlockBox','',2),(54203,'1683110860.81452','furniture-mobile','block-54202','BlockBox','',4),(54204,'1683110860.815931','furniture-mobile','block-54203','Html_box','',1),(54205,'1683110860.818836','furniture-mobile','block-54203','cart\\UpSell','8',2),(54206,'1683110860.82112','furniture-mobile','block-54202','BlockBox','',1),(54207,'1683110860.82264','furniture-mobile','block-54206','cart\\Products','',4),(54208,'1683110860.823336','furniture-mobile','block-54206','BlockBox','',3),(54209,'1683110860.82490','furniture-mobile','block-54208','MultiCart\\CartSwitcher','',1),(54210,'1683110860.825674','furniture-mobile','block-54208','MultiCart\\SaveCart','',2),(54211,'1683110860.826797','furniture-mobile','block-54208-2','MultiCart\\Actions','',1),(54212,'1683110860.827896','furniture-mobile','block-54206','BlockBox','',5),(54213,'1683110860.829995','furniture-mobile','block-54212','cart\\DiscountCoupon','',1),(54214,'1683110860.830980','furniture-mobile','block-54212-2','cart\\BonusPoints','',3),(54215,'1683110860.831742','furniture-mobile','block-54212-2','cart\\CreditAmount','',2),(54216,'1683110860.83215','furniture-mobile','block-54212-3','cart\\FreeDelivery','',2),(54217,'1683110860.833430','furniture-mobile','block-54206','Html_box','',2),(54218,'1683110860.835461','furniture-mobile','block-54202','BlockBox','',3),(54219,'1683110860.837349','furniture-mobile','block-54218','cart\\GiveAway','',2),(54220,'1683110860.83786','furniture-mobile','block-54218','Html_box','',1),(54221,'1683110860.839462','furniture-mobile','block-54202','BlockBox','',5),(54222,'1683110860.841398','furniture-mobile','block-54221','Html_box','',1),(54223,'1683110860.84291','furniture-mobile','block-54221','cart\\ShippingEstimator','',2),(54224,'1683110860.843639','furniture-mobile','block-54202','cart\\DependedProducts','8',2),(54225,'1683110860.846971','furniture-mobile','block-54202-2','BlockBox','',1),(54226,'1683110860.849323','furniture-mobile','block-54225','BlockBox','',2),(54227,'1683110860.862447','furniture-mobile','block-54226','cart\\CheckoutBtn','',2),(54228,'1683110860.86420','furniture-mobile','block-54226','cart\\OrderTotal','',1),(54229,'1683110860.864695','furniture-mobile','block-54225','Html_box','',1),(54230,'116242','furniture-mobile','cart2','BlockBox','',2),(54231,'116243','furniture-mobile','block-54230','cart\\CartTabs','',2),(54232,'116244','furniture-mobile','block-54231','BlockBox','',1),(54233,'116245','furniture-mobile','block-54232','BlockBox','',4),(54234,'116246','furniture-mobile','block-54233','cart\\UpSell','6',2),(54235,'116247','furniture-mobile','block-54233','Html_box','',1),(54236,'116248','furniture-mobile','block-54232','BlockBox','',1),(54237,'116249','furniture-mobile','block-54236','cart\\Products','',3),(54238,'116250','furniture-mobile','block-54236','BlockBox','',2),(54239,'116251','furniture-mobile','block-54238','MultiCart\\CartSwitcher','',1),(54240,'116252','furniture-mobile','block-54238','MultiCart\\SaveCart','',2),(54241,'116253','furniture-mobile','block-54238-2','MultiCart\\Actions','',1),(54242,'116254','furniture-mobile','block-54232','BlockBox','',3),(54243,'116255','furniture-mobile','block-54242','cart\\GiveAway','',2),(54244,'116256','furniture-mobile','block-54242','Html_box','',1),(54245,'116257','furniture-mobile','block-54232','BlockBox','',2),(54246,'116258','furniture-mobile','block-54245','Html_box','',1),(54247,'116259','furniture-mobile','block-54245','BlockBox','',2),(54248,'116260','furniture-mobile','block-54247','cart\\DiscountCoupon','',1),(54249,'116261','furniture-mobile','block-54247-2','cart\\CreditAmount','',1),(54250,'116262','furniture-mobile','block-54247-3','cart\\BonusPoints','',1),(54251,'116263','furniture-mobile','block-54232','BlockBox','',5),(54252,'116264','furniture-mobile','block-54251','Html_box','',1),(54253,'116265','furniture-mobile','block-54251','cart\\ShippingEstimator','',2),(54254,'116266','furniture-mobile','block-54232-2','BlockBox','',1),(54255,'116267','furniture-mobile','block-54254','Html_box','',1),(54256,'116268','furniture-mobile','block-54254','BlockBox','',2),(54257,'116269','furniture-mobile','block-54256','Image','',4),(54258,'116270','furniture-mobile','block-54256','cart\\CheckoutBtn','',2),(54259,'116271','furniture-mobile','block-54256','cart\\OrderTotal','',1),(54270,'116272','furniture-mobile','categories','BlockBox','catalog-content',1),(54271,'116273','furniture-mobile','block-54270','BlockBox','',2),(54272,'116274','furniture-mobile','block-54271','Filters','',3),(54273,'1639749663.0229','furniture-mobile','block-54271','ShowInactive\\ShowInactive','',1),(54274,'116275','furniture-mobile','block-54271-2','Listing','',8),(54275,'116276','furniture-mobile','block-54271-2','catalog\\Image','',3),(54276,'116277','furniture-mobile','block-54271-2','BlockBox','',9),(54277,'116278','furniture-mobile','block-54276','catalog\\CountsItems','',1),(54278,'116279','furniture-mobile','block-54276-2','catalog\\Paging','',1),(54279,'116280','furniture-mobile','block-54271-2','catalog\\ImageMapCategory','',6),(54280,'116281','furniture-mobile','block-54271-2','Categories','',4),(54281,'116282','furniture-mobile','block-54271-2','BlockBox','catalog-features',7),(54282,'116283','furniture-mobile','block-54281','catalog\\ListingLook','',1),(54283,'116284','furniture-mobile','block-54281','catalog\\CompareButton','',2),(54284,'116285','furniture-mobile','block-54281','catalog\\ItemsOnPage','',4),(54285,'116286','furniture-mobile','block-54281','catalog\\Sorting','',3),(54286,'116287','furniture-mobile','block-54270','catalog\\Title','',1),(54287,'116288','furniture-mobile','category','Categories','',1),(54288,'116289','furniture-mobile','category','Listing','',4),(54289,'116290','furniture-mobile','category','ListingFunctionality','',2),(54290,'116291','furniture-mobile','category','PagingBar','',3),(54291,'116292','furniture-mobile','category','PagingBar','',5),(54292,'116293','furniture-mobile','category_2','BlockBox','',1),(54293,'116294','furniture-mobile','block-54292','catalog\\Title','',1),(54294,'116295','furniture-mobile','block-54292','BlockBox','',2),(54295,'116296','furniture-mobile','block-54294','Filters','',1),(54296,'116297','furniture-mobile','block-54294-2','catalog\\Image','',1),(54297,'116298','furniture-mobile','block-54294-2','Listing','',5),(54298,'116299','furniture-mobile','block-54294-2','BlockBox','',4),(54299,'116300','furniture-mobile','block-54298','catalog\\Sorting','',3),(54300,'116301','furniture-mobile','block-54298','catalog\\ItemsOnPage','',4),(54301,'116302','furniture-mobile','block-54298','catalog\\CompareButton','',2),(54302,'116303','furniture-mobile','block-54298','catalog\\ListingLook','',1),(54303,'116304','furniture-mobile','block-54294-2','catalog\\ImageMapCategory','',3),(54304,'116305','furniture-mobile','block-54294-2','Categories','',2),(54305,'116306','furniture-mobile','block-54294-2','BlockBox','',6),(54306,'116307','furniture-mobile','block-54305','catalog\\CountsItems','',1),(54307,'116308','furniture-mobile','block-54305-2','catalog\\Paging','',1),(54308,'116309','furniture-mobile','category_no_filters','BlockBox','catalog-content',1),(54309,'116310','furniture-mobile','block-54308','catalog\\Title','',1),(54310,'116311','furniture-mobile','block-54308','Categories','',3),(54311,'116312','furniture-mobile','block-54308','BlockBox','catalog-features',4),(54312,'116313','furniture-mobile','block-54311','catalog\\ItemsOnPage','',4),(54313,'116314','furniture-mobile','block-54311','catalog\\Sorting','',3),(54314,'116315','furniture-mobile','block-54311','catalog\\CompareButton','',2),(54315,'116316','furniture-mobile','block-54311','catalog\\ListingLook','',1),(54316,'116317','furniture-mobile','block-54311','HeaderStock','',5),(54317,'116318','furniture-mobile','block-54308','BlockBox','',6),(54318,'116319','furniture-mobile','block-54317','catalog\\CountsItems','',1),(54319,'116320','furniture-mobile','block-54317-2','catalog\\Paging','',1),(54320,'116321','furniture-mobile','block-54308','Listing','',5),(54321,'116322','furniture-mobile','block-54308','catalog\\Image','',2),(54322,'116323','furniture-mobile','block-54308','catalog\\B2bAddButton','',7),(54323,'1683112094.454335','furniture-mobile','checkout','BlockBox','',2),(54324,'1683112094.46510','furniture-mobile','block-54323','BlockBox','',2),(54325,'1683112094.466634','furniture-mobile','block-54324','BlockBox','',2),(54326,'1683112094.468254','furniture-mobile','block-54325','BlockBox','',5),(54327,'1683112094.470662','furniture-mobile','block-54326','checkout\\Comments','',2),(54328,'1683112094.473482','furniture-mobile','block-54326','Html_box','',1),(54329,'1683112094.477128','furniture-mobile','block-54325','BlockBox','',4),(54330,'1683112094.479689','furniture-mobile','block-54329','Html_box','',1),(54331,'1683112094.481499','furniture-mobile','block-54329','BlockBox','',2),(54332,'1683112094.482824','furniture-mobile','block-54331','CouponsAndVauchers\\Checkout','',1),(54333,'1683112094.484566','furniture-mobile','block-54331-2','checkout\\CreditAmount','',1),(54334,'1683112094.486280','furniture-mobile','block-54331-2','checkout\\BonusPoints','',2),(54335,'1683112094.487748','furniture-mobile','block-54325','BlockBox','',2),(54336,'1683112094.489595','furniture-mobile','block-54335','BlockBox','',3),(54337,'1683112094.491715','furniture-mobile','block-54336','checkout\\ShippingChoice','',1),(54338,'1683112094.49547','furniture-mobile','block-54335','Neighbour\\Checkout','',5),(54339,'1683112094.496940','furniture-mobile','block-54335','BlockBox','',4),(54340,'1683112094.498374','furniture-mobile','block-54339','BlockBox','',1),(54341,'1683112094.499910','furniture-mobile','block-54340','checkout\\ShippingAddress','',2),(54342,'1683112094.502626','furniture-mobile','block-54340','Html_box','',3),(54343,'1683112094.503954','furniture-mobile','block-54340','checkout\\ContactInformation','',4),(54344,'1683112094.505375','furniture-mobile','block-54340','UploadCustomerId\\UploadCustomerIdForm','',5),(54345,'1683112094.508236','furniture-mobile','block-54339-2','BlockBox','',1),(54346,'1683112094.509614','furniture-mobile','block-54345','checkout\\Shipping','',2),(54347,'1683112094.510627','furniture-mobile','block-54345','DelayedDespatch\\Checkout','',4),(54348,'1683112094.511898','furniture-mobile','block-54345','Html_box','',1),(54349,'1683112094.513380','furniture-mobile','block-54345','DeliveryDay','',3),(54350,'1683112094.516692','furniture-mobile','block-54345','checkout\\PoNumber','',6),(54351,'1683112094.518294','furniture-mobile','block-54335','Html_box','',2),(54352,'1683112094.5284','furniture-mobile','block-54325','BlockBox','',6),(54353,'1683112094.522685','furniture-mobile','block-54352','cart\\Products','',1),(54354,'1683112094.52788','furniture-mobile','block-54352','checkout\\CreateAccount','',2),(54355,'1683112094.530263','furniture-mobile','block-54352','DeliveryOptions\\Checkout','',0),(54356,'1683112094.532112','furniture-mobile','block-54325','BlockBox','',3),(54357,'1683112094.53526','furniture-mobile','block-54356','Html_box','',1),(54358,'1683112094.536687','furniture-mobile','block-54356','BlockBox','',2),(54359,'1683112094.53846','furniture-mobile','block-54358','Html_box','',1),(54360,'1683112094.539137','furniture-mobile','block-54358','checkout\\BillingAddress','',2),(54361,'1683112094.542437','furniture-mobile','block-54358-2','BlockBox','',1),(54362,'1683112094.543634','furniture-mobile','block-54361','checkout\\PaymentMethod','',2),(54363,'1683112094.544994','furniture-mobile','block-54361','Html_box','',1),(54364,'1683112094.546257','furniture-mobile','block-54325','BlockBox','',0),(54365,'1683112094.547713','furniture-mobile','block-54364','checkout\\LoginOnForm','',0),(54366,'1683112094.549336','furniture-mobile','block-54324-2','BlockBox','',1),(54367,'1683112094.554924','furniture-mobile','block-54366','Html_box','',5),(54368,'1683112094.556948','furniture-mobile','block-54366','Html_box','',1),(54369,'1683112094.558436','furniture-mobile','block-54366','checkout\\Terms','',4),(54370,'1683112094.560477','furniture-mobile','block-54366','checkout\\Totals','',2),(54371,'1683112094.561633','furniture-mobile','block-54366','checkout\\ContinueBtn','',3),(54372,'116368','furniture-mobile','checkout_confirmation','BlockBox','',1),(54373,'116369','furniture-mobile','block-54372','checkout\\Totals','',8),(54374,'116370','furniture-mobile','block-54372','Html_box','',5),(54375,'116371','furniture-mobile','block-54372','checkout\\EditBtn','',6),(54376,'116372','furniture-mobile','block-54372','BlockBox','',3),(54377,'116373','furniture-mobile','block-54376','BlockBox','',1),(54378,'116374','furniture-mobile','block-54377','Html_box','',1),(54379,'116375','furniture-mobile','block-54377','checkout\\ShippingConfirm','',3),(54380,'116376','furniture-mobile','block-54376-2','BlockBox','',1),(54381,'116377','furniture-mobile','block-54380','checkout\\PaymentMethodConfirm','',3),(54382,'116378','furniture-mobile','block-54380','Html_box','',1),(54383,'116379','furniture-mobile','block-54372','checkout\\ConfirmBtn','',9),(54384,'116380','furniture-mobile','block-54372','BlockBox','',2),(54385,'116381','furniture-mobile','block-54384','BlockBox','',1),(54386,'116382','furniture-mobile','block-54385','checkout\\ShippingAddressConfirm','',3),(54387,'116383','furniture-mobile','block-54385','Html_box','',1),(54388,'116384','furniture-mobile','block-54384-2','BlockBox','',1),(54389,'116385','furniture-mobile','block-54388','Html_box','',1),(54390,'116386','furniture-mobile','block-54388','checkout\\BillingAddressConfirm','',3),(54391,'116387','furniture-mobile','block-54372','checkout\\ConfirmBtn','',4),(54392,'116388','furniture-mobile','block-54372','cart\\Products','',7),(54393,'116402','furniture-mobile','checkout_confirmation_no_shipping','BlockBox','',1),(54394,'116403','furniture-mobile','block-54393','checkout\\ConfirmBtn','',9),(54395,'116404','furniture-mobile','block-54393','BlockBox','',2),(54396,'116405','furniture-mobile','block-54395','BlockBox','',1),(54397,'116406','furniture-mobile','block-54396','Html_box','',1),(54398,'116407','furniture-mobile','block-54396','checkout\\BillingAddressConfirm','',3),(54399,'116408','furniture-mobile','block-54395-2','BlockBox','',1),(54400,'116409','furniture-mobile','block-54399','Html_box','',1),(54401,'116410','furniture-mobile','block-54399','checkout\\PaymentMethodConfirm','',3),(54402,'116411','furniture-mobile','block-54393','checkout\\ConfirmBtn','',4),(54403,'116412','furniture-mobile','block-54393','checkout\\Totals','',8),(54404,'116413','furniture-mobile','block-54393','cart\\Products','',7),(54405,'116414','furniture-mobile','block-54393','Html_box','',5),(54406,'116389','furniture-mobile','checkout_confirmation_no_shipping_q','BlockBox','',1),(54407,'116390','furniture-mobile','block-54406','quote\\Products','',4),(54408,'116391','furniture-mobile','block-54406','checkout\\ConfirmBtn','',2),(54409,'116392','furniture-mobile','block-54406','checkout\\ConfirmBtn','',6),(54410,'116393','furniture-mobile','block-54406','BlockBox','',1),(54411,'116394','furniture-mobile','block-54410','BlockBox','',1),(54412,'116395','furniture-mobile','block-54411','checkout\\BillingAddressConfirm','',3),(54413,'116396','furniture-mobile','block-54411','Html_box','',1),(54414,'116397','furniture-mobile','block-54410-2','BlockBox','',1),(54415,'116398','furniture-mobile','block-54414','checkout\\PaymentMethodConfirm','',3),(54416,'116399','furniture-mobile','block-54414','Html_box','',1),(54417,'116400','furniture-mobile','block-54406','Html_box','',3),(54418,'116401','furniture-mobile','block-54406','checkout\\Totals','',5),(54419,'116415','furniture-mobile','checkout_confirmation_q','BlockBox','',1),(54420,'116416','furniture-mobile','block-54419','BlockBox','',1),(54421,'116417','furniture-mobile','block-54420','BlockBox','',1),(54422,'116418','furniture-mobile','block-54421','checkout\\ShippingAddressConfirm','',3),(54423,'116419','furniture-mobile','block-54421','Html_box','',1),(54424,'116420','furniture-mobile','block-54420-2','BlockBox','',1),(54425,'116421','furniture-mobile','block-54424','checkout\\BillingAddressConfirm','',3),(54426,'116422','furniture-mobile','block-54424','Html_box','',1),(54427,'116423','furniture-mobile','block-54419','checkout\\Totals','',7),(54428,'116424','furniture-mobile','block-54419','quote\\Products','',6),(54429,'116425','furniture-mobile','block-54419','Html_box','',4),(54430,'116426','furniture-mobile','block-54419','checkout\\EditBtn','',5),(54431,'116427','furniture-mobile','block-54419','checkout\\ConfirmBtn','',8),(54432,'116428','furniture-mobile','block-54419','checkout\\ConfirmBtn','',3),(54433,'116429','furniture-mobile','block-54419','BlockBox','',2),(54434,'116430','furniture-mobile','block-54433','BlockBox','',1),(54435,'116431','furniture-mobile','block-54434','Html_box','',1),(54436,'116432','furniture-mobile','block-54434','checkout\\ShippingConfirm','',3),(54437,'116433','furniture-mobile','block-54433-2','BlockBox','',1),(54438,'116434','furniture-mobile','block-54437','Html_box','',1),(54439,'116435','furniture-mobile','block-54437','checkout\\PaymentMethodConfirm','',3),(54440,'116436','furniture-mobile','checkout_confirmation_title','Html_box','',1),(54441,'116437','furniture-mobile','checkout_confirmation_title_g','Html_box','',1),(54442,'116439','furniture-mobile','checkout_confirmation_title_no_shipping','Html_box','',1),(54443,'116438','furniture-mobile','checkout_confirmation_title_no_shipping_g','Html_box','',1),(54444,'116440','furniture-mobile','checkout_confirmation_title_q','Html_box','',1),(54445,'116441','furniture-mobile','checkout_confirmation_title_s','Html_box','',1),(54446,'116442','furniture-mobile','checkout_delivery','BlockBox','',2),(54447,'116443','furniture-mobile','block-54446','BlockBox','',1),(54448,'116444','furniture-mobile','block-54447','Html_box','',1),(54449,'116445','furniture-mobile','block-54447','checkout\\ContactInformation','',2),(54450,'116446','furniture-mobile','block-54446','BlockBox','',2),(54451,'116447','furniture-mobile','block-54450','Html_box','',1),(54452,'116448','furniture-mobile','block-54450','checkout\\Comments','',2),(54453,'116449','furniture-mobile','checkout_delivery','BlockBox','',3),(54454,'116450','furniture-mobile','block-54453','Html_box','',1),(54455,'116451','furniture-mobile','block-54453-2','checkout\\ContinueBtn','',1),(54456,'116452','furniture-mobile','checkout_delivery','BlockBox','',1),(54457,'116453','furniture-mobile','block-54456','BlockBox','',1),(54459,'116455','furniture-mobile','block-54457','checkout\\ShippingAddress','',2),(54460,'116456','furniture-mobile','block-54456','BlockBox','checkout-shipping',2),(54461,'116457','furniture-mobile','block-54460','DelayedDespatch\\Checkout','',3),(54462,'116458','furniture-mobile','block-54460','checkout\\Shipping','',2),(54463,'116459','furniture-mobile','block-54460','Html_box','',1),(54464,'116460','furniture-mobile','block-54460','Neighbour\\Checkout','',4),(54465,'116461','furniture-mobile','checkout_delivery_g','BlockBox','',2),(54466,'116462','furniture-mobile','block-54465','BlockBox','',1),(54467,'116463','furniture-mobile','block-54466','checkout\\ContactInformation','',2),(54468,'116464','furniture-mobile','block-54466','Html_box','',1),(54469,'116465','furniture-mobile','block-54465-2','BlockBox','',1),(54470,'116466','furniture-mobile','block-54469','Html_box','',1),(54471,'116467','furniture-mobile','block-54469','checkout\\Comments','',2),(54472,'116468','furniture-mobile','checkout_delivery_g','BlockBox','',3),(54473,'116469','furniture-mobile','block-54472','Html_box','',1),(54474,'116470','furniture-mobile','block-54472-2','checkout\\ContinueBtn','',1),(54475,'116471','furniture-mobile','checkout_delivery_g','BlockBox','',1),(54476,'116472','furniture-mobile','block-54475','BlockBox','',1),(54477,'116473','furniture-mobile','block-54476','checkout\\ShippingAddress','',2),(54478,'116474','furniture-mobile','block-54476','Html_box','',1),(54479,'116475','furniture-mobile','block-54475-2','BlockBox','',1),(54480,'116476','furniture-mobile','block-54479','checkout\\Shipping','',2),(54481,'116477','furniture-mobile','block-54479','Html_box','',1),(54482,'116478','furniture-mobile','block-54479','DelayedDespatch\\Checkout','',3),(54483,'116479','furniture-mobile','block-54479','Neighbour\\Checkout','',4),(54484,'116480','furniture-mobile','checkout_delivery_no_shipping','BlockBox','',2),(54485,'116481','furniture-mobile','block-54484','Html_box','',1),(54486,'116482','furniture-mobile','block-54484-2','checkout\\ContinueBtn','',1),(54487,'116483','furniture-mobile','checkout_delivery_no_shipping','BlockBox','',1),(54488,'116484','furniture-mobile','block-54487','BlockBox','',1),(54489,'116485','furniture-mobile','block-54488','checkout\\ContactInformation','',2),(54490,'116486','furniture-mobile','block-54487-2','BlockBox','',1),(54491,'116487','furniture-mobile','block-54490','Html_box','',1),(54492,'116488','furniture-mobile','block-54490','checkout\\Comments','',2),(54493,'116489','furniture-mobile','checkout_delivery_no_shipping_g','BlockBox','',2),(54494,'116490','furniture-mobile','block-54493','Html_box','',1),(54495,'116491','furniture-mobile','block-54493-2','checkout\\ContinueBtn','',1),(54496,'116492','furniture-mobile','checkout_delivery_no_shipping_g','BlockBox','',1),(54497,'116493','furniture-mobile','block-54496','BlockBox','',1),(54498,'116494','furniture-mobile','block-54497','checkout\\ContactInformation','',2),(54499,'116495','furniture-mobile','block-54496-2','BlockBox','',1),(54500,'116496','furniture-mobile','block-54499','checkout\\Comments','',2),(54501,'116497','furniture-mobile','block-54499','Html_box','',1),(54502,'116498','furniture-mobile','checkout_delivery_title','Html_box','',1),(54503,'116499','furniture-mobile','checkout_delivery_title_g','Html_box','',1),(54504,'116501','furniture-mobile','checkout_delivery_title_no_shipping','Html_box','',1),(54505,'116500','furniture-mobile','checkout_delivery_title_no_shipping_g','Html_box','',1),(54506,'116502','furniture-mobile','checkout_delivery_title_q','Html_box','',1),(54507,'116503','furniture-mobile','checkout_delivery_title_s','Html_box','',1),(54508,'116504','furniture-mobile','checkout_free_s','BlockBox','',1),(54509,'116505','furniture-mobile','block-54508','BlockBox','',2),(54510,'116506','furniture-mobile','block-54509','BlockBox','',2),(54511,'116508','furniture-mobile','block-54510','BlockBox','',6),(54512,'116509','furniture-mobile','block-54511','sample\\Products','',1),(54513,'116510','furniture-mobile','block-54511','checkout\\CreateAccount','',3),(54514,'116511','furniture-mobile','block-54510','BlockBox','',5),(54515,'116512','furniture-mobile','block-54514','Html_box','',1),(54516,'116513','furniture-mobile','block-54514','checkout\\Comments','',2),(54517,'116514','furniture-mobile','block-54510','BlockBox','',2),(54518,'116515','furniture-mobile','block-54517','BlockBox','',2),(54519,'116516','furniture-mobile','block-54518','checkout\\ShippingChoice','',1),(54520,'116517','furniture-mobile','block-54517','Html_box','',1),(54521,'116518','furniture-mobile','block-54517','BlockBox','',3),(54522,'116519','furniture-mobile','block-54521','BlockBox','',1),(54523,'116520','furniture-mobile','block-54522','checkout\\ContactInformation','',4),(54524,'116521','furniture-mobile','block-54522','checkout\\ShippingAddress','',2),(54525,'116522','furniture-mobile','block-54522','Html_box','',3),(54526,'116523','furniture-mobile','block-54521-2','BlockBox','',1),(54527,'116524','furniture-mobile','block-54526','DelayedDespatch\\Checkout','',3),(54528,'116525','furniture-mobile','block-54517','Neighbour\\Checkout','',4),(54529,'116526','furniture-mobile','block-54509-2','BlockBox','',1),(54530,'116527','furniture-mobile','block-54529','Html_box','',3),(54531,'116528','furniture-mobile','block-54529','checkout\\ContinueBtn','',1),(54532,'1638956949.0762','furniture-mobile','block-54529','checkout\\Terms','',2),(54533,'1638957135.2709','furniture-mobile','block-54529','Html_box','',0),(54534,'116529','furniture-mobile','checkout_no_shipping','BlockBox','',1),(54535,'116530','furniture-mobile','block-54534','BlockBox','',2),(54536,'116531','furniture-mobile','block-54535','BlockBox','',1),(54537,'116532','furniture-mobile','block-54536','BlockBox','',6),(54538,'116533','furniture-mobile','block-54537','checkout\\CreateAccount','',2),(54539,'116534','furniture-mobile','block-54537','cart\\Products','',1),(54540,'116535','furniture-mobile','block-54536','BlockBox','',3),(54541,'116536','furniture-mobile','block-54540','Html_box','',1),(54542,'116537','furniture-mobile','block-54540','BlockBox','',2),(54543,'116538','furniture-mobile','block-54542','checkout\\BillingAddress','',2),(54544,'116539','furniture-mobile','block-54542','Html_box','',1),(54545,'116540','furniture-mobile','block-54542-2','BlockBox','',1),(54546,'116541','furniture-mobile','block-54545','Html_box','',1),(54547,'116542','furniture-mobile','block-54545','checkout\\PaymentMethod','',2),(54548,'116543','furniture-mobile','block-54536','BlockBox','',4),(54549,'116544','furniture-mobile','block-54548','BlockBox','',2),(54550,'116545','furniture-mobile','block-54549','CouponsAndVauchers\\Checkout','',1),(54551,'116546','furniture-mobile','block-54549-2','checkout\\CreditAmount','',1),(54552,'116547','furniture-mobile','block-54549-2','checkout\\BonusPoints','',2),(54553,'116548','furniture-mobile','block-54548','Html_box','',1),(54554,'116549','furniture-mobile','block-54536','BlockBox','',5),(54555,'116550','furniture-mobile','block-54554','checkout\\Comments','',2),(54556,'116551','furniture-mobile','block-54554','Html_box','',1),(54557,'116552','furniture-mobile','block-54535-2','BlockBox','',1),(54558,'116553','furniture-mobile','block-54557','Html_box','',1),(54559,'116554','furniture-mobile','block-54557','Html_box','',5),(54560,'116555','furniture-mobile','block-54557','checkout\\Totals','',2),(54561,'116556','furniture-mobile','block-54557','checkout\\ContinueBtn','',3),(54562,'116557','furniture-mobile','block-54557','checkout\\Terms','',4),(54563,'116558','furniture-mobile','checkout_no_shipping_g','BlockBox','',1),(54564,'116559','furniture-mobile','block-54563','checkout\\Totals','',5),(54565,'116560','furniture-mobile','block-54563','BlockBox','',6),(54566,'116561','furniture-mobile','block-54565','Html_box','',1),(54567,'116562','furniture-mobile','block-54565-2','checkout\\ContinueBtn','',1),(54568,'116563','furniture-mobile','block-54563','BlockBox','',2),(54569,'116564','furniture-mobile','block-54568','BlockBox','',1),(54570,'116565','furniture-mobile','block-54569','checkout\\ContactInformation','',2),(54571,'116566','furniture-mobile','block-54569','Html_box','',1),(54572,'116567','furniture-mobile','block-54568-2','BlockBox','',1),(54573,'116568','furniture-mobile','block-54572','checkout\\Comments','',2),(54574,'116569','furniture-mobile','block-54572','Html_box','',1),(54575,'116570','furniture-mobile','block-54563','BlockBox','',1),(54576,'116571','furniture-mobile','block-54575','BlockBox','',1),(54577,'116572','furniture-mobile','block-54576','Html_box','',1),(54578,'116573','furniture-mobile','block-54576','checkout\\BillingAddress','',2),(54579,'116574','furniture-mobile','block-54575-2','BlockBox','',1),(54580,'116575','furniture-mobile','block-54579','checkout\\BonusPoints','',4),(54581,'116576','furniture-mobile','block-54579','CouponsAndVauchers\\Checkout','',5),(54582,'116577','furniture-mobile','block-54579','checkout\\PaymentMethod','',2),(54583,'116578','furniture-mobile','block-54579','checkout\\CreditAmount','',3),(54584,'116579','furniture-mobile','block-54579','Html_box','',1),(54585,'116580','furniture-mobile','block-54563','quote\\Products','',3),(54586,'116581','furniture-mobile','checkout_no_shipping_q','BlockBox','',1),(54587,'116582','furniture-mobile','block-54586','BlockBox','',2),(54588,'116583','furniture-mobile','block-54587','BlockBox','',2),(54589,'116585','furniture-mobile','block-54588','BlockBox','',5),(54590,'116586','furniture-mobile','block-54589','checkout\\Comments','',2),(54591,'116587','furniture-mobile','block-54589','Html_box','',1),(54592,'116588','furniture-mobile','block-54588','BlockBox','',6),(54593,'116589','furniture-mobile','block-54592','checkout\\CreateAccount','',3),(54594,'116590','furniture-mobile','block-54592','quote\\Products','',2),(54595,'116591','furniture-mobile','block-54588','BlockBox','',3),(54596,'116592','furniture-mobile','block-54595','Html_box','',1),(54597,'116593','furniture-mobile','block-54595','BlockBox','',2),(54598,'116594','furniture-mobile','block-54597','Html_box','',1),(54599,'116595','furniture-mobile','block-54597','checkout\\BillingAddress','',2),(54600,'116596','furniture-mobile','block-54597-2','BlockBox','',1),(54601,'116597','furniture-mobile','block-54600','checkout\\PaymentMethod','',2),(54602,'116598','furniture-mobile','block-54600','Html_box','',1),(54603,'116599','furniture-mobile','block-54587-2','BlockBox','',1),(54604,'116600','furniture-mobile','block-54603','checkout\\ContinueBtn','',3),(54605,'116601','furniture-mobile','block-54603','Html_box','',5),(54606,'116602','furniture-mobile','block-54603','Html_box','',1),(54607,'116603','furniture-mobile','block-54603','checkout\\Totals','',2),(54608,'120984','furniture-mobile','block-54603','checkout\\Terms','',4),(54609,'116604','furniture-mobile','checkout_payment','BlockBox','',1),(54610,'116605','furniture-mobile','block-54609','BlockBox','',1),(54611,'116606','furniture-mobile','block-54610','checkout\\BillingAddress','',2),(54612,'116607','furniture-mobile','block-54610','Html_box','',1),(54613,'116608','furniture-mobile','block-54609','BlockBox','',2),(54614,'116609','furniture-mobile','block-54613','checkout\\CreditAmount','',3),(54615,'116610','furniture-mobile','block-54613','checkout\\BonusPoints','',4),(54616,'116611','furniture-mobile','block-54613','CouponsAndVauchers\\Checkout','',5),(54617,'116612','furniture-mobile','block-54613','checkout\\PaymentMethod','',2),(54618,'116613','furniture-mobile','block-54613','Html_box','',1),(54619,'116614','furniture-mobile','checkout_payment','BlockBox','',3),(54620,'116615','furniture-mobile','block-54619','Html_box','',1),(54621,'116616','furniture-mobile','block-54619-2','checkout\\ContinueBtn','',1),(54622,'116617','furniture-mobile','checkout_payment_g','BlockBox','',1),(54623,'116618','furniture-mobile','block-54622','BlockBox','',1),(54624,'116619','furniture-mobile','block-54623','checkout\\BillingAddress','',2),(54625,'116620','furniture-mobile','block-54623','Html_box','',1),(54626,'116621','furniture-mobile','block-54622-2','BlockBox','',1),(54627,'116622','furniture-mobile','block-54626','checkout\\CreditAmount','',3),(54628,'116623','furniture-mobile','block-54626','Html_box','',1),(54629,'116624','furniture-mobile','block-54626','checkout\\PaymentMethod','',2),(54630,'116625','furniture-mobile','block-54626','CouponsAndVauchers\\Checkout','',5),(54631,'116626','furniture-mobile','block-54626','checkout\\BonusPoints','',4),(54632,'116627','furniture-mobile','checkout_payment_g','BlockBox','',2),(54633,'116628','furniture-mobile','block-54632','Html_box','',1),(54634,'116629','furniture-mobile','block-54632-2','checkout\\ContinueBtn','',1),(54635,'116630','furniture-mobile','checkout_payment_no_shipping','BlockBox','',2),(54636,'116631','furniture-mobile','block-54635','Html_box','',1),(54637,'116632','furniture-mobile','block-54635-2','checkout\\ContinueBtn','',1),(54638,'116633','furniture-mobile','checkout_payment_no_shipping','BlockBox','',1),(54639,'116634','furniture-mobile','block-54638','BlockBox','',1),(54640,'116635','furniture-mobile','block-54639','Html_box','',1),(54641,'116636','furniture-mobile','block-54639','checkout\\BillingAddress','',2),(54642,'116637','furniture-mobile','block-54638-2','BlockBox','',1),(54643,'116638','furniture-mobile','block-54642','checkout\\BonusPoints','',4),(54644,'116639','furniture-mobile','block-54642','CouponsAndVauchers\\Checkout','',5),(54645,'116640','furniture-mobile','block-54642','checkout\\PaymentMethod','',2),(54646,'116641','furniture-mobile','block-54642','checkout\\CreditAmount','',3),(54647,'116642','furniture-mobile','block-54642','Html_box','',1),(54648,'116643','furniture-mobile','checkout_payment_no_shipping_g','BlockBox','',2),(54649,'116644','furniture-mobile','block-54648','Html_box','',1),(54650,'116645','furniture-mobile','block-54648-2','checkout\\ContinueBtn','',1),(54651,'116646','furniture-mobile','checkout_payment_no_shipping_g','BlockBox','',1),(54652,'116647','furniture-mobile','block-54651','BlockBox','',1),(54653,'116648','furniture-mobile','block-54652','checkout\\BillingAddress','',2),(54654,'116649','furniture-mobile','block-54652','Html_box','',1),(54655,'116650','furniture-mobile','block-54651-2','BlockBox','',1),(54656,'116651','furniture-mobile','block-54655','checkout\\BonusPoints','',4),(54657,'116652','furniture-mobile','block-54655','checkout\\CreditAmount','',3),(54658,'116653','furniture-mobile','block-54655','checkout\\PaymentMethod','',2),(54659,'116654','furniture-mobile','block-54655','Html_box','',1),(54660,'116655','furniture-mobile','block-54655','CouponsAndVauchers\\Checkout','',5),(54661,'116656','furniture-mobile','checkout_payment_title','Html_box','',1),(54662,'116657','furniture-mobile','checkout_payment_title_g','Html_box','',1),(54663,'116658','furniture-mobile','checkout_payment_title_no_shipping','Html_box','',1),(54664,'116659','furniture-mobile','checkout_payment_title_no_shipping_g','Html_box','',1),(54665,'116660','furniture-mobile','checkout_payment_title_q','Html_box','',1),(54666,'116661','furniture-mobile','checkout_payment_title_s','Html_box','',1),(54667,'120947','furniture-mobile','checkout_q','BlockBox','',1),(54668,'120948','furniture-mobile','block-54667','BlockBox','',2),(54669,'120949','furniture-mobile','block-54668','BlockBox','',2),(54670,'120950','furniture-mobile','block-54669','BlockBox','',6),(54671,'120951','furniture-mobile','block-54670','checkout\\CreateAccount','',3),(54672,'120952','furniture-mobile','block-54670','quote\\Products','',2),(54673,'120953','furniture-mobile','block-54669','BlockBox','',2),(54674,'120954','furniture-mobile','block-54673','BlockBox','',2),(54675,'120955','furniture-mobile','block-54674','checkout\\ShippingChoice','',1),(54676,'120956','furniture-mobile','block-54673','Neighbour\\Checkout','',4),(54677,'120957','furniture-mobile','block-54673','Html_box','',1),(54678,'120958','furniture-mobile','block-54673','BlockBox','',3),(54679,'120959','furniture-mobile','block-54678','BlockBox','',1),(54680,'120960','furniture-mobile','block-54679','checkout\\ContactInformation','',4),(54681,'120961','furniture-mobile','block-54679','checkout\\ShippingAddress','',2),(54682,'120962','furniture-mobile','block-54679','Html_box','',3),(54683,'120963','furniture-mobile','block-54678-2','BlockBox','',1),(54684,'120964','furniture-mobile','block-54683','checkout\\Shipping','',2),(54685,'120965','furniture-mobile','block-54683','Html_box','',1),(54686,'120966','furniture-mobile','block-54683','DelayedDespatch\\Checkout','',3),(54687,'120967','furniture-mobile','block-54669','BlockBox','',5),(54688,'120968','furniture-mobile','block-54687','Html_box','',1),(54689,'120969','furniture-mobile','block-54687','checkout\\Comments','',2),(54690,'120970','furniture-mobile','block-54669','BlockBox','',3),(54691,'120971','furniture-mobile','block-54690','Html_box','',1),(54692,'120972','furniture-mobile','block-54690','BlockBox','',2),(54693,'120973','furniture-mobile','block-54692','checkout\\BillingAddress','',2),(54694,'120974','furniture-mobile','block-54692','Html_box','',1),(54695,'120975','furniture-mobile','block-54692-2','BlockBox','',1),(54696,'120976','furniture-mobile','block-54695','checkout\\PaymentMethod','',2),(54697,'120977','furniture-mobile','block-54695','Html_box','',1),(54698,'120978','furniture-mobile','block-54668-2','BlockBox','',1),(54699,'120979','furniture-mobile','block-54698','Html_box','',1),(54700,'120980','furniture-mobile','block-54698','Html_box','',5),(54701,'120981','furniture-mobile','block-54698','checkout\\Totals','',2),(54702,'120982','furniture-mobile','block-54698','checkout\\ContinueBtn','',3),(54703,'120983','furniture-mobile','block-54698','checkout\\Terms','',4),(54704,'116699','furniture-mobile','checkout_s','BlockBox','',1),(54705,'116700','furniture-mobile','block-54704','BlockBox','',2),(54706,'116701','furniture-mobile','block-54705','BlockBox','',2),(54707,'116703','furniture-mobile','block-54706','BlockBox','',6),(54708,'116704','furniture-mobile','block-54707','sample\\Products','',1),(54709,'116705','furniture-mobile','block-54707','checkout\\CreateAccount','',3),(54710,'116706','furniture-mobile','block-54706','BlockBox','',2),(54711,'116707','furniture-mobile','block-54710','Html_box','',1),(54712,'116708','furniture-mobile','block-54710','Neighbour\\Checkout','',4),(54713,'116709','furniture-mobile','block-54710','BlockBox','',2),(54714,'116710','furniture-mobile','block-54713','checkout\\ShippingChoice','',1),(54715,'116711','furniture-mobile','block-54710','BlockBox','',3),(54716,'116712','furniture-mobile','block-54715','BlockBox','',1),(54717,'116713','furniture-mobile','block-54716','checkout\\ShippingAddress','',2),(54718,'116714','furniture-mobile','block-54716','checkout\\ContactInformation','',4),(54719,'116715','furniture-mobile','block-54716','Html_box','',3),(54720,'116716','furniture-mobile','block-54715-2','BlockBox','',1),(54721,'116717','furniture-mobile','block-54720','checkout\\Shipping','',2),(54722,'116718','furniture-mobile','block-54720','DelayedDespatch\\Checkout','',3),(54723,'116719','furniture-mobile','block-54720','Html_box','',1),(54724,'116720','furniture-mobile','block-54706','BlockBox','',3),(54725,'116721','furniture-mobile','block-54724','BlockBox','',2),(54726,'116722','furniture-mobile','block-54725','Html_box','',1),(54727,'116723','furniture-mobile','block-54725','checkout\\BillingAddress','',2),(54728,'116724','furniture-mobile','block-54725-2','BlockBox','',1),(54729,'116725','furniture-mobile','block-54728','Html_box','',1),(54730,'116726','furniture-mobile','block-54728','checkout\\PaymentMethod','',2),(54731,'116727','furniture-mobile','block-54724','Html_box','',1),(54732,'116728','furniture-mobile','block-54706','BlockBox','',5),(54733,'116729','furniture-mobile','block-54732','Html_box','',1),(54734,'116730','furniture-mobile','block-54732','checkout\\Comments','',2),(54735,'116731','furniture-mobile','block-54706','BlockBox','',4),(54736,'116732','furniture-mobile','block-54735','BlockBox','',2),(54737,'116733','furniture-mobile','block-54736','CouponsAndVauchers\\Checkout','',1),(54738,'116734','furniture-mobile','block-54736-2','checkout\\BonusPoints','',2),(54739,'116735','furniture-mobile','block-54736-2','checkout\\CreditAmount','',1),(54740,'116736','furniture-mobile','block-54735','Html_box','',1),(54741,'116737','furniture-mobile','block-54705-2','BlockBox','',1),(54742,'116738','furniture-mobile','block-54741','checkout\\Totals','',2),(54743,'116739','furniture-mobile','block-54741','Html_box','',5),(54744,'116740','furniture-mobile','block-54741','Html_box','',1),(54745,'116741','furniture-mobile','block-54741','checkout\\ContinueBtn','',3),(54746,'120986','furniture-mobile','block-54741','checkout\\Terms','',4),(54747,'116742','furniture-mobile','checkout_step_bottom','Html_box','',1),(54748,'116743','furniture-mobile','checkout_step_bottom','cart\\Products','',2),(54749,'116744','furniture-mobile','checkout_step_bottom','checkout\\Totals','',3),(54750,'116745','furniture-mobile','checkout_step_bottom_g','checkout\\Totals','',3),(54751,'116746','furniture-mobile','checkout_step_bottom_g','quote\\Products','',2),(54752,'116747','furniture-mobile','checkout_step_bottom_g','Html_box','',1),(54753,'116749','furniture-mobile','checkout_step_bottom_no_shipping','Html_box','',1),(54754,'116750','furniture-mobile','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(54755,'116753','furniture-mobile','checkout_step_bottom_no_shipping','cart\\Products','',2),(54756,'116748','furniture-mobile','checkout_step_bottom_no_shipping_g','Html_box','',1),(54757,'116751','furniture-mobile','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(54758,'116752','furniture-mobile','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(54759,'116754','furniture-mobile','communication','BlockBox','',1),(54760,'116755','furniture-mobile','block-54759','Html_box','',2),(54761,'116756','furniture-mobile','block-54759','Communication\\NewTopicButton','',1),(54762,'116757','furniture-mobile','block-54759','Communication\\Topic','',3),(54763,'116758','furniture-mobile','compare','BlockBox','',1),(54764,'116759','furniture-mobile','block-54763','catalog\\Compare','',1),(54765,'117665.000001','furniture-mobile','compareproduct','BlockBox','listing-item',1),(54766,'120921.000001','furniture-mobile','block-54765','BlockBox','',1),(54767,'120919.000001','furniture-mobile','block-54766','BlockBox','listing-item',1),(54768,'1638872990.9609','furniture-mobile','block-54767','BlockBox','',2),(54769,'117671.000001','furniture-mobile','block-54768','productListing\\image','',1),(54770,'117677.000001','furniture-mobile','block-54768-2','productListing\\compare','',1),(54771,'117675.000001','furniture-mobile','block-54768-2','productListing\\name','',2),(54772,'117676.000001','furniture-mobile','block-54768-2','productListing\\stock','',3),(54773,'1638873112.0384','furniture-mobile','block-54768-2','BlockBox','',4),(54774,'117670.000001','furniture-mobile','block-54773','productListing\\rating','',2),(54775,'117673.000001','furniture-mobile','block-54773-2','productListing\\price','',1),(54776,'116760','furniture-mobile','compare_products','BlockBox','',2),(54777,'116761','furniture-mobile','block-54776','productListing\\rating','',4),(54778,'116762','furniture-mobile','block-54776','productListing\\model','',5),(54779,'116763','furniture-mobile','block-54776','productListing\\compare','',1),(54780,'116764','furniture-mobile','block-54776','BlockBox','',2),(54781,'116765','furniture-mobile','block-54780','productListing\\image','',1),(54782,'116766','furniture-mobile','block-54780-2','productListing\\name','',2),(54783,'116767','furniture-mobile','block-54776','BlockBox','',3),(54784,'116768','furniture-mobile','block-54783','productListing\\price','',1),(54785,'116769','furniture-mobile','block-54783-2','productListing\\buyButton','',1),(54786,'116770','furniture-mobile','confirmation','BlockBox','',1),(54787,'116771','furniture-mobile','block-54786','BlockBox','',2),(54788,'116772','furniture-mobile','block-54787','BlockBox','',2),(54789,'116773','furniture-mobile','block-54788','BlockBox','',4),(54790,'116774','furniture-mobile','block-54789','checkout\\EditBtn','',2),(54791,'116775','furniture-mobile','block-54789','cart\\Products','',3),(54792,'116776','furniture-mobile','block-54789','Html_box','',1),(54793,'116777','furniture-mobile','block-54788','BlockBox','',3),(54794,'116778','furniture-mobile','block-54793','checkout\\EditBtn','',2),(54795,'116779','furniture-mobile','block-54793','Html_box','',1),(54796,'116780','furniture-mobile','block-54793','checkout\\CommentsConfirm','',3),(54797,'116781','furniture-mobile','block-54788','BlockBox','',1),(54798,'116782','furniture-mobile','block-54797','BlockBox','',1),(54799,'116783','furniture-mobile','block-54798','checkout\\EditBtn','',6),(54800,'116784','furniture-mobile','block-54798','DelayedDespatch\\CheckoutConfirm','',8),(54801,'116785','furniture-mobile','block-54798','Html_box','',9),(54802,'116786','furniture-mobile','block-54798','checkout\\EditBtn','',10),(54803,'116787','furniture-mobile','block-54798','Html_box','',5),(54804,'116788','furniture-mobile','block-54798','checkout\\ShippingConfirm','',7),(54805,'116789','furniture-mobile','block-54798','Html_box','',1),(54806,'116790','furniture-mobile','block-54798','checkout\\EditBtn','',3),(54807,'116791','furniture-mobile','block-54798','checkout\\ContactConfirm','',11),(54808,'116792','furniture-mobile','block-54798','Html_box','',2),(54809,'116793','furniture-mobile','block-54798','checkout\\ShippingAddressConfirm','',4),(54810,'116794','furniture-mobile','block-54797-2','BlockBox','',1),(54811,'116795','furniture-mobile','block-54810','checkout\\EditBtn','',6),(54812,'116796','furniture-mobile','block-54810','checkout\\EditBtn','',3),(54813,'116797','furniture-mobile','block-54810','checkout\\PaymentMethodConfirm','',7),(54814,'116798','furniture-mobile','block-54810','Html_box','',5),(54815,'116799','furniture-mobile','block-54810','Html_box','',1),(54816,'116800','furniture-mobile','block-54810','checkout\\BillingAddressConfirm','',4),(54817,'116801','furniture-mobile','block-54810','Html_box','',2),(54818,'116802','furniture-mobile','block-54787','UploadCustomerId\\UploadCustomerIdForm','',1),(54819,'116803','furniture-mobile','block-54787-2','BlockBox','',1),(54820,'116804','furniture-mobile','block-54819','Html_box','',1),(54821,'116805','furniture-mobile','block-54819','checkout\\ConfirmBtn','',3),(54822,'116806','furniture-mobile','block-54819','checkout\\Totals','',2),(54823,'116807','furniture-mobile','block-54786','Html_box','',1),(54824,'116808','furniture-mobile','confirmation_free_s','BlockBox','',1),(54825,'116809','furniture-mobile','block-54824','BlockBox','',2),(54826,'116810','furniture-mobile','block-54825','BlockBox','',1),(54827,'116811','furniture-mobile','block-54826','BlockBox','',2),(54828,'116812','furniture-mobile','block-54827','checkout\\CommentsConfirm','',3),(54829,'116813','furniture-mobile','block-54827','checkout\\EditBtn','',2),(54830,'116814','furniture-mobile','block-54827','Html_box','',1),(54831,'116815','furniture-mobile','block-54826','BlockBox','',3),(54832,'116816','furniture-mobile','block-54831','checkout\\EditBtn','',3),(54833,'116817','furniture-mobile','block-54831','Html_box','',1),(54834,'116818','furniture-mobile','block-54831','sample\\Products','',2),(54835,'116819','furniture-mobile','block-54826','BlockBox','',1),(54836,'116820','furniture-mobile','block-54835','BlockBox','',1),(54837,'116821','furniture-mobile','block-54836','checkout\\EditBtn','',3),(54838,'116822','furniture-mobile','block-54836','checkout\\ShippingConfirm','',7),(54839,'116823','furniture-mobile','block-54836','Html_box','',5),(54840,'116824','furniture-mobile','block-54836','checkout\\EditBtn','',6),(54841,'116825','furniture-mobile','block-54836','Html_box','',2),(54842,'116826','furniture-mobile','block-54836','checkout\\ShippingAddressConfirm','',4),(54843,'116827','furniture-mobile','block-54835-2','BlockBox','',1),(54844,'116828','furniture-mobile','block-54843','checkout\\ContactConfirm','',3),(54845,'116829','furniture-mobile','block-54843','DelayedDespatch\\CheckoutConfirm','',4),(54846,'116830','furniture-mobile','block-54843','checkout\\EditBtn','',2),(54847,'116831','furniture-mobile','block-54843','Html_box','',1),(54848,'116832','furniture-mobile','block-54825-2','BlockBox','',1),(54849,'116833','furniture-mobile','block-54848','checkout\\ConfirmBtn','',3),(54850,'116834','furniture-mobile','block-54824','Html_box','',1),(54851,'116835','furniture-mobile','confirmation_no_shipping','BlockBox','',1),(54852,'116836','furniture-mobile','block-54851','Html_box','',1),(54853,'116837','furniture-mobile','block-54851','BlockBox','',2),(54854,'116838','furniture-mobile','block-54853','BlockBox','',1),(54855,'116839','furniture-mobile','block-54854','BlockBox','',1),(54856,'116840','furniture-mobile','block-54855','BlockBox','',1),(54857,'116841','furniture-mobile','block-54856','checkout\\EditBtn','',10),(54858,'116842','furniture-mobile','block-54856','Html_box','',9),(54859,'116843','furniture-mobile','block-54856','checkout\\ContactConfirm','',11),(54860,'116844','furniture-mobile','block-54855-2','BlockBox','',1),(54861,'116845','furniture-mobile','block-54860','checkout\\PaymentMethodConfirm','',7),(54862,'116846','furniture-mobile','block-54860','checkout\\EditBtn','',6),(54863,'116847','furniture-mobile','block-54860','Html_box','',5),(54864,'116848','furniture-mobile','block-54860','Html_box','',1),(54865,'116849','furniture-mobile','block-54860','checkout\\EditBtn','',3),(54866,'116850','furniture-mobile','block-54860','checkout\\BillingAddressConfirm','',4),(54867,'116851','furniture-mobile','block-54860','Html_box','',2),(54868,'116852','furniture-mobile','block-54854','BlockBox','',2),(54869,'116853','furniture-mobile','block-54868','Html_box','',1),(54870,'116854','furniture-mobile','block-54868','checkout\\CommentsConfirm','',3),(54871,'116855','furniture-mobile','block-54868','checkout\\EditBtn','',2),(54872,'116856','furniture-mobile','block-54854','BlockBox','',3),(54873,'116857','furniture-mobile','block-54872','Html_box','',1),(54874,'116858','furniture-mobile','block-54872','checkout\\EditBtn','',2),(54875,'116859','furniture-mobile','block-54872','cart\\Products','',3),(54876,'116860','furniture-mobile','block-54853-2','BlockBox','',1),(54877,'116861','furniture-mobile','block-54876','checkout\\ConfirmBtn','',3),(54878,'116862','furniture-mobile','block-54876','Html_box','',1),(54879,'116863','furniture-mobile','block-54876','checkout\\Totals','',2),(54880,'116864','furniture-mobile','confirmation_no_shipping_q','BlockBox','',2),(54881,'116865','furniture-mobile','block-54880','Html_box','',1),(54882,'116866','furniture-mobile','block-54880','BlockBox','',2),(54883,'116867','furniture-mobile','block-54882','BlockBox','',1),(54884,'116868','furniture-mobile','block-54883','BlockBox','',2),(54885,'116869','furniture-mobile','block-54884','Html_box','',1),(54886,'116870','furniture-mobile','block-54884','checkout\\CommentsConfirm','',3),(54887,'116871','furniture-mobile','block-54884','checkout\\EditBtn','',2),(54888,'116872','furniture-mobile','block-54883','BlockBox','',1),(54889,'116873','furniture-mobile','block-54888','BlockBox','',1),(54890,'116874','furniture-mobile','block-54889','checkout\\EditBtn','',5),(54891,'116875','furniture-mobile','block-54889','checkout\\ContactConfirm','',6),(54892,'116876','furniture-mobile','block-54889','checkout\\PaymentMethodConfirm','',3),(54893,'116877','furniture-mobile','block-54889','checkout\\EditBtn','',2),(54894,'116878','furniture-mobile','block-54889','Html_box','',4),(54895,'116879','furniture-mobile','block-54889','Html_box','',1),(54896,'116880','furniture-mobile','block-54888-2','BlockBox','',1),(54897,'116881','furniture-mobile','block-54896','checkout\\BillingAddressConfirm','',4),(54898,'116882','furniture-mobile','block-54896','checkout\\EditBtn','',3),(54899,'116883','furniture-mobile','block-54896','Html_box','',2),(54900,'116884','furniture-mobile','block-54883','BlockBox','',3),(54901,'116885','furniture-mobile','block-54900','checkout\\EditBtn','',2),(54902,'116886','furniture-mobile','block-54900','Html_box','',1),(54903,'116887','furniture-mobile','block-54900','quote\\Products','',3),(54904,'116888','furniture-mobile','block-54882-2','BlockBox','',1),(54905,'116889','furniture-mobile','block-54904','checkout\\ConfirmBtn','',3),(54906,'116890','furniture-mobile','block-54904','checkout\\Totals','',2),(54907,'116891','furniture-mobile','block-54904','Html_box','',1),(54908,'116892','furniture-mobile','confirmation_q','BlockBox','',1),(54909,'116893','furniture-mobile','block-54908','Html_box','',1),(54910,'116894','furniture-mobile','block-54908','BlockBox','',2),(54911,'116895','furniture-mobile','block-54910','BlockBox','',1),(54912,'116896','furniture-mobile','block-54911','BlockBox','',3),(54913,'116897','furniture-mobile','block-54912','quote\\Products','',3),(54914,'116898','furniture-mobile','block-54912','Html_box','',1),(54915,'116899','furniture-mobile','block-54912','checkout\\EditBtn','',2),(54916,'116900','furniture-mobile','block-54911','BlockBox','',1),(54917,'116901','furniture-mobile','block-54916','BlockBox','',1),(54918,'116902','furniture-mobile','block-54917','Html_box','',1),(54919,'116903','furniture-mobile','block-54917','checkout\\EditBtn','',10),(54920,'116904','furniture-mobile','block-54917','Html_box','',2),(54921,'116905','furniture-mobile','block-54917','checkout\\ContactConfirm','',11),(54922,'116906','furniture-mobile','block-54917','checkout\\ShippingAddressConfirm','',4),(54923,'116907','furniture-mobile','block-54917','checkout\\ShippingConfirm','',7),(54924,'116908','furniture-mobile','block-54917','checkout\\EditBtn','',3),(54925,'116909','furniture-mobile','block-54917','DelayedDespatch\\CheckoutConfirm','',8),(54926,'116910','furniture-mobile','block-54917','Html_box','',9),(54927,'116911','furniture-mobile','block-54917','Html_box','',5),(54928,'116912','furniture-mobile','block-54917','checkout\\EditBtn','',6),(54929,'116913','furniture-mobile','block-54916-2','BlockBox','',1),(54930,'116914','furniture-mobile','block-54929','checkout\\EditBtn','',3),(54931,'116915','furniture-mobile','block-54929','checkout\\BillingAddressConfirm','',4),(54932,'116916','furniture-mobile','block-54929','checkout\\PaymentMethodConfirm','',7),(54933,'116917','furniture-mobile','block-54929','Html_box','',1),(54934,'116918','furniture-mobile','block-54929','Html_box','',2),(54935,'116919','furniture-mobile','block-54929','checkout\\EditBtn','',6),(54936,'116920','furniture-mobile','block-54929','Html_box','',5),(54937,'116921','furniture-mobile','block-54911','BlockBox','',2),(54938,'116922','furniture-mobile','block-54937','checkout\\CommentsConfirm','',3),(54939,'116923','furniture-mobile','block-54937','Html_box','',1),(54940,'116924','furniture-mobile','block-54937','checkout\\EditBtn','',2),(54941,'116925','furniture-mobile','block-54910-2','BlockBox','',1),(54942,'116926','furniture-mobile','block-54941','Html_box','',1),(54943,'116927','furniture-mobile','block-54941','checkout\\Totals','',2),(54944,'116928','furniture-mobile','block-54941','checkout\\ConfirmBtn','',3),(54945,'116929','furniture-mobile','confirmation_s','BlockBox','',1),(54946,'116930','furniture-mobile','block-54945','BlockBox','',2),(54947,'116931','furniture-mobile','block-54946','BlockBox','',1),(54948,'116932','furniture-mobile','block-54947','BlockBox','',1),(54949,'116933','furniture-mobile','block-54948','BlockBox','',1),(54950,'116934','furniture-mobile','block-54949','checkout\\ShippingAddressConfirm','',4),(54951,'116935','furniture-mobile','block-54949','checkout\\EditBtn','',3),(54952,'116936','furniture-mobile','block-54949','Html_box','',2),(54953,'116937','furniture-mobile','block-54949','DelayedDespatch\\CheckoutConfirm','',8),(54954,'116938','furniture-mobile','block-54949','checkout\\ShippingConfirm','',7),(54955,'116939','furniture-mobile','block-54949','Html_box','',1),(54956,'116940','furniture-mobile','block-54949','Html_box','',5),(54957,'116941','furniture-mobile','block-54949','Html_box','',9),(54958,'116942','furniture-mobile','block-54949','checkout\\ContactConfirm','',11),(54959,'116943','furniture-mobile','block-54949','checkout\\EditBtn','',6),(54960,'116944','furniture-mobile','block-54949','checkout\\EditBtn','',10),(54961,'116945','furniture-mobile','block-54948-2','BlockBox','',1),(54962,'116946','furniture-mobile','block-54961','Html_box','',2),(54963,'116947','furniture-mobile','block-54961','checkout\\BillingAddressConfirm','',4),(54964,'116948','furniture-mobile','block-54961','checkout\\EditBtn','',3),(54965,'116949','furniture-mobile','block-54961','checkout\\PaymentMethodConfirm','',7),(54966,'116950','furniture-mobile','block-54961','checkout\\EditBtn','',6),(54967,'116951','furniture-mobile','block-54961','Html_box','',1),(54968,'116952','furniture-mobile','block-54961','Html_box','',5),(54969,'116953','furniture-mobile','block-54947','BlockBox','',3),(54970,'116954','furniture-mobile','block-54969','checkout\\EditBtn','',3),(54971,'116955','furniture-mobile','block-54969','Html_box','',1),(54972,'116956','furniture-mobile','block-54969','sample\\Products','',2),(54973,'116957','furniture-mobile','block-54947','BlockBox','',2),(54974,'116958','furniture-mobile','block-54973','Html_box','',1),(54975,'116959','furniture-mobile','block-54973','checkout\\EditBtn','',2),(54976,'116960','furniture-mobile','block-54973','checkout\\CommentsConfirm','',3),(54977,'116961','furniture-mobile','block-54946-2','BlockBox','',1),(54978,'116962','furniture-mobile','block-54977','checkout\\Totals','',2),(54979,'116963','furniture-mobile','block-54977','checkout\\ConfirmBtn','',3),(54980,'116964','furniture-mobile','block-54977','Html_box','',1),(54981,'116965','furniture-mobile','block-54945','Html_box','',1),(54982,'116966','furniture-mobile','contact','BlockBox','info-content',1),(54983,'116967','furniture-mobile','block-54982','info\\Title','',1),(54984,'116968','furniture-mobile','block-54982','BlockBox','',2),(54985,'116969','furniture-mobile','block-54984','contact\\ContactForm','',1),(54986,'116970','furniture-mobile','block-54984-2','contact\\Contacts','',1),(54987,'116971','furniture-mobile','created_success','BlockBox','',1),(54988,'116972','furniture-mobile','block-54987','Html_box','',1),(54989,'116973','furniture-mobile','block-54987','Html_box','',2),(54990,'116102.000001','furniture-mobile','credit_amount_history','BlockBox','',1),(54991,'116103.000001','furniture-mobile','block-54990','BlockBox','',1),(54992,'116104.000001','furniture-mobile','block-54991','WidgetsAria','',1),(55012,'116109.000001','furniture-mobile','block-54991-2','Html_box','',1),(55013,'1638895944.9672','furniture-mobile','block-54991-2','account\\CreditAmountHistory','',2),(55014,'116974','furniture-mobile','credit_note','invoice\\Container','',1),(55015,'116975','furniture-mobile','block-55014','BlockBox','',5),(55016,'116976','furniture-mobile','block-55015','invoice\\StoreAddress','',8),(55017,'116977','furniture-mobile','block-55015','Text','',1),(55018,'116978','furniture-mobile','block-55015-2','Text','',2),(55019,'116979','furniture-mobile','block-55015-2','Logo','',1),(55020,'116980','furniture-mobile','block-55015-3','Text','',1),(55021,'116981','furniture-mobile','block-55015-3','BlockBox','',3),(55022,'116982','furniture-mobile','block-55021','Text','',1),(55023,'116983','furniture-mobile','block-55021-2','invoice\\StoreEmail','',1),(55024,'116984','furniture-mobile','block-55015-3','BlockBox','',2),(55025,'116985','furniture-mobile','block-55024','Text','',1),(55026,'116986','furniture-mobile','block-55024-2','invoice\\StorePhone','',1),(55027,'116987','furniture-mobile','block-55014','invoice\\Products','',3),(55028,'116988','furniture-mobile','block-55014','BlockBox','',1),(55029,'116989','furniture-mobile','block-55028','Logo','',1),(55030,'116990','furniture-mobile','block-55028-2','BlockBox','',4),(55031,'116991','furniture-mobile','block-55030','Text','',1),(55032,'116992','furniture-mobile','block-55030-2','invoice\\StoreSite','',1),(55033,'116993','furniture-mobile','block-55028-2','BlockBox','',2),(55034,'116994','furniture-mobile','block-55033','Text','',1),(55035,'116995','furniture-mobile','block-55033-2','invoice\\StorePhone','',1),(55036,'116996','furniture-mobile','block-55028-2','BlockBox','',3),(55037,'116997','furniture-mobile','block-55036','Text','',1),(55038,'116998','furniture-mobile','block-55036-2','invoice\\StoreEmail','',1),(55039,'116999','furniture-mobile','block-55028-2','BlockBox','',1),(55040,'117000','furniture-mobile','block-55039','invoice\\StoreAddress','',1),(55041,'117001','furniture-mobile','block-55014','BlockBox','',4),(55042,'117002','furniture-mobile','block-55041','BlockBox','',1),(55043,'117003','furniture-mobile','block-55042','invoice\\ShippingAddress','',2),(55044,'117004','furniture-mobile','block-55042','Text','',1),(55045,'117005','furniture-mobile','block-55041-2','BlockBox','',1),(55046,'117006','furniture-mobile','block-55014','BlockBox','',2),(55047,'117007','furniture-mobile','block-55046','BlockBox','',7),(55048,'117008','furniture-mobile','block-55047','BlockBox','',1),(55049,'117009','furniture-mobile','block-55048','Text','',1),(55050,'117010','furniture-mobile','block-55048','invoice\\BillingAddress','',2),(55051,'117011','furniture-mobile','block-55047-2','BlockBox','',1),(55052,'117012','furniture-mobile','block-55051','invoice\\CustomerPhone','',4),(55053,'117013','furniture-mobile','block-55051','Text','',1),(55054,'117014','furniture-mobile','block-55051','Text','',3),(55055,'117015','furniture-mobile','block-55051','invoice\\CustomerName','',2),(55056,'117016','furniture-mobile','block-55051','invoice\\CustomerEmail','',6),(55057,'117017','furniture-mobile','block-55051','Text','',5),(55058,'117018','furniture-mobile','block-55046','BlockBox','',8),(55059,'117019','furniture-mobile','block-55058','BlockBox','',1),(55060,'117020','furniture-mobile','block-55059','invoice\\ShippingMethod','',2),(55061,'117021','furniture-mobile','block-55059','Text','',1),(55062,'117022','furniture-mobile','block-55058-2','BlockBox','',1),(55063,'117023','furniture-mobile','block-55062','Text','',1),(55064,'117024','furniture-mobile','block-55062','invoice\\ShippingMethod','',2),(55065,'117025','furniture-mobile','block-55046-2','invoice\\OrderId','',1),(55066,'117026','furniture-mobile','block-55046-2','Text','',2),(55067,'117027','furniture-mobile','block-55046-2','invoice\\PaymentDate','',3),(55069,'117034','furniture-mobile','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(55070,'1639155816.3893','furniture-mobile','delivery-location','BlockBox','',2),(55071,'117028','furniture-mobile','block-55070','DeliveryLocation\\FeaturedList','',6),(55072,'117029','furniture-mobile','block-55070','DeliveryLocation\\LocationLongDescription','',3),(55073,'117030','furniture-mobile','block-55070','DeliveryLocation\\LocationList','',4),(55074,'117031','furniture-mobile','block-55070','DeliveryLocation\\LocationTitle','',1),(55075,'117032','furniture-mobile','block-55070','DeliveryLocation\\LocationProducts','',7),(55076,'117033','furniture-mobile','block-55070','DeliveryLocation\\LocationDescription','',2),(55077,'1639485067.5512','furniture-mobile','block-55070','DeliveryLocation\\CrossPages','',0),(55078,'1639485089.2227','furniture-mobile','block-55070','DeliveryLocation\\ProductCategories','',0),(55079,'1639154415.2739','furniture-mobile','delivery-location-default','BlockBox','',2),(55080,'117035','furniture-mobile','block-55079','DeliveryLocation\\TopLocationList','',2),(55081,'117036','furniture-mobile','block-55079','Heading','',1),(55082,'1639419797.9718','furniture-mobile','block-55079','DeliveryLocation\\ListByPage','',3),(55083,'117037','furniture-mobile','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(55084,'117038','furniture-mobile','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(55085,'117039','furniture-mobile','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(55086,'117040','furniture-mobile','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(55087,'117041','furniture-mobile','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(55088,'117042','furniture-mobile','delivery_loc_2','DeliveryLocation\\LocationList','',7),(55089,'117043','furniture-mobile','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(55090,'117044','furniture-mobile','email','email\\BlockBox','',1),(55091,'117045','furniture-mobile','block-55090','email\\BlockBox','',1),(55092,'117046','furniture-mobile','block-55091','Copyright','',4),(55093,'117047','furniture-mobile','block-55091','email\\Content','',3),(55094,'117048','furniture-mobile','block-55091','email\\BlockBox','',2),(55095,'117049','furniture-mobile','block-55094','email\\Title','',1),(55096,'117050','furniture-mobile','block-55094-2','email\\Date','',1),(55097,'117051','furniture-mobile','block-55091','Logo','',1),(55098,'117052','furniture-mobile','email_2','email\\BlockBox','',1),(55099,'117053','furniture-mobile','block-55098','email\\BlockBox','',1),(55100,'117054','furniture-mobile','block-55099','Copyright','',4),(55101,'117055','furniture-mobile','block-55099','Logo','',1),(55102,'117056','furniture-mobile','block-55099','email\\Content','',3),(55103,'117057','furniture-mobile','block-55099','email\\BlockBox','',2),(55104,'117058','furniture-mobile','block-55103','email\\Title','',1),(55105,'117059','furniture-mobile','block-55103-2','email\\Date','',1),(55106,'117060','furniture-mobile','email_3','email\\BlockBox','',1),(55107,'117061','furniture-mobile','block-55106','email\\BlockBox','',1),(55108,'117062','furniture-mobile','block-55107','email\\BlockBox','',2),(55109,'117063','furniture-mobile','block-55108','email\\Content','',2),(55110,'117064','furniture-mobile','block-55108','email\\BlockBox','',1),(55111,'117065','furniture-mobile','block-55110','email\\Title','',1),(55112,'117066','furniture-mobile','block-55110-2','email\\Date','',1),(55113,'117067','furniture-mobile','block-55107','Copyright','',3),(55114,'117068','furniture-mobile','block-55107','Logo','',1),(55115,'117069','furniture-mobile','email_4','email\\BlockBox','',1),(55116,'117070','furniture-mobile','block-55115','email\\BlockBox','',1),(55117,'117071','furniture-mobile','block-55116','Copyright','',2),(55118,'117072','furniture-mobile','block-55116','email\\BlockBox','',1),(55119,'117073','furniture-mobile','block-55118','email\\BlockBox','',1),(55120,'117074','furniture-mobile','block-55119','Logo','',1),(55121,'117075','furniture-mobile','block-55119-2','email\\Date','',2),(55122,'117076','furniture-mobile','block-55119-2','email\\Title','',1),(55123,'117077','furniture-mobile','block-55118','email\\Content','',2),(55124,'121029','furniture-mobile','filescatalog_category','BlockBox','',1),(55125,'121030','furniture-mobile','block-55124','FilesCatalog\\widgets\\FilesList','',3),(55126,'121031','furniture-mobile','block-55124','FilesCatalog\\widgets\\Title','',1),(55127,'121032','furniture-mobile','block-55124','FilesCatalog\\widgets\\Description','',2),(55128,'121025','furniture-mobile','filescatalog_index','BlockBox','',1),(55129,'121026','furniture-mobile','block-55128','Html_box','',1),(55130,'121027','furniture-mobile','block-55128','FilesCatalog\\widgets\\FilesCatalog','',2),(55131,'117078','furniture-mobile','footer','BlockBox','footer-content',1),(55132,'120866','furniture-mobile','block-55131','BlockBox','',3),(55133,'117091','furniture-mobile','block-55132','Contacts','',2),(55134,'120868','furniture-mobile','block-55132','Logo','',1),(55135,'120871','furniture-mobile','block-55132-2','BlockBox','',1),(55136,'117085','furniture-mobile','block-55135','Menu','Footer',2),(55137,'117093','furniture-mobile','footer','BlockBox','',2),(55138,'117094','furniture-mobile','block-55137','Copyright','',1),(55139,'117096','furniture-mobile','for_menu','BlockBox','',1),(55140,'117097','furniture-mobile','block-55139','Html_box','',1),(55141,'117098','furniture-mobile','block-55139-2','Languages','',1),(55142,'117099','furniture-mobile','for_menu','BlockBox','',3),(55143,'117100','furniture-mobile','block-55142','Html_box','',1),(55144,'117101','furniture-mobile','block-55142-2','Currencies','',1),(55145,'117102','furniture-mobile','gift','BlockBox','',1),(55146,'117103','furniture-mobile','block-55145','BlockBox','',3),(55147,'117104','furniture-mobile','block-55146','BlockBox','',1),(55148,'117105','furniture-mobile','block-55147','gift\\Card','',1),(55149,'117106','furniture-mobile','block-55146-2','gift\\Form','',2),(55150,'117107','furniture-mobile','block-55146-2','Text','',1),(55151,'117108','furniture-mobile','block-55145','info\\Title','',1),(55152,'117109','furniture-mobile','gift_card','BlockBox','',1),(55153,'117110','furniture-mobile','block-55152','BlockBox','',11),(55154,'117111','furniture-mobile','block-55153','invoice\\StoreEmail','',3),(55155,'117112','furniture-mobile','block-55153','Text','',1),(55156,'117113','furniture-mobile','block-55153','invoice\\StorePhone','',2),(55157,'117114','furniture-mobile','block-55152','Text','',8),(55158,'117115','furniture-mobile','block-55152','Text','',3),(55159,'117116','furniture-mobile','block-55152','BlockBox','',10),(55160,'117117','furniture-mobile','block-55159','Text','',1),(55161,'117118','furniture-mobile','block-55159-2','gift\\CodeView','',1),(55162,'117119','furniture-mobile','block-55152','gift\\MessageView','',7),(55163,'117120','furniture-mobile','block-55152','gift\\AmountView','',5),(55164,'117121','furniture-mobile','block-55152','Text','',6),(55165,'117123','furniture-mobile','block-55152','Logo','',1),(55166,'117124','furniture-mobile','block-55152','Text','',4),(55167,'117125','furniture-mobile','block-55152','Text','',9),(55168,'117126','furniture-mobile','gift_card_2','BlockBox','',1),(55169,'117127','furniture-mobile','block-55168','gift\\AmountView','',4),(55170,'117128','furniture-mobile','block-55168','BlockBox','',9),(55171,'117129','furniture-mobile','block-55170','Text','',1),(55172,'117130','furniture-mobile','block-55170-2','gift\\CodeView','',1),(55173,'117131','furniture-mobile','block-55168','BlockBox','',10),(55174,'117132','furniture-mobile','block-55173','invoice\\StoreEmail','',3),(55175,'117133','furniture-mobile','block-55173','Text','',1),(55176,'117134','furniture-mobile','block-55173','invoice\\StorePhone','',2),(55177,'117135','furniture-mobile','block-55168','gift\\MessageView','',6),(55178,'117136','furniture-mobile','block-55168','Text','',5),(55179,'117137','furniture-mobile','block-55168','Text','',8),(55180,'117138','furniture-mobile','block-55168','Text','',3),(55181,'117139','furniture-mobile','block-55168','Text','',7),(55182,'1638804282.8587','furniture-mobile','block-55168','Logo','',1),(55183,'117141','furniture-mobile','gift_card_2_pdf','BlockBox','',1),(55184,'117142','furniture-mobile','block-55183','BlockBox','',12),(55185,'117143','furniture-mobile','block-55184','invoice\\StoreEmail','',4),(55186,'117144','furniture-mobile','block-55184','invoice\\StorePhone','',3),(55187,'117145','furniture-mobile','block-55184','Html_box','',1),(55188,'117146','furniture-mobile','block-55183','BlockBox','',11),(55189,'117147','furniture-mobile','block-55188','Html_box','',1),(55190,'117148','furniture-mobile','block-55188-2','gift\\CodeViewPdf','',1),(55191,'117149','furniture-mobile','block-55183','BlockBox','',1),(55192,'117150','furniture-mobile','block-55191','Text','',4),(55193,'117151','furniture-mobile','block-55191','Html_box','',1),(55194,'117152','furniture-mobile','block-55191','Html_box','',2),(55195,'117153','furniture-mobile','block-55191','gift\\AmountViewPdf','',3),(55196,'117154','furniture-mobile','block-55191','gift\\MessageViewPdf','',5),(55197,'117155','furniture-mobile','block-55191','Html_box','',7),(55198,'117156','furniture-mobile','block-55191','Html_box','',6),(55199,'117157','furniture-mobile','gift_card_2_pdf','Import','',1),(55200,'117158','furniture-mobile','gift_card_pdf','BlockBox','',1),(55201,'117159','furniture-mobile','block-55200','BlockBox','',12),(55202,'117160','furniture-mobile','block-55201','invoice\\StoreEmail','',4),(55203,'117161','furniture-mobile','block-55201','invoice\\StorePhone','',3),(55204,'117162','furniture-mobile','block-55201','Html_box','',1),(55205,'117163','furniture-mobile','block-55200','BlockBox','',11),(55206,'117164','furniture-mobile','block-55205','Html_box','',1),(55207,'117165','furniture-mobile','block-55205-2','gift\\CodeViewPdf','',1),(55208,'117166','furniture-mobile','block-55200','BlockBox','',1),(55209,'117167','furniture-mobile','block-55208','Text','',5),(55210,'117169','furniture-mobile','block-55208','Html_box','',3),(55211,'117170','furniture-mobile','block-55208','gift\\AmountViewPdf','',4),(55212,'117171','furniture-mobile','block-55208','gift\\MessageViewPdf','',6),(55213,'117172','furniture-mobile','block-55208','Html_box','',8),(55214,'117173','furniture-mobile','block-55208','Html_box','',7),(55215,'1638978695.8384','furniture-mobile','block-55208','Logo','',2),(55216,'117175','furniture-mobile','gift_certificate','BlockBox','',1),(55217,'117176','furniture-mobile','block-55216','account\\ApplyCertificate','',2),(55218,'117177','furniture-mobile','block-55216','Html_box','',1),(55219,'117178','furniture-mobile','gigt_card_3','BlockBox','',1),(55220,'117179','furniture-mobile','block-55219','BlockBox','',9),(55221,'117180','furniture-mobile','block-55220','Text','',1),(55222,'117181','furniture-mobile','block-55220-2','gift\\CodeView','',1),(55223,'117182','furniture-mobile','block-55219','Text','',7),(55224,'117184','furniture-mobile','block-55219','BlockBox','',10),(55225,'117185','furniture-mobile','block-55224','Text','',1),(55226,'117186','furniture-mobile','block-55224','invoice\\StoreEmail','',3),(55227,'117187','furniture-mobile','block-55224','invoice\\StorePhone','',2),(55228,'117188','furniture-mobile','block-55219','gift\\MessageView','',6),(55229,'117189','furniture-mobile','block-55219','Text','',3),(55230,'117190','furniture-mobile','block-55219','Text','',5),(55231,'117191','furniture-mobile','block-55219','gift\\AmountView','',4),(55232,'117192','furniture-mobile','block-55219','Text','',8),(55233,'1638804328.7281','furniture-mobile','block-55219','Logo','',1),(55234,'117193','furniture-mobile','gigt_card_3_pdf','BlockBox','',1),(55235,'117194','furniture-mobile','block-55234','BlockBox','',12),(55236,'117195','furniture-mobile','block-55235','invoice\\StoreEmail','',4),(55237,'117196','furniture-mobile','block-55235','invoice\\StorePhone','',3),(55238,'117197','furniture-mobile','block-55235','Html_box','',1),(55239,'117198','furniture-mobile','block-55234','BlockBox','',11),(55240,'117199','furniture-mobile','block-55239','Html_box','',1),(55241,'117200','furniture-mobile','block-55239-2','gift\\CodeViewPdf','',1),(55242,'117201','furniture-mobile','block-55234','BlockBox','',1),(55243,'117202','furniture-mobile','block-55242','Text','',4),(55244,'117203','furniture-mobile','block-55242','Html_box','',1),(55245,'117204','furniture-mobile','block-55242','Html_box','',2),(55246,'117205','furniture-mobile','block-55242','gift\\AmountViewPdf','',3),(55247,'117206','furniture-mobile','block-55242','gift\\MessageViewPdf','',5),(55248,'117207','furniture-mobile','block-55242','Html_box','',7),(55249,'117208','furniture-mobile','block-55242','Html_box','',6),(55250,'117209','furniture-mobile','header','BlockBox','',5),(55251,'117210','furniture-mobile','block-55250','Menu','Categories',1),(55252,'117212','furniture-mobile','header','BlockBox','header-content',4),(55253,'117213','furniture-mobile','block-55252','Logo','',3),(55254,'117214','furniture-mobile','block-55252','Search','',5),(55255,'117215','furniture-mobile','block-55252','GoogleReviews','',8),(55256,'117216','furniture-mobile','block-55252','Cart','',1),(55257,'117217','furniture-mobile','block-55252','Account','',2),(55258,'117218','furniture-mobile','block-55252','Image','',4),(55259,'120877','furniture-mobile','block-55252','Html_box','',7),(55260,'117219','furniture-mobile','header','BlockBox','header-content-small',3),(55261,'117220','furniture-mobile','block-55260','BlockBox','header-content-small-left',1),(55262,'117221','furniture-mobile','block-55261','Menu','Header menu',1),(55263,'117222','furniture-mobile','block-55261','Currencies','',3),(55264,'117223','furniture-mobile','block-55261','Languages','',2),(55265,'121040','furniture-mobile','header','UnsupportedBrowser','',1),(55266,'120887','furniture-mobile','header_menu','Currencies','',2),(55267,'120888','furniture-mobile','header_menu','Languages','',1),(55268,'117224','furniture-mobile','info','BlockBox','info-content',1),(55269,'117225','furniture-mobile','block-55268','info\\DescriptionShort','',3),(55270,'117226','furniture-mobile','block-55268','info\\Content','',6),(55271,'117227','furniture-mobile','block-55268','info\\Title','',1),(55272,'117228','furniture-mobile','block-55268','info\\Image','',4),(55273,'1638467467.3028','furniture-mobile','block-55268','info\\DescriptionShort','',5),(55274,'117229','furniture-mobile','invoice','invoice\\Container','',1),(55275,'117230','furniture-mobile','block-55274','BlockBox','',4),(55276,'117231','furniture-mobile','block-55275','BlockBox','',8),(55277,'117232','furniture-mobile','block-55276','BlockBox','',1),(55278,'117233','furniture-mobile','block-55277','invoice\\ShippingMethod','',2),(55279,'117234','furniture-mobile','block-55277','Text','',1),(55280,'117235','furniture-mobile','block-55276-2','BlockBox','',1),(55281,'117236','furniture-mobile','block-55280','Text','',1),(55282,'117237','furniture-mobile','block-55280','invoice\\ShippingMethod','',2),(55283,'117238','furniture-mobile','block-55275','BlockBox','',7),(55284,'117239','furniture-mobile','block-55283','BlockBox','',2),(55285,'117240','furniture-mobile','block-55284','Text','',2),(55286,'117241','furniture-mobile','block-55284','invoice\\BillingAddress','',3),(55287,'1639659760.0392','furniture-mobile','block-55283','GiftWrapMessage\\ShowInfo','',1),(55288,'117242','furniture-mobile','block-55283-2','BlockBox','',1),(55289,'117243','furniture-mobile','block-55288','Text','',5),(55290,'117244','furniture-mobile','block-55288','invoice\\CustomerName','',2),(55291,'117245','furniture-mobile','block-55288','invoice\\CustomerPhone','',4),(55292,'117246','furniture-mobile','block-55288','Text','',1),(55293,'117247','furniture-mobile','block-55288','Text','',3),(55294,'117248','furniture-mobile','block-55288','invoice\\CustomerEmail','',6),(55295,'117249','furniture-mobile','block-55275-2','invoice\\PaymentMethod','',6),(55296,'117250','furniture-mobile','block-55275-2','Text','',5),(55297,'117251','furniture-mobile','block-55275-2','Text','',3),(55298,'117252','furniture-mobile','block-55275-2','invoice\\OrderId','',2),(55299,'117253','furniture-mobile','block-55275-2','invoice\\PaymentDate','',4),(55300,'117254','furniture-mobile','block-55275-2','invoice\\OrderBarcode','',7),(55301,'117255','furniture-mobile','block-55274','BlockBox','',8),(55302,'117256','furniture-mobile','block-55301','invoice\\StoreAddress','',8),(55303,'117257','furniture-mobile','block-55301','Text','',1),(55304,'117258','furniture-mobile','block-55301-2','Text','',2),(55305,'117260','furniture-mobile','block-55301-3','BlockBox','',3),(55306,'117261','furniture-mobile','block-55305','Text','',1),(55307,'117262','furniture-mobile','block-55305-2','invoice\\StoreEmail','',1),(55308,'117263','furniture-mobile','block-55301-3','BlockBox','',2),(55309,'117264','furniture-mobile','block-55308','Text','',1),(55310,'117265','furniture-mobile','block-55308-2','invoice\\StorePhone','',1),(55311,'117266','furniture-mobile','block-55301-3','Text','',1),(55312,'117267','furniture-mobile','block-55274','invoice\\Products','',5),(55313,'117268','furniture-mobile','block-55274','BlockBox','',7),(55314,'117269','furniture-mobile','block-55313','BlockBox','',1),(55315,'117270','furniture-mobile','block-55314','invoice\\ShippingAddress','',2),(55316,'117271','furniture-mobile','block-55314','Text','',1),(55317,'117272','furniture-mobile','block-55313-2','BlockBox','',1),(55318,'117273','furniture-mobile','block-55317','invoice\\Totals','',1),(55319,'117274','furniture-mobile','block-55274','BlockBox','',2),(55320,'117275','furniture-mobile','block-55319','Logo','',1),(55321,'117276','furniture-mobile','block-55319-2','BlockBox','',4),(55322,'117277','furniture-mobile','block-55321','Text','',1),(55323,'117278','furniture-mobile','block-55321-2','invoice\\StoreSite','',1),(55324,'117279','furniture-mobile','block-55319-2','BlockBox','',3),(55325,'117280','furniture-mobile','block-55324','Text','',1),(55326,'117281','furniture-mobile','block-55324-2','invoice\\StoreEmail','',1),(55327,'117282','furniture-mobile','block-55319-2','BlockBox','',1),(55328,'117283','furniture-mobile','block-55327','invoice\\StoreAddress','',2),(55329,'117284','furniture-mobile','block-55319-2','BlockBox','',2),(55330,'117285','furniture-mobile','block-55329','Text','',1),(55331,'117286','furniture-mobile','block-55329-2','invoice\\StorePhone','',1),(55332,'1640103567.8175','furniture-mobile','block-55274','invoice\\StructuredProducts','',6),(55333,'1640180896.2131','furniture-mobile','block-55274','BlockBox','',1),(55334,'1639994189.268','furniture-mobile','block-55333','invoice\\PaidMark','',1),(55335,'1639996119.9463','furniture-mobile','block-55333','invoice\\UnpaidMark','',2),(55336,'117287','furniture-mobile','login_account','BlockBox','',1),(55337,'117288','furniture-mobile','block-55336','Tabs','',2),(55338,'117289','furniture-mobile','block-55337-1','login\\Returning','',1),(55339,'117290','furniture-mobile','block-55337-2','BlockBox','',1),(55340,'117291','furniture-mobile','block-55339','Html_box','',1),(55341,'117292','furniture-mobile','block-55339-2','BlockBox','',1),(55342,'117293','furniture-mobile','block-55341','Html_box','',2),(55343,'117294','furniture-mobile','block-55341','login\\Register','',1),(55344,'117295','furniture-mobile','block-55336','BlockBox','',1),(55345,'117296','furniture-mobile','block-55344','Html_box','',5),(55346,'117297','furniture-mobile','block-55344','Html_box','',1),(55347,'117298','furniture-mobile','block-55344','login\\Socials','',4),(55348,'117299','furniture-mobile','login_checkout','BlockBox','',1),(55349,'117300','furniture-mobile','block-55348','BlockBox','',1),(55350,'117301','furniture-mobile','block-55349','checkout\\CreateBtn','',4),(55351,'117302','furniture-mobile','block-55349','checkout\\GuestBtn','',2),(55352,'117303','furniture-mobile','block-55349','Html_box','',3),(55353,'117304','furniture-mobile','block-55349','BlockBox','',5),(55354,'117305','furniture-mobile','block-55353','Html_box','',1),(55355,'117306','furniture-mobile','block-55353','login\\Socials','',2),(55356,'117307','furniture-mobile','block-55349','Html_box','',1),(55357,'117308','furniture-mobile','block-55349-2','login\\Returning','',2),(55358,'117309','furniture-mobile','block-55349-2','Html_box','',1),(55359,'117310','furniture-mobile','login_checkout2','BlockBox','',1),(55360,'117311','furniture-mobile','block-55359','Tabs','',4),(55361,'117312','furniture-mobile','block-55360-1','BlockBox','',1),(55362,'117313','furniture-mobile','block-55361','Html_box','',1),(55363,'117314','furniture-mobile','block-55361-2','BlockBox','',1),(55364,'117315','furniture-mobile','block-55363','login\\Guest','',1),(55365,'117316','furniture-mobile','block-55363','Html_box','',2),(55366,'117317','furniture-mobile','block-55360-2','login\\Returning','',1),(55367,'117318','furniture-mobile','block-55360-3','BlockBox','',1),(55368,'117319','furniture-mobile','block-55367','Html_box','',1),(55369,'117320','furniture-mobile','block-55367-2','BlockBox','',1),(55370,'117321','furniture-mobile','block-55369','Html_box','',2),(55371,'117322','furniture-mobile','block-55369','login\\Register','',1),(55372,'117323','furniture-mobile','block-55359','login\\Socials','',2),(55373,'117324','furniture-mobile','block-55359','Html_box','',3),(55374,'117325','furniture-mobile','block-55359','Html_box','',1),(55375,'117326','furniture-mobile','login_checkout2_q','BlockBox','',1),(55376,'117327','furniture-mobile','block-55375','Tabs','',4),(55377,'117328','furniture-mobile','block-55376-1','BlockBox','',1),(55378,'117329','furniture-mobile','block-55377','Html_box','',1),(55379,'117330','furniture-mobile','block-55377-2','quote\\FastOrder','',1),(55380,'117331','furniture-mobile','block-55376-2','login\\Returning','',1),(55381,'117332','furniture-mobile','block-55376-3','BlockBox','',1),(55382,'117333','furniture-mobile','block-55381','Html_box','',1),(55383,'117334','furniture-mobile','block-55381','Import','',2),(55384,'117335','furniture-mobile','block-55381-2','BlockBox','',1),(55385,'117336','furniture-mobile','block-55384','login\\Register','',1),(55386,'117337','furniture-mobile','block-55384','Html_box','',2),(55387,'117338','furniture-mobile','block-55375','Html_box','',3),(55388,'117339','furniture-mobile','block-55375','Html_box','',1),(55389,'117340','furniture-mobile','block-55375','login\\Socials','',2),(55390,'117341','furniture-mobile','login_checkout2_s','BlockBox','',1),(55391,'117342','furniture-mobile','block-55390','login\\Socials','',2),(55392,'117343','furniture-mobile','block-55390','Html_box','',3),(55393,'117344','furniture-mobile','block-55390','Tabs','',4),(55394,'117345','furniture-mobile','block-55393-1','BlockBox','',1),(55395,'117346','furniture-mobile','block-55394','Html_box','',1),(55396,'117347','furniture-mobile','block-55394-2','quote\\FastOrder','',1),(55397,'117348','furniture-mobile','block-55393-2','login\\Returning','',1),(55398,'117349','furniture-mobile','block-55393-3','BlockBox','',1),(55399,'117350','furniture-mobile','block-55398','Html_box','',1),(55400,'117351','furniture-mobile','block-55398-2','BlockBox','',1),(55401,'117352','furniture-mobile','block-55400','login\\Register','',1),(55402,'117353','furniture-mobile','block-55400','Html_box','',2),(55403,'117354','furniture-mobile','block-55390','Html_box','',1),(55404,'117355','furniture-mobile','login_checkout_q','BlockBox','',1),(55405,'117356','furniture-mobile','block-55404','BlockBox','',1),(55406,'117357','furniture-mobile','block-55405','BlockBox','',5),(55407,'117358','furniture-mobile','block-55406','Html_box','',1),(55408,'117359','furniture-mobile','block-55406','login\\Socials','',2),(55409,'117360','furniture-mobile','block-55405','checkout\\GuestBtn','',2),(55410,'117361','furniture-mobile','block-55405','checkout\\CreateBtn','',4),(55411,'117362','furniture-mobile','block-55405','Html_box','',3),(55412,'117363','furniture-mobile','block-55405','Html_box','',1),(55413,'117364','furniture-mobile','block-55405-2','Html_box','',1),(55414,'117365','furniture-mobile','block-55405-2','login\\Returning','',2),(55415,'117366','furniture-mobile','login_checkout_s','BlockBox','',1),(55416,'117367','furniture-mobile','block-55415','BlockBox','',1),(55417,'117368','furniture-mobile','block-55416','Html_box','',1),(55418,'117369','furniture-mobile','block-55416','checkout\\GuestBtn','',2),(55419,'117370','furniture-mobile','block-55416','checkout\\CreateBtn','',4),(55420,'117371','furniture-mobile','block-55416','Html_box','',3),(55421,'117372','furniture-mobile','block-55416','BlockBox','',5),(55422,'117373','furniture-mobile','block-55421','Html_box','',1),(55423,'117374','furniture-mobile','block-55421','login\\Socials','',2),(55424,'117375','furniture-mobile','block-55416-2','Html_box','',1),(55425,'117376','furniture-mobile','block-55416-2','login\\Returning','',2),(55426,'117377','furniture-mobile','logoff','BlockBox','',1),(55427,'117378','furniture-mobile','block-55426','Html_box','',1),(55428,'117379','furniture-mobile','logoff_forever','BlockBox','',1),(55429,'117380','furniture-mobile','block-55428','Html_box','',1),(55430,'117386','furniture-mobile','main','BlockBox','main-content',3),(55431,'120856','furniture-mobile','block-55430','BlockBox','',1),(55432,'120857','furniture-mobile','block-55431','Banner','',1),(55433,'120858','furniture-mobile','block-55430','BlockBox','',2),(55434,'120859','furniture-mobile','block-55433','Html_box','',1),(55435,'120860','furniture-mobile','block-55433-2','Html_box','',1),(55436,'120861','furniture-mobile','block-55433-3','Html_box','',1),(55437,'120862','furniture-mobile','block-55430','BlockBox','',3),(55438,'117389','furniture-mobile','block-55437','NewProducts','8',3),(55439,'121014','furniture-mobile','block-55437','Html_box','',2),(55440,'120864','furniture-mobile','block-55430','BlockBox','',4),(55441,'120865','furniture-mobile','block-55440','Banner','',2),(55442,'121015','furniture-mobile','block-55440','Html_box','',1),(55443,'1683022993.8509','furniture-mobile','main','BlockBox','',2),(55444,'1683023028.4274','furniture-mobile','block-55443','Banner','',1),(55445,'117394','furniture-mobile','manufacturers','BlockBox','',1),(55446,'117395','furniture-mobile','block-55445','Html_box','',1),(55447,'117396','furniture-mobile','block-55445','Brands','',2),(55448,'117397','furniture-mobile','messages-index','BlockBox','',1),(55449,'117398','furniture-mobile','block-55448','BlockBox','',1),(55450,'117399','furniture-mobile','block-55449','BlockBox','',1),(55451,'117400','furniture-mobile','block-55450','Messages\\Sidebar','',1),(55452,'117401','furniture-mobile','block-55449-2','Messages\\Listing','',1),(55453,'117402','furniture-mobile','messages-new','BlockBox','',1),(55454,'117403','furniture-mobile','block-55453','BlockBox','',1),(55455,'117404','furniture-mobile','block-55454','Messages\\Sidebar','',1),(55456,'117405','furniture-mobile','block-55454-2','Messages\\NewMessage','',1),(55457,'117406','furniture-mobile','messages-view','BlockBox','',1),(55458,'117407','furniture-mobile','block-55457','BlockBox','',1),(55459,'117408','furniture-mobile','block-55458','Messages\\Sidebar','',1),(55460,'117409','furniture-mobile','block-55458-2','Messages\\Message','',1),(55461,'117410','furniture-mobile','my_password','BlockBox','',1),(55462,'117411','furniture-mobile','block-55461','BlockBox','',1),(55463,'117412','furniture-mobile','block-55462','WidgetsAria','',1),(55483,'117413','furniture-mobile','block-55462-2','account\\ChangePassword','',2),(55484,'117414','furniture-mobile','block-55462-2','Html_box','',1),(55485,'117415','furniture-mobile','need_login','BlockBox','',1),(55486,'117416','furniture-mobile','block-55485','Tabs','',2),(55487,'117417','furniture-mobile','block-55486-1','login\\Returning','',1),(55488,'117418','furniture-mobile','block-55486-2','BlockBox','',1),(55489,'117419','furniture-mobile','block-55488','Html_box','',2),(55490,'117420','furniture-mobile','block-55488-2','BlockBox','',1),(55491,'117421','furniture-mobile','block-55490','login\\Register','',1),(55492,'117422','furniture-mobile','block-55490','Html_box','',2),(55493,'117423','furniture-mobile','block-55485','BlockBox','',1),(55494,'117424','furniture-mobile','new-topic','BlockBox','',1),(55495,'117425','furniture-mobile','block-55494','Breadcrumb','',2),(55496,'117426','furniture-mobile','block-55494','Communication\\NewTopic','',3),(55497,'117427','furniture-mobile','block-55494','Html_box','',1),(55498,'117428','furniture-mobile','nnnn','BlockBox','',1),(55499,'117429','furniture-mobile','block-55498','catalog\\Title','',1),(55500,'117430','furniture-mobile','block-55498','BlockBox','',2),(55501,'117431','furniture-mobile','block-55500','Filters','',1),(55502,'117432','furniture-mobile','block-55500-2','Listing','',5),(55503,'117433','furniture-mobile','block-55500-2','catalog\\Image','',1),(55504,'117434','furniture-mobile','block-55500-2','BlockBox','',6),(55505,'117435','furniture-mobile','block-55504','catalog\\CountsItems','',1),(55506,'117436','furniture-mobile','block-55504-2','catalog\\Paging','',1),(55507,'117437','furniture-mobile','block-55500-2','catalog\\ImageMapCategory','',3),(55508,'117438','furniture-mobile','block-55500-2','Categories','',2),(55509,'117439','furniture-mobile','block-55500-2','BlockBox','',4),(55510,'117440','furniture-mobile','block-55509','catalog\\ListingLook','',1),(55511,'117441','furniture-mobile','block-55509','catalog\\ItemsOnPage','',4),(55512,'117442','furniture-mobile','block-55509','catalog\\CompareButton','',2),(55513,'117443','furniture-mobile','block-55509','catalog\\Sorting','',3),(55514,'117444','furniture-mobile','no-logged','BlockBox','',1),(55515,'117445','furniture-mobile','block-55514','Communication\\NewTopic','',2),(55516,'117446','furniture-mobile','block-55514','Html_box','',1),(55517,'117447','furniture-mobile','no_filters','BlockBox','catalog-content',1),(55518,'117448','furniture-mobile','block-55517','BlockBox','',4),(55519,'117449','furniture-mobile','block-55518','catalog\\CountsItems','',1),(55520,'117450','furniture-mobile','block-55518-2','catalog\\Paging','',1),(55521,'117451','furniture-mobile','block-55517','Listing','',3),(55522,'117452','furniture-mobile','block-55517','catalog\\Title','',1),(55523,'117453','furniture-mobile','block-55517','catalog\\B2bAddButton','',5),(55524,'117454','furniture-mobile','block-55517','BlockBox','catalog-features',2),(55525,'117455','furniture-mobile','block-55524','BlockBox','',2),(55526,'117456','furniture-mobile','block-55525','HeaderStock','',5),(55527,'117457','furniture-mobile','block-55525','catalog\\ListingLook','',1),(55528,'117458','furniture-mobile','block-55525','catalog\\CompareButton','',2),(55529,'117459','furniture-mobile','block-55525','catalog\\ItemsOnPage','',4),(55530,'117460','furniture-mobile','block-55525','catalog\\Sorting','',3),(55531,'117461','furniture-mobile','block-55524','catalog\\Image','',1),(55532,'117462','furniture-mobile','order_history','BlockBox','',1),(55533,'117463','furniture-mobile','block-55532','BlockBox','',1),(55534,'117464','furniture-mobile','block-55533','WidgetsAria','',1),(55554,'117465','furniture-mobile','block-55533-2','Html_box','',1),(55555,'117466','furniture-mobile','block-55533-2','account\\OrdersHistory','',2),(55556,'117467','furniture-mobile','order_history_info','BlockBox','',1),(55557,'117468','furniture-mobile','block-55556','BlockBox','',1),(55558,'117469','furniture-mobile','block-55557','WidgetsAria','',1),(55578,'117470','furniture-mobile','block-55557-2','account\\OrderInvoiceButton','',3),(55579,'117471','furniture-mobile','block-55557-2','account\\OrderSubTotals','',11),(55580,'117472','furniture-mobile','block-55557-2','account\\OrderPayButton','',5),(55581,'117473','furniture-mobile','block-55557-2','BlockBox','',14),(55582,'117474','furniture-mobile','block-55581','account\\AccountLink','',1),(55583,'117475','furniture-mobile','block-55581-2','account\\OrderInvoiceButton','',1),(55584,'117476','furniture-mobile','block-55557-2','Html_box','',9),(55585,'117477','furniture-mobile','block-55557-2','account\\OrderHistory','',13),(55586,'117478','furniture-mobile','block-55557-2','account\\OrderCancelAndReorder','',4),(55587,'117479','furniture-mobile','block-55557-2','account\\OrderHeading','',1),(55588,'117480','furniture-mobile','block-55557-2','account\\OrderDownload','',6),(55589,'117481','furniture-mobile','block-55557-2','Html_box','',12),(55590,'117482','furniture-mobile','block-55557-2','account\\OrderProducts','',10),(55591,'117483','furniture-mobile','block-55557-2','account\\OrderReorderButton','',2),(55592,'117484','furniture-mobile','block-55557-2','BlockBox','',8),(55593,'117485','furniture-mobile','block-55592','BlockBox','',2),(55594,'117486','furniture-mobile','block-55593','Html_box','',1),(55595,'117487','furniture-mobile','block-55593','account\\OrderData','',2),(55596,'117488','furniture-mobile','block-55592','BlockBox','',1),(55597,'117489','furniture-mobile','block-55596','Html_box','',1),(55598,'117490','furniture-mobile','block-55596','account\\OrderData','',2),(55599,'117491','furniture-mobile','block-55592','BlockBox','',3),(55600,'117492','furniture-mobile','block-55599','account\\OrderTracking','',2),(55601,'117493','furniture-mobile','block-55599','Html_box','',1),(55602,'117494','furniture-mobile','block-55599','account\\AccountLink','',3),(55603,'117495','furniture-mobile','block-55592-2','BlockBox','',2),(55604,'117496','furniture-mobile','block-55603','account\\OrderData','',2),(55605,'117497','furniture-mobile','block-55603','Html_box','',1),(55606,'117498','furniture-mobile','block-55592-2','BlockBox','',1),(55607,'117499','furniture-mobile','block-55606','account\\OrderData','',2),(55608,'117500','furniture-mobile','block-55606','Html_box','',1),(55609,'117501','furniture-mobile','block-55592-3','BlockBox','',2),(55610,'117502','furniture-mobile','block-55609','account\\OrderData','',2),(55611,'117503','furniture-mobile','block-55609','Html_box','',1),(55612,'117504','furniture-mobile','block-55592-3','BlockBox','',1),(55613,'117505','furniture-mobile','block-55612','Html_box','',1),(55614,'117506','furniture-mobile','block-55612','account\\OrderData','',2),(55615,'117507','furniture-mobile','order_pay','BlockBox','',1),(55616,'117508','furniture-mobile','block-55615','BlockBox','',1),(55617,'117509','furniture-mobile','block-55616','WidgetsAria','',1),(55637,'117510','furniture-mobile','block-55616-2','account\\OrderProducts','',4),(55638,'117511','furniture-mobile','block-55616-2','BlockBox','',2),(55639,'117512','furniture-mobile','block-55638','BlockBox','',1),(55640,'117513','furniture-mobile','block-55639','Html_box','',1),(55641,'117514','furniture-mobile','block-55639','account\\OrderData','',2),(55642,'117515','furniture-mobile','block-55638','BlockBox','',4),(55643,'117516','furniture-mobile','block-55642','account\\OrderData','',2),(55644,'117517','furniture-mobile','block-55642','Html_box','',1),(55645,'117518','furniture-mobile','block-55638-2','BlockBox','',1),(55646,'117519','furniture-mobile','block-55645','Html_box','',1),(55647,'117520','furniture-mobile','block-55645','account\\OrderData','',2),(55648,'117521','furniture-mobile','block-55638-2','BlockBox','',2),(55649,'117522','furniture-mobile','block-55648','account\\OrderData','',2),(55650,'117523','furniture-mobile','block-55648','Html_box','',1),(55651,'117524','furniture-mobile','block-55638-3','BlockBox','',2),(55652,'117525','furniture-mobile','block-55651','Html_box','',1),(55653,'117526','furniture-mobile','block-55651','account\\OrderData','',2),(55654,'117527','furniture-mobile','block-55638-3','BlockBox','',1),(55655,'117528','furniture-mobile','block-55654','account\\OrderData','',2),(55656,'117529','furniture-mobile','block-55654','Html_box','',1),(55657,'117530','furniture-mobile','block-55616-2','UpdateAndPay\\PayForm','',6),(55658,'117531','furniture-mobile','block-55616-2','Html_box','',3),(55659,'117532','furniture-mobile','block-55616-2','account\\OrderHeading','',1),(55660,'117533','furniture-mobile','block-55616-2','account\\OrderSubTotals','',5),(55661,'117534','furniture-mobile','packingslip','invoice\\Container','',2),(55662,'117535','furniture-mobile','block-55661','BlockBox','',2),(55663,'117536','furniture-mobile','block-55662','Logo','',1),(55664,'117537','furniture-mobile','block-55662-2','BlockBox','',3),(55665,'117538','furniture-mobile','block-55664','Text','',2),(55666,'117539','furniture-mobile','block-55664-2','invoice\\StoreEmail','',1),(55667,'117540','furniture-mobile','block-55662-2','BlockBox','',2),(55668,'117541','furniture-mobile','block-55667','Text','',2),(55669,'117542','furniture-mobile','block-55667-2','invoice\\StorePhone','',1),(55670,'117543','furniture-mobile','block-55662-2','BlockBox','',1),(55671,'117544','furniture-mobile','block-55670','invoice\\StoreAddress','',1),(55672,'117545','furniture-mobile','block-55662-2','BlockBox','',4),(55673,'117546','furniture-mobile','block-55672','Text','',2),(55674,'117547','furniture-mobile','block-55672-2','invoice\\StoreSite','',1),(55675,'117548','furniture-mobile','block-55661','packingslip\\Products','',5),(55676,'117549','furniture-mobile','block-55661','BlockBox','',6),(55677,'117550','furniture-mobile','block-55676','invoice\\StoreAddress','',2),(55678,'117551','furniture-mobile','block-55676','Text','',1),(55679,'117552','furniture-mobile','block-55661','BlockBox','',3),(55680,'117553','furniture-mobile','block-55679','BlockBox','',2),(55681,'117554','furniture-mobile','block-55680','BlockBox','',1),(55682,'117555','furniture-mobile','block-55681','invoice\\ShippingAddress','',2),(55683,'117556','furniture-mobile','block-55681','Text','',1),(55684,'117557','furniture-mobile','block-55680-2','BlockBox','',1),(55685,'117558','furniture-mobile','block-55684','Text','',1),(55686,'117559','furniture-mobile','block-55684','invoice\\CustomerName','',2),(55687,'117560','furniture-mobile','block-55684','invoice\\CustomerEmail','',6),(55688,'117561','furniture-mobile','block-55684','Text','',3),(55689,'117562','furniture-mobile','block-55684','invoice\\CustomerPhone','',4),(55690,'117563','furniture-mobile','block-55684','Text','',5),(55691,'117564','furniture-mobile','block-55679','BlockBox','',3),(55692,'117565','furniture-mobile','block-55691','BlockBox','',1),(55693,'117566','furniture-mobile','block-55692','invoice\\ShippingMethod','',2),(55694,'117567','furniture-mobile','block-55692','Text','',1),(55695,'117568','furniture-mobile','block-55691-2','BlockBox','',1),(55696,'117569','furniture-mobile','block-55695','invoice\\ShippingMethod','',2),(55697,'117570','furniture-mobile','block-55695','Text','',1),(55698,'117571','furniture-mobile','block-55679-2','invoice\\AddressQrcode','',1),(55699,'1639660991.8692','furniture-mobile','block-55661','Neighbour\\PackingSlipInfo','',1),(55700,'1639661081.5616','furniture-mobile','block-55661','Neighbour\\PackingSlipInfo','',4),(55701,'117572','furniture-mobile','password_forgotten','BlockBox','',1),(55702,'117573','furniture-mobile','block-55701','BlockBox','',2),(55703,'1638807246.6206','furniture-mobile','block-55702','Html_box','',1),(55704,'117574','furniture-mobile','block-55702-2','Html_box','',1),(55705,'117575','furniture-mobile','block-55702-2','login\\PasswordForgotten','',2),(55706,'117576','furniture-mobile','block-55701','Html_box','',1),(55707,'117577','furniture-mobile','pdf','invoice\\Container','',1),(55708,'117578','furniture-mobile','block-55707','BlockBox','',1),(55709,'117579','furniture-mobile','block-55708','BlockBox','',1),(55710,'117580','furniture-mobile','block-55709','BlockBox','',1),(55711,'117581','furniture-mobile','block-55710','pdf\\ProductElement','',1),(55712,'117582','furniture-mobile','block-55709','BlockBox','',2),(55713,'117583','furniture-mobile','block-55712','pdf\\ProductElement','',1),(55714,'117584','furniture-mobile','block-55712-2','pdf\\ProductElement','',2),(55715,'117585','furniture-mobile','block-55712-2','pdf\\ProductElement','',1),(55716,'117586','furniture-mobile','block-55708-2','BlockBox','',1),(55717,'117587','furniture-mobile','block-55716','BlockBox','',2),(55718,'117588','furniture-mobile','block-55717','pdf\\ProductElement','',1),(55719,'117589','furniture-mobile','block-55717-2','pdf\\ProductElement','',2),(55720,'117590','furniture-mobile','block-55717-2','pdf\\ProductElement','',1),(55721,'117591','furniture-mobile','block-55716','BlockBox','',1),(55722,'117592','furniture-mobile','block-55721','pdf\\ProductElement','',1),(55723,'117593','furniture-mobile','pdf_category','pdf\\CategoryName','',2),(55724,'117594','furniture-mobile','pdf_category','pdf\\CategoryImage','',1),(55725,'117595','furniture-mobile','pdf_cover','invoice\\Container','',1),(55726,'117596','furniture-mobile','block-55725','Logo','',1),(55727,'117597','furniture-mobile','block-55725','Text','',3),(55728,'117598','furniture-mobile','pdf_footer','BlockBox','',1),(55729,'117599','furniture-mobile','block-55728-2','pdf\\PageNumber','',1),(55730,'117600','furniture-mobile','pdf_header','pdf\\CategoryName','',1),(55731,'117601','furniture-mobile','personal_catalog','BlockBox','',1),(55732,'117602','furniture-mobile','block-55731','BlockBox','',1),(55733,'117603','furniture-mobile','block-55732','WidgetsAria','',1),(55753,'117604','furniture-mobile','block-55732-2','Html_box','',1),(55754,'117606','furniture-mobile','block-55732-2','account\\PersonalCatalog','',2),(55755,'117607','furniture-mobile','points_earnt_history','BlockBox','',1),(55756,'117608','furniture-mobile','block-55755','Html_box','',1),(55757,'117609','furniture-mobile','block-55755','account\\PointsEarntHistory','',2),(55758,'117610','furniture-mobile','posts','BlockBox','',1),(55759,'117611','furniture-mobile','block-55758','Breadcrumb','',2),(55760,'117612','furniture-mobile','block-55758','Html_box','',1),(55761,'117613','furniture-mobile','block-55758','Communication\\Post','',3),(55762,'117614','furniture-mobile','product','BlockBox','product-content',2),(55763,'120997','furniture-mobile','block-55762','BlockBox','',1),(55764,'117646','furniture-mobile','block-55763','Tabs','',2),(55765,'117647','furniture-mobile','block-55764-1','product\\Description','',2),(55766,'117648','furniture-mobile','block-55764-1','product\\Properties','',1),(55767,'121011','furniture-mobile','block-55764-2','Html_box','',1),(55768,'1638898052.8626','furniture-mobile','block-55764-3','product\\Attributes','',1),(55769,'117654','furniture-mobile','block-55763','product\\CrossSell','',1),(55770,'121002','furniture-mobile','block-55762','Tabs','',3),(55771,'117645','furniture-mobile','block-55770-1','product\\AlsoPurchased','10',1),(55772,'117641','furniture-mobile','block-55770-2','ViewedProducts','4',1),(55773,'121004','furniture-mobile','block-55762','BlockBox','',2),(55774,'121005','furniture-mobile','block-55773','Html_box','',1),(55775,'121006','furniture-mobile','block-55773-2','Html_box','',1),(55776,'121007','furniture-mobile','block-55773-3','Html_box','',1),(55777,'121010','furniture-mobile','block-55762','BlockBox','',4),(55778,'117649','furniture-mobile','block-55777','product\\Reviews','',1),(55779,'1639053401.678','furniture-mobile','product','BlockBox','',0),(55780,'117616','furniture-mobile','block-55779','BlockBox','product-image',5),(55781,'117618','furniture-mobile','block-55780','product\\Images','',2),(55782,'117620','furniture-mobile','block-55780','product\\PromotionIcons','',1),(55783,'1638463239.7427','furniture-mobile','block-55780','product\\QuantityDiscounts','',3),(55784,'1639416584.6039','furniture-mobile','block-55780','product\\PropertiesIcons','',4),(55785,'1639497493.4253','furniture-mobile','block-55780','ProductDesigner\\Designer','',8),(55786,'1639497522.4889','furniture-mobile','block-55780','ProductDesigner\\Button','',6),(55787,'1639497722.549','furniture-mobile','block-55780','ProductDesigner\\Picture','',5),(55788,'120988','furniture-mobile','block-55780-2','BlockBox','product-side',3),(55789,'121009','furniture-mobile','block-55788','BlockBox','',1),(55790,'117629','furniture-mobile','block-55789','product\\DescriptionShort','',2),(55791,'117638','furniture-mobile','block-55789','product\\Model','',1),(55792,'121016','furniture-mobile','block-55789','Html_box','',3),(55793,'1639414189.221','furniture-mobile','block-55789','WeddingRegistry\\Button','',4),(55794,'1639656190.5331','furniture-mobile','block-55789','product\\Groups','',5),(55795,'121008','furniture-mobile','block-55788-2','BlockBox','',1),(55796,'120991','furniture-mobile','block-55795','BlockBox','',1),(55797,'120989','furniture-mobile','block-55796','product\\SaleEnds','',2),(55798,'120990','furniture-mobile','block-55796','BlockBox','',3),(55799,'117622','furniture-mobile','block-55798','product\\ButtonsQuote','',7),(55800,'117624','furniture-mobile','block-55798','product\\Price','',3),(55801,'117625','furniture-mobile','block-55798','product\\Quantity','',4),(55802,'117627','furniture-mobile','block-55798','product\\Buttons','',5),(55803,'117628','furniture-mobile','block-55798','product\\ButtonsSample','',8),(55804,'117635','furniture-mobile','block-55798','product\\PersonalCatalogButton','',6),(55805,'117640','furniture-mobile','block-55798','product\\Stock','',2),(55806,'1642500303.417','furniture-mobile','block-55798','product\\Attributes','',1),(55807,'1639582674.022','furniture-mobile','block-55795','BlockBox','',3),(55808,'117626','furniture-mobile','block-55807','product\\BonusPoints','',1),(55809,'117639','furniture-mobile','block-55779','product\\Name','',2),(55810,'117644','furniture-mobile','block-55779','Breadcrumb','',1),(55811,'120996','furniture-mobile','block-55779','BlockBox','',6),(55812,'117651','furniture-mobile','block-55811','product\\InBundles','',2),(55813,'120995','furniture-mobile','block-55811','product\\Bundle','',1),(55814,'120998','furniture-mobile','block-55779','BlockBox','product-image',3),(55815,'121000','furniture-mobile','block-55814','product\\Rating','',2),(55816,'121001','furniture-mobile','block-55814','Html_box','',2),(55817,'1639053523.9657','furniture-mobile','product','BlockBox','',0),(55818,'1638963486.2331','furniture-mobile','block-55817','product\\Collection','',4),(55819,'1639149261.0383','furniture-mobile','block-55817','product\\CustomBundle','',3),(55820,'1639659357.0881','furniture-mobile','block-55817','BlockBox','',2),(55821,'1639659044.5523','furniture-mobile','block-55820','ObsoleteProducts\\ObsoleteReplacementProducts','',1),(55822,'117655','furniture-mobile','product-bottom','product\\Properties','',1),(55823,'117656','furniture-mobile','product-tabs','product\\Reviews','',2),(55824,'117657','furniture-mobile','product-tabs','product\\Description','',1),(55825,'117658','furniture-mobile','product-top-left','product\\Images','',1),(55826,'117659','furniture-mobile','product-top-right','product\\Price','',2),(55827,'117660','furniture-mobile','product-top-right','product\\Quantity','',5),(55828,'117661','furniture-mobile','product-top-right','product\\Quantity','',6),(55829,'117662','furniture-mobile','product-top-right','product\\Attributes','',3),(55830,'117663','furniture-mobile','product-top-right','product\\Name','',1),(55831,'117664','furniture-mobile','product-top-right','product\\Buttons','',6),(55832,'117665','furniture-mobile','productListing','BlockBox','listing-item',1),(55833,'120921','furniture-mobile','block-55832','BlockBox','',1),(55834,'120896','furniture-mobile','block-55833','BlockBox','',2),(55835,'117677','furniture-mobile','block-55834','productListing\\compare','',3),(55836,'120882','furniture-mobile','block-55834','productListing\\personalCatalog','',2),(55837,'120895','furniture-mobile','block-55834','productListing\\viewButton','',1),(55838,'120919','furniture-mobile','block-55833','BlockBox','',1),(55839,'117667','furniture-mobile','block-55838','productListing\\bonusPoints','',3),(55840,'117668','furniture-mobile','block-55838','productListing\\description','',7),(55841,'117670','furniture-mobile','block-55838','productListing\\rating','',8),(55842,'117671','furniture-mobile','block-55838','productListing\\image','',1),(55843,'117673','furniture-mobile','block-55838','productListing\\price','',5),(55844,'117675','furniture-mobile','block-55838','productListing\\name','',6),(55845,'117676','furniture-mobile','block-55838','productListing\\stock','',4),(55846,'120863','furniture-mobile','block-55838','productListing\\ratingCounts','',9),(55847,'1639645717.6681','furniture-mobile','block-55838','productListing\\productGroup','',2),(55848,'117678','furniture-mobile','products','BlockBox','catalog-content',1),(55849,'117679','furniture-mobile','block-55848','BlockBox','catalog-side',4),(55850,'117680','furniture-mobile','block-55849','Filters','',3),(55851,'117681','furniture-mobile','block-55849','HeaderStock','',4),(55852,'120916','furniture-mobile','block-55849','BlockBox','',1),(55853,'120918','furniture-mobile','block-55852','BlockBox','',3),(55854,'120884','furniture-mobile','block-55853','Menu','LeftCategories',2),(55855,'120917','furniture-mobile','block-55853','Html_box','',1),(55856,'117682','furniture-mobile','block-55849-2','catalog\\B2bAddButton','',5),(55857,'117683','furniture-mobile','block-55849-2','BlockBox','catalog-features',2),(55858,'117684','furniture-mobile','block-55857','catalog\\Sorting','',3),(55859,'117685','furniture-mobile','block-55857','catalog\\ListingLook','',1),(55860,'117686','furniture-mobile','block-55857','catalog\\ItemsOnPage','',4),(55861,'117687','furniture-mobile','block-55857','catalog\\CompareButton','',2),(55862,'117688','furniture-mobile','block-55849-2','BlockBox','',6),(55863,'117689','furniture-mobile','block-55862','catalog\\CountsItems','',1),(55864,'117690','furniture-mobile','block-55862-2','catalog\\Paging','',1),(55865,'117691','furniture-mobile','block-55849-2','Listing','',4),(55866,'120912','furniture-mobile','block-55849-2','BlockBox','',3),(55867,'120913','furniture-mobile','block-55866','catalog\\CountsItems','',1),(55868,'120914','furniture-mobile','block-55866-2','catalog\\Paging','',1),(55869,'1639760443.0645','furniture-mobile','block-55849-2','catalog\\AdditionalImages','',1),(55870,'117692','furniture-mobile','block-55848','catalog\\Title','',2),(55871,'117693','furniture-mobile','block-55848','BlockBox','',3),(55872,'117694','furniture-mobile','block-55871','catalog\\Image','',2),(55873,'1639415554.3073','furniture-mobile','block-55871','product\\WeddingRegistryButton','',3),(55874,'121018','furniture-mobile','products','Compare','',2),(55875,'117695','furniture-mobile','products-list','packingslip\\AllProductsList','',2),(55876,'117696','furniture-mobile','promotions','BlockBox','info-content',1),(55877,'117697','furniture-mobile','block-55876','promotions\\PromoList','',2),(55878,'117698','furniture-mobile','block-55876','Html_box','',1),(55879,'117699','furniture-mobile','purchase','invoice\\Container','',1),(55880,'117700','furniture-mobile','block-55879','invoice\\Products','',3),(55881,'117701','furniture-mobile','block-55879','BlockBox','',5),(55882,'117702','furniture-mobile','block-55881','Text','',1),(55883,'117703','furniture-mobile','block-55881','invoice\\StoreAddress','',8),(55884,'117704','furniture-mobile','block-55881-2','Text','',2),(55885,'117705','furniture-mobile','block-55881-2','Logo','',1),(55886,'117706','furniture-mobile','block-55881-3','BlockBox','',3),(55887,'117707','furniture-mobile','block-55886','Text','',1),(55888,'117708','furniture-mobile','block-55886-2','invoice\\StoreEmail','',1),(55889,'117709','furniture-mobile','block-55881-3','Text','',1),(55890,'117710','furniture-mobile','block-55881-3','BlockBox','',2),(55891,'117711','furniture-mobile','block-55890','Text','',1),(55892,'117712','furniture-mobile','block-55890-2','invoice\\StorePhone','',1),(55893,'117713','furniture-mobile','block-55879','BlockBox','',1),(55894,'117714','furniture-mobile','block-55893','Logo','',1),(55895,'117715','furniture-mobile','block-55893-2','BlockBox','',2),(55896,'117716','furniture-mobile','block-55895','Text','',1),(55897,'117717','furniture-mobile','block-55895-2','invoice\\StorePhone','',1),(55898,'117718','furniture-mobile','block-55893-2','BlockBox','',4),(55899,'117719','furniture-mobile','block-55898','Text','',1),(55900,'117720','furniture-mobile','block-55898-2','invoice\\StoreSite','',1),(55901,'117721','furniture-mobile','block-55893-2','BlockBox','',1),(55902,'117722','furniture-mobile','block-55901','invoice\\StoreAddress','',1),(55903,'117723','furniture-mobile','block-55893-2','BlockBox','',3),(55904,'117724','furniture-mobile','block-55903','Text','',1),(55905,'117725','furniture-mobile','block-55903-2','invoice\\StoreEmail','',1),(55906,'117726','furniture-mobile','block-55879','BlockBox','',2),(55907,'117727','furniture-mobile','block-55906','BlockBox','',7),(55908,'117728','furniture-mobile','block-55907','BlockBox','',1),(55909,'117729','furniture-mobile','block-55908','invoice\\BillingAddress','',2),(55910,'117730','furniture-mobile','block-55908','Text','',1),(55911,'117731','furniture-mobile','block-55907-2','BlockBox','',1),(55912,'117732','furniture-mobile','block-55911','invoice\\CustomerEmail','',6),(55913,'117733','furniture-mobile','block-55911','Text','',5),(55914,'117734','furniture-mobile','block-55911','invoice\\CustomerPhone','',4),(55915,'117735','furniture-mobile','block-55911','invoice\\CustomerName','',2),(55916,'117736','furniture-mobile','block-55911','Text','',3),(55917,'117737','furniture-mobile','block-55911','Text','',1),(55918,'117738','furniture-mobile','block-55906-2','invoice\\OrderId','',1),(55919,'117739','furniture-mobile','block-55906-2','Text','',2),(55920,'117740','furniture-mobile','block-55906-2','invoice\\PaymentDate','',3),(55921,'117741','furniture-mobile','block-55879','BlockBox','',4),(55922,'117742','furniture-mobile','block-55921','BlockBox','',1),(55923,'117743','furniture-mobile','block-55922','invoice\\ShippingAddress','',2),(55924,'117744','furniture-mobile','block-55922','Text','',1),(55928,'117745','furniture-mobile','quotations','BlockBox','',1),(55929,'117746','furniture-mobile','block-55928','BlockBox','',1),(55930,'117747','furniture-mobile','block-55929','WidgetsAria','',1),(55950,'117748','furniture-mobile','block-55929-2','Html_box','',1),(55951,'117749','furniture-mobile','block-55929-2','Quotations\\QuotationsHistory','',2),(55952,'117750','furniture-mobile','quotation_info','BlockBox','',1),(55953,'117751','furniture-mobile','block-55952','BlockBox','',1),(55954,'117752','furniture-mobile','block-55953','WidgetsAria','',1),(55974,'117753','furniture-mobile','block-55953-2','BlockBox','',5),(55975,'117754','furniture-mobile','block-55974','BlockBox','',1),(55976,'117755','furniture-mobile','block-55975','Quotations\\QuotationData','',2),(55977,'117756','furniture-mobile','block-55975','Html_box','',1),(55978,'117757','furniture-mobile','block-55974','BlockBox','',4),(55979,'117758','furniture-mobile','block-55978','Html_box','',1),(55980,'117759','furniture-mobile','block-55978','Quotations\\QuotationData','',2),(55981,'117760','furniture-mobile','block-55974-2','BlockBox','',2),(55982,'117761','furniture-mobile','block-55981','Html_box','',1),(55983,'117762','furniture-mobile','block-55981','Quotations\\QuotationData','',2),(55984,'117763','furniture-mobile','block-55974-2','BlockBox','',1),(55985,'117764','furniture-mobile','block-55984','Html_box','',1),(55986,'117765','furniture-mobile','block-55984','Quotations\\QuotationData','',2),(55987,'117766','furniture-mobile','block-55974-3','BlockBox','',1),(55988,'117767','furniture-mobile','block-55987','Quotations\\QuotationData','',2),(55989,'117768','furniture-mobile','block-55987','Html_box','',1),(55990,'117769','furniture-mobile','block-55974-3','BlockBox','',2),(55991,'117770','furniture-mobile','block-55990','Quotations\\QuotationData','',2),(55992,'117771','furniture-mobile','block-55990','Html_box','',1),(55993,'117772','furniture-mobile','block-55953-2','Html_box','',6),(55994,'117773','furniture-mobile','block-55953-2','Quotations\\QuotationHistory','',10),(55995,'117774','furniture-mobile','block-55953-2','Html_box','',9),(55996,'117775','furniture-mobile','block-55953-2','Quotations\\QuotationProducts','',7),(55997,'117776','furniture-mobile','block-55953-2','Quotations\\QuotationSubTotal','',8),(55998,'117777','furniture-mobile','block-55953-2','BlockBox','',12),(55999,'117778','furniture-mobile','block-55998','account\\AccountLink','',1),(56000,'117779','furniture-mobile','block-55953-2','Html_box','',4),(56001,'117780','furniture-mobile','quote','BlockBox','',1),(56002,'117781','furniture-mobile','block-56001','cart\\CartTabs','',1),(56003,'117782','furniture-mobile','block-56002','BlockBox','',1),(56004,'117783','furniture-mobile','block-56003','quote\\Products','',1),(56005,'117784','furniture-mobile','block-56003-2','BlockBox','',1),(56006,'117785','furniture-mobile','block-56005','BlockBox','',1),(56007,'117786','furniture-mobile','block-56006','quote\\CheckoutBtn','',2),(56008,'117787','furniture-mobile','block-56002','Quotations\\QuotationSubTotal','',2),(56009,'117788','furniture-mobile','review','BlockBox','',1),(56010,'117789','furniture-mobile','block-56009','BlockBox','',1),(56011,'117790','furniture-mobile','block-56010','WidgetsAria','',1),(56031,'117791','furniture-mobile','block-56010-2','Html_box','',1),(56032,'117792','furniture-mobile','block-56010-2','account\\Reviews','',2),(56033,'117793','furniture-mobile','reviews','BlockBox','info-content',1),(56034,'117794','furniture-mobile','block-56033','reviews\\Heading','',1),(56035,'117795','furniture-mobile','block-56033','reviews\\Content','',2),(56036,'117796','furniture-mobile','rma_document','invoice\\Container','',1),(56037,'117797','furniture-mobile','block-56036','BlockBox','',1),(56038,'117798','furniture-mobile','block-56037','BlockBox','',1),(56039,'117799','furniture-mobile','block-56038','BlockBox','',2),(56040,'117800','furniture-mobile','block-56039','Html_box','',1),(56041,'117801','furniture-mobile','block-56039-2','Html_box','',1),(56042,'117802','furniture-mobile','block-56038','BlockBox','',5),(56043,'117803','furniture-mobile','block-56042','Html_box','',1),(56044,'117804','furniture-mobile','block-56042-2','Html_box','',1),(56045,'117805','furniture-mobile','block-56038','BlockBox','',4),(56046,'117806','furniture-mobile','block-56045','Html_box','',1),(56047,'117807','furniture-mobile','block-56045-2','Html_box','',1),(56048,'117808','furniture-mobile','block-56038','BlockBox','',3),(56049,'117809','furniture-mobile','block-56048','Html_box','',1),(56050,'117810','furniture-mobile','block-56048-2','Html_box','',1),(56051,'117811','furniture-mobile','block-56038','BlockBox','',1),(56052,'117812','furniture-mobile','block-56051','Html_box','',1),(56053,'117813','furniture-mobile','block-56051','Html_box','',2),(56054,'117814','furniture-mobile','block-56037-2','BlockBox','',1),(56055,'117815','furniture-mobile','block-56054','Html_box','',2),(56056,'117816','furniture-mobile','block-56054','Logo','',1),(56057,'117817','furniture-mobile','block-56037-2','BlockBox','',2),(56058,'117818','furniture-mobile','block-56057','BlockBox','',5),(56059,'117819','furniture-mobile','block-56058','BlockBox','',1),(56060,'117820','furniture-mobile','block-56059','Html_box','',1),(56061,'117821','furniture-mobile','block-56059-2','Rma\\DocumentData','',1),(56062,'117822','furniture-mobile','block-56058-2','BlockBox','',1),(56063,'117823','furniture-mobile','block-56062','Html_box','',1),(56064,'117824','furniture-mobile','block-56062-2','Rma\\DocumentData','',1),(56065,'117825','furniture-mobile','block-56057','BlockBox','',4),(56066,'117826','furniture-mobile','block-56065','BlockBox','',1),(56067,'117827','furniture-mobile','block-56066','Html_box','',1),(56068,'117828','furniture-mobile','block-56066-2','Rma\\DocumentData','',1),(56069,'117829','furniture-mobile','block-56065-2','BlockBox','',1),(56070,'117830','furniture-mobile','block-56069','Html_box','',1),(56071,'117831','furniture-mobile','block-56069-2','Rma\\DocumentData','',1),(56072,'117832','furniture-mobile','block-56057','BlockBox','',3),(56073,'117833','furniture-mobile','block-56072','BlockBox','',1),(56074,'117834','furniture-mobile','block-56073','Html_box','',1),(56075,'117835','furniture-mobile','block-56073-2','Rma\\DocumentData','',1),(56076,'117836','furniture-mobile','block-56072-2','BlockBox','',1),(56077,'117837','furniture-mobile','block-56076','Html_box','',1),(56078,'117838','furniture-mobile','block-56076-2','Rma\\DocumentData','',1),(56079,'117839','furniture-mobile','block-56057','BlockBox','',2),(56080,'117840','furniture-mobile','block-56079','Html_box','',1),(56081,'117841','furniture-mobile','block-56079-2','Rma\\DocumentData','',1),(56082,'117842','furniture-mobile','block-56057','BlockBox','',1),(56083,'117843','furniture-mobile','block-56082','BlockBox','',1),(56084,'117844','furniture-mobile','block-56083','Html_box','',1),(56085,'117845','furniture-mobile','block-56083-2','Rma\\DocumentData','',1),(56086,'117846','furniture-mobile','block-56082-2','BlockBox','',1),(56087,'117847','furniture-mobile','block-56086','Html_box','',1),(56088,'117848','furniture-mobile','block-56086-2','Rma\\DocumentData','',1),(56089,'117849','furniture-mobile','block-56037-2','BlockBox','',3),(56090,'117850','furniture-mobile','block-56089','BlockBox','',1),(56091,'117851','furniture-mobile','block-56090','Html_box','',1),(56092,'117852','furniture-mobile','block-56090-2','Rma\\DocumentData','',1),(56093,'117853','furniture-mobile','block-56089-2','BlockBox','',1),(56094,'117854','furniture-mobile','block-56093','Html_box','',1),(56095,'117855','furniture-mobile','block-56093-2','Rma\\DocumentData','',1),(56096,'117856','furniture-mobile','block-56036','BlockBox','',2),(56097,'117857','furniture-mobile','block-56096','Html_box','',1),(56098,'117858','furniture-mobile','block-56096','Rma\\Products','',2),(56099,'117859','furniture-mobile','block-56036','BlockBox','',3),(56100,'117860','furniture-mobile','block-56099','BlockBox','',1),(56101,'117861','furniture-mobile','block-56100','BlockBox','',1),(56102,'117862','furniture-mobile','block-56101','BlockBox','',5),(56103,'117863','furniture-mobile','block-56102','Html_box','',1),(56104,'117864','furniture-mobile','block-56102-2','invoice\\StoreAddress','',2),(56105,'117865','furniture-mobile','block-56102-2','Html_box','',1),(56106,'117866','furniture-mobile','block-56101','BlockBox','',4),(56107,'117867','furniture-mobile','block-56106','Html_box','',1),(56108,'117868','furniture-mobile','block-56106-2','Html_box','',1),(56109,'117869','furniture-mobile','block-56101','BlockBox','',2),(56110,'117870','furniture-mobile','block-56109','Html_box','',1),(56111,'117871','furniture-mobile','block-56109-2','Html_box','',1),(56112,'117872','furniture-mobile','block-56101','BlockBox','',1),(56113,'117873','furniture-mobile','block-56112','Html_box','',1),(56114,'117874','furniture-mobile','block-56101','BlockBox','',3),(56115,'117875','furniture-mobile','block-56114','Html_box','',1),(56116,'117876','furniture-mobile','block-56114-2','Html_box','',1),(56117,'117877','furniture-mobile','block-56101','BlockBox','',6),(56118,'117878','furniture-mobile','block-56117','Html_box','',1),(56119,'117879','furniture-mobile','block-56100-2','BlockBox','',1),(56120,'117880','furniture-mobile','block-56119','BlockBox','',1),(56121,'117881','furniture-mobile','block-56120','BlockBox','',1),(56122,'117882','furniture-mobile','block-56121','Rma\\DocumentData','',2),(56123,'117883','furniture-mobile','block-56121-3','BlockBox','',1),(56124,'117884','furniture-mobile','block-56123','Html_box','',1),(56125,'117885','furniture-mobile','block-56123-2','Rma\\DocumentData','',1),(56126,'117886','furniture-mobile','block-56120','BlockBox','',2),(56127,'117887','furniture-mobile','block-56126-2','invoice\\StoreAddress','',1),(56128,'117888','furniture-mobile','block-56100-2','BlockBox','',2),(56129,'117889','furniture-mobile','block-56128','Html_box','',1),(56130,'117890','furniture-mobile','block-56128','Html_box','',2),(56131,'117891','furniture-mobile','block-56128','Html_box','',3),(56132,'117892','furniture-mobile','block-56128','Html_box','',4),(56133,'117893','furniture-mobile','block-56128','Html_box','',5),(56134,'117894','furniture-mobile','block-56100-2','BlockBox','',4),(56135,'117895','furniture-mobile','block-56134','Html_box','',1),(56136,'117896','furniture-mobile','block-56134-2','Html_box','',1),(56137,'117897','furniture-mobile','block-56134-3','BlockBox','',1),(56138,'117898','furniture-mobile','block-56137','Html_box','',1),(56139,'117899','furniture-mobile','block-56137-2','Html_box','',1),(56140,'117900','furniture-mobile','block-56100-2','BlockBox','',3),(56141,'117901','furniture-mobile','block-56140','Html_box','',1),(56142,'117902','furniture-mobile','block-56140-2','Html_box','',1),(56143,'117903','furniture-mobile','block-56140-3','BlockBox','',1),(56144,'117904','furniture-mobile','block-56143','Html_box','',1),(56145,'117905','furniture-mobile','block-56143-2','Html_box','',1),(56146,'117906','furniture-mobile','rows','BlockBox','listing-item',1),(56147,'117907','furniture-mobile','block-56146','BlockBox','',2),(56148,'117908','furniture-mobile','block-56147','BlockBox','',2),(56149,'117909','furniture-mobile','block-56148','productListing\\bonusPoints','',2),(56150,'117910','furniture-mobile','block-56148','productListing\\image','',1),(56151,'117914','furniture-mobile','block-56148-2','productListing\\name','',1),(56152,'117915','furniture-mobile','block-56148-2','productListing\\description','',2),(56153,'117916','furniture-mobile','block-56148-2','productListing\\model','',4),(56154,'117917','furniture-mobile','block-56148-2','productListing\\attributes','',5),(56155,'120922','furniture-mobile','block-56148-2','productListing\\properties','',3),(56156,'1639146806.7019','furniture-mobile','block-56148-2','productListing\\productGroup','',6),(56157,'117918','furniture-mobile','block-56147-2','BlockBox','listing-item',1),(56158,'117911','furniture-mobile','block-56157','BlockBox','',3),(56159,'117912','furniture-mobile','block-56158','productListing\\rating','',1),(56160,'117913','furniture-mobile','block-56158','productListing\\ratingCounts','',2),(56161,'117919','furniture-mobile','block-56157','productListing\\qtyInput','',4),(56162,'117920','furniture-mobile','block-56157','productListing\\price','',2),(56163,'117922','furniture-mobile','block-56157','productListing\\buyButton','',5),(56164,'117924','furniture-mobile','block-56157','productListing\\stock','',1),(56165,'120924','furniture-mobile','block-56157','BlockBox','',8),(56166,'120925','furniture-mobile','block-56165','productListing\\compare','',3),(56167,'120926','furniture-mobile','block-56165','productListing\\personalCatalog','',2),(56168,'120927','furniture-mobile','block-56165','productListing\\viewButton','',1),(56169,'117925','furniture-mobile','sample','BlockBox','',1),(56170,'117926','furniture-mobile','block-56169','cart\\CartTabs','',1),(56171,'117927','furniture-mobile','block-56170','BlockBox','',1),(56172,'117928','furniture-mobile','block-56171','sample\\Products','',1),(56173,'117929','furniture-mobile','block-56171-2','BlockBox','',1),(56174,'117930','furniture-mobile','block-56173','BlockBox','',1),(56175,'117931','furniture-mobile','block-56174','sample\\CheckoutBtn','',1),(56176,'117932','furniture-mobile','samples','BlockBox','',1),(56177,'117933','furniture-mobile','block-56176','BlockBox','',1),(56178,'117934','furniture-mobile','block-56177','WidgetsAria','',1),(56198,'117935','furniture-mobile','block-56177-2','Html_box','',1),(56199,'117936','furniture-mobile','block-56177-2','Samples\\SamplesHistory','',2),(56200,'117937','furniture-mobile','sample_info','BlockBox','',1),(56201,'117938','furniture-mobile','block-56200','BlockBox','',1),(56202,'117939','furniture-mobile','block-56201','WidgetsAria','',1),(56222,'117940','furniture-mobile','block-56201-2','Html_box','',1),(56223,'117941','furniture-mobile','block-56201-2','BlockBox','',8),(56224,'117942','furniture-mobile','block-56223','account\\AccountLink','',1),(56225,'117943','furniture-mobile','block-56201-2','Samples\\SampleHistory','',7),(56226,'117944','furniture-mobile','block-56201-2','Html_box','',3),(56227,'117945','furniture-mobile','block-56201-2','Samples\\SampleSubTotal','',5),(56228,'117946','furniture-mobile','block-56201-2','Samples\\SampleProducts','',4),(56229,'117947','furniture-mobile','block-56201-2','Html_box','',6),(56230,'117948','furniture-mobile','block-56201-2','BlockBox','',2),(56231,'117949','furniture-mobile','block-56230','BlockBox','',4),(56232,'117950','furniture-mobile','block-56231','Html_box','',1),(56233,'117951','furniture-mobile','block-56231','Samples\\SampleData','',2),(56234,'117952','furniture-mobile','block-56230','BlockBox','',1),(56235,'117953','furniture-mobile','block-56234','Samples\\SampleData','',2),(56236,'117954','furniture-mobile','block-56234','Html_box','',1),(56237,'117955','furniture-mobile','block-56230-2','BlockBox','',2),(56238,'117956','furniture-mobile','block-56237','Samples\\SampleData','',2),(56239,'117957','furniture-mobile','block-56237','Html_box','',1),(56240,'117958','furniture-mobile','block-56230-2','BlockBox','',1),(56241,'117959','furniture-mobile','block-56240','Samples\\SampleData','',2),(56242,'117960','furniture-mobile','block-56240','Html_box','',1),(56243,'117961','furniture-mobile','block-56230-3','BlockBox','',2),(56244,'117962','furniture-mobile','block-56243','Samples\\SampleData','',2),(56245,'117963','furniture-mobile','block-56243','Html_box','',1),(56246,'117964','furniture-mobile','block-56230-3','BlockBox','',1),(56247,'117965','furniture-mobile','block-56246','Samples\\SampleData','',2),(56248,'117966','furniture-mobile','block-56246','Html_box','',1),(56249,'117967','furniture-mobile','sitemap','BlockBox','info-content',1),(56250,'117968','furniture-mobile','block-56249','Html_box','',1),(56251,'117969','furniture-mobile','block-56249','BlockBox','',2),(56252,'117970','furniture-mobile','block-56251','Html_box','',1),(56253,'117971','furniture-mobile','block-56251','Html_box','',5),(56254,'117972','furniture-mobile','block-56251','Html_box','',3),(56255,'117973','furniture-mobile','block-56251','sitemap\\InfoPages','',2),(56256,'117974','furniture-mobile','block-56251','sitemap\\Categories','',4),(56257,'117975','furniture-mobile','block-56251','Menu','Account box',6),(56258,'117976','furniture-mobile','block-56251-2','sitemap\\DeliveryLocation','',2),(56259,'117977','furniture-mobile','block-56251-2','Html_box','',1),(56260,'120878','furniture-mobile','social','SocialLinks','',1),(56261,'117978','furniture-mobile','subscribe','BlockBox','',1),(56262,'117979','furniture-mobile','block-56261','Html_box','',3),(56263,'117980','furniture-mobile','block-56261','subscribers\\UnsubscribeForm','',4),(56264,'117981','furniture-mobile','block-56261','Html_box','',1),(56265,'117982','furniture-mobile','block-56261','subscribers\\SubscribeForm','',2),(56266,'117983','furniture-mobile','subscribed','BlockBox','',1),(56267,'117984','furniture-mobile','block-56266','Html_box','',1),(56268,'117985','furniture-mobile','subscription','BlockBox','',2),(56269,'117986','furniture-mobile','block-56268','BlockBox','',1),(56270,'117987','furniture-mobile','block-56269','WidgetsAria','',1),(56290,'117988','furniture-mobile','block-56269-2','Html_box','',2),(56291,'117989','furniture-mobile','block-56269-2','Html_box','',3),(56292,'117990','furniture-mobile','block-56269-2','account\\Subscription','',4),(56293,'117991','furniture-mobile','success','BlockBox','',2),(56294,'117992','furniture-mobile','block-56293','BlockBox','',1),(56295,'117993','furniture-mobile','block-56294','Html_box','',1),(56296,'117994','furniture-mobile','block-56294','BlockBox','',2),(56297,'117995','furniture-mobile','block-56296','success\\PrintBtn','',1),(56298,'117996','furniture-mobile','block-56296','success\\ContinueBtn','',2),(56299,'1639413072.5477','furniture-mobile','block-56296','success\\Download','',3),(56300,'117997','furniture-mobile','success_q','BlockBox','',1),(56301,'117998','furniture-mobile','block-56300','BlockBox','',1),(56302,'117999','furniture-mobile','block-56301','BlockBox','',2),(56303,'118000','furniture-mobile','block-56302','success\\ContinueBtn','',2),(56304,'118001','furniture-mobile','block-56302','success\\PrintBtn','',1),(56305,'118002','furniture-mobile','block-56301','Html_box','',1),(56310,'118007','furniture-mobile','ticket','invoice\\Container','',1),(56311,'118008','furniture-mobile','block-56310','BlockBox','',4),(56312,'118009','furniture-mobile','block-56311','BlockBox','',1),(56313,'118010','furniture-mobile','block-56312','invoice\\ShippingAddress','',2),(56314,'118011','furniture-mobile','block-56312','Text','',1),(56315,'118012','furniture-mobile','block-56311-2','BlockBox','',1),(56316,'118013','furniture-mobile','block-56315','invoice\\Totals','',1),(56317,'118014','furniture-mobile','block-56310','BlockBox','',5),(56318,'118015','furniture-mobile','block-56317','Text','',1),(56319,'118016','furniture-mobile','block-56317','invoice\\StoreAddress','',8),(56320,'118018','furniture-mobile','block-56317-2','Text','',2),(56321,'118019','furniture-mobile','block-56317-3','Text','',1),(56322,'118020','furniture-mobile','block-56317-3','BlockBox','',3),(56323,'118021','furniture-mobile','block-56322','Text','',1),(56324,'118022','furniture-mobile','block-56322-2','invoice\\StoreEmail','',1),(56325,'118023','furniture-mobile','block-56317-3','BlockBox','',2),(56326,'118024','furniture-mobile','block-56325','Text','',1),(56327,'118025','furniture-mobile','block-56325-2','invoice\\StorePhone','',1),(56328,'118026','furniture-mobile','block-56310','invoice\\Products','',3),(56329,'118027','furniture-mobile','block-56310','BlockBox','',1),(56330,'118028','furniture-mobile','block-56329-2','BlockBox','',3),(56331,'118029','furniture-mobile','block-56330','Text','',1),(56332,'118030','furniture-mobile','block-56330-2','invoice\\StoreEmail','',1),(56333,'118031','furniture-mobile','block-56329-2','BlockBox','',4),(56334,'118032','furniture-mobile','block-56333','Text','',1),(56335,'118033','furniture-mobile','block-56333-2','invoice\\StoreSite','',1),(56336,'118034','furniture-mobile','block-56329-2','BlockBox','',1),(56337,'118035','furniture-mobile','block-56336','invoice\\StoreAddress','',1),(56338,'118036','furniture-mobile','block-56329-2','BlockBox','',2),(56339,'118037','furniture-mobile','block-56338','Text','',1),(56340,'118038','furniture-mobile','block-56338-2','invoice\\StorePhone','',1),(56341,'118039','furniture-mobile','block-56310','BlockBox','',2),(56342,'118040','furniture-mobile','block-56341','BlockBox','',8),(56343,'118041','furniture-mobile','block-56342','BlockBox','',1),(56344,'118042','furniture-mobile','block-56343','Text','',1),(56345,'118043','furniture-mobile','block-56343','invoice\\ShippingMethod','',2),(56346,'118044','furniture-mobile','block-56342-2','BlockBox','',1),(56347,'118045','furniture-mobile','block-56346','Text','',1),(56348,'118046','furniture-mobile','block-56346','invoice\\ShippingMethod','',2),(56349,'118047','furniture-mobile','block-56341','BlockBox','',7),(56350,'118048','furniture-mobile','block-56349','BlockBox','',1),(56351,'118049','furniture-mobile','block-56350','invoice\\BillingAddress','',2),(56352,'118050','furniture-mobile','block-56350','Text','',1),(56353,'118051','furniture-mobile','block-56349-2','BlockBox','',1),(56354,'118052','furniture-mobile','block-56353','invoice\\CustomerName','',2),(56355,'118053','furniture-mobile','block-56353','Text','',3),(56356,'118054','furniture-mobile','block-56353','invoice\\CustomerEmail','',6),(56357,'118055','furniture-mobile','block-56353','invoice\\CustomerPhone','',4),(56358,'118056','furniture-mobile','block-56353','Text','',5),(56359,'118057','furniture-mobile','block-56353','Text','',1),(56360,'118058','furniture-mobile','block-56341-2','invoice\\PaymentDate','',3),(56361,'118059','furniture-mobile','block-56341-2','Text','',2),(56362,'118060','furniture-mobile','block-56341-2','Text','',4),(56363,'118061','furniture-mobile','block-56341-2','invoice\\OrderId','',1),(56364,'118062','furniture-mobile','block-56341-2','invoice\\PaymentMethod','',5),(56365,'118063','furniture-mobile','block-56341-2','invoice\\OrderBarcode','',6),(56366,'118064','furniture-mobile','tl_blog_category','BlockBox','',1),(56367,'118065','furniture-mobile','block-56366','BlockBox','',1),(56368,'118066','furniture-mobile','block-56367','BlockBox','',1),(56369,'118067','furniture-mobile','block-56368','Blog\\widget\\PostListing','',1),(56370,'118068','furniture-mobile','block-56368','catalog\\Paging','',2),(56371,'118069','furniture-mobile','block-56367-2','WidgetsAria','',1),(56376,'118070','furniture-mobile','tl_blog_index','BlockBox','',2),(56377,'118071','furniture-mobile','block-56376','Banner','',1),(56378,'118072','furniture-mobile','block-56376','BlockBox','',2),(56379,'118073','furniture-mobile','block-56378','BlockBox','',1),(56380,'118074','furniture-mobile','block-56379','catalog\\Paging','',2),(56381,'118075','furniture-mobile','block-56379','Blog\\widget\\PostListing','',1),(56382,'118076','furniture-mobile','block-56378-2','WidgetsAria','',1),(56387,'118077','furniture-mobile','tl_blog_post','BlockBox','',1),(56388,'118078','furniture-mobile','block-56387','BlockBox','',3),(56389,'118079','furniture-mobile','block-56388','Blog\\widget\\PostLinkedProducts','',4),(56390,'118080','furniture-mobile','block-56388','BlockBox','',1),(56391,'118081','furniture-mobile','block-56390','Blog\\widget\\PostImage','',1),(56392,'118082','furniture-mobile','block-56390','Blog\\widget\\PostDate','',2),(56393,'118083','furniture-mobile','block-56390','Blog\\widget\\PostTitle','',3),(56394,'118084','furniture-mobile','block-56390','Blog\\widget\\PostDescription','',4),(56395,'118085','furniture-mobile','block-56390','BlockBox','',5),(56396,'118086','furniture-mobile','block-56395','Blog\\widget\\PostViewed','',1),(56397,'118087','furniture-mobile','block-56388-2','WidgetsAria','',1),(56402,'118088','furniture-mobile','tl_blog_tags','BlockBox','',1),(56403,'118089','furniture-mobile','block-56402','BlockBox','',1),(56404,'118090','furniture-mobile','block-56403','BlockBox','',1),(56405,'118091','furniture-mobile','block-56404','Blog\\widget\\PostListing','',1),(56406,'118092','furniture-mobile','block-56404','catalog\\Paging','',2),(56407,'118093','furniture-mobile','block-56403-2','WidgetsAria','',1),(56408,'116208','furniture-mobile','blogsidebar','BlockBox','',1),(56409,'116209','furniture-mobile','block-56408','Blog\\widget\\MostPopularPosts','',3),(56410,'116210','furniture-mobile','block-56408','Blog\\widget\\TagCloud','',2),(56411,'116211','furniture-mobile','block-56408','Blog\\widget\\CategoriesList','',1),(56412,'118094','furniture-mobile','tracking_numbers','BlockBox','',1),(56413,'118095','furniture-mobile','block-56412','Html_box','',1),(56414,'118096','furniture-mobile','block-56412','account\\OrderTracking','',2),(56415,'118097','furniture-mobile','trade_form','BlockBox','',1),(56416,'118098','furniture-mobile','block-56415','Html_box','',6),(56417,'118099','furniture-mobile','block-56415','BlockBox','',7),(56418,'118100','furniture-mobile','block-56417','BlockBox','',1),(56419,'118101','furniture-mobile','block-56418','account\\CustomerAdditionalField','',2),(56420,'118102','furniture-mobile','block-56418','account\\CustomerAdditionalField','',1),(56421,'118103','furniture-mobile','block-56417-2','BlockBox','',1),(56422,'118104','furniture-mobile','block-56421','account\\CustomerAdditionalField','',2),(56423,'118105','furniture-mobile','block-56421','account\\CustomerAdditionalField','',1),(56424,'118106','furniture-mobile','block-56415','BlockBox','',5),(56425,'118107','furniture-mobile','block-56424','BlockBox','',1),(56426,'118108','furniture-mobile','block-56425','account\\CustomerAdditionalField','',1),(56427,'118109','furniture-mobile','block-56425','account\\CustomerAdditionalField','',2),(56428,'118110','furniture-mobile','block-56415','Html_box','',2),(56429,'118111','furniture-mobile','block-56415','BlockBox','',4),(56430,'118112','furniture-mobile','block-56429','BlockBox','',1),(56431,'118113','furniture-mobile','block-56430','account\\AddressesList','',2),(56432,'118114','furniture-mobile','block-56430','BlockBox','',4),(56433,'118115','furniture-mobile','block-56432','BlockBox','',1),(56434,'118116','furniture-mobile','block-56433','account\\CustomerAdditionalField','',3),(56435,'118117','furniture-mobile','block-56433','account\\CustomerAdditionalField','',1),(56436,'118118','furniture-mobile','block-56433','account\\CustomerAdditionalField','',2),(56437,'118119','furniture-mobile','block-56433','account\\CustomerAdditionalField','',4),(56438,'118120','furniture-mobile','block-56432-2','BlockBox','',1),(56439,'118121','furniture-mobile','block-56438','account\\CustomerAdditionalField','',4),(56440,'118122','furniture-mobile','block-56438','account\\CustomerAdditionalField','',1),(56441,'118123','furniture-mobile','block-56438','account\\CustomerAdditionalField','',2),(56442,'118124','furniture-mobile','block-56438','account\\CustomerAdditionalField','',3),(56443,'118125','furniture-mobile','block-56430','BlockBox','',3),(56444,'118126','furniture-mobile','block-56443','account\\CustomerAdditionalField','',1),(56445,'118127','furniture-mobile','block-56430','Html_box','',1),(56446,'118128','furniture-mobile','block-56429-2','BlockBox','',1),(56447,'118129','furniture-mobile','block-56446','account\\AddressesList','',2),(56448,'118130','furniture-mobile','block-56446','Html_box','',1),(56449,'118131','furniture-mobile','block-56446','BlockBox','',4),(56450,'118132','furniture-mobile','block-56449','BlockBox','',1),(56451,'118133','furniture-mobile','block-56450','account\\CustomerAdditionalField','',3),(56452,'118134','furniture-mobile','block-56450','account\\CustomerAdditionalField','',1),(56453,'118135','furniture-mobile','block-56450','account\\CustomerAdditionalField','',2),(56454,'118136','furniture-mobile','block-56449-2','BlockBox','',1),(56455,'118137','furniture-mobile','block-56454','account\\CustomerAdditionalField','',1),(56456,'118138','furniture-mobile','block-56454','account\\CustomerAdditionalField','',3),(56457,'118139','furniture-mobile','block-56454','account\\CustomerAdditionalField','',2),(56458,'118140','furniture-mobile','block-56446','BlockBox','',3),(56459,'118141','furniture-mobile','block-56458','BlockBox','',1),(56460,'118142','furniture-mobile','block-56459','account\\CustomerAdditionalField','',2),(56461,'118143','furniture-mobile','block-56459','account\\CustomerAdditionalField','',1),(56462,'118144','furniture-mobile','block-56458-2','BlockBox','',1),(56463,'118145','furniture-mobile','block-56462','account\\CustomerAdditionalField','',1),(56464,'118146','furniture-mobile','block-56415','Html_box','',1),(56465,'118147','furniture-mobile','block-56415','BlockBox','',9),(56466,'118148','furniture-mobile','block-56465','BlockBox','',1),(56467,'118149','furniture-mobile','block-56466','account\\CustomerAdditionalField','',2),(56468,'118150','furniture-mobile','block-56466','account\\CustomerAdditionalField','',1),(56469,'118151','furniture-mobile','block-56465-2','BlockBox','',1),(56470,'118152','furniture-mobile','block-56469','account\\CustomerAdditionalField','',1),(56471,'118153','furniture-mobile','block-56415','Html_box','',10),(56472,'118154','furniture-mobile','block-56415','Html_box','',8),(56473,'118155','furniture-mobile','block-56415','BlockBox','',11),(56474,'118156','furniture-mobile','block-56473','BlockBox','',1),(56475,'118157','furniture-mobile','block-56474','Html_box','',1),(56476,'118158','furniture-mobile','block-56474','account\\CustomerAdditionalField','',2),(56477,'118159','furniture-mobile','block-56474','account\\CustomerAdditionalField','',4),(56478,'118160','furniture-mobile','block-56474','account\\CustomerAdditionalField','',3),(56479,'118161','furniture-mobile','block-56473-2','BlockBox','',1),(56480,'118162','furniture-mobile','block-56479','Html_box','',1),(56481,'118163','furniture-mobile','block-56479','account\\CustomerAdditionalField','',2),(56482,'118164','furniture-mobile','block-56479','account\\CustomerAdditionalField','',3),(56483,'118165','furniture-mobile','block-56479','account\\CustomerAdditionalField','',4),(56484,'118166','furniture-mobile','block-56415','Html_box','',12),(56485,'118167','furniture-mobile','block-56415','BlockBox','',13),(56486,'118168','furniture-mobile','block-56485','BlockBox','',1),(56487,'118169','furniture-mobile','block-56486','account\\CustomerAdditionalField','',1),(56488,'118170','furniture-mobile','block-56485-2','BlockBox','',1),(56489,'118171','furniture-mobile','block-56488','account\\CustomerAdditionalField','',1),(56490,'118172','furniture-mobile','block-56415','BlockBox','',14),(56491,'118173','furniture-mobile','block-56490','account\\BackButton','',1),(56492,'118174','furniture-mobile','block-56490-2','account\\SaveButton','',1),(56493,'118175','furniture-mobile','block-56490-2','account\\PdfButton','',2),(56494,'118176','furniture-mobile','block-56415','BlockBox','',3),(56495,'118177','furniture-mobile','block-56494','BlockBox','',1),(56496,'118178','furniture-mobile','block-56495','account\\CustomerAdditionalField','',2),(56497,'118179','furniture-mobile','block-56495','account\\CustomerAdditionalField','',1),(56498,'118180','furniture-mobile','trade_form_pdf','BlockBox','',1),(56499,'118181','furniture-mobile','block-56498','BlockBox','',29),(56500,'118182','furniture-mobile','block-56499','Html_box','',2),(56501,'118183','furniture-mobile','block-56498','BlockBox','',28),(56502,'118184','furniture-mobile','block-56501','Html_box','',1),(56503,'118185','furniture-mobile','block-56501-2','account\\CustomerAdditionalField','',1),(56504,'118186','furniture-mobile','block-56501-3','Html_box','',1),(56505,'118187','furniture-mobile','block-56501-4','account\\CustomerAdditionalField','',1),(56506,'118188','furniture-mobile','block-56498','BlockBox','',27),(56507,'118189','furniture-mobile','block-56506','Html_box','',1),(56508,'118190','furniture-mobile','block-56506-2','Html_box','',1),(56509,'118191','furniture-mobile','block-56506-3','Html_box','',1),(56510,'118192','furniture-mobile','block-56506-4','Html_box','',1),(56511,'118193','furniture-mobile','block-56498','BlockBox','',22),(56512,'118194','furniture-mobile','block-56511','Html_box','',1),(56513,'118195','furniture-mobile','block-56511-2','account\\CustomerAdditionalField','',1),(56514,'118196','furniture-mobile','block-56498','BlockBox','',26),(56515,'118197','furniture-mobile','block-56514','Html_box','',1),(56516,'118198','furniture-mobile','block-56498','BlockBox','',24),(56517,'118199','furniture-mobile','block-56516','Html_box','',1),(56518,'118200','furniture-mobile','block-56516-2','account\\CustomerAdditionalField','',1),(56519,'118201','furniture-mobile','block-56498','BlockBox','',25),(56520,'118202','furniture-mobile','block-56519','Html_box','',1),(56521,'118203','furniture-mobile','block-56498','BlockBox','',21),(56522,'118204','furniture-mobile','block-56521','Html_box','',1),(56523,'118205','furniture-mobile','block-56498','BlockBox','',23),(56524,'118206','furniture-mobile','block-56523','Html_box','',1),(56525,'118207','furniture-mobile','block-56523-2','account\\CustomerAdditionalField','',1),(56526,'118208','furniture-mobile','block-56498','BlockBox','',19),(56527,'118209','furniture-mobile','block-56526','Html_box','',1),(56528,'118210','furniture-mobile','block-56526-2','account\\CustomerAdditionalField','',1),(56529,'118211','furniture-mobile','block-56498','BlockBox','',16),(56530,'118212','furniture-mobile','block-56529','Html_box','',1),(56531,'118213','furniture-mobile','block-56529-2','BlockBox','',1),(56532,'118214','furniture-mobile','block-56531','account\\CustomerAdditionalField','',1),(56533,'118215','furniture-mobile','block-56531-2','Html_box','',1),(56534,'118216','furniture-mobile','block-56531-3','account\\CustomerAdditionalField','',1),(56535,'118217','furniture-mobile','block-56529-3','BlockBox','',1),(56536,'118218','furniture-mobile','block-56498','BlockBox','',18),(56537,'118219','furniture-mobile','block-56536','Html_box','',1),(56538,'118220','furniture-mobile','block-56536-2','account\\CustomerAdditionalField','',1),(56539,'118221','furniture-mobile','block-56498','BlockBox','',15),(56540,'118222','furniture-mobile','block-56539','Html_box','',1),(56541,'118223','furniture-mobile','block-56498','BlockBox','',20),(56542,'118224','furniture-mobile','block-56541','Html_box','',1),(56543,'118225','furniture-mobile','block-56541-2','account\\CustomerAdditionalField','',1),(56544,'118226','furniture-mobile','block-56498','BlockBox','',17),(56545,'118227','furniture-mobile','block-56544','Html_box','',1),(56546,'118228','furniture-mobile','block-56498','BlockBox','',10),(56547,'118229','furniture-mobile','block-56546','Html_box','',1),(56548,'118230','furniture-mobile','block-56546-2','account\\CustomerAdditionalField','',1),(56549,'118231','furniture-mobile','block-56498','BlockBox','',14),(56550,'118232','furniture-mobile','block-56549','Html_box','',1),(56551,'118233','furniture-mobile','block-56549-2','account\\CustomerAdditionalField','',1),(56552,'118234','furniture-mobile','block-56498','BlockBox','',6),(56553,'118235','furniture-mobile','block-56552','Html_box','',1),(56554,'118236','furniture-mobile','block-56552-2','account\\CombinedField','',2),(56555,'118237','furniture-mobile','block-56498','BlockBox','',13),(56556,'118238','furniture-mobile','block-56555','Html_box','',1),(56557,'118239','furniture-mobile','block-56555-2','account\\CustomerAdditionalField','',1),(56558,'118240','furniture-mobile','block-56498','BlockBox','',12),(56559,'118241','furniture-mobile','block-56558','Html_box','',1),(56560,'118242','furniture-mobile','block-56558-2','account\\CombinedField','',2),(56561,'118243','furniture-mobile','block-56498','BlockBox','',9),(56562,'118244','furniture-mobile','block-56561','Html_box','',1),(56563,'118245','furniture-mobile','block-56561-2','account\\CustomerAdditionalField','',1),(56564,'118246','furniture-mobile','block-56498','BlockBox','',11),(56565,'118247','furniture-mobile','block-56564','Html_box','',1),(56566,'118248','furniture-mobile','block-56564-2','account\\CombinedField','',1),(56567,'118249','furniture-mobile','block-56498','BlockBox','',8),(56568,'118250','furniture-mobile','block-56567','Html_box','',1),(56569,'118251','furniture-mobile','block-56567-2','BlockBox','',1),(56570,'118252','furniture-mobile','block-56569','account\\CustomerAdditionalField','',1),(56571,'118253','furniture-mobile','block-56569-2','BlockBox','',1),(56572,'118254','furniture-mobile','block-56571','Html_box','',2),(56573,'118255','furniture-mobile','block-56571-2','account\\CustomerAdditionalField','',1),(56574,'118256','furniture-mobile','block-56498','BlockBox','',3),(56575,'118257','furniture-mobile','block-56574','Html_box','',1),(56576,'118258','furniture-mobile','block-56498','BlockBox','',4),(56577,'118259','furniture-mobile','block-56576-2','BlockBox','',1),(56578,'118260','furniture-mobile','block-56577','BlockBox','',1),(56579,'118261','furniture-mobile','block-56578','Html_box','',2),(56580,'118262','furniture-mobile','block-56578-2','account\\CustomerAdditionalField','',1),(56581,'118263','furniture-mobile','block-56577-2','BlockBox','',1),(56582,'118264','furniture-mobile','block-56581','Html_box','',1),(56583,'118265','furniture-mobile','block-56581-2','account\\CustomerAdditionalField','',1),(56584,'118266','furniture-mobile','block-56498','BlockBox','',1),(56585,'118267','furniture-mobile','block-56584','Contacts','',1),(56586,'118268','furniture-mobile','block-56584-2','Html_box','',1),(56587,'118269','furniture-mobile','block-56498','BlockBox','',2),(56588,'118270','furniture-mobile','block-56587','Contacts','',1),(56589,'118271','furniture-mobile','block-56498','BlockBox','',5),(56590,'118272','furniture-mobile','block-56589','Html_box','',1),(56591,'118273','furniture-mobile','block-56589-2','account\\CustomerAdditionalField','',1),(56592,'118274','furniture-mobile','block-56498','BlockBox','',7),(56593,'118275','furniture-mobile','block-56592','Html_box','',1),(56594,'118276','furniture-mobile','block-56592-2','account\\CustomerAdditionalField','',1),(56597,'118279','furniture-mobile','block-56596-1','product\\Description','',2),(56598,'118280','furniture-mobile','block-56596-1','product\\Properties','',1),(56636,'118318','furniture-mobile','unsubscribed','BlockBox','',1),(56637,'118319','furniture-mobile','block-56636','Html_box','',1),(56638,'118320','furniture-mobile','update-and-pay-order_confirmation','BlockBox','',1),(56639,'118321','furniture-mobile','block-56638','BlockBox','',3),(56640,'118322','furniture-mobile','block-56639','BlockBox','',1),(56641,'118323','furniture-mobile','block-56640','BlockBox','',1),(56642,'118324','furniture-mobile','block-56641','BlockBox','',1),(56643,'118325','furniture-mobile','block-56642','order\\ShippingMethod','',5),(56644,'118326','furniture-mobile','block-56642','Html_box','',2),(56645,'118327','furniture-mobile','block-56642','Html_box','',4),(56646,'118328','furniture-mobile','block-56642','Html_box','',1),(56647,'118329','furniture-mobile','block-56642','order\\Telephone','',8),(56648,'118330','furniture-mobile','block-56642','Html_box','',6),(56649,'118331','furniture-mobile','block-56642','order\\Name','',7),(56650,'118332','furniture-mobile','block-56642','order\\Email','',9),(56651,'118333','furniture-mobile','block-56642','order\\DeliveryAddress','',3),(56652,'118334','furniture-mobile','block-56641-2','BlockBox','',1),(56653,'118335','furniture-mobile','block-56652','order\\BillingAddress','',3),(56654,'118336','furniture-mobile','block-56652','UpdateAndPay\\PayConfirm','',5),(56655,'118337','furniture-mobile','block-56652','Html_box','',1),(56656,'118338','furniture-mobile','block-56652','Html_box','',2),(56657,'118339','furniture-mobile','block-56652','Html_box','',4),(56658,'118340','furniture-mobile','block-56640','BlockBox','',3),(56659,'118341','furniture-mobile','block-56658','order\\Products','',2),(56660,'118342','furniture-mobile','block-56658','Html_box','',1),(56661,'118343','furniture-mobile','block-56639-2','BlockBox','',1),(56662,'118344','furniture-mobile','block-56661','Html_box','',1),(56663,'118345','furniture-mobile','block-56661','checkout\\ContinueBtn','',3),(56664,'118346','furniture-mobile','block-56661','order\\Totals','',2),(56665,'118347','furniture-mobile','block-56638','account\\OrderHeading','',1),(56666,'118348','furniture-mobile','update-and-pay-order_pay','BlockBox','',1),(56667,'118349','furniture-mobile','block-56666','BlockBox','',3),(56668,'118350','furniture-mobile','block-56667','BlockBox','',1),(56669,'118351','furniture-mobile','block-56668','BlockBox','',1),(56670,'118352','furniture-mobile','block-56669','BlockBox','',1),(56671,'118353','furniture-mobile','block-56670','order\\DeliveryAddress','',4),(56672,'118354','furniture-mobile','block-56670','order\\Email','',10),(56673,'118355','furniture-mobile','block-56670','order\\Name','',8),(56674,'118356','furniture-mobile','block-56670','Html_box','',7),(56675,'118357','furniture-mobile','block-56670','order\\Telephone','',9),(56676,'118358','furniture-mobile','block-56670','Html_box','',5),(56677,'118359','furniture-mobile','block-56670','order\\ShippingMethod','',6),(56678,'118360','furniture-mobile','block-56670','Html_box','',2),(56679,'118361','furniture-mobile','block-56670','Html_box','',3),(56680,'1639647774.7838','furniture-mobile','block-56670','DelayedDespatch\\OrderPay','',1),(56681,'118362','furniture-mobile','block-56669-2','BlockBox','',1),(56682,'118363','furniture-mobile','block-56681','Html_box','',1),(56683,'118364','furniture-mobile','block-56681','Html_box','',2),(56684,'118365','furniture-mobile','block-56681','Html_box','',4),(56685,'118366','furniture-mobile','block-56681','order\\BillingAddress','',3),(56686,'118367','furniture-mobile','block-56681','UpdateAndPay\\PayForm','',5),(56687,'118368','furniture-mobile','block-56668','BlockBox','',3),(56688,'118369','furniture-mobile','block-56687','Html_box','',1),(56689,'118370','furniture-mobile','block-56687','order\\Products','',2),(56690,'118371','furniture-mobile','block-56667-2','BlockBox','',1),(56691,'118372','furniture-mobile','block-56690','order\\Totals','',2),(56692,'118373','furniture-mobile','block-56690','checkout\\ContinueBtn','',3),(56693,'118374','furniture-mobile','block-56690','Html_box','',1),(56694,'118375','furniture-mobile','block-56666','account\\OrderHeading','',1),(56695,'118392','furniture-mobile','wedding_manage','WeddingRegistry\\widgets\\ManageBanner','',1),(56696,'1639406339.5675','furniture-mobile','wedding_manage','BlockBox','',3),(56697,'118381','furniture-mobile','block-56696','WeddingRegistry\\widgets\\Products','',3),(56698,'118382','furniture-mobile','block-56696','WeddingRegistry\\widgets\\AddItemsLink','',2),(56699,'118383','furniture-mobile','block-56696','BlockBox','',1),(56700,'118384','furniture-mobile','block-56699','WeddingRegistry\\widgets\\Photos','',1),(56701,'118385','furniture-mobile','block-56699-2','WeddingRegistry\\widgets\\ManageDate','',2),(56702,'118386','furniture-mobile','block-56699-2','WeddingRegistry\\widgets\\ManageNames','',1),(56703,'118387','furniture-mobile','block-56699-2','BlockBox','',3),(56704,'118388','furniture-mobile','block-56703','WeddingRegistry\\widgets\\EditLink','',1),(56705,'118389','furniture-mobile','block-56703','WeddingRegistry\\widgets\\ShareLink','',3),(56706,'118390','furniture-mobile','block-56703','WeddingRegistry\\widgets\\DeleteLink','',2),(56707,'118391','furniture-mobile','block-56699-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(56711,'118396','furniture-mobile','wedding_search','BlockBox','',1),(56712,'118397','furniture-mobile','block-56711','BlockBox','',1),(56713,'118398','furniture-mobile','block-56712','BlockBox','',1),(56714,'118399','furniture-mobile','block-56713','WeddingRegistry\\widgets\\SearchForm','',2),(56715,'118400','furniture-mobile','block-56713','Html_box','',1),(56716,'118401','furniture-mobile','block-56711','WeddingRegistry\\widgets\\SearchList','',2),(56717,'118402','furniture-mobile','block-56711','WeddingRegistry\\widgets\\SearchPaging','',3),(56718,'118403','furniture-mobile','wedding_share','BlockBox','',2),(56719,'118404','furniture-mobile','block-56718','BlockBox','',4),(56720,'1639410195.9973','furniture-mobile','block-56719','Html_box','',0),(56721,'118405','furniture-mobile','block-56719-2','Html_box','',1),(56722,'118406','furniture-mobile','block-56719-2','WeddingRegistry\\widgets\\InviteList','',4),(56723,'118407','furniture-mobile','block-56719-2','Html_box','',3),(56724,'118408','furniture-mobile','block-56719-2','WeddingRegistry\\widgets\\ShareUrl','',2),(56725,'118410','furniture-mobile','block-56718','WeddingRegistry\\widgets\\Photos','',2),(56726,'118411','furniture-mobile','block-56718','Html_box','',3),(56727,'118409','furniture-mobile','wedding_share','WeddingRegistry\\widgets\\ManageBanner','',1),(56728,'1639405874.8749','furniture-mobile','wedding_success','BlockBox','',0),(56729,'118412','furniture-mobile','block-56728','WeddingRegistry\\widgets\\BackButton','',2),(56730,'118413','furniture-mobile','block-56728','Html_box','',1),(56731,'1639393156.401','furniture-mobile','wedding_update','BlockBox','',0),(56732,'118414','furniture-mobile','block-56731','BlockBox','',2),(56733,'118415','furniture-mobile','block-56732','BlockBox','',1),(56734,'118416','furniture-mobile','block-56733','Html_box','',5),(56735,'118417','furniture-mobile','block-56733','WeddingRegistry\\widgets\\ShareRegistry','',6),(56736,'118418','furniture-mobile','block-56733','Html_box','',3),(56737,'118419','furniture-mobile','block-56733','Html_box','',1),(56738,'118420','furniture-mobile','block-56733','WeddingRegistry\\widgets\\Names','',2),(56739,'118421','furniture-mobile','block-56733','WeddingRegistry\\widgets\\Details','',4),(56740,'118422','furniture-mobile','block-56732-2','BlockBox','',1),(56741,'118423','furniture-mobile','block-56740','WeddingRegistry\\widgets\\InformationText','',4),(56742,'118424','furniture-mobile','block-56740','Html_box','',5),(56743,'118425','furniture-mobile','block-56740','WeddingRegistry\\widgets\\ShippingDetails','',2),(56744,'118426','furniture-mobile','block-56740','WeddingRegistry\\widgets\\Photos','',6),(56745,'118427','furniture-mobile','block-56740','Html_box','',1),(56746,'118428','furniture-mobile','block-56740','Html_box','',3),(56747,'118429','furniture-mobile','block-56731','BlockBox','',3),(56748,'118430','furniture-mobile','block-56747','WeddingRegistry\\widgets\\BackButton','',1),(56749,'118431','furniture-mobile','block-56747-2','WeddingRegistry\\widgets\\SaveButton','',1),(56750,'118432','furniture-mobile','block-56731','Html_box','',1),(56751,'118439','furniture-mobile','wedding_view','WeddingRegistry\\widgets\\ManageBanner','',1),(56752,'1639500465.781','furniture-mobile','wedding_view','BlockBox','',2),(56753,'118433','furniture-mobile','block-56752','BlockBox','',1),(56754,'118434','furniture-mobile','block-56753','WeddingRegistry\\widgets\\Photos','',1),(56755,'118435','furniture-mobile','block-56753-2','WeddingRegistry\\widgets\\ManageDate','',2),(56756,'118436','furniture-mobile','block-56753-2','WeddingRegistry\\widgets\\ManageNames','',1),(56757,'118437','furniture-mobile','block-56753-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(56758,'118438','furniture-mobile','block-56752','WeddingRegistry\\widgets\\Products','',2),(56759,'118440','furniture-mobile','wishlist','BlockBox','',1),(56760,'118441','furniture-mobile','block-56759','BlockBox','',1),(56761,'118442','furniture-mobile','block-56760','WidgetsAria','',1),(56762,'116126','furniture-mobile','account-menu','BlockBox','',1),(56763,'116127','furniture-mobile','block-56762','BlockBox','account-side',1),(56764,'116128','furniture-mobile','block-56763','Html_box','',16),(56765,'116129','furniture-mobile','block-56763','account\\AccountLink','',17),(56766,'116130','furniture-mobile','block-56763','account\\AccountLink','',18),(56767,'116131','furniture-mobile','block-56763','account\\AccountLink','',1),(56768,'116132','furniture-mobile','block-56763','Html_box','',2),(56769,'116133','furniture-mobile','block-56763','account\\AccountLink','',4),(56770,'116134','furniture-mobile','block-56763','account\\AccountLink','',7),(56771,'116135','furniture-mobile','block-56763','account\\AccountLink','',11),(56772,'116136','furniture-mobile','block-56763','Html_box','',6),(56773,'116137','furniture-mobile','block-56763','account\\AccountLink','',3),(56774,'116138','furniture-mobile','block-56763','account\\AccountLink','',14),(56775,'116139','furniture-mobile','block-56763','account\\AccountLink','',8),(56776,'116140','furniture-mobile','block-56763','account\\AccountLink','',5),(56777,'116141','furniture-mobile','block-56763','account\\AccountLink','',9),(56778,'116142','furniture-mobile','block-56763','account\\AccountLink','',12),(56779,'116143','furniture-mobile','block-56763','Html_box','',10),(56780,'116144','furniture-mobile','block-56763','account\\AccountLink','',15),(56781,'118443','furniture-mobile','block-56760-2','account\\Wishlist','',2),(56782,'118444','furniture-mobile','block-56760-2','Html_box','',1),(56783,'118445','furniture-mobile','wishlist-cart','BlockBox','',1),(56784,'118446','furniture-mobile','block-56783','cart\\CartTabs','',1),(56785,'118447','furniture-mobile','block-56784','account\\Wishlist','',1),(56789,'1694453786.292251','watch-mobile','block-3356','checkout\\ShippingAddress','',2),(108861,'117044','splash','email','email\\BlockBox','',1),(108862,'117045','splash','block-108861','email\\BlockBox','',1),(108863,'117046','splash','block-108862','Copyright','',4),(108864,'117047','splash','block-108862','email\\Content','',3),(108865,'117048','splash','block-108862','email\\BlockBox','',2),(108866,'117049','splash','block-108865','email\\Title','',1),(108867,'117050','splash','block-108865-2','email\\Date','',1),(108868,'117051','splash','block-108862','Logo','',1),(108869,'1661353033.436213','splash','info','BlockBox','',1),(108870,'1661353033.440468','splash','block-108869','info\\Title','',0),(108871,'1661353033.44440','splash','block-108869','info\\Content','',0),(108872,'1661353032.24842','splash','invoice','invoice\\Container','',1),(108873,'1661353032.270236','splash','block-108872','BlockBox','',4),(108874,'1661353032.296769','splash','block-108873','BlockBox','',8),(108875,'1661353032.306393','splash','block-108874','BlockBox','',1),(108876,'1661353032.318453','splash','block-108875','invoice\\ShippingMethod','',2),(108877,'1661353032.323757','splash','block-108875','Html_box','',0),(108878,'1661353032.337230','splash','block-108874-2','BlockBox','',1),(108879,'1661353032.346115','splash','block-108878','invoice\\ShippingMethod','',2),(108880,'1661353032.34962','splash','block-108878','Html_box','',0),(108881,'1661353032.356416','splash','block-108873','BlockBox','',7),(108882,'1661353032.363923','splash','block-108881','BlockBox','',2),(108883,'1661353032.374368','splash','block-108882','invoice\\BillingAddress','',3),(108884,'1661353032.380968','splash','block-108882','Html_box','',0),(108885,'1661353032.389876','splash','block-108881','GiftWrapMessage\\ShowInfo','',1),(108886,'1661353032.39417','splash','block-108881-2','BlockBox','',1),(108887,'1661353032.40481','splash','block-108886','invoice\\CustomerName','',2),(108888,'1661353032.410660','splash','block-108886','invoice\\CustomerPhone','',4),(108889,'1661353032.416141','splash','block-108886','invoice\\CustomerEmail','',7),(108890,'1661353032.4242','splash','block-108886','Html_box','',1),(108891,'1661353032.430173','splash','block-108886','Html_box','',3),(108892,'1661353032.440350','splash','block-108886','Html_box','',5),(108893,'1661353032.449537','splash','block-108873-2','invoice\\PaymentMethod','',6),(108894,'1661353032.456412','splash','block-108873-2','invoice\\OrderId','',1),(108895,'1661353032.464888','splash','block-108873-2','invoice\\PaymentDate','',3),(108896,'1661353032.471888','splash','block-108873-2','invoice\\OrderBarcode','',7),(108897,'1661353032.47812','splash','block-108873-2','Html_box','',2),(108898,'1661353032.486692','splash','block-108873-2','Html_box','',5),(108899,'1661353032.495713','splash','block-108872','BlockBox','',8),(108900,'1661353032.50157','splash','block-108899','invoice\\StoreAddress','',8),(108901,'1661353032.50664','splash','block-108899','Html_box','',0),(108902,'1661353032.514429','splash','block-108899-2','Html_box','',1),(108903,'1661353032.527783','splash','block-108899-3','BlockBox','',4),(108904,'1661353032.533932','splash','block-108903','Html_box','',0),(108905,'1661353032.54216','splash','block-108903-2','invoice\\StoreEmail','',1),(108906,'1661353032.549414','splash','block-108899-3','BlockBox','',3),(108907,'1661353032.556356','splash','block-108906','Html_box','',0),(108908,'1661353032.56487','splash','block-108906-2','invoice\\StorePhone','',1),(108909,'1661353032.572983','splash','block-108899-3','Html_box','',1),(108910,'1661353032.588254','splash','block-108872','invoice\\Products','',5),(108911,'1661353032.596366','splash','block-108872','BlockBox','',7),(108912,'1661353032.616225','splash','block-108911','BlockBox','',1),(108913,'1661353032.624746','splash','block-108912','invoice\\ShippingAddress','',2),(108914,'1661353032.6344','splash','block-108912','Html_box','',0),(108915,'1661353032.645291','splash','block-108911-2','BlockBox','',1),(108916,'1661353032.656840','splash','block-108915','invoice\\Totals','',1),(108917,'1661353032.665237','splash','block-108872','BlockBox','',2),(108918,'1661353032.672459','splash','block-108917','Logo','',0),(108919,'1661353032.693794','splash','block-108917-2','BlockBox','',4),(108920,'1661353032.699666','splash','block-108919','Html_box','',0),(108921,'1661353032.705757','splash','block-108919-2','invoice\\StoreSite','',1),(108922,'1661353032.712713','splash','block-108917-2','BlockBox','',3),(108923,'1661353032.717779','splash','block-108922','Html_box','',0),(108924,'1661353032.724733','splash','block-108922-2','invoice\\StoreEmail','',1),(108925,'1661353032.729329','splash','block-108917-2','BlockBox','',1),(108926,'1661353032.73418','splash','block-108925','invoice\\StoreAddress','',2),(108927,'1661353032.745349','splash','block-108917-2','BlockBox','',2),(108928,'1661353032.752179','splash','block-108927','Html_box','',0),(108929,'1661353032.759958','splash','block-108927-2','invoice\\StorePhone','',1),(108930,'1661353032.765438','splash','block-108872','invoice\\StructuredProducts','',6),(108931,'1640168549.8258','splash','main','BlockBox','',0),(108932,'1640168603.5833','splash','block-108931','BlockBox','',1),(108933,'1640168618.7708','splash','block-108932','Image','',0),(108934,'1640181569.3506','splash','block-108931','BlockBox','',2),(108935,'1640168851.5282','splash','block-108934','BlockBox','',1),(108936,'1640169872.1589','splash','block-108935','Image','',1),(108937,'1640276640.1123','splash','block-108935-2','Text','',1),(108938,'1640170154.7803','splash','block-108935-3','Image','',1),(108939,'1645204049.8114','splash','block-108931','BlockBox','',3),(108940,'1640170023.0001','splash','block-108939','Image','',1),(108941,'1640170023.1491','splash','block-108939-2','Image','',2),(108942,'1640170023','splash','block-108939-3','Image','',1),(108943,'1661353032.958564','splash','packingslip','invoice\\Container','',1),(108944,'1661353032.968771','splash','block-108943','BlockBox','',2),(108945,'1661353032.975845','splash','block-108944','Logo','',1),(108946,'1661353032.991276','splash','block-108944-2','BlockBox','',3),(108947,'1661353032.99777','splash','block-108946','Html_box','',0),(108948,'1661353033.00539','splash','block-108946-2','invoice\\StoreEmail','',1),(108949,'1661353033.010798','splash','block-108944-2','BlockBox','',2),(108950,'1661353033.017634','splash','block-108949','Html_box','',0),(108951,'1661353033.027946','splash','block-108949-2','invoice\\StorePhone','',1),(108952,'1661353033.033296','splash','block-108944-2','BlockBox','',1),(108953,'1661353033.03754','splash','block-108952','invoice\\StoreAddress','',1),(108954,'1661353033.046342','splash','block-108944-2','BlockBox','',4),(108955,'1661353033.052669','splash','block-108954','Html_box','',0),(108956,'1661353033.060721','splash','block-108954-2','invoice\\StoreSite','',1),(108957,'1661353033.065977','splash','block-108943','packingslip\\Products','',5),(108958,'1661353033.073678','splash','block-108943','BlockBox','',6),(108959,'1661353033.081543','splash','block-108958','invoice\\StoreAddress','',2),(108960,'1661353033.085331','splash','block-108958','Html_box','',0),(108961,'1661353033.093224','splash','block-108943','BlockBox','',3),(108962,'1661353033.108992','splash','block-108961','BlockBox','',2),(108963,'1661353033.11758','splash','block-108962','BlockBox','',1),(108964,'1661353033.129825','splash','block-108963','invoice\\ShippingAddress','',2),(108965,'1661353033.136397','splash','block-108963','Html_box','',0),(108966,'1661353033.145276','splash','block-108962-2','BlockBox','',1),(108967,'1661353033.15637','splash','block-108966','invoice\\CustomerName','',2),(108968,'1661353033.16030','splash','block-108966','invoice\\CustomerEmail','',6),(108969,'1661353033.16397','splash','block-108966','invoice\\CustomerPhone','',4),(108970,'1661353033.168995','splash','block-108966','Html_box','',1),(108971,'1661353033.176872','splash','block-108966','Html_box','',3),(108972,'1661353033.185817','splash','block-108966','Html_box','',5),(108973,'1661353033.197558','splash','block-108961','BlockBox','',3),(108974,'1661353033.208111','splash','block-108973','BlockBox','',1),(108975,'1661353033.219882','splash','block-108974','invoice\\ShippingMethod','',2),(108976,'1661353033.22360','splash','block-108974','Html_box','',0),(108977,'1661353033.2314','splash','block-108973-2','BlockBox','',1),(108978,'1661353033.240139','splash','block-108977','invoice\\ShippingMethod','',2),(108979,'1661353033.243986','splash','block-108977','Html_box','',0),(108980,'1661353033.250617','splash','block-108961-2','invoice\\AddressQrcode','',1),(108981,'1661353033.258425','splash','block-108943','Neighbour\\PackingSlipInfo','',4),(108982,'74683','splash','pdf','invoice\\Container','',1),(108983,'74684','splash','block-108982','BlockBox','',1),(108984,'74685','splash','block-108983','BlockBox','',1),(108985,'74686','splash','block-108984','BlockBox','',1),(108986,'74687','splash','block-108985','pdf\\ProductElement','',1),(108987,'74688','splash','block-108984','BlockBox','',2),(108988,'74689','splash','block-108987','pdf\\ProductElement','',1),(108989,'74690','splash','block-108987-2','pdf\\ProductElement','',2),(108990,'74691','splash','block-108987-2','pdf\\ProductElement','',1),(108991,'74692','splash','block-108983-2','BlockBox','',1),(108992,'74693','splash','block-108991','BlockBox','',2),(108993,'74694','splash','block-108992','pdf\\ProductElement','',1),(108994,'74695','splash','block-108992-2','pdf\\ProductElement','',2),(108995,'74696','splash','block-108992-2','pdf\\ProductElement','',1),(108996,'74697','splash','block-108991','BlockBox','',1),(108997,'74698','splash','block-108996','pdf\\ProductElement','',1),(108998,'74700','splash','pdf_category','pdf\\CategoryImage','',1),(108999,'74699','splash','pdf_category','pdf\\CategoryName','',2),(109000,'74701','splash','pdf_cover','invoice\\Container','',1),(109001,'74702','splash','block-109000','Logo','',1),(109002,'74703','splash','block-109000','Text','',3),(109003,'74704','splash','pdf_footer','BlockBox','',1),(109004,'74705','splash','block-109003-2','pdf\\PageNumber','',1),(109005,'74706','splash','pdf_header','pdf\\CategoryName','',1),(109007,'116005','furniture','404','Html_box','',1),(109240,'117906.000001','furniture','b2b','BlockBox','listing-item',1),(109241,'117907.000001','furniture','block-109240','BlockBox','',2),(109242,'117908.000001','furniture','block-109241','BlockBox','',2),(109243,'117909.000001','furniture','block-109242','productListing\\bonusPoints','',2),(109244,'117910.000001','furniture','block-109242','productListing\\image','',1),(109245,'117914.000001','furniture','block-109242-2','productListing\\name','',1),(109246,'117915.000001','furniture','block-109242-2','productListing\\description','',2),(109247,'117916.000001','furniture','block-109242-2','productListing\\model','',4),(109248,'117917.000001','furniture','block-109242-2','productListing\\attributes','',5),(109249,'120922.000001','furniture','block-109242-2','productListing\\properties','',3),(109250,'117918.000001','furniture','block-109241-2','BlockBox','',1),(109251,'117911.000001','furniture','block-109250','BlockBox','',3),(109252,'117912.000001','furniture','block-109251','productListing\\rating','',1),(109253,'117913.000001','furniture','block-109251','productListing\\ratingCounts','',2),(109254,'117919.000001','furniture','block-109250','productListing\\qtyInput','',4),(109255,'117920.000001','furniture','block-109250','productListing\\price','',2),(109256,'117922.000001','furniture','block-109250','productListing\\buyButton','',5),(109257,'117924.000001','furniture','block-109250','productListing\\stock','',1),(109258,'120924.000001','furniture','block-109250','BlockBox','',8),(109259,'120925.000001','furniture','block-109258','productListing\\compare','',3),(109260,'120926.000001','furniture','block-109258','productListing\\personalCatalog','',2),(109261,'120927.000001','furniture','block-109258','productListing\\viewButton','',1),(109262,'116176','furniture','batch','BlockBox','',1),(109263,'116177','furniture','block-109262','productListing\\attributes','',5),(109264,'116178','furniture','block-109262','productListing\\price','',6),(109265,'116179','furniture','block-109262','productListing\\name','',4),(109266,'116180','furniture','block-109262','productListing\\image','',2),(109267,'116181','furniture','block-109262','batchSelect','',1),(109268,'116182','furniture','batch_selected','BlockBox','',1),(109269,'116183','furniture','block-109268','BlockBox','',13),(109270,'116184','furniture','block-109269','productListing\\image','',1),(109271,'116185','furniture','block-109269-2','batchRemove','',1),(109272,'116186','furniture','block-109269-2','productListing\\price','',3),(109273,'116187','furniture','block-109269-2','productListing\\name','',2),(109274,'116188','furniture','bbbbb','BlockBox','',1),(109275,'116189','furniture','block-109274','BlockBox','',2),(109276,'116190','furniture','block-109275','Filters','',1),(109277,'116191','furniture','block-109275-2','BlockBox','',6),(109278,'116192','furniture','block-109277','catalog\\CountsItems','',1),(109279,'116193','furniture','block-109277-2','catalog\\Paging','',1),(109280,'116194','furniture','block-109275-2','catalog\\Image','',1),(109281,'116195','furniture','block-109275-2','Listing','',5),(109282,'116196','furniture','block-109275-2','catalog\\ImageMapCategory','',3),(109283,'116197','furniture','block-109275-2','BlockBox','',4),(109284,'116198','furniture','block-109283','catalog\\ListingLook','',1),(109285,'116199','furniture','block-109283','catalog\\CompareButton','',2),(109286,'116200','furniture','block-109283','catalog\\ItemsOnPage','',4),(109287,'116201','furniture','block-109283','catalog\\Sorting','',3),(109288,'116202','furniture','block-109275-2','Categories','',2),(109289,'116203','furniture','block-109274','catalog\\Title','',1),(109290,'1683103176.926637','furniture','cart','BlockBox','',1),(109291,'1683103176.947325','furniture','block-109290','BlockBox','',3),(109292,'1683103176.971768','furniture','block-109291','BlockBox','cart-content',1),(109293,'1683103176.974446','furniture','block-109292','cart\\Products','',4),(109294,'1683103176.975161','furniture','block-109292','BlockBox','',3),(109295,'1683103176.976938','furniture','block-109294','MultiCart\\CartSwitcher','',1),(109296,'1683103176.977748','furniture','block-109294','MultiCart\\SaveCart','',2),(109297,'1683103176.9792','furniture','block-109294-2','MultiCart\\Actions','',1),(109298,'1683103176.9841','furniture','block-109292','BlockBox','',5),(109299,'1683103176.98248','furniture','block-109298','cart\\CreditAmount','',1),(109300,'1683103176.982975','furniture','block-109298-2','cart\\BonusPoints','',3),(109301,'1683103176.983866','furniture','block-109298-3','cart\\FreeDelivery','',2),(109302,'1683103176.985151','furniture','block-109292','Html_box','',2),(109303,'1683103176.987818','furniture','block-109291','BlockBox','',3),(109304,'1683103176.989631','furniture','block-109303','cart\\GiveAway','',2),(109305,'1683103176.99020','furniture','block-109303','Html_box','',1),(109306,'1683103176.992136','furniture','block-109291','BlockBox','',5),(109307,'1683103176.99416','furniture','block-109306','Html_box','',1),(109308,'1683103176.995796','furniture','block-109306','cart\\ShippingEstimator','',2),(109309,'1683103176.996373','furniture','block-109291','cart\\DependedProducts','8',2),(109310,'1683103176.999540','furniture','block-109291-2','BlockBox','cart-side',1),(109311,'1683103177.002177','furniture','block-109310','BlockBox','',2),(109312,'1683103177.003296','furniture','block-109311','cart\\DiscountCoupon','',2),(109313,'1683103177.016825','furniture','block-109311','cart\\CheckoutBtn','',4),(109314,'1683103177.018382','furniture','block-109311','cart\\OrderTotal','',1),(109315,'1683103177.018993','furniture','block-109311','cart\\OrderTotal','',3),(109316,'1683103177.019577','furniture','block-109310','Html_box','',1),(109327,'116272','furniture','categories','BlockBox','catalog-content',1),(109328,'116273','furniture','block-109327','BlockBox','',2),(109329,'116274','furniture','block-109328','Filters','',3),(109330,'1639749663.0229','furniture','block-109328','ShowInactive\\ShowInactive','',1),(109331,'116275','furniture','block-109328-2','Listing','',8),(109332,'116276','furniture','block-109328-2','catalog\\Image','',3),(109333,'116277','furniture','block-109328-2','BlockBox','',9),(109334,'116278','furniture','block-109333','catalog\\CountsItems','',1),(109335,'116279','furniture','block-109333-2','catalog\\Paging','',1),(109336,'116280','furniture','block-109328-2','catalog\\ImageMapCategory','',6),(109337,'116281','furniture','block-109328-2','Categories','',4),(109338,'116282','furniture','block-109328-2','BlockBox','catalog-features',7),(109339,'116283','furniture','block-109338','catalog\\ListingLook','',1),(109340,'116284','furniture','block-109338','catalog\\CompareButton','',2),(109341,'116285','furniture','block-109338','catalog\\ItemsOnPage','',4),(109342,'116286','furniture','block-109338','catalog\\Sorting','',3),(109343,'116287','furniture','block-109327','catalog\\Title','',1),(109344,'116288','furniture','category','Categories','',1),(109345,'116289','furniture','category','Listing','',4),(109346,'116290','furniture','category','ListingFunctionality','',2),(109347,'116291','furniture','category','PagingBar','',3),(109348,'116292','furniture','category','PagingBar','',5),(109349,'116293','furniture','category_2','BlockBox','',1),(109350,'116294','furniture','block-109349','catalog\\Title','',1),(109351,'116295','furniture','block-109349','BlockBox','',2),(109352,'116296','furniture','block-109351','Filters','',1),(109353,'116297','furniture','block-109351-2','catalog\\Image','',1),(109354,'116298','furniture','block-109351-2','Listing','',5),(109355,'116299','furniture','block-109351-2','BlockBox','',4),(109356,'116300','furniture','block-109355','catalog\\Sorting','',3),(109357,'116301','furniture','block-109355','catalog\\ItemsOnPage','',4),(109358,'116302','furniture','block-109355','catalog\\CompareButton','',2),(109359,'116303','furniture','block-109355','catalog\\ListingLook','',1),(109360,'116304','furniture','block-109351-2','catalog\\ImageMapCategory','',3),(109361,'116305','furniture','block-109351-2','Categories','',2),(109362,'116306','furniture','block-109351-2','BlockBox','',6),(109363,'116307','furniture','block-109362','catalog\\CountsItems','',1),(109364,'116308','furniture','block-109362-2','catalog\\Paging','',1),(109365,'116309','furniture','category_no_filters','BlockBox','catalog-content',1),(109366,'116310','furniture','block-109365','catalog\\Title','',1),(109367,'116311','furniture','block-109365','Categories','',3),(109368,'116312','furniture','block-109365','BlockBox','catalog-features',4),(109369,'116313','furniture','block-109368','catalog\\ItemsOnPage','',4),(109370,'116314','furniture','block-109368','catalog\\Sorting','',3),(109371,'116315','furniture','block-109368','catalog\\CompareButton','',2),(109372,'116316','furniture','block-109368','catalog\\ListingLook','',1),(109373,'116317','furniture','block-109368','HeaderStock','',5),(109374,'116318','furniture','block-109365','BlockBox','',6),(109375,'116319','furniture','block-109374','catalog\\CountsItems','',1),(109376,'116320','furniture','block-109374-2','catalog\\Paging','',1),(109377,'116321','furniture','block-109365','Listing','',5),(109378,'116322','furniture','block-109365','catalog\\Image','',2),(109379,'116323','furniture','block-109365','catalog\\B2bAddButton','',7),(109380,'1693847444.869439','furniture','checkout','BlockBox','',1),(109381,'1693847444.885847','furniture','block-109380','BlockBox','',2),(109382,'1693847444.888529','furniture','block-109381','BlockBox','',2),(109383,'1693847444.8951','furniture','block-109382','BlockBox','checkout-comments',5),(109384,'1693847444.891978','furniture','block-109383','checkout\\Comments','',2),(109385,'1693847444.893451','furniture','block-109383','Html_box','',1),(109386,'1693847444.898927','furniture','block-109382','BlockBox','checkout-discount',4),(109387,'1693847444.90129','furniture','block-109386','Html_box','',1),(109388,'1693847444.902745','furniture','block-109386','BlockBox','',2),(109389,'1693847444.904471','furniture','block-109388','CouponsAndVauchers\\Checkout','',1),(109390,'1693847444.906639','furniture','block-109388-2','checkout\\CreditAmount','',1),(109391,'1693847444.908631','furniture','block-109388-2','checkout\\BonusPoints','',2),(109392,'1693847444.910474','furniture','block-109382','BlockBox','checkout-shipping',2),(109393,'1693847444.912443','furniture','block-109392','BlockBox','',3),(109394,'1693847444.914967','furniture','block-109393','checkout\\ShippingChoice','',1),(109395,'1693847444.921382','furniture','block-109392','Neighbour\\Checkout','',5),(109396,'1693847444.923161','furniture','block-109392','BlockBox','',4),(109397,'1693847444.924488','furniture','block-109396','BlockBox','',1),(109398,'1693847444.926170','furniture','block-109397','checkout\\ShippingAddress','',2),(109399,'1693847444.928743','furniture','block-109397','Html_box','',3),(109400,'1693847444.930224','furniture','block-109397','checkout\\ContactInformation','',4),(109401,'1693847444.93149','furniture','block-109397','UploadCustomerId\\UploadCustomerIdForm','',5),(109402,'1693847444.934659','furniture','block-109396-2','BlockBox','',1),(109403,'1693847444.936512','furniture','block-109402','checkout\\Shipping','',2),(109404,'1693847444.9487','furniture','block-109402','DelayedDespatch\\Checkout','',4),(109405,'1693847444.942192','furniture','block-109402','Html_box','',1),(109406,'1693847444.946113','furniture','block-109402','DeliveryDay','',3),(109408,'1693847444.95160','furniture','block-109392','Html_box','',2),(109409,'1693847444.954571','furniture','block-109382','BlockBox','',6),(109410,'1693847444.956524','furniture','block-109409','cart\\Products','',1),(109411,'1693847444.960635','furniture','block-109409','checkout\\CreateAccount','',2),(109412,'1693847444.963447','furniture','block-109409','DeliveryOptions\\Checkout','',0),(109413,'1693847444.965195','furniture','block-109382','BlockBox','checkout-payment',3),(109414,'1693847444.967253','furniture','block-109413','Html_box','',1),(109415,'1693847444.96852','furniture','block-109413','BlockBox','',2),(109416,'1693847444.969566','furniture','block-109415','Html_box','',1),(109417,'1693847444.97077','furniture','block-109415','checkout\\BillingAddress','',2),(109418,'1693847444.97415','furniture','block-109415-2','BlockBox','',1),(109419,'1693847444.975198','furniture','block-109418','checkout\\PaymentMethod','',2),(109420,'1693847444.97623','furniture','block-109418','Html_box','',1),(109421,'1693847444.977354','furniture','block-109382','BlockBox','',0),(109422,'1693847444.978759','furniture','block-109421','checkout\\LoginOnForm','',0),(109423,'1693847444.979723','furniture','block-109381-2','BlockBox','checkout-side',1),(109424,'1693847444.98495','furniture','block-109423','Html_box','',5),(109425,'1693847444.986544','furniture','block-109423','Html_box','',1),(109426,'1693847444.987613','furniture','block-109423','checkout\\Terms','',4),(109427,'1693847444.988926','furniture','block-109423','checkout\\Totals','',2),(109428,'1693847444.989754','furniture','block-109423','checkout\\ContinueBtn','',3),(109429,'116368','furniture','checkout_confirmation','BlockBox','',1),(109430,'116369','furniture','block-109429','checkout\\Totals','',7),(109431,'116370','furniture','block-109429','Html_box','',4),(109432,'116371','furniture','block-109429','checkout\\EditBtn','',5),(109433,'116372','furniture','block-109429','BlockBox','',2),(109434,'116373','furniture','block-109433','BlockBox','',1),(109435,'116374','furniture','block-109434','Html_box','',1),(109436,'116375','furniture','block-109434','checkout\\ShippingConfirm','',3),(109437,'116376','furniture','block-109433-2','BlockBox','',1),(109438,'116377','furniture','block-109437','checkout\\PaymentMethodConfirm','',3),(109439,'116378','furniture','block-109437','Html_box','',1),(109440,'116380','furniture','block-109429','BlockBox','',1),(109441,'116381','furniture','block-109440','BlockBox','',1),(109442,'116382','furniture','block-109441','checkout\\ShippingAddressConfirm','',3),(109443,'116383','furniture','block-109441','Html_box','',1),(109444,'116384','furniture','block-109440-2','BlockBox','',1),(109445,'116385','furniture','block-109444','Html_box','',1),(109446,'116386','furniture','block-109444','checkout\\BillingAddressConfirm','',3),(109447,'116387','furniture','block-109429','checkout\\ConfirmBtn','',3),(109448,'116388','furniture','block-109429','cart\\Products','',6),(109449,'116379','furniture','checkout_confirmation','checkout\\ConfirmBtn','',2),(109450,'116402','furniture','checkout_confirmation_no_shipping','BlockBox','',1),(109451,'116403','furniture','block-109450','checkout\\ConfirmBtn','',9),(109452,'116404','furniture','block-109450','BlockBox','',2),(109453,'116405','furniture','block-109452','BlockBox','',1),(109454,'116406','furniture','block-109453','Html_box','',1),(109455,'116407','furniture','block-109453','checkout\\BillingAddressConfirm','',3),(109456,'116408','furniture','block-109452-2','BlockBox','',1),(109457,'116409','furniture','block-109456','Html_box','',1),(109458,'116410','furniture','block-109456','checkout\\PaymentMethodConfirm','',3),(109459,'116411','furniture','block-109450','checkout\\ConfirmBtn','',4),(109460,'116412','furniture','block-109450','checkout\\Totals','',8),(109461,'116413','furniture','block-109450','cart\\Products','',7),(109462,'116414','furniture','block-109450','Html_box','',5),(109463,'116389','furniture','checkout_confirmation_no_shipping_q','BlockBox','',1),(109464,'116390','furniture','block-109463','quote\\Products','',4),(109465,'116391','furniture','block-109463','checkout\\ConfirmBtn','',2),(109466,'116392','furniture','block-109463','checkout\\ConfirmBtn','',6),(109467,'116393','furniture','block-109463','BlockBox','',1),(109468,'116394','furniture','block-109467','BlockBox','',1),(109469,'116395','furniture','block-109468','checkout\\BillingAddressConfirm','',3),(109470,'116396','furniture','block-109468','Html_box','',1),(109471,'116397','furniture','block-109467-2','BlockBox','',1),(109472,'116398','furniture','block-109471','checkout\\PaymentMethodConfirm','',3),(109473,'116399','furniture','block-109471','Html_box','',1),(109474,'116400','furniture','block-109463','Html_box','',3),(109475,'116401','furniture','block-109463','checkout\\Totals','',5),(109476,'116415','furniture','checkout_confirmation_q','BlockBox','',1),(109477,'116416','furniture','block-109476','BlockBox','',1),(109478,'116417','furniture','block-109477','BlockBox','',1),(109479,'116418','furniture','block-109478','checkout\\ShippingAddressConfirm','',3),(109480,'116419','furniture','block-109478','Html_box','',1),(109481,'116420','furniture','block-109477-2','BlockBox','',1),(109482,'116421','furniture','block-109481','checkout\\BillingAddressConfirm','',3),(109483,'116422','furniture','block-109481','Html_box','',1),(109484,'116423','furniture','block-109476','checkout\\Totals','',7),(109485,'116424','furniture','block-109476','quote\\Products','',6),(109486,'116425','furniture','block-109476','Html_box','',4),(109487,'116426','furniture','block-109476','checkout\\EditBtn','',5),(109488,'116427','furniture','block-109476','checkout\\ConfirmBtn','',8),(109489,'116428','furniture','block-109476','checkout\\ConfirmBtn','',3),(109490,'116429','furniture','block-109476','BlockBox','',2),(109491,'116430','furniture','block-109490','BlockBox','',1),(109492,'116431','furniture','block-109491','Html_box','',1),(109493,'116432','furniture','block-109491','checkout\\ShippingConfirm','',3),(109494,'116433','furniture','block-109490-2','BlockBox','',1),(109495,'116434','furniture','block-109494','Html_box','',1),(109496,'116435','furniture','block-109494','checkout\\PaymentMethodConfirm','',3),(109497,'116436','furniture','checkout_confirmation_title','Html_box','',1),(109498,'116437','furniture','checkout_confirmation_title_g','Html_box','',1),(109499,'116439','furniture','checkout_confirmation_title_no_shipping','Html_box','',1),(109500,'116438','furniture','checkout_confirmation_title_no_shipping_g','Html_box','',1),(109501,'116440','furniture','checkout_confirmation_title_q','Html_box','',1),(109502,'116441','furniture','checkout_confirmation_title_s','Html_box','',1),(109503,'116442','furniture','checkout_delivery','BlockBox','',2),(109504,'116443','furniture','block-109503','BlockBox','',1),(109505,'116444','furniture','block-109504','Html_box','',1),(109506,'116445','furniture','block-109504','checkout\\ContactInformation','',2),(109507,'116446','furniture','block-109503-2','BlockBox','',1),(109508,'116447','furniture','block-109507','Html_box','',1),(109509,'116448','furniture','block-109507','checkout\\Comments','',2),(109510,'116449','furniture','checkout_delivery','BlockBox','',3),(109511,'116450','furniture','block-109510','Html_box','',1),(109512,'116451','furniture','block-109510-2','checkout\\ContinueBtn','',1),(109513,'116452','furniture','checkout_delivery','BlockBox','',1),(109514,'116453','furniture','block-109513','BlockBox','',1),(109515,'116455','furniture','block-109514','checkout\\ShippingAddress','',2),(109516,'116456','furniture','block-109513-2','BlockBox','',1),(109517,'116457','furniture','block-109516','DelayedDespatch\\Checkout','',3),(109518,'116458','furniture','block-109516','checkout\\Shipping','',2),(109519,'116459','furniture','block-109516','Html_box','',1),(109520,'116460','furniture','block-109516','Neighbour\\Checkout','',4),(109521,'116461','furniture','checkout_delivery_g','BlockBox','',2),(109522,'116462','furniture','block-109521','BlockBox','',1),(109523,'116463','furniture','block-109522','checkout\\ContactInformation','',2),(109524,'116464','furniture','block-109522','Html_box','',1),(109525,'116465','furniture','block-109521-2','BlockBox','',1),(109526,'116466','furniture','block-109525','Html_box','',1),(109527,'116467','furniture','block-109525','checkout\\Comments','',2),(109528,'116468','furniture','checkout_delivery_g','BlockBox','',3),(109529,'116469','furniture','block-109528','Html_box','',1),(109530,'116470','furniture','block-109528-2','checkout\\ContinueBtn','',1),(109531,'116471','furniture','checkout_delivery_g','BlockBox','',1),(109532,'116472','furniture','block-109531','BlockBox','',1),(109533,'116473','furniture','block-109532','checkout\\ShippingAddress','',2),(109534,'116474','furniture','block-109532','Html_box','',1),(109535,'116475','furniture','block-109531-2','BlockBox','',1),(109536,'116476','furniture','block-109535','checkout\\Shipping','',2),(109537,'116477','furniture','block-109535','Html_box','',1),(109538,'116478','furniture','block-109535','DelayedDespatch\\Checkout','',3),(109539,'116479','furniture','block-109535','Neighbour\\Checkout','',4),(109540,'116480','furniture','checkout_delivery_no_shipping','BlockBox','',2),(109541,'116481','furniture','block-109540','Html_box','',1),(109542,'116482','furniture','block-109540-2','checkout\\ContinueBtn','',1),(109543,'116483','furniture','checkout_delivery_no_shipping','BlockBox','',1),(109544,'116484','furniture','block-109543','BlockBox','',1),(109545,'116485','furniture','block-109544','checkout\\ContactInformation','',2),(109546,'116486','furniture','block-109543-2','BlockBox','',1),(109547,'116487','furniture','block-109546','Html_box','',1),(109548,'116488','furniture','block-109546','checkout\\Comments','',2),(109549,'116489','furniture','checkout_delivery_no_shipping_g','BlockBox','',2),(109550,'116490','furniture','block-109549','Html_box','',1),(109551,'116491','furniture','block-109549-2','checkout\\ContinueBtn','',1),(109552,'116492','furniture','checkout_delivery_no_shipping_g','BlockBox','',1),(109553,'116493','furniture','block-109552','BlockBox','',1),(109554,'116494','furniture','block-109553','checkout\\ContactInformation','',2),(109555,'116495','furniture','block-109552-2','BlockBox','',1),(109556,'116496','furniture','block-109555','checkout\\Comments','',2),(109557,'116497','furniture','block-109555','Html_box','',1),(109558,'116498','furniture','checkout_delivery_title','Html_box','',1),(109559,'116499','furniture','checkout_delivery_title_g','Html_box','',1),(109560,'116501','furniture','checkout_delivery_title_no_shipping','Html_box','',1),(109561,'116500','furniture','checkout_delivery_title_no_shipping_g','Html_box','',1),(109562,'116502','furniture','checkout_delivery_title_q','Html_box','',1),(109563,'116503','furniture','checkout_delivery_title_s','Html_box','',1),(109564,'116504','furniture','checkout_free_s','BlockBox','',1),(109565,'116505','furniture','block-109564','BlockBox','',2),(109566,'116506','furniture','block-109565','BlockBox','',2),(109567,'116508','furniture','block-109566','BlockBox','',6),(109568,'116509','furniture','block-109567','sample\\Products','',1),(109569,'116510','furniture','block-109567','checkout\\CreateAccount','',3),(109570,'116511','furniture','block-109566','BlockBox','',5),(109571,'116512','furniture','block-109570','Html_box','',1),(109572,'116513','furniture','block-109570','checkout\\Comments','',2),(109573,'116514','furniture','block-109566','BlockBox','',2),(109574,'116515','furniture','block-109573','BlockBox','',2),(109575,'116516','furniture','block-109574','checkout\\ShippingChoice','',1),(109576,'116517','furniture','block-109573','Html_box','',1),(109577,'116518','furniture','block-109573','BlockBox','',3),(109578,'116519','furniture','block-109577','BlockBox','',1),(109579,'116520','furniture','block-109578','checkout\\ContactInformation','',4),(109580,'116521','furniture','block-109578','checkout\\ShippingAddress','',2),(109581,'116522','furniture','block-109578','Html_box','',3),(109582,'116523','furniture','block-109577-2','BlockBox','',1),(109583,'116524','furniture','block-109582','DelayedDespatch\\Checkout','',3),(109584,'116525','furniture','block-109573','Neighbour\\Checkout','',4),(109585,'116526','furniture','block-109565-2','BlockBox','',1),(109586,'116527','furniture','block-109585','Html_box','',3),(109587,'116528','furniture','block-109585','checkout\\ContinueBtn','',1),(109588,'1638956949.0762','furniture','block-109585','checkout\\Terms','',2),(109589,'1638957135.2709','furniture','block-109585','Html_box','',0),(109590,'116529','furniture','checkout_no_shipping','BlockBox','',1),(109591,'116530','furniture','block-109590','BlockBox','',2),(109592,'116531','furniture','block-109591','BlockBox','',1),(109593,'116532','furniture','block-109592','BlockBox','',6),(109594,'116533','furniture','block-109593','checkout\\CreateAccount','',2),(109595,'116534','furniture','block-109593','cart\\Products','',1),(109596,'116535','furniture','block-109592','BlockBox','',3),(109597,'116536','furniture','block-109596','Html_box','',1),(109598,'116537','furniture','block-109596','BlockBox','',2),(109599,'116538','furniture','block-109598','checkout\\BillingAddress','',2),(109600,'116539','furniture','block-109598','Html_box','',1),(109601,'116540','furniture','block-109598-2','BlockBox','',1),(109602,'116541','furniture','block-109601','Html_box','',1),(109603,'116542','furniture','block-109601','checkout\\PaymentMethod','',2),(109604,'116543','furniture','block-109592','BlockBox','',4),(109605,'116544','furniture','block-109604','BlockBox','',2),(109606,'116545','furniture','block-109605','CouponsAndVauchers\\Checkout','',1),(109607,'116546','furniture','block-109605-2','checkout\\CreditAmount','',1),(109608,'116547','furniture','block-109605-2','checkout\\BonusPoints','',2),(109609,'116548','furniture','block-109604','Html_box','',1),(109610,'116549','furniture','block-109592','BlockBox','',5),(109611,'116550','furniture','block-109610','checkout\\Comments','',2),(109612,'116551','furniture','block-109610','Html_box','',1),(109613,'116552','furniture','block-109591-2','BlockBox','',1),(109614,'116553','furniture','block-109613','Html_box','',1),(109615,'116554','furniture','block-109613','Html_box','',5),(109616,'116555','furniture','block-109613','checkout\\Totals','',2),(109617,'116556','furniture','block-109613','checkout\\ContinueBtn','',3),(109618,'116557','furniture','block-109613','checkout\\Terms','',4),(109619,'116558','furniture','checkout_no_shipping_g','BlockBox','',1),(109620,'116559','furniture','block-109619','checkout\\Totals','',5),(109621,'116560','furniture','block-109619','BlockBox','',6),(109622,'116561','furniture','block-109621','Html_box','',1),(109623,'116562','furniture','block-109621-2','checkout\\ContinueBtn','',1),(109624,'116563','furniture','block-109619','BlockBox','',2),(109625,'116564','furniture','block-109624','BlockBox','',1),(109626,'116565','furniture','block-109625','checkout\\ContactInformation','',2),(109627,'116566','furniture','block-109625','Html_box','',1),(109628,'116567','furniture','block-109624-2','BlockBox','',1),(109629,'116568','furniture','block-109628','checkout\\Comments','',2),(109630,'116569','furniture','block-109628','Html_box','',1),(109631,'116570','furniture','block-109619','BlockBox','',1),(109632,'116571','furniture','block-109631','BlockBox','',1),(109633,'116572','furniture','block-109632','Html_box','',1),(109634,'116573','furniture','block-109632','checkout\\BillingAddress','',2),(109635,'116574','furniture','block-109631-2','BlockBox','',1),(109636,'116575','furniture','block-109635','checkout\\BonusPoints','',4),(109637,'116576','furniture','block-109635','CouponsAndVauchers\\Checkout','',5),(109638,'116577','furniture','block-109635','checkout\\PaymentMethod','',2),(109639,'116578','furniture','block-109635','checkout\\CreditAmount','',3),(109640,'116579','furniture','block-109635','Html_box','',1),(109641,'116580','furniture','block-109619','quote\\Products','',3),(109642,'116581','furniture','checkout_no_shipping_q','BlockBox','',1),(109643,'116582','furniture','block-109642','BlockBox','',2),(109644,'116583','furniture','block-109643','BlockBox','',2),(109645,'116585','furniture','block-109644','BlockBox','',5),(109646,'116586','furniture','block-109645','checkout\\Comments','',2),(109647,'116587','furniture','block-109645','Html_box','',1),(109648,'116588','furniture','block-109644','BlockBox','',6),(109649,'116589','furniture','block-109648','checkout\\CreateAccount','',3),(109650,'116590','furniture','block-109648','quote\\Products','',2),(109651,'116591','furniture','block-109644','BlockBox','',3),(109652,'116592','furniture','block-109651','Html_box','',1),(109653,'116593','furniture','block-109651','BlockBox','',2),(109654,'116594','furniture','block-109653','Html_box','',1),(109655,'116595','furniture','block-109653','checkout\\BillingAddress','',2),(109656,'116596','furniture','block-109653-2','BlockBox','',1),(109657,'116597','furniture','block-109656','checkout\\PaymentMethod','',2),(109658,'116598','furniture','block-109656','Html_box','',1),(109659,'116599','furniture','block-109643-2','BlockBox','',1),(109660,'116600','furniture','block-109659','checkout\\ContinueBtn','',3),(109661,'116601','furniture','block-109659','Html_box','',5),(109662,'116602','furniture','block-109659','Html_box','',1),(109663,'116603','furniture','block-109659','checkout\\Totals','',2),(109664,'120984','furniture','block-109659','checkout\\Terms','',4),(109665,'116604','furniture','checkout_payment','BlockBox','',1),(109666,'116605','furniture','block-109665','BlockBox','',1),(109667,'116606','furniture','block-109666','checkout\\BillingAddress','',2),(109668,'116607','furniture','block-109666','Html_box','',1),(109669,'116608','furniture','block-109665-2','BlockBox','',1),(109670,'116609','furniture','block-109669','checkout\\CreditAmount','',3),(109671,'116610','furniture','block-109669','checkout\\BonusPoints','',4),(109672,'116611','furniture','block-109669','CouponsAndVauchers\\Checkout','',5),(109673,'116612','furniture','block-109669','checkout\\PaymentMethod','',2),(109674,'116613','furniture','block-109669','Html_box','',1),(109675,'116614','furniture','checkout_payment','BlockBox','',2),(109676,'116615','furniture','block-109675','Html_box','',1),(109677,'116616','furniture','block-109675-2','checkout\\ContinueBtn','',1),(109678,'116617','furniture','checkout_payment_g','BlockBox','',1),(109679,'116618','furniture','block-109678','BlockBox','',1),(109680,'116619','furniture','block-109679','checkout\\BillingAddress','',2),(109681,'116620','furniture','block-109679','Html_box','',1),(109682,'116621','furniture','block-109678-2','BlockBox','',1),(109683,'116622','furniture','block-109682','checkout\\CreditAmount','',3),(109684,'116623','furniture','block-109682','Html_box','',1),(109685,'116624','furniture','block-109682','checkout\\PaymentMethod','',2),(109686,'116625','furniture','block-109682','CouponsAndVauchers\\Checkout','',5),(109687,'116626','furniture','block-109682','checkout\\BonusPoints','',4),(109688,'116627','furniture','checkout_payment_g','BlockBox','',2),(109689,'116628','furniture','block-109688','Html_box','',1),(109690,'116629','furniture','block-109688-2','checkout\\ContinueBtn','',1),(109691,'116630','furniture','checkout_payment_no_shipping','BlockBox','',2),(109692,'116631','furniture','block-109691','Html_box','',1),(109693,'116632','furniture','block-109691-2','checkout\\ContinueBtn','',1),(109694,'116633','furniture','checkout_payment_no_shipping','BlockBox','',1),(109695,'116634','furniture','block-109694','BlockBox','',1),(109696,'116635','furniture','block-109695','Html_box','',1),(109697,'116636','furniture','block-109695','checkout\\BillingAddress','',2),(109698,'116637','furniture','block-109694-2','BlockBox','',1),(109699,'116638','furniture','block-109698','checkout\\BonusPoints','',4),(109700,'116639','furniture','block-109698','CouponsAndVauchers\\Checkout','',5),(109701,'116640','furniture','block-109698','checkout\\PaymentMethod','',2),(109702,'116641','furniture','block-109698','checkout\\CreditAmount','',3),(109703,'116642','furniture','block-109698','Html_box','',1),(109704,'116643','furniture','checkout_payment_no_shipping_g','BlockBox','',2),(109705,'116644','furniture','block-109704','Html_box','',1),(109706,'116645','furniture','block-109704-2','checkout\\ContinueBtn','',1),(109707,'116646','furniture','checkout_payment_no_shipping_g','BlockBox','',1),(109708,'116647','furniture','block-109707','BlockBox','',1),(109709,'116648','furniture','block-109708','checkout\\BillingAddress','',2),(109710,'116649','furniture','block-109708','Html_box','',1),(109711,'116650','furniture','block-109707-2','BlockBox','',1),(109712,'116651','furniture','block-109711','checkout\\BonusPoints','',4),(109713,'116652','furniture','block-109711','checkout\\CreditAmount','',3),(109714,'116653','furniture','block-109711','checkout\\PaymentMethod','',2),(109715,'116654','furniture','block-109711','Html_box','',1),(109716,'116655','furniture','block-109711','CouponsAndVauchers\\Checkout','',5),(109717,'116656','furniture','checkout_payment_title','Html_box','',1),(109718,'116657','furniture','checkout_payment_title_g','Html_box','',1),(109719,'116658','furniture','checkout_payment_title_no_shipping','Html_box','',1),(109720,'116659','furniture','checkout_payment_title_no_shipping_g','Html_box','',1),(109721,'116660','furniture','checkout_payment_title_q','Html_box','',1),(109722,'116661','furniture','checkout_payment_title_s','Html_box','',1),(109723,'120947','furniture','checkout_q','BlockBox','',1),(109724,'120948','furniture','block-109723','BlockBox','',2),(109725,'120949','furniture','block-109724','BlockBox','',2),(109726,'120950','furniture','block-109725','BlockBox','',6),(109727,'120951','furniture','block-109726','checkout\\CreateAccount','',3),(109728,'120952','furniture','block-109726','quote\\Products','',2),(109729,'120953','furniture','block-109725','BlockBox','',2),(109730,'120954','furniture','block-109729','BlockBox','',2),(109731,'120955','furniture','block-109730','checkout\\ShippingChoice','',1),(109732,'120956','furniture','block-109729','Neighbour\\Checkout','',4),(109733,'120957','furniture','block-109729','Html_box','',1),(109734,'120958','furniture','block-109729','BlockBox','',3),(109735,'120959','furniture','block-109734','BlockBox','',1),(109736,'120960','furniture','block-109735','checkout\\ContactInformation','',4),(109737,'120961','furniture','block-109735','checkout\\ShippingAddress','',2),(109738,'120962','furniture','block-109735','Html_box','',3),(109739,'120963','furniture','block-109734-2','BlockBox','',1),(109740,'120964','furniture','block-109739','checkout\\Shipping','',2),(109741,'120965','furniture','block-109739','Html_box','',1),(109742,'120966','furniture','block-109739','DelayedDespatch\\Checkout','',3),(109743,'120967','furniture','block-109725','BlockBox','',5),(109744,'120968','furniture','block-109743','Html_box','',1),(109745,'120969','furniture','block-109743','checkout\\Comments','',2),(109746,'120970','furniture','block-109725','BlockBox','',3),(109747,'120971','furniture','block-109746','Html_box','',1),(109748,'120972','furniture','block-109746','BlockBox','',2),(109749,'120973','furniture','block-109748','checkout\\BillingAddress','',2),(109750,'120974','furniture','block-109748','Html_box','',1),(109751,'120975','furniture','block-109748-2','BlockBox','',1),(109752,'120976','furniture','block-109751','checkout\\PaymentMethod','',2),(109753,'120977','furniture','block-109751','Html_box','',1),(109754,'120978','furniture','block-109724-2','BlockBox','',1),(109755,'120979','furniture','block-109754','Html_box','',1),(109756,'120980','furniture','block-109754','Html_box','',5),(109757,'120981','furniture','block-109754','checkout\\Totals','',2),(109758,'120982','furniture','block-109754','checkout\\ContinueBtn','',3),(109759,'120983','furniture','block-109754','checkout\\Terms','',4),(109760,'116699','furniture','checkout_s','BlockBox','',1),(109761,'116700','furniture','block-109760','BlockBox','',2),(109762,'116701','furniture','block-109761','BlockBox','',2),(109763,'116703','furniture','block-109762','BlockBox','',6),(109764,'116704','furniture','block-109763','sample\\Products','',1),(109765,'116705','furniture','block-109763','checkout\\CreateAccount','',3),(109766,'116706','furniture','block-109762','BlockBox','',2),(109767,'116707','furniture','block-109766','Html_box','',1),(109768,'116708','furniture','block-109766','Neighbour\\Checkout','',4),(109769,'116709','furniture','block-109766','BlockBox','',2),(109770,'116710','furniture','block-109769','checkout\\ShippingChoice','',1),(109771,'116711','furniture','block-109766','BlockBox','',3),(109772,'116712','furniture','block-109771','BlockBox','',1),(109773,'116713','furniture','block-109772','checkout\\ShippingAddress','',2),(109774,'116714','furniture','block-109772','checkout\\ContactInformation','',4),(109775,'116715','furniture','block-109772','Html_box','',3),(109776,'116716','furniture','block-109771-2','BlockBox','',1),(109777,'116717','furniture','block-109776','checkout\\Shipping','',2),(109778,'116718','furniture','block-109776','DelayedDespatch\\Checkout','',3),(109779,'116719','furniture','block-109776','Html_box','',1),(109780,'116720','furniture','block-109762','BlockBox','',3),(109781,'116721','furniture','block-109780','BlockBox','',2),(109782,'116722','furniture','block-109781','Html_box','',1),(109783,'116723','furniture','block-109781','checkout\\BillingAddress','',2),(109784,'116724','furniture','block-109781-2','BlockBox','',1),(109785,'116725','furniture','block-109784','Html_box','',1),(109786,'116726','furniture','block-109784','checkout\\PaymentMethod','',2),(109787,'116727','furniture','block-109780','Html_box','',1),(109788,'116728','furniture','block-109762','BlockBox','',5),(109789,'116729','furniture','block-109788','Html_box','',1),(109790,'116730','furniture','block-109788','checkout\\Comments','',2),(109791,'116731','furniture','block-109762','BlockBox','',4),(109792,'116732','furniture','block-109791','BlockBox','',2),(109793,'116733','furniture','block-109792','CouponsAndVauchers\\Checkout','',1),(109794,'116734','furniture','block-109792-2','checkout\\BonusPoints','',2),(109795,'116735','furniture','block-109792-2','checkout\\CreditAmount','',1),(109796,'116736','furniture','block-109791','Html_box','',1),(109797,'116737','furniture','block-109761-2','BlockBox','',1),(109798,'116738','furniture','block-109797','checkout\\Totals','',2),(109799,'116739','furniture','block-109797','Html_box','',5),(109800,'116740','furniture','block-109797','Html_box','',1),(109801,'116741','furniture','block-109797','checkout\\ContinueBtn','',3),(109802,'120986','furniture','block-109797','checkout\\Terms','',4),(109803,'116742','furniture','checkout_step_bottom','Html_box','',1),(109804,'116743','furniture','checkout_step_bottom','cart\\Products','',2),(109805,'116744','furniture','checkout_step_bottom','checkout\\Totals','',3),(109806,'116745','furniture','checkout_step_bottom_g','checkout\\Totals','',3),(109807,'116746','furniture','checkout_step_bottom_g','quote\\Products','',2),(109808,'116747','furniture','checkout_step_bottom_g','Html_box','',1),(109809,'116749','furniture','checkout_step_bottom_no_shipping','Html_box','',1),(109810,'116750','furniture','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(109811,'116753','furniture','checkout_step_bottom_no_shipping','cart\\Products','',2),(109812,'116748','furniture','checkout_step_bottom_no_shipping_g','Html_box','',1),(109813,'116751','furniture','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(109814,'116752','furniture','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(109815,'116754','furniture','communication','BlockBox','',1),(109816,'116755','furniture','block-109815','Html_box','',2),(109817,'116756','furniture','block-109815','Communication\\NewTopicButton','',1),(109818,'116757','furniture','block-109815','Communication\\Topic','',3),(109819,'116758','furniture','compare','BlockBox','',1),(109820,'116759','furniture','block-109819','catalog\\Compare','',1),(109821,'117665.000001','furniture','compareproduct','BlockBox','listing-item',1),(109822,'120921.000001','furniture','block-109821','BlockBox','',1),(109823,'120919.000001','furniture','block-109822','BlockBox','listing-item',1),(109824,'1638872990.9609','furniture','block-109823','BlockBox','',2),(109825,'117671.000001','furniture','block-109824','productListing\\image','',1),(109826,'117677.000001','furniture','block-109824-2','productListing\\compare','',1),(109827,'117675.000001','furniture','block-109824-2','productListing\\name','',2),(109828,'117676.000001','furniture','block-109824-2','productListing\\stock','',3),(109829,'1638873112.0384','furniture','block-109824-2','BlockBox','',4),(109830,'117670.000001','furniture','block-109829','productListing\\rating','',2),(109831,'117673.000001','furniture','block-109829-2','productListing\\price','',1),(109832,'116760','furniture','compare_products','BlockBox','',2),(109833,'116761','furniture','block-109832','productListing\\rating','',4),(109834,'116762','furniture','block-109832','productListing\\model','',5),(109835,'116763','furniture','block-109832','productListing\\compare','',1),(109836,'116764','furniture','block-109832','BlockBox','',2),(109837,'116765','furniture','block-109836','productListing\\image','',1),(109838,'116766','furniture','block-109836-2','productListing\\name','',2),(109839,'116767','furniture','block-109832','BlockBox','',3),(109840,'116768','furniture','block-109839','productListing\\price','',1),(109841,'116769','furniture','block-109839-2','productListing\\buyButton','',1),(109842,'116770','furniture','confirmation','BlockBox','',1),(109843,'116771','furniture','block-109842','BlockBox','',2),(109844,'116772','furniture','block-109843','BlockBox','',2),(109845,'116773','furniture','block-109844','BlockBox','',4),(109846,'116774','furniture','block-109845','checkout\\EditBtn','',2),(109847,'116775','furniture','block-109845','cart\\Products','',3),(109848,'116776','furniture','block-109845','Html_box','',1),(109849,'116777','furniture','block-109844','BlockBox','',3),(109850,'116778','furniture','block-109849','checkout\\EditBtn','',2),(109851,'116779','furniture','block-109849','Html_box','',1),(109852,'116780','furniture','block-109849','checkout\\CommentsConfirm','',3),(109853,'116781','furniture','block-109844','BlockBox','',1),(109854,'116782','furniture','block-109853','BlockBox','',1),(109855,'116783','furniture','block-109854','checkout\\EditBtn','',6),(109856,'116784','furniture','block-109854','DelayedDespatch\\CheckoutConfirm','',8),(109857,'116785','furniture','block-109854','Html_box','',9),(109858,'116786','furniture','block-109854','checkout\\EditBtn','',10),(109859,'116787','furniture','block-109854','Html_box','',5),(109860,'116788','furniture','block-109854','checkout\\ShippingConfirm','',7),(109861,'116789','furniture','block-109854','Html_box','',1),(109862,'116790','furniture','block-109854','checkout\\EditBtn','',3),(109863,'116791','furniture','block-109854','checkout\\ContactConfirm','',11),(109864,'116792','furniture','block-109854','Html_box','',2),(109865,'116793','furniture','block-109854','checkout\\ShippingAddressConfirm','',4),(109866,'116794','furniture','block-109853-2','BlockBox','',1),(109867,'116795','furniture','block-109866','checkout\\EditBtn','',6),(109868,'116796','furniture','block-109866','checkout\\EditBtn','',3),(109869,'116797','furniture','block-109866','checkout\\PaymentMethodConfirm','',7),(109870,'116798','furniture','block-109866','Html_box','',5),(109871,'116799','furniture','block-109866','Html_box','',1),(109872,'116800','furniture','block-109866','checkout\\BillingAddressConfirm','',4),(109873,'116801','furniture','block-109866','Html_box','',2),(109874,'116802','furniture','block-109843','UploadCustomerId\\UploadCustomerIdForm','',1),(109875,'116803','furniture','block-109843-2','BlockBox','',1),(109876,'116804','furniture','block-109875','Html_box','',1),(109877,'116805','furniture','block-109875','checkout\\ConfirmBtn','',3),(109878,'116806','furniture','block-109875','checkout\\Totals','',2),(109879,'116807','furniture','block-109842','Html_box','',1),(109880,'116808','furniture','confirmation_free_s','BlockBox','',1),(109881,'116809','furniture','block-109880','BlockBox','',2),(109882,'116810','furniture','block-109881','BlockBox','',1),(109883,'116811','furniture','block-109882','BlockBox','',2),(109884,'116812','furniture','block-109883','checkout\\CommentsConfirm','',3),(109885,'116813','furniture','block-109883','checkout\\EditBtn','',2),(109886,'116814','furniture','block-109883','Html_box','',1),(109887,'116815','furniture','block-109882','BlockBox','',3),(109888,'116816','furniture','block-109887','checkout\\EditBtn','',3),(109889,'116817','furniture','block-109887','Html_box','',1),(109890,'116818','furniture','block-109887','sample\\Products','',2),(109891,'116819','furniture','block-109882','BlockBox','',1),(109892,'116820','furniture','block-109891','BlockBox','',1),(109893,'116821','furniture','block-109892','checkout\\EditBtn','',3),(109894,'116822','furniture','block-109892','checkout\\ShippingConfirm','',7),(109895,'116823','furniture','block-109892','Html_box','',5),(109896,'116824','furniture','block-109892','checkout\\EditBtn','',6),(109897,'116825','furniture','block-109892','Html_box','',2),(109898,'116826','furniture','block-109892','checkout\\ShippingAddressConfirm','',4),(109899,'116827','furniture','block-109891-2','BlockBox','',1),(109900,'116828','furniture','block-109899','checkout\\ContactConfirm','',3),(109901,'116829','furniture','block-109899','DelayedDespatch\\CheckoutConfirm','',4),(109902,'116830','furniture','block-109899','checkout\\EditBtn','',2),(109903,'116831','furniture','block-109899','Html_box','',1),(109904,'116832','furniture','block-109881-2','BlockBox','',1),(109905,'116833','furniture','block-109904','checkout\\ConfirmBtn','',3),(109906,'116834','furniture','block-109880','Html_box','',1),(109907,'116835','furniture','confirmation_no_shipping','BlockBox','',1),(109908,'116836','furniture','block-109907','Html_box','',1),(109909,'116837','furniture','block-109907','BlockBox','',2),(109910,'116838','furniture','block-109909','BlockBox','',1),(109911,'116839','furniture','block-109910','BlockBox','',1),(109912,'116840','furniture','block-109911','BlockBox','',1),(109913,'116841','furniture','block-109912','checkout\\EditBtn','',10),(109914,'116842','furniture','block-109912','Html_box','',9),(109915,'116843','furniture','block-109912','checkout\\ContactConfirm','',11),(109916,'116844','furniture','block-109911-2','BlockBox','',1),(109917,'116845','furniture','block-109916','checkout\\PaymentMethodConfirm','',7),(109918,'116846','furniture','block-109916','checkout\\EditBtn','',6),(109919,'116847','furniture','block-109916','Html_box','',5),(109920,'116848','furniture','block-109916','Html_box','',1),(109921,'116849','furniture','block-109916','checkout\\EditBtn','',3),(109922,'116850','furniture','block-109916','checkout\\BillingAddressConfirm','',4),(109923,'116851','furniture','block-109916','Html_box','',2),(109924,'116852','furniture','block-109910','BlockBox','',2),(109925,'116853','furniture','block-109924','Html_box','',1),(109926,'116854','furniture','block-109924','checkout\\CommentsConfirm','',3),(109927,'116855','furniture','block-109924','checkout\\EditBtn','',2),(109928,'116856','furniture','block-109910','BlockBox','',3),(109929,'116857','furniture','block-109928','Html_box','',1),(109930,'116858','furniture','block-109928','checkout\\EditBtn','',2),(109931,'116859','furniture','block-109928','cart\\Products','',3),(109932,'116860','furniture','block-109909-2','BlockBox','',1),(109933,'116861','furniture','block-109932','checkout\\ConfirmBtn','',3),(109934,'116862','furniture','block-109932','Html_box','',1),(109935,'116863','furniture','block-109932','checkout\\Totals','',2),(109936,'116864','furniture','confirmation_no_shipping_q','BlockBox','',2),(109937,'116865','furniture','block-109936','Html_box','',1),(109938,'116866','furniture','block-109936','BlockBox','',2),(109939,'116867','furniture','block-109938','BlockBox','',1),(109940,'116868','furniture','block-109939','BlockBox','',2),(109941,'116869','furniture','block-109940','Html_box','',1),(109942,'116870','furniture','block-109940','checkout\\CommentsConfirm','',3),(109943,'116871','furniture','block-109940','checkout\\EditBtn','',2),(109944,'116872','furniture','block-109939','BlockBox','',1),(109945,'116873','furniture','block-109944','BlockBox','',1),(109946,'116874','furniture','block-109945','checkout\\EditBtn','',5),(109947,'116875','furniture','block-109945','checkout\\ContactConfirm','',6),(109948,'116876','furniture','block-109945','checkout\\PaymentMethodConfirm','',3),(109949,'116877','furniture','block-109945','checkout\\EditBtn','',2),(109950,'116878','furniture','block-109945','Html_box','',4),(109951,'116879','furniture','block-109945','Html_box','',1),(109952,'116880','furniture','block-109944-2','BlockBox','',1),(109953,'116881','furniture','block-109952','checkout\\BillingAddressConfirm','',4),(109954,'116882','furniture','block-109952','checkout\\EditBtn','',3),(109955,'116883','furniture','block-109952','Html_box','',2),(109956,'116884','furniture','block-109939','BlockBox','',3),(109957,'116885','furniture','block-109956','checkout\\EditBtn','',2),(109958,'116886','furniture','block-109956','Html_box','',1),(109959,'116887','furniture','block-109956','quote\\Products','',3),(109960,'116888','furniture','block-109938-2','BlockBox','',1),(109961,'116889','furniture','block-109960','checkout\\ConfirmBtn','',3),(109962,'116890','furniture','block-109960','checkout\\Totals','',2),(109963,'116891','furniture','block-109960','Html_box','',1),(109964,'116892','furniture','confirmation_q','BlockBox','',1),(109965,'116893','furniture','block-109964','Html_box','',1),(109966,'116894','furniture','block-109964','BlockBox','',2),(109967,'116895','furniture','block-109966','BlockBox','',1),(109968,'116896','furniture','block-109967','BlockBox','',3),(109969,'116897','furniture','block-109968','quote\\Products','',3),(109970,'116898','furniture','block-109968','Html_box','',1),(109971,'116899','furniture','block-109968','checkout\\EditBtn','',2),(109972,'116900','furniture','block-109967','BlockBox','',1),(109973,'116901','furniture','block-109972','BlockBox','',1),(109974,'116902','furniture','block-109973','Html_box','',1),(109975,'116903','furniture','block-109973','checkout\\EditBtn','',10),(109976,'116904','furniture','block-109973','Html_box','',2),(109977,'116905','furniture','block-109973','checkout\\ContactConfirm','',11),(109978,'116906','furniture','block-109973','checkout\\ShippingAddressConfirm','',4),(109979,'116907','furniture','block-109973','checkout\\ShippingConfirm','',7),(109980,'116908','furniture','block-109973','checkout\\EditBtn','',3),(109981,'116909','furniture','block-109973','DelayedDespatch\\CheckoutConfirm','',8),(109982,'116910','furniture','block-109973','Html_box','',9),(109983,'116911','furniture','block-109973','Html_box','',5),(109984,'116912','furniture','block-109973','checkout\\EditBtn','',6),(109985,'116913','furniture','block-109972-2','BlockBox','',1),(109986,'116914','furniture','block-109985','checkout\\EditBtn','',3),(109987,'116915','furniture','block-109985','checkout\\BillingAddressConfirm','',4),(109988,'116916','furniture','block-109985','checkout\\PaymentMethodConfirm','',7),(109989,'116917','furniture','block-109985','Html_box','',1),(109990,'116918','furniture','block-109985','Html_box','',2),(109991,'116919','furniture','block-109985','checkout\\EditBtn','',6),(109992,'116920','furniture','block-109985','Html_box','',5),(109993,'116921','furniture','block-109967','BlockBox','',2),(109994,'116922','furniture','block-109993','checkout\\CommentsConfirm','',3),(109995,'116923','furniture','block-109993','Html_box','',1),(109996,'116924','furniture','block-109993','checkout\\EditBtn','',2),(109997,'116925','furniture','block-109966-2','BlockBox','',1),(109998,'116926','furniture','block-109997','Html_box','',1),(109999,'116927','furniture','block-109997','checkout\\Totals','',2),(110000,'116928','furniture','block-109997','checkout\\ConfirmBtn','',3),(110001,'116929','furniture','confirmation_s','BlockBox','',1),(110002,'116930','furniture','block-110001','BlockBox','',2),(110003,'116931','furniture','block-110002','BlockBox','',1),(110004,'116932','furniture','block-110003','BlockBox','',1),(110005,'116933','furniture','block-110004','BlockBox','',1),(110006,'116934','furniture','block-110005','checkout\\ShippingAddressConfirm','',4),(110007,'116935','furniture','block-110005','checkout\\EditBtn','',3),(110008,'116936','furniture','block-110005','Html_box','',2),(110009,'116937','furniture','block-110005','DelayedDespatch\\CheckoutConfirm','',8),(110010,'116938','furniture','block-110005','checkout\\ShippingConfirm','',7),(110011,'116939','furniture','block-110005','Html_box','',1),(110012,'116940','furniture','block-110005','Html_box','',5),(110013,'116941','furniture','block-110005','Html_box','',9),(110014,'116942','furniture','block-110005','checkout\\ContactConfirm','',11),(110015,'116943','furniture','block-110005','checkout\\EditBtn','',6),(110016,'116944','furniture','block-110005','checkout\\EditBtn','',10),(110017,'116945','furniture','block-110004-2','BlockBox','',1),(110018,'116946','furniture','block-110017','Html_box','',2),(110019,'116947','furniture','block-110017','checkout\\BillingAddressConfirm','',4),(110020,'116948','furniture','block-110017','checkout\\EditBtn','',3),(110021,'116949','furniture','block-110017','checkout\\PaymentMethodConfirm','',7),(110022,'116950','furniture','block-110017','checkout\\EditBtn','',6),(110023,'116951','furniture','block-110017','Html_box','',1),(110024,'116952','furniture','block-110017','Html_box','',5),(110025,'116953','furniture','block-110003','BlockBox','',3),(110026,'116954','furniture','block-110025','checkout\\EditBtn','',3),(110027,'116955','furniture','block-110025','Html_box','',1),(110028,'116956','furniture','block-110025','sample\\Products','',2),(110029,'116957','furniture','block-110003','BlockBox','',2),(110030,'116958','furniture','block-110029','Html_box','',1),(110031,'116959','furniture','block-110029','checkout\\EditBtn','',2),(110032,'116960','furniture','block-110029','checkout\\CommentsConfirm','',3),(110033,'116961','furniture','block-110002-2','BlockBox','',1),(110034,'116962','furniture','block-110033','checkout\\Totals','',2),(110035,'116963','furniture','block-110033','checkout\\ConfirmBtn','',3),(110036,'116964','furniture','block-110033','Html_box','',1),(110037,'116965','furniture','block-110001','Html_box','',1),(110038,'116966','furniture','contact','BlockBox','info-content',1),(110039,'116967','furniture','block-110038','info\\Title','',1),(110040,'116968','furniture','block-110038','BlockBox','',2),(110041,'116969','furniture','block-110040','contact\\ContactForm','',1),(110042,'116970','furniture','block-110040-2','contact\\Contacts','',1),(110043,'116971','furniture','created_success','BlockBox','',1),(110044,'116972','furniture','block-110043','Html_box','',1),(110045,'116973','furniture','block-110043','Html_box','',2),(110046,'116102.000001','furniture','credit_amount_history','BlockBox','',1),(110047,'116103.000001','furniture','block-110046','BlockBox','',1),(110048,'116104.000001','furniture','block-110047','WidgetsAria','',1),(110068,'116109.000001','furniture','block-110047-2','Html_box','',1),(110069,'1638895944.9672','furniture','block-110047-2','account\\CreditAmountHistory','',2),(110070,'116974','furniture','credit_note','invoice\\Container','',1),(110071,'116975','furniture','block-110070','BlockBox','',5),(110072,'116976','furniture','block-110071','invoice\\StoreAddress','',8),(110073,'116977','furniture','block-110071','Text','',1),(110074,'116978','furniture','block-110071-2','Text','',2),(110075,'116979','furniture','block-110071-2','Logo','',1),(110076,'116980','furniture','block-110071-3','Text','',1),(110077,'116981','furniture','block-110071-3','BlockBox','',3),(110078,'116982','furniture','block-110077','Text','',1),(110079,'116983','furniture','block-110077-2','invoice\\StoreEmail','',1),(110080,'116984','furniture','block-110071-3','BlockBox','',2),(110081,'116985','furniture','block-110080','Text','',1),(110082,'116986','furniture','block-110080-2','invoice\\StorePhone','',1),(110083,'116987','furniture','block-110070','invoice\\Products','',3),(110084,'116988','furniture','block-110070','BlockBox','',1),(110085,'116989','furniture','block-110084','Logo','',1),(110086,'116990','furniture','block-110084-2','BlockBox','',4),(110087,'116991','furniture','block-110086','Text','',1),(110088,'116992','furniture','block-110086-2','invoice\\StoreSite','',1),(110089,'116993','furniture','block-110084-2','BlockBox','',2),(110090,'116994','furniture','block-110089','Text','',1),(110091,'116995','furniture','block-110089-2','invoice\\StorePhone','',1),(110092,'116996','furniture','block-110084-2','BlockBox','',3),(110093,'116997','furniture','block-110092','Text','',1),(110094,'116998','furniture','block-110092-2','invoice\\StoreEmail','',1),(110095,'116999','furniture','block-110084-2','BlockBox','',1),(110096,'117000','furniture','block-110095','invoice\\StoreAddress','',1),(110097,'117001','furniture','block-110070','BlockBox','',4),(110098,'117002','furniture','block-110097','BlockBox','',1),(110099,'117003','furniture','block-110098','invoice\\ShippingAddress','',2),(110100,'117004','furniture','block-110098','Text','',1),(110101,'117005','furniture','block-110097-2','BlockBox','',1),(110102,'117006','furniture','block-110070','BlockBox','',2),(110103,'117007','furniture','block-110102','BlockBox','',7),(110104,'117008','furniture','block-110103','BlockBox','',1),(110105,'117009','furniture','block-110104','Text','',1),(110106,'117010','furniture','block-110104','invoice\\BillingAddress','',2),(110107,'117011','furniture','block-110103-2','BlockBox','',1),(110108,'117012','furniture','block-110107','invoice\\CustomerPhone','',4),(110109,'117013','furniture','block-110107','Text','',1),(110110,'117014','furniture','block-110107','Text','',3),(110111,'117015','furniture','block-110107','invoice\\CustomerName','',2),(110112,'117016','furniture','block-110107','invoice\\CustomerEmail','',6),(110113,'117017','furniture','block-110107','Text','',5),(110114,'117018','furniture','block-110102','BlockBox','',8),(110115,'117019','furniture','block-110114','BlockBox','',1),(110116,'117020','furniture','block-110115','invoice\\ShippingMethod','',2),(110117,'117021','furniture','block-110115','Text','',1),(110118,'117022','furniture','block-110114-2','BlockBox','',1),(110119,'117023','furniture','block-110118','Text','',1),(110120,'117024','furniture','block-110118','invoice\\ShippingMethod','',2),(110121,'117025','furniture','block-110102-2','invoice\\OrderId','',1),(110122,'117026','furniture','block-110102-2','Text','',2),(110123,'117027','furniture','block-110102-2','invoice\\PaymentDate','',3),(110124,'117034','furniture','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(110125,'1639155816.3893','furniture','delivery-location','BlockBox','',2),(110126,'117028','furniture','block-110125','DeliveryLocation\\FeaturedList','',6),(110127,'117029','furniture','block-110125','DeliveryLocation\\LocationLongDescription','',3),(110128,'117030','furniture','block-110125','DeliveryLocation\\LocationList','',4),(110129,'117031','furniture','block-110125','DeliveryLocation\\LocationTitle','',1),(110130,'117032','furniture','block-110125','DeliveryLocation\\LocationProducts','',7),(110131,'117033','furniture','block-110125','DeliveryLocation\\LocationDescription','',2),(110132,'1639485067.5512','furniture','block-110125','DeliveryLocation\\CrossPages','',0),(110133,'1639485089.2227','furniture','block-110125','DeliveryLocation\\ProductCategories','',0),(110134,'1639154415.2739','furniture','delivery-location-default','BlockBox','',2),(110135,'117035','furniture','block-110134','DeliveryLocation\\TopLocationList','',2),(110136,'117036','furniture','block-110134','Heading','',1),(110137,'1639419797.9718','furniture','block-110134','DeliveryLocation\\ListByPage','',3),(110138,'117037','furniture','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(110139,'117038','furniture','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(110140,'117039','furniture','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(110141,'117040','furniture','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(110142,'117041','furniture','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(110143,'117042','furniture','delivery_loc_2','DeliveryLocation\\LocationList','',7),(110144,'117043','furniture','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(110145,'117044','furniture','email','email\\BlockBox','',1),(110146,'117045','furniture','block-110145','email\\BlockBox','',1),(110147,'117046','furniture','block-110146','Copyright','',4),(110148,'117047','furniture','block-110146','email\\Content','',3),(110149,'117048','furniture','block-110146','email\\BlockBox','',2),(110150,'117049','furniture','block-110149','email\\Title','',1),(110151,'117050','furniture','block-110149-2','email\\Date','',1),(110152,'117051','furniture','block-110146','Logo','',1),(110153,'117052','furniture','email_2','email\\BlockBox','',1),(110154,'117053','furniture','block-110153','email\\BlockBox','',1),(110155,'117054','furniture','block-110154','Copyright','',4),(110156,'117055','furniture','block-110154','Logo','',1),(110157,'117056','furniture','block-110154','email\\Content','',3),(110158,'117057','furniture','block-110154','email\\BlockBox','',2),(110159,'117058','furniture','block-110158','email\\Title','',1),(110160,'117059','furniture','block-110158-2','email\\Date','',1),(110161,'117060','furniture','email_3','email\\BlockBox','',1),(110162,'117061','furniture','block-110161','email\\BlockBox','',1),(110163,'117062','furniture','block-110162','email\\BlockBox','',2),(110164,'117063','furniture','block-110163','email\\Content','',2),(110165,'117064','furniture','block-110163','email\\BlockBox','',1),(110166,'117065','furniture','block-110165','email\\Title','',1),(110167,'117066','furniture','block-110165-2','email\\Date','',1),(110168,'117067','furniture','block-110162','Copyright','',3),(110169,'117068','furniture','block-110162','Logo','',1),(110170,'117069','furniture','email_4','email\\BlockBox','',1),(110171,'117070','furniture','block-110170','email\\BlockBox','',1),(110172,'117071','furniture','block-110171','Copyright','',2),(110173,'117072','furniture','block-110171','email\\BlockBox','',1),(110174,'117073','furniture','block-110173','email\\BlockBox','',1),(110175,'117074','furniture','block-110174','Logo','',1),(110176,'117075','furniture','block-110174-2','email\\Date','',2),(110177,'117076','furniture','block-110174-2','email\\Title','',1),(110178,'117077','furniture','block-110173','email\\Content','',2),(110179,'121029','furniture','filescatalog_category','BlockBox','',1),(110180,'121030','furniture','block-110179','FilesCatalog\\widgets\\FilesList','',3),(110181,'121031','furniture','block-110179','FilesCatalog\\widgets\\Title','',1),(110182,'121032','furniture','block-110179','FilesCatalog\\widgets\\Description','',2),(110183,'121025','furniture','filescatalog_index','BlockBox','',1),(110184,'121026','furniture','block-110183','Html_box','',1),(110185,'121027','furniture','block-110183','FilesCatalog\\widgets\\FilesCatalog','',2),(110186,'117078','furniture','footer','BlockBox','footer-content',1),(110187,'120866','furniture','block-110186','BlockBox','',3),(110188,'117091','furniture','block-110187','Contacts','',2),(110189,'120868','furniture','block-110187','Logo','',1),(110190,'120871','furniture','block-110187-2','BlockBox','',1),(110191,'117085','furniture','block-110190','Menu','Footer',2),(110192,'120869','furniture','block-110190','BlockBox','',3),(110193,'120870','furniture','block-110192','Image','',3),(110194,'120872','furniture','block-110192','Banner','',1),(110195,'120873','furniture','block-110192','Html_box','',2),(110196,'117093','furniture','footer','BlockBox','',2),(110197,'117094','furniture','block-110196','Copyright','',1),(110198,'117096','furniture','for_menu','BlockBox','',1),(110199,'117097','furniture','block-110198','Html_box','',1),(110200,'117098','furniture','block-110198-2','Languages','',1),(110201,'117099','furniture','for_menu','BlockBox','',3),(110202,'117100','furniture','block-110201','Html_box','',1),(110203,'117101','furniture','block-110201-2','Currencies','',1),(110204,'117102','furniture','gift','BlockBox','',1),(110205,'117103','furniture','block-110204','BlockBox','',3),(110206,'117104','furniture','block-110205','BlockBox','',1),(110207,'117105','furniture','block-110206','gift\\Card','',1),(110208,'117106','furniture','block-110205-2','gift\\Form','',2),(110209,'117107','furniture','block-110205-2','Text','',1),(110210,'117108','furniture','block-110204','info\\Title','',1),(110211,'117109','furniture','gift_card','BlockBox','',1),(110212,'117110','furniture','block-110211','BlockBox','',11),(110213,'117111','furniture','block-110212','invoice\\StoreEmail','',3),(110214,'117112','furniture','block-110212','Text','',1),(110215,'117113','furniture','block-110212','invoice\\StorePhone','',2),(110216,'117114','furniture','block-110211','Text','',8),(110217,'117115','furniture','block-110211','Text','',3),(110218,'117116','furniture','block-110211','BlockBox','',10),(110219,'117117','furniture','block-110218','Text','',1),(110220,'117118','furniture','block-110218-2','gift\\CodeView','',1),(110221,'117119','furniture','block-110211','gift\\MessageView','',7),(110222,'117120','furniture','block-110211','gift\\AmountView','',5),(110223,'117121','furniture','block-110211','Text','',6),(110224,'117123','furniture','block-110211','Logo','',1),(110225,'117124','furniture','block-110211','Text','',4),(110226,'117125','furniture','block-110211','Text','',9),(110227,'117126','furniture','gift_card_2','BlockBox','',1),(110228,'117127','furniture','block-110227','gift\\AmountView','',4),(110229,'117128','furniture','block-110227','BlockBox','',9),(110230,'117129','furniture','block-110229','Text','',1),(110231,'117130','furniture','block-110229-2','gift\\CodeView','',1),(110232,'117131','furniture','block-110227','BlockBox','',10),(110233,'117132','furniture','block-110232','invoice\\StoreEmail','',3),(110234,'117133','furniture','block-110232','Text','',1),(110235,'117134','furniture','block-110232','invoice\\StorePhone','',2),(110236,'117135','furniture','block-110227','gift\\MessageView','',6),(110237,'117136','furniture','block-110227','Text','',5),(110238,'117137','furniture','block-110227','Text','',8),(110239,'117138','furniture','block-110227','Text','',3),(110240,'117139','furniture','block-110227','Text','',7),(110241,'1638804282.8587','furniture','block-110227','Logo','',1),(110242,'117141','furniture','gift_card_2_pdf','BlockBox','',1),(110243,'117142','furniture','block-110242','BlockBox','',12),(110244,'117143','furniture','block-110243','invoice\\StoreEmail','',4),(110245,'117144','furniture','block-110243','invoice\\StorePhone','',3),(110246,'117145','furniture','block-110243','Html_box','',1),(110247,'117146','furniture','block-110242','BlockBox','',11),(110248,'117147','furniture','block-110247','Html_box','',1),(110249,'117148','furniture','block-110247-2','gift\\CodeViewPdf','',1),(110250,'117149','furniture','block-110242','BlockBox','',1),(110251,'117150','furniture','block-110250','Text','',4),(110252,'117151','furniture','block-110250','Html_box','',1),(110253,'117152','furniture','block-110250','Html_box','',2),(110254,'117153','furniture','block-110250','gift\\AmountViewPdf','',3),(110255,'117154','furniture','block-110250','gift\\MessageViewPdf','',5),(110256,'117155','furniture','block-110250','Html_box','',7),(110257,'117156','furniture','block-110250','Html_box','',6),(110258,'117157','furniture','gift_card_2_pdf','Import','',1),(110259,'117158','furniture','gift_card_pdf','BlockBox','',1),(110260,'117159','furniture','block-110259','BlockBox','',12),(110261,'117160','furniture','block-110260','invoice\\StoreEmail','',4),(110262,'117161','furniture','block-110260','invoice\\StorePhone','',3),(110263,'117162','furniture','block-110260','Html_box','',1),(110264,'117163','furniture','block-110259','BlockBox','',11),(110265,'117164','furniture','block-110264','Html_box','',1),(110266,'117165','furniture','block-110264-2','gift\\CodeViewPdf','',1),(110267,'117166','furniture','block-110259','BlockBox','',1),(110268,'117167','furniture','block-110267','Text','',5),(110269,'117169','furniture','block-110267','Html_box','',3),(110270,'117170','furniture','block-110267','gift\\AmountViewPdf','',4),(110271,'117171','furniture','block-110267','gift\\MessageViewPdf','',6),(110272,'117172','furniture','block-110267','Html_box','',8),(110273,'117173','furniture','block-110267','Html_box','',7),(110274,'1638978695.8384','furniture','block-110267','Logo','',2),(110275,'117175','furniture','gift_certificate','BlockBox','',1),(110276,'117176','furniture','block-110275','account\\ApplyCertificate','',2),(110277,'117177','furniture','block-110275','Html_box','',1),(110278,'117178','furniture','gigt_card_3','BlockBox','',1),(110279,'117179','furniture','block-110278','BlockBox','',9),(110280,'117180','furniture','block-110279','Text','',1),(110281,'117181','furniture','block-110279-2','gift\\CodeView','',1),(110282,'117182','furniture','block-110278','Text','',7),(110283,'117184','furniture','block-110278','BlockBox','',10),(110284,'117185','furniture','block-110283','Text','',1),(110285,'117186','furniture','block-110283','invoice\\StoreEmail','',3),(110286,'117187','furniture','block-110283','invoice\\StorePhone','',2),(110287,'117188','furniture','block-110278','gift\\MessageView','',6),(110288,'117189','furniture','block-110278','Text','',3),(110289,'117190','furniture','block-110278','Text','',5),(110290,'117191','furniture','block-110278','gift\\AmountView','',4),(110291,'117192','furniture','block-110278','Text','',8),(110292,'1638804328.7281','furniture','block-110278','Logo','',1),(110293,'117193','furniture','gigt_card_3_pdf','BlockBox','',1),(110294,'117194','furniture','block-110293','BlockBox','',12),(110295,'117195','furniture','block-110294','invoice\\StoreEmail','',4),(110296,'117196','furniture','block-110294','invoice\\StorePhone','',3),(110297,'117197','furniture','block-110294','Html_box','',1),(110298,'117198','furniture','block-110293','BlockBox','',11),(110299,'117199','furniture','block-110298','Html_box','',1),(110300,'117200','furniture','block-110298-2','gift\\CodeViewPdf','',1),(110301,'117201','furniture','block-110293','BlockBox','',1),(110302,'117202','furniture','block-110301','Text','',4),(110303,'117203','furniture','block-110301','Html_box','',1),(110304,'117204','furniture','block-110301','Html_box','',2),(110305,'117205','furniture','block-110301','gift\\AmountViewPdf','',3),(110306,'117206','furniture','block-110301','gift\\MessageViewPdf','',5),(110307,'117207','furniture','block-110301','Html_box','',7),(110308,'117208','furniture','block-110301','Html_box','',6),(110326,'120887','furniture','header_menu','Currencies','',2),(110327,'120888','furniture','header_menu','Languages','',1),(110328,'117224','furniture','info','BlockBox','info-content',1),(110329,'117225','furniture','block-110328','info\\DescriptionShort','',3),(110330,'117226','furniture','block-110328','info\\Content','',6),(110331,'117227','furniture','block-110328','info\\Title','',1),(110332,'117228','furniture','block-110328','info\\Image','',4),(110333,'1638467467.3028','furniture','block-110328','info\\DescriptionShort','',5),(110334,'117229','furniture','invoice','invoice\\Container','',1),(110335,'117230','furniture','block-110334','BlockBox','',4),(110336,'117231','furniture','block-110335','BlockBox','',8),(110337,'117232','furniture','block-110336','BlockBox','',1),(110338,'117233','furniture','block-110337','invoice\\ShippingMethod','',2),(110339,'117234','furniture','block-110337','Text','',1),(110340,'117235','furniture','block-110336-2','BlockBox','',1),(110341,'117236','furniture','block-110340','Text','',1),(110342,'117237','furniture','block-110340','invoice\\ShippingMethod','',2),(110343,'117238','furniture','block-110335','BlockBox','',7),(110344,'117239','furniture','block-110343','BlockBox','',2),(110345,'117240','furniture','block-110344','Text','',1),(110346,'117241','furniture','block-110344','invoice\\BillingAddress','',2),(110347,'1639659760.0392','furniture','block-110344','GiftWrapMessage\\ShowInfo','',3),(110348,'117242','furniture','block-110343-2','BlockBox','',1),(110349,'117243','furniture','block-110348','Text','',5),(110350,'117244','furniture','block-110348','invoice\\CustomerName','',2),(110351,'117245','furniture','block-110348','invoice\\CustomerPhone','',4),(110352,'117246','furniture','block-110348','Text','',1),(110353,'117247','furniture','block-110348','Text','',3),(110354,'117248','furniture','block-110348','invoice\\CustomerEmail','',6),(110355,'117249','furniture','block-110335-2','invoice\\PaymentMethod','',6),(110356,'117250','furniture','block-110335-2','Text','',5),(110357,'117251','furniture','block-110335-2','Text','',3),(110358,'117252','furniture','block-110335-2','invoice\\OrderId','',2),(110359,'117253','furniture','block-110335-2','invoice\\PaymentDate','',4),(110360,'117254','furniture','block-110335-2','invoice\\OrderBarcode','',7),(110361,'117255','furniture','block-110334','BlockBox','',8),(110362,'117256','furniture','block-110361','invoice\\StoreAddress','',8),(110363,'117257','furniture','block-110361','Text','',1),(110364,'117258','furniture','block-110361-2','Text','',2),(110365,'117260','furniture','block-110361-3','BlockBox','',3),(110366,'117261','furniture','block-110365','Text','',1),(110367,'117262','furniture','block-110365-2','invoice\\StoreEmail','',1),(110368,'117263','furniture','block-110361-3','BlockBox','',2),(110369,'117264','furniture','block-110368','Text','',1),(110370,'117265','furniture','block-110368-2','invoice\\StorePhone','',1),(110371,'117266','furniture','block-110361-3','Text','',1),(110372,'117267','furniture','block-110334','invoice\\Products','',5),(110373,'117268','furniture','block-110334','BlockBox','',7),(110374,'117269','furniture','block-110373','BlockBox','',1),(110375,'117270','furniture','block-110374','invoice\\ShippingAddress','',2),(110376,'117271','furniture','block-110374','Text','',1),(110377,'117272','furniture','block-110373-2','BlockBox','',1),(110378,'117273','furniture','block-110377','invoice\\Totals','',1),(110379,'117274','furniture','block-110334','BlockBox','',2),(110380,'117275','furniture','block-110379','Logo','',1),(110381,'117276','furniture','block-110379-2','BlockBox','',4),(110382,'117277','furniture','block-110381','Text','',1),(110383,'117278','furniture','block-110381-2','invoice\\StoreSite','',1),(110384,'117279','furniture','block-110379-2','BlockBox','',3),(110385,'117280','furniture','block-110384','Text','',1),(110386,'117281','furniture','block-110384-2','invoice\\StoreEmail','',1),(110387,'117282','furniture','block-110379-2','BlockBox','',1),(110388,'117283','furniture','block-110387','invoice\\StoreAddress','',2),(110389,'117284','furniture','block-110379-2','BlockBox','',2),(110390,'117285','furniture','block-110389','Text','',1),(110391,'117286','furniture','block-110389-2','invoice\\StorePhone','',1),(110392,'1640103567.8175','furniture','block-110334','invoice\\StructuredProducts','',6),(110393,'117287','furniture','login_account','BlockBox','',1),(110394,'117288','furniture','block-110393','Tabs','',2),(110395,'117289','furniture','block-110394-1','login\\Returning','',1),(110396,'117290','furniture','block-110394-2','BlockBox','',1),(110397,'117291','furniture','block-110396','Html_box','',1),(110398,'117292','furniture','block-110396-2','BlockBox','',1),(110399,'117293','furniture','block-110398','Html_box','',2),(110400,'117294','furniture','block-110398','login\\Register','',1),(110401,'117295','furniture','block-110393','BlockBox','',1),(110402,'117296','furniture','block-110401','Html_box','',5),(110403,'117297','furniture','block-110401','Html_box','',1),(110404,'117298','furniture','block-110401','login\\Socials','',4),(110405,'117299','furniture','login_checkout','BlockBox','',1),(110406,'117300','furniture','block-110405','BlockBox','',1),(110407,'117301','furniture','block-110406','checkout\\CreateBtn','',4),(110408,'117302','furniture','block-110406','checkout\\GuestBtn','',2),(110409,'117303','furniture','block-110406','Html_box','',3),(110410,'117304','furniture','block-110406','BlockBox','',5),(110411,'117305','furniture','block-110410','Html_box','',1),(110412,'117306','furniture','block-110410','login\\Socials','',2),(110413,'117307','furniture','block-110406','Html_box','',1),(110414,'117308','furniture','block-110406-2','login\\Returning','',2),(110415,'117309','furniture','block-110406-2','Html_box','',1),(110416,'117310','furniture','login_checkout2','BlockBox','',1),(110417,'117311','furniture','block-110416','Tabs','',4),(110418,'117312','furniture','block-110417-1','BlockBox','',1),(110419,'117313','furniture','block-110418','Html_box','',1),(110420,'117314','furniture','block-110418-2','BlockBox','',1),(110421,'117315','furniture','block-110420','login\\Guest','',1),(110422,'117316','furniture','block-110420','Html_box','',2),(110423,'117317','furniture','block-110417-2','login\\Returning','',1),(110424,'117318','furniture','block-110417-3','BlockBox','',1),(110425,'117319','furniture','block-110424','Html_box','',1),(110426,'117320','furniture','block-110424-2','BlockBox','',1),(110427,'117321','furniture','block-110426','Html_box','',2),(110428,'117322','furniture','block-110426','login\\Register','',1),(110429,'117323','furniture','block-110416','login\\Socials','',2),(110430,'117324','furniture','block-110416','Html_box','',3),(110431,'117325','furniture','block-110416','Html_box','',1),(110432,'117326','furniture','login_checkout2_q','BlockBox','',1),(110433,'117327','furniture','block-110432','Tabs','',4),(110434,'117328','furniture','block-110433-1','BlockBox','',1),(110435,'117329','furniture','block-110434','Html_box','',1),(110436,'117330','furniture','block-110434-2','quote\\FastOrder','',1),(110437,'117331','furniture','block-110433-2','login\\Returning','',1),(110438,'117332','furniture','block-110433-3','BlockBox','',1),(110439,'117333','furniture','block-110438','Html_box','',1),(110440,'117334','furniture','block-110438','Import','',2),(110441,'117335','furniture','block-110438-2','BlockBox','',1),(110442,'117336','furniture','block-110441','login\\Register','',1),(110443,'117337','furniture','block-110441','Html_box','',2),(110444,'117338','furniture','block-110432','Html_box','',3),(110445,'117339','furniture','block-110432','Html_box','',1),(110446,'117340','furniture','block-110432','login\\Socials','',2),(110447,'117341','furniture','login_checkout2_s','BlockBox','',1),(110448,'117342','furniture','block-110447','login\\Socials','',2),(110449,'117343','furniture','block-110447','Html_box','',3),(110450,'117344','furniture','block-110447','Tabs','',4),(110451,'117345','furniture','block-110450-1','BlockBox','',1),(110452,'117346','furniture','block-110451','Html_box','',1),(110453,'117347','furniture','block-110451-2','quote\\FastOrder','',1),(110454,'117348','furniture','block-110450-2','login\\Returning','',1),(110455,'117349','furniture','block-110450-3','BlockBox','',1),(110456,'117350','furniture','block-110455','Html_box','',1),(110457,'117351','furniture','block-110455-2','BlockBox','',1),(110458,'117352','furniture','block-110457','login\\Register','',1),(110459,'117353','furniture','block-110457','Html_box','',2),(110460,'117354','furniture','block-110447','Html_box','',1),(110461,'117355','furniture','login_checkout_q','BlockBox','',1),(110462,'117356','furniture','block-110461','BlockBox','',1),(110463,'117357','furniture','block-110462','BlockBox','',5),(110464,'117358','furniture','block-110463','Html_box','',1),(110465,'117359','furniture','block-110463','login\\Socials','',2),(110466,'117360','furniture','block-110462','checkout\\GuestBtn','',2),(110467,'117361','furniture','block-110462','checkout\\CreateBtn','',4),(110468,'117362','furniture','block-110462','Html_box','',3),(110469,'117363','furniture','block-110462','Html_box','',1),(110470,'117364','furniture','block-110462-2','Html_box','',1),(110471,'117365','furniture','block-110462-2','login\\Returning','',2),(110472,'117366','furniture','login_checkout_s','BlockBox','',1),(110473,'117367','furniture','block-110472','BlockBox','',1),(110474,'117368','furniture','block-110473','Html_box','',1),(110475,'117369','furniture','block-110473','checkout\\GuestBtn','',2),(110476,'117370','furniture','block-110473','checkout\\CreateBtn','',4),(110477,'117371','furniture','block-110473','Html_box','',3),(110478,'117372','furniture','block-110473','BlockBox','',5),(110479,'117373','furniture','block-110478','Html_box','',1),(110480,'117374','furniture','block-110478','login\\Socials','',2),(110481,'117375','furniture','block-110473-2','Html_box','',1),(110482,'117376','furniture','block-110473-2','login\\Returning','',2),(110483,'117377','furniture','logoff','BlockBox','',1),(110484,'117378','furniture','block-110483','Html_box','',1),(110485,'117379','furniture','logoff_forever','BlockBox','',1),(110486,'117380','furniture','block-110485','Html_box','',1),(110487,'1683019393.8433','furniture','main','BlockBox','',1),(110488,'1683018455.4659','furniture','block-110487','Banner','',1),(110489,'1703584951.8917','furniture','main','BlockBox','',5),(110490,'1705058746.79624','furniture','main','BlockBox','main-content',3),(110491,'1705058746.808883','furniture','block-110490','BlockBox','',1),(110492,'1705058746.898727','furniture','block-110491','Banner','',2),(110493,'1705058747.047682','furniture','block-110490','BlockBox','',2),(110494,'1705058747.07661','furniture','block-110493','Html_box','',1),(110495,'1705058747.089734','furniture','block-110493-2','Html_box','',1),(110496,'1705058747.092420','furniture','block-110493-3','Html_box','',1),(110497,'1705058747.094689','furniture','block-110490','BlockBox','',3),(110498,'1705058747.096170','furniture','block-110497','NewProducts','8',3),(110499,'1705058747.101394','furniture','block-110497','Html_box','',2),(110500,'1705058747.103997','furniture','block-110490','BlockBox','',4),(110501,'1705058747.131252','furniture','block-110500','Banner','',2),(110502,'1705058747.202374','furniture','block-110500','Html_box','',1),(110504,'117394','furniture','manufacturers','BlockBox','',1),(110505,'117395','furniture','block-110504','Html_box','',1),(110506,'117396','furniture','block-110504','Brands','',2),(110507,'117397','furniture','messages-index','BlockBox','',1),(110508,'117398','furniture','block-110507','BlockBox','',1),(110509,'117399','furniture','block-110508','BlockBox','',1),(110510,'117400','furniture','block-110509','Messages\\Sidebar','',1),(110511,'117401','furniture','block-110508-2','Messages\\Listing','',1),(110512,'117402','furniture','messages-new','BlockBox','',1),(110513,'117403','furniture','block-110512','BlockBox','',1),(110514,'117404','furniture','block-110513','Messages\\Sidebar','',1),(110515,'117405','furniture','block-110513-2','Messages\\NewMessage','',1),(110516,'117406','furniture','messages-view','BlockBox','',1),(110517,'117407','furniture','block-110516','BlockBox','',1),(110518,'117408','furniture','block-110517','Messages\\Sidebar','',1),(110519,'117409','furniture','block-110517-2','Messages\\Message','',1),(110520,'117410','furniture','my_password','BlockBox','',1),(110521,'117411','furniture','block-110520','BlockBox','',1),(110522,'117412','furniture','block-110521','WidgetsAria','',1),(110542,'117413','furniture','block-110521-2','account\\ChangePassword','',2),(110543,'117414','furniture','block-110521-2','Html_box','',1),(110544,'117415','furniture','need_login','BlockBox','',1),(110545,'117416','furniture','block-110544','Tabs','',2),(110546,'117417','furniture','block-110545-1','login\\Returning','',1),(110547,'117418','furniture','block-110545-2','BlockBox','',1),(110548,'117419','furniture','block-110547','Html_box','',2),(110549,'117420','furniture','block-110547-2','BlockBox','',1),(110550,'117421','furniture','block-110549','login\\Register','',1),(110551,'117422','furniture','block-110549','Html_box','',2),(110552,'117423','furniture','block-110544','BlockBox','',1),(110553,'117424','furniture','new-topic','BlockBox','',1),(110554,'117425','furniture','block-110553','Breadcrumb','',2),(110555,'117426','furniture','block-110553','Communication\\NewTopic','',3),(110556,'117427','furniture','block-110553','Html_box','',1),(110557,'117428','furniture','nnnn','BlockBox','',1),(110558,'117429','furniture','block-110557','catalog\\Title','',1),(110559,'117430','furniture','block-110557','BlockBox','',2),(110560,'117431','furniture','block-110559','Filters','',1),(110561,'117432','furniture','block-110559-2','Listing','',5),(110562,'117433','furniture','block-110559-2','catalog\\Image','',1),(110563,'117434','furniture','block-110559-2','BlockBox','',6),(110564,'117435','furniture','block-110563','catalog\\CountsItems','',1),(110565,'117436','furniture','block-110563-2','catalog\\Paging','',1),(110566,'117437','furniture','block-110559-2','catalog\\ImageMapCategory','',3),(110567,'117438','furniture','block-110559-2','Categories','',2),(110568,'117439','furniture','block-110559-2','BlockBox','',4),(110569,'117440','furniture','block-110568','catalog\\ListingLook','',1),(110570,'117441','furniture','block-110568','catalog\\ItemsOnPage','',4),(110571,'117442','furniture','block-110568','catalog\\CompareButton','',2),(110572,'117443','furniture','block-110568','catalog\\Sorting','',3),(110573,'117444','furniture','no-logged','BlockBox','',1),(110574,'117445','furniture','block-110573','Communication\\NewTopic','',2),(110575,'117446','furniture','block-110573','Html_box','',1),(110576,'117447','furniture','no_filters','BlockBox','catalog-content',1),(110577,'117448','furniture','block-110576','BlockBox','',4),(110578,'117449','furniture','block-110577','catalog\\CountsItems','',1),(110579,'117450','furniture','block-110577-2','catalog\\Paging','',1),(110580,'117451','furniture','block-110576','Listing','',3),(110581,'117452','furniture','block-110576','catalog\\Title','',1),(110582,'117453','furniture','block-110576','catalog\\B2bAddButton','',5),(110583,'117454','furniture','block-110576','BlockBox','catalog-features',2),(110584,'117455','furniture','block-110583','BlockBox','',2),(110585,'117456','furniture','block-110584','HeaderStock','',5),(110586,'117457','furniture','block-110584','catalog\\ListingLook','',1),(110587,'117458','furniture','block-110584','catalog\\CompareButton','',2),(110588,'117459','furniture','block-110584','catalog\\ItemsOnPage','',4),(110589,'117460','furniture','block-110584','catalog\\Sorting','',3),(110590,'117461','furniture','block-110583','catalog\\Image','',1),(110674,'117507','furniture','order_pay','BlockBox','',1),(110675,'117508','furniture','block-110674','BlockBox','',1),(110676,'117509','furniture','block-110675','WidgetsAria','',1),(110696,'117510','furniture','block-110675-2','account\\OrderProducts','',4),(110697,'117511','furniture','block-110675-2','BlockBox','',2),(110698,'117512','furniture','block-110697','BlockBox','',1),(110699,'117513','furniture','block-110698','Html_box','',1),(110700,'117514','furniture','block-110698','account\\OrderData','',2),(110701,'117515','furniture','block-110697','BlockBox','',4),(110702,'117516','furniture','block-110701','account\\OrderData','',2),(110703,'117517','furniture','block-110701','Html_box','',1),(110704,'117518','furniture','block-110697-2','BlockBox','',1),(110705,'117519','furniture','block-110704','Html_box','',1),(110706,'117520','furniture','block-110704','account\\OrderData','',2),(110707,'117521','furniture','block-110697-2','BlockBox','',2),(110708,'117522','furniture','block-110707','account\\OrderData','',2),(110709,'117523','furniture','block-110707','Html_box','',1),(110710,'117524','furniture','block-110697-3','BlockBox','',2),(110711,'117525','furniture','block-110710','Html_box','',1),(110712,'117526','furniture','block-110710','account\\OrderData','',2),(110713,'117527','furniture','block-110697-3','BlockBox','',1),(110714,'117528','furniture','block-110713','account\\OrderData','',2),(110715,'117529','furniture','block-110713','Html_box','',1),(110716,'117530','furniture','block-110675-2','UpdateAndPay\\PayForm','',6),(110717,'117531','furniture','block-110675-2','Html_box','',3),(110718,'117532','furniture','block-110675-2','account\\OrderHeading','',1),(110719,'117533','furniture','block-110675-2','account\\OrderSubTotals','',5),(110720,'117534','furniture','packingslip','invoice\\Container','',2),(110721,'117535','furniture','block-110720','BlockBox','',2),(110722,'117536','furniture','block-110721','Logo','',1),(110723,'117537','furniture','block-110721-2','BlockBox','',3),(110724,'117538','furniture','block-110723','Text','',2),(110725,'117539','furniture','block-110723-2','invoice\\StoreEmail','',1),(110726,'117540','furniture','block-110721-2','BlockBox','',2),(110727,'117541','furniture','block-110726','Text','',2),(110728,'117542','furniture','block-110726-2','invoice\\StorePhone','',1),(110729,'117543','furniture','block-110721-2','BlockBox','',1),(110730,'117544','furniture','block-110729','invoice\\StoreAddress','',1),(110731,'117545','furniture','block-110721-2','BlockBox','',4),(110732,'117546','furniture','block-110731','Text','',2),(110733,'117547','furniture','block-110731-2','invoice\\StoreSite','',1),(110734,'117548','furniture','block-110720','packingslip\\Products','',5),(110735,'117549','furniture','block-110720','BlockBox','',6),(110736,'117550','furniture','block-110735','invoice\\StoreAddress','',2),(110737,'117551','furniture','block-110735','Text','',1),(110738,'117552','furniture','block-110720','BlockBox','',3),(110739,'117553','furniture','block-110738','BlockBox','',2),(110740,'117554','furniture','block-110739','BlockBox','',1),(110741,'117555','furniture','block-110740','invoice\\ShippingAddress','',2),(110742,'117556','furniture','block-110740','Text','',1),(110743,'117557','furniture','block-110739-2','BlockBox','',1),(110744,'117558','furniture','block-110743','Text','',1),(110745,'117559','furniture','block-110743','invoice\\CustomerName','',2),(110746,'117560','furniture','block-110743','invoice\\CustomerEmail','',6),(110747,'117561','furniture','block-110743','Text','',3),(110748,'117562','furniture','block-110743','invoice\\CustomerPhone','',4),(110749,'117563','furniture','block-110743','Text','',5),(110750,'117564','furniture','block-110738','BlockBox','',3),(110751,'117565','furniture','block-110750','BlockBox','',1),(110752,'117566','furniture','block-110751','invoice\\ShippingMethod','',2),(110753,'117567','furniture','block-110751','Text','',1),(110754,'117568','furniture','block-110750-2','BlockBox','',1),(110755,'117569','furniture','block-110754','invoice\\ShippingMethod','',2),(110756,'117570','furniture','block-110754','Text','',1),(110757,'117571','furniture','block-110738-2','invoice\\AddressQrcode','',1),(110758,'1639660991.8692','furniture','block-110720','Neighbour\\PackingSlipInfo','',1),(110759,'1639661081.5616','furniture','block-110720','Neighbour\\PackingSlipInfo','',4),(110760,'117572','furniture','password_forgotten','BlockBox','',1),(110761,'117573','furniture','block-110760','BlockBox','',2),(110762,'1638807246.6206','furniture','block-110761','Html_box','',1),(110763,'117574','furniture','block-110761-2','Html_box','',1),(110764,'117575','furniture','block-110761-2','login\\PasswordForgotten','',2),(110765,'117576','furniture','block-110760','Html_box','',1),(110766,'117577','furniture','pdf','invoice\\Container','',1),(110767,'117578','furniture','block-110766','BlockBox','',1),(110768,'117579','furniture','block-110767','BlockBox','',1),(110769,'117580','furniture','block-110768','BlockBox','',1),(110770,'117581','furniture','block-110769','pdf\\ProductElement','',1),(110771,'117582','furniture','block-110768','BlockBox','',2),(110772,'117583','furniture','block-110771','pdf\\ProductElement','',1),(110773,'117584','furniture','block-110771-2','pdf\\ProductElement','',2),(110774,'117585','furniture','block-110771-2','pdf\\ProductElement','',1),(110775,'117586','furniture','block-110767-2','BlockBox','',1),(110776,'117587','furniture','block-110775','BlockBox','',2),(110777,'117588','furniture','block-110776','pdf\\ProductElement','',1),(110778,'117589','furniture','block-110776-2','pdf\\ProductElement','',2),(110779,'117590','furniture','block-110776-2','pdf\\ProductElement','',1),(110780,'117591','furniture','block-110775','BlockBox','',1),(110781,'117592','furniture','block-110780','pdf\\ProductElement','',1),(110782,'117593','furniture','pdf_category','pdf\\CategoryName','',2),(110783,'117594','furniture','pdf_category','pdf\\CategoryImage','',1),(110784,'117595','furniture','pdf_cover','invoice\\Container','',1),(110785,'117596','furniture','block-110784','Logo','',1),(110786,'117597','furniture','block-110784','Text','',3),(110787,'117598','furniture','pdf_footer','BlockBox','',1),(110788,'117599','furniture','block-110787-2','pdf\\PageNumber','',1),(110789,'117600','furniture','pdf_header','pdf\\CategoryName','',1),(110790,'117601','furniture','personal_catalog','BlockBox','',1),(110791,'117602','furniture','block-110790','BlockBox','',1),(110792,'117603','furniture','block-110791','WidgetsAria','',1),(110812,'117604','furniture','block-110791-2','Html_box','',1),(110813,'117606','furniture','block-110791-2','account\\PersonalCatalog','',2),(110814,'117607','furniture','points_earnt_history','BlockBox','',1),(110815,'117608','furniture','block-110814','Html_box','',1),(110816,'117609','furniture','block-110814','account\\PointsEarntHistory','',2),(110817,'117610','furniture','posts','BlockBox','',1),(110818,'117611','furniture','block-110817','Breadcrumb','',2),(110819,'117612','furniture','block-110817','Html_box','',1),(110820,'117613','furniture','block-110817','Communication\\Post','',3),(110821,'1683109599.245213','furniture','product','BlockBox','',1),(110822,'1683109599.255978','furniture','block-110821','BlockBox','',4),(110823,'1683109599.25889','furniture','block-110822','BlockBox','product-image',1),(110824,'1683109599.25915','furniture','block-110823','product\\Images','',2),(110825,'1683109599.2678','furniture','block-110823','Promotions\\widgets\\PromotionIcons','',1),(110826,'1683109599.261153','furniture','block-110823','product\\PropertiesIcons','',3),(110827,'1683109599.261571','furniture','block-110823','ProductDesigner\\Designer','',6),(110828,'1683109599.261910','furniture','block-110823','ProductDesigner\\Button','',5),(110829,'1683109599.262388','furniture','block-110823','ProductDesigner\\Picture','',4),(110830,'1683109599.263173','furniture','block-110822-2','BlockBox','product-side',3),(110831,'1683109599.264430','furniture','block-110830','BlockBox','',1),(110832,'1683109599.26556','furniture','block-110831','product\\DescriptionShort','',2),(110833,'1683109599.26782','furniture','block-110831','product\\Model','',1),(110834,'1683109599.267742','furniture','block-110831','Html_box','',3),(110835,'1683109599.27259','furniture','block-110831','product\\Groups','',6),(110836,'1683109599.272734','furniture','block-110830','BlockBox','',3),(110837,'1683109599.273896','furniture','block-110836','Promotions\\widgets\\PromotionIconsDesc','',2),(110838,'1683109599.292170','furniture','block-110830-2','BlockBox','',1),(110839,'1683109599.294458','furniture','block-110838','BlockBox','',1),(110840,'1683109599.297231','furniture','block-110839','product\\SaleEnds','',2),(110841,'1683109599.30758','furniture','block-110839','BlockBox','',3),(110842,'1683109599.30990','furniture','block-110841','product\\QuantityDiscounts','',5),(110843,'1683109599.310437','furniture','block-110841','product\\ButtonsQuote','',8),(110844,'1683109599.313121','furniture','block-110841','product\\Price','',3),(110845,'1683109599.315738','furniture','block-110841','product\\Quantity','',4),(110846,'1683109599.322597','furniture','block-110841','product\\Buttons','',6),(110847,'1683109599.325422','furniture','block-110841','product\\ButtonsSample','',9),(110848,'1683109599.326754','furniture','block-110841','product\\PersonalCatalogButton','',7),(110849,'1683109599.329949','furniture','block-110841','product\\Stock','',2),(110850,'1683109599.331551','furniture','block-110841','product\\Attributes','',1),(110851,'1683109599.334184','furniture','block-110838','BlockBox','',3),(110852,'1683109599.335484','furniture','block-110851','product\\BonusPoints','',1),(110853,'1683109599.33824','furniture','block-110821','product\\Name','',2),(110854,'1683109599.338931','furniture','block-110821','Breadcrumb','',1),(110855,'1683109599.343489','furniture','block-110821','BlockBox','',3),(110856,'1683109599.345520','furniture','block-110855','product\\Rating','',2),(110857,'1683109599.348715','furniture','block-110855','Html_box','',2),(110858,'1683109648.23241','furniture','product','BlockBox','',3),(110859,'1683109648.239129','furniture','block-110858','product\\InBundles','',3),(110860,'1683109648.244334','furniture','block-110858','product\\Bundle','',2),(110861,'1683109666.978945','furniture','product','BlockBox','product-content',4),(110862,'1683109666.985380','furniture','block-110861','BlockBox','',1),(110863,'1683109666.986680','furniture','block-110862','Tabs','',3),(110864,'1683109666.994221','furniture','block-110863-1','product\\Description','',2),(110865,'1683109666.99570','furniture','block-110863-1','product\\Properties','',1),(110866,'1683109666.999888','furniture','block-110863-2','InfoPage','',1),(110867,'1683109667.001793','furniture','block-110861','Tabs','',3),(110868,'1683109667.003150','furniture','block-110867-1','product\\AlsoPurchased','10',1),(110869,'1683109667.007130','furniture','block-110867-2','ViewedProducts','4',1),(110870,'1683109667.010748','furniture','block-110861','BlockBox','',2),(110871,'1683109667.01353','furniture','block-110870','Html_box','',1),(110872,'1683109667.014986','furniture','block-110870-2','Html_box','',1),(110873,'1683109667.016871','furniture','block-110870-3','Html_box','',1),(110874,'1683109667.01857','furniture','block-110861','BlockBox','',4),(110875,'1683109667.019642','furniture','block-110874','product\\Reviews','',1),(110876,'1707919218.1062','furniture','block-110861','UpSell\\widgets\\CrossSellProducts','',5),(110877,'117655','furniture','product-bottom','product\\Properties','',1),(110878,'117656','furniture','product-tabs','product\\Reviews','',2),(110879,'117657','furniture','product-tabs','product\\Description','',1),(110880,'117658','furniture','product-top-left','product\\Images','',1),(110881,'117659','furniture','product-top-right','product\\Price','',2),(110882,'117660','furniture','product-top-right','product\\Quantity','',5),(110883,'117661','furniture','product-top-right','product\\Quantity','',6),(110884,'117662','furniture','product-top-right','product\\Attributes','',3),(110885,'117663','furniture','product-top-right','product\\Name','',1),(110886,'117664','furniture','product-top-right','product\\Buttons','',6),(110887,'117665','furniture','productListing','BlockBox','listing-item',1),(110888,'120921','furniture','block-110887','BlockBox','',1),(110889,'120896','furniture','block-110888','BlockBox','',2),(110890,'117677','furniture','block-110889','productListing\\compare','',3),(110891,'120882','furniture','block-110889','productListing\\personalCatalog','',2),(110892,'120895','furniture','block-110889','productListing\\viewButton','',1),(110893,'120919','furniture','block-110888','BlockBox','',1),(110894,'117667','furniture','block-110893','productListing\\bonusPoints','',3),(110895,'117668','furniture','block-110893','productListing\\description','',7),(110896,'117670','furniture','block-110893','productListing\\rating','',8),(110897,'117671','furniture','block-110893','productListing\\image','',1),(110898,'117673','furniture','block-110893','productListing\\price','',5),(110899,'117675','furniture','block-110893','productListing\\name','',6),(110900,'117676','furniture','block-110893','productListing\\stock','',4),(110901,'120863','furniture','block-110893','productListing\\ratingCounts','',9),(110902,'1639645717.6681','furniture','block-110893','productListing\\productGroup','',2),(110903,'117678','furniture','products','BlockBox','catalog-content',1),(110904,'117679','furniture','block-110903','BlockBox','catalog-side',4),(110905,'117680','furniture','block-110904','Filters','',3),(110906,'117681','furniture','block-110904','HeaderStock','',4),(110907,'120916','furniture','block-110904','BlockBox','',1),(110908,'120918','furniture','block-110907','BlockBox','',3),(110909,'120884','furniture','block-110908','Menu','LeftCategories',2),(110910,'120917','furniture','block-110908','Html_box','',1),(110911,'117682','furniture','block-110904-2','catalog\\B2bAddButton','',5),(110912,'117683','furniture','block-110904-2','BlockBox','catalog-features',2),(110913,'117684','furniture','block-110912','catalog\\Sorting','',3),(110914,'117685','furniture','block-110912','catalog\\ListingLook','',1),(110915,'117686','furniture','block-110912','catalog\\ItemsOnPage','',4),(110916,'117687','furniture','block-110912','catalog\\CompareButton','',2),(110917,'117688','furniture','block-110904-2','BlockBox','',6),(110918,'117689','furniture','block-110917','catalog\\CountsItems','',1),(110919,'117690','furniture','block-110917-2','catalog\\Paging','',1),(110920,'117691','furniture','block-110904-2','Listing','',4),(110921,'120912','furniture','block-110904-2','BlockBox','',3),(110922,'120913','furniture','block-110921','catalog\\CountsItems','',1),(110923,'120914','furniture','block-110921-2','catalog\\Paging','',1),(110924,'1639760443.0645','furniture','block-110904-2','catalog\\AdditionalImages','',1),(110925,'117692','furniture','block-110903','catalog\\Title','',2),(110926,'117693','furniture','block-110903','BlockBox','',3),(110927,'117694','furniture','block-110926','catalog\\Image','',2),(110928,'1639415554.3073','furniture','block-110926','product\\WeddingRegistryButton','',3),(110929,'121018','furniture','products','Compare','',2),(110930,'117695','furniture','products-list','packingslip\\AllProductsList','',2),(110931,'117696','furniture','promotions','BlockBox','info-content',1),(110932,'117697','furniture','block-110931','promotions\\PromoList','',2),(110933,'117698','furniture','block-110931','Html_box','',1),(110934,'117699','furniture','purchase','invoice\\Container','',1),(110935,'117700','furniture','block-110934','invoice\\Products','',3),(110936,'117701','furniture','block-110934','BlockBox','',5),(110937,'117702','furniture','block-110936','Text','',1),(110938,'117703','furniture','block-110936','invoice\\StoreAddress','',8),(110939,'117704','furniture','block-110936-2','Text','',2),(110940,'117705','furniture','block-110936-2','Logo','',1),(110941,'117706','furniture','block-110936-3','BlockBox','',3),(110942,'117707','furniture','block-110941','Text','',1),(110943,'117708','furniture','block-110941-2','invoice\\StoreEmail','',1),(110944,'117709','furniture','block-110936-3','Text','',1),(110945,'117710','furniture','block-110936-3','BlockBox','',2),(110946,'117711','furniture','block-110945','Text','',1),(110947,'117712','furniture','block-110945-2','invoice\\StorePhone','',1),(110948,'117713','furniture','block-110934','BlockBox','',1),(110949,'117714','furniture','block-110948','Logo','',1),(110950,'117715','furniture','block-110948-2','BlockBox','',2),(110951,'117716','furniture','block-110950','Text','',1),(110952,'117717','furniture','block-110950-2','invoice\\StorePhone','',1),(110953,'117718','furniture','block-110948-2','BlockBox','',4),(110954,'117719','furniture','block-110953','Text','',1),(110955,'117720','furniture','block-110953-2','invoice\\StoreSite','',1),(110956,'117721','furniture','block-110948-2','BlockBox','',1),(110957,'117722','furniture','block-110956','invoice\\StoreAddress','',1),(110958,'117723','furniture','block-110948-2','BlockBox','',3),(110959,'117724','furniture','block-110958','Text','',1),(110960,'117725','furniture','block-110958-2','invoice\\StoreEmail','',1),(110961,'117726','furniture','block-110934','BlockBox','',2),(110962,'117727','furniture','block-110961','BlockBox','',7),(110963,'117728','furniture','block-110962','BlockBox','',1),(110964,'117729','furniture','block-110963','invoice\\BillingAddress','',2),(110965,'117730','furniture','block-110963','Text','',1),(110966,'117731','furniture','block-110962-2','BlockBox','',1),(110967,'117732','furniture','block-110966','invoice\\CustomerEmail','',6),(110968,'117733','furniture','block-110966','Text','',5),(110969,'117734','furniture','block-110966','invoice\\CustomerPhone','',4),(110970,'117735','furniture','block-110966','invoice\\CustomerName','',2),(110971,'117736','furniture','block-110966','Text','',3),(110972,'117737','furniture','block-110966','Text','',1),(110973,'117738','furniture','block-110961-2','invoice\\OrderId','',1),(110974,'117739','furniture','block-110961-2','Text','',2),(110975,'117740','furniture','block-110961-2','invoice\\PaymentDate','',3),(110976,'117741','furniture','block-110934','BlockBox','',4),(110977,'117742','furniture','block-110976','BlockBox','',1),(110978,'117743','furniture','block-110977','invoice\\ShippingAddress','',2),(110979,'117744','furniture','block-110977','Text','',1),(110983,'117745','furniture','quotations','BlockBox','',1),(110984,'117746','furniture','block-110983','BlockBox','',1),(110985,'117747','furniture','block-110984','WidgetsAria','',1),(111005,'117748','furniture','block-110984-2','Html_box','',1),(111006,'117749','furniture','block-110984-2','Quotations\\QuotationsHistory','',2),(111007,'117750','furniture','quotation_info','BlockBox','',1),(111008,'117751','furniture','block-111007','BlockBox','',1),(111009,'117752','furniture','block-111008','WidgetsAria','',1),(111029,'117753','furniture','block-111008-2','BlockBox','',5),(111030,'117754','furniture','block-111029','BlockBox','',1),(111031,'117755','furniture','block-111030','Quotations\\QuotationData','',2),(111032,'117756','furniture','block-111030','Html_box','',1),(111033,'117757','furniture','block-111029','BlockBox','',4),(111034,'117758','furniture','block-111033','Html_box','',1),(111035,'117759','furniture','block-111033','Quotations\\QuotationData','',2),(111036,'117760','furniture','block-111029-2','BlockBox','',2),(111037,'117761','furniture','block-111036','Html_box','',1),(111038,'117762','furniture','block-111036','Quotations\\QuotationData','',2),(111039,'117763','furniture','block-111029-2','BlockBox','',1),(111040,'117764','furniture','block-111039','Html_box','',1),(111041,'117765','furniture','block-111039','Quotations\\QuotationData','',2),(111042,'117766','furniture','block-111029-3','BlockBox','',1),(111043,'117767','furniture','block-111042','Quotations\\QuotationData','',2),(111044,'117768','furniture','block-111042','Html_box','',1),(111045,'117769','furniture','block-111029-3','BlockBox','',2),(111046,'117770','furniture','block-111045','Quotations\\QuotationData','',2),(111047,'117771','furniture','block-111045','Html_box','',1),(111048,'117772','furniture','block-111008-2','Html_box','',6),(111049,'117773','furniture','block-111008-2','Quotations\\QuotationHistory','',10),(111050,'117774','furniture','block-111008-2','Html_box','',9),(111051,'117775','furniture','block-111008-2','Quotations\\QuotationProducts','',7),(111052,'117776','furniture','block-111008-2','Quotations\\QuotationSubTotal','',8),(111053,'117777','furniture','block-111008-2','BlockBox','',12),(111054,'117778','furniture','block-111053','account\\AccountLink','',1),(111055,'117779','furniture','block-111008-2','Html_box','',4),(111056,'117780','furniture','quote','BlockBox','',1),(111057,'117781','furniture','block-111056','cart\\CartTabs','',1),(111058,'117782','furniture','block-111057','BlockBox','',1),(111059,'117783','furniture','block-111058','quote\\Products','',1),(111060,'117784','furniture','block-111058-2','BlockBox','',1),(111061,'117785','furniture','block-111060','BlockBox','',1),(111062,'117786','furniture','block-111061','quote\\CheckoutBtn','',2),(111063,'117787','furniture','block-111057','Quotations\\QuotationSubTotal','',2),(111088,'117793','furniture','reviews','BlockBox','info-content',1),(111089,'117794','furniture','block-111088','reviews\\Heading','',1),(111090,'117795','furniture','block-111088','reviews\\Content','',2),(111091,'117796','furniture','rma_document','invoice\\Container','',1),(111092,'117797','furniture','block-111091','BlockBox','',1),(111093,'117798','furniture','block-111092','BlockBox','',1),(111094,'117799','furniture','block-111093','BlockBox','',2),(111095,'117800','furniture','block-111094','Html_box','',1),(111096,'117801','furniture','block-111094-2','Html_box','',1),(111097,'117802','furniture','block-111093','BlockBox','',5),(111098,'117803','furniture','block-111097','Html_box','',1),(111099,'117804','furniture','block-111097-2','Html_box','',1),(111100,'117805','furniture','block-111093','BlockBox','',4),(111101,'117806','furniture','block-111100','Html_box','',1),(111102,'117807','furniture','block-111100-2','Html_box','',1),(111103,'117808','furniture','block-111093','BlockBox','',3),(111104,'117809','furniture','block-111103','Html_box','',1),(111105,'117810','furniture','block-111103-2','Html_box','',1),(111106,'117811','furniture','block-111093','BlockBox','',1),(111107,'117812','furniture','block-111106','Html_box','',1),(111108,'117813','furniture','block-111106','Html_box','',2),(111109,'117814','furniture','block-111092-2','BlockBox','',1),(111110,'117815','furniture','block-111109','Html_box','',2),(111111,'117816','furniture','block-111109','Logo','',1),(111112,'117817','furniture','block-111092-2','BlockBox','',2),(111113,'117818','furniture','block-111112','BlockBox','',5),(111114,'117819','furniture','block-111113','BlockBox','',1),(111115,'117820','furniture','block-111114','Html_box','',1),(111116,'117821','furniture','block-111114-2','Rma\\DocumentData','',1),(111117,'117822','furniture','block-111113-2','BlockBox','',1),(111118,'117823','furniture','block-111117','Html_box','',1),(111119,'117824','furniture','block-111117-2','Rma\\DocumentData','',1),(111120,'117825','furniture','block-111112','BlockBox','',4),(111121,'117826','furniture','block-111120','BlockBox','',1),(111122,'117827','furniture','block-111121','Html_box','',1),(111123,'117828','furniture','block-111121-2','Rma\\DocumentData','',1),(111124,'117829','furniture','block-111120-2','BlockBox','',1),(111125,'117830','furniture','block-111124','Html_box','',1),(111126,'117831','furniture','block-111124-2','Rma\\DocumentData','',1),(111127,'117832','furniture','block-111112','BlockBox','',3),(111128,'117833','furniture','block-111127','BlockBox','',1),(111129,'117834','furniture','block-111128','Html_box','',1),(111130,'117835','furniture','block-111128-2','Rma\\DocumentData','',1),(111131,'117836','furniture','block-111127-2','BlockBox','',1),(111132,'117837','furniture','block-111131','Html_box','',1),(111133,'117838','furniture','block-111131-2','Rma\\DocumentData','',1),(111134,'117839','furniture','block-111112','BlockBox','',2),(111135,'117840','furniture','block-111134','Html_box','',1),(111136,'117841','furniture','block-111134-2','Rma\\DocumentData','',1),(111137,'117842','furniture','block-111112','BlockBox','',1),(111138,'117843','furniture','block-111137','BlockBox','',1),(111139,'117844','furniture','block-111138','Html_box','',1),(111140,'117845','furniture','block-111138-2','Rma\\DocumentData','',1),(111141,'117846','furniture','block-111137-2','BlockBox','',1),(111142,'117847','furniture','block-111141','Html_box','',1),(111143,'117848','furniture','block-111141-2','Rma\\DocumentData','',1),(111144,'117849','furniture','block-111092-2','BlockBox','',3),(111145,'117850','furniture','block-111144','BlockBox','',1),(111146,'117851','furniture','block-111145','Html_box','',1),(111147,'117852','furniture','block-111145-2','Rma\\DocumentData','',1),(111148,'117853','furniture','block-111144-2','BlockBox','',1),(111149,'117854','furniture','block-111148','Html_box','',1),(111150,'117855','furniture','block-111148-2','Rma\\DocumentData','',1),(111151,'117856','furniture','block-111091','BlockBox','',2),(111152,'117857','furniture','block-111151','Html_box','',1),(111153,'117858','furniture','block-111151','Rma\\Products','',2),(111154,'117859','furniture','block-111091','BlockBox','',3),(111155,'117860','furniture','block-111154','BlockBox','',1),(111156,'117861','furniture','block-111155','BlockBox','',1),(111157,'117862','furniture','block-111156','BlockBox','',5),(111158,'117863','furniture','block-111157','Html_box','',1),(111159,'117864','furniture','block-111157-2','invoice\\StoreAddress','',2),(111160,'117865','furniture','block-111157-2','Html_box','',1),(111161,'117866','furniture','block-111156','BlockBox','',4),(111162,'117867','furniture','block-111161','Html_box','',1),(111163,'117868','furniture','block-111161-2','Html_box','',1),(111164,'117869','furniture','block-111156','BlockBox','',2),(111165,'117870','furniture','block-111164','Html_box','',1),(111166,'117871','furniture','block-111164-2','Html_box','',1),(111167,'117872','furniture','block-111156','BlockBox','',1),(111168,'117873','furniture','block-111167','Html_box','',1),(111169,'117874','furniture','block-111156','BlockBox','',3),(111170,'117875','furniture','block-111169','Html_box','',1),(111171,'117876','furniture','block-111169-2','Html_box','',1),(111172,'117877','furniture','block-111156','BlockBox','',6),(111173,'117878','furniture','block-111172','Html_box','',1),(111174,'117879','furniture','block-111155-2','BlockBox','',1),(111175,'117880','furniture','block-111174','BlockBox','',1),(111176,'117881','furniture','block-111175','BlockBox','',1),(111177,'117882','furniture','block-111176','Rma\\DocumentData','',2),(111178,'117883','furniture','block-111176-3','BlockBox','',1),(111179,'117884','furniture','block-111178','Html_box','',1),(111180,'117885','furniture','block-111178-2','Rma\\DocumentData','',1),(111181,'117886','furniture','block-111175','BlockBox','',2),(111182,'117887','furniture','block-111181-2','invoice\\StoreAddress','',1),(111183,'117888','furniture','block-111155-2','BlockBox','',2),(111184,'117889','furniture','block-111183','Html_box','',1),(111185,'117890','furniture','block-111183','Html_box','',2),(111186,'117891','furniture','block-111183','Html_box','',3),(111187,'117892','furniture','block-111183','Html_box','',4),(111188,'117893','furniture','block-111183','Html_box','',5),(111189,'117894','furniture','block-111155-2','BlockBox','',4),(111190,'117895','furniture','block-111189','Html_box','',1),(111191,'117896','furniture','block-111189-2','Html_box','',1),(111192,'117897','furniture','block-111189-3','BlockBox','',1),(111193,'117898','furniture','block-111192','Html_box','',1),(111194,'117899','furniture','block-111192-2','Html_box','',1),(111195,'117900','furniture','block-111155-2','BlockBox','',3),(111196,'117901','furniture','block-111195','Html_box','',1),(111197,'117902','furniture','block-111195-2','Html_box','',1),(111198,'117903','furniture','block-111195-3','BlockBox','',1),(111199,'117904','furniture','block-111198','Html_box','',1),(111200,'117905','furniture','block-111198-2','Html_box','',1),(111201,'117906','furniture','rows','BlockBox','listing-item',1),(111202,'117907','furniture','block-111201','BlockBox','',2),(111203,'117908','furniture','block-111202','BlockBox','',2),(111204,'117909','furniture','block-111203','productListing\\bonusPoints','',2),(111205,'117910','furniture','block-111203','productListing\\image','',1),(111206,'117914','furniture','block-111203-2','productListing\\name','',1),(111207,'117915','furniture','block-111203-2','productListing\\description','',2),(111208,'117916','furniture','block-111203-2','productListing\\model','',4),(111209,'117917','furniture','block-111203-2','productListing\\attributes','',5),(111210,'120922','furniture','block-111203-2','productListing\\properties','',3),(111211,'1639146806.7019','furniture','block-111203-2','productListing\\productGroup','',6),(111212,'117918','furniture','block-111202-2','BlockBox','listing-item',1),(111213,'117911','furniture','block-111212','BlockBox','',3),(111214,'117912','furniture','block-111213','productListing\\rating','',1),(111215,'117913','furniture','block-111213','productListing\\ratingCounts','',2),(111216,'117919','furniture','block-111212','productListing\\qtyInput','',4),(111217,'117920','furniture','block-111212','productListing\\price','',2),(111218,'117922','furniture','block-111212','productListing\\buyButton','',5),(111219,'117924','furniture','block-111212','productListing\\stock','',1),(111220,'120924','furniture','block-111212','BlockBox','',8),(111221,'120925','furniture','block-111220','productListing\\compare','',3),(111222,'120926','furniture','block-111220','productListing\\personalCatalog','',2),(111223,'120927','furniture','block-111220','productListing\\viewButton','',1),(111224,'117925','furniture','sample','BlockBox','',1),(111225,'117926','furniture','block-111224','cart\\CartTabs','',1),(111226,'117927','furniture','block-111225','BlockBox','',1),(111227,'117928','furniture','block-111226','sample\\Products','',1),(111228,'117929','furniture','block-111226-2','BlockBox','',1),(111229,'117930','furniture','block-111228','BlockBox','',1),(111230,'117931','furniture','block-111229','sample\\CheckoutBtn','',1),(111231,'117932','furniture','samples','BlockBox','',1),(111232,'117933','furniture','block-111231','BlockBox','',1),(111233,'117934','furniture','block-111232','WidgetsAria','',1),(111253,'117935','furniture','block-111232-2','Html_box','',1),(111254,'117936','furniture','block-111232-2','Samples\\SamplesHistory','',2),(111255,'117937','furniture','sample_info','BlockBox','',1),(111256,'117938','furniture','block-111255','BlockBox','',1),(111257,'117939','furniture','block-111256','WidgetsAria','',1),(111277,'117940','furniture','block-111256-2','Html_box','',1),(111278,'117941','furniture','block-111256-2','BlockBox','',8),(111279,'117942','furniture','block-111278','account\\AccountLink','',1),(111280,'117943','furniture','block-111256-2','Samples\\SampleHistory','',7),(111281,'117944','furniture','block-111256-2','Html_box','',3),(111282,'117945','furniture','block-111256-2','Samples\\SampleSubTotal','',5),(111283,'117946','furniture','block-111256-2','Samples\\SampleProducts','',4),(111284,'117947','furniture','block-111256-2','Html_box','',6),(111285,'117948','furniture','block-111256-2','BlockBox','',2),(111286,'117949','furniture','block-111285','BlockBox','',4),(111287,'117950','furniture','block-111286','Html_box','',1),(111288,'117951','furniture','block-111286','Samples\\SampleData','',2),(111289,'117952','furniture','block-111285','BlockBox','',1),(111290,'117953','furniture','block-111289','Samples\\SampleData','',2),(111291,'117954','furniture','block-111289','Html_box','',1),(111292,'117955','furniture','block-111285-2','BlockBox','',2),(111293,'117956','furniture','block-111292','Samples\\SampleData','',2),(111294,'117957','furniture','block-111292','Html_box','',1),(111295,'117958','furniture','block-111285-2','BlockBox','',1),(111296,'117959','furniture','block-111295','Samples\\SampleData','',2),(111297,'117960','furniture','block-111295','Html_box','',1),(111298,'117961','furniture','block-111285-3','BlockBox','',2),(111299,'117962','furniture','block-111298','Samples\\SampleData','',2),(111300,'117963','furniture','block-111298','Html_box','',1),(111301,'117964','furniture','block-111285-3','BlockBox','',1),(111302,'117965','furniture','block-111301','Samples\\SampleData','',2),(111303,'117966','furniture','block-111301','Html_box','',1),(111304,'117967','furniture','sitemap','BlockBox','info-content',1),(111305,'117968','furniture','block-111304','Html_box','',1),(111306,'117969','furniture','block-111304','BlockBox','',2),(111307,'117970','furniture','block-111306','Html_box','',1),(111308,'117971','furniture','block-111306','Html_box','',5),(111309,'117972','furniture','block-111306','Html_box','',3),(111310,'117973','furniture','block-111306','sitemap\\InfoPages','',2),(111311,'117974','furniture','block-111306','sitemap\\Categories','',4),(111312,'117975','furniture','block-111306','Menu','Account box',6),(111313,'117976','furniture','block-111306-2','sitemap\\DeliveryLocation','',2),(111314,'117977','furniture','block-111306-2','Html_box','',1),(111315,'120878','furniture','social','SocialLinks','',1),(111316,'117978','furniture','subscribe','BlockBox','',1),(111317,'117979','furniture','block-111316','Html_box','',3),(111318,'117980','furniture','block-111316','subscribers\\UnsubscribeForm','',4),(111319,'117981','furniture','block-111316','Html_box','',1),(111320,'117982','furniture','block-111316','subscribers\\SubscribeForm','',2),(111321,'117983','furniture','subscribed','BlockBox','',1),(111322,'117984','furniture','block-111321','Html_box','',1),(111323,'117985','furniture','subscription','BlockBox','',2),(111324,'117986','furniture','block-111323','BlockBox','',1),(111325,'117987','furniture','block-111324','WidgetsAria','',1),(111345,'117988','furniture','block-111324-2','Html_box','',2),(111346,'117989','furniture','block-111324-2','Html_box','',3),(111347,'117990','furniture','block-111324-2','account\\Subscription','',4),(111348,'1695216662.204376','furniture','success','BlockBox','',1),(111349,'1695216662.283842','furniture','block-111348','BlockBox','',2),(111350,'1695216662.28679','furniture','block-111349','BlockBox','',3),(111351,'1695216662.287367','furniture','block-111350','BlockBox','',2),(111352,'1695216662.28994','furniture','block-111351','BlockBox','',1),(111353,'1695216662.291839','furniture','block-111352','order\\ShippingMethod','',6),(111354,'1695216662.293199','furniture','block-111352','order\\DeliveryAddress','',3),(111355,'1695216662.294382','furniture','block-111352','Html_box','',7),(111356,'1695216662.301223','furniture','block-111352','Html_box','',5),(111357,'1695216662.303717','furniture','block-111352','Html_box','',1),(111358,'1695216662.305529','furniture','block-111352','checkout\\ContactConfirm','',9),(111359,'1695216662.306549','furniture','block-111352','Html_box','',2),(111360,'1695216662.308881','furniture','block-111351-2','BlockBox','',1),(111361,'1695216662.310724','furniture','block-111360','order\\PaymentMethod','',6),(111362,'1695216662.311766','furniture','block-111360','order\\BillingAddress','',3),(111363,'1695216662.312915','furniture','block-111360','Html_box','',5),(111364,'1695216662.314711','furniture','block-111360','Html_box','',1),(111365,'1695216662.316646','furniture','block-111360','Html_box','',2),(111366,'1695216662.31980','furniture','block-111350','Html_box','',1),(111367,'1695216662.322253','furniture','block-111349-2','BlockBox','',1),(111368,'1695216662.323587','furniture','block-111367','success\\PrintBtn','',3),(111369,'1695216662.325129','furniture','block-111367','success\\ContinueBtn','',4),(111370,'1695216662.333192','furniture','block-111367','order\\Products','',1),(111371,'1695216662.334266','furniture','block-111367','order\\Totals','',2),(111372,'1695216662.335222','furniture','block-111348','BlockBox','',1),(111373,'1695216662.336556','furniture','block-111372','Html_box','',2),(111374,'1695216662.338898','furniture','block-111372','order\\OrderNumber','',1),(111375,'117997','furniture','success_q','BlockBox','',1),(111376,'117998','furniture','block-111375','BlockBox','',1),(111377,'117999','furniture','block-111376','BlockBox','',2),(111378,'118000','furniture','block-111377','success\\ContinueBtn','',2),(111379,'118001','furniture','block-111377','success\\PrintBtn','',1),(111380,'118002','furniture','block-111376','Html_box','',1),(111385,'118007','furniture','ticket','invoice\\Container','',1),(111386,'118008','furniture','block-111385','BlockBox','',4),(111387,'118009','furniture','block-111386','BlockBox','',1),(111388,'118010','furniture','block-111387','invoice\\ShippingAddress','',2),(111389,'118011','furniture','block-111387','Text','',1),(111390,'118012','furniture','block-111386-2','BlockBox','',1),(111391,'118013','furniture','block-111390','invoice\\Totals','',1),(111392,'118014','furniture','block-111385','BlockBox','',5),(111393,'118015','furniture','block-111392','Text','',1),(111394,'118016','furniture','block-111392','invoice\\StoreAddress','',8),(111395,'118018','furniture','block-111392-2','Text','',2),(111396,'118019','furniture','block-111392-3','Text','',1),(111397,'118020','furniture','block-111392-3','BlockBox','',3),(111398,'118021','furniture','block-111397','Text','',1),(111399,'118022','furniture','block-111397-2','invoice\\StoreEmail','',1),(111400,'118023','furniture','block-111392-3','BlockBox','',2),(111401,'118024','furniture','block-111400','Text','',1),(111402,'118025','furniture','block-111400-2','invoice\\StorePhone','',1),(111403,'118026','furniture','block-111385','invoice\\Products','',3),(111404,'118027','furniture','block-111385','BlockBox','',1),(111405,'118028','furniture','block-111404-2','BlockBox','',3),(111406,'118029','furniture','block-111405','Text','',1),(111407,'118030','furniture','block-111405-2','invoice\\StoreEmail','',1),(111408,'118031','furniture','block-111404-2','BlockBox','',4),(111409,'118032','furniture','block-111408','Text','',1),(111410,'118033','furniture','block-111408-2','invoice\\StoreSite','',1),(111411,'118034','furniture','block-111404-2','BlockBox','',1),(111412,'118035','furniture','block-111411','invoice\\StoreAddress','',1),(111413,'118036','furniture','block-111404-2','BlockBox','',2),(111414,'118037','furniture','block-111413','Text','',1),(111415,'118038','furniture','block-111413-2','invoice\\StorePhone','',1),(111416,'118039','furniture','block-111385','BlockBox','',2),(111417,'118040','furniture','block-111416','BlockBox','',8),(111418,'118041','furniture','block-111417','BlockBox','',1),(111419,'118042','furniture','block-111418','Text','',1),(111420,'118043','furniture','block-111418','invoice\\ShippingMethod','',2),(111421,'118044','furniture','block-111417-2','BlockBox','',1),(111422,'118045','furniture','block-111421','Text','',1),(111423,'118046','furniture','block-111421','invoice\\ShippingMethod','',2),(111424,'118047','furniture','block-111416','BlockBox','',7),(111425,'118048','furniture','block-111424','BlockBox','',1),(111426,'118049','furniture','block-111425','invoice\\BillingAddress','',2),(111427,'118050','furniture','block-111425','Text','',1),(111428,'118051','furniture','block-111424-2','BlockBox','',1),(111429,'118052','furniture','block-111428','invoice\\CustomerName','',2),(111430,'118053','furniture','block-111428','Text','',3),(111431,'118054','furniture','block-111428','invoice\\CustomerEmail','',6),(111432,'118055','furniture','block-111428','invoice\\CustomerPhone','',4),(111433,'118056','furniture','block-111428','Text','',5),(111434,'118057','furniture','block-111428','Text','',1),(111435,'118058','furniture','block-111416-2','invoice\\PaymentDate','',3),(111436,'118059','furniture','block-111416-2','Text','',2),(111437,'118060','furniture','block-111416-2','Text','',4),(111438,'118061','furniture','block-111416-2','invoice\\OrderId','',1),(111439,'118062','furniture','block-111416-2','invoice\\PaymentMethod','',5),(111440,'118063','furniture','block-111416-2','invoice\\OrderBarcode','',6),(111441,'118094','furniture','tracking_numbers','BlockBox','',1),(111442,'118095','furniture','block-111441','Html_box','',1),(111443,'118096','furniture','block-111441','account\\OrderTracking','',2),(111444,'118318','furniture','unsubscribed','BlockBox','',1),(111445,'118319','furniture','block-111444','Html_box','',1),(111446,'118320','furniture','update-and-pay-order_confirmation','BlockBox','',1),(111447,'118321','furniture','block-111446','BlockBox','',3),(111448,'118322','furniture','block-111447','BlockBox','',1),(111449,'118323','furniture','block-111448','BlockBox','',1),(111450,'118324','furniture','block-111449','BlockBox','',1),(111451,'118325','furniture','block-111450','order\\ShippingMethod','',5),(111452,'118326','furniture','block-111450','Html_box','',2),(111453,'118327','furniture','block-111450','Html_box','',4),(111454,'118328','furniture','block-111450','Html_box','',1),(111455,'118329','furniture','block-111450','order\\Telephone','',8),(111456,'118330','furniture','block-111450','Html_box','',6),(111457,'118331','furniture','block-111450','order\\Name','',7),(111458,'118332','furniture','block-111450','order\\Email','',9),(111459,'118333','furniture','block-111450','order\\DeliveryAddress','',3),(111460,'118334','furniture','block-111449-2','BlockBox','',1),(111461,'118335','furniture','block-111460','order\\BillingAddress','',3),(111462,'118336','furniture','block-111460','UpdateAndPay\\PayConfirm','',5),(111463,'118337','furniture','block-111460','Html_box','',1),(111464,'118338','furniture','block-111460','Html_box','',2),(111465,'118339','furniture','block-111460','Html_box','',4),(111466,'118340','furniture','block-111448','BlockBox','',3),(111467,'118341','furniture','block-111466','order\\Products','',2),(111468,'118342','furniture','block-111466','Html_box','',1),(111469,'118343','furniture','block-111447-2','BlockBox','',1),(111470,'118344','furniture','block-111469','Html_box','',1),(111471,'118345','furniture','block-111469','checkout\\ContinueBtn','',3),(111472,'118346','furniture','block-111469','order\\Totals','',2),(111473,'118347','furniture','block-111446','account\\OrderHeading','',1),(111474,'118348','furniture','update-and-pay-order_pay','BlockBox','',1),(111475,'118349','furniture','block-111474','BlockBox','',3),(111476,'118350','furniture','block-111475','BlockBox','',1),(111477,'118351','furniture','block-111476','BlockBox','',1),(111478,'118352','furniture','block-111477','BlockBox','',1),(111479,'118353','furniture','block-111478','order\\DeliveryAddress','',4),(111480,'118354','furniture','block-111478','order\\Email','',10),(111481,'118355','furniture','block-111478','order\\Name','',8),(111482,'118356','furniture','block-111478','Html_box','',7),(111483,'118357','furniture','block-111478','order\\Telephone','',9),(111484,'118358','furniture','block-111478','Html_box','',5),(111485,'118359','furniture','block-111478','order\\ShippingMethod','',6),(111486,'118360','furniture','block-111478','Html_box','',2),(111487,'118361','furniture','block-111478','Html_box','',3),(111488,'1639647774.7838','furniture','block-111478','DelayedDespatch\\OrderPay','',1),(111489,'118362','furniture','block-111477-2','BlockBox','',1),(111490,'118363','furniture','block-111489','Html_box','',1),(111491,'118364','furniture','block-111489','Html_box','',2),(111492,'118365','furniture','block-111489','Html_box','',4),(111493,'118366','furniture','block-111489','order\\BillingAddress','',3),(111494,'118367','furniture','block-111489','UpdateAndPay\\PayForm','',5),(111495,'118368','furniture','block-111476','BlockBox','',3),(111496,'118369','furniture','block-111495','Html_box','',1),(111497,'118370','furniture','block-111495','order\\Products','',2),(111498,'118371','furniture','block-111475-2','BlockBox','',1),(111499,'118372','furniture','block-111498','order\\Totals','',2),(111500,'118373','furniture','block-111498','checkout\\ContinueBtn','',3),(111501,'118374','furniture','block-111498','Html_box','',1),(111502,'118375','furniture','block-111474','account\\OrderHeading','',1),(111503,'118440','furniture','wishlist','BlockBox','',1),(111504,'118441','furniture','block-111503','BlockBox','',1),(111505,'118442','furniture','block-111504','WidgetsAria','',1),(111525,'118443','furniture','block-111504-2','account\\Wishlist','',2),(111526,'118444','furniture','block-111504-2','Html_box','',1),(111527,'118445','furniture','wishlist-cart','BlockBox','',1),(111528,'118446','furniture','block-111527','cart\\CartTabs','',1),(111529,'118447','furniture','block-111528','account\\Wishlist','',1),(111530,'73349','watch','404','Html_box','',1),(111764,'73409','watch','b2b','BlockBox','listing-item',1),(111765,'73410','watch','block-111764','BlockBox','',1),(111766,'73411','watch','block-111765','productListing\\image','',1),(111767,'73412','watch','block-111765-2','productListing\\description','',6),(111768,'73413','watch','block-111765-2','productListing\\model','',5),(111769,'73414','watch','block-111765-2','productListing\\attributes','',3),(111770,'73415','watch','block-111765-2','BlockBox','',4),(111771,'73416','watch','block-111770','BlockBox','',1),(111772,'73417','watch','block-111771','productListing\\price','',1),(111773,'73418','watch','block-111771-2','BonusActions\\widgets\\BonusPointsProductListing','',1),(111774,'73419','watch','block-111770-2','productListing\\qtyInput','',1),(111775,'73420','watch','block-111765-2','productListing\\name','',1),(111776,'73421','watch','block-111765-2','BlockBox','',2),(111777,'73422','watch','block-111776','productListing\\stock','',1),(111778,'73423','watch','block-111776-2','productListing\\rating','',1),(111779,'76000','watch','batch','BlockBox','',1),(111780,'76001','watch','block-111779','productListing\\attributes','',5),(111781,'76002','watch','block-111779','productListing\\price','',6),(111782,'76003','watch','block-111779','productListing\\name','',4),(111783,'76004','watch','block-111779','productListing\\image','',2),(111784,'76005','watch','block-111779','batchSelect','',1),(111785,'76006','watch','batch_selected','BlockBox','',1),(111786,'76007','watch','block-111785','BlockBox','',13),(111787,'76008','watch','block-111786','productListing\\image','',1),(111788,'76009','watch','block-111786-2','batchRemove','',1),(111789,'76010','watch','block-111786-2','productListing\\price','',3),(111790,'76011','watch','block-111786-2','productListing\\name','',2),(111791,'76012','watch','bbbbb','BlockBox','',1),(111792,'76013','watch','block-111791','BlockBox','',2),(111793,'76014','watch','block-111792','Filters','',1),(111794,'76015','watch','block-111792-2','BlockBox','',6),(111795,'76016','watch','block-111794','catalog\\CountsItems','',1),(111796,'76017','watch','block-111794-2','catalog\\Paging','',1),(111797,'76018','watch','block-111792-2','catalog\\Image','',1),(111798,'76019','watch','block-111792-2','Listing','',5),(111799,'76020','watch','block-111792-2','catalog\\ImageMapCategory','',3),(111800,'76021','watch','block-111792-2','BlockBox','',4),(111801,'76022','watch','block-111800','catalog\\ListingLook','',1),(111802,'76023','watch','block-111800','catalog\\CompareButton','',2),(111803,'76024','watch','block-111800','catalog\\ItemsOnPage','',4),(111804,'76025','watch','block-111800','catalog\\Sorting','',3),(111805,'76026','watch','block-111792-2','Categories','',2),(111806,'76027','watch','block-111791','catalog\\Title','',1),(111807,'1683124632.767746','watch','cart','BlockBox','',1),(111808,'1683124632.80670','watch','block-111807','BlockBox','',2),(111809,'1683124632.809680','watch','block-111808','BlockBox','cart-content',4),(111810,'1683124632.816335','watch','block-111808','BlockBox','',1),(111811,'1683124632.817623','watch','block-111810','cart\\Products','',2),(111812,'1683124632.818551','watch','block-111810','BlockBox','',1),(111813,'1683124632.820317','watch','block-111812','MultiCart\\CartSwitcher','',1),(111814,'1683124632.820914','watch','block-111812','MultiCart\\SaveCart','',2),(111815,'1683124632.822588','watch','block-111812-2','MultiCart\\Actions','',1),(111816,'1683124632.823175','watch','block-111810','BlockBox','',3),(111817,'1683124632.825245','watch','block-111816','cart\\CreditAmount','',1),(111818,'1683124632.825649','watch','block-111816-2','BonusActions\\widgets\\BonusPointsCart','',1),(111819,'1683124632.82683','watch','block-111808','BlockBox','',3),(111820,'1683124632.827413','watch','block-111819','cart\\GiveAway','',2),(111821,'1683124632.828374','watch','block-111819','Html_box','',1),(111822,'1683124632.829840','watch','block-111808','BlockBox','',5),(111823,'1683124632.831459','watch','block-111822','Html_box','',1),(111824,'1683124632.832592','watch','block-111822','cart\\ShippingEstimator','',2),(111825,'1683124632.833353','watch','block-111808-2','BlockBox','',1),(111826,'1683124632.834715','watch','block-111825','BlockBox','',2),(111827,'1683124632.835884','watch','block-111826','cart\\DiscountCoupon','',1),(111828,'1683124632.836532','watch','block-111826','Image','',4),(111829,'1683124632.844829','watch','block-111826','cart\\CheckoutBtn','',3),(111830,'1683124632.84681','watch','block-111826','cart\\OrderTotal','',2),(111831,'1683124632.846538','watch','block-111826','cart\\OrderTotal','',0),(111832,'1683124632.84726','watch','block-111825','Html_box','',1),(111833,'94658','watch','cart2','BlockBox','',2),(111834,'94659','watch','block-111833','cart\\CartTabs','',2),(111835,'94660','watch','block-111834','BlockBox','',1),(111836,'94661','watch','block-111835','BlockBox','',4),(111837,'94662','watch','block-111836','cart\\UpSell','6',2),(111838,'94663','watch','block-111836','Html_box','',1),(111839,'94664','watch','block-111835','BlockBox','',1),(111840,'94665','watch','block-111839','cart\\Products','',3),(111841,'94666','watch','block-111839','BlockBox','',2),(111842,'94667','watch','block-111841','MultiCart\\CartSwitcher','',1),(111843,'94668','watch','block-111841','MultiCart\\SaveCart','',2),(111844,'94669','watch','block-111841-2','MultiCart\\Actions','',1),(111845,'94670','watch','block-111835','BlockBox','',3),(111846,'94671','watch','block-111845','cart\\GiveAway','',2),(111847,'94672','watch','block-111845','Html_box','',1),(111848,'94673','watch','block-111835','BlockBox','',2),(111849,'94674','watch','block-111848','Html_box','',1),(111850,'94675','watch','block-111848','BlockBox','',2),(111851,'94676','watch','block-111850','cart\\DiscountCoupon','',1),(111852,'94677','watch','block-111850-2','cart\\CreditAmount','',1),(111853,'94678','watch','block-111850-3','BonusActions\\widgets\\BonusPointsCart','',1),(111854,'94679','watch','block-111835','BlockBox','',5),(111855,'94680','watch','block-111854','Html_box','',1),(111856,'94681','watch','block-111854','cart\\ShippingEstimator','',2),(111857,'94682','watch','block-111835-2','BlockBox','',1),(111858,'94683','watch','block-111857','Html_box','',1),(111859,'94684','watch','block-111857','BlockBox','',2),(111860,'94685','watch','block-111859','Image','',4),(111861,'94686','watch','block-111859','cart\\CheckoutBtn','',2),(111862,'94687','watch','block-111859','cart\\OrderTotal','',1),(111863,'73462','watch','categories','BlockBox','catalog-content',1),(111864,'73463','watch','block-111863','BlockBox','catalog-side',2),(111865,'73464','watch','block-111864','Filters','',1),(111866,'73465','watch','block-111864-2','Listing','',5),(111867,'73466','watch','block-111864-2','catalog\\Image','',1),(111868,'73467','watch','block-111864-2','BlockBox','',6),(111869,'73468','watch','block-111868','catalog\\CountsItems','',1),(111870,'73469','watch','block-111868-2','catalog\\Paging','',1),(111871,'73470','watch','block-111864-2','catalog\\ImageMapCategory','',3),(111872,'73471','watch','block-111864-2','Categories','',2),(111873,'73472','watch','block-111864-2','BlockBox','catalog-features',4),(111874,'73473','watch','block-111873','catalog\\ListingLook','',1),(111875,'73474','watch','block-111873','catalog\\CompareButton','',2),(111876,'73475','watch','block-111873','catalog\\ItemsOnPage','',4),(111877,'73476','watch','block-111873','catalog\\Sorting','',3),(111878,'73477','watch','block-111863','catalog\\Title','',1),(111879,'73478','watch','category','Categories','',1),(111880,'73479','watch','category','Listing','',4),(111881,'73480','watch','category','ListingFunctionality','',2),(111882,'73481','watch','category','PagingBar','',3),(111883,'73482','watch','category','PagingBar','',5),(111884,'94688','watch','category_2','BlockBox','',1),(111885,'94689','watch','block-111884','catalog\\Title','',1),(111886,'94690','watch','block-111884','BlockBox','',2),(111887,'94691','watch','block-111886','Filters','',1),(111888,'94692','watch','block-111886-2','catalog\\Image','',1),(111889,'94693','watch','block-111886-2','Listing','',5),(111890,'94694','watch','block-111886-2','BlockBox','',4),(111891,'94695','watch','block-111890','catalog\\Sorting','',3),(111892,'94696','watch','block-111890','catalog\\ItemsOnPage','',4),(111893,'94697','watch','block-111890','catalog\\CompareButton','',2),(111894,'94698','watch','block-111890','catalog\\ListingLook','',1),(111895,'94699','watch','block-111886-2','catalog\\ImageMapCategory','',3),(111896,'94700','watch','block-111886-2','Categories','',2),(111897,'94701','watch','block-111886-2','BlockBox','',6),(111898,'94702','watch','block-111897','catalog\\CountsItems','',1),(111899,'94703','watch','block-111897-2','catalog\\Paging','',1),(111900,'73483','watch','category_no_filters','BlockBox','',1),(111901,'73484','watch','block-111900','catalog\\Title','',1),(111902,'73485','watch','block-111900','Categories','',3),(111903,'73486','watch','block-111900','BlockBox','catalog-features',4),(111904,'73487','watch','block-111903','catalog\\ItemsOnPage','',4),(111905,'73488','watch','block-111903','catalog\\Sorting','',3),(111906,'73489','watch','block-111903','catalog\\CompareButton','',2),(111907,'73490','watch','block-111903','catalog\\ListingLook','',1),(111908,'73491','watch','block-111903','HeaderStock','',5),(111909,'73492','watch','block-111900','BlockBox','',6),(111910,'73493','watch','block-111909','catalog\\CountsItems','',1),(111911,'73494','watch','block-111909-2','catalog\\Paging','',1),(111912,'73495','watch','block-111900','Listing','',5),(111913,'73496','watch','block-111900','catalog\\Image','',2),(111914,'73497','watch','block-111900','catalog\\B2bAddButton','',7),(111915,'1683125852.345798','watch','checkout','BlockBox','',1),(111916,'1683125852.356555','watch','block-111915','BlockBox','',2),(111917,'1683125852.358412','watch','block-111916','BlockBox','',2),(111918,'1683125852.35982','watch','block-111917','BlockBox','checkout-comments',5),(111919,'1683125852.361569','watch','block-111918','checkout\\Comments','',2),(111920,'1683125852.362847','watch','block-111918','Html_box','',1),(111921,'1683125852.36485','watch','block-111917','BlockBox','checkout-discount',4),(111922,'1683125852.366422','watch','block-111921','Html_box','',1),(111923,'1683125852.367732','watch','block-111921','BlockBox','',2),(111924,'1683125852.36968','watch','block-111923','CouponsAndVauchers\\Checkout','',1),(111925,'1683125852.369745','watch','block-111923-2','checkout\\CreditAmount','',1),(111926,'1683125852.37045','watch','block-111923-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(111927,'1683125852.371233','watch','block-111917','BlockBox','checkout-shipping',2),(111928,'1683125852.37350','watch','block-111927','BlockBox','',3),(111929,'1683125852.374899','watch','block-111928','checkout\\ShippingChoice','',1),(111930,'1683125852.375685','watch','block-111927','Neighbour\\Checkout','',5),(111931,'1683125852.376557','watch','block-111927','BlockBox','',4),(111932,'1683125852.377637','watch','block-111931','BlockBox','',1),(111933,'1683125852.378829','watch','block-111932','checkout\\ShippingAddress','',2),(111934,'1683125852.379375','watch','block-111932','Html_box','',3),(111935,'1683125852.380323','watch','block-111932','checkout\\ContactInformation','',4),(111936,'1683125852.380722','watch','block-111932','UploadCustomerId\\UploadCustomerIdForm','',4),(111937,'1683125852.381183','watch','block-111931-2','BlockBox','',1),(111938,'1683125852.382226','watch','block-111937','checkout\\Shipping','',2),(111939,'1683125852.382635','watch','block-111937','DelayedDespatch\\Checkout','',3),(111940,'1683125852.383516','watch','block-111937','Html_box','',1),(111941,'1683125852.385278','watch','block-111927','Html_box','',2),(111942,'1683125852.386397','watch','block-111917','cart\\Products','',6),(111943,'1683125852.386970','watch','block-111917','checkout\\CreateAccount','',7),(111944,'1683125852.38820','watch','block-111917','BlockBox','checkout-payment',3),(111945,'1683125852.390244','watch','block-111944','Html_box','',1),(111946,'1683125852.391810','watch','block-111944','BlockBox','',2),(111947,'1683125852.393320','watch','block-111946','Html_box','',1),(111948,'1683125852.394747','watch','block-111946','checkout\\BillingAddress','',2),(111949,'1683125852.395767','watch','block-111946-2','BlockBox','',1),(111950,'1683125852.397129','watch','block-111949','checkout\\PaymentMethod','',2),(111951,'1683125852.398588','watch','block-111949','Html_box','',1),(111952,'1683125852.400291','watch','block-111917','BlockBox','',1),(111953,'1683125852.402237','watch','block-111952','checkout\\LoginOnForm','',0),(111954,'1683128325.0836','watch','block-111952','BlockBox','',1),(111955,'1683125852.403563','watch','block-111916-2','BlockBox','checkout-side',1),(111956,'1683125852.405625','watch','block-111955','Html_box','',6),(111957,'1683125852.407666','watch','block-111955','Html_box','',1),(111958,'1683125852.40885','watch','block-111955','checkout\\Terms','',5),(111959,'1683125852.409688','watch','block-111955','checkout\\Totals','',3),(111960,'1683125852.410151','watch','block-111955','checkout\\ContinueBtn','',4),(111961,'1683125852.412647','watch','block-111955','cart\\Products','',2),(111962,'73542','watch','checkout_confirmation','BlockBox','',1),(111963,'73543','watch','block-111962','checkout\\Totals','',8),(111964,'73544','watch','block-111962','Html_box','',5),(111965,'73545','watch','block-111962','checkout\\EditBtn','',6),(111966,'73546','watch','block-111962','BlockBox','',3),(111967,'73547','watch','block-111966','BlockBox','',1),(111968,'73548','watch','block-111967','Html_box','',1),(111969,'73549','watch','block-111967','checkout\\ShippingConfirm','',3),(111970,'73550','watch','block-111966-2','BlockBox','',1),(111971,'73551','watch','block-111970','checkout\\PaymentMethodConfirm','',3),(111972,'73552','watch','block-111970','Html_box','',1),(111973,'73553','watch','block-111962','checkout\\ConfirmBtn','',9),(111974,'73554','watch','block-111962','BlockBox','',2),(111975,'73555','watch','block-111974','BlockBox','',1),(111976,'73556','watch','block-111975','checkout\\ShippingAddressConfirm','',3),(111977,'73557','watch','block-111975','Html_box','',1),(111978,'73558','watch','block-111974-2','BlockBox','',1),(111979,'73559','watch','block-111978','Html_box','',1),(111980,'73560','watch','block-111978','checkout\\BillingAddressConfirm','',3),(111981,'73561','watch','block-111962','checkout\\ConfirmBtn','',4),(111982,'73562','watch','block-111962','cart\\Products','',7),(111983,'73576','watch','checkout_confirmation_no_shipping','BlockBox','',1),(111984,'73577','watch','block-111983','checkout\\ConfirmBtn','',9),(111985,'73578','watch','block-111983','BlockBox','',2),(111986,'73579','watch','block-111985','BlockBox','',1),(111987,'73580','watch','block-111986','Html_box','',1),(111988,'73581','watch','block-111986','checkout\\BillingAddressConfirm','',3),(111989,'73582','watch','block-111985-2','BlockBox','',1),(111990,'73583','watch','block-111989','Html_box','',1),(111991,'73584','watch','block-111989','checkout\\PaymentMethodConfirm','',3),(111992,'73585','watch','block-111983','checkout\\ConfirmBtn','',4),(111993,'73586','watch','block-111983','checkout\\Totals','',8),(111994,'73587','watch','block-111983','cart\\Products','',7),(111995,'73588','watch','block-111983','Html_box','',5),(111996,'73563','watch','checkout_confirmation_no_shipping_q','BlockBox','',1),(111997,'73564','watch','block-111996','quote\\Products','',4),(111998,'73565','watch','block-111996','checkout\\ConfirmBtn','',2),(111999,'73566','watch','block-111996','checkout\\ConfirmBtn','',6),(112000,'73567','watch','block-111996','BlockBox','',1),(112001,'73568','watch','block-112000','BlockBox','',1),(112002,'73569','watch','block-112001','checkout\\BillingAddressConfirm','',3),(112003,'73570','watch','block-112001','Html_box','',1),(112004,'73571','watch','block-112000-2','BlockBox','',1),(112005,'73572','watch','block-112004','checkout\\PaymentMethodConfirm','',3),(112006,'73573','watch','block-112004','Html_box','',1),(112007,'73574','watch','block-111996','Html_box','',3),(112008,'73575','watch','block-111996','checkout\\Totals','',5),(112009,'73589','watch','checkout_confirmation_q','BlockBox','',1),(112010,'73590','watch','block-112009','BlockBox','',1),(112011,'73591','watch','block-112010','BlockBox','',1),(112012,'73592','watch','block-112011','checkout\\ShippingAddressConfirm','',3),(112013,'73593','watch','block-112011','Html_box','',1),(112014,'73594','watch','block-112010-2','BlockBox','',1),(112015,'73595','watch','block-112014','checkout\\BillingAddressConfirm','',3),(112016,'73596','watch','block-112014','Html_box','',1),(112017,'73597','watch','block-112009','checkout\\Totals','',7),(112018,'73598','watch','block-112009','quote\\Products','',6),(112019,'73599','watch','block-112009','Html_box','',4),(112020,'73600','watch','block-112009','checkout\\EditBtn','',5),(112021,'73601','watch','block-112009','checkout\\ConfirmBtn','',8),(112022,'73602','watch','block-112009','checkout\\ConfirmBtn','',3),(112023,'73603','watch','block-112009','BlockBox','',2),(112024,'73604','watch','block-112023','BlockBox','',1),(112025,'73605','watch','block-112024','Html_box','',1),(112026,'73606','watch','block-112024','checkout\\ShippingConfirm','',3),(112027,'73607','watch','block-112023-2','BlockBox','',1),(112028,'73608','watch','block-112027','Html_box','',1),(112029,'73609','watch','block-112027','checkout\\PaymentMethodConfirm','',3),(112030,'73610','watch','checkout_confirmation_title','Html_box','',1),(112031,'73611','watch','checkout_confirmation_title_g','Html_box','',1),(112032,'73613','watch','checkout_confirmation_title_no_shipping','Html_box','',1),(112033,'73612','watch','checkout_confirmation_title_no_shipping_g','Html_box','',1),(112034,'73614','watch','checkout_confirmation_title_q','Html_box','',1),(112035,'73615','watch','checkout_confirmation_title_s','Html_box','',1),(112036,'73616','watch','checkout_delivery','BlockBox','',2),(112037,'73617','watch','block-112036','BlockBox','',1),(112038,'73618','watch','block-112037','Html_box','',1),(112039,'73619','watch','block-112037','checkout\\ContactInformation','',2),(112040,'73620','watch','block-112036-2','BlockBox','',1),(112041,'73621','watch','block-112040','Html_box','',1),(112042,'73622','watch','block-112040','checkout\\Comments','',2),(112043,'73623','watch','checkout_delivery','BlockBox','',3),(112044,'73624','watch','block-112043','Html_box','',1),(112045,'73625','watch','block-112043-2','checkout\\ContinueBtn','',1),(112046,'73626','watch','checkout_delivery','BlockBox','',1),(112047,'73627','watch','block-112046','BlockBox','',1),(112048,'73628','watch','block-112047','Html_box','',1),(112049,'73629','watch','block-112047','checkout\\ShippingAddress','',2),(112050,'73630','watch','block-112046-2','BlockBox','',1),(112051,'73631','watch','block-112050','DelayedDespatch\\Checkout','',3),(112052,'73632','watch','block-112050','checkout\\Shipping','',2),(112053,'73633','watch','block-112050','Html_box','',1),(112054,'73634','watch','block-112050','Neighbour\\Checkout','',4),(112055,'73635','watch','checkout_delivery_g','BlockBox','',2),(112056,'73636','watch','block-112055','BlockBox','',1),(112057,'73637','watch','block-112056','checkout\\ContactInformation','',2),(112058,'73638','watch','block-112056','Html_box','',1),(112059,'73639','watch','block-112055-2','BlockBox','',1),(112060,'73640','watch','block-112059','Html_box','',1),(112061,'73641','watch','block-112059','checkout\\Comments','',2),(112062,'73642','watch','checkout_delivery_g','BlockBox','',3),(112063,'73643','watch','block-112062','Html_box','',1),(112064,'73644','watch','block-112062-2','checkout\\ContinueBtn','',1),(112065,'73645','watch','checkout_delivery_g','BlockBox','',1),(112066,'73646','watch','block-112065','BlockBox','',1),(112067,'73647','watch','block-112066','checkout\\ShippingAddress','',2),(112068,'73648','watch','block-112066','Html_box','',1),(112069,'73649','watch','block-112065-2','BlockBox','',1),(112070,'73650','watch','block-112069','checkout\\Shipping','',2),(112071,'73651','watch','block-112069','Html_box','',1),(112072,'73652','watch','block-112069','DelayedDespatch\\Checkout','',3),(112073,'73653','watch','block-112069','Neighbour\\Checkout','',4),(112074,'73654','watch','checkout_delivery_no_shipping','BlockBox','',2),(112075,'73655','watch','block-112074','Html_box','',1),(112076,'73656','watch','block-112074-2','checkout\\ContinueBtn','',1),(112077,'73657','watch','checkout_delivery_no_shipping','BlockBox','',1),(112078,'73658','watch','block-112077','BlockBox','',1),(112079,'73659','watch','block-112078','checkout\\ContactInformation','',2),(112080,'73660','watch','block-112077-2','BlockBox','',1),(112081,'73661','watch','block-112080','Html_box','',1),(112082,'73662','watch','block-112080','checkout\\Comments','',2),(112083,'73663','watch','checkout_delivery_no_shipping_g','BlockBox','',2),(112084,'73664','watch','block-112083','Html_box','',1),(112085,'73665','watch','block-112083-2','checkout\\ContinueBtn','',1),(112086,'73666','watch','checkout_delivery_no_shipping_g','BlockBox','',1),(112087,'73667','watch','block-112086','BlockBox','',1),(112088,'73668','watch','block-112087','checkout\\ContactInformation','',2),(112089,'73669','watch','block-112086-2','BlockBox','',1),(112090,'73670','watch','block-112089','checkout\\Comments','',2),(112091,'73671','watch','block-112089','Html_box','',1),(112092,'73672','watch','checkout_delivery_title','Html_box','',1),(112093,'73673','watch','checkout_delivery_title_g','Html_box','',1),(112094,'73675','watch','checkout_delivery_title_no_shipping','Html_box','',1),(112095,'73674','watch','checkout_delivery_title_no_shipping_g','Html_box','',1),(112096,'73676','watch','checkout_delivery_title_q','Html_box','',1),(112097,'73677','watch','checkout_delivery_title_s','Html_box','',1),(112098,'73678','watch','checkout_free_s','BlockBox','',1),(112099,'73679','watch','block-112098','BlockBox','',2),(112100,'73680','watch','block-112099','BlockBox','',2),(112101,'73682','watch','block-112100','BlockBox','',6),(112102,'73683','watch','block-112101','sample\\Products','',1),(112103,'73684','watch','block-112101','checkout\\CreateAccount','',3),(112104,'73685','watch','block-112100','BlockBox','',5),(112105,'73686','watch','block-112104','Html_box','',1),(112106,'73687','watch','block-112104','checkout\\Comments','',2),(112107,'73688','watch','block-112100','BlockBox','',2),(112108,'73689','watch','block-112107','BlockBox','',2),(112109,'73690','watch','block-112108','checkout\\ShippingChoice','',1),(112110,'73691','watch','block-112107','Html_box','',1),(112111,'73692','watch','block-112107','BlockBox','',3),(112112,'73693','watch','block-112111','BlockBox','',1),(112113,'73694','watch','block-112112','checkout\\ContactInformation','',4),(112114,'73695','watch','block-112112','checkout\\ShippingAddress','',2),(112115,'73696','watch','block-112112','Html_box','',3),(112116,'73697','watch','block-112111-2','BlockBox','',1),(112117,'73698','watch','block-112116','DelayedDespatch\\Checkout','',3),(112118,'73699','watch','block-112107','Neighbour\\Checkout','',4),(112119,'73700','watch','block-112099-2','BlockBox','',1),(112120,'73701','watch','block-112119','Html_box','',3),(112121,'73702','watch','block-112119','checkout\\ContinueBtn','',1),(112122,'115999','watch','block-112119','checkout\\Terms','',2),(112123,'73703','watch','checkout_no_shipping','BlockBox','',1),(112124,'73704','watch','block-112123','BlockBox','',2),(112125,'73705','watch','block-112124','BlockBox','',1),(112126,'73706','watch','block-112125','BlockBox','',6),(112127,'73707','watch','block-112126','checkout\\CreateAccount','',2),(112128,'73708','watch','block-112126','cart\\Products','',1),(112129,'73709','watch','block-112125','BlockBox','',3),(112130,'73710','watch','block-112129','Html_box','',1),(112131,'73711','watch','block-112129','BlockBox','',2),(112132,'73712','watch','block-112131','checkout\\BillingAddress','',2),(112133,'73713','watch','block-112131','Html_box','',1),(112134,'73714','watch','block-112131-2','BlockBox','',1),(112135,'73715','watch','block-112134','Html_box','',1),(112136,'73716','watch','block-112134','checkout\\PaymentMethod','',2),(112137,'73717','watch','block-112125','BlockBox','',4),(112138,'73718','watch','block-112137','BlockBox','',2),(112139,'73719','watch','block-112138','CouponsAndVauchers\\Checkout','',1),(112140,'73720','watch','block-112138-2','checkout\\CreditAmount','',1),(112141,'73721','watch','block-112138-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(112142,'73722','watch','block-112137','Html_box','',1),(112143,'73723','watch','block-112125','BlockBox','',5),(112144,'73724','watch','block-112143','checkout\\Comments','',2),(112145,'73725','watch','block-112143','Html_box','',1),(112146,'73726','watch','block-112124-2','BlockBox','',1),(112147,'73727','watch','block-112146','Html_box','',1),(112148,'73728','watch','block-112146','Html_box','',5),(112149,'73729','watch','block-112146','checkout\\Totals','',2),(112150,'73730','watch','block-112146','checkout\\ContinueBtn','',3),(112151,'73731','watch','block-112146','checkout\\Terms','',4),(112152,'73732','watch','checkout_no_shipping_g','BlockBox','',1),(112153,'73733','watch','block-112152','checkout\\Totals','',5),(112154,'73734','watch','block-112152','BlockBox','',6),(112155,'73735','watch','block-112154','Html_box','',1),(112156,'73736','watch','block-112154-2','checkout\\ContinueBtn','',1),(112157,'73737','watch','block-112152','BlockBox','',2),(112158,'73738','watch','block-112157','BlockBox','',1),(112159,'73739','watch','block-112158','checkout\\ContactInformation','',2),(112160,'73740','watch','block-112158','Html_box','',1),(112161,'73741','watch','block-112157-2','BlockBox','',1),(112162,'73742','watch','block-112161','checkout\\Comments','',2),(112163,'73743','watch','block-112161','Html_box','',1),(112164,'73744','watch','block-112152','BlockBox','',1),(112165,'73745','watch','block-112164','BlockBox','',1),(112166,'73746','watch','block-112165','Html_box','',1),(112167,'73747','watch','block-112165','checkout\\BillingAddress','',2),(112168,'73748','watch','block-112164-2','BlockBox','',1),(112169,'73749','watch','block-112168','BonusActions\\widgets\\BonusPointsCheckout','',4),(112170,'73750','watch','block-112168','CouponsAndVauchers\\Checkout','',5),(112171,'73751','watch','block-112168','checkout\\PaymentMethod','',2),(112172,'73752','watch','block-112168','checkout\\CreditAmount','',3),(112173,'73753','watch','block-112168','Html_box','',1),(112174,'73754','watch','block-112152','quote\\Products','',3),(112175,'73755','watch','checkout_no_shipping_q','BlockBox','',1),(112176,'73756','watch','block-112175','BlockBox','',2),(112177,'73757','watch','block-112176','BlockBox','',2),(112178,'73758','watch','block-112177','checkout\\Gdpr','',1),(112179,'73759','watch','block-112177','BlockBox','',5),(112180,'73760','watch','block-112179','checkout\\Comments','',2),(112181,'73761','watch','block-112179','Html_box','',1),(112182,'73762','watch','block-112177','BlockBox','',6),(112183,'73763','watch','block-112182','checkout\\CreateAccount','',3),(112184,'73764','watch','block-112182','quote\\Products','',2),(112185,'73765','watch','block-112177','BlockBox','',3),(112186,'73766','watch','block-112185','Html_box','',1),(112187,'73767','watch','block-112185','BlockBox','',2),(112188,'73768','watch','block-112187','Html_box','',1),(112189,'73769','watch','block-112187','checkout\\BillingAddress','',2),(112190,'73770','watch','block-112187-2','BlockBox','',1),(112191,'73771','watch','block-112190','checkout\\PaymentMethod','',2),(112192,'73772','watch','block-112190','Html_box','',1),(112193,'73773','watch','block-112176-2','BlockBox','',1),(112194,'73774','watch','block-112193','checkout\\ContinueBtn','',3),(112195,'73775','watch','block-112193','Html_box','',4),(112196,'73776','watch','block-112193','Html_box','',1),(112197,'73777','watch','block-112193','checkout\\Totals','',2),(112198,'73778','watch','checkout_payment','BlockBox','',1),(112199,'73779','watch','block-112198','BlockBox','',1),(112200,'73780','watch','block-112199','checkout\\BillingAddress','',2),(112201,'73781','watch','block-112199','Html_box','',1),(112202,'73782','watch','block-112198-2','BlockBox','',1),(112203,'73783','watch','block-112202','checkout\\CreditAmount','',3),(112204,'73784','watch','block-112202','BonusActions\\widgets\\BonusPointsCheckout','',4),(112205,'73785','watch','block-112202','CouponsAndVauchers\\Checkout','',5),(112206,'73786','watch','block-112202','checkout\\PaymentMethod','',2),(112207,'73787','watch','block-112202','Html_box','',1),(112208,'73788','watch','checkout_payment','BlockBox','',2),(112209,'73789','watch','block-112208','Html_box','',1),(112210,'73790','watch','block-112208-2','checkout\\ContinueBtn','',1),(112211,'73791','watch','checkout_payment_g','BlockBox','',1),(112212,'73792','watch','block-112211','BlockBox','',1),(112213,'73793','watch','block-112212','checkout\\BillingAddress','',2),(112214,'73794','watch','block-112212','Html_box','',1),(112215,'73795','watch','block-112211-2','BlockBox','',1),(112216,'73796','watch','block-112215','checkout\\CreditAmount','',3),(112217,'73797','watch','block-112215','Html_box','',1),(112218,'73798','watch','block-112215','checkout\\PaymentMethod','',2),(112219,'73799','watch','block-112215','CouponsAndVauchers\\Checkout','',5),(112220,'73800','watch','block-112215','BonusActions\\widgets\\BonusPointsCheckout','',4),(112221,'73801','watch','checkout_payment_g','BlockBox','',2),(112222,'73802','watch','block-112221','Html_box','',1),(112223,'73803','watch','block-112221-2','checkout\\ContinueBtn','',1),(112224,'73804','watch','checkout_payment_no_shipping','BlockBox','',2),(112225,'73805','watch','block-112224','Html_box','',1),(112226,'73806','watch','block-112224-2','checkout\\ContinueBtn','',1),(112227,'73807','watch','checkout_payment_no_shipping','BlockBox','',1),(112228,'73808','watch','block-112227','BlockBox','',1),(112229,'73809','watch','block-112228','Html_box','',1),(112230,'73810','watch','block-112228','checkout\\BillingAddress','',2),(112231,'73811','watch','block-112227-2','BlockBox','',1),(112232,'73812','watch','block-112231','BonusActions\\widgets\\BonusPointsCheckout','',4),(112233,'73813','watch','block-112231','CouponsAndVauchers\\Checkout','',5),(112234,'73814','watch','block-112231','checkout\\PaymentMethod','',2),(112235,'73815','watch','block-112231','checkout\\CreditAmount','',3),(112236,'73816','watch','block-112231','Html_box','',1),(112237,'73817','watch','checkout_payment_no_shipping_g','BlockBox','',2),(112238,'73818','watch','block-112237','Html_box','',1),(112239,'73819','watch','block-112237-2','checkout\\ContinueBtn','',1),(112240,'73820','watch','checkout_payment_no_shipping_g','BlockBox','',1),(112241,'73821','watch','block-112240','BlockBox','',1),(112242,'73822','watch','block-112241','checkout\\BillingAddress','',2),(112243,'73823','watch','block-112241','Html_box','',1),(112244,'73824','watch','block-112240-2','BlockBox','',1),(112245,'73825','watch','block-112244','BonusActions\\widgets\\BonusPointsCheckout','',4),(112246,'73826','watch','block-112244','checkout\\CreditAmount','',3),(112247,'73827','watch','block-112244','checkout\\PaymentMethod','',2),(112248,'73828','watch','block-112244','Html_box','',1),(112249,'73829','watch','block-112244','CouponsAndVauchers\\Checkout','',5),(112250,'73830','watch','checkout_payment_title','Html_box','',1),(112251,'73831','watch','checkout_payment_title_g','Html_box','',1),(112252,'73832','watch','checkout_payment_title_no_shipping','Html_box','',1),(112253,'73833','watch','checkout_payment_title_no_shipping_g','Html_box','',1),(112254,'73834','watch','checkout_payment_title_q','Html_box','',1),(112255,'73835','watch','checkout_payment_title_s','Html_box','',1),(112256,'73836','watch','checkout_q','BlockBox','',1),(112257,'73837','watch','block-112256','BlockBox','',2),(112258,'73838','watch','block-112257','BlockBox','',2),(112259,'73839','watch','block-112258','BlockBox','',6),(112260,'73840','watch','block-112259','checkout\\CreateAccount','',3),(112261,'73841','watch','block-112259','quote\\Products','',2),(112262,'73842','watch','block-112258','BlockBox','',2),(112263,'73843','watch','block-112262','BlockBox','',2),(112264,'73844','watch','block-112263','checkout\\ShippingChoice','',1),(112265,'73845','watch','block-112262','Neighbour\\Checkout','',4),(112266,'73846','watch','block-112262','Html_box','',1),(112267,'73847','watch','block-112262','BlockBox','',3),(112268,'73848','watch','block-112267','BlockBox','',1),(112269,'73849','watch','block-112268','checkout\\ContactInformation','',4),(112270,'73850','watch','block-112268','checkout\\ShippingAddress','',2),(112271,'73851','watch','block-112268','Html_box','',3),(112272,'73852','watch','block-112267-2','BlockBox','',1),(112273,'73853','watch','block-112272','checkout\\Shipping','',2),(112274,'73854','watch','block-112272','Html_box','',1),(112275,'73855','watch','block-112272','DelayedDespatch\\Checkout','',3),(112276,'73856','watch','block-112258','BlockBox','',5),(112277,'73857','watch','block-112276','Html_box','',1),(112278,'73858','watch','block-112276','checkout\\Comments','',2),(112279,'73860','watch','block-112258','BlockBox','',3),(112280,'73861','watch','block-112279','Html_box','',1),(112281,'73862','watch','block-112279','BlockBox','',2),(112282,'73863','watch','block-112281','checkout\\BillingAddress','',2),(112283,'73864','watch','block-112281','Html_box','',1),(112284,'73865','watch','block-112281-2','BlockBox','',1),(112285,'73866','watch','block-112284','checkout\\PaymentMethod','',2),(112286,'73867','watch','block-112284','Html_box','',1),(112287,'73868','watch','block-112257-2','BlockBox','',1),(112288,'73869','watch','block-112287','Html_box','',1),(112289,'73870','watch','block-112287','Html_box','',5),(112290,'73871','watch','block-112287','checkout\\Totals','',2),(112291,'73872','watch','block-112287','checkout\\ContinueBtn','',3),(112292,'115996','watch','block-112287','checkout\\Terms','',4),(112293,'73873','watch','checkout_s','BlockBox','',1),(112294,'73874','watch','block-112293','BlockBox','',2),(112295,'73875','watch','block-112294','BlockBox','',2),(112296,'73876','watch','block-112295','checkout\\Gdpr','',1),(112297,'73877','watch','block-112295','BlockBox','',6),(112298,'73878','watch','block-112297','sample\\Products','',1),(112299,'73879','watch','block-112297','checkout\\CreateAccount','',3),(112300,'73880','watch','block-112295','BlockBox','',2),(112301,'73881','watch','block-112300','Html_box','',1),(112302,'73882','watch','block-112300','Neighbour\\Checkout','',4),(112303,'73883','watch','block-112300','BlockBox','',2),(112304,'73884','watch','block-112303','checkout\\ShippingChoice','',1),(112305,'73885','watch','block-112300','BlockBox','',3),(112306,'73886','watch','block-112305','BlockBox','',1),(112307,'73887','watch','block-112306','checkout\\ShippingAddress','',2),(112308,'73888','watch','block-112306','checkout\\ContactInformation','',4),(112309,'73889','watch','block-112306','Html_box','',3),(112310,'73890','watch','block-112305-2','BlockBox','',1),(112311,'73891','watch','block-112310','checkout\\Shipping','',2),(112312,'73892','watch','block-112310','DelayedDespatch\\Checkout','',3),(112313,'73893','watch','block-112310','Html_box','',1),(112314,'73894','watch','block-112295','BlockBox','',3),(112315,'73895','watch','block-112314','BlockBox','',2),(112316,'73896','watch','block-112315','Html_box','',1),(112317,'73897','watch','block-112315','checkout\\BillingAddress','',2),(112318,'73898','watch','block-112315-2','BlockBox','',1),(112319,'73899','watch','block-112318','Html_box','',1),(112320,'73900','watch','block-112318','checkout\\PaymentMethod','',2),(112321,'73901','watch','block-112314','Html_box','',1),(112322,'73902','watch','block-112295','BlockBox','',5),(112323,'73903','watch','block-112322','Html_box','',1),(112324,'73904','watch','block-112322','checkout\\Comments','',2),(112325,'73905','watch','block-112295','BlockBox','',4),(112326,'73906','watch','block-112325','BlockBox','',2),(112327,'73907','watch','block-112326','CouponsAndVauchers\\Checkout','',1),(112328,'73908','watch','block-112326-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(112329,'73909','watch','block-112326-2','checkout\\CreditAmount','',1),(112330,'73910','watch','block-112325','Html_box','',1),(112331,'73911','watch','block-112294-2','BlockBox','',1),(112332,'73912','watch','block-112331','checkout\\Totals','',2),(112333,'73913','watch','block-112331','Html_box','',5),(112334,'73914','watch','block-112331','Html_box','',1),(112335,'73915','watch','block-112331','checkout\\ContinueBtn','',3),(112336,'115998','watch','block-112331','checkout\\Terms','',4),(112337,'73916','watch','checkout_step_bottom','Html_box','',1),(112338,'73917','watch','checkout_step_bottom','cart\\Products','',2),(112339,'73918','watch','checkout_step_bottom','checkout\\Totals','',3),(112340,'73919','watch','checkout_step_bottom_g','checkout\\Totals','',3),(112341,'73920','watch','checkout_step_bottom_g','quote\\Products','',2),(112342,'73921','watch','checkout_step_bottom_g','Html_box','',1),(112343,'73923','watch','checkout_step_bottom_no_shipping','Html_box','',1),(112344,'73924','watch','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(112345,'73927','watch','checkout_step_bottom_no_shipping','cart\\Products','',2),(112346,'73922','watch','checkout_step_bottom_no_shipping_g','Html_box','',1),(112347,'73925','watch','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(112348,'73926','watch','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(112349,'73928','watch','communication','BlockBox','',1),(112350,'73929','watch','block-112349','Html_box','',2),(112351,'73930','watch','block-112349','Communication\\NewTopicButton','',1),(112352,'73931','watch','block-112349','Communication\\Topic','',3),(112353,'94704','watch','compare','BlockBox','',1),(112354,'94705','watch','block-112353','catalog\\Compare','',1),(112355,'94706','watch','compare_products','BlockBox','',2),(112356,'94707','watch','block-112355','productListing\\rating','',4),(112357,'94708','watch','block-112355','productListing\\model','',5),(112358,'94709','watch','block-112355','productListing\\compare','',1),(112359,'94710','watch','block-112355','BlockBox','',2),(112360,'94711','watch','block-112359','productListing\\image','',1),(112361,'94712','watch','block-112359-2','productListing\\name','',2),(112362,'94713','watch','block-112355','BlockBox','',3),(112363,'94714','watch','block-112362','productListing\\price','',1),(112364,'94715','watch','block-112362-2','productListing\\buyButton','',1),(112365,'73932','watch','confirmation','BlockBox','',1),(112366,'73933','watch','block-112365','BlockBox','',2),(112367,'73934','watch','block-112366','BlockBox','',2),(112368,'73935','watch','block-112367','BlockBox','',3),(112369,'73936','watch','block-112368','checkout\\EditBtn','',2),(112370,'73937','watch','block-112368','cart\\Products','',3),(112371,'73938','watch','block-112368','Html_box','',1),(112372,'73939','watch','block-112367','BlockBox','',2),(112373,'73940','watch','block-112372','checkout\\EditBtn','',2),(112374,'73941','watch','block-112372','Html_box','',1),(112375,'73942','watch','block-112372','checkout\\CommentsConfirm','',3),(112376,'73943','watch','block-112367','BlockBox','',1),(112377,'73944','watch','block-112376','BlockBox','',1),(112378,'73945','watch','block-112377','checkout\\EditBtn','',6),(112379,'73946','watch','block-112377','DelayedDespatch\\CheckoutConfirm','',8),(112380,'73947','watch','block-112377','Html_box','',9),(112381,'73948','watch','block-112377','checkout\\EditBtn','',10),(112382,'73949','watch','block-112377','Html_box','',5),(112383,'73950','watch','block-112377','checkout\\ShippingConfirm','',7),(112384,'73951','watch','block-112377','Html_box','',1),(112385,'73952','watch','block-112377','checkout\\EditBtn','',3),(112386,'73953','watch','block-112377','checkout\\ContactConfirm','',11),(112387,'73954','watch','block-112377','Html_box','',2),(112388,'73955','watch','block-112377','checkout\\ShippingAddressConfirm','',4),(112389,'73956','watch','block-112376-2','BlockBox','',1),(112390,'73957','watch','block-112389','checkout\\EditBtn','',6),(112391,'73958','watch','block-112389','checkout\\EditBtn','',3),(112392,'73959','watch','block-112389','checkout\\PaymentMethodConfirm','',7),(112393,'73960','watch','block-112389','Html_box','',5),(112394,'73961','watch','block-112389','Html_box','',1),(112395,'73962','watch','block-112389','checkout\\BillingAddressConfirm','',4),(112396,'73963','watch','block-112389','Html_box','',2),(112397,'73964','watch','block-112366','UploadCustomerId\\UploadCustomerIdForm','',1),(112398,'73965','watch','block-112366-2','BlockBox','',1),(112399,'73966','watch','block-112398','Html_box','',1),(112400,'73967','watch','block-112398','checkout\\ConfirmBtn','',3),(112401,'73968','watch','block-112398','checkout\\Totals','',2),(112402,'73969','watch','block-112365','Html_box','',1),(112403,'73970','watch','confirmation_free_s','BlockBox','',1),(112404,'73971','watch','block-112403','BlockBox','',2),(112405,'73972','watch','block-112404','BlockBox','',1),(112406,'73973','watch','block-112405','BlockBox','',2),(112407,'73974','watch','block-112406','checkout\\CommentsConfirm','',3),(112408,'73975','watch','block-112406','checkout\\EditBtn','',2),(112409,'73976','watch','block-112406','Html_box','',1),(112410,'73977','watch','block-112405','BlockBox','',3),(112411,'73978','watch','block-112410','checkout\\EditBtn','',3),(112412,'73979','watch','block-112410','Html_box','',1),(112413,'73980','watch','block-112410','sample\\Products','',2),(112414,'73981','watch','block-112405','BlockBox','',1),(112415,'73982','watch','block-112414','BlockBox','',1),(112416,'73983','watch','block-112415','checkout\\EditBtn','',3),(112417,'73984','watch','block-112415','checkout\\ShippingConfirm','',7),(112418,'73985','watch','block-112415','Html_box','',5),(112419,'73986','watch','block-112415','checkout\\EditBtn','',6),(112420,'73987','watch','block-112415','Html_box','',2),(112421,'73988','watch','block-112415','checkout\\ShippingAddressConfirm','',4),(112422,'73989','watch','block-112414-2','BlockBox','',1),(112423,'73990','watch','block-112422','checkout\\ContactConfirm','',3),(112424,'73991','watch','block-112422','DelayedDespatch\\CheckoutConfirm','',4),(112425,'73992','watch','block-112422','checkout\\EditBtn','',2),(112426,'73993','watch','block-112422','Html_box','',1),(112427,'73994','watch','block-112404-2','BlockBox','',1),(112428,'73995','watch','block-112427','checkout\\ConfirmBtn','',3),(112429,'73996','watch','block-112403','Html_box','',1),(112430,'73997','watch','confirmation_no_shipping','BlockBox','',1),(112431,'73998','watch','block-112430','Html_box','',1),(112432,'73999','watch','block-112430','BlockBox','',2),(112433,'74000','watch','block-112432','BlockBox','',1),(112434,'74001','watch','block-112433','BlockBox','',1),(112435,'74002','watch','block-112434','BlockBox','',1),(112436,'74003','watch','block-112435','checkout\\EditBtn','',10),(112437,'74004','watch','block-112435','Html_box','',9),(112438,'74005','watch','block-112435','checkout\\ContactConfirm','',11),(112439,'74006','watch','block-112434-2','BlockBox','',1),(112440,'74007','watch','block-112439','checkout\\PaymentMethodConfirm','',7),(112441,'74008','watch','block-112439','checkout\\EditBtn','',6),(112442,'74009','watch','block-112439','Html_box','',5),(112443,'74010','watch','block-112439','Html_box','',1),(112444,'74011','watch','block-112439','checkout\\EditBtn','',3),(112445,'74012','watch','block-112439','checkout\\BillingAddressConfirm','',4),(112446,'74013','watch','block-112439','Html_box','',2),(112447,'74014','watch','block-112433','BlockBox','',2),(112448,'74015','watch','block-112447','Html_box','',1),(112449,'74016','watch','block-112447','checkout\\CommentsConfirm','',3),(112450,'74017','watch','block-112447','checkout\\EditBtn','',2),(112451,'74018','watch','block-112433','BlockBox','',3),(112452,'74019','watch','block-112451','Html_box','',1),(112453,'74020','watch','block-112451','checkout\\EditBtn','',2),(112454,'74021','watch','block-112451','cart\\Products','',3),(112455,'74022','watch','block-112432-2','BlockBox','',1),(112456,'74023','watch','block-112455','checkout\\ConfirmBtn','',3),(112457,'74024','watch','block-112455','Html_box','',1),(112458,'74025','watch','block-112455','checkout\\Totals','',2),(112459,'74026','watch','confirmation_no_shipping_q','BlockBox','',2),(112460,'74027','watch','block-112459','Html_box','',1),(112461,'74028','watch','block-112459','BlockBox','',2),(112462,'74029','watch','block-112461','BlockBox','',1),(112463,'74030','watch','block-112462','BlockBox','',2),(112464,'74031','watch','block-112463','Html_box','',1),(112465,'74032','watch','block-112463','checkout\\CommentsConfirm','',3),(112466,'74033','watch','block-112463','checkout\\EditBtn','',2),(112467,'74034','watch','block-112462','BlockBox','',1),(112468,'74035','watch','block-112467','BlockBox','',1),(112469,'74036','watch','block-112468','checkout\\EditBtn','',5),(112470,'74037','watch','block-112468','checkout\\ContactConfirm','',6),(112471,'74038','watch','block-112468','checkout\\PaymentMethodConfirm','',3),(112472,'74039','watch','block-112468','checkout\\EditBtn','',2),(112473,'74040','watch','block-112468','Html_box','',4),(112474,'74041','watch','block-112468','Html_box','',1),(112475,'74042','watch','block-112467-2','BlockBox','',1),(112476,'74043','watch','block-112475','checkout\\BillingAddressConfirm','',4),(112477,'74044','watch','block-112475','checkout\\EditBtn','',3),(112478,'74045','watch','block-112475','Html_box','',2),(112479,'74046','watch','block-112462','BlockBox','',3),(112480,'74047','watch','block-112479','checkout\\EditBtn','',2),(112481,'74048','watch','block-112479','Html_box','',1),(112482,'74049','watch','block-112479','quote\\Products','',3),(112483,'74050','watch','block-112461-2','BlockBox','',1),(112484,'74051','watch','block-112483','checkout\\ConfirmBtn','',3),(112485,'74052','watch','block-112483','checkout\\Totals','',2),(112486,'74053','watch','block-112483','Html_box','',1),(112487,'74054','watch','confirmation_q','BlockBox','',1),(112488,'74055','watch','block-112487','Html_box','',1),(112489,'74056','watch','block-112487','BlockBox','',2),(112490,'74057','watch','block-112489','BlockBox','',1),(112491,'74058','watch','block-112490','BlockBox','',3),(112492,'74059','watch','block-112491','quote\\Products','',3),(112493,'74060','watch','block-112491','Html_box','',1),(112494,'74061','watch','block-112491','checkout\\EditBtn','',2),(112495,'74062','watch','block-112490','BlockBox','',1),(112496,'74063','watch','block-112495','BlockBox','',1),(112497,'74064','watch','block-112496','Html_box','',1),(112498,'74065','watch','block-112496','checkout\\EditBtn','',10),(112499,'74066','watch','block-112496','Html_box','',2),(112500,'74067','watch','block-112496','checkout\\ContactConfirm','',11),(112501,'74068','watch','block-112496','checkout\\ShippingAddressConfirm','',4),(112502,'74069','watch','block-112496','checkout\\ShippingConfirm','',7),(112503,'74070','watch','block-112496','checkout\\EditBtn','',3),(112504,'74071','watch','block-112496','DelayedDespatch\\CheckoutConfirm','',8),(112505,'74072','watch','block-112496','Html_box','',9),(112506,'74073','watch','block-112496','Html_box','',5),(112507,'74074','watch','block-112496','checkout\\EditBtn','',6),(112508,'74075','watch','block-112495-2','BlockBox','',1),(112509,'74076','watch','block-112508','checkout\\EditBtn','',3),(112510,'74077','watch','block-112508','checkout\\BillingAddressConfirm','',4),(112511,'74078','watch','block-112508','checkout\\PaymentMethodConfirm','',7),(112512,'74079','watch','block-112508','Html_box','',1),(112513,'74080','watch','block-112508','Html_box','',2),(112514,'74081','watch','block-112508','checkout\\EditBtn','',6),(112515,'74082','watch','block-112508','Html_box','',5),(112516,'74083','watch','block-112490','BlockBox','',2),(112517,'74084','watch','block-112516','checkout\\CommentsConfirm','',3),(112518,'74085','watch','block-112516','Html_box','',1),(112519,'74086','watch','block-112516','checkout\\EditBtn','',2),(112520,'74087','watch','block-112489-2','BlockBox','',1),(112521,'74088','watch','block-112520','Html_box','',1),(112522,'74089','watch','block-112520','checkout\\Totals','',2),(112523,'74090','watch','block-112520','checkout\\ConfirmBtn','',3),(112524,'74091','watch','confirmation_s','BlockBox','',1),(112525,'74092','watch','block-112524','BlockBox','',2),(112526,'74093','watch','block-112525','BlockBox','',1),(112527,'74094','watch','block-112526','BlockBox','',1),(112528,'74095','watch','block-112527','BlockBox','',1),(112529,'74096','watch','block-112528','checkout\\ShippingAddressConfirm','',4),(112530,'74097','watch','block-112528','checkout\\EditBtn','',3),(112531,'74098','watch','block-112528','Html_box','',2),(112532,'74099','watch','block-112528','DelayedDespatch\\CheckoutConfirm','',8),(112533,'74100','watch','block-112528','checkout\\ShippingConfirm','',7),(112534,'74101','watch','block-112528','Html_box','',1),(112535,'74102','watch','block-112528','Html_box','',5),(112536,'74103','watch','block-112528','Html_box','',9),(112537,'74104','watch','block-112528','checkout\\ContactConfirm','',11),(112538,'74105','watch','block-112528','checkout\\EditBtn','',6),(112539,'74106','watch','block-112528','checkout\\EditBtn','',10),(112540,'74107','watch','block-112527-2','BlockBox','',1),(112541,'74108','watch','block-112540','Html_box','',2),(112542,'74109','watch','block-112540','checkout\\BillingAddressConfirm','',4),(112543,'74110','watch','block-112540','checkout\\EditBtn','',3),(112544,'74111','watch','block-112540','checkout\\PaymentMethodConfirm','',7),(112545,'74112','watch','block-112540','checkout\\EditBtn','',6),(112546,'74113','watch','block-112540','Html_box','',1),(112547,'74114','watch','block-112540','Html_box','',5),(112548,'74115','watch','block-112526','BlockBox','',3),(112549,'74116','watch','block-112548','checkout\\EditBtn','',3),(112550,'74117','watch','block-112548','Html_box','',1),(112551,'74118','watch','block-112548','sample\\Products','',2),(112552,'74119','watch','block-112526','BlockBox','',2),(112553,'74120','watch','block-112552','Html_box','',1),(112554,'74121','watch','block-112552','checkout\\EditBtn','',2),(112555,'74122','watch','block-112552','checkout\\CommentsConfirm','',3),(112556,'74123','watch','block-112525-2','BlockBox','',1),(112557,'74124','watch','block-112556','checkout\\Totals','',2),(112558,'74125','watch','block-112556','checkout\\ConfirmBtn','',3),(112559,'74126','watch','block-112556','Html_box','',1),(112560,'74127','watch','block-112524','Html_box','',1),(112561,'74128','watch','contact','BlockBox','',1),(112562,'74132','watch','block-112561','info\\Title','',1),(112563,'74133','watch','block-112561','BlockBox','',3),(112564,'74134','watch','block-112563','contact\\ContactForm','',1),(112565,'74135','watch','block-112563-2','contact\\Contacts','',1),(112566,'74136','watch','created_success','BlockBox','',1),(112567,'74137','watch','block-112566','Html_box','',1),(112568,'74138','watch','block-112566','Html_box','',2),(112569,'74139','watch','credit_note','invoice\\Container','',1),(112570,'74140','watch','block-112569','BlockBox','',5),(112571,'74141','watch','block-112570','invoice\\StoreAddress','',8),(112572,'74142','watch','block-112570','Text','',1),(112573,'74143','watch','block-112570-2','Text','',2),(112574,'74144','watch','block-112570-2','Logo','',1),(112575,'74145','watch','block-112570-3','Text','',1),(112576,'74146','watch','block-112570-3','BlockBox','',3),(112577,'74147','watch','block-112576','Text','',1),(112578,'74148','watch','block-112576-2','invoice\\StoreEmail','',1),(112579,'74149','watch','block-112570-3','BlockBox','',2),(112580,'74150','watch','block-112579','Text','',1),(112581,'74151','watch','block-112579-2','invoice\\StorePhone','',1),(112582,'74152','watch','block-112569','invoice\\Products','',3),(112583,'74153','watch','block-112569','BlockBox','',1),(112584,'74154','watch','block-112583','Logo','',1),(112585,'74155','watch','block-112583-2','BlockBox','',4),(112586,'74156','watch','block-112585','Text','',1),(112587,'74157','watch','block-112585-2','invoice\\StoreSite','',1),(112588,'74158','watch','block-112583-2','BlockBox','',2),(112589,'74159','watch','block-112588','Text','',1),(112590,'74160','watch','block-112588-2','invoice\\StorePhone','',1),(112591,'74161','watch','block-112583-2','BlockBox','',3),(112592,'74162','watch','block-112591','Text','',1),(112593,'74163','watch','block-112591-2','invoice\\StoreEmail','',1),(112594,'74164','watch','block-112583-2','BlockBox','',1),(112595,'74165','watch','block-112594','invoice\\StoreAddress','',1),(112596,'74166','watch','block-112569','BlockBox','',4),(112597,'74167','watch','block-112596','BlockBox','',1),(112598,'74168','watch','block-112597','invoice\\ShippingAddress','',2),(112599,'74169','watch','block-112597','Text','',1),(112600,'74170','watch','block-112596-2','BlockBox','',1),(112601,'74171','watch','block-112569','BlockBox','',2),(112602,'74172','watch','block-112601','BlockBox','',7),(112603,'74173','watch','block-112602','BlockBox','',1),(112604,'74174','watch','block-112603','Text','',1),(112605,'74175','watch','block-112603','invoice\\BillingAddress','',2),(112606,'74176','watch','block-112602-2','BlockBox','',1),(112607,'74177','watch','block-112606','invoice\\CustomerPhone','',4),(112608,'74178','watch','block-112606','Text','',1),(112609,'74179','watch','block-112606','Text','',3),(112610,'74180','watch','block-112606','invoice\\CustomerName','',2),(112611,'74181','watch','block-112606','invoice\\CustomerEmail','',6),(112612,'74182','watch','block-112606','Text','',5),(112613,'74183','watch','block-112601','BlockBox','',8),(112614,'74184','watch','block-112613','BlockBox','',1),(112615,'74185','watch','block-112614','invoice\\ShippingMethod','',2),(112616,'74186','watch','block-112614','Text','',1),(112617,'74187','watch','block-112613-2','BlockBox','',1),(112618,'74188','watch','block-112617','Text','',1),(112619,'74189','watch','block-112617','invoice\\ShippingMethod','',2),(112620,'74190','watch','block-112601-2','invoice\\OrderId','',1),(112621,'74191','watch','block-112601-2','Text','',2),(112622,'74192','watch','block-112601-2','invoice\\PaymentDate','',3),(112623,'74193','watch','delivery-location','DeliveryLocation\\FeaturedList','',6),(112624,'74194','watch','delivery-location','DeliveryLocation\\LocationLongDescription','',5),(112625,'74195','watch','delivery-location','DeliveryLocation\\LocationList','',7),(112626,'74196','watch','delivery-location','DeliveryLocation\\LocationTitle','',2),(112627,'74197','watch','delivery-location','DeliveryLocation\\LocationProducts','',8),(112628,'74198','watch','delivery-location','DeliveryLocation\\LocationDescription','',3),(112629,'74199','watch','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(112630,'74200','watch','delivery-location-default','DeliveryLocation\\TopLocationList','',2),(112631,'74201','watch','delivery-location-default','Heading','',1),(112632,'94716','watch','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(112633,'94717','watch','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(112634,'94718','watch','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(112635,'94719','watch','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(112636,'94720','watch','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(112637,'94721','watch','delivery_loc_2','DeliveryLocation\\LocationList','',7),(112638,'94722','watch','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(112639,'74202','watch','email','email\\BlockBox','',1),(112640,'74203','watch','block-112639','email\\BlockBox','',1),(112641,'74204','watch','block-112640','Copyright','',4),(112642,'74205','watch','block-112640','email\\Content','',3),(112643,'74206','watch','block-112640','email\\BlockBox','',2),(112644,'74207','watch','block-112643','email\\Title','',1),(112645,'74208','watch','block-112643-2','email\\Date','',1),(112646,'74209','watch','block-112640','Logo','',1),(112647,'74210','watch','email_2','email\\BlockBox','',1),(112648,'74211','watch','block-112647','email\\BlockBox','',1),(112649,'74212','watch','block-112648','Copyright','',4),(112650,'74213','watch','block-112648','Logo','',1),(112651,'74214','watch','block-112648','email\\Content','',3),(112652,'74215','watch','block-112648','email\\BlockBox','',2),(112653,'74216','watch','block-112652','email\\Title','',1),(112654,'74217','watch','block-112652-2','email\\Date','',1),(112655,'74218','watch','email_3','email\\BlockBox','',1),(112656,'74219','watch','block-112655','email\\BlockBox','',1),(112657,'74220','watch','block-112656','email\\BlockBox','',2),(112658,'74221','watch','block-112657','email\\Content','',2),(112659,'74222','watch','block-112657','email\\BlockBox','',1),(112660,'74223','watch','block-112659','email\\Title','',1),(112661,'74224','watch','block-112659-2','email\\Date','',1),(112662,'74225','watch','block-112656','Copyright','',3),(112663,'74226','watch','block-112656','Logo','',1),(112664,'74227','watch','email_4','email\\BlockBox','',1),(112665,'74228','watch','block-112664','email\\BlockBox','',1),(112666,'74229','watch','block-112665','Copyright','',2),(112667,'74230','watch','block-112665','email\\BlockBox','',1),(112668,'74231','watch','block-112667','email\\BlockBox','',1),(112669,'74232','watch','block-112668','Logo','',1),(112670,'74233','watch','block-112668-2','email\\Date','',2),(112671,'74234','watch','block-112668-2','email\\Title','',1),(112672,'74235','watch','block-112667','email\\Content','',2),(112673,'74236','watch','footer','BlockBox','',1),(112674,'74237','watch','block-112673','BlockBox','',1),(112675,'74238','watch','block-112674','BlockBox','',1),(112676,'74239','watch','block-112675','Menu','footer3',3),(112677,'1695906739.5696','watch','block-112675','Html_box','',2),(112678,'74241','watch','block-112674-2','BlockBox','',1),(112679,'74243','watch','block-112678','Menu','footer1',3),(112680,'1695906751.0591','watch','block-112678','Html_box','',2),(112681,'74244','watch','block-112674-3','BlockBox','',1),(112682,'74246','watch','block-112681','Menu','footer2',3),(112683,'1695906756.0887','watch','block-112681','Html_box','',2),(112684,'74247','watch','block-112674-4','BlockBox','',1),(112685,'74248','watch','block-112684','Contacts','',4),(112686,'74249','watch','block-112684','Contacts','',3),(112687,'1695906761.6568','watch','block-112684','Html_box','',2),(112688,'74256','watch','block-112673','BlockBox','footer-content',4),(112689,'74257','watch','block-112688','Copyright','',1),(112690,'74258','watch','block-112688-2','invoice\\StoreAddress','',1),(112691,'94723','watch','for_menu','BlockBox','',1),(112692,'94724','watch','block-112691','Html_box','',1),(112693,'94725','watch','block-112691-2','Languages','',1),(112694,'94726','watch','for_menu','BlockBox','',3),(112695,'94727','watch','block-112694','Html_box','',1),(112696,'94728','watch','block-112694-2','Currencies','',1),(112697,'74263','watch','gift','BlockBox','',1),(112698,'74264','watch','block-112697','BlockBox','',3),(112699,'74265','watch','block-112698','BlockBox','',1),(112700,'74266','watch','block-112699','gift\\Card','',1),(112701,'74267','watch','block-112698-2','gift\\Form','',2),(112702,'74268','watch','block-112698-2','Text','',1),(112703,'74269','watch','block-112697','info\\Title','',1),(112704,'74270','watch','gift_card','BlockBox','',1),(112705,'74271','watch','block-112704','BlockBox','',11),(112706,'74272','watch','block-112705','invoice\\StoreEmail','',3),(112707,'74273','watch','block-112705','Text','',1),(112708,'74274','watch','block-112705','invoice\\StorePhone','',2),(112709,'74275','watch','block-112704','Text','',8),(112710,'74276','watch','block-112704','Text','',3),(112711,'74277','watch','block-112704','BlockBox','',10),(112712,'74278','watch','block-112711','Text','',1),(112713,'74279','watch','block-112711-2','gift\\CodeView','',1),(112714,'74280','watch','block-112704','gift\\MessageView','',7),(112715,'74281','watch','block-112704','gift\\AmountView','',5),(112716,'74282','watch','block-112704','Text','',6),(112717,'74284','watch','block-112704','Logo','',1),(112718,'74285','watch','block-112704','Text','',4),(112719,'74286','watch','block-112704','Text','',9),(112720,'74287','watch','gift_card_2','BlockBox','',1),(112721,'74288','watch','block-112720','gift\\AmountView','',3),(112722,'74289','watch','block-112720','BlockBox','',8),(112723,'74290','watch','block-112722','Text','',1),(112724,'74291','watch','block-112722-2','gift\\CodeView','',1),(112725,'74292','watch','block-112720','BlockBox','',9),(112726,'74293','watch','block-112725','invoice\\StoreEmail','',3),(112727,'74294','watch','block-112725','Text','',1),(112728,'74295','watch','block-112725','invoice\\StorePhone','',2),(112729,'74296','watch','block-112720','gift\\MessageView','',5),(112730,'74297','watch','block-112720','Text','',4),(112731,'74298','watch','block-112720','Text','',7),(112732,'74299','watch','block-112720','Text','',2),(112733,'74300','watch','block-112720','Text','',6),(112734,'74301','watch','block-112720','Text','',1),(112735,'94729','watch','gift_card_2_pdf','BlockBox','',1),(112736,'94730','watch','block-112735','BlockBox','',12),(112737,'94731','watch','block-112736','invoice\\StoreEmail','',4),(112738,'94732','watch','block-112736','invoice\\StorePhone','',3),(112739,'94733','watch','block-112736','Html_box','',1),(112740,'94734','watch','block-112735','BlockBox','',11),(112741,'94735','watch','block-112740','Html_box','',1),(112742,'94736','watch','block-112740-2','gift\\CodeViewPdf','',1),(112743,'94737','watch','block-112735','BlockBox','',1),(112744,'94738','watch','block-112743','Text','',4),(112745,'94739','watch','block-112743','Html_box','',1),(112746,'94740','watch','block-112743','Html_box','',2),(112747,'94741','watch','block-112743','gift\\AmountViewPdf','',3),(112748,'94742','watch','block-112743','gift\\MessageViewPdf','',5),(112749,'94743','watch','block-112743','Html_box','',7),(112750,'94744','watch','block-112743','Html_box','',6),(112751,'94746','watch','gift_card_pdf','BlockBox','',1),(112752,'94747','watch','block-112751','BlockBox','',12),(112753,'94748','watch','block-112752','invoice\\StoreEmail','',4),(112754,'94749','watch','block-112752','invoice\\StorePhone','',3),(112755,'94750','watch','block-112752','Html_box','',1),(112756,'94751','watch','block-112751','BlockBox','',11),(112757,'94752','watch','block-112756','Html_box','',1),(112758,'94753','watch','block-112756-2','gift\\CodeViewPdf','',1),(112759,'94754','watch','block-112751','BlockBox','',1),(112760,'94755','watch','block-112759','Text','',5),(112761,'94757','watch','block-112759','Html_box','',3),(112762,'94758','watch','block-112759','gift\\AmountViewPdf','',4),(112763,'94759','watch','block-112759','gift\\MessageViewPdf','',6),(112764,'94760','watch','block-112759','Html_box','',8),(112765,'94761','watch','block-112759','Html_box','',7),(112766,'1707902674.2595','watch','block-112759','Logo','',2),(112767,'94762','watch','gift_card_pdf','Import','',1),(112768,'74302','watch','gift_certificate','BlockBox','',1),(112769,'74303','watch','block-112768','account\\ApplyCertificate','',2),(112770,'74304','watch','block-112768','Html_box','',1),(112771,'74305','watch','gigt_card_3','BlockBox','',1),(112772,'74306','watch','block-112771','BlockBox','',8),(112773,'74307','watch','block-112772','Text','',1),(112774,'74308','watch','block-112772-2','gift\\CodeView','',1),(112775,'74309','watch','block-112771','Text','',6),(112776,'74310','watch','block-112771','Text','',1),(112777,'74311','watch','block-112771','BlockBox','',9),(112778,'74312','watch','block-112777','Text','',1),(112779,'74313','watch','block-112777','invoice\\StoreEmail','',3),(112780,'74314','watch','block-112777','invoice\\StorePhone','',2),(112781,'74315','watch','block-112771','gift\\MessageView','',5),(112782,'74316','watch','block-112771','Text','',2),(112783,'74317','watch','block-112771','Text','',4),(112784,'74318','watch','block-112771','gift\\AmountView','',3),(112785,'74319','watch','block-112771','Text','',7),(112786,'94763','watch','gigt_card_3_pdf','BlockBox','',1),(112787,'94764','watch','block-112786','BlockBox','',12),(112788,'94765','watch','block-112787','invoice\\StoreEmail','',4),(112789,'94766','watch','block-112787','invoice\\StorePhone','',3),(112790,'94767','watch','block-112787','Html_box','',1),(112791,'94768','watch','block-112786','BlockBox','',11),(112792,'94769','watch','block-112791','Html_box','',1),(112793,'94770','watch','block-112791-2','gift\\CodeViewPdf','',1),(112794,'94771','watch','block-112786','BlockBox','',1),(112795,'94772','watch','block-112794','Text','',4),(112796,'94773','watch','block-112794','Html_box','',1),(112797,'94774','watch','block-112794','Html_box','',2),(112798,'94775','watch','block-112794','gift\\AmountViewPdf','',3),(112799,'94776','watch','block-112794','gift\\MessageViewPdf','',5),(112800,'94777','watch','block-112794','Html_box','',7),(112801,'94778','watch','block-112794','Html_box','',6),(112821,'74346','watch','info','BlockBox','info-content',1),(112822,'74347','watch','block-112821','info\\DescriptionShort','',2),(112823,'74348','watch','block-112821','info\\Content','',4),(112824,'74349','watch','block-112821','info\\Title','',1),(112825,'74350','watch','block-112821','info\\Image','',3),(112826,'74351','watch','invoice','invoice\\Container','',1),(112827,'74352','watch','block-112826','BlockBox','',3),(112828,'74353','watch','block-112827','BlockBox','',8),(112829,'74354','watch','block-112828','BlockBox','',1),(112830,'74355','watch','block-112829','invoice\\ShippingMethod','',2),(112831,'74356','watch','block-112829','Text','',1),(112832,'74357','watch','block-112828-2','BlockBox','',1),(112833,'74358','watch','block-112832','Text','',1),(112834,'74359','watch','block-112832','invoice\\ShippingMethod','',2),(112835,'74360','watch','block-112827','BlockBox','',7),(112836,'74361','watch','block-112835','BlockBox','',1),(112837,'74362','watch','block-112836','Text','',1),(112838,'74363','watch','block-112836','invoice\\BillingAddress','',2),(112839,'74364','watch','block-112835-2','BlockBox','',1),(112840,'74365','watch','block-112839','Text','',5),(112841,'74366','watch','block-112839','invoice\\CustomerName','',2),(112842,'74367','watch','block-112839','invoice\\CustomerPhone','',4),(112843,'74368','watch','block-112839','Text','',1),(112844,'74369','watch','block-112839','Text','',3),(112845,'74370','watch','block-112839','invoice\\CustomerEmail','',6),(112846,'74371','watch','block-112827-2','invoice\\PaymentMethod','',5),(112847,'74372','watch','block-112827-2','Text','',4),(112848,'74373','watch','block-112827-2','Text','',2),(112849,'74374','watch','block-112827-2','invoice\\OrderId','',1),(112850,'74375','watch','block-112827-2','invoice\\PaymentDate','',3),(112851,'74376','watch','block-112827-2','invoice\\OrderBarcode','',6),(112852,'74377','watch','block-112826','BlockBox','',6),(112853,'74378','watch','block-112852','invoice\\StoreAddress','',8),(112854,'74379','watch','block-112852','Text','',1),(112855,'74380','watch','block-112852-2','Text','',2),(112856,'74381','watch','block-112852-2','Logo','',1),(112857,'74382','watch','block-112852-3','BlockBox','',3),(112858,'74383','watch','block-112857','Text','',1),(112859,'74384','watch','block-112857-2','invoice\\StoreEmail','',1),(112860,'74385','watch','block-112852-3','BlockBox','',2),(112861,'74386','watch','block-112860','Text','',1),(112862,'74387','watch','block-112860-2','invoice\\StorePhone','',1),(112863,'74388','watch','block-112852-3','Text','',1),(112864,'74389','watch','block-112826','invoice\\Products','',4),(112865,'74390','watch','block-112826','BlockBox','',5),(112866,'74391','watch','block-112865','BlockBox','',1),(112867,'74392','watch','block-112866','invoice\\ShippingAddress','',2),(112868,'74393','watch','block-112866','Text','',1),(112869,'74394','watch','block-112865-2','BlockBox','',1),(112870,'74395','watch','block-112869','invoice\\Totals','',1),(112871,'74396','watch','block-112826','BlockBox','',2),(112872,'74397','watch','block-112871','Logo','',1),(112873,'74398','watch','block-112871-2','BlockBox','',4),(112874,'74399','watch','block-112873','Text','',1),(112875,'74400','watch','block-112873-2','invoice\\StoreSite','',1),(112876,'74401','watch','block-112871-2','BlockBox','',3),(112877,'74402','watch','block-112876','Text','',1),(112878,'74403','watch','block-112876-2','invoice\\StoreEmail','',1),(112879,'74404','watch','block-112871-2','BlockBox','',1),(112880,'74405','watch','block-112879','invoice\\StoreAddress','',3),(112881,'74406','watch','block-112871-2','BlockBox','',2),(112882,'74407','watch','block-112881','Text','',1),(112883,'74408','watch','block-112881-2','invoice\\StorePhone','',1),(112884,'74409','watch','login_account','BlockBox','',1),(112885,'74410','watch','block-112884','Tabs','',2),(112886,'74411','watch','block-112885-1','login\\Returning','',1),(112887,'74412','watch','block-112885-2','BlockBox','',1),(112888,'74413','watch','block-112887','Html_box','',1),(112889,'74414','watch','block-112887-2','BlockBox','',1),(112890,'74415','watch','block-112889','Html_box','',2),(112891,'74416','watch','block-112889','login\\Register','',1),(112892,'74417','watch','block-112884','BlockBox','',1),(112893,'74418','watch','block-112892','Html_box','',3),(112894,'74419','watch','block-112892','Html_box','',1),(112895,'74420','watch','block-112892','login\\Socials','',2),(112896,'74421','watch','login_checkout','BlockBox','',1),(112897,'74422','watch','block-112896','BlockBox','',1),(112898,'74423','watch','block-112897','checkout\\CreateBtn','',4),(112899,'74424','watch','block-112897','checkout\\GuestBtn','',2),(112900,'74425','watch','block-112897','Html_box','',3),(112901,'74426','watch','block-112897','BlockBox','',5),(112902,'74427','watch','block-112901','Html_box','',1),(112903,'74428','watch','block-112901','login\\Socials','',2),(112904,'74429','watch','block-112897','Html_box','',1),(112905,'74430','watch','block-112897-2','login\\Returning','',2),(112906,'74431','watch','block-112897-2','Html_box','',1),(112907,'74432','watch','login_checkout2','BlockBox','',1),(112908,'74433','watch','block-112907','Tabs','',4),(112909,'74434','watch','block-112908-1','BlockBox','',1),(112910,'74435','watch','block-112909','Html_box','',1),(112911,'74436','watch','block-112909-2','BlockBox','',1),(112912,'74437','watch','block-112911','login\\Guest','',1),(112913,'74438','watch','block-112911','Html_box','',2),(112914,'74439','watch','block-112908-2','login\\Returning','',1),(112915,'74440','watch','block-112908-3','BlockBox','',1),(112916,'74441','watch','block-112915','Html_box','',1),(112917,'74442','watch','block-112915-2','BlockBox','',1),(112918,'74443','watch','block-112917','Html_box','',2),(112919,'74444','watch','block-112917','login\\Register','',1),(112920,'74445','watch','block-112907','login\\Socials','',2),(112921,'74446','watch','block-112907','Html_box','',3),(112922,'74447','watch','block-112907','Html_box','',1),(112923,'74448','watch','login_checkout2_q','BlockBox','',1),(112924,'74449','watch','block-112923','Tabs','',4),(112925,'74450','watch','block-112924-1','BlockBox','',1),(112926,'74451','watch','block-112925','Html_box','',1),(112927,'74452','watch','block-112925-2','quote\\FastOrder','',1),(112928,'74453','watch','block-112924-2','login\\Returning','',1),(112929,'74454','watch','block-112924-3','BlockBox','',1),(112930,'74455','watch','block-112929','Html_box','',1),(112931,'74456','watch','block-112929','Import','',2),(112932,'74457','watch','block-112929-2','BlockBox','',1),(112933,'74458','watch','block-112932','login\\Register','',1),(112934,'74459','watch','block-112932','Html_box','',2),(112935,'74460','watch','block-112923','Html_box','',3),(112936,'74461','watch','block-112923','Html_box','',1),(112937,'74462','watch','block-112923','login\\Socials','',2),(112938,'74463','watch','login_checkout2_s','BlockBox','',1),(112939,'74464','watch','block-112938','login\\Socials','',2),(112940,'74465','watch','block-112938','Html_box','',3),(112941,'74466','watch','block-112938','Tabs','',4),(112942,'74467','watch','block-112941-1','BlockBox','',1),(112943,'74468','watch','block-112942','Html_box','',1),(112944,'74469','watch','block-112942-2','quote\\FastOrder','',1),(112945,'74470','watch','block-112941-2','login\\Returning','',1),(112946,'74471','watch','block-112941-3','BlockBox','',1),(112947,'74472','watch','block-112946','Html_box','',1),(112948,'74473','watch','block-112946-2','BlockBox','',1),(112949,'74474','watch','block-112948','login\\Register','',1),(112950,'74475','watch','block-112948','Html_box','',2),(112951,'74476','watch','block-112938','Html_box','',1),(112952,'74477','watch','login_checkout_q','BlockBox','',1),(112953,'74478','watch','block-112952','BlockBox','',1),(112954,'74479','watch','block-112953','BlockBox','',6),(112955,'74480','watch','block-112954','Html_box','',1),(112956,'74481','watch','block-112954','login\\Socials','',2),(112957,'74482','watch','block-112953','checkout\\GuestBtn','',2),(112958,'74483','watch','block-112953','checkout\\CreateBtn','',5),(112959,'74484','watch','block-112953','Html_box','',4),(112960,'74485','watch','block-112953','Html_box','',1),(112961,'74486','watch','block-112953-2','Html_box','',1),(112962,'74487','watch','block-112953-2','login\\Returning','',2),(112963,'74488','watch','login_checkout_s','BlockBox','',1),(112964,'74489','watch','block-112963','BlockBox','',1),(112965,'74490','watch','block-112964','Html_box','',1),(112966,'74491','watch','block-112964','checkout\\GuestBtn','',2),(112967,'74492','watch','block-112964','checkout\\CreateBtn','',4),(112968,'74493','watch','block-112964','Html_box','',3),(112969,'74494','watch','block-112964','BlockBox','',5),(112970,'74495','watch','block-112969','Html_box','',1),(112971,'74496','watch','block-112969','login\\Socials','',2),(112972,'74497','watch','block-112964-2','Html_box','',1),(112973,'74498','watch','block-112964-2','login\\Returning','',2),(112974,'74499','watch','logoff','BlockBox','',1),(112975,'74500','watch','block-112974','Html_box','',1),(112976,'74501','watch','logoff_forever','BlockBox','',1),(112977,'74502','watch','block-112976','Html_box','',1),(112978,'74503','watch','main','BlockBox','',5),(112979,'74504','watch','block-112978','BlockBox','',1),(112980,'74505','watch','block-112979','Bestsellers','10',1),(112981,'74506','watch','block-112979-2','Reviews','3',1),(112982,'74507','watch','main','Banner','',2),(112983,'74508','watch','main','BlockBox','main-content',4),(112984,'74510','watch','block-112983','Tabs','',3),(112985,'74511','watch','block-112984-1','NewProducts','8',1),(112986,'74512','watch','block-112984-2','SpecialsProducts','',2),(112987,'74513','watch','block-112984-3','FeaturedProducts','4',2),(112988,'74514','watch','block-112983','TopCategories','',2),(112989,'1708695037.0808','watch','block-112983','FormBuilder\\widgets\\Form','',1),(112990,'74515','watch','main','Heading','',3),(112992,'74516','watch','manufacturers','BlockBox','',1),(112993,'74517','watch','block-112992','Html_box','',1),(112994,'74518','watch','block-112992','Brands','',2),(112995,'74519','watch','messages-index','BlockBox','',1),(112996,'74520','watch','block-112995','BlockBox','',1),(112997,'74521','watch','block-112996','BlockBox','',1),(112998,'74522','watch','block-112997','Messages\\Sidebar','',1),(112999,'74523','watch','block-112996-2','Messages\\Listing','',1),(113000,'74524','watch','messages-new','BlockBox','',1),(113001,'74525','watch','block-113000','BlockBox','',1),(113002,'74526','watch','block-113001','Messages\\Sidebar','',1),(113003,'74527','watch','block-113001-2','Messages\\NewMessage','',1),(113004,'74528','watch','messages-view','BlockBox','',1),(113005,'74529','watch','block-113004','BlockBox','',1),(113006,'74530','watch','block-113005','Messages\\Sidebar','',1),(113007,'74531','watch','block-113005-2','Messages\\Message','',1),(113008,'74532','watch','my_password','BlockBox','',1),(113009,'74533','watch','block-113008','BlockBox','',1),(113010,'74534','watch','block-113009','WidgetsAria','',1),(113030,'74535','watch','block-113009-2','account\\ChangePassword','',2),(113031,'74536','watch','block-113009-2','Html_box','',1),(113032,'74537','watch','need_login','BlockBox','',1),(113033,'74538','watch','block-113032','Tabs','',2),(113034,'74539','watch','block-113033-1','login\\Returning','',1),(113035,'74540','watch','block-113033-2','BlockBox','',1),(113036,'74541','watch','block-113035','Html_box','',1),(113037,'74542','watch','block-113035-2','BlockBox','',1),(113038,'74543','watch','block-113037','login\\Register','',1),(113039,'74544','watch','block-113037','Html_box','',2),(113040,'74545','watch','block-113032','BlockBox','',1),(113041,'74546','watch','new-topic','BlockBox','',1),(113042,'74547','watch','block-113041','Breadcrumb','',2),(113043,'74548','watch','block-113041','Communication\\NewTopic','',3),(113044,'74549','watch','block-113041','Html_box','',1),(113045,'94779','watch','nnnn','BlockBox','',1),(113046,'94780','watch','block-113045','catalog\\Title','',1),(113047,'94781','watch','block-113045','BlockBox','',2),(113048,'94782','watch','block-113047','Filters','',1),(113049,'94783','watch','block-113047-2','Listing','',5),(113050,'94784','watch','block-113047-2','catalog\\Image','',1),(113051,'94785','watch','block-113047-2','BlockBox','',6),(113052,'94786','watch','block-113051','catalog\\CountsItems','',1),(113053,'94787','watch','block-113051-2','catalog\\Paging','',1),(113054,'94788','watch','block-113047-2','catalog\\ImageMapCategory','',3),(113055,'94789','watch','block-113047-2','Categories','',2),(113056,'94790','watch','block-113047-2','BlockBox','',4),(113057,'94791','watch','block-113056','catalog\\ListingLook','',1),(113058,'94792','watch','block-113056','catalog\\ItemsOnPage','',4),(113059,'94793','watch','block-113056','catalog\\CompareButton','',2),(113060,'94794','watch','block-113056','catalog\\Sorting','',3),(113061,'74550','watch','no-logged','BlockBox','',1),(113062,'74551','watch','block-113061','Communication\\NewTopic','',2),(113063,'74552','watch','block-113061','Html_box','',1),(113064,'74553','watch','no_filters','BlockBox','catalog-content',1),(113065,'74554','watch','block-113064','BlockBox','',4),(113066,'74555','watch','block-113065','catalog\\CountsItems','',1),(113067,'74556','watch','block-113065-2','catalog\\Paging','',1),(113068,'74557','watch','block-113064','Listing','',3),(113069,'74558','watch','block-113064','catalog\\Title','',1),(113070,'74559','watch','block-113064','catalog\\B2bAddButton','',5),(113071,'74560','watch','block-113064','BlockBox','',2),(113072,'74561','watch','block-113071','BlockBox','catalog-features',2),(113073,'74562','watch','block-113072','HeaderStock','',5),(113074,'74563','watch','block-113072','catalog\\ListingLook','',1),(113075,'74564','watch','block-113072','catalog\\CompareButton','',2),(113076,'74565','watch','block-113072','catalog\\ItemsOnPage','',4),(113077,'74566','watch','block-113072','catalog\\Sorting','',3),(113078,'74567','watch','block-113071','catalog\\Image','',1),(113162,'74613','watch','order_pay','BlockBox','',1),(113163,'74614','watch','block-113162','BlockBox','',1),(113164,'74615','watch','block-113163','WidgetsAria','',1),(113184,'74616','watch','block-113163-2','account\\OrderProducts','',4),(113185,'74617','watch','block-113163-2','BlockBox','',2),(113186,'74618','watch','block-113185','BlockBox','',1),(113187,'74619','watch','block-113186','Html_box','',1),(113188,'74620','watch','block-113186','account\\OrderData','',2),(113189,'74621','watch','block-113185','BlockBox','',4),(113190,'74622','watch','block-113189','account\\OrderData','',2),(113191,'74623','watch','block-113189','Html_box','',1),(113192,'74624','watch','block-113185-2','BlockBox','',1),(113193,'74625','watch','block-113192','Html_box','',1),(113194,'74626','watch','block-113192','account\\OrderData','',2),(113195,'74627','watch','block-113185-2','BlockBox','',2),(113196,'74628','watch','block-113195','account\\OrderData','',2),(113197,'74629','watch','block-113195','Html_box','',1),(113198,'74630','watch','block-113185-3','BlockBox','',2),(113199,'74631','watch','block-113198','Html_box','',1),(113200,'74632','watch','block-113198','account\\OrderData','',2),(113201,'74633','watch','block-113185-3','BlockBox','',1),(113202,'74634','watch','block-113201','account\\OrderData','',2),(113203,'74635','watch','block-113201','Html_box','',1),(113204,'74636','watch','block-113163-2','UpdateAndPay\\PayForm','',6),(113205,'74637','watch','block-113163-2','Html_box','',3),(113206,'74638','watch','block-113163-2','account\\OrderHeading','',1),(113207,'74639','watch','block-113163-2','account\\OrderSubTotals','',5),(113208,'74640','watch','packingslip','invoice\\Container','',2),(113209,'74641','watch','block-113208','BlockBox','',1),(113210,'74642','watch','block-113209','Logo','',1),(113211,'74643','watch','block-113209-2','BlockBox','',3),(113212,'74644','watch','block-113211','Text','',2),(113213,'74645','watch','block-113211-2','invoice\\StoreEmail','',1),(113214,'74646','watch','block-113209-2','BlockBox','',2),(113215,'74647','watch','block-113214','Text','',2),(113216,'74648','watch','block-113214-2','invoice\\StorePhone','',1),(113217,'74649','watch','block-113209-2','BlockBox','',1),(113218,'74650','watch','block-113217','invoice\\StoreAddress','',1),(113219,'74651','watch','block-113209-2','BlockBox','',4),(113220,'74652','watch','block-113219','Text','',2),(113221,'74653','watch','block-113219-2','invoice\\StoreSite','',1),(113222,'74654','watch','block-113208','packingslip\\Products','',3),(113223,'74655','watch','block-113208','BlockBox','',4),(113224,'74656','watch','block-113223','invoice\\StoreAddress','',2),(113225,'74657','watch','block-113223','Text','',1),(113226,'74658','watch','block-113208','BlockBox','',2),(113227,'74659','watch','block-113226','BlockBox','',2),(113228,'74660','watch','block-113227','BlockBox','',1),(113229,'74661','watch','block-113228','invoice\\ShippingAddress','',2),(113230,'74662','watch','block-113228','Text','',1),(113231,'74663','watch','block-113227-2','BlockBox','',1),(113232,'74664','watch','block-113231','Text','',1),(113233,'74665','watch','block-113231','invoice\\CustomerName','',2),(113234,'74666','watch','block-113231','invoice\\CustomerEmail','',6),(113235,'74667','watch','block-113231','Text','',3),(113236,'74668','watch','block-113231','invoice\\CustomerPhone','',4),(113237,'74669','watch','block-113231','Text','',5),(113238,'74670','watch','block-113226','BlockBox','',3),(113239,'74671','watch','block-113238','BlockBox','',1),(113240,'74672','watch','block-113239','invoice\\ShippingMethod','',2),(113241,'74673','watch','block-113239','Text','',1),(113242,'74674','watch','block-113238-2','BlockBox','',1),(113243,'74675','watch','block-113242','invoice\\ShippingMethod','',2),(113244,'74676','watch','block-113242','Text','',1),(113245,'74677','watch','block-113226-2','invoice\\AddressQrcode','',1),(113246,'74678','watch','password_forgotten','BlockBox','',1),(113247,'74679','watch','block-113246','BlockBox','',2),(113248,'74680','watch','block-113247-2','Html_box','',1),(113249,'74681','watch','block-113247-2','login\\PasswordForgotten','',2),(113250,'74682','watch','block-113246','Html_box','',1),(113251,'74683','watch','pdf','invoice\\Container','',1),(113252,'74684','watch','block-113251','BlockBox','',1),(113253,'74685','watch','block-113252','BlockBox','',1),(113254,'74686','watch','block-113253','BlockBox','',1),(113255,'74687','watch','block-113254','pdf\\ProductElement','',1),(113256,'74688','watch','block-113253','BlockBox','',2),(113257,'74689','watch','block-113256','pdf\\ProductElement','',1),(113258,'74690','watch','block-113256-2','pdf\\ProductElement','',2),(113259,'74691','watch','block-113256-2','pdf\\ProductElement','',1),(113260,'74692','watch','block-113252-2','BlockBox','',1),(113261,'74693','watch','block-113260','BlockBox','',2),(113262,'74694','watch','block-113261','pdf\\ProductElement','',1),(113263,'74695','watch','block-113261-2','pdf\\ProductElement','',2),(113264,'74696','watch','block-113261-2','pdf\\ProductElement','',1),(113265,'74697','watch','block-113260','BlockBox','',1),(113266,'74698','watch','block-113265','pdf\\ProductElement','',1),(113267,'74699','watch','pdf_category','pdf\\CategoryName','',2),(113268,'74700','watch','pdf_category','pdf\\CategoryImage','',1),(113269,'74701','watch','pdf_cover','invoice\\Container','',1),(113270,'74702','watch','block-113269','Logo','',1),(113271,'74703','watch','block-113269','Text','',3),(113272,'74704','watch','pdf_footer','BlockBox','',1),(113273,'74705','watch','block-113272-2','pdf\\PageNumber','',1),(113274,'74706','watch','pdf_header','pdf\\CategoryName','',1),(113275,'74707','watch','personal_catalog','BlockBox','',1),(113276,'74708','watch','block-113275','BlockBox','',1),(113277,'74709','watch','block-113276','WidgetsAria','',1),(113297,'74710','watch','block-113276-2','Html_box','',1),(113298,'74711','watch','block-113276-2','account\\AccountLink','',3),(113299,'74712','watch','block-113276-2','account\\PersonalCatalog','',2),(113300,'74713','watch','points_earnt_history','BlockBox','',1),(113301,'74714','watch','block-113300','Html_box','',1),(113302,'74715','watch','block-113300','BonusActions\\widgets\\PointsEarntHistory','',2),(113303,'74716','watch','posts','BlockBox','',1),(113304,'74717','watch','block-113303','Breadcrumb','',2),(113305,'74718','watch','block-113303','Html_box','',1),(113306,'74719','watch','block-113303','Communication\\Post','',3),(113307,'74720','watch','product','BlockBox','product-content',2),(113308,'74721','watch','block-113307','product\\CustomersActivity','',11),(113309,'74722','watch','block-113307','BlockBox','product-image',2),(113310,'74724','watch','block-113309','product\\Images','',2),(113311,'74725','watch','block-113309','product\\ImageMapProduct','',4),(113312,'74726','watch','block-113309','product\\PromotionIcons','',1),(113313,'74727','watch','block-113309-2','BlockBox','product-side',10),(113314,'74728','watch','block-113313','product\\ButtonsQuote','',3),(113315,'74729','watch','block-113313','BlockBox','',1),(113316,'74730','watch','block-113315','product\\Price','',1),(113317,'74731','watch','block-113315-2','product\\Quantity','',1),(113318,'74732','watch','block-113313','BonusActions\\widgets\\BonusPointsProduct','',4),(113319,'1694165842.4776','watch','block-113313','product\\QuantityDiscounts','',2),(113320,'74733','watch','block-113313-2','product\\Buttons','',1),(113321,'74734','watch','block-113313-2','product\\ButtonsSample','',2),(113322,'74735','watch','block-113309-2','product\\DescriptionShort','',6),(113323,'74737','watch','block-113309-2','product\\Documents','',5),(113324,'74738','watch','block-113309-2','product\\AvailableInWarehouses','',9),(113325,'74739','watch','block-113309-2','BlockBox','',11),(113326,'74741','watch','block-113325','product\\PersonalCatalogButton','',1),(113327,'74743','watch','block-113309-2','product\\Brand','',4),(113328,'74744','watch','block-113309-2','product\\Model','',3),(113329,'74745','watch','block-113309-2','product\\Name','',2),(113330,'74746','watch','block-113309-2','product\\Stock','',1),(113331,'1642500646.3623','watch','block-113309-2','product\\Attributes','',7),(113332,'74749','watch','block-113307','product\\Configurator','',5),(113333,'74750','watch','block-113307','Breadcrumb','',1),(113334,'74752','watch','block-113307','Tabs','',6),(113335,'74753','watch','block-113334-1','product\\Description','',2),(113336,'74754','watch','block-113334-1','product\\Properties','',1),(113337,'74755','watch','block-113334-2','product\\Reviews','',1),(113338,'74757','watch','block-113307','product\\InBundles','',4),(113339,'74758','watch','block-113307','product\\Bundle','',3),(113340,'1694166186.2638','watch','block-113307','BlockBox','',7),(113341,'74751','watch','block-113340','product\\AlsoPurchased','10',2),(113342,'1694166209.3278','watch','block-113340','Html_box','',1),(113343,'1694166191.5684','watch','block-113307','BlockBox','',9),(113344,'74747','watch','block-113343','ViewedProducts','4',2),(113345,'1694166222.3382','watch','block-113343','Html_box','',1),(113346,'74761','watch','product-bottom','product\\Properties','',1),(113347,'74762','watch','product-tabs','product\\Reviews','',2),(113348,'74763','watch','product-tabs','product\\Description','',1),(113349,'74764','watch','product-top-left','product\\Images','',1),(113350,'74765','watch','product-top-right','product\\Price','',2),(113351,'74766','watch','product-top-right','product\\Quantity','',5),(113352,'74767','watch','product-top-right','product\\Quantity','',6),(113353,'74768','watch','product-top-right','product\\Attributes','',3),(113354,'74769','watch','product-top-right','product\\Name','',1),(113355,'74770','watch','product-top-right','product\\Buttons','',6),(113356,'74771','watch','productListing','BlockBox','listing-item',1),(113357,'74773','watch','block-113356','productListing\\model','',7),(113358,'74774','watch','block-113356','BonusActions\\widgets\\BonusPointsProductListing','',6),(113359,'74775','watch','block-113356','productListing\\description','',5),(113360,'74776','watch','block-113356','productListing\\buyButton','',9),(113361,'74777','watch','block-113356','productListing\\rating','',3),(113362,'74778','watch','block-113356','productListing\\image','',1),(113363,'74779','watch','block-113356','BlockBox','',8),(113364,'74780','watch','block-113363','productListing\\price','',1),(113365,'74781','watch','block-113363-2','productListing\\qtyInput','',1),(113366,'74782','watch','block-113356','productListing\\name','',4),(113367,'74783','watch','block-113356','productListing\\stock','',2),(113368,'75903','watch','block-113356','productListing\\compare','',10),(113369,'74785','watch','products','BlockBox','catalog-content',1),(113370,'74786','watch','block-113369','BlockBox','catalog-side',4),(113371,'74787','watch','block-113370','Filters','',1),(113372,'74788','watch','block-113370','HeaderStock','',2),(113373,'74789','watch','block-113370-2','catalog\\B2bAddButton','',4),(113374,'74790','watch','block-113370-2','BlockBox','catalog-features',2),(113375,'74791','watch','block-113374','catalog\\Sorting','',3),(113376,'74792','watch','block-113374','catalog\\ListingLook','',1),(113377,'74793','watch','block-113374','catalog\\ItemsOnPage','',4),(113378,'74794','watch','block-113374','catalog\\CompareButton','',2),(113379,'74795','watch','block-113370-2','BlockBox','',5),(113380,'74796','watch','block-113379','catalog\\CountsItems','',1),(113381,'74797','watch','block-113379-2','catalog\\Paging','',1),(113382,'74798','watch','block-113370-2','Listing','',3),(113383,'74799','watch','block-113369','catalog\\Title','',1),(113384,'74800','watch','block-113369','BlockBox','',3),(113385,'74801','watch','block-113384','catalog\\Image','',1),(113386,'75886','watch','products-list','packingslip\\AllProductsList','',2),(113387,'74802','watch','promotions','BlockBox','',1),(113388,'74803','watch','block-113387','promotions\\PromoList','',2),(113389,'74804','watch','block-113387','Html_box','',1),(113390,'74805','watch','purchase','invoice\\Container','',1),(113391,'74806','watch','block-113390','invoice\\Products','',3),(113392,'74807','watch','block-113390','BlockBox','',5),(113393,'74808','watch','block-113392','Text','',1),(113394,'74809','watch','block-113392','invoice\\StoreAddress','',8),(113395,'74810','watch','block-113392-2','Text','',2),(113396,'74811','watch','block-113392-2','Logo','',1),(113397,'74812','watch','block-113392-3','BlockBox','',3),(113398,'74813','watch','block-113397','Text','',1),(113399,'74814','watch','block-113397-2','invoice\\StoreEmail','',1),(113400,'74815','watch','block-113392-3','Text','',1),(113401,'74816','watch','block-113392-3','BlockBox','',2),(113402,'74817','watch','block-113401','Text','',1),(113403,'74818','watch','block-113401-2','invoice\\StorePhone','',1),(113404,'74819','watch','block-113390','BlockBox','',1),(113405,'74820','watch','block-113404','Logo','',1),(113406,'74821','watch','block-113404-2','BlockBox','',2),(113407,'74822','watch','block-113406','Text','',1),(113408,'74823','watch','block-113406-2','invoice\\StorePhone','',1),(113409,'74824','watch','block-113404-2','BlockBox','',4),(113410,'74825','watch','block-113409','Text','',1),(113411,'74826','watch','block-113409-2','invoice\\StoreSite','',1),(113412,'74827','watch','block-113404-2','BlockBox','',1),(113413,'74828','watch','block-113412','invoice\\StoreAddress','',1),(113414,'74829','watch','block-113404-2','BlockBox','',3),(113415,'74830','watch','block-113414','Text','',1),(113416,'74831','watch','block-113414-2','invoice\\StoreEmail','',1),(113417,'74832','watch','block-113390','BlockBox','',2),(113418,'74833','watch','block-113417','BlockBox','',7),(113419,'74834','watch','block-113418','BlockBox','',1),(113420,'74835','watch','block-113419','invoice\\BillingAddress','',2),(113421,'74836','watch','block-113419','Text','',1),(113422,'74837','watch','block-113418-2','BlockBox','',1),(113423,'74838','watch','block-113422','invoice\\CustomerEmail','',6),(113424,'74839','watch','block-113422','Text','',5),(113425,'74840','watch','block-113422','invoice\\CustomerPhone','',4),(113426,'74841','watch','block-113422','invoice\\CustomerName','',2),(113427,'74842','watch','block-113422','Text','',3),(113428,'74843','watch','block-113422','Text','',1),(113429,'74844','watch','block-113417-2','invoice\\OrderId','',1),(113430,'74845','watch','block-113417-2','Text','',2),(113431,'74846','watch','block-113417-2','invoice\\PaymentDate','',3),(113432,'74847','watch','block-113390','BlockBox','',4),(113433,'74848','watch','block-113432','BlockBox','',1),(113434,'74849','watch','block-113433','invoice\\ShippingAddress','',2),(113435,'74850','watch','block-113433','Text','',1),(113436,'74851','watch','quotations','BlockBox','',1),(113437,'74852','watch','block-113436','BlockBox','',1),(113438,'74853','watch','block-113437','WidgetsAria','',1),(113458,'74854','watch','block-113437-2','Html_box','',1),(113459,'74855','watch','block-113437-2','Quotations\\QuotationsHistory','',2),(113460,'74856','watch','quotation_info','BlockBox','',1),(113461,'74857','watch','block-113460','BlockBox','',1),(113462,'74858','watch','block-113461','WidgetsAria','',1),(113482,'74859','watch','block-113461-2','BlockBox','',5),(113483,'74860','watch','block-113482','BlockBox','',1),(113484,'74861','watch','block-113483','Quotations\\QuotationData','',2),(113485,'74862','watch','block-113483','Html_box','',1),(113486,'74863','watch','block-113482','BlockBox','',4),(113487,'74864','watch','block-113486','Html_box','',1),(113488,'74865','watch','block-113486','Quotations\\QuotationData','',2),(113489,'74866','watch','block-113482-2','BlockBox','',2),(113490,'74867','watch','block-113489','Html_box','',1),(113491,'74868','watch','block-113489','Quotations\\QuotationData','',2),(113492,'74869','watch','block-113482-2','BlockBox','',1),(113493,'74870','watch','block-113492','Html_box','',1),(113494,'74871','watch','block-113492','Quotations\\QuotationData','',2),(113495,'74872','watch','block-113482-3','BlockBox','',1),(113496,'74873','watch','block-113495','Quotations\\QuotationData','',2),(113497,'74874','watch','block-113495','Html_box','',1),(113498,'74875','watch','block-113482-3','BlockBox','',2),(113499,'74876','watch','block-113498','Quotations\\QuotationData','',2),(113500,'74877','watch','block-113498','Html_box','',1),(113501,'74878','watch','block-113461-2','Html_box','',6),(113502,'74879','watch','block-113461-2','Quotations\\QuotationHistory','',10),(113503,'74880','watch','block-113461-2','Html_box','',9),(113504,'74881','watch','block-113461-2','Quotations\\QuotationProducts','',7),(113505,'74882','watch','block-113461-2','Quotations\\QuotationSubTotal','',8),(113506,'74883','watch','block-113461-2','BlockBox','',12),(113507,'74884','watch','block-113506','account\\AccountLink','',1),(113508,'74885','watch','block-113461-2','Html_box','',4),(113509,'74886','watch','quote','BlockBox','',1),(113510,'74887','watch','block-113509','cart\\CartTabs','',1),(113511,'74888','watch','block-113510','BlockBox','',1),(113512,'74889','watch','block-113511','quote\\Products','',1),(113513,'74890','watch','block-113511-2','BlockBox','',1),(113514,'74891','watch','block-113513','BlockBox','',1),(113515,'74892','watch','block-113514','quote\\CheckoutBtn','',2),(113516,'74893','watch','block-113510','Quotations\\QuotationSubTotal','',2),(113541,'74899','watch','reviews','BlockBox','',1),(113542,'74900','watch','block-113541','reviews\\Heading','',1),(113543,'74901','watch','block-113541','reviews\\Content','',2),(113544,'74902','watch','rma_document','invoice\\Container','',1),(113545,'74903','watch','block-113544','BlockBox','',1),(113546,'74904','watch','block-113545','BlockBox','',1),(113547,'74905','watch','block-113546','BlockBox','',2),(113548,'74906','watch','block-113547','Html_box','',1),(113549,'74907','watch','block-113547-2','Html_box','',1),(113550,'74908','watch','block-113546','BlockBox','',5),(113551,'74909','watch','block-113550','Html_box','',1),(113552,'74910','watch','block-113550-2','Html_box','',1),(113553,'74911','watch','block-113546','BlockBox','',4),(113554,'74912','watch','block-113553','Html_box','',1),(113555,'74913','watch','block-113553-2','Html_box','',1),(113556,'74914','watch','block-113546','BlockBox','',3),(113557,'74915','watch','block-113556','Html_box','',1),(113558,'74916','watch','block-113556-2','Html_box','',1),(113559,'74917','watch','block-113546','BlockBox','',1),(113560,'74918','watch','block-113559','Html_box','',1),(113561,'74919','watch','block-113559','Html_box','',2),(113562,'74920','watch','block-113545-2','BlockBox','',1),(113563,'74921','watch','block-113562','Html_box','',2),(113564,'74922','watch','block-113562','Logo','',1),(113565,'74923','watch','block-113545-2','BlockBox','',2),(113566,'74924','watch','block-113565','BlockBox','',5),(113567,'74925','watch','block-113566','BlockBox','',1),(113568,'74926','watch','block-113567','Html_box','',1),(113569,'74927','watch','block-113567-2','Rma\\DocumentData','',1),(113570,'74928','watch','block-113566-2','BlockBox','',1),(113571,'74929','watch','block-113570','Html_box','',1),(113572,'74930','watch','block-113570-2','Rma\\DocumentData','',1),(113573,'74931','watch','block-113565','BlockBox','',4),(113574,'74932','watch','block-113573','BlockBox','',1),(113575,'74933','watch','block-113574','Html_box','',1),(113576,'74934','watch','block-113574-2','Rma\\DocumentData','',1),(113577,'74935','watch','block-113573-2','BlockBox','',1),(113578,'74936','watch','block-113577','Html_box','',1),(113579,'74937','watch','block-113577-2','Rma\\DocumentData','',1),(113580,'74938','watch','block-113565','BlockBox','',3),(113581,'74939','watch','block-113580','BlockBox','',1),(113582,'74940','watch','block-113581','Html_box','',1),(113583,'74941','watch','block-113581-2','Rma\\DocumentData','',1),(113584,'74942','watch','block-113580-2','BlockBox','',1),(113585,'74943','watch','block-113584','Html_box','',1),(113586,'74944','watch','block-113584-2','Rma\\DocumentData','',1),(113587,'74945','watch','block-113565','BlockBox','',2),(113588,'74946','watch','block-113587','Html_box','',1),(113589,'74947','watch','block-113587-2','Rma\\DocumentData','',1),(113590,'74948','watch','block-113565','BlockBox','',1),(113591,'74949','watch','block-113590','BlockBox','',1),(113592,'74950','watch','block-113591','Html_box','',1),(113593,'74951','watch','block-113591-2','Rma\\DocumentData','',1),(113594,'74952','watch','block-113590-2','BlockBox','',1),(113595,'74953','watch','block-113594','Html_box','',1),(113596,'74954','watch','block-113594-2','Rma\\DocumentData','',1),(113597,'74955','watch','block-113545-2','BlockBox','',3),(113598,'74956','watch','block-113597','BlockBox','',1),(113599,'74957','watch','block-113598','Html_box','',1),(113600,'74958','watch','block-113598-2','Rma\\DocumentData','',1),(113601,'74959','watch','block-113597-2','BlockBox','',1),(113602,'74960','watch','block-113601','Html_box','',1),(113603,'74961','watch','block-113601-2','Rma\\DocumentData','',1),(113604,'74962','watch','block-113544','BlockBox','',2),(113605,'74963','watch','block-113604','Html_box','',1),(113606,'74964','watch','block-113604','Rma\\Products','',2),(113607,'74965','watch','block-113544','BlockBox','',3),(113608,'74966','watch','block-113607','BlockBox','',1),(113609,'74967','watch','block-113608','BlockBox','',1),(113610,'74968','watch','block-113609','BlockBox','',5),(113611,'74969','watch','block-113610','Html_box','',1),(113612,'74970','watch','block-113610-2','invoice\\StoreAddress','',2),(113613,'74971','watch','block-113610-2','Html_box','',1),(113614,'74972','watch','block-113609','BlockBox','',4),(113615,'74973','watch','block-113614','Html_box','',1),(113616,'74974','watch','block-113614-2','Html_box','',1),(113617,'74975','watch','block-113609','BlockBox','',2),(113618,'74976','watch','block-113617','Html_box','',1),(113619,'74977','watch','block-113617-2','Html_box','',1),(113620,'74978','watch','block-113609','BlockBox','',1),(113621,'74979','watch','block-113620','Html_box','',1),(113622,'74980','watch','block-113609','BlockBox','',3),(113623,'74981','watch','block-113622','Html_box','',1),(113624,'74982','watch','block-113622-2','Html_box','',1),(113625,'74983','watch','block-113609','BlockBox','',6),(113626,'74984','watch','block-113625','Html_box','',1),(113627,'74985','watch','block-113608-2','BlockBox','',1),(113628,'74986','watch','block-113627','BlockBox','',1),(113629,'74987','watch','block-113628','BlockBox','',1),(113630,'74988','watch','block-113629','Rma\\DocumentData','',2),(113631,'74989','watch','block-113629-3','BlockBox','',1),(113632,'74990','watch','block-113631','Html_box','',1),(113633,'74991','watch','block-113631-2','Rma\\DocumentData','',1),(113634,'74992','watch','block-113628','BlockBox','',2),(113635,'74993','watch','block-113634-2','invoice\\StoreAddress','',1),(113636,'74994','watch','block-113608-2','BlockBox','',2),(113637,'74995','watch','block-113636','Html_box','',1),(113638,'74996','watch','block-113636','Html_box','',2),(113639,'74997','watch','block-113636','Html_box','',3),(113640,'74998','watch','block-113636','Html_box','',4),(113641,'74999','watch','block-113636','Html_box','',5),(113642,'75000','watch','block-113608-2','BlockBox','',4),(113643,'75001','watch','block-113642','Html_box','',1),(113644,'75002','watch','block-113642-2','Html_box','',1),(113645,'75003','watch','block-113642-3','BlockBox','',1),(113646,'75004','watch','block-113645','Html_box','',1),(113647,'75005','watch','block-113645-2','Html_box','',1),(113648,'75006','watch','block-113608-2','BlockBox','',3),(113649,'75007','watch','block-113648','Html_box','',1),(113650,'75008','watch','block-113648-2','Html_box','',1),(113651,'75009','watch','block-113648-3','BlockBox','',1),(113652,'75010','watch','block-113651','Html_box','',1),(113653,'75011','watch','block-113651-2','Html_box','',1),(113654,'75012','watch','rows','BlockBox','',1),(113655,'75013','watch','block-113654','BlockBox','',2),(113656,'75014','watch','block-113655','BlockBox','',2),(113657,'75015','watch','block-113656','BonusActions\\widgets\\BonusPointsProductListing','',1),(113658,'75016','watch','block-113656','productListing\\image','',2),(113659,'75017','watch','block-113656','BlockBox','',3),(113660,'75018','watch','block-113659','productListing\\rating','',1),(113661,'75019','watch','block-113659','productListing\\ratingCounts','',2),(113662,'75020','watch','block-113656-2','productListing\\name','',1),(113663,'75021','watch','block-113656-2','productListing\\description','',2),(113664,'75022','watch','block-113656-2','productListing\\model','',3),(113665,'75023','watch','block-113656-2','productListing\\attributes','',4),(113666,'75024','watch','block-113655-2','BlockBox','listing-item',1),(113667,'75025','watch','block-113666','productListing\\qtyInput','',3),(113668,'75026','watch','block-113666','productListing\\price','',2),(113669,'75027','watch','block-113666','productListing\\compare','',5),(113670,'75028','watch','block-113666','productListing\\buyButton','',4),(113671,'75030','watch','block-113666','productListing\\stock','',1),(113672,'75031','watch','sample','BlockBox','',1),(113673,'75032','watch','block-113672','cart\\CartTabs','',1),(113674,'75033','watch','block-113673','BlockBox','',1),(113675,'75034','watch','block-113674','sample\\Products','',1),(113676,'75035','watch','block-113674-2','BlockBox','',1),(113677,'75036','watch','block-113676','BlockBox','',1),(113678,'75037','watch','block-113677','sample\\CheckoutBtn','',1),(113679,'75038','watch','samples','BlockBox','',1),(113680,'75039','watch','block-113679','BlockBox','',1),(113681,'75040','watch','block-113680','WidgetsAria','',1),(113701,'75041','watch','block-113680-2','Html_box','',1),(113702,'75042','watch','block-113680-2','Samples\\SamplesHistory','',2),(113703,'75043','watch','sample_info','BlockBox','',1),(113704,'75044','watch','block-113703','BlockBox','',1),(113705,'75045','watch','block-113704','WidgetsAria','',1),(113725,'75046','watch','block-113704-2','Html_box','',1),(113726,'75047','watch','block-113704-2','BlockBox','',8),(113727,'75048','watch','block-113726','account\\AccountLink','',1),(113728,'75049','watch','block-113704-2','Samples\\SampleHistory','',7),(113729,'75050','watch','block-113704-2','Html_box','',3),(113730,'75051','watch','block-113704-2','Samples\\SampleSubTotal','',5),(113731,'75052','watch','block-113704-2','Samples\\SampleProducts','',4),(113732,'75053','watch','block-113704-2','Html_box','',6),(113733,'75054','watch','block-113704-2','BlockBox','',2),(113734,'75055','watch','block-113733','BlockBox','',4),(113735,'75056','watch','block-113734','Html_box','',1),(113736,'75057','watch','block-113734','Samples\\SampleData','',2),(113737,'75058','watch','block-113733','BlockBox','',1),(113738,'75059','watch','block-113737','Samples\\SampleData','',2),(113739,'75060','watch','block-113737','Html_box','',1),(113740,'75061','watch','block-113733-2','BlockBox','',2),(113741,'75062','watch','block-113740','Samples\\SampleData','',2),(113742,'75063','watch','block-113740','Html_box','',1),(113743,'75064','watch','block-113733-2','BlockBox','',1),(113744,'75065','watch','block-113743','Samples\\SampleData','',2),(113745,'75066','watch','block-113743','Html_box','',1),(113746,'75067','watch','block-113733-3','BlockBox','',2),(113747,'75068','watch','block-113746','Samples\\SampleData','',2),(113748,'75069','watch','block-113746','Html_box','',1),(113749,'75070','watch','block-113733-3','BlockBox','',1),(113750,'75071','watch','block-113749','Samples\\SampleData','',2),(113751,'75072','watch','block-113749','Html_box','',1),(113752,'75073','watch','sitemap','BlockBox','',1),(113753,'75074','watch','block-113752','Html_box','',1),(113754,'75075','watch','block-113752','BlockBox','',2),(113755,'75076','watch','block-113754','Html_box','',1),(113756,'75077','watch','block-113754','Html_box','',5),(113757,'75078','watch','block-113754','Html_box','',3),(113758,'75079','watch','block-113754','sitemap\\InfoPages','',2),(113759,'75080','watch','block-113754','sitemap\\Categories','',4),(113760,'75081','watch','block-113754','Menu','Account box',6),(113761,'75082','watch','block-113754-2','sitemap\\DeliveryLocation','',2),(113762,'75083','watch','block-113754-2','Html_box','',1),(113763,'75084','watch','subscribe','BlockBox','',1),(113764,'75085','watch','block-113763','Html_box','',3),(113765,'75086','watch','block-113763','subscribers\\UnsubscribeForm','',4),(113766,'75087','watch','block-113763','Html_box','',1),(113767,'75088','watch','block-113763','subscribers\\SubscribeForm','',2),(113768,'75089','watch','subscribed','BlockBox','',1),(113769,'75090','watch','block-113768','Html_box','',1),(113770,'94795','watch','subscription','BlockBox','',2),(113771,'94796','watch','block-113770','BlockBox','',1),(113772,'94797','watch','block-113771','WidgetsAria','',1),(113792,'94798','watch','block-113771-2','Html_box','',2),(113793,'94799','watch','block-113771-2','Html_box','',3),(113794,'94800','watch','block-113771-2','account\\Subscription','',4),(113795,'1694099590.22143','watch','success','BlockBox','',1),(113796,'1694099590.340695','watch','block-113795','BlockBox','',2),(113797,'1694099590.343733','watch','block-113796','BlockBox','',3),(113798,'1694099590.345212','watch','block-113797','BlockBox','',2),(113799,'1694099590.34749','watch','block-113798','BlockBox','',1),(113800,'1694099590.3531','watch','block-113799','order\\ShippingMethod','',6),(113801,'1694099590.351567','watch','block-113799','order\\DeliveryAddress','',3),(113802,'1694099590.35337','watch','block-113799','Html_box','',7),(113803,'1694099590.360420','watch','block-113799','Html_box','',5),(113804,'1694099590.362714','watch','block-113799','Html_box','',1),(113805,'1694099590.36422','watch','block-113799','checkout\\ContactConfirm','',9),(113806,'1694099590.365625','watch','block-113799','Html_box','',2),(113807,'1694099590.367789','watch','block-113798-2','BlockBox','',1),(113808,'1694099590.369488','watch','block-113807','order\\PaymentMethod','',6),(113809,'1694099590.370690','watch','block-113807','order\\BillingAddress','',3),(113810,'1694099590.371953','watch','block-113807','Html_box','',5),(113811,'1694099590.373633','watch','block-113807','Html_box','',1),(113812,'1694099590.37590','watch','block-113807','Html_box','',2),(113813,'1694099590.376747','watch','block-113797','Html_box','',1),(113814,'1694099590.38020','watch','block-113796-2','BlockBox','',1),(113815,'1694099590.381373','watch','block-113814','success\\PrintBtn','',3),(113816,'1694099590.382864','watch','block-113814','success\\ContinueBtn','',4),(113817,'1694099590.384241','watch','block-113814','order\\Products','',1),(113818,'1694099590.385486','watch','block-113814','order\\Totals','',2),(113819,'1694099590.386683','watch','block-113795','BlockBox','',1),(113820,'1694099590.387673','watch','block-113819','Html_box','',2),(113821,'1694099590.389337','watch','block-113819','order\\OrderNumber','',1),(113822,'75097','watch','success_q','BlockBox','',1),(113823,'75098','watch','block-113822','BlockBox','',1),(113824,'75099','watch','block-113823','BlockBox','',2),(113825,'75100','watch','block-113824','success\\ContinueBtn','',2),(113826,'75101','watch','block-113824','success\\PrintBtn','',1),(113827,'75102','watch','block-113823','Html_box','',1),(113832,'75107','watch','ticket','invoice\\Container','',1),(113833,'75108','watch','block-113832','BlockBox','',4),(113834,'75109','watch','block-113833','BlockBox','',1),(113835,'75110','watch','block-113834','invoice\\ShippingAddress','',2),(113836,'75111','watch','block-113834','Text','',1),(113837,'75112','watch','block-113833-2','BlockBox','',1),(113838,'75113','watch','block-113837','invoice\\Totals','',1),(113839,'75114','watch','block-113832','BlockBox','',5),(113840,'75115','watch','block-113839','Text','',1),(113841,'75116','watch','block-113839','invoice\\StoreAddress','',8),(113842,'75117','watch','block-113839-2','Logo','',1),(113843,'75118','watch','block-113839-2','Text','',2),(113844,'75119','watch','block-113839-3','Text','',1),(113845,'75120','watch','block-113839-3','BlockBox','',3),(113846,'75121','watch','block-113845','Text','',1),(113847,'75122','watch','block-113845-2','invoice\\StoreEmail','',1),(113848,'75123','watch','block-113839-3','BlockBox','',2),(113849,'75124','watch','block-113848','Text','',1),(113850,'75125','watch','block-113848-2','invoice\\StorePhone','',1),(113851,'75126','watch','block-113832','invoice\\Products','',3),(113852,'75127','watch','block-113832','BlockBox','',1),(113853,'75128','watch','block-113852-2','BlockBox','',3),(113854,'75129','watch','block-113853','Text','',1),(113855,'75130','watch','block-113853-2','invoice\\StoreEmail','',1),(113856,'75131','watch','block-113852-2','BlockBox','',4),(113857,'75132','watch','block-113856','Text','',1),(113858,'75133','watch','block-113856-2','invoice\\StoreSite','',1),(113859,'75134','watch','block-113852-2','BlockBox','',1),(113860,'75135','watch','block-113859','invoice\\StoreAddress','',1),(113861,'75136','watch','block-113852-2','BlockBox','',2),(113862,'75137','watch','block-113861','Text','',1),(113863,'75138','watch','block-113861-2','invoice\\StorePhone','',1),(113864,'75139','watch','block-113832','BlockBox','',2),(113865,'75140','watch','block-113864','BlockBox','',8),(113866,'75141','watch','block-113865','BlockBox','',1),(113867,'75142','watch','block-113866','Text','',1),(113868,'75143','watch','block-113866','invoice\\ShippingMethod','',2),(113869,'75144','watch','block-113865-2','BlockBox','',1),(113870,'75145','watch','block-113869','Text','',1),(113871,'75146','watch','block-113869','invoice\\ShippingMethod','',2),(113872,'75147','watch','block-113864','BlockBox','',7),(113873,'75148','watch','block-113872','BlockBox','',1),(113874,'75149','watch','block-113873','invoice\\BillingAddress','',2),(113875,'75150','watch','block-113873','Text','',1),(113876,'75151','watch','block-113872-2','BlockBox','',1),(113877,'75152','watch','block-113876','invoice\\CustomerName','',2),(113878,'75153','watch','block-113876','Text','',3),(113879,'75154','watch','block-113876','invoice\\CustomerEmail','',6),(113880,'75155','watch','block-113876','invoice\\CustomerPhone','',4),(113881,'75156','watch','block-113876','Text','',5),(113882,'75157','watch','block-113876','Text','',1),(113883,'75158','watch','block-113864-2','invoice\\PaymentDate','',3),(113884,'75159','watch','block-113864-2','Text','',2),(113885,'75160','watch','block-113864-2','Text','',4),(113886,'75161','watch','block-113864-2','invoice\\OrderId','',1),(113887,'75162','watch','block-113864-2','invoice\\PaymentMethod','',5),(113888,'75163','watch','block-113864-2','invoice\\OrderBarcode','',6),(113889,'75194','watch','tracking_numbers','BlockBox','',1),(113890,'75195','watch','block-113889','Html_box','',1),(113891,'75196','watch','block-113889','account\\OrderTracking','',2),(113892,'75418','watch','unsubscribed','BlockBox','',1),(113893,'75419','watch','block-113892','Html_box','',1),(113894,'75420','watch','update-and-pay-order_confirmation','BlockBox','',1),(113895,'75421','watch','block-113894','BlockBox','',3),(113896,'75422','watch','block-113895','BlockBox','',1),(113897,'75423','watch','block-113896','BlockBox','',1),(113898,'75424','watch','block-113897','BlockBox','',1),(113899,'75425','watch','block-113898','order\\ShippingMethod','',5),(113900,'75426','watch','block-113898','Html_box','',2),(113901,'75427','watch','block-113898','Html_box','',4),(113902,'75428','watch','block-113898','Html_box','',1),(113903,'75429','watch','block-113898','order\\Telephone','',8),(113904,'75430','watch','block-113898','Html_box','',6),(113905,'75431','watch','block-113898','order\\Name','',7),(113906,'75432','watch','block-113898','order\\Email','',9),(113907,'75433','watch','block-113898','order\\DeliveryAddress','',3),(113908,'75434','watch','block-113897-2','BlockBox','',1),(113909,'75435','watch','block-113908','order\\BillingAddress','',3),(113910,'75436','watch','block-113908','UpdateAndPay\\PayConfirm','',5),(113911,'75437','watch','block-113908','Html_box','',1),(113912,'75438','watch','block-113908','Html_box','',2),(113913,'75439','watch','block-113908','Html_box','',4),(113914,'75440','watch','block-113896','BlockBox','',3),(113915,'75441','watch','block-113914','order\\Products','',2),(113916,'75442','watch','block-113914','Html_box','',1),(113917,'75443','watch','block-113895-2','BlockBox','',1),(113918,'75444','watch','block-113917','Html_box','',1),(113919,'75445','watch','block-113917','checkout\\ContinueBtn','',3),(113920,'75446','watch','block-113917','order\\Totals','',2),(113921,'75447','watch','block-113894','account\\OrderHeading','',1),(113922,'75448','watch','update-and-pay-order_pay','BlockBox','',1),(113923,'75449','watch','block-113922','BlockBox','',3),(113924,'75450','watch','block-113923','BlockBox','',1),(113925,'75451','watch','block-113924','BlockBox','',1),(113926,'75452','watch','block-113925','BlockBox','',1),(113927,'75453','watch','block-113926','order\\DeliveryAddress','',3),(113928,'75454','watch','block-113926','order\\Email','',9),(113929,'75455','watch','block-113926','order\\Name','',7),(113930,'75456','watch','block-113926','Html_box','',6),(113931,'75457','watch','block-113926','order\\Telephone','',8),(113932,'75458','watch','block-113926','Html_box','',4),(113933,'75459','watch','block-113926','order\\ShippingMethod','',5),(113934,'75460','watch','block-113926','Html_box','',1),(113935,'75461','watch','block-113926','Html_box','',2),(113936,'75462','watch','block-113925-2','BlockBox','',1),(113937,'75463','watch','block-113936','Html_box','',1),(113938,'75464','watch','block-113936','Html_box','',2),(113939,'75465','watch','block-113936','Html_box','',4),(113940,'75466','watch','block-113936','order\\BillingAddress','',3),(113941,'75467','watch','block-113936','UpdateAndPay\\PayForm','',5),(113942,'75468','watch','block-113924','BlockBox','',3),(113943,'75469','watch','block-113942','Html_box','',1),(113944,'75470','watch','block-113942','order\\Products','',2),(113945,'75471','watch','block-113923-2','BlockBox','',1),(113946,'75472','watch','block-113945','order\\Totals','',2),(113947,'75473','watch','block-113945','checkout\\ContinueBtn','',3),(113948,'75474','watch','block-113945','Html_box','',1),(113949,'75475','watch','block-113922','account\\OrderHeading','',1),(113950,'75540','watch','wishlist','BlockBox','',1),(113951,'75541','watch','block-113950','BlockBox','',1),(113952,'75542','watch','block-113951','WidgetsAria','',1),(113972,'75543','watch','block-113951-2','account\\Wishlist','',2),(113973,'75544','watch','block-113951-2','Html_box','',1),(113974,'75545','watch','wishlist-cart','BlockBox','',1),(113975,'75546','watch','block-113974','cart\\CartTabs','',1),(113976,'75547','watch','block-113975','account\\Wishlist','',1),(113977,'116005','printshop','404','Html_box','',1),(114205,'117906.000001','printshop','b2b','BlockBox','listing-item',1),(114206,'117907.000001','printshop','block-114205','BlockBox','',2),(114207,'117908.000001','printshop','block-114206','BlockBox','',2),(114208,'117909.000001','printshop','block-114207','productListing\\bonusPoints','',2),(114209,'117910.000001','printshop','block-114207','productListing\\image','',1),(114210,'117914.000001','printshop','block-114207-2','productListing\\name','',1),(114211,'117915.000001','printshop','block-114207-2','productListing\\description','',2),(114212,'117916.000001','printshop','block-114207-2','productListing\\model','',4),(114213,'117917.000001','printshop','block-114207-2','productListing\\attributes','',5),(114214,'120922.000001','printshop','block-114207-2','productListing\\properties','',3),(114215,'117918.000001','printshop','block-114206-2','BlockBox','',1),(114216,'117911.000001','printshop','block-114215','BlockBox','',3),(114217,'117912.000001','printshop','block-114216','productListing\\rating','',1),(114218,'117913.000001','printshop','block-114216','productListing\\ratingCounts','',2),(114219,'117919.000001','printshop','block-114215','productListing\\qtyInput','',4),(114220,'117920.000001','printshop','block-114215','productListing\\price','',2),(114221,'117922.000001','printshop','block-114215','productListing\\buyButton','',5),(114222,'117924.000001','printshop','block-114215','productListing\\stock','',1),(114223,'120925.000001','printshop','block-114215','productListing\\compare','',8),(114224,'120926.000001','printshop','block-114215','productListing\\personalCatalog','',7),(114225,'120927.000001','printshop','block-114215','productListing\\viewButton','',6),(114226,'116176','printshop','batch','BlockBox','',1),(114227,'116177','printshop','block-114226','productListing\\attributes','',5),(114228,'116178','printshop','block-114226','productListing\\price','',6),(114229,'116179','printshop','block-114226','productListing\\name','',4),(114230,'116180','printshop','block-114226','productListing\\image','',2),(114231,'116181','printshop','block-114226','batchSelect','',1),(114232,'116182','printshop','batch_selected','BlockBox','',1),(114233,'116183','printshop','block-114232','BlockBox','',13),(114234,'116184','printshop','block-114233','productListing\\image','',1),(114235,'116185','printshop','block-114233-2','batchRemove','',1),(114236,'116186','printshop','block-114233-2','productListing\\price','',3),(114237,'116187','printshop','block-114233-2','productListing\\name','',2),(114238,'116188','printshop','bbbbb','BlockBox','',1),(114239,'116189','printshop','block-114238','BlockBox','',2),(114240,'116190','printshop','block-114239','Filters','',1),(114241,'116191','printshop','block-114239-2','BlockBox','',6),(114242,'116192','printshop','block-114241','catalog\\CountsItems','',1),(114243,'116193','printshop','block-114241-2','catalog\\Paging','',1),(114244,'116194','printshop','block-114239-2','catalog\\Image','',1),(114245,'116195','printshop','block-114239-2','Listing','',5),(114246,'116196','printshop','block-114239-2','catalog\\ImageMapCategory','',3),(114247,'116197','printshop','block-114239-2','BlockBox','',4),(114248,'116198','printshop','block-114247','catalog\\ListingLook','',1),(114249,'116199','printshop','block-114247','catalog\\CompareButton','',2),(114250,'116200','printshop','block-114247','catalog\\ItemsOnPage','',4),(114251,'116201','printshop','block-114247','catalog\\Sorting','',3),(114252,'116202','printshop','block-114239-2','Categories','',2),(114253,'116203','printshop','block-114238','catalog\\Title','',1),(114254,'1683121571.054367','printshop','cart','BlockBox','',1),(114255,'1683121571.06664','printshop','block-114254','BlockBox','',2),(114256,'1683121571.069437','printshop','block-114255','BlockBox','cart-content',4),(114257,'1683121571.078735','printshop','block-114255','BlockBox','',1),(114258,'1683121571.080729','printshop','block-114257','cart\\Products','',4),(114259,'1683121571.081549','printshop','block-114257','BlockBox','',3),(114260,'1683121571.08463','printshop','block-114259','MultiCart\\CartSwitcher','',1),(114261,'1683121571.085411','printshop','block-114259','MultiCart\\SaveCart','',2),(114262,'1683121571.086647','printshop','block-114259-2','MultiCart\\Actions','',1),(114263,'1683121571.087562','printshop','block-114257','BlockBox','',5),(114264,'1683121571.088844','printshop','block-114263','BlockBox','',3),(114265,'1683121571.089839','printshop','block-114264','cart\\CreditAmount','',2),(114266,'1683121571.09021','printshop','block-114264-2','cart\\BonusPoints','',1),(114267,'1683121571.090954','printshop','block-114257','Html_box','',2),(114268,'1683121571.092944','printshop','block-114255','cart\\ShippingEstimator','',5),(114269,'1683121571.09410','printshop','block-114255-2','BlockBox','',1),(114270,'1683121571.095515','printshop','block-114269','BlockBox','',2),(114271,'1683121571.096422','printshop','block-114270','cart\\DiscountCoupon','',1),(114272,'1683121571.107437','printshop','block-114270','cart\\CheckoutBtn','',3),(114273,'1683121571.108775','printshop','block-114270','cart\\OrderTotal','',2),(114274,'1683121571.109664','printshop','block-114270','cart\\OrderTotal','',0),(114275,'1683121571.110832','printshop','block-114269','Html_box','',1),(114276,'116242','printshop','cart2','BlockBox','',2),(114277,'116243','printshop','block-114276','cart\\CartTabs','',2),(114278,'116244','printshop','block-114277','BlockBox','',1),(114279,'116245','printshop','block-114278','BlockBox','',4),(114280,'116246','printshop','block-114279','cart\\UpSell','6',2),(114281,'116247','printshop','block-114279','Html_box','',1),(114282,'116248','printshop','block-114278','BlockBox','',1),(114283,'116249','printshop','block-114282','cart\\Products','',3),(114284,'116250','printshop','block-114282','BlockBox','',2),(114285,'116251','printshop','block-114284','MultiCart\\CartSwitcher','',1),(114286,'116252','printshop','block-114284','MultiCart\\SaveCart','',2),(114287,'116253','printshop','block-114284-2','MultiCart\\Actions','',1),(114288,'116254','printshop','block-114278','BlockBox','',3),(114289,'116255','printshop','block-114288','cart\\GiveAway','',2),(114290,'116256','printshop','block-114288','Html_box','',1),(114291,'116257','printshop','block-114278','BlockBox','',2),(114292,'116258','printshop','block-114291','Html_box','',1),(114293,'116259','printshop','block-114291','BlockBox','',2),(114294,'116260','printshop','block-114293','cart\\DiscountCoupon','',1),(114295,'116261','printshop','block-114293-2','cart\\CreditAmount','',1),(114296,'116262','printshop','block-114293-3','cart\\BonusPoints','',1),(114297,'116263','printshop','block-114278','BlockBox','',5),(114298,'116264','printshop','block-114297','Html_box','',1),(114299,'116265','printshop','block-114297','cart\\ShippingEstimator','',2),(114300,'116266','printshop','block-114278-2','BlockBox','',1),(114301,'116267','printshop','block-114300','Html_box','',1),(114302,'116268','printshop','block-114300','BlockBox','',2),(114303,'116269','printshop','block-114302','Image','',4),(114304,'116270','printshop','block-114302','cart\\CheckoutBtn','',2),(114305,'116271','printshop','block-114302','cart\\OrderTotal','',1),(114316,'116272','printshop','categories','BlockBox','catalog-content',2),(114317,'116281','printshop','block-114316','Categories','',2),(114318,'116287','printshop','block-114316','catalog\\Title','',1),(114319,'1644410221.0341','printshop','categories','BlockBox','',1),(114320,'1644410246.7393','printshop','block-114319','Breadcrumb','',0),(114321,'116288','printshop','category','Categories','',1),(114322,'116289','printshop','category','Listing','',4),(114323,'116290','printshop','category','ListingFunctionality','',2),(114324,'116291','printshop','category','PagingBar','',3),(114325,'116292','printshop','category','PagingBar','',5),(114326,'116293','printshop','category_2','BlockBox','',1),(114327,'116294','printshop','block-114326','catalog\\Title','',1),(114328,'116295','printshop','block-114326','BlockBox','',2),(114329,'116296','printshop','block-114328','Filters','',1),(114330,'116297','printshop','block-114328-2','catalog\\Image','',1),(114331,'116298','printshop','block-114328-2','Listing','',5),(114332,'116299','printshop','block-114328-2','BlockBox','',4),(114333,'116300','printshop','block-114332','catalog\\Sorting','',3),(114334,'116301','printshop','block-114332','catalog\\ItemsOnPage','',4),(114335,'116302','printshop','block-114332','catalog\\CompareButton','',2),(114336,'116303','printshop','block-114332','catalog\\ListingLook','',1),(114337,'116304','printshop','block-114328-2','catalog\\ImageMapCategory','',3),(114338,'116305','printshop','block-114328-2','Categories','',2),(114339,'116306','printshop','block-114328-2','BlockBox','',6),(114340,'116307','printshop','block-114339','catalog\\CountsItems','',1),(114341,'116308','printshop','block-114339-2','catalog\\Paging','',1),(114342,'116309','printshop','category_no_filters','BlockBox','catalog-content',2),(114343,'116310','printshop','block-114342','catalog\\Title','',2),(114344,'116311','printshop','block-114342','Categories','',4),(114345,'116312','printshop','block-114342','BlockBox','catalog-features',5),(114346,'116313','printshop','block-114345','catalog\\ItemsOnPage','',4),(114347,'116314','printshop','block-114345','catalog\\Sorting','',3),(114348,'116315','printshop','block-114345','catalog\\CompareButton','',2),(114349,'116316','printshop','block-114345','catalog\\ListingLook','',1),(114350,'116317','printshop','block-114345','HeaderStock','',5),(114351,'116318','printshop','block-114342','BlockBox','',7),(114352,'116319','printshop','block-114351','catalog\\CountsItems','',1),(114353,'116320','printshop','block-114351-2','catalog\\Paging','',1),(114354,'116321','printshop','block-114342','Listing','',6),(114355,'116322','printshop','block-114342','catalog\\Image','',3),(114356,'116323','printshop','block-114342','catalog\\B2bAddButton','',8),(114357,'1645199413.4466','printshop','category_no_filters','BlockBox','',1),(114358,'1645199453.4261','printshop','block-114357','Breadcrumb','',0),(114359,'1683123155.763578','printshop','checkout','BlockBox','',2),(114360,'1683123155.780265','printshop','block-114359','BlockBox','',2),(114361,'1683123155.783425','printshop','block-114360','BlockBox','',2),(114362,'1683123155.78537','printshop','block-114361','BlockBox','checkout-comments',4),(114363,'1683123155.788891','printshop','block-114362','checkout\\Comments','',2),(114364,'1683123155.790851','printshop','block-114362','Html_box','',1),(114365,'1683123155.79411','printshop','block-114361','BlockBox','checkout-discount',3),(114366,'1683123155.797477','printshop','block-114365','Html_box','',1),(114367,'1683123155.799115','printshop','block-114365','BlockBox','',2),(114368,'1683123155.800526','printshop','block-114367','CouponsAndVauchers\\Checkout','',1),(114369,'1683123155.802510','printshop','block-114367-2','checkout\\CreditAmount','',1),(114370,'1683123155.804496','printshop','block-114367-2','checkout\\BonusPoints','',2),(114371,'1683123155.806347','printshop','block-114361','BlockBox','checkout-shipping',1),(114372,'1683123155.808713','printshop','block-114371','BlockBox','',3),(114373,'1683123155.81126','printshop','block-114372','checkout\\ShippingChoice','',1),(114374,'1683123155.81663','printshop','block-114371','Neighbour\\Checkout','',5),(114375,'1683123155.81847','printshop','block-114371','BlockBox','',4),(114376,'1683123155.819772','printshop','block-114375','BlockBox','',1),(114377,'1683123155.821777','printshop','block-114376','checkout\\ShippingAddress','',2),(114378,'1683123155.824396','printshop','block-114376','Html_box','',3),(114379,'1683123155.825857','printshop','block-114376','checkout\\ContactInformation','',4),(114380,'1683123155.827441','printshop','block-114376','UploadCustomerId\\UploadCustomerIdForm','',5),(114381,'1683123155.830610','printshop','block-114375-2','BlockBox','',1),(114382,'1683123155.83245','printshop','block-114381','checkout\\Shipping','',2),(114383,'1683123155.833668','printshop','block-114381','DelayedDespatch\\Checkout','',4),(114384,'1683123155.835296','printshop','block-114381','Html_box','',1),(114385,'1683123155.83711','printshop','block-114381','DeliveryDay','',3),(114386,'1683123155.840722','printshop','block-114371','Html_box','',2),(114387,'1683123155.842595','printshop','block-114361','cart\\Products','',6),(114388,'1683123155.846131','printshop','block-114361','checkout\\CreateAccount','',7),(114389,'1683123155.849743','printshop','block-114361','DeliveryOptions\\Checkout','',5),(114390,'1683123155.851776','printshop','block-114361','BlockBox','checkout-payment',2),(114391,'1683123155.855125','printshop','block-114390','Html_box','',1),(114392,'1683123155.856899','printshop','block-114390','BlockBox','',2),(114393,'1683123155.858186','printshop','block-114392','Html_box','',1),(114394,'1683123155.859329','printshop','block-114392','checkout\\BillingAddress','',2),(114395,'1683123155.863160','printshop','block-114392-2','BlockBox','',1),(114396,'1683123155.864648','printshop','block-114395','checkout\\PaymentMethod','',2),(114397,'1683123155.866124','printshop','block-114395','Html_box','',1),(114398,'1683123155.867656','printshop','block-114361','BlockBox','',0),(114399,'1683123155.869487','printshop','block-114398','checkout\\LoginOnForm','',0),(114400,'1683123155.87110','printshop','block-114360-2','BlockBox','checkout-side',1),(114401,'1683123155.877884','printshop','block-114400','Html_box','',6),(114402,'1683123155.879734','printshop','block-114400','Html_box','',1),(114403,'1683123155.881441','printshop','block-114400','checkout\\Terms','',5),(114404,'1683123155.883138','printshop','block-114400','checkout\\Totals','',3),(114405,'1683123155.88477','printshop','block-114400','checkout\\ContinueBtn','',4),(114406,'1683123155.887325','printshop','block-114400','cart\\Products','',2),(114407,'116368','printshop','checkout_confirmation','BlockBox','',1),(114408,'116369','printshop','block-114407','checkout\\Totals','',8),(114409,'116370','printshop','block-114407','Html_box','',5),(114410,'116371','printshop','block-114407','checkout\\EditBtn','',6),(114411,'116372','printshop','block-114407','BlockBox','',3),(114412,'116373','printshop','block-114411','BlockBox','',1),(114413,'116374','printshop','block-114412','Html_box','',1),(114414,'116375','printshop','block-114412','checkout\\ShippingConfirm','',3),(114415,'116376','printshop','block-114411-2','BlockBox','',1),(114416,'116377','printshop','block-114415','checkout\\PaymentMethodConfirm','',3),(114417,'116378','printshop','block-114415','Html_box','',1),(114418,'116379','printshop','block-114407','checkout\\ConfirmBtn','',9),(114419,'116380','printshop','block-114407','BlockBox','',2),(114420,'116381','printshop','block-114419','BlockBox','',1),(114421,'116382','printshop','block-114420','checkout\\ShippingAddressConfirm','',3),(114422,'116383','printshop','block-114420','Html_box','',1),(114423,'116384','printshop','block-114419-2','BlockBox','',1),(114424,'116385','printshop','block-114423','Html_box','',1),(114425,'116386','printshop','block-114423','checkout\\BillingAddressConfirm','',3),(114426,'116387','printshop','block-114407','checkout\\ConfirmBtn','',4),(114427,'116388','printshop','block-114407','cart\\Products','',7),(114428,'116402','printshop','checkout_confirmation_no_shipping','BlockBox','',1),(114429,'116403','printshop','block-114428','checkout\\ConfirmBtn','',9),(114430,'116404','printshop','block-114428','BlockBox','',2),(114431,'116405','printshop','block-114430','BlockBox','',1),(114432,'116406','printshop','block-114431','Html_box','',1),(114433,'116407','printshop','block-114431','checkout\\BillingAddressConfirm','',3),(114434,'116408','printshop','block-114430-2','BlockBox','',1),(114435,'116409','printshop','block-114434','Html_box','',1),(114436,'116410','printshop','block-114434','checkout\\PaymentMethodConfirm','',3),(114437,'116411','printshop','block-114428','checkout\\ConfirmBtn','',4),(114438,'116412','printshop','block-114428','checkout\\Totals','',8),(114439,'116413','printshop','block-114428','cart\\Products','',7),(114440,'116414','printshop','block-114428','Html_box','',5),(114441,'116389','printshop','checkout_confirmation_no_shipping_q','BlockBox','',1),(114442,'116390','printshop','block-114441','quote\\Products','',4),(114443,'116391','printshop','block-114441','checkout\\ConfirmBtn','',2),(114444,'116392','printshop','block-114441','checkout\\ConfirmBtn','',6),(114445,'116393','printshop','block-114441','BlockBox','',1),(114446,'116394','printshop','block-114445','BlockBox','',1),(114447,'116395','printshop','block-114446','checkout\\BillingAddressConfirm','',3),(114448,'116396','printshop','block-114446','Html_box','',1),(114449,'116397','printshop','block-114445-2','BlockBox','',1),(114450,'116398','printshop','block-114449','checkout\\PaymentMethodConfirm','',3),(114451,'116399','printshop','block-114449','Html_box','',1),(114452,'116400','printshop','block-114441','Html_box','',3),(114453,'116401','printshop','block-114441','checkout\\Totals','',5),(114454,'116415','printshop','checkout_confirmation_q','BlockBox','',1),(114455,'116416','printshop','block-114454','BlockBox','',1),(114456,'116417','printshop','block-114455','BlockBox','',1),(114457,'116418','printshop','block-114456','checkout\\ShippingAddressConfirm','',3),(114458,'116419','printshop','block-114456','Html_box','',1),(114459,'116420','printshop','block-114455-2','BlockBox','',1),(114460,'116421','printshop','block-114459','checkout\\BillingAddressConfirm','',3),(114461,'116422','printshop','block-114459','Html_box','',1),(114462,'116423','printshop','block-114454','checkout\\Totals','',7),(114463,'116424','printshop','block-114454','quote\\Products','',6),(114464,'116425','printshop','block-114454','Html_box','',4),(114465,'116426','printshop','block-114454','checkout\\EditBtn','',5),(114466,'116427','printshop','block-114454','checkout\\ConfirmBtn','',8),(114467,'116428','printshop','block-114454','checkout\\ConfirmBtn','',3),(114468,'116429','printshop','block-114454','BlockBox','',2),(114469,'116430','printshop','block-114468','BlockBox','',1),(114470,'116431','printshop','block-114469','Html_box','',1),(114471,'116432','printshop','block-114469','checkout\\ShippingConfirm','',3),(114472,'116433','printshop','block-114468-2','BlockBox','',1),(114473,'116434','printshop','block-114472','Html_box','',1),(114474,'116435','printshop','block-114472','checkout\\PaymentMethodConfirm','',3),(114475,'116436','printshop','checkout_confirmation_title','Html_box','',1),(114476,'116437','printshop','checkout_confirmation_title_g','Html_box','',1),(114477,'116439','printshop','checkout_confirmation_title_no_shipping','Html_box','',1),(114478,'116438','printshop','checkout_confirmation_title_no_shipping_g','Html_box','',1),(114479,'116440','printshop','checkout_confirmation_title_q','Html_box','',1),(114480,'116441','printshop','checkout_confirmation_title_s','Html_box','',1),(114481,'116442','printshop','checkout_delivery','BlockBox','',2),(114482,'116443','printshop','block-114481','BlockBox','',1),(114483,'116444','printshop','block-114482','Html_box','',1),(114484,'116445','printshop','block-114482','checkout\\ContactInformation','',2),(114485,'116446','printshop','block-114481-2','BlockBox','',1),(114486,'116447','printshop','block-114485','Html_box','',1),(114487,'116448','printshop','block-114485','checkout\\Comments','',2),(114488,'116449','printshop','checkout_delivery','BlockBox','',3),(114489,'116450','printshop','block-114488','Html_box','',1),(114490,'116451','printshop','block-114488-2','checkout\\ContinueBtn','',1),(114491,'116452','printshop','checkout_delivery','BlockBox','',1),(114492,'116453','printshop','block-114491','BlockBox','',1),(114493,'116454','printshop','block-114492','Html_box','',1),(114494,'116455','printshop','block-114492','checkout\\ShippingAddress','',2),(114495,'116456','printshop','block-114491-2','BlockBox','',1),(114496,'116457','printshop','block-114495','DelayedDespatch\\Checkout','',3),(114497,'116458','printshop','block-114495','checkout\\Shipping','',2),(114498,'116459','printshop','block-114495','Html_box','',1),(114499,'116460','printshop','block-114495','Neighbour\\Checkout','',4),(114500,'116461','printshop','checkout_delivery_g','BlockBox','',2),(114501,'116462','printshop','block-114500','BlockBox','',1),(114502,'116463','printshop','block-114501','checkout\\ContactInformation','',2),(114503,'116464','printshop','block-114501','Html_box','',1),(114504,'116465','printshop','block-114500-2','BlockBox','',1),(114505,'116466','printshop','block-114504','Html_box','',1),(114506,'116467','printshop','block-114504','checkout\\Comments','',2),(114507,'116468','printshop','checkout_delivery_g','BlockBox','',3),(114508,'116469','printshop','block-114507','Html_box','',1),(114509,'116470','printshop','block-114507-2','checkout\\ContinueBtn','',1),(114510,'116471','printshop','checkout_delivery_g','BlockBox','',1),(114511,'116472','printshop','block-114510','BlockBox','',1),(114512,'116473','printshop','block-114511','checkout\\ShippingAddress','',2),(114513,'116474','printshop','block-114511','Html_box','',1),(114514,'116475','printshop','block-114510-2','BlockBox','',1),(114515,'116476','printshop','block-114514','checkout\\Shipping','',2),(114516,'116477','printshop','block-114514','Html_box','',1),(114517,'116478','printshop','block-114514','DelayedDespatch\\Checkout','',3),(114518,'116479','printshop','block-114514','Neighbour\\Checkout','',4),(114519,'116480','printshop','checkout_delivery_no_shipping','BlockBox','',2),(114520,'116481','printshop','block-114519','Html_box','',1),(114521,'116482','printshop','block-114519-2','checkout\\ContinueBtn','',1),(114522,'116483','printshop','checkout_delivery_no_shipping','BlockBox','',1),(114523,'116484','printshop','block-114522','BlockBox','',1),(114524,'116485','printshop','block-114523','checkout\\ContactInformation','',2),(114525,'116486','printshop','block-114522-2','BlockBox','',1),(114526,'116487','printshop','block-114525','Html_box','',1),(114527,'116488','printshop','block-114525','checkout\\Comments','',2),(114528,'116489','printshop','checkout_delivery_no_shipping_g','BlockBox','',2),(114529,'116490','printshop','block-114528','Html_box','',1),(114530,'116491','printshop','block-114528-2','checkout\\ContinueBtn','',1),(114531,'116492','printshop','checkout_delivery_no_shipping_g','BlockBox','',1),(114532,'116493','printshop','block-114531','BlockBox','',1),(114533,'116494','printshop','block-114532','checkout\\ContactInformation','',2),(114534,'116495','printshop','block-114531-2','BlockBox','',1),(114535,'116496','printshop','block-114534','checkout\\Comments','',2),(114536,'116497','printshop','block-114534','Html_box','',1),(114537,'116498','printshop','checkout_delivery_title','Html_box','',1),(114538,'116499','printshop','checkout_delivery_title_g','Html_box','',1),(114539,'116501','printshop','checkout_delivery_title_no_shipping','Html_box','',1),(114540,'116500','printshop','checkout_delivery_title_no_shipping_g','Html_box','',1),(114541,'116502','printshop','checkout_delivery_title_q','Html_box','',1),(114542,'116503','printshop','checkout_delivery_title_s','Html_box','',1),(114543,'116504','printshop','checkout_free_s','BlockBox','',1),(114544,'116505','printshop','block-114543','BlockBox','',2),(114545,'116506','printshop','block-114544','BlockBox','',2),(114546,'116508','printshop','block-114545','BlockBox','',6),(114547,'116509','printshop','block-114546','sample\\Products','',1),(114548,'116510','printshop','block-114546','checkout\\CreateAccount','',3),(114549,'116511','printshop','block-114545','BlockBox','',5),(114550,'116512','printshop','block-114549','Html_box','',1),(114551,'116513','printshop','block-114549','checkout\\Comments','',2),(114552,'116514','printshop','block-114545','BlockBox','',2),(114553,'116515','printshop','block-114552','BlockBox','',2),(114554,'116516','printshop','block-114553','checkout\\ShippingChoice','',1),(114555,'116517','printshop','block-114552','Html_box','',1),(114556,'116518','printshop','block-114552','BlockBox','',3),(114557,'116519','printshop','block-114556','BlockBox','',1),(114558,'116520','printshop','block-114557','checkout\\ContactInformation','',4),(114559,'116521','printshop','block-114557','checkout\\ShippingAddress','',2),(114560,'116522','printshop','block-114557','Html_box','',3),(114561,'116523','printshop','block-114556-2','BlockBox','',1),(114562,'116524','printshop','block-114561','DelayedDespatch\\Checkout','',3),(114563,'116525','printshop','block-114552','Neighbour\\Checkout','',4),(114564,'116526','printshop','block-114544-2','BlockBox','',1),(114565,'116527','printshop','block-114564','Html_box','',3),(114566,'116528','printshop','block-114564','checkout\\ContinueBtn','',1),(114567,'1638956949.0762','printshop','block-114564','checkout\\Terms','',2),(114568,'1638957135.2709','printshop','block-114564','Html_box','',0),(114569,'116529','printshop','checkout_no_shipping','BlockBox','',1),(114570,'116530','printshop','block-114569','BlockBox','',2),(114571,'116531','printshop','block-114570','BlockBox','',1),(114572,'116532','printshop','block-114571','BlockBox','',6),(114573,'116533','printshop','block-114572','checkout\\CreateAccount','',2),(114574,'116534','printshop','block-114572','cart\\Products','',1),(114575,'116535','printshop','block-114571','BlockBox','',3),(114576,'116536','printshop','block-114575','Html_box','',1),(114577,'116537','printshop','block-114575','BlockBox','',2),(114578,'116538','printshop','block-114577','checkout\\BillingAddress','',2),(114579,'116539','printshop','block-114577','Html_box','',1),(114580,'116540','printshop','block-114577-2','BlockBox','',1),(114581,'116541','printshop','block-114580','Html_box','',1),(114582,'116542','printshop','block-114580','checkout\\PaymentMethod','',2),(114583,'116543','printshop','block-114571','BlockBox','',4),(114584,'116544','printshop','block-114583','BlockBox','',2),(114585,'116545','printshop','block-114584','CouponsAndVauchers\\Checkout','',1),(114586,'116546','printshop','block-114584-2','checkout\\CreditAmount','',1),(114587,'116547','printshop','block-114584-2','checkout\\BonusPoints','',2),(114588,'116548','printshop','block-114583','Html_box','',1),(114589,'116549','printshop','block-114571','BlockBox','',5),(114590,'116550','printshop','block-114589','checkout\\Comments','',2),(114591,'116551','printshop','block-114589','Html_box','',1),(114592,'116552','printshop','block-114570-2','BlockBox','',1),(114593,'116553','printshop','block-114592','Html_box','',1),(114594,'116554','printshop','block-114592','Html_box','',5),(114595,'116555','printshop','block-114592','checkout\\Totals','',2),(114596,'116556','printshop','block-114592','checkout\\ContinueBtn','',3),(114597,'116557','printshop','block-114592','checkout\\Terms','',4),(114598,'116558','printshop','checkout_no_shipping_g','BlockBox','',1),(114599,'116559','printshop','block-114598','checkout\\Totals','',5),(114600,'116560','printshop','block-114598','BlockBox','',6),(114601,'116561','printshop','block-114600','Html_box','',1),(114602,'116562','printshop','block-114600-2','checkout\\ContinueBtn','',1),(114603,'116563','printshop','block-114598','BlockBox','',2),(114604,'116564','printshop','block-114603','BlockBox','',1),(114605,'116565','printshop','block-114604','checkout\\ContactInformation','',2),(114606,'116566','printshop','block-114604','Html_box','',1),(114607,'116567','printshop','block-114603-2','BlockBox','',1),(114608,'116568','printshop','block-114607','checkout\\Comments','',2),(114609,'116569','printshop','block-114607','Html_box','',1),(114610,'116570','printshop','block-114598','BlockBox','',1),(114611,'116571','printshop','block-114610','BlockBox','',1),(114612,'116572','printshop','block-114611','Html_box','',1),(114613,'116573','printshop','block-114611','checkout\\BillingAddress','',2),(114614,'116574','printshop','block-114610-2','BlockBox','',1),(114615,'116575','printshop','block-114614','checkout\\BonusPoints','',4),(114616,'116576','printshop','block-114614','CouponsAndVauchers\\Checkout','',5),(114617,'116577','printshop','block-114614','checkout\\PaymentMethod','',2),(114618,'116578','printshop','block-114614','checkout\\CreditAmount','',3),(114619,'116579','printshop','block-114614','Html_box','',1),(114620,'116580','printshop','block-114598','quote\\Products','',3),(114621,'116581','printshop','checkout_no_shipping_q','BlockBox','',1),(114622,'116582','printshop','block-114621','BlockBox','',2),(114623,'116583','printshop','block-114622','BlockBox','',2),(114624,'116585','printshop','block-114623','BlockBox','',5),(114625,'116586','printshop','block-114624','checkout\\Comments','',2),(114626,'116587','printshop','block-114624','Html_box','',1),(114627,'116588','printshop','block-114623','BlockBox','',6),(114628,'116589','printshop','block-114627','checkout\\CreateAccount','',3),(114629,'116590','printshop','block-114627','quote\\Products','',2),(114630,'116591','printshop','block-114623','BlockBox','',3),(114631,'116592','printshop','block-114630','Html_box','',1),(114632,'116593','printshop','block-114630','BlockBox','',2),(114633,'116594','printshop','block-114632','Html_box','',1),(114634,'116595','printshop','block-114632','checkout\\BillingAddress','',2),(114635,'116596','printshop','block-114632-2','BlockBox','',1),(114636,'116597','printshop','block-114635','checkout\\PaymentMethod','',2),(114637,'116598','printshop','block-114635','Html_box','',1),(114638,'116599','printshop','block-114622-2','BlockBox','',1),(114639,'116600','printshop','block-114638','checkout\\ContinueBtn','',3),(114640,'116601','printshop','block-114638','Html_box','',5),(114641,'116602','printshop','block-114638','Html_box','',1),(114642,'116603','printshop','block-114638','checkout\\Totals','',2),(114643,'120984','printshop','block-114638','checkout\\Terms','',4),(114644,'116604','printshop','checkout_payment','BlockBox','',1),(114645,'116605','printshop','block-114644','BlockBox','',1),(114646,'116606','printshop','block-114645','checkout\\BillingAddress','',2),(114647,'116607','printshop','block-114645','Html_box','',1),(114648,'116608','printshop','block-114644-2','BlockBox','',1),(114649,'116609','printshop','block-114648','checkout\\CreditAmount','',3),(114650,'116610','printshop','block-114648','checkout\\BonusPoints','',4),(114651,'116611','printshop','block-114648','CouponsAndVauchers\\Checkout','',5),(114652,'116612','printshop','block-114648','checkout\\PaymentMethod','',2),(114653,'116613','printshop','block-114648','Html_box','',1),(114654,'116614','printshop','checkout_payment','BlockBox','',2),(114655,'116615','printshop','block-114654','Html_box','',1),(114656,'116616','printshop','block-114654-2','checkout\\ContinueBtn','',1),(114657,'116617','printshop','checkout_payment_g','BlockBox','',1),(114658,'116618','printshop','block-114657','BlockBox','',1),(114659,'116619','printshop','block-114658','checkout\\BillingAddress','',2),(114660,'116620','printshop','block-114658','Html_box','',1),(114661,'116621','printshop','block-114657-2','BlockBox','',1),(114662,'116622','printshop','block-114661','checkout\\CreditAmount','',3),(114663,'116623','printshop','block-114661','Html_box','',1),(114664,'116624','printshop','block-114661','checkout\\PaymentMethod','',2),(114665,'116625','printshop','block-114661','CouponsAndVauchers\\Checkout','',5),(114666,'116626','printshop','block-114661','checkout\\BonusPoints','',4),(114667,'116627','printshop','checkout_payment_g','BlockBox','',2),(114668,'116628','printshop','block-114667','Html_box','',1),(114669,'116629','printshop','block-114667-2','checkout\\ContinueBtn','',1),(114670,'116630','printshop','checkout_payment_no_shipping','BlockBox','',2),(114671,'116631','printshop','block-114670','Html_box','',1),(114672,'116632','printshop','block-114670-2','checkout\\ContinueBtn','',1),(114673,'116633','printshop','checkout_payment_no_shipping','BlockBox','',1),(114674,'116634','printshop','block-114673','BlockBox','',1),(114675,'116635','printshop','block-114674','Html_box','',1),(114676,'116636','printshop','block-114674','checkout\\BillingAddress','',2),(114677,'116637','printshop','block-114673-2','BlockBox','',1),(114678,'116638','printshop','block-114677','checkout\\BonusPoints','',4),(114679,'116639','printshop','block-114677','CouponsAndVauchers\\Checkout','',5),(114680,'116640','printshop','block-114677','checkout\\PaymentMethod','',2),(114681,'116641','printshop','block-114677','checkout\\CreditAmount','',3),(114682,'116642','printshop','block-114677','Html_box','',1),(114683,'116643','printshop','checkout_payment_no_shipping_g','BlockBox','',2),(114684,'116644','printshop','block-114683','Html_box','',1),(114685,'116645','printshop','block-114683-2','checkout\\ContinueBtn','',1),(114686,'116646','printshop','checkout_payment_no_shipping_g','BlockBox','',1),(114687,'116647','printshop','block-114686','BlockBox','',1),(114688,'116648','printshop','block-114687','checkout\\BillingAddress','',2),(114689,'116649','printshop','block-114687','Html_box','',1),(114690,'116650','printshop','block-114686-2','BlockBox','',1),(114691,'116651','printshop','block-114690','checkout\\BonusPoints','',4),(114692,'116652','printshop','block-114690','checkout\\CreditAmount','',3),(114693,'116653','printshop','block-114690','checkout\\PaymentMethod','',2),(114694,'116654','printshop','block-114690','Html_box','',1),(114695,'116655','printshop','block-114690','CouponsAndVauchers\\Checkout','',5),(114696,'116656','printshop','checkout_payment_title','Html_box','',1),(114697,'116657','printshop','checkout_payment_title_g','Html_box','',1),(114698,'116658','printshop','checkout_payment_title_no_shipping','Html_box','',1),(114699,'116659','printshop','checkout_payment_title_no_shipping_g','Html_box','',1),(114700,'116660','printshop','checkout_payment_title_q','Html_box','',1),(114701,'116661','printshop','checkout_payment_title_s','Html_box','',1),(114702,'120947','printshop','checkout_q','BlockBox','',1),(114703,'120948','printshop','block-114702','BlockBox','',2),(114704,'120949','printshop','block-114703','BlockBox','',2),(114705,'120950','printshop','block-114704','BlockBox','',6),(114706,'120951','printshop','block-114705','checkout\\CreateAccount','',3),(114707,'120952','printshop','block-114705','quote\\Products','',2),(114708,'120953','printshop','block-114704','BlockBox','',2),(114709,'120954','printshop','block-114708','BlockBox','',2),(114710,'120955','printshop','block-114709','checkout\\ShippingChoice','',1),(114711,'120956','printshop','block-114708','Neighbour\\Checkout','',4),(114712,'120957','printshop','block-114708','Html_box','',1),(114713,'120958','printshop','block-114708','BlockBox','',3),(114714,'120959','printshop','block-114713','BlockBox','',1),(114715,'120960','printshop','block-114714','checkout\\ContactInformation','',4),(114716,'120961','printshop','block-114714','checkout\\ShippingAddress','',2),(114717,'120962','printshop','block-114714','Html_box','',3),(114718,'120963','printshop','block-114713-2','BlockBox','',1),(114719,'120964','printshop','block-114718','checkout\\Shipping','',2),(114720,'120965','printshop','block-114718','Html_box','',1),(114721,'120966','printshop','block-114718','DelayedDespatch\\Checkout','',3),(114722,'120967','printshop','block-114704','BlockBox','',5),(114723,'120968','printshop','block-114722','Html_box','',1),(114724,'120969','printshop','block-114722','checkout\\Comments','',2),(114725,'120970','printshop','block-114704','BlockBox','',3),(114726,'120971','printshop','block-114725','Html_box','',1),(114727,'120972','printshop','block-114725','BlockBox','',2),(114728,'120973','printshop','block-114727','checkout\\BillingAddress','',2),(114729,'120974','printshop','block-114727','Html_box','',1),(114730,'120975','printshop','block-114727-2','BlockBox','',1),(114731,'120976','printshop','block-114730','checkout\\PaymentMethod','',2),(114732,'120977','printshop','block-114730','Html_box','',1),(114733,'120978','printshop','block-114703-2','BlockBox','',1),(114734,'120979','printshop','block-114733','Html_box','',1),(114735,'120980','printshop','block-114733','Html_box','',5),(114736,'120981','printshop','block-114733','checkout\\Totals','',2),(114737,'120982','printshop','block-114733','checkout\\ContinueBtn','',3),(114738,'120983','printshop','block-114733','checkout\\Terms','',4),(114739,'116699','printshop','checkout_s','BlockBox','',1),(114740,'116700','printshop','block-114739','BlockBox','',2),(114741,'116701','printshop','block-114740','BlockBox','',2),(114742,'116703','printshop','block-114741','BlockBox','',6),(114743,'116704','printshop','block-114742','sample\\Products','',1),(114744,'116705','printshop','block-114742','checkout\\CreateAccount','',3),(114745,'116706','printshop','block-114741','BlockBox','',2),(114746,'116707','printshop','block-114745','Html_box','',1),(114747,'116708','printshop','block-114745','Neighbour\\Checkout','',4),(114748,'116709','printshop','block-114745','BlockBox','',2),(114749,'116710','printshop','block-114748','checkout\\ShippingChoice','',1),(114750,'116711','printshop','block-114745','BlockBox','',3),(114751,'116712','printshop','block-114750','BlockBox','',1),(114752,'116713','printshop','block-114751','checkout\\ShippingAddress','',2),(114753,'116714','printshop','block-114751','checkout\\ContactInformation','',4),(114754,'116715','printshop','block-114751','Html_box','',3),(114755,'116716','printshop','block-114750-2','BlockBox','',1),(114756,'116717','printshop','block-114755','checkout\\Shipping','',2),(114757,'116718','printshop','block-114755','DelayedDespatch\\Checkout','',3),(114758,'116719','printshop','block-114755','Html_box','',1),(114759,'116720','printshop','block-114741','BlockBox','',3),(114760,'116721','printshop','block-114759','BlockBox','',2),(114761,'116722','printshop','block-114760','Html_box','',1),(114762,'116723','printshop','block-114760','checkout\\BillingAddress','',2),(114763,'116724','printshop','block-114760-2','BlockBox','',1),(114764,'116725','printshop','block-114763','Html_box','',1),(114765,'116726','printshop','block-114763','checkout\\PaymentMethod','',2),(114766,'116727','printshop','block-114759','Html_box','',1),(114767,'116728','printshop','block-114741','BlockBox','',5),(114768,'116729','printshop','block-114767','Html_box','',1),(114769,'116730','printshop','block-114767','checkout\\Comments','',2),(114770,'116731','printshop','block-114741','BlockBox','',4),(114771,'116732','printshop','block-114770','BlockBox','',2),(114772,'116733','printshop','block-114771','CouponsAndVauchers\\Checkout','',1),(114773,'116734','printshop','block-114771-2','checkout\\BonusPoints','',2),(114774,'116735','printshop','block-114771-2','checkout\\CreditAmount','',1),(114775,'116736','printshop','block-114770','Html_box','',1),(114776,'116737','printshop','block-114740-2','BlockBox','',1),(114777,'116738','printshop','block-114776','checkout\\Totals','',2),(114778,'116739','printshop','block-114776','Html_box','',5),(114779,'116740','printshop','block-114776','Html_box','',1),(114780,'116741','printshop','block-114776','checkout\\ContinueBtn','',3),(114781,'120986','printshop','block-114776','checkout\\Terms','',4),(114782,'116742','printshop','checkout_step_bottom','Html_box','',1),(114783,'116743','printshop','checkout_step_bottom','cart\\Products','',2),(114784,'116744','printshop','checkout_step_bottom','checkout\\Totals','',3),(114785,'116745','printshop','checkout_step_bottom_g','checkout\\Totals','',3),(114786,'116746','printshop','checkout_step_bottom_g','quote\\Products','',2),(114787,'116747','printshop','checkout_step_bottom_g','Html_box','',1),(114788,'116749','printshop','checkout_step_bottom_no_shipping','Html_box','',1),(114789,'116750','printshop','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(114790,'116753','printshop','checkout_step_bottom_no_shipping','cart\\Products','',2),(114791,'116748','printshop','checkout_step_bottom_no_shipping_g','Html_box','',1),(114792,'116751','printshop','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(114793,'116752','printshop','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(114794,'116754','printshop','communication','BlockBox','',1),(114795,'116755','printshop','block-114794','Html_box','',2),(114796,'116756','printshop','block-114794','Communication\\NewTopicButton','',1),(114797,'116757','printshop','block-114794','Communication\\Topic','',3),(114798,'116758','printshop','compare','BlockBox','',1),(114799,'116759','printshop','block-114798','catalog\\Compare','',1),(114800,'117665.000001','printshop','compareproduct','BlockBox','listing-item',1),(114801,'120921.000001','printshop','block-114800','BlockBox','',1),(114802,'120919.000001','printshop','block-114801','BlockBox','listing-item',1),(114803,'1638872990.9609','printshop','block-114802','BlockBox','',2),(114804,'117671.000001','printshop','block-114803','productListing\\image','',1),(114805,'117677.000001','printshop','block-114803-2','productListing\\compare','',1),(114806,'117675.000001','printshop','block-114803-2','productListing\\name','',2),(114807,'117676.000001','printshop','block-114803-2','productListing\\stock','',3),(114808,'1638873112.0384','printshop','block-114803-2','BlockBox','',4),(114809,'117670.000001','printshop','block-114808','productListing\\rating','',2),(114810,'117673.000001','printshop','block-114808-2','productListing\\price','',1),(114811,'116760','printshop','compare_products','BlockBox','',2),(114812,'116761','printshop','block-114811','productListing\\rating','',4),(114813,'116762','printshop','block-114811','productListing\\model','',5),(114814,'116763','printshop','block-114811','productListing\\compare','',1),(114815,'116764','printshop','block-114811','BlockBox','',2),(114816,'116765','printshop','block-114815','productListing\\image','',1),(114817,'116766','printshop','block-114815-2','productListing\\name','',2),(114818,'116767','printshop','block-114811','BlockBox','',3),(114819,'116768','printshop','block-114818','productListing\\price','',1),(114820,'116769','printshop','block-114818-2','productListing\\buyButton','',1),(114821,'116770','printshop','confirmation','BlockBox','',1),(114822,'116771','printshop','block-114821','BlockBox','',2),(114823,'116772','printshop','block-114822','BlockBox','',2),(114824,'116773','printshop','block-114823','BlockBox','',4),(114825,'116774','printshop','block-114824','checkout\\EditBtn','',2),(114826,'116775','printshop','block-114824','cart\\Products','',3),(114827,'116776','printshop','block-114824','Html_box','',1),(114828,'116777','printshop','block-114823','BlockBox','',3),(114829,'116778','printshop','block-114828','checkout\\EditBtn','',2),(114830,'116779','printshop','block-114828','Html_box','',1),(114831,'116780','printshop','block-114828','checkout\\CommentsConfirm','',3),(114832,'116781','printshop','block-114823','BlockBox','',1),(114833,'116782','printshop','block-114832','BlockBox','',1),(114834,'116783','printshop','block-114833','checkout\\EditBtn','',6),(114835,'116784','printshop','block-114833','DelayedDespatch\\CheckoutConfirm','',8),(114836,'116785','printshop','block-114833','Html_box','',9),(114837,'116786','printshop','block-114833','checkout\\EditBtn','',10),(114838,'116787','printshop','block-114833','Html_box','',5),(114839,'116788','printshop','block-114833','checkout\\ShippingConfirm','',7),(114840,'116789','printshop','block-114833','Html_box','',1),(114841,'116790','printshop','block-114833','checkout\\EditBtn','',3),(114842,'116791','printshop','block-114833','checkout\\ContactConfirm','',11),(114843,'116792','printshop','block-114833','Html_box','',2),(114844,'116793','printshop','block-114833','checkout\\ShippingAddressConfirm','',4),(114845,'116794','printshop','block-114832-2','BlockBox','',1),(114846,'116795','printshop','block-114845','checkout\\EditBtn','',6),(114847,'116796','printshop','block-114845','checkout\\EditBtn','',3),(114848,'116797','printshop','block-114845','checkout\\PaymentMethodConfirm','',7),(114849,'116798','printshop','block-114845','Html_box','',5),(114850,'116799','printshop','block-114845','Html_box','',1),(114851,'116800','printshop','block-114845','checkout\\BillingAddressConfirm','',4),(114852,'116801','printshop','block-114845','Html_box','',2),(114853,'116802','printshop','block-114822','UploadCustomerId\\UploadCustomerIdForm','',1),(114854,'116803','printshop','block-114822-2','BlockBox','',1),(114855,'116804','printshop','block-114854','Html_box','',1),(114856,'116805','printshop','block-114854','checkout\\ConfirmBtn','',3),(114857,'116806','printshop','block-114854','checkout\\Totals','',2),(114858,'116807','printshop','block-114821','Html_box','',1),(114859,'116808','printshop','confirmation_free_s','BlockBox','',1),(114860,'116809','printshop','block-114859','BlockBox','',2),(114861,'116810','printshop','block-114860','BlockBox','',1),(114862,'116811','printshop','block-114861','BlockBox','',2),(114863,'116812','printshop','block-114862','checkout\\CommentsConfirm','',3),(114864,'116813','printshop','block-114862','checkout\\EditBtn','',2),(114865,'116814','printshop','block-114862','Html_box','',1),(114866,'116815','printshop','block-114861','BlockBox','',3),(114867,'116816','printshop','block-114866','checkout\\EditBtn','',3),(114868,'116817','printshop','block-114866','Html_box','',1),(114869,'116818','printshop','block-114866','sample\\Products','',2),(114870,'116819','printshop','block-114861','BlockBox','',1),(114871,'116820','printshop','block-114870','BlockBox','',1),(114872,'116821','printshop','block-114871','checkout\\EditBtn','',3),(114873,'116822','printshop','block-114871','checkout\\ShippingConfirm','',7),(114874,'116823','printshop','block-114871','Html_box','',5),(114875,'116824','printshop','block-114871','checkout\\EditBtn','',6),(114876,'116825','printshop','block-114871','Html_box','',2),(114877,'116826','printshop','block-114871','checkout\\ShippingAddressConfirm','',4),(114878,'116827','printshop','block-114870-2','BlockBox','',1),(114879,'116828','printshop','block-114878','checkout\\ContactConfirm','',3),(114880,'116829','printshop','block-114878','DelayedDespatch\\CheckoutConfirm','',4),(114881,'116830','printshop','block-114878','checkout\\EditBtn','',2),(114882,'116831','printshop','block-114878','Html_box','',1),(114883,'116832','printshop','block-114860-2','BlockBox','',1),(114884,'116833','printshop','block-114883','checkout\\ConfirmBtn','',3),(114885,'116834','printshop','block-114859','Html_box','',1),(114886,'116835','printshop','confirmation_no_shipping','BlockBox','',1),(114887,'116836','printshop','block-114886','Html_box','',1),(114888,'116837','printshop','block-114886','BlockBox','',2),(114889,'116838','printshop','block-114888','BlockBox','',1),(114890,'116839','printshop','block-114889','BlockBox','',1),(114891,'116840','printshop','block-114890','BlockBox','',1),(114892,'116841','printshop','block-114891','checkout\\EditBtn','',10),(114893,'116842','printshop','block-114891','Html_box','',9),(114894,'116843','printshop','block-114891','checkout\\ContactConfirm','',11),(114895,'116844','printshop','block-114890-2','BlockBox','',1),(114896,'116845','printshop','block-114895','checkout\\PaymentMethodConfirm','',7),(114897,'116846','printshop','block-114895','checkout\\EditBtn','',6),(114898,'116847','printshop','block-114895','Html_box','',5),(114899,'116848','printshop','block-114895','Html_box','',1),(114900,'116849','printshop','block-114895','checkout\\EditBtn','',3),(114901,'116850','printshop','block-114895','checkout\\BillingAddressConfirm','',4),(114902,'116851','printshop','block-114895','Html_box','',2),(114903,'116852','printshop','block-114889','BlockBox','',2),(114904,'116853','printshop','block-114903','Html_box','',1),(114905,'116854','printshop','block-114903','checkout\\CommentsConfirm','',3),(114906,'116855','printshop','block-114903','checkout\\EditBtn','',2),(114907,'116856','printshop','block-114889','BlockBox','',3),(114908,'116857','printshop','block-114907','Html_box','',1),(114909,'116858','printshop','block-114907','checkout\\EditBtn','',2),(114910,'116859','printshop','block-114907','cart\\Products','',3),(114911,'116860','printshop','block-114888-2','BlockBox','',1),(114912,'116861','printshop','block-114911','checkout\\ConfirmBtn','',3),(114913,'116862','printshop','block-114911','Html_box','',1),(114914,'116863','printshop','block-114911','checkout\\Totals','',2),(114915,'116864','printshop','confirmation_no_shipping_q','BlockBox','',2),(114916,'116865','printshop','block-114915','Html_box','',1),(114917,'116866','printshop','block-114915','BlockBox','',2),(114918,'116867','printshop','block-114917','BlockBox','',1),(114919,'116868','printshop','block-114918','BlockBox','',2),(114920,'116869','printshop','block-114919','Html_box','',1),(114921,'116870','printshop','block-114919','checkout\\CommentsConfirm','',3),(114922,'116871','printshop','block-114919','checkout\\EditBtn','',2),(114923,'116872','printshop','block-114918','BlockBox','',1),(114924,'116873','printshop','block-114923','BlockBox','',1),(114925,'116874','printshop','block-114924','checkout\\EditBtn','',5),(114926,'116875','printshop','block-114924','checkout\\ContactConfirm','',6),(114927,'116876','printshop','block-114924','checkout\\PaymentMethodConfirm','',3),(114928,'116877','printshop','block-114924','checkout\\EditBtn','',2),(114929,'116878','printshop','block-114924','Html_box','',4),(114930,'116879','printshop','block-114924','Html_box','',1),(114931,'116880','printshop','block-114923-2','BlockBox','',1),(114932,'116881','printshop','block-114931','checkout\\BillingAddressConfirm','',4),(114933,'116882','printshop','block-114931','checkout\\EditBtn','',3),(114934,'116883','printshop','block-114931','Html_box','',2),(114935,'116884','printshop','block-114918','BlockBox','',3),(114936,'116885','printshop','block-114935','checkout\\EditBtn','',2),(114937,'116886','printshop','block-114935','Html_box','',1),(114938,'116887','printshop','block-114935','quote\\Products','',3),(114939,'116888','printshop','block-114917-2','BlockBox','',1),(114940,'116889','printshop','block-114939','checkout\\ConfirmBtn','',3),(114941,'116890','printshop','block-114939','checkout\\Totals','',2),(114942,'116891','printshop','block-114939','Html_box','',1),(114943,'116892','printshop','confirmation_q','BlockBox','',1),(114944,'116893','printshop','block-114943','Html_box','',1),(114945,'116894','printshop','block-114943','BlockBox','',2),(114946,'116895','printshop','block-114945','BlockBox','',1),(114947,'116896','printshop','block-114946','BlockBox','',3),(114948,'116897','printshop','block-114947','quote\\Products','',3),(114949,'116898','printshop','block-114947','Html_box','',1),(114950,'116899','printshop','block-114947','checkout\\EditBtn','',2),(114951,'116900','printshop','block-114946','BlockBox','',1),(114952,'116901','printshop','block-114951','BlockBox','',1),(114953,'116902','printshop','block-114952','Html_box','',1),(114954,'116903','printshop','block-114952','checkout\\EditBtn','',10),(114955,'116904','printshop','block-114952','Html_box','',2),(114956,'116905','printshop','block-114952','checkout\\ContactConfirm','',11),(114957,'116906','printshop','block-114952','checkout\\ShippingAddressConfirm','',4),(114958,'116907','printshop','block-114952','checkout\\ShippingConfirm','',7),(114959,'116908','printshop','block-114952','checkout\\EditBtn','',3),(114960,'116909','printshop','block-114952','DelayedDespatch\\CheckoutConfirm','',8),(114961,'116910','printshop','block-114952','Html_box','',9),(114962,'116911','printshop','block-114952','Html_box','',5),(114963,'116912','printshop','block-114952','checkout\\EditBtn','',6),(114964,'116913','printshop','block-114951-2','BlockBox','',1),(114965,'116914','printshop','block-114964','checkout\\EditBtn','',3),(114966,'116915','printshop','block-114964','checkout\\BillingAddressConfirm','',4),(114967,'116916','printshop','block-114964','checkout\\PaymentMethodConfirm','',7),(114968,'116917','printshop','block-114964','Html_box','',1),(114969,'116918','printshop','block-114964','Html_box','',2),(114970,'116919','printshop','block-114964','checkout\\EditBtn','',6),(114971,'116920','printshop','block-114964','Html_box','',5),(114972,'116921','printshop','block-114946','BlockBox','',2),(114973,'116922','printshop','block-114972','checkout\\CommentsConfirm','',3),(114974,'116923','printshop','block-114972','Html_box','',1),(114975,'116924','printshop','block-114972','checkout\\EditBtn','',2),(114976,'116925','printshop','block-114945-2','BlockBox','',1),(114977,'116926','printshop','block-114976','Html_box','',1),(114978,'116927','printshop','block-114976','checkout\\Totals','',2),(114979,'116928','printshop','block-114976','checkout\\ConfirmBtn','',3),(114980,'116929','printshop','confirmation_s','BlockBox','',1),(114981,'116930','printshop','block-114980','BlockBox','',2),(114982,'116931','printshop','block-114981','BlockBox','',1),(114983,'116932','printshop','block-114982','BlockBox','',1),(114984,'116933','printshop','block-114983','BlockBox','',1),(114985,'116934','printshop','block-114984','checkout\\ShippingAddressConfirm','',4),(114986,'116935','printshop','block-114984','checkout\\EditBtn','',3),(114987,'116936','printshop','block-114984','Html_box','',2),(114988,'116937','printshop','block-114984','DelayedDespatch\\CheckoutConfirm','',8),(114989,'116938','printshop','block-114984','checkout\\ShippingConfirm','',7),(114990,'116939','printshop','block-114984','Html_box','',1),(114991,'116940','printshop','block-114984','Html_box','',5),(114992,'116941','printshop','block-114984','Html_box','',9),(114993,'116942','printshop','block-114984','checkout\\ContactConfirm','',11),(114994,'116943','printshop','block-114984','checkout\\EditBtn','',6),(114995,'116944','printshop','block-114984','checkout\\EditBtn','',10),(114996,'116945','printshop','block-114983-2','BlockBox','',1),(114997,'116946','printshop','block-114996','Html_box','',2),(114998,'116947','printshop','block-114996','checkout\\BillingAddressConfirm','',4),(114999,'116948','printshop','block-114996','checkout\\EditBtn','',3),(115000,'116949','printshop','block-114996','checkout\\PaymentMethodConfirm','',7),(115001,'116950','printshop','block-114996','checkout\\EditBtn','',6),(115002,'116951','printshop','block-114996','Html_box','',1),(115003,'116952','printshop','block-114996','Html_box','',5),(115004,'116953','printshop','block-114982','BlockBox','',3),(115005,'116954','printshop','block-115004','checkout\\EditBtn','',3),(115006,'116955','printshop','block-115004','Html_box','',1),(115007,'116956','printshop','block-115004','sample\\Products','',2),(115008,'116957','printshop','block-114982','BlockBox','',2),(115009,'116958','printshop','block-115008','Html_box','',1),(115010,'116959','printshop','block-115008','checkout\\EditBtn','',2),(115011,'116960','printshop','block-115008','checkout\\CommentsConfirm','',3),(115012,'116961','printshop','block-114981-2','BlockBox','',1),(115013,'116962','printshop','block-115012','checkout\\Totals','',2),(115014,'116963','printshop','block-115012','checkout\\ConfirmBtn','',3),(115015,'116964','printshop','block-115012','Html_box','',1),(115016,'116965','printshop','block-114980','Html_box','',1),(115017,'116966','printshop','contact','BlockBox','info-content',1),(115018,'116967','printshop','block-115017','info\\Title','',1),(115019,'116968','printshop','block-115017','BlockBox','',2),(115020,'116969','printshop','block-115019','contact\\ContactForm','',1),(115021,'116970','printshop','block-115019-2','contact\\Contacts','',1),(115022,'116971','printshop','created_success','BlockBox','',1),(115023,'116972','printshop','block-115022','Html_box','',1),(115024,'116973','printshop','block-115022','Html_box','',2),(115025,'116102.000001','printshop','credit_amount_history','BlockBox','',1),(115026,'116103.000001','printshop','block-115025','BlockBox','',1),(115027,'116104.000001','printshop','block-115026','WidgetsAria','',1),(115047,'116109.000001','printshop','block-115026-2','Html_box','',1),(115048,'1638895944.9672','printshop','block-115026-2','account\\CreditAmountHistory','',2),(115049,'116974','printshop','credit_note','invoice\\Container','',1),(115050,'116975','printshop','block-115049','BlockBox','',5),(115051,'116976','printshop','block-115050','invoice\\StoreAddress','',8),(115052,'116977','printshop','block-115050','Text','',1),(115053,'116978','printshop','block-115050-2','Text','',2),(115054,'116979','printshop','block-115050-2','Logo','',1),(115055,'116980','printshop','block-115050-3','Text','',1),(115056,'116981','printshop','block-115050-3','BlockBox','',3),(115057,'116982','printshop','block-115056','Text','',1),(115058,'116983','printshop','block-115056-2','invoice\\StoreEmail','',1),(115059,'116984','printshop','block-115050-3','BlockBox','',2),(115060,'116985','printshop','block-115059','Text','',1),(115061,'116986','printshop','block-115059-2','invoice\\StorePhone','',1),(115062,'116987','printshop','block-115049','invoice\\Products','',3),(115063,'116988','printshop','block-115049','BlockBox','',1),(115064,'116989','printshop','block-115063','Logo','',1),(115065,'116990','printshop','block-115063-2','BlockBox','',4),(115066,'116991','printshop','block-115065','Text','',1),(115067,'116992','printshop','block-115065-2','invoice\\StoreSite','',1),(115068,'116993','printshop','block-115063-2','BlockBox','',2),(115069,'116994','printshop','block-115068','Text','',1),(115070,'116995','printshop','block-115068-2','invoice\\StorePhone','',1),(115071,'116996','printshop','block-115063-2','BlockBox','',3),(115072,'116997','printshop','block-115071','Text','',1),(115073,'116998','printshop','block-115071-2','invoice\\StoreEmail','',1),(115074,'116999','printshop','block-115063-2','BlockBox','',1),(115075,'117000','printshop','block-115074','invoice\\StoreAddress','',1),(115076,'117001','printshop','block-115049','BlockBox','',4),(115077,'117002','printshop','block-115076','BlockBox','',1),(115078,'117003','printshop','block-115077','invoice\\ShippingAddress','',2),(115079,'117004','printshop','block-115077','Text','',1),(115080,'117005','printshop','block-115076-2','BlockBox','',1),(115081,'117006','printshop','block-115049','BlockBox','',2),(115082,'117007','printshop','block-115081','BlockBox','',7),(115083,'117008','printshop','block-115082','BlockBox','',1),(115084,'117009','printshop','block-115083','Text','',1),(115085,'117010','printshop','block-115083','invoice\\BillingAddress','',2),(115086,'117011','printshop','block-115082-2','BlockBox','',1),(115087,'117012','printshop','block-115086','invoice\\CustomerPhone','',4),(115088,'117013','printshop','block-115086','Text','',1),(115089,'117014','printshop','block-115086','Text','',3),(115090,'117015','printshop','block-115086','invoice\\CustomerName','',2),(115091,'117016','printshop','block-115086','invoice\\CustomerEmail','',6),(115092,'117017','printshop','block-115086','Text','',5),(115093,'117018','printshop','block-115081','BlockBox','',8),(115094,'117019','printshop','block-115093','BlockBox','',1),(115095,'117020','printshop','block-115094','invoice\\ShippingMethod','',2),(115096,'117021','printshop','block-115094','Text','',1),(115097,'117022','printshop','block-115093-2','BlockBox','',1),(115098,'117023','printshop','block-115097','Text','',1),(115099,'117024','printshop','block-115097','invoice\\ShippingMethod','',2),(115100,'117025','printshop','block-115081-2','invoice\\OrderId','',1),(115101,'117026','printshop','block-115081-2','Text','',2),(115102,'117027','printshop','block-115081-2','invoice\\PaymentDate','',3),(115103,'117034','printshop','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(115104,'1639155816.3893','printshop','delivery-location','BlockBox','',2),(115105,'117028','printshop','block-115104','DeliveryLocation\\FeaturedList','',6),(115106,'117029','printshop','block-115104','DeliveryLocation\\LocationLongDescription','',3),(115107,'117030','printshop','block-115104','DeliveryLocation\\LocationList','',4),(115108,'117031','printshop','block-115104','DeliveryLocation\\LocationTitle','',1),(115109,'117032','printshop','block-115104','DeliveryLocation\\LocationProducts','',7),(115110,'117033','printshop','block-115104','DeliveryLocation\\LocationDescription','',2),(115111,'1639485067.5512','printshop','block-115104','DeliveryLocation\\CrossPages','',0),(115112,'1639485089.2227','printshop','block-115104','DeliveryLocation\\ProductCategories','',0),(115113,'1639154415.2739','printshop','delivery-location-default','BlockBox','',2),(115114,'117035','printshop','block-115113','DeliveryLocation\\TopLocationList','',2),(115115,'117036','printshop','block-115113','Heading','',1),(115116,'1639419797.9718','printshop','block-115113','DeliveryLocation\\ListByPage','',3),(115117,'117037','printshop','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(115118,'117038','printshop','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(115119,'117039','printshop','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(115120,'117040','printshop','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(115121,'117041','printshop','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(115122,'117042','printshop','delivery_loc_2','DeliveryLocation\\LocationList','',7),(115123,'117043','printshop','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(115124,'117044','printshop','email','email\\BlockBox','',1),(115125,'117045','printshop','block-115124','email\\BlockBox','',1),(115126,'117046','printshop','block-115125','Copyright','',4),(115127,'117047','printshop','block-115125','email\\Content','',3),(115128,'117048','printshop','block-115125','email\\BlockBox','',2),(115129,'117049','printshop','block-115128','email\\Title','',1),(115130,'117050','printshop','block-115128-2','email\\Date','',1),(115131,'117051','printshop','block-115125','Logo','',1),(115132,'117052','printshop','email_2','email\\BlockBox','',1),(115133,'117053','printshop','block-115132','email\\BlockBox','',1),(115134,'117054','printshop','block-115133','Copyright','',4),(115135,'117055','printshop','block-115133','Logo','',1),(115136,'117056','printshop','block-115133','email\\Content','',3),(115137,'117057','printshop','block-115133','email\\BlockBox','',2),(115138,'117058','printshop','block-115137','email\\Title','',1),(115139,'117059','printshop','block-115137-2','email\\Date','',1),(115140,'117060','printshop','email_3','email\\BlockBox','',1),(115141,'117061','printshop','block-115140','email\\BlockBox','',1),(115142,'117062','printshop','block-115141','email\\BlockBox','',2),(115143,'117063','printshop','block-115142','email\\Content','',2),(115144,'117064','printshop','block-115142','email\\BlockBox','',1),(115145,'117065','printshop','block-115144','email\\Title','',1),(115146,'117066','printshop','block-115144-2','email\\Date','',1),(115147,'117067','printshop','block-115141','Copyright','',3),(115148,'117068','printshop','block-115141','Logo','',1),(115149,'117069','printshop','email_4','email\\BlockBox','',1),(115150,'117070','printshop','block-115149','email\\BlockBox','',1),(115151,'117071','printshop','block-115150','Copyright','',2),(115152,'117072','printshop','block-115150','email\\BlockBox','',1),(115153,'117073','printshop','block-115152','email\\BlockBox','',1),(115154,'117074','printshop','block-115153','Logo','',1),(115155,'117075','printshop','block-115153-2','email\\Date','',2),(115156,'117076','printshop','block-115153-2','email\\Title','',1),(115157,'117077','printshop','block-115152','email\\Content','',2),(115158,'121029','printshop','filescatalog_category','BlockBox','',1),(115159,'121030','printshop','block-115158','FilesCatalog\\widgets\\FilesList','',3),(115160,'121031','printshop','block-115158','FilesCatalog\\widgets\\Title','',1),(115161,'121032','printshop','block-115158','FilesCatalog\\widgets\\Description','',2),(115162,'121025','printshop','filescatalog_index','BlockBox','',1),(115163,'121026','printshop','block-115162','Html_box','',1),(115164,'121027','printshop','block-115162','FilesCatalog\\widgets\\FilesCatalog','',2),(115165,'117078','printshop','footer','BlockBox','footer-content',1),(115166,'120869','printshop','block-115165','BlockBox','',2),(115167,'120870','printshop','block-115166','Image','',3),(115168,'1644341222.4626','printshop','block-115166-2','SocialLinks','',1),(115169,'1644573331.7071','printshop','block-115166-3','Image','',1),(115170,'1644340895.1318','printshop','block-115165','BlockBox','',1),(115171,'117085','printshop','block-115170','Menu','Footer',1),(115172,'1644342832.3703','printshop','block-115170-2','BlockBox','',2),(115173,'117091','printshop','block-115172','Contacts','',1),(115174,'1644406988.3921','printshop','block-115172','Text','',0),(115175,'1644406713.4425','printshop','block-115172-2','Contacts','',1),(115176,'1644406751.9542','printshop','block-115172-2','Contacts','',2),(115177,'117093','printshop','footer','BlockBox','',2),(115178,'117094','printshop','block-115177','Copyright','',1),(115179,'117096','printshop','for_menu','BlockBox','',1),(115180,'117097','printshop','block-115179','Html_box','',1),(115181,'117098','printshop','block-115179-2','Languages','',1),(115182,'117099','printshop','for_menu','BlockBox','',3),(115183,'117100','printshop','block-115182','Html_box','',1),(115184,'117101','printshop','block-115182-2','Currencies','',1),(115185,'117102','printshop','gift','BlockBox','',1),(115186,'117103','printshop','block-115185','BlockBox','',3),(115187,'117104','printshop','block-115186','BlockBox','',1),(115188,'117105','printshop','block-115187','gift\\Card','',1),(115189,'117106','printshop','block-115186-2','gift\\Form','',2),(115190,'117107','printshop','block-115186-2','Text','',1),(115191,'117108','printshop','block-115185','info\\Title','',1),(115192,'117109','printshop','gift_card','BlockBox','',1),(115193,'117110','printshop','block-115192','BlockBox','',11),(115194,'117111','printshop','block-115193','invoice\\StoreEmail','',3),(115195,'117112','printshop','block-115193','Text','',1),(115196,'117113','printshop','block-115193','invoice\\StorePhone','',2),(115197,'117114','printshop','block-115192','Text','',8),(115198,'117115','printshop','block-115192','Text','',3),(115199,'117116','printshop','block-115192','BlockBox','',10),(115200,'117117','printshop','block-115199','Text','',1),(115201,'117118','printshop','block-115199-2','gift\\CodeView','',1),(115202,'117119','printshop','block-115192','gift\\MessageView','',7),(115203,'117120','printshop','block-115192','gift\\AmountView','',5),(115204,'117121','printshop','block-115192','Text','',6),(115205,'117123','printshop','block-115192','Logo','',1),(115206,'117124','printshop','block-115192','Text','',4),(115207,'117125','printshop','block-115192','Text','',9),(115208,'117126','printshop','gift_card_2','BlockBox','',1),(115209,'117127','printshop','block-115208','gift\\AmountView','',4),(115210,'117128','printshop','block-115208','BlockBox','',9),(115211,'117129','printshop','block-115210','Text','',1),(115212,'117130','printshop','block-115210-2','gift\\CodeView','',1),(115213,'117131','printshop','block-115208','BlockBox','',10),(115214,'117132','printshop','block-115213','invoice\\StoreEmail','',3),(115215,'117133','printshop','block-115213','Text','',1),(115216,'117134','printshop','block-115213','invoice\\StorePhone','',2),(115217,'117135','printshop','block-115208','gift\\MessageView','',6),(115218,'117136','printshop','block-115208','Text','',5),(115219,'117137','printshop','block-115208','Text','',8),(115220,'117138','printshop','block-115208','Text','',3),(115221,'117139','printshop','block-115208','Text','',7),(115222,'1638804282.8587','printshop','block-115208','Logo','',1),(115223,'117141','printshop','gift_card_2_pdf','BlockBox','',1),(115224,'117142','printshop','block-115223','BlockBox','',12),(115225,'117143','printshop','block-115224','invoice\\StoreEmail','',4),(115226,'117144','printshop','block-115224','invoice\\StorePhone','',3),(115227,'117145','printshop','block-115224','Html_box','',1),(115228,'117146','printshop','block-115223','BlockBox','',11),(115229,'117147','printshop','block-115228','Html_box','',1),(115230,'117148','printshop','block-115228-2','gift\\CodeViewPdf','',1),(115231,'117149','printshop','block-115223','BlockBox','',1),(115232,'117150','printshop','block-115231','Text','',4),(115233,'117151','printshop','block-115231','Html_box','',1),(115234,'117152','printshop','block-115231','Html_box','',2),(115235,'117153','printshop','block-115231','gift\\AmountViewPdf','',3),(115236,'117154','printshop','block-115231','gift\\MessageViewPdf','',5),(115237,'117155','printshop','block-115231','Html_box','',7),(115238,'117156','printshop','block-115231','Html_box','',6),(115239,'117158','printshop','gift_card_pdf','BlockBox','',1),(115240,'117159','printshop','block-115239','BlockBox','',12),(115241,'117160','printshop','block-115240','invoice\\StoreEmail','',4),(115242,'117161','printshop','block-115240','invoice\\StorePhone','',3),(115243,'117162','printshop','block-115240','Html_box','',1),(115244,'117163','printshop','block-115239','BlockBox','',11),(115245,'117164','printshop','block-115244','Html_box','',1),(115246,'117165','printshop','block-115244-2','gift\\CodeViewPdf','',1),(115247,'117166','printshop','block-115239','BlockBox','',1),(115248,'117167','printshop','block-115247','Text','',5),(115249,'117169','printshop','block-115247','Html_box','',3),(115250,'117170','printshop','block-115247','gift\\AmountViewPdf','',4),(115251,'117171','printshop','block-115247','gift\\MessageViewPdf','',6),(115252,'117172','printshop','block-115247','Html_box','',8),(115253,'117173','printshop','block-115247','Html_box','',7),(115254,'1638978695.8384','printshop','block-115247','Logo','',2),(115255,'117175','printshop','gift_certificate','BlockBox','',1),(115256,'117176','printshop','block-115255','account\\ApplyCertificate','',2),(115257,'117177','printshop','block-115255','Html_box','',1),(115258,'117178','printshop','gigt_card_3','BlockBox','',1),(115259,'117179','printshop','block-115258','BlockBox','',9),(115260,'117180','printshop','block-115259','Text','',1),(115261,'117181','printshop','block-115259-2','gift\\CodeView','',1),(115262,'117182','printshop','block-115258','Text','',7),(115263,'117184','printshop','block-115258','BlockBox','',10),(115264,'117185','printshop','block-115263','Text','',1),(115265,'117186','printshop','block-115263','invoice\\StoreEmail','',3),(115266,'117187','printshop','block-115263','invoice\\StorePhone','',2),(115267,'117188','printshop','block-115258','gift\\MessageView','',6),(115268,'117189','printshop','block-115258','Text','',3),(115269,'117190','printshop','block-115258','Text','',5),(115270,'117191','printshop','block-115258','gift\\AmountView','',4),(115271,'117192','printshop','block-115258','Text','',8),(115272,'1638804328.7281','printshop','block-115258','Logo','',1),(115273,'117193','printshop','gigt_card_3_pdf','BlockBox','',1),(115274,'117194','printshop','block-115273','BlockBox','',12),(115275,'117195','printshop','block-115274','invoice\\StoreEmail','',4),(115276,'117196','printshop','block-115274','invoice\\StorePhone','',3),(115277,'117197','printshop','block-115274','Html_box','',1),(115278,'117198','printshop','block-115273','BlockBox','',11),(115279,'117199','printshop','block-115278','Html_box','',1),(115280,'117200','printshop','block-115278-2','gift\\CodeViewPdf','',1),(115281,'117201','printshop','block-115273','BlockBox','',1),(115282,'117202','printshop','block-115281','Text','',4),(115283,'117203','printshop','block-115281','Html_box','',1),(115284,'117204','printshop','block-115281','Html_box','',2),(115285,'117205','printshop','block-115281','gift\\AmountViewPdf','',3),(115286,'117206','printshop','block-115281','gift\\MessageViewPdf','',5),(115287,'117207','printshop','block-115281','Html_box','',7),(115288,'117208','printshop','block-115281','Html_box','',6),(115306,'117224','printshop','info','BlockBox','info-content',1),(115307,'117225','printshop','block-115306','info\\DescriptionShort','',3),(115308,'117226','printshop','block-115306','info\\Content','',6),(115309,'117227','printshop','block-115306','info\\Title','',1),(115310,'117228','printshop','block-115306','info\\Image','',4),(115311,'1638467467.3028','printshop','block-115306','info\\DescriptionShort','',5),(115312,'117229','printshop','invoice','invoice\\Container','',1),(115313,'117230','printshop','block-115312','BlockBox','',4),(115314,'117231','printshop','block-115313','BlockBox','',8),(115315,'117232','printshop','block-115314','BlockBox','',1),(115316,'117233','printshop','block-115315','invoice\\ShippingMethod','',2),(115317,'117234','printshop','block-115315','Text','',1),(115318,'117235','printshop','block-115314-2','BlockBox','',1),(115319,'117236','printshop','block-115318','Text','',1),(115320,'117237','printshop','block-115318','invoice\\ShippingMethod','',2),(115321,'117238','printshop','block-115313','BlockBox','',7),(115322,'117239','printshop','block-115321','BlockBox','',1),(115323,'117240','printshop','block-115322','Text','',1),(115324,'117241','printshop','block-115322','invoice\\BillingAddress','',2),(115325,'1639659760.0392','printshop','block-115322','GiftWrapMessage\\ShowInfo','',3),(115326,'117242','printshop','block-115321-2','BlockBox','',1),(115327,'117243','printshop','block-115326','Text','',5),(115328,'117244','printshop','block-115326','invoice\\CustomerName','',2),(115329,'117245','printshop','block-115326','invoice\\CustomerPhone','',4),(115330,'117246','printshop','block-115326','Text','',1),(115331,'117247','printshop','block-115326','Text','',3),(115332,'117248','printshop','block-115326','invoice\\CustomerEmail','',6),(115333,'117249','printshop','block-115313-2','invoice\\PaymentMethod','',6),(115334,'117250','printshop','block-115313-2','Text','',5),(115335,'117251','printshop','block-115313-2','Text','',3),(115336,'117252','printshop','block-115313-2','invoice\\OrderId','',2),(115337,'117253','printshop','block-115313-2','invoice\\PaymentDate','',4),(115338,'117254','printshop','block-115313-2','invoice\\OrderBarcode','',7),(115339,'117255','printshop','block-115312','BlockBox','',8),(115340,'117256','printshop','block-115339','invoice\\StoreAddress','',8),(115341,'117257','printshop','block-115339','Text','',1),(115342,'117258','printshop','block-115339-2','Text','',2),(115343,'117260','printshop','block-115339-3','BlockBox','',3),(115344,'117261','printshop','block-115343','Text','',1),(115345,'117262','printshop','block-115343-2','invoice\\StoreEmail','',1),(115346,'117263','printshop','block-115339-3','BlockBox','',2),(115347,'117264','printshop','block-115346','Text','',1),(115348,'117265','printshop','block-115346-2','invoice\\StorePhone','',1),(115349,'117266','printshop','block-115339-3','Text','',1),(115350,'117267','printshop','block-115312','invoice\\Products','',5),(115351,'117268','printshop','block-115312','BlockBox','',7),(115352,'117269','printshop','block-115351','BlockBox','',1),(115353,'117270','printshop','block-115352','invoice\\ShippingAddress','',2),(115354,'117271','printshop','block-115352','Text','',1),(115355,'117272','printshop','block-115351-2','BlockBox','',1),(115356,'117273','printshop','block-115355','invoice\\Totals','',1),(115357,'117274','printshop','block-115312','BlockBox','',2),(115358,'117275','printshop','block-115357','Logo','',1),(115359,'117276','printshop','block-115357-2','BlockBox','',4),(115360,'117277','printshop','block-115359','Text','',1),(115361,'117278','printshop','block-115359-2','invoice\\StoreSite','',1),(115362,'117279','printshop','block-115357-2','BlockBox','',3),(115363,'117280','printshop','block-115362','Text','',1),(115364,'117281','printshop','block-115362-2','invoice\\StoreEmail','',1),(115365,'117282','printshop','block-115357-2','BlockBox','',1),(115366,'117283','printshop','block-115365','invoice\\StoreAddress','',2),(115367,'117284','printshop','block-115357-2','BlockBox','',2),(115368,'117285','printshop','block-115367','Text','',1),(115369,'117286','printshop','block-115367-2','invoice\\StorePhone','',1),(115370,'1640103567.8175','printshop','block-115312','invoice\\StructuredProducts','',6),(115371,'117287','printshop','login_account','BlockBox','',1),(115372,'117288','printshop','block-115371','Tabs','',2),(115373,'117289','printshop','block-115372-1','login\\Returning','',1),(115374,'117290','printshop','block-115372-2','BlockBox','',1),(115375,'117291','printshop','block-115374','Html_box','',1),(115376,'117292','printshop','block-115374-2','BlockBox','',1),(115377,'117293','printshop','block-115376','Html_box','',2),(115378,'117294','printshop','block-115376','login\\Register','',1),(115379,'117295','printshop','block-115371','BlockBox','',1),(115380,'117296','printshop','block-115379','Html_box','',5),(115381,'117297','printshop','block-115379','Html_box','',1),(115382,'117298','printshop','block-115379','login\\Socials','',4),(115383,'117299','printshop','login_checkout','BlockBox','',1),(115384,'117300','printshop','block-115383','BlockBox','',1),(115385,'1644496194.7022','printshop','block-115384','BlockBox','',0),(115386,'117301','printshop','block-115385','checkout\\CreateBtn','',4),(115387,'117302','printshop','block-115385','checkout\\GuestBtn','',2),(115388,'117303','printshop','block-115385','Html_box','',3),(115389,'117304','printshop','block-115385','BlockBox','',5),(115390,'117305','printshop','block-115389','Html_box','',1),(115391,'117306','printshop','block-115389','login\\Socials','',2),(115392,'117307','printshop','block-115385','Html_box','',1),(115393,'1644496248.7478','printshop','block-115384-2','BlockBox','',2),(115394,'117308','printshop','block-115393','login\\Returning','',2),(115395,'117309','printshop','block-115393','Html_box','',1),(115396,'117310','printshop','login_checkout2','BlockBox','',1),(115397,'117311','printshop','block-115396','Tabs','',4),(115398,'117312','printshop','block-115397-1','BlockBox','',1),(115399,'117313','printshop','block-115398','Html_box','',1),(115400,'117314','printshop','block-115398-2','BlockBox','',1),(115401,'117315','printshop','block-115400','login\\Guest','',1),(115402,'117316','printshop','block-115400','Html_box','',2),(115403,'117317','printshop','block-115397-2','login\\Returning','',1),(115404,'117318','printshop','block-115397-3','BlockBox','',1),(115405,'117319','printshop','block-115404','Html_box','',1),(115406,'117320','printshop','block-115404-2','BlockBox','',1),(115407,'117321','printshop','block-115406','Html_box','',2),(115408,'117322','printshop','block-115406','login\\Register','',1),(115409,'117323','printshop','block-115396','login\\Socials','',2),(115410,'117324','printshop','block-115396','Html_box','',3),(115411,'117325','printshop','block-115396','Html_box','',1),(115412,'117326','printshop','login_checkout2_q','BlockBox','',1),(115413,'117327','printshop','block-115412','Tabs','',4),(115414,'117328','printshop','block-115413-1','BlockBox','',1),(115415,'117329','printshop','block-115414','Html_box','',1),(115416,'117330','printshop','block-115414-2','quote\\FastOrder','',1),(115417,'117331','printshop','block-115413-2','login\\Returning','',1),(115418,'117332','printshop','block-115413-3','BlockBox','',1),(115419,'117333','printshop','block-115418','Html_box','',1),(115420,'117334','printshop','block-115418','Import','',2),(115421,'117335','printshop','block-115418-2','BlockBox','',1),(115422,'117336','printshop','block-115421','login\\Register','',1),(115423,'117337','printshop','block-115421','Html_box','',2),(115424,'117338','printshop','block-115412','Html_box','',3),(115425,'117339','printshop','block-115412','Html_box','',1),(115426,'117340','printshop','block-115412','login\\Socials','',2),(115427,'117341','printshop','login_checkout2_s','BlockBox','',1),(115428,'117342','printshop','block-115427','login\\Socials','',2),(115429,'117343','printshop','block-115427','Html_box','',3),(115430,'117344','printshop','block-115427','Tabs','',4),(115431,'117345','printshop','block-115430-1','BlockBox','',1),(115432,'117346','printshop','block-115431','Html_box','',1),(115433,'117347','printshop','block-115431-2','quote\\FastOrder','',1),(115434,'117348','printshop','block-115430-2','login\\Returning','',1),(115435,'117349','printshop','block-115430-3','BlockBox','',1),(115436,'117350','printshop','block-115435','Html_box','',1),(115437,'117351','printshop','block-115435-2','BlockBox','',1),(115438,'117352','printshop','block-115437','login\\Register','',1),(115439,'117353','printshop','block-115437','Html_box','',2),(115440,'117354','printshop','block-115427','Html_box','',1),(115441,'117355','printshop','login_checkout_q','BlockBox','',1),(115442,'117356','printshop','block-115441','BlockBox','',1),(115443,'117357','printshop','block-115442','BlockBox','',5),(115444,'117358','printshop','block-115443','Html_box','',1),(115445,'117359','printshop','block-115443','login\\Socials','',2),(115446,'117360','printshop','block-115442','checkout\\GuestBtn','',2),(115447,'117361','printshop','block-115442','checkout\\CreateBtn','',4),(115448,'117362','printshop','block-115442','Html_box','',3),(115449,'117363','printshop','block-115442','Html_box','',1),(115450,'117364','printshop','block-115442-2','Html_box','',1),(115451,'117365','printshop','block-115442-2','login\\Returning','',2),(115452,'117366','printshop','login_checkout_s','BlockBox','',1),(115453,'117367','printshop','block-115452','BlockBox','',1),(115454,'117368','printshop','block-115453','Html_box','',1),(115455,'117369','printshop','block-115453','checkout\\GuestBtn','',2),(115456,'117370','printshop','block-115453','checkout\\CreateBtn','',4),(115457,'117371','printshop','block-115453','Html_box','',3),(115458,'117372','printshop','block-115453','BlockBox','',5),(115459,'117373','printshop','block-115458','Html_box','',1),(115460,'117374','printshop','block-115458','login\\Socials','',2),(115461,'117375','printshop','block-115453-2','Html_box','',1),(115462,'117376','printshop','block-115453-2','login\\Returning','',2),(115463,'117377','printshop','logoff','BlockBox','',1),(115464,'117378','printshop','block-115463','Html_box','',1),(115465,'117379','printshop','logoff_forever','BlockBox','',1),(115466,'117380','printshop','block-115465','Html_box','',1),(115467,'117386','printshop','main','BlockBox','main-content',3),(115468,'120856','printshop','block-115467','BlockBox','',1),(115469,'120857','printshop','block-115468','Banner','',1),(115470,'120862','printshop','block-115467','BlockBox','',3),(115471,'117389','printshop','block-115470','NewProducts','4',2),(115472,'121014','printshop','block-115470','Html_box','',1),(115473,'1644485886.0558','printshop','block-115467','BlockBox','',7),(115474,'1644486520.9017','printshop','block-115473','Banner','',2),(115475,'1644577826.0002','printshop','block-115467','BlockBox','',2),(115476,'1644321730.7025','printshop','block-115475','Banner','',1),(115477,'1644580572.4789','printshop','block-115467','BlockBox','',6),(115478,'1644580744.5807','printshop','block-115477','Banner','',0),(115479,'1644580721.7097','printshop','block-115467','BlockBox','',5),(115480,'120865','printshop','block-115479','Banner','',1),(115481,'1644601798.7155','printshop','main','BlockBox','',2),(115482,'1683025508.153','printshop','block-115481','Banner','',2),(115483,'1708693902.95','printshop','main','FormBuilder\\widgets\\Form','',4),(115484,'117394','printshop','manufacturers','BlockBox','',1),(115485,'117395','printshop','block-115484','Html_box','',1),(115486,'117396','printshop','block-115484','Brands','',2),(115487,'117397','printshop','messages-index','BlockBox','',1),(115488,'117398','printshop','block-115487','BlockBox','',1),(115489,'117399','printshop','block-115488','BlockBox','',1),(115490,'117400','printshop','block-115489','Messages\\Sidebar','',1),(115491,'117401','printshop','block-115488-2','Messages\\Listing','',1),(115492,'117402','printshop','messages-new','BlockBox','',1),(115493,'117403','printshop','block-115492','BlockBox','',1),(115494,'117404','printshop','block-115493','Messages\\Sidebar','',1),(115495,'117405','printshop','block-115493-2','Messages\\NewMessage','',1),(115496,'117406','printshop','messages-view','BlockBox','',1),(115497,'117407','printshop','block-115496','BlockBox','',1),(115498,'117408','printshop','block-115497','Messages\\Sidebar','',1),(115499,'117409','printshop','block-115497-2','Messages\\Message','',1),(115500,'117410','printshop','my_password','BlockBox','',1),(115501,'117411','printshop','block-115500','BlockBox','',2),(115502,'117412','printshop','block-115501','WidgetsAria','',1),(115522,'117413','printshop','block-115501-2','account\\ChangePassword','',2),(115523,'117414','printshop','block-115500','Html_box','',1),(115524,'117415','printshop','need_login','BlockBox','',1),(115525,'117416','printshop','block-115524','Tabs','',2),(115526,'117417','printshop','block-115525-1','login\\Returning','',1),(115527,'117418','printshop','block-115525-2','BlockBox','',1),(115528,'117419','printshop','block-115527','Html_box','',2),(115529,'117420','printshop','block-115527-2','BlockBox','',1),(115530,'117421','printshop','block-115529','login\\Register','',1),(115531,'117422','printshop','block-115529','Html_box','',2),(115532,'117423','printshop','block-115524','BlockBox','',1),(115533,'117424','printshop','new-topic','BlockBox','',1),(115534,'117425','printshop','block-115533','Breadcrumb','',2),(115535,'117426','printshop','block-115533','Communication\\NewTopic','',3),(115536,'117427','printshop','block-115533','Html_box','',1),(115537,'117428','printshop','nnnn','BlockBox','',1),(115538,'117429','printshop','block-115537','catalog\\Title','',1),(115539,'117430','printshop','block-115537','BlockBox','',2),(115540,'117431','printshop','block-115539','Filters','',1),(115541,'117432','printshop','block-115539-2','Listing','',5),(115542,'117433','printshop','block-115539-2','catalog\\Image','',1),(115543,'117434','printshop','block-115539-2','BlockBox','',6),(115544,'117435','printshop','block-115543','catalog\\CountsItems','',1),(115545,'117436','printshop','block-115543-2','catalog\\Paging','',1),(115546,'117437','printshop','block-115539-2','catalog\\ImageMapCategory','',3),(115547,'117438','printshop','block-115539-2','Categories','',2),(115548,'117439','printshop','block-115539-2','BlockBox','',4),(115549,'117440','printshop','block-115548','catalog\\ListingLook','',1),(115550,'117441','printshop','block-115548','catalog\\ItemsOnPage','',4),(115551,'117442','printshop','block-115548','catalog\\CompareButton','',2),(115552,'117443','printshop','block-115548','catalog\\Sorting','',3),(115553,'117444','printshop','no-logged','BlockBox','',1),(115554,'117445','printshop','block-115553','Communication\\NewTopic','',2),(115555,'117446','printshop','block-115553','Html_box','',1),(115556,'117447','printshop','no_filters','BlockBox','catalog-content',2),(115557,'117448','printshop','block-115556','BlockBox','',4),(115558,'117449','printshop','block-115557','catalog\\CountsItems','',1),(115559,'117450','printshop','block-115557-2','catalog\\Paging','',1),(115560,'117451','printshop','block-115556','Listing','',3),(115561,'117452','printshop','block-115556','catalog\\Title','',1),(115562,'117453','printshop','block-115556','catalog\\B2bAddButton','',5),(115563,'117454','printshop','block-115556','BlockBox','catalog-features',2),(115564,'117455','printshop','block-115563','BlockBox','',2),(115565,'117456','printshop','block-115564','HeaderStock','',5),(115566,'117457','printshop','block-115564','catalog\\ListingLook','',1),(115567,'117458','printshop','block-115564','catalog\\CompareButton','',2),(115568,'117459','printshop','block-115564','catalog\\ItemsOnPage','',4),(115569,'117460','printshop','block-115564','catalog\\Sorting','',3),(115570,'117461','printshop','block-115563','catalog\\Image','',1),(115571,'1645199275.381','printshop','no_filters','BlockBox','',1),(115572,'1645199299.5233','printshop','block-115571','Breadcrumb','',0),(115656,'117507','printshop','order_pay','BlockBox','',1),(115657,'117508','printshop','block-115656','BlockBox','',1),(115658,'117509','printshop','block-115657','WidgetsAria','',1),(115678,'117510','printshop','block-115657-2','account\\OrderProducts','',4),(115679,'117511','printshop','block-115657-2','BlockBox','',2),(115680,'117512','printshop','block-115679','BlockBox','',1),(115681,'117513','printshop','block-115680','Html_box','',1),(115682,'117514','printshop','block-115680','account\\OrderData','',2),(115683,'117515','printshop','block-115679','BlockBox','',4),(115684,'117516','printshop','block-115683','account\\OrderData','',2),(115685,'117517','printshop','block-115683','Html_box','',1),(115686,'117518','printshop','block-115679-2','BlockBox','',1),(115687,'117519','printshop','block-115686','Html_box','',1),(115688,'117520','printshop','block-115686','account\\OrderData','',2),(115689,'117521','printshop','block-115679-2','BlockBox','',2),(115690,'117522','printshop','block-115689','account\\OrderData','',2),(115691,'117523','printshop','block-115689','Html_box','',1),(115692,'117524','printshop','block-115679-3','BlockBox','',2),(115693,'117525','printshop','block-115692','Html_box','',1),(115694,'117526','printshop','block-115692','account\\OrderData','',2),(115695,'117527','printshop','block-115679-3','BlockBox','',1),(115696,'117528','printshop','block-115695','account\\OrderData','',2),(115697,'117529','printshop','block-115695','Html_box','',1),(115698,'117530','printshop','block-115657-2','UpdateAndPay\\PayForm','',6),(115699,'117531','printshop','block-115657-2','Html_box','',3),(115700,'117532','printshop','block-115657-2','account\\OrderHeading','',1),(115701,'117533','printshop','block-115657-2','account\\OrderSubTotals','',5),(115702,'117534','printshop','packingslip','invoice\\Container','',2),(115703,'117535','printshop','block-115702','BlockBox','',2),(115704,'117536','printshop','block-115703','Logo','',1),(115705,'117537','printshop','block-115703-2','BlockBox','',3),(115706,'117538','printshop','block-115705','Text','',2),(115707,'117539','printshop','block-115705-2','invoice\\StoreEmail','',1),(115708,'117540','printshop','block-115703-2','BlockBox','',2),(115709,'117541','printshop','block-115708','Text','',2),(115710,'117542','printshop','block-115708-2','invoice\\StorePhone','',1),(115711,'117543','printshop','block-115703-2','BlockBox','',1),(115712,'117544','printshop','block-115711','invoice\\StoreAddress','',1),(115713,'117545','printshop','block-115703-2','BlockBox','',4),(115714,'117546','printshop','block-115713','Text','',2),(115715,'117547','printshop','block-115713-2','invoice\\StoreSite','',1),(115716,'117548','printshop','block-115702','packingslip\\Products','',5),(115717,'117549','printshop','block-115702','BlockBox','',6),(115718,'117550','printshop','block-115717','invoice\\StoreAddress','',2),(115719,'117551','printshop','block-115717','Text','',1),(115720,'117552','printshop','block-115702','BlockBox','',3),(115721,'117553','printshop','block-115720','BlockBox','',2),(115722,'117554','printshop','block-115721','BlockBox','',1),(115723,'117555','printshop','block-115722','invoice\\ShippingAddress','',2),(115724,'117556','printshop','block-115722','Text','',1),(115725,'117557','printshop','block-115721-2','BlockBox','',1),(115726,'117558','printshop','block-115725','Text','',1),(115727,'117559','printshop','block-115725','invoice\\CustomerName','',2),(115728,'117560','printshop','block-115725','invoice\\CustomerEmail','',6),(115729,'117561','printshop','block-115725','Text','',3),(115730,'117562','printshop','block-115725','invoice\\CustomerPhone','',4),(115731,'117563','printshop','block-115725','Text','',5),(115732,'117564','printshop','block-115720','BlockBox','',3),(115733,'117565','printshop','block-115732','BlockBox','',1),(115734,'117566','printshop','block-115733','invoice\\ShippingMethod','',2),(115735,'117567','printshop','block-115733','Text','',1),(115736,'117568','printshop','block-115732-2','BlockBox','',1),(115737,'117569','printshop','block-115736','invoice\\ShippingMethod','',2),(115738,'117570','printshop','block-115736','Text','',1),(115739,'117571','printshop','block-115720-2','invoice\\AddressQrcode','',1),(115740,'1639660991.8692','printshop','block-115702','Neighbour\\PackingSlipInfo','',1),(115741,'1639661081.5616','printshop','block-115702','Neighbour\\PackingSlipInfo','',4),(115742,'117572','printshop','password_forgotten','BlockBox','',1),(115743,'117573','printshop','block-115742','BlockBox','',2),(115744,'1638807246.6206','printshop','block-115743','Html_box','',2),(115745,'117574','printshop','block-115743','Html_box','',1),(115746,'117575','printshop','block-115743','login\\PasswordForgotten','',3),(115747,'117576','printshop','block-115742','Html_box','',1),(115748,'117577','printshop','pdf','invoice\\Container','',1),(115749,'117578','printshop','block-115748','BlockBox','',1),(115750,'117579','printshop','block-115749','BlockBox','',1),(115751,'117580','printshop','block-115750','BlockBox','',1),(115752,'117581','printshop','block-115751','pdf\\ProductElement','',1),(115753,'117582','printshop','block-115750','BlockBox','',2),(115754,'117583','printshop','block-115753','pdf\\ProductElement','',1),(115755,'117584','printshop','block-115753-2','pdf\\ProductElement','',2),(115756,'117585','printshop','block-115753-2','pdf\\ProductElement','',1),(115757,'117586','printshop','block-115749-2','BlockBox','',1),(115758,'117587','printshop','block-115757','BlockBox','',2),(115759,'117588','printshop','block-115758','pdf\\ProductElement','',1),(115760,'117589','printshop','block-115758-2','pdf\\ProductElement','',2),(115761,'117590','printshop','block-115758-2','pdf\\ProductElement','',1),(115762,'117591','printshop','block-115757','BlockBox','',1),(115763,'117592','printshop','block-115762','pdf\\ProductElement','',1),(115764,'117593','printshop','pdf_category','pdf\\CategoryName','',2),(115765,'117594','printshop','pdf_category','pdf\\CategoryImage','',1),(115766,'117595','printshop','pdf_cover','invoice\\Container','',1),(115767,'117596','printshop','block-115766','Logo','',1),(115768,'117597','printshop','block-115766','Text','',3),(115769,'117598','printshop','pdf_footer','BlockBox','',1),(115770,'117599','printshop','block-115769-2','pdf\\PageNumber','',1),(115771,'117600','printshop','pdf_header','pdf\\CategoryName','',1),(115772,'117601','printshop','personal_catalog','BlockBox','',1),(115773,'117602','printshop','block-115772','BlockBox','',2),(115774,'117603','printshop','block-115773','WidgetsAria','',1),(115794,'117606','printshop','block-115773-2','account\\PersonalCatalog','',2),(115795,'117604','printshop','block-115772','Html_box','',1),(115796,'117607','printshop','points_earnt_history','BlockBox','',1),(115797,'117608','printshop','block-115796','Html_box','',1),(115798,'117609','printshop','block-115796','account\\PointsEarntHistory','',2),(115799,'117610','printshop','posts','BlockBox','',1),(115800,'117611','printshop','block-115799','Breadcrumb','',2),(115801,'117612','printshop','block-115799','Html_box','',1),(115802,'117613','printshop','block-115799','Communication\\Post','',3),(115803,'1639053523.9657','printshop','product','BlockBox','',4),(115804,'1638963486.2331','printshop','block-115803','product\\Collection','',4),(115805,'1639659357.0881','printshop','block-115803','BlockBox','',2),(115806,'1639659044.5523','printshop','block-115805','ObsoleteProducts\\ObsoleteReplacementProducts','',1),(115807,'1644421585.0243','printshop','product','BlockBox','',1),(115808,'117644','printshop','block-115807','Breadcrumb','',1),(115809,'1683120066.375199','printshop','product','BlockBox','',2),(115810,'1683120066.40840','printshop','block-115809','BlockBox','',1),(115811,'1683120066.411537','printshop','block-115810','product\\Images','',2),(115812,'1683120066.412741','printshop','block-115810','Promotions\\widgets\\PromotionIcons','',1),(115813,'1683120066.41444','printshop','block-115810','product\\PropertiesIcons','',4),(115814,'1696601788.1354','printshop','block-115810-2','BlockBox','',1),(115815,'1683120066.4157','printshop','block-115814','BlockBox','',2),(115816,'1683120066.416580','printshop','block-115815','product\\Properties','',2),(115817,'1683120066.417385','printshop','block-115815','BlockBox','',1),(115818,'1683120066.41899','printshop','block-115817','product\\MultiInventory','',3),(115819,'1683120066.41955','printshop','block-115817','product\\DescriptionShort','',2),(115820,'1683120066.42249','printshop','block-115817','product\\Model','',1),(115821,'1683120066.423672','printshop','block-115817','product\\Groups','',4),(115822,'1683120066.42445','printshop','block-115815','Promotions\\widgets\\PromotionIconsDesc','',3),(115823,'1683120066.432243','printshop','block-115815-2','BlockBox','',1),(115824,'1683120066.43441','printshop','block-115823','BlockBox','',1),(115825,'1683120066.437271','printshop','block-115824','product\\SaleEnds','',1),(115826,'1683120066.450387','printshop','block-115824','BlockBox','',2),(115827,'1683120066.452834','printshop','block-115826','product\\QuantityDiscounts','',2),(115828,'1683120066.454686','printshop','block-115826','product\\PersonalCatalogButton','',5),(115829,'1683120066.458637','printshop','block-115826','BlockBox','',1),(115830,'1683120066.460688','printshop','block-115829','product\\Price','',1),(115831,'1683120066.46336','printshop','block-115829','product\\Stock','',2),(115832,'1683120066.465283','printshop','block-115826','BlockBox','',3),(115833,'1683120066.468523','printshop','block-115832','product\\Buttons','',1),(115834,'1683120066.472391','printshop','block-115832-2','product\\Quantity','',1),(115835,'1683120066.480552','printshop','block-115826','BlockBox','',4),(115836,'1683120066.48186','printshop','block-115835','product\\ButtonsQuote','',1),(115837,'1683120066.483821','printshop','block-115835-2','product\\ButtonsSample','',1),(115838,'1683120066.485594','printshop','block-115823','product\\BonusPoints','',2),(115839,'1683120066.488481','printshop','block-115814','product\\Name','',1),(115840,'1683120066.489437','printshop','block-115809','BlockBox','',3),(115841,'1683120066.490651','printshop','block-115840','product\\InBundles','',2),(115842,'1683120066.494682','printshop','block-115840','product\\Bundle','',1),(115843,'1683120087.08448','printshop','product','BlockBox','',5),(115844,'1683120087.116193','printshop','block-115843','BlockBox','',1),(115845,'1683120087.118690','printshop','block-115844','Tabs','',3),(115846,'1683120087.12923','printshop','block-115845-1','product\\Description','',2),(115847,'1683120087.13141','printshop','block-115845-2','InfoPage','',1),(115848,'1683120087.133123','printshop','block-115845-3','product\\Attributes','',1),(115849,'1683120087.14498','printshop','block-115843','Tabs','',3),(115850,'1683120087.145578','printshop','block-115849-1','product\\AlsoPurchased','10',1),(115851,'1683120087.150199','printshop','block-115849-2','ViewedProducts','4',1),(115852,'1683120087.154258','printshop','block-115843','BlockBox','',4),(115853,'1683120087.155397','printshop','block-115852','product\\Reviews','',1),(115854,'1683120087.157963','printshop','block-115843','BlockBox','',2),(115855,'1683120087.159777','printshop','block-115854','Banner','',0),(115856,'117655','printshop','product-bottom','product\\Properties','',1),(115857,'117656','printshop','product-tabs','product\\Reviews','',2),(115858,'117657','printshop','product-tabs','product\\Description','',1),(115859,'117658','printshop','product-top-left','product\\Images','',1),(115860,'117659','printshop','product-top-right','product\\Price','',2),(115861,'117660','printshop','product-top-right','product\\Quantity','',5),(115862,'117661','printshop','product-top-right','product\\Quantity','',6),(115863,'117662','printshop','product-top-right','product\\Attributes','',3),(115864,'117663','printshop','product-top-right','product\\Name','',1),(115865,'117664','printshop','product-top-right','product\\Buttons','',6),(115866,'117665','printshop','productListing','BlockBox','listing-item',1),(115867,'120921','printshop','block-115866','BlockBox','',1),(115868,'117667','printshop','block-115867','productListing\\bonusPoints','',3),(115869,'117671','printshop','block-115867','productListing\\image','',1),(115870,'1639645717.6681','printshop','block-115867','productListing\\productGroup','',4),(115871,'117677','printshop','block-115867','productListing\\compare','',2),(115872,'120919','printshop','block-115867-2','BlockBox','',1),(115873,'117668','printshop','block-115872','productListing\\description','',2),(115874,'117675','printshop','block-115872','productListing\\name','',1),(115875,'1644336042.3199','printshop','block-115872','BlockBox','',3),(115876,'117676','printshop','block-115875','productListing\\stock','',1),(115877,'117670','printshop','block-115875-2','productListing\\rating','',1),(115878,'120863','printshop','block-115875-2','productListing\\ratingCounts','',2),(115879,'1644336088.4429','printshop','block-115872','BlockBox','',4),(115880,'117673','printshop','block-115879','productListing\\price','',1),(115881,'120895','printshop','block-115879-2','productListing\\viewButton','',1),(115882,'1644336183.1139','printshop','block-115872','BlockBox','',6),(115883,'120882','printshop','block-115882','productListing\\personalCatalog','',1),(115884,'117678','printshop','products','BlockBox','catalog-content',2),(115885,'117679','printshop','block-115884','BlockBox','catalog-side',4),(115886,'117680','printshop','block-115885','Filters','',3),(115887,'117681','printshop','block-115885','HeaderStock','',4),(115888,'117682','printshop','block-115885-2','catalog\\B2bAddButton','',5),(115889,'117683','printshop','block-115885-2','BlockBox','catalog-features',2),(115890,'117684','printshop','block-115889','catalog\\Sorting','',3),(115891,'117685','printshop','block-115889','catalog\\ListingLook','',1),(115892,'117686','printshop','block-115889','catalog\\ItemsOnPage','',4),(115893,'117687','printshop','block-115889','catalog\\CompareButton','',2),(115894,'117688','printshop','block-115885-2','BlockBox','',6),(115895,'117689','printshop','block-115894','catalog\\CountsItems','',1),(115896,'117690','printshop','block-115894-2','catalog\\Paging','',1),(115897,'117691','printshop','block-115885-2','Listing','',4),(115898,'1639760443.0645','printshop','block-115885-2','catalog\\AdditionalImages','',1),(115899,'117692','printshop','block-115884','catalog\\Title','',2),(115900,'117693','printshop','block-115884','BlockBox','',3),(115901,'117694','printshop','block-115900','catalog\\Image','',2),(115902,'1639415554.3073','printshop','block-115900','product\\WeddingRegistryButton','',3),(115903,'121018','printshop','products','Compare','',3),(115904,'1645192276.9329','printshop','products','BlockBox','',1),(115905,'1645192301.6776','printshop','block-115904','Breadcrumb','',0),(115906,'117695','printshop','products-list','packingslip\\AllProductsList','',2),(115907,'117696','printshop','promotions','BlockBox','info-content',1),(115908,'117697','printshop','block-115907','promotions\\PromoList','',2),(115909,'117698','printshop','block-115907','Html_box','',1),(115910,'117699','printshop','purchase','invoice\\Container','',1),(115911,'117700','printshop','block-115910','invoice\\Products','',3),(115912,'117701','printshop','block-115910','BlockBox','',5),(115913,'117702','printshop','block-115912','Text','',1),(115914,'117703','printshop','block-115912','invoice\\StoreAddress','',8),(115915,'117704','printshop','block-115912-2','Text','',2),(115916,'117705','printshop','block-115912-2','Logo','',1),(115917,'117706','printshop','block-115912-3','BlockBox','',3),(115918,'117707','printshop','block-115917','Text','',1),(115919,'117708','printshop','block-115917-2','invoice\\StoreEmail','',1),(115920,'117709','printshop','block-115912-3','Text','',1),(115921,'117710','printshop','block-115912-3','BlockBox','',2),(115922,'117711','printshop','block-115921','Text','',1),(115923,'117712','printshop','block-115921-2','invoice\\StorePhone','',1),(115924,'117713','printshop','block-115910','BlockBox','',1),(115925,'117714','printshop','block-115924','Logo','',1),(115926,'117715','printshop','block-115924-2','BlockBox','',2),(115927,'117716','printshop','block-115926','Text','',1),(115928,'117717','printshop','block-115926-2','invoice\\StorePhone','',1),(115929,'117718','printshop','block-115924-2','BlockBox','',4),(115930,'117719','printshop','block-115929','Text','',1),(115931,'117720','printshop','block-115929-2','invoice\\StoreSite','',1),(115932,'117721','printshop','block-115924-2','BlockBox','',1),(115933,'117722','printshop','block-115932','invoice\\StoreAddress','',1),(115934,'117723','printshop','block-115924-2','BlockBox','',3),(115935,'117724','printshop','block-115934','Text','',1),(115936,'117725','printshop','block-115934-2','invoice\\StoreEmail','',1),(115937,'117726','printshop','block-115910','BlockBox','',2),(115938,'117727','printshop','block-115937','BlockBox','',7),(115939,'117728','printshop','block-115938','BlockBox','',1),(115940,'117729','printshop','block-115939','invoice\\BillingAddress','',2),(115941,'117730','printshop','block-115939','Text','',1),(115942,'117731','printshop','block-115938-2','BlockBox','',1),(115943,'117732','printshop','block-115942','invoice\\CustomerEmail','',6),(115944,'117733','printshop','block-115942','Text','',5),(115945,'117734','printshop','block-115942','invoice\\CustomerPhone','',4),(115946,'117735','printshop','block-115942','invoice\\CustomerName','',2),(115947,'117736','printshop','block-115942','Text','',3),(115948,'117737','printshop','block-115942','Text','',1),(115949,'117738','printshop','block-115937-2','invoice\\OrderId','',1),(115950,'117739','printshop','block-115937-2','Text','',2),(115951,'117740','printshop','block-115937-2','invoice\\PaymentDate','',3),(115952,'117741','printshop','block-115910','BlockBox','',4),(115953,'117742','printshop','block-115952','BlockBox','',1),(115954,'117743','printshop','block-115953','invoice\\ShippingAddress','',2),(115955,'117744','printshop','block-115953','Text','',1),(115959,'117745','printshop','quotations','BlockBox','',1),(115960,'117746','printshop','block-115959','BlockBox','',1),(115961,'117747','printshop','block-115960','WidgetsAria','',1),(115981,'117748','printshop','block-115960-2','Html_box','',1),(115982,'117749','printshop','block-115960-2','Quotations\\QuotationsHistory','',2),(115983,'117750','printshop','quotation_info','BlockBox','',1),(115984,'117751','printshop','block-115983','BlockBox','',1),(115985,'117752','printshop','block-115984','WidgetsAria','',1),(116005,'117753','printshop','block-115984-2','BlockBox','',5),(116006,'117754','printshop','block-116005','BlockBox','',1),(116007,'117755','printshop','block-116006','Quotations\\QuotationData','',2),(116008,'117756','printshop','block-116006','Html_box','',1),(116009,'117757','printshop','block-116005','BlockBox','',4),(116010,'117758','printshop','block-116009','Html_box','',1),(116011,'117759','printshop','block-116009','Quotations\\QuotationData','',2),(116012,'117760','printshop','block-116005-2','BlockBox','',2),(116013,'117761','printshop','block-116012','Html_box','',1),(116014,'117762','printshop','block-116012','Quotations\\QuotationData','',2),(116015,'117763','printshop','block-116005-2','BlockBox','',1),(116016,'117764','printshop','block-116015','Html_box','',1),(116017,'117765','printshop','block-116015','Quotations\\QuotationData','',2),(116018,'117766','printshop','block-116005-3','BlockBox','',1),(116019,'117767','printshop','block-116018','Quotations\\QuotationData','',2),(116020,'117768','printshop','block-116018','Html_box','',1),(116021,'117769','printshop','block-116005-3','BlockBox','',2),(116022,'117770','printshop','block-116021','Quotations\\QuotationData','',2),(116023,'117771','printshop','block-116021','Html_box','',1),(116024,'117772','printshop','block-115984-2','Html_box','',6),(116025,'117773','printshop','block-115984-2','Quotations\\QuotationHistory','',10),(116026,'117774','printshop','block-115984-2','Html_box','',9),(116027,'117775','printshop','block-115984-2','Quotations\\QuotationProducts','',7),(116028,'117776','printshop','block-115984-2','Quotations\\QuotationSubTotal','',8),(116029,'117777','printshop','block-115984-2','BlockBox','',12),(116030,'117778','printshop','block-116029','account\\AccountLink','',1),(116031,'117779','printshop','block-115984-2','Html_box','',4),(116032,'117780','printshop','quote','BlockBox','',1),(116033,'117781','printshop','block-116032','cart\\CartTabs','',1),(116034,'117782','printshop','block-116033','BlockBox','',1),(116035,'117783','printshop','block-116034','quote\\Products','',1),(116036,'117784','printshop','block-116034-2','BlockBox','',1),(116037,'117785','printshop','block-116036','BlockBox','',1),(116038,'117786','printshop','block-116037','quote\\CheckoutBtn','',2),(116039,'117787','printshop','block-116033','Quotations\\QuotationSubTotal','',2),(116064,'117793','printshop','reviews','BlockBox','info-content',1),(116065,'117794','printshop','block-116064','reviews\\Heading','',1),(116066,'117795','printshop','block-116064','reviews\\Content','',2),(116067,'117796','printshop','rma_document','invoice\\Container','',1),(116068,'117797','printshop','block-116067','BlockBox','',1),(116069,'117798','printshop','block-116068','BlockBox','',1),(116070,'117799','printshop','block-116069','BlockBox','',2),(116071,'117800','printshop','block-116070','Html_box','',1),(116072,'117801','printshop','block-116070-2','Html_box','',1),(116073,'117802','printshop','block-116069','BlockBox','',5),(116074,'117803','printshop','block-116073','Html_box','',1),(116075,'117804','printshop','block-116073-2','Html_box','',1),(116076,'117805','printshop','block-116069','BlockBox','',4),(116077,'117806','printshop','block-116076','Html_box','',1),(116078,'117807','printshop','block-116076-2','Html_box','',1),(116079,'117808','printshop','block-116069','BlockBox','',3),(116080,'117809','printshop','block-116079','Html_box','',1),(116081,'117810','printshop','block-116079-2','Html_box','',1),(116082,'117811','printshop','block-116069','BlockBox','',1),(116083,'117812','printshop','block-116082','Html_box','',1),(116084,'117813','printshop','block-116082','Html_box','',2),(116085,'117814','printshop','block-116068-2','BlockBox','',1),(116086,'117815','printshop','block-116085','Html_box','',2),(116087,'117816','printshop','block-116085','Logo','',1),(116088,'117817','printshop','block-116068-2','BlockBox','',2),(116089,'117818','printshop','block-116088','BlockBox','',5),(116090,'117819','printshop','block-116089','BlockBox','',1),(116091,'117820','printshop','block-116090','Html_box','',1),(116092,'117821','printshop','block-116090-2','Rma\\DocumentData','',1),(116093,'117822','printshop','block-116089-2','BlockBox','',1),(116094,'117823','printshop','block-116093','Html_box','',1),(116095,'117824','printshop','block-116093-2','Rma\\DocumentData','',1),(116096,'117825','printshop','block-116088','BlockBox','',4),(116097,'117826','printshop','block-116096','BlockBox','',1),(116098,'117827','printshop','block-116097','Html_box','',1),(116099,'117828','printshop','block-116097-2','Rma\\DocumentData','',1),(116100,'117829','printshop','block-116096-2','BlockBox','',1),(116101,'117830','printshop','block-116100','Html_box','',1),(116102,'117831','printshop','block-116100-2','Rma\\DocumentData','',1),(116103,'117832','printshop','block-116088','BlockBox','',3),(116104,'117833','printshop','block-116103','BlockBox','',1),(116105,'117834','printshop','block-116104','Html_box','',1),(116106,'117835','printshop','block-116104-2','Rma\\DocumentData','',1),(116107,'117836','printshop','block-116103-2','BlockBox','',1),(116108,'117837','printshop','block-116107','Html_box','',1),(116109,'117838','printshop','block-116107-2','Rma\\DocumentData','',1),(116110,'117839','printshop','block-116088','BlockBox','',2),(116111,'117840','printshop','block-116110','Html_box','',1),(116112,'117841','printshop','block-116110-2','Rma\\DocumentData','',1),(116113,'117842','printshop','block-116088','BlockBox','',1),(116114,'117843','printshop','block-116113','BlockBox','',1),(116115,'117844','printshop','block-116114','Html_box','',1),(116116,'117845','printshop','block-116114-2','Rma\\DocumentData','',1),(116117,'117846','printshop','block-116113-2','BlockBox','',1),(116118,'117847','printshop','block-116117','Html_box','',1),(116119,'117848','printshop','block-116117-2','Rma\\DocumentData','',1),(116120,'117849','printshop','block-116068-2','BlockBox','',3),(116121,'117850','printshop','block-116120','BlockBox','',1),(116122,'117851','printshop','block-116121','Html_box','',1),(116123,'117852','printshop','block-116121-2','Rma\\DocumentData','',1),(116124,'117853','printshop','block-116120-2','BlockBox','',1),(116125,'117854','printshop','block-116124','Html_box','',1),(116126,'117855','printshop','block-116124-2','Rma\\DocumentData','',1),(116127,'117856','printshop','block-116067','BlockBox','',2),(116128,'117857','printshop','block-116127','Html_box','',1),(116129,'117858','printshop','block-116127','Rma\\Products','',2),(116130,'117859','printshop','block-116067','BlockBox','',3),(116131,'117860','printshop','block-116130','BlockBox','',1),(116132,'117861','printshop','block-116131','BlockBox','',1),(116133,'117862','printshop','block-116132','BlockBox','',5),(116134,'117863','printshop','block-116133','Html_box','',1),(116135,'117864','printshop','block-116133-2','invoice\\StoreAddress','',2),(116136,'117865','printshop','block-116133-2','Html_box','',1),(116137,'117866','printshop','block-116132','BlockBox','',4),(116138,'117867','printshop','block-116137','Html_box','',1),(116139,'117868','printshop','block-116137-2','Html_box','',1),(116140,'117869','printshop','block-116132','BlockBox','',2),(116141,'117870','printshop','block-116140','Html_box','',1),(116142,'117871','printshop','block-116140-2','Html_box','',1),(116143,'117872','printshop','block-116132','BlockBox','',1),(116144,'117873','printshop','block-116143','Html_box','',1),(116145,'117874','printshop','block-116132','BlockBox','',3),(116146,'117875','printshop','block-116145','Html_box','',1),(116147,'117876','printshop','block-116145-2','Html_box','',1),(116148,'117877','printshop','block-116132','BlockBox','',6),(116149,'117878','printshop','block-116148','Html_box','',1),(116150,'117879','printshop','block-116131-2','BlockBox','',1),(116151,'117880','printshop','block-116150','BlockBox','',1),(116152,'117881','printshop','block-116151','BlockBox','',1),(116153,'117882','printshop','block-116152','Rma\\DocumentData','',2),(116154,'117883','printshop','block-116152-3','BlockBox','',1),(116155,'117884','printshop','block-116154','Html_box','',1),(116156,'117885','printshop','block-116154-2','Rma\\DocumentData','',1),(116157,'117886','printshop','block-116151','BlockBox','',2),(116158,'117887','printshop','block-116157-2','invoice\\StoreAddress','',1),(116159,'117888','printshop','block-116131-2','BlockBox','',2),(116160,'117889','printshop','block-116159','Html_box','',1),(116161,'117890','printshop','block-116159','Html_box','',2),(116162,'117891','printshop','block-116159','Html_box','',3),(116163,'117892','printshop','block-116159','Html_box','',4),(116164,'117893','printshop','block-116159','Html_box','',5),(116165,'117894','printshop','block-116131-2','BlockBox','',4),(116166,'117895','printshop','block-116165','Html_box','',1),(116167,'117896','printshop','block-116165-2','Html_box','',1),(116168,'117897','printshop','block-116165-3','BlockBox','',1),(116169,'117898','printshop','block-116168','Html_box','',1),(116170,'117899','printshop','block-116168-2','Html_box','',1),(116171,'117900','printshop','block-116131-2','BlockBox','',3),(116172,'117901','printshop','block-116171','Html_box','',1),(116173,'117902','printshop','block-116171-2','Html_box','',1),(116174,'117903','printshop','block-116171-3','BlockBox','',1),(116175,'117904','printshop','block-116174','Html_box','',1),(116176,'117905','printshop','block-116174-2','Html_box','',1),(116177,'117906','printshop','rows','BlockBox','listing-item',1),(116178,'117907','printshop','block-116177','BlockBox','',2),(116179,'117908','printshop','block-116178','BlockBox','',2),(116180,'117909','printshop','block-116179','productListing\\bonusPoints','',2),(116181,'117910','printshop','block-116179','productListing\\image','',1),(116182,'117914','printshop','block-116179-2','productListing\\name','',1),(116183,'117915','printshop','block-116179-2','productListing\\description','',2),(116184,'117916','printshop','block-116179-2','productListing\\model','',4),(116185,'117917','printshop','block-116179-2','productListing\\attributes','',5),(116186,'120922','printshop','block-116179-2','productListing\\properties','',3),(116187,'1639146806.7019','printshop','block-116179-2','productListing\\productGroup','',6),(116188,'117918','printshop','block-116178-2','BlockBox','listing-item',1),(116189,'117911','printshop','block-116188','BlockBox','',3),(116190,'117912','printshop','block-116189','productListing\\rating','',1),(116191,'117913','printshop','block-116189','productListing\\ratingCounts','',2),(116192,'117919','printshop','block-116188','productListing\\qtyInput','',4),(116193,'117920','printshop','block-116188','productListing\\price','',2),(116194,'117922','printshop','block-116188','productListing\\buyButton','',5),(116195,'117924','printshop','block-116188','productListing\\stock','',1),(116196,'120925','printshop','block-116188','productListing\\compare','',8),(116197,'120926','printshop','block-116188','productListing\\personalCatalog','',7),(116198,'120927','printshop','block-116188','productListing\\viewButton','',6),(116199,'117925','printshop','sample','BlockBox','',1),(116200,'117926','printshop','block-116199','cart\\CartTabs','',1),(116201,'117927','printshop','block-116200','BlockBox','',1),(116202,'117928','printshop','block-116201','sample\\Products','',1),(116203,'117929','printshop','block-116201-2','BlockBox','',1),(116204,'117930','printshop','block-116203','BlockBox','',1),(116205,'117931','printshop','block-116204','sample\\CheckoutBtn','',1),(116206,'117932','printshop','samples','BlockBox','',1),(116207,'117933','printshop','block-116206','BlockBox','',1),(116208,'117934','printshop','block-116207','WidgetsAria','',1),(116228,'117935','printshop','block-116207-2','Html_box','',1),(116229,'117936','printshop','block-116207-2','Samples\\SamplesHistory','',2),(116230,'117937','printshop','sample_info','BlockBox','',1),(116231,'117938','printshop','block-116230','BlockBox','',1),(116232,'117939','printshop','block-116231','WidgetsAria','',1),(116252,'117940','printshop','block-116231-2','Html_box','',1),(116253,'117941','printshop','block-116231-2','BlockBox','',8),(116254,'117942','printshop','block-116253','account\\AccountLink','',1),(116255,'117943','printshop','block-116231-2','Samples\\SampleHistory','',7),(116256,'117944','printshop','block-116231-2','Html_box','',3),(116257,'117945','printshop','block-116231-2','Samples\\SampleSubTotal','',5),(116258,'117946','printshop','block-116231-2','Samples\\SampleProducts','',4),(116259,'117947','printshop','block-116231-2','Html_box','',6),(116260,'117948','printshop','block-116231-2','BlockBox','',2),(116261,'117949','printshop','block-116260','BlockBox','',4),(116262,'117950','printshop','block-116261','Html_box','',1),(116263,'117951','printshop','block-116261','Samples\\SampleData','',2),(116264,'117952','printshop','block-116260','BlockBox','',1),(116265,'117953','printshop','block-116264','Samples\\SampleData','',2),(116266,'117954','printshop','block-116264','Html_box','',1),(116267,'117955','printshop','block-116260-2','BlockBox','',2),(116268,'117956','printshop','block-116267','Samples\\SampleData','',2),(116269,'117957','printshop','block-116267','Html_box','',1),(116270,'117958','printshop','block-116260-2','BlockBox','',1);
INSERT INTO `design_boxes` VALUES (116271,'117959','printshop','block-116270','Samples\\SampleData','',2),(116272,'117960','printshop','block-116270','Html_box','',1),(116273,'117961','printshop','block-116260-3','BlockBox','',2),(116274,'117962','printshop','block-116273','Samples\\SampleData','',2),(116275,'117963','printshop','block-116273','Html_box','',1),(116276,'117964','printshop','block-116260-3','BlockBox','',1),(116277,'117965','printshop','block-116276','Samples\\SampleData','',2),(116278,'117966','printshop','block-116276','Html_box','',1),(116279,'117967','printshop','sitemap','BlockBox','info-content',1),(116280,'117968','printshop','block-116279','Html_box','',1),(116281,'117969','printshop','block-116279','BlockBox','',2),(116282,'117970','printshop','block-116281','Html_box','',1),(116283,'117971','printshop','block-116281','Html_box','',5),(116284,'117972','printshop','block-116281','Html_box','',3),(116285,'117973','printshop','block-116281','sitemap\\InfoPages','',2),(116286,'117974','printshop','block-116281','sitemap\\Categories','',4),(116287,'117975','printshop','block-116281','Menu','Account box',6),(116288,'117976','printshop','block-116281-2','sitemap\\DeliveryLocation','',2),(116289,'117977','printshop','block-116281-2','Html_box','',1),(116290,'120878','printshop','social','SocialLinks','',1),(116291,'117978','printshop','subscribe','BlockBox','',1),(116292,'117979','printshop','block-116291','Html_box','',3),(116293,'117980','printshop','block-116291','subscribers\\UnsubscribeForm','',4),(116294,'117981','printshop','block-116291','Html_box','',1),(116295,'117982','printshop','block-116291','subscribers\\SubscribeForm','',2),(116296,'117983','printshop','subscribed','BlockBox','',1),(116297,'117984','printshop','block-116296','Html_box','',1),(116298,'117985','printshop','subscription','BlockBox','',2),(116299,'117986','printshop','block-116298','BlockBox','',1),(116300,'117987','printshop','block-116299','WidgetsAria','',1),(116320,'117988','printshop','block-116299-2','Html_box','',2),(116321,'117989','printshop','block-116299-2','Html_box','',3),(116322,'117990','printshop','block-116299-2','account\\Subscription','',4),(116323,'1694162315.037980','printshop','success','BlockBox','',1),(116324,'1694162315.120936','printshop','block-116323','BlockBox','',2),(116325,'1694162315.123135','printshop','block-116324','BlockBox','',3),(116326,'1694162315.12436','printshop','block-116325','BlockBox','',2),(116327,'1694162315.125735','printshop','block-116326','BlockBox','',1),(116328,'1694162315.12826','printshop','block-116327','order\\ShippingMethod','',6),(116329,'1694162315.128991','printshop','block-116327','order\\DeliveryAddress','',3),(116330,'1694162315.136','printshop','block-116327','Html_box','',7),(116331,'1694162315.143264','printshop','block-116327','Html_box','',5),(116332,'1694162315.14584','printshop','block-116327','Html_box','',1),(116333,'1694162315.146322','printshop','block-116327','checkout\\ContactConfirm','',9),(116334,'1694162315.147338','printshop','block-116327','Html_box','',2),(116335,'1694162315.14989','printshop','block-116326-2','BlockBox','',1),(116336,'1694162315.150471','printshop','block-116335','order\\PaymentMethod','',6),(116337,'1694162315.151341','printshop','block-116335','order\\BillingAddress','',3),(116338,'1694162315.152381','printshop','block-116335','Html_box','',5),(116339,'1694162315.153514','printshop','block-116335','Html_box','',1),(116340,'1694162315.154777','printshop','block-116335','Html_box','',2),(116341,'1694162315.155812','printshop','block-116325','Html_box','',1),(116342,'1694162315.15769','printshop','block-116324-2','BlockBox','',1),(116343,'1694162315.158534','printshop','block-116342','success\\PrintBtn','',3),(116344,'1694162315.1668','printshop','block-116342','success\\ContinueBtn','',4),(116345,'1694162315.16157','printshop','block-116342','order\\Products','',1),(116346,'1694162315.162213','printshop','block-116342','order\\Totals','',2),(116347,'1694162315.163184','printshop','block-116323','BlockBox','',1),(116348,'1694162315.16467','printshop','block-116347','Html_box','',2),(116349,'1694162315.165266','printshop','block-116347','order\\OrderNumber','',1),(116350,'117997','printshop','success_q','BlockBox','',1),(116351,'117998','printshop','block-116350','BlockBox','',1),(116352,'117999','printshop','block-116351','BlockBox','',2),(116353,'118000','printshop','block-116352','success\\ContinueBtn','',2),(116354,'118001','printshop','block-116352','success\\PrintBtn','',1),(116355,'118002','printshop','block-116351','Html_box','',1),(116360,'118007','printshop','ticket','invoice\\Container','',1),(116361,'118008','printshop','block-116360','BlockBox','',4),(116362,'118009','printshop','block-116361','BlockBox','',1),(116363,'118010','printshop','block-116362','invoice\\ShippingAddress','',2),(116364,'118011','printshop','block-116362','Text','',1),(116365,'118012','printshop','block-116361-2','BlockBox','',1),(116366,'118013','printshop','block-116365','invoice\\Totals','',1),(116367,'118014','printshop','block-116360','BlockBox','',5),(116368,'118015','printshop','block-116367','Text','',1),(116369,'118016','printshop','block-116367','invoice\\StoreAddress','',8),(116370,'118018','printshop','block-116367-2','Text','',2),(116371,'118019','printshop','block-116367-3','Text','',1),(116372,'118020','printshop','block-116367-3','BlockBox','',3),(116373,'118021','printshop','block-116372','Text','',1),(116374,'118022','printshop','block-116372-2','invoice\\StoreEmail','',1),(116375,'118023','printshop','block-116367-3','BlockBox','',2),(116376,'118024','printshop','block-116375','Text','',1),(116377,'118025','printshop','block-116375-2','invoice\\StorePhone','',1),(116378,'118026','printshop','block-116360','invoice\\Products','',3),(116379,'118027','printshop','block-116360','BlockBox','',1),(116380,'118028','printshop','block-116379-2','BlockBox','',3),(116381,'118029','printshop','block-116380','Text','',1),(116382,'118030','printshop','block-116380-2','invoice\\StoreEmail','',1),(116383,'118031','printshop','block-116379-2','BlockBox','',4),(116384,'118032','printshop','block-116383','Text','',1),(116385,'118033','printshop','block-116383-2','invoice\\StoreSite','',1),(116386,'118034','printshop','block-116379-2','BlockBox','',1),(116387,'118035','printshop','block-116386','invoice\\StoreAddress','',1),(116388,'118036','printshop','block-116379-2','BlockBox','',2),(116389,'118037','printshop','block-116388','Text','',1),(116390,'118038','printshop','block-116388-2','invoice\\StorePhone','',1),(116391,'118039','printshop','block-116360','BlockBox','',2),(116392,'118040','printshop','block-116391','BlockBox','',8),(116393,'118041','printshop','block-116392','BlockBox','',1),(116394,'118042','printshop','block-116393','Text','',1),(116395,'118043','printshop','block-116393','invoice\\ShippingMethod','',2),(116396,'118044','printshop','block-116392-2','BlockBox','',1),(116397,'118045','printshop','block-116396','Text','',1),(116398,'118046','printshop','block-116396','invoice\\ShippingMethod','',2),(116399,'118047','printshop','block-116391','BlockBox','',7),(116400,'118048','printshop','block-116399','BlockBox','',1),(116401,'118049','printshop','block-116400','invoice\\BillingAddress','',2),(116402,'118050','printshop','block-116400','Text','',1),(116403,'118051','printshop','block-116399-2','BlockBox','',1),(116404,'118052','printshop','block-116403','invoice\\CustomerName','',2),(116405,'118053','printshop','block-116403','Text','',3),(116406,'118054','printshop','block-116403','invoice\\CustomerEmail','',6),(116407,'118055','printshop','block-116403','invoice\\CustomerPhone','',4),(116408,'118056','printshop','block-116403','Text','',5),(116409,'118057','printshop','block-116403','Text','',1),(116410,'118058','printshop','block-116391-2','invoice\\PaymentDate','',3),(116411,'118059','printshop','block-116391-2','Text','',2),(116412,'118060','printshop','block-116391-2','Text','',4),(116413,'118061','printshop','block-116391-2','invoice\\OrderId','',1),(116414,'118062','printshop','block-116391-2','invoice\\PaymentMethod','',5),(116415,'118063','printshop','block-116391-2','invoice\\OrderBarcode','',6),(116416,'118094','printshop','tracking_numbers','BlockBox','',1),(116417,'118095','printshop','block-116416','Html_box','',1),(116418,'118096','printshop','block-116416','account\\OrderTracking','',2),(116419,'118318','printshop','unsubscribed','BlockBox','',1),(116420,'118319','printshop','block-116419','Html_box','',1),(116421,'118320','printshop','update-and-pay-order_confirmation','BlockBox','',1),(116422,'118321','printshop','block-116421','BlockBox','',3),(116423,'118322','printshop','block-116422','BlockBox','',1),(116424,'118323','printshop','block-116423','BlockBox','',1),(116425,'118324','printshop','block-116424','BlockBox','',1),(116426,'118325','printshop','block-116425','order\\ShippingMethod','',5),(116427,'118326','printshop','block-116425','Html_box','',2),(116428,'118327','printshop','block-116425','Html_box','',4),(116429,'118328','printshop','block-116425','Html_box','',1),(116430,'118329','printshop','block-116425','order\\Telephone','',8),(116431,'118330','printshop','block-116425','Html_box','',6),(116432,'118331','printshop','block-116425','order\\Name','',7),(116433,'118332','printshop','block-116425','order\\Email','',9),(116434,'118333','printshop','block-116425','order\\DeliveryAddress','',3),(116435,'118334','printshop','block-116424-2','BlockBox','',1),(116436,'118335','printshop','block-116435','order\\BillingAddress','',3),(116437,'118336','printshop','block-116435','UpdateAndPay\\PayConfirm','',5),(116438,'118337','printshop','block-116435','Html_box','',1),(116439,'118338','printshop','block-116435','Html_box','',2),(116440,'118339','printshop','block-116435','Html_box','',4),(116441,'118340','printshop','block-116423','BlockBox','',3),(116442,'118341','printshop','block-116441','order\\Products','',2),(116443,'118342','printshop','block-116441','Html_box','',1),(116444,'118343','printshop','block-116422-2','BlockBox','',1),(116445,'118344','printshop','block-116444','Html_box','',1),(116446,'118345','printshop','block-116444','checkout\\ContinueBtn','',3),(116447,'118346','printshop','block-116444','order\\Totals','',2),(116448,'118347','printshop','block-116421','account\\OrderHeading','',1),(116449,'118348','printshop','update-and-pay-order_pay','BlockBox','',1),(116450,'118349','printshop','block-116449','BlockBox','',3),(116451,'118350','printshop','block-116450','BlockBox','',1),(116452,'118351','printshop','block-116451','BlockBox','',1),(116453,'118352','printshop','block-116452','BlockBox','',1),(116454,'118353','printshop','block-116453','order\\DeliveryAddress','',4),(116455,'118354','printshop','block-116453','order\\Email','',10),(116456,'118355','printshop','block-116453','order\\Name','',8),(116457,'118356','printshop','block-116453','Html_box','',7),(116458,'118357','printshop','block-116453','order\\Telephone','',9),(116459,'118358','printshop','block-116453','Html_box','',5),(116460,'118359','printshop','block-116453','order\\ShippingMethod','',6),(116461,'118360','printshop','block-116453','Html_box','',2),(116462,'118361','printshop','block-116453','Html_box','',3),(116463,'1639647774.7838','printshop','block-116453','DelayedDespatch\\OrderPay','',1),(116464,'118362','printshop','block-116452-2','BlockBox','',1),(116465,'118363','printshop','block-116464','Html_box','',1),(116466,'118364','printshop','block-116464','Html_box','',2),(116467,'118365','printshop','block-116464','Html_box','',4),(116468,'118366','printshop','block-116464','order\\BillingAddress','',3),(116469,'118367','printshop','block-116464','UpdateAndPay\\PayForm','',5),(116470,'118368','printshop','block-116451','BlockBox','',3),(116471,'118369','printshop','block-116470','Html_box','',1),(116472,'118370','printshop','block-116470','order\\Products','',2),(116473,'118371','printshop','block-116450-2','BlockBox','',1),(116474,'118372','printshop','block-116473','order\\Totals','',2),(116475,'118373','printshop','block-116473','checkout\\ContinueBtn','',3),(116476,'118374','printshop','block-116473','Html_box','',1),(116477,'118375','printshop','block-116449','account\\OrderHeading','',1),(116478,'118440','printshop','wishlist','BlockBox','',1),(116479,'118441','printshop','block-116478','BlockBox','',1),(116480,'118442','printshop','block-116479','WidgetsAria','',1),(116500,'118443','printshop','block-116479-2','account\\Wishlist','',2),(116501,'118444','printshop','block-116479-2','Html_box','',1),(116502,'118445','printshop','wishlist-cart','BlockBox','',1),(116503,'118446','printshop','block-116502','cart\\CartTabs','',1),(116504,'118447','printshop','block-116503','account\\Wishlist','',1),(121477,'116005','deals','404','Html_box','',1),(121705,'117906','deals','b2b','BlockBox','listing-item',1),(121706,'117907','deals','block-121705','BlockBox','',2),(121707,'117908','deals','block-121706','BlockBox','',2),(121708,'117909','deals','block-121707','productListing\\bonusPoints','',2),(121709,'117910','deals','block-121707','productListing\\image','',1),(121710,'117914','deals','block-121707-2','productListing\\name','',1),(121711,'117915','deals','block-121707-2','productListing\\description','',2),(121712,'117916','deals','block-121707-2','productListing\\model','',4),(121713,'117917','deals','block-121707-2','productListing\\attributes','',5),(121714,'120922','deals','block-121707-2','productListing\\properties','',3),(121715,'117918','deals','block-121706-2','BlockBox','listing-item',1),(121716,'117911','deals','block-121715','BlockBox','',3),(121717,'117912','deals','block-121716','productListing\\rating','',1),(121718,'117913','deals','block-121716','productListing\\ratingCounts','',2),(121719,'117919','deals','block-121715','productListing\\qtyInput','',4),(121720,'117920','deals','block-121715','productListing\\price','',2),(121721,'117924','deals','block-121715','productListing\\stock','',1),(121722,'120924','deals','block-121715','BlockBox','',8),(121723,'120925','deals','block-121722','productListing\\compare','',3),(121724,'120926','deals','block-121722','productListing\\personalCatalog','',2),(121725,'120927','deals','block-121722','productListing\\viewButton','',1),(121726,'116176','deals','batch','BlockBox','',1),(121727,'116177','deals','block-121726','productListing\\attributes','',5),(121728,'116178','deals','block-121726','productListing\\price','',6),(121729,'116179','deals','block-121726','productListing\\name','',4),(121730,'116180','deals','block-121726','productListing\\image','',2),(121731,'116181','deals','block-121726','batchSelect','',1),(121732,'116182','deals','batch_selected','BlockBox','',1),(121733,'116183','deals','block-121732','BlockBox','',13),(121734,'116184','deals','block-121733','productListing\\image','',1),(121735,'116185','deals','block-121733-2','batchRemove','',1),(121736,'116186','deals','block-121733-2','productListing\\price','',3),(121737,'116187','deals','block-121733-2','productListing\\name','',2),(121738,'116188','deals','bbbbb','BlockBox','',1),(121739,'116189','deals','block-121738','BlockBox','',2),(121740,'116190','deals','block-121739','Filters','',1),(121741,'116191','deals','block-121739-2','BlockBox','',6),(121742,'116192','deals','block-121741','catalog\\CountsItems','',1),(121743,'116193','deals','block-121741-2','catalog\\Paging','',1),(121744,'116194','deals','block-121739-2','catalog\\Image','',1),(121745,'116195','deals','block-121739-2','Listing','',5),(121746,'116196','deals','block-121739-2','catalog\\ImageMapCategory','',3),(121747,'116197','deals','block-121739-2','BlockBox','',4),(121748,'116198','deals','block-121747','catalog\\ListingLook','',1),(121749,'116199','deals','block-121747','catalog\\CompareButton','',2),(121750,'116200','deals','block-121747','catalog\\ItemsOnPage','',4),(121751,'116201','deals','block-121747','catalog\\Sorting','',3),(121752,'116202','deals','block-121739-2','Categories','',2),(121753,'116203','deals','block-121738','catalog\\Title','',1),(121754,'1683114704.562135','deals','cart','BlockBox','',1),(121755,'1683114704.57226','deals','block-121754','BlockBox','',2),(121756,'1683114704.58194','deals','block-121755','BlockBox','cart-top',1),(121757,'1683114704.582420','deals','block-121756','cart\\Products','',3),(121758,'1683114704.583230','deals','block-121756','BlockBox','',2),(121759,'1683114704.585598','deals','block-121758','MultiCart\\CartSwitcher','',1),(121760,'1683114704.586389','deals','block-121758','MultiCart\\SaveCart','',2),(121761,'1683114704.587718','deals','block-121758-2','MultiCart\\Actions','',1),(121762,'1683114704.58974','deals','block-121756','Html_box','',1),(121763,'1683114704.594755','deals','block-121755','cart\\ShippingEstimator','',6),(121764,'1683114704.595625','deals','block-121755','cart\\DependedProducts','8',3),(121765,'1683114704.601126','deals','block-121755','BlockBox','cart-content',2),(121766,'1683114704.602943','deals','block-121765','BlockBox','',2),(121767,'1683114704.604593','deals','block-121766','cart\\CreditAmount','',1),(121768,'1683114704.605124','deals','block-121766-2','cart\\BonusPoints','',1),(121769,'1683114704.606118','deals','block-121755-2','BlockBox','cart-side',1),(121770,'1683114704.608683','deals','block-121769','BlockBox','',3),(121771,'1683114704.609838','deals','block-121770','cart\\DiscountCoupon','',2),(121772,'1683114704.623818','deals','block-121770','cart\\CheckoutBtn','',4),(121773,'1683114704.62578','deals','block-121770','cart\\OrderTotal','',3),(121774,'1683114704.626342','deals','block-121770','cart\\OrderTotal','',1),(121775,'1683114704.62755','deals','block-121769','Html_box','',1),(121776,'116242','deals','cart2','BlockBox','',2),(121777,'116243','deals','block-121776','cart\\CartTabs','',2),(121778,'116244','deals','block-121777','BlockBox','',1),(121779,'116245','deals','block-121778','BlockBox','',4),(121780,'116246','deals','block-121779','cart\\UpSell','6',2),(121781,'116247','deals','block-121779','Html_box','',1),(121782,'116248','deals','block-121778','BlockBox','',1),(121783,'116249','deals','block-121782','cart\\Products','',3),(121784,'116250','deals','block-121782','BlockBox','',2),(121785,'116251','deals','block-121784','MultiCart\\CartSwitcher','',1),(121786,'116252','deals','block-121784','MultiCart\\SaveCart','',2),(121787,'116253','deals','block-121784-2','MultiCart\\Actions','',1),(121788,'116254','deals','block-121778','BlockBox','',3),(121789,'116255','deals','block-121788','cart\\GiveAway','',2),(121790,'116256','deals','block-121788','Html_box','',1),(121791,'116257','deals','block-121778','BlockBox','',2),(121792,'116258','deals','block-121791','Html_box','',1),(121793,'116259','deals','block-121791','BlockBox','',2),(121794,'116260','deals','block-121793','cart\\DiscountCoupon','',1),(121795,'116261','deals','block-121793-2','cart\\CreditAmount','',1),(121796,'116262','deals','block-121793-3','cart\\BonusPoints','',1),(121797,'116263','deals','block-121778','BlockBox','',5),(121798,'116264','deals','block-121797','Html_box','',1),(121799,'116265','deals','block-121797','cart\\ShippingEstimator','',2),(121800,'116266','deals','block-121778-2','BlockBox','',1),(121801,'116267','deals','block-121800','Html_box','',1),(121802,'116268','deals','block-121800','BlockBox','',2),(121803,'116269','deals','block-121802','Image','',4),(121804,'116270','deals','block-121802','cart\\CheckoutBtn','',2),(121805,'116271','deals','block-121802','cart\\OrderTotal','',1),(121816,'116272','deals','categories','BlockBox','catalog-content',2),(121817,'116275','deals','block-121816','Listing','',6),(121818,'116277','deals','block-121816','BlockBox','',7),(121819,'116278','deals','block-121818','catalog\\CountsItems','',1),(121820,'116279','deals','block-121818-2','catalog\\Paging','',1),(121821,'116281','deals','block-121816','Categories','',3),(121822,'116282','deals','block-121816','BlockBox','catalog-features',5),(121823,'116283','deals','block-121822','catalog\\ListingLook','',1),(121824,'116287','deals','block-121816','catalog\\Title','',2),(121825,'1641809968','deals','block-121816','BlockBox','',4),(121826,'116286','deals','block-121825','catalog\\Sorting','',2),(121827,'1641810239','deals','block-121825','Filters','',1),(121828,'116288','deals','category','Categories','',1),(121829,'116289','deals','category','Listing','',4),(121830,'116290','deals','category','ListingFunctionality','',2),(121831,'116291','deals','category','PagingBar','',3),(121832,'116292','deals','category','PagingBar','',5),(121833,'116293','deals','category_2','BlockBox','',1),(121834,'116294','deals','block-121833','catalog\\Title','',1),(121835,'116295','deals','block-121833','BlockBox','',2),(121836,'116296','deals','block-121835','Filters','',1),(121837,'116297','deals','block-121835-2','catalog\\Image','',1),(121838,'116298','deals','block-121835-2','Listing','',5),(121839,'116299','deals','block-121835-2','BlockBox','',4),(121840,'116300','deals','block-121839','catalog\\Sorting','',3),(121841,'116301','deals','block-121839','catalog\\ItemsOnPage','',4),(121842,'116302','deals','block-121839','catalog\\CompareButton','',2),(121843,'116303','deals','block-121839','catalog\\ListingLook','',1),(121844,'116304','deals','block-121835-2','catalog\\ImageMapCategory','',3),(121845,'116305','deals','block-121835-2','Categories','',2),(121846,'116306','deals','block-121835-2','BlockBox','',6),(121847,'116307','deals','block-121846','catalog\\CountsItems','',1),(121848,'116308','deals','block-121846-2','catalog\\Paging','',1),(121849,'116309','deals','category_no_filters','BlockBox','catalog-content',1),(121850,'116310','deals','block-121849','catalog\\Title','',1),(121851,'116311','deals','block-121849','Categories','',3),(121852,'116312','deals','block-121849','BlockBox','catalog-features',4),(121853,'116313','deals','block-121852','catalog\\ItemsOnPage','',4),(121854,'116314','deals','block-121852','catalog\\Sorting','',3),(121855,'116315','deals','block-121852','catalog\\CompareButton','',2),(121856,'116316','deals','block-121852','catalog\\ListingLook','',1),(121857,'116318','deals','block-121849','BlockBox','',6),(121858,'116319','deals','block-121857','catalog\\CountsItems','',1),(121859,'116320','deals','block-121857-2','catalog\\Paging','',1),(121860,'116321','deals','block-121849','Listing','',5),(121861,'116322','deals','block-121849','catalog\\Image','',2),(121862,'116323','deals','block-121849','catalog\\B2bAddButton','',7),(121863,'1683116708.492798','deals','checkout','BlockBox','',1),(121864,'1683116708.500294','deals','block-121863','BlockBox','',2),(121865,'1683116708.502483','deals','block-121864','BlockBox','checkout-content',2),(121866,'1683116708.503841','deals','block-121865','BlockBox','checkout-comments',5),(121867,'1683116708.507547','deals','block-121866','checkout\\Comments','',2),(121868,'1683116708.50914','deals','block-121866','Html_box','',1),(121869,'1683116708.511660','deals','block-121865','BlockBox','checkout-discount',4),(121870,'1683116708.515882','deals','block-121869','Html_box','',1),(121871,'1683116708.517470','deals','block-121869','BlockBox','',2),(121872,'1683116708.518949','deals','block-121871','CouponsAndVauchers\\Checkout','',1),(121873,'1683116708.519823','deals','block-121871-2','checkout\\CreditAmount','',1),(121874,'1683116708.52078','deals','block-121871-2','checkout\\BonusPoints','',2),(121875,'1683116708.521619','deals','block-121865','BlockBox','checkout-shipping',2),(121876,'1683116708.52521','deals','block-121875','BlockBox','',3),(121877,'1683116708.527559','deals','block-121876','checkout\\ShippingChoice','',1),(121878,'1683116708.528597','deals','block-121875','Neighbour\\Checkout','',5),(121879,'1683116708.529860','deals','block-121875','BlockBox','',4),(121880,'1683116708.531118','deals','block-121879','BlockBox','',1),(121881,'1683116708.532686','deals','block-121880','checkout\\ShippingAddress','',2),(121882,'1683116708.533279','deals','block-121880','Html_box','',3),(121883,'1683116708.534524','deals','block-121880','checkout\\ContactInformation','',4),(121884,'1683116708.534947','deals','block-121880','UploadCustomerId\\UploadCustomerIdForm','',5),(121885,'1683116708.535390','deals','block-121879-2','BlockBox','',1),(121886,'1683116708.536845','deals','block-121885','checkout\\Shipping','',2),(121887,'1683116708.537397','deals','block-121885','DelayedDespatch\\Checkout','',4),(121888,'1683116708.538283','deals','block-121885','Html_box','',1),(121889,'1683116708.539729','deals','block-121885','DeliveryDay','',3),(121890,'1683116708.540444','deals','block-121875','Html_box','',2),(121891,'1683116708.541679','deals','block-121865','BlockBox','',8),(121892,'1683116708.544887','deals','block-121891','DeliveryOptions\\Checkout','',0),(121893,'1683116708.545373','deals','block-121865','cart\\Products','',6),(121894,'1683116708.547120','deals','block-121865','checkout\\CreateAccount','',7),(121895,'1683116708.548247','deals','block-121865','BlockBox','checkout-payment',3),(121896,'1683116708.551273','deals','block-121895','Html_box','',1),(121897,'1683116708.552428','deals','block-121895','BlockBox','',2),(121898,'1683116708.553758','deals','block-121897','Html_box','',1),(121899,'1683116708.55521','deals','block-121897','checkout\\BillingAddress','',2),(121900,'1683116708.5566','deals','block-121897-2','BlockBox','',1),(121901,'1683116708.557237','deals','block-121900','checkout\\PaymentMethod','',2),(121902,'1683116708.558367','deals','block-121900','Html_box','',1),(121903,'1683116708.559513','deals','block-121865','BlockBox','',1),(121904,'1683116708.562121','deals','block-121903','checkout\\LoginOnForm','',1),(121905,'1683116708.563392','deals','block-121864-2','BlockBox','checkout-side',1),(121906,'1683116708.56533','deals','block-121905','Html_box','',6),(121907,'1683116708.56713','deals','block-121905','Html_box','',1),(121908,'1683116708.568362','deals','block-121905','checkout\\Terms','',5),(121909,'1683116708.568971','deals','block-121905','checkout\\Totals','',3),(121910,'1683116708.569560','deals','block-121905','checkout\\ContinueBtn','',4),(121911,'1683116708.572798','deals','block-121905','cart\\Products','',2),(121912,'116368','deals','checkout_confirmation','BlockBox','',1),(121913,'116369','deals','block-121912','checkout\\Totals','',8),(121914,'116370','deals','block-121912','Html_box','',5),(121915,'116371','deals','block-121912','checkout\\EditBtn','',6),(121916,'116372','deals','block-121912','BlockBox','',3),(121917,'116373','deals','block-121916','BlockBox','',1),(121918,'116374','deals','block-121917','Html_box','',1),(121919,'116375','deals','block-121917','checkout\\ShippingConfirm','',3),(121920,'116376','deals','block-121916-2','BlockBox','',1),(121921,'116377','deals','block-121920','checkout\\PaymentMethodConfirm','',3),(121922,'116378','deals','block-121920','Html_box','',1),(121923,'116379','deals','block-121912','checkout\\ConfirmBtn','',9),(121924,'116380','deals','block-121912','BlockBox','',2),(121925,'116381','deals','block-121924','BlockBox','',1),(121926,'116382','deals','block-121925','checkout\\ShippingAddressConfirm','',3),(121927,'116383','deals','block-121925','Html_box','',1),(121928,'116384','deals','block-121924-2','BlockBox','',1),(121929,'116385','deals','block-121928','Html_box','',1),(121930,'116386','deals','block-121928','checkout\\BillingAddressConfirm','',3),(121931,'116387','deals','block-121912','checkout\\ConfirmBtn','',4),(121932,'116388','deals','block-121912','cart\\Products','',7),(121933,'116402','deals','checkout_confirmation_no_shipping','BlockBox','',1),(121934,'116403','deals','block-121933','checkout\\ConfirmBtn','',9),(121935,'116404','deals','block-121933','BlockBox','',2),(121936,'116405','deals','block-121935','BlockBox','',1),(121937,'116406','deals','block-121936','Html_box','',1),(121938,'116407','deals','block-121936','checkout\\BillingAddressConfirm','',3),(121939,'116408','deals','block-121935-2','BlockBox','',1),(121940,'116409','deals','block-121939','Html_box','',1),(121941,'116410','deals','block-121939','checkout\\PaymentMethodConfirm','',3),(121942,'116411','deals','block-121933','checkout\\ConfirmBtn','',4),(121943,'116412','deals','block-121933','checkout\\Totals','',8),(121944,'116413','deals','block-121933','cart\\Products','',7),(121945,'116414','deals','block-121933','Html_box','',5),(121946,'116389','deals','checkout_confirmation_no_shipping_q','BlockBox','',1),(121947,'116390','deals','block-121946','quote\\Products','',4),(121948,'116391','deals','block-121946','checkout\\ConfirmBtn','',2),(121949,'116392','deals','block-121946','checkout\\ConfirmBtn','',6),(121950,'116393','deals','block-121946','BlockBox','',1),(121951,'116394','deals','block-121950','BlockBox','',1),(121952,'116395','deals','block-121951','checkout\\BillingAddressConfirm','',3),(121953,'116396','deals','block-121951','Html_box','',1),(121954,'116397','deals','block-121950-2','BlockBox','',1),(121955,'116398','deals','block-121954','checkout\\PaymentMethodConfirm','',3),(121956,'116399','deals','block-121954','Html_box','',1),(121957,'116400','deals','block-121946','Html_box','',3),(121958,'116401','deals','block-121946','checkout\\Totals','',5),(121959,'116415','deals','checkout_confirmation_q','BlockBox','',1),(121960,'116416','deals','block-121959','BlockBox','',1),(121961,'116417','deals','block-121960','BlockBox','',1),(121962,'116418','deals','block-121961','checkout\\ShippingAddressConfirm','',3),(121963,'116419','deals','block-121961','Html_box','',1),(121964,'116420','deals','block-121960-2','BlockBox','',1),(121965,'116421','deals','block-121964','checkout\\BillingAddressConfirm','',3),(121966,'116422','deals','block-121964','Html_box','',1),(121967,'116423','deals','block-121959','checkout\\Totals','',7),(121968,'116424','deals','block-121959','quote\\Products','',6),(121969,'116425','deals','block-121959','Html_box','',4),(121970,'116426','deals','block-121959','checkout\\EditBtn','',5),(121971,'116427','deals','block-121959','checkout\\ConfirmBtn','',8),(121972,'116428','deals','block-121959','checkout\\ConfirmBtn','',3),(121973,'116429','deals','block-121959','BlockBox','',2),(121974,'116430','deals','block-121973','BlockBox','',1),(121975,'116431','deals','block-121974','Html_box','',1),(121976,'116432','deals','block-121974','checkout\\ShippingConfirm','',3),(121977,'116433','deals','block-121973-2','BlockBox','',1),(121978,'116434','deals','block-121977','Html_box','',1),(121979,'116435','deals','block-121977','checkout\\PaymentMethodConfirm','',3),(121980,'116436','deals','checkout_confirmation_title','Html_box','',1),(121981,'116437','deals','checkout_confirmation_title_g','Html_box','',1),(121982,'116439','deals','checkout_confirmation_title_no_shipping','Html_box','',1),(121983,'116438','deals','checkout_confirmation_title_no_shipping_g','Html_box','',1),(121984,'116440','deals','checkout_confirmation_title_q','Html_box','',1),(121985,'116441','deals','checkout_confirmation_title_s','Html_box','',1),(121986,'116442','deals','checkout_delivery','BlockBox','',2),(121987,'116443','deals','block-121986','BlockBox','',1),(121988,'116444','deals','block-121987','Html_box','',1),(121989,'116445','deals','block-121987','checkout\\ContactInformation','',2),(121990,'116446','deals','block-121986-2','BlockBox','',1),(121991,'116447','deals','block-121990','Html_box','',1),(121992,'116448','deals','block-121990','checkout\\Comments','',2),(121993,'116449','deals','checkout_delivery','BlockBox','',3),(121994,'116450','deals','block-121993','Html_box','',1),(121995,'116451','deals','block-121993-2','checkout\\ContinueBtn','',1),(121996,'116452','deals','checkout_delivery','BlockBox','',1),(121997,'116453','deals','block-121996','BlockBox','',1),(121998,'116455','deals','block-121997','checkout\\ShippingAddress','',2),(121999,'116456','deals','block-121996-2','BlockBox','',1),(122000,'116457','deals','block-121999','DelayedDespatch\\Checkout','',3),(122001,'116458','deals','block-121999','checkout\\Shipping','',2),(122002,'116459','deals','block-121999','Html_box','',1),(122003,'116460','deals','block-121999','Neighbour\\Checkout','',4),(122004,'116461','deals','checkout_delivery_g','BlockBox','',2),(122005,'116462','deals','block-122004','BlockBox','',1),(122006,'116463','deals','block-122005','checkout\\ContactInformation','',2),(122007,'116464','deals','block-122005','Html_box','',1),(122008,'116465','deals','block-122004-2','BlockBox','',1),(122009,'116466','deals','block-122008','Html_box','',1),(122010,'116467','deals','block-122008','checkout\\Comments','',2),(122011,'116468','deals','checkout_delivery_g','BlockBox','',3),(122012,'116469','deals','block-122011','Html_box','',1),(122013,'116470','deals','block-122011-2','checkout\\ContinueBtn','',1),(122014,'116471','deals','checkout_delivery_g','BlockBox','',1),(122015,'116472','deals','block-122014','BlockBox','',1),(122016,'116473','deals','block-122015','checkout\\ShippingAddress','',2),(122017,'116474','deals','block-122015','Html_box','',1),(122018,'116475','deals','block-122014-2','BlockBox','',1),(122019,'116476','deals','block-122018','checkout\\Shipping','',2),(122020,'116477','deals','block-122018','Html_box','',1),(122021,'116478','deals','block-122018','DelayedDespatch\\Checkout','',3),(122022,'116479','deals','block-122018','Neighbour\\Checkout','',4),(122023,'116480','deals','checkout_delivery_no_shipping','BlockBox','',2),(122024,'116481','deals','block-122023','Html_box','',1),(122025,'116482','deals','block-122023-2','checkout\\ContinueBtn','',1),(122026,'116483','deals','checkout_delivery_no_shipping','BlockBox','',1),(122027,'116484','deals','block-122026','BlockBox','',1),(122028,'116485','deals','block-122027','checkout\\ContactInformation','',2),(122029,'116486','deals','block-122026-2','BlockBox','',1),(122030,'116487','deals','block-122029','Html_box','',1),(122031,'116488','deals','block-122029','checkout\\Comments','',2),(122032,'116489','deals','checkout_delivery_no_shipping_g','BlockBox','',2),(122033,'116490','deals','block-122032','Html_box','',1),(122034,'116491','deals','block-122032-2','checkout\\ContinueBtn','',1),(122035,'116492','deals','checkout_delivery_no_shipping_g','BlockBox','',1),(122036,'116493','deals','block-122035','BlockBox','',1),(122037,'116494','deals','block-122036','checkout\\ContactInformation','',2),(122038,'116495','deals','block-122035-2','BlockBox','',1),(122039,'116496','deals','block-122038','checkout\\Comments','',2),(122040,'116497','deals','block-122038','Html_box','',1),(122041,'116498','deals','checkout_delivery_title','Html_box','',1),(122042,'116499','deals','checkout_delivery_title_g','Html_box','',1),(122043,'116501','deals','checkout_delivery_title_no_shipping','Html_box','',1),(122044,'116500','deals','checkout_delivery_title_no_shipping_g','Html_box','',1),(122045,'116502','deals','checkout_delivery_title_q','Html_box','',1),(122046,'116503','deals','checkout_delivery_title_s','Html_box','',1),(122047,'116504','deals','checkout_free_s','BlockBox','',1),(122048,'116505','deals','block-122047','BlockBox','',2),(122049,'116506','deals','block-122048','BlockBox','',2),(122050,'116508','deals','block-122049','BlockBox','',6),(122051,'116509','deals','block-122050','sample\\Products','',1),(122052,'116510','deals','block-122050','checkout\\CreateAccount','',3),(122053,'116511','deals','block-122049','BlockBox','',5),(122054,'116512','deals','block-122053','Html_box','',1),(122055,'116513','deals','block-122053','checkout\\Comments','',2),(122056,'116514','deals','block-122049','BlockBox','',2),(122057,'116515','deals','block-122056','BlockBox','',2),(122058,'116516','deals','block-122057','checkout\\ShippingChoice','',1),(122059,'116517','deals','block-122056','Html_box','',1),(122060,'116518','deals','block-122056','BlockBox','',3),(122061,'116519','deals','block-122060','BlockBox','',1),(122062,'116520','deals','block-122061','checkout\\ContactInformation','',4),(122063,'116521','deals','block-122061','checkout\\ShippingAddress','',2),(122064,'116522','deals','block-122061','Html_box','',3),(122065,'116523','deals','block-122060-2','BlockBox','',1),(122066,'116524','deals','block-122065','DelayedDespatch\\Checkout','',3),(122067,'116525','deals','block-122056','Neighbour\\Checkout','',4),(122068,'116526','deals','block-122048-2','BlockBox','',1),(122069,'116527','deals','block-122068','Html_box','',3),(122070,'116528','deals','block-122068','checkout\\ContinueBtn','',1),(122071,'1638956949','deals','block-122068','checkout\\Terms','',2),(122072,'1638957135','deals','block-122068','Html_box','',0),(122073,'116529','deals','checkout_no_shipping','BlockBox','',1),(122074,'116530','deals','block-122073','BlockBox','',2),(122075,'116531','deals','block-122074','BlockBox','',1),(122076,'116532','deals','block-122075','BlockBox','',6),(122077,'116533','deals','block-122076','checkout\\CreateAccount','',2),(122078,'116534','deals','block-122076','cart\\Products','',1),(122079,'116535','deals','block-122075','BlockBox','',3),(122080,'116536','deals','block-122079','Html_box','',1),(122081,'116537','deals','block-122079','BlockBox','',2),(122082,'116538','deals','block-122081','checkout\\BillingAddress','',2),(122083,'116539','deals','block-122081','Html_box','',1),(122084,'116540','deals','block-122081-2','BlockBox','',1),(122085,'116541','deals','block-122084','Html_box','',1),(122086,'116542','deals','block-122084','checkout\\PaymentMethod','',2),(122087,'116543','deals','block-122075','BlockBox','',4),(122088,'116544','deals','block-122087','BlockBox','',2),(122089,'116545','deals','block-122088','CouponsAndVauchers\\Checkout','',1),(122090,'116546','deals','block-122088-2','checkout\\CreditAmount','',1),(122091,'116547','deals','block-122088-2','checkout\\BonusPoints','',2),(122092,'116548','deals','block-122087','Html_box','',1),(122093,'116549','deals','block-122075','BlockBox','',5),(122094,'116550','deals','block-122093','checkout\\Comments','',2),(122095,'116551','deals','block-122093','Html_box','',1),(122096,'116552','deals','block-122074-2','BlockBox','',1),(122097,'116553','deals','block-122096','Html_box','',1),(122098,'116554','deals','block-122096','Html_box','',5),(122099,'116555','deals','block-122096','checkout\\Totals','',2),(122100,'116556','deals','block-122096','checkout\\ContinueBtn','',3),(122101,'116557','deals','block-122096','checkout\\Terms','',4),(122102,'116558','deals','checkout_no_shipping_g','BlockBox','',1),(122103,'116559','deals','block-122102','checkout\\Totals','',5),(122104,'116560','deals','block-122102','BlockBox','',6),(122105,'116561','deals','block-122104','Html_box','',1),(122106,'116562','deals','block-122104-2','checkout\\ContinueBtn','',1),(122107,'116563','deals','block-122102','BlockBox','',2),(122108,'116564','deals','block-122107','BlockBox','',1),(122109,'116565','deals','block-122108','checkout\\ContactInformation','',2),(122110,'116566','deals','block-122108','Html_box','',1),(122111,'116567','deals','block-122107-2','BlockBox','',1),(122112,'116568','deals','block-122111','checkout\\Comments','',2),(122113,'116569','deals','block-122111','Html_box','',1),(122114,'116570','deals','block-122102','BlockBox','',1),(122115,'116571','deals','block-122114','BlockBox','',1),(122116,'116572','deals','block-122115','Html_box','',1),(122117,'116573','deals','block-122115','checkout\\BillingAddress','',2),(122118,'116574','deals','block-122114-2','BlockBox','',1),(122119,'116575','deals','block-122118','checkout\\BonusPoints','',4),(122120,'116576','deals','block-122118','CouponsAndVauchers\\Checkout','',5),(122121,'116577','deals','block-122118','checkout\\PaymentMethod','',2),(122122,'116578','deals','block-122118','checkout\\CreditAmount','',3),(122123,'116579','deals','block-122118','Html_box','',1),(122124,'116580','deals','block-122102','quote\\Products','',3),(122125,'116581','deals','checkout_no_shipping_q','BlockBox','',1),(122126,'116582','deals','block-122125','BlockBox','',2),(122127,'116583','deals','block-122126','BlockBox','',2),(122128,'116585','deals','block-122127','BlockBox','',5),(122129,'116586','deals','block-122128','checkout\\Comments','',2),(122130,'116587','deals','block-122128','Html_box','',1),(122131,'116588','deals','block-122127','BlockBox','',6),(122132,'116589','deals','block-122131','checkout\\CreateAccount','',3),(122133,'116590','deals','block-122131','quote\\Products','',2),(122134,'116591','deals','block-122127','BlockBox','',3),(122135,'116592','deals','block-122134','Html_box','',1),(122136,'116593','deals','block-122134','BlockBox','',2),(122137,'116594','deals','block-122136','Html_box','',1),(122138,'116595','deals','block-122136','checkout\\BillingAddress','',2),(122139,'116596','deals','block-122136-2','BlockBox','',1),(122140,'116597','deals','block-122139','checkout\\PaymentMethod','',2),(122141,'116598','deals','block-122139','Html_box','',1),(122142,'116599','deals','block-122126-2','BlockBox','',1),(122143,'116600','deals','block-122142','checkout\\ContinueBtn','',3),(122144,'116601','deals','block-122142','Html_box','',5),(122145,'116602','deals','block-122142','Html_box','',1),(122146,'116603','deals','block-122142','checkout\\Totals','',2),(122147,'120984','deals','block-122142','checkout\\Terms','',4),(122148,'116604','deals','checkout_payment','BlockBox','',1),(122149,'116605','deals','block-122148','BlockBox','',1),(122150,'116606','deals','block-122149','checkout\\BillingAddress','',2),(122151,'116607','deals','block-122149','Html_box','',1),(122152,'116608','deals','block-122148-2','BlockBox','',1),(122153,'116609','deals','block-122152','checkout\\CreditAmount','',3),(122154,'116610','deals','block-122152','checkout\\BonusPoints','',4),(122155,'116611','deals','block-122152','CouponsAndVauchers\\Checkout','',5),(122156,'116612','deals','block-122152','checkout\\PaymentMethod','',2),(122157,'116613','deals','block-122152','Html_box','',1),(122158,'116614','deals','checkout_payment','BlockBox','',2),(122159,'116615','deals','block-122158','Html_box','',1),(122160,'116616','deals','block-122158-2','checkout\\ContinueBtn','',1),(122161,'116617','deals','checkout_payment_g','BlockBox','',1),(122162,'116618','deals','block-122161','BlockBox','',1),(122163,'116619','deals','block-122162','checkout\\BillingAddress','',2),(122164,'116620','deals','block-122162','Html_box','',1),(122165,'116621','deals','block-122161-2','BlockBox','',1),(122166,'116622','deals','block-122165','checkout\\CreditAmount','',3),(122167,'116623','deals','block-122165','Html_box','',1),(122168,'116624','deals','block-122165','checkout\\PaymentMethod','',2),(122169,'116625','deals','block-122165','CouponsAndVauchers\\Checkout','',5),(122170,'116626','deals','block-122165','checkout\\BonusPoints','',4),(122171,'116627','deals','checkout_payment_g','BlockBox','',2),(122172,'116628','deals','block-122171','Html_box','',1),(122173,'116629','deals','block-122171-2','checkout\\ContinueBtn','',1),(122174,'116630','deals','checkout_payment_no_shipping','BlockBox','',2),(122175,'116631','deals','block-122174','Html_box','',1),(122176,'116632','deals','block-122174-2','checkout\\ContinueBtn','',1),(122177,'116633','deals','checkout_payment_no_shipping','BlockBox','',1),(122178,'116634','deals','block-122177','BlockBox','',1),(122179,'116635','deals','block-122178','Html_box','',1),(122180,'116636','deals','block-122178','checkout\\BillingAddress','',2),(122181,'116637','deals','block-122177-2','BlockBox','',1),(122182,'116638','deals','block-122181','checkout\\BonusPoints','',4),(122183,'116639','deals','block-122181','CouponsAndVauchers\\Checkout','',5),(122184,'116640','deals','block-122181','checkout\\PaymentMethod','',2),(122185,'116641','deals','block-122181','checkout\\CreditAmount','',3),(122186,'116642','deals','block-122181','Html_box','',1),(122187,'116643','deals','checkout_payment_no_shipping_g','BlockBox','',2),(122188,'116644','deals','block-122187','Html_box','',1),(122189,'116645','deals','block-122187-2','checkout\\ContinueBtn','',1),(122190,'116646','deals','checkout_payment_no_shipping_g','BlockBox','',1),(122191,'116647','deals','block-122190','BlockBox','',1),(122192,'116648','deals','block-122191','checkout\\BillingAddress','',2),(122193,'116649','deals','block-122191','Html_box','',1),(122194,'116650','deals','block-122190-2','BlockBox','',1),(122195,'116651','deals','block-122194','checkout\\BonusPoints','',4),(122196,'116652','deals','block-122194','checkout\\CreditAmount','',3),(122197,'116653','deals','block-122194','checkout\\PaymentMethod','',2),(122198,'116654','deals','block-122194','Html_box','',1),(122199,'116655','deals','block-122194','CouponsAndVauchers\\Checkout','',5),(122200,'116656','deals','checkout_payment_title','Html_box','',1),(122201,'116657','deals','checkout_payment_title_g','Html_box','',1),(122202,'116658','deals','checkout_payment_title_no_shipping','Html_box','',1),(122203,'116659','deals','checkout_payment_title_no_shipping_g','Html_box','',1),(122204,'116660','deals','checkout_payment_title_q','Html_box','',1),(122205,'116661','deals','checkout_payment_title_s','Html_box','',1),(122206,'120947','deals','checkout_q','BlockBox','',1),(122207,'120948','deals','block-122206','BlockBox','',2),(122208,'120949','deals','block-122207','BlockBox','',2),(122209,'120950','deals','block-122208','BlockBox','',6),(122210,'120951','deals','block-122209','checkout\\CreateAccount','',3),(122211,'120952','deals','block-122209','quote\\Products','',2),(122212,'120953','deals','block-122208','BlockBox','',2),(122213,'120954','deals','block-122212','BlockBox','',2),(122214,'120955','deals','block-122213','checkout\\ShippingChoice','',1),(122215,'120956','deals','block-122212','Neighbour\\Checkout','',4),(122216,'120957','deals','block-122212','Html_box','',1),(122217,'120958','deals','block-122212','BlockBox','',3),(122218,'120959','deals','block-122217','BlockBox','',1),(122219,'120960','deals','block-122218','checkout\\ContactInformation','',4),(122220,'120961','deals','block-122218','checkout\\ShippingAddress','',2),(122221,'120962','deals','block-122218','Html_box','',3),(122222,'120963','deals','block-122217-2','BlockBox','',1),(122223,'120964','deals','block-122222','checkout\\Shipping','',2),(122224,'120965','deals','block-122222','Html_box','',1),(122225,'120966','deals','block-122222','DelayedDespatch\\Checkout','',3),(122226,'120967','deals','block-122208','BlockBox','',5),(122227,'120968','deals','block-122226','Html_box','',1),(122228,'120969','deals','block-122226','checkout\\Comments','',2),(122229,'120970','deals','block-122208','BlockBox','',3),(122230,'120971','deals','block-122229','Html_box','',1),(122231,'120972','deals','block-122229','BlockBox','',2),(122232,'120973','deals','block-122231','checkout\\BillingAddress','',2),(122233,'120974','deals','block-122231','Html_box','',1),(122234,'120975','deals','block-122231-2','BlockBox','',1),(122235,'120976','deals','block-122234','checkout\\PaymentMethod','',2),(122236,'120977','deals','block-122234','Html_box','',1),(122237,'120978','deals','block-122207-2','BlockBox','',1),(122238,'120979','deals','block-122237','Html_box','',1),(122239,'120980','deals','block-122237','Html_box','',5),(122240,'120981','deals','block-122237','checkout\\Totals','',2),(122241,'120982','deals','block-122237','checkout\\ContinueBtn','',3),(122242,'120983','deals','block-122237','checkout\\Terms','',4),(122243,'116699','deals','checkout_s','BlockBox','',1),(122244,'116700','deals','block-122243','BlockBox','',2),(122245,'116701','deals','block-122244','BlockBox','',2),(122246,'116703','deals','block-122245','BlockBox','',6),(122247,'116704','deals','block-122246','sample\\Products','',1),(122248,'116705','deals','block-122246','checkout\\CreateAccount','',3),(122249,'116706','deals','block-122245','BlockBox','',2),(122250,'116707','deals','block-122249','Html_box','',1),(122251,'116708','deals','block-122249','Neighbour\\Checkout','',4),(122252,'116709','deals','block-122249','BlockBox','',2),(122253,'116710','deals','block-122252','checkout\\ShippingChoice','',1),(122254,'116711','deals','block-122249','BlockBox','',3),(122255,'116712','deals','block-122254','BlockBox','',1),(122256,'116713','deals','block-122255','checkout\\ShippingAddress','',2),(122257,'116714','deals','block-122255','checkout\\ContactInformation','',4),(122258,'116715','deals','block-122255','Html_box','',3),(122259,'116716','deals','block-122254-2','BlockBox','',1),(122260,'116717','deals','block-122259','checkout\\Shipping','',2),(122261,'116718','deals','block-122259','DelayedDespatch\\Checkout','',3),(122262,'116719','deals','block-122259','Html_box','',1),(122263,'116720','deals','block-122245','BlockBox','',3),(122264,'116721','deals','block-122263','BlockBox','',2),(122265,'116722','deals','block-122264','Html_box','',1),(122266,'116723','deals','block-122264','checkout\\BillingAddress','',2),(122267,'116724','deals','block-122264-2','BlockBox','',1),(122268,'116725','deals','block-122267','Html_box','',1),(122269,'116726','deals','block-122267','checkout\\PaymentMethod','',2),(122270,'116727','deals','block-122263','Html_box','',1),(122271,'116728','deals','block-122245','BlockBox','',5),(122272,'116729','deals','block-122271','Html_box','',1),(122273,'116730','deals','block-122271','checkout\\Comments','',2),(122274,'116731','deals','block-122245','BlockBox','',4),(122275,'116732','deals','block-122274','BlockBox','',2),(122276,'116733','deals','block-122275','CouponsAndVauchers\\Checkout','',1),(122277,'116734','deals','block-122275-2','checkout\\BonusPoints','',2),(122278,'116735','deals','block-122275-2','checkout\\CreditAmount','',1),(122279,'116736','deals','block-122274','Html_box','',1),(122280,'116737','deals','block-122244-2','BlockBox','',1),(122281,'116738','deals','block-122280','checkout\\Totals','',2),(122282,'116739','deals','block-122280','Html_box','',5),(122283,'116740','deals','block-122280','Html_box','',1),(122284,'116741','deals','block-122280','checkout\\ContinueBtn','',3),(122285,'120986','deals','block-122280','checkout\\Terms','',4),(122286,'116742','deals','checkout_step_bottom','Html_box','',1),(122287,'116743','deals','checkout_step_bottom','cart\\Products','',2),(122288,'116744','deals','checkout_step_bottom','checkout\\Totals','',3),(122289,'116745','deals','checkout_step_bottom_g','checkout\\Totals','',3),(122290,'116746','deals','checkout_step_bottom_g','quote\\Products','',2),(122291,'116747','deals','checkout_step_bottom_g','Html_box','',1),(122292,'116749','deals','checkout_step_bottom_no_shipping','Html_box','',1),(122293,'116750','deals','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(122294,'116753','deals','checkout_step_bottom_no_shipping','cart\\Products','',2),(122295,'116748','deals','checkout_step_bottom_no_shipping_g','Html_box','',1),(122296,'116751','deals','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(122297,'116752','deals','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(122298,'116754','deals','communication','BlockBox','',1),(122299,'116755','deals','block-122298','Html_box','',2),(122300,'116756','deals','block-122298','Communication\\NewTopicButton','',1),(122301,'116757','deals','block-122298','Communication\\Topic','',3),(122302,'116758','deals','compare','BlockBox','',1),(122303,'116759','deals','block-122302','catalog\\Compare','',1),(122304,'117665','deals','compareproduct','BlockBox','listing-item',1),(122305,'120921','deals','block-122304','BlockBox','',1),(122306,'120919','deals','block-122305','BlockBox','',1),(122307,'1638872990','deals','block-122306','BlockBox','',2),(122308,'117671','deals','block-122307','productListing\\image','',1),(122309,'117677','deals','block-122307-2','productListing\\compare','',1),(122310,'117675','deals','block-122307-2','productListing\\name','',2),(122311,'117676','deals','block-122307-2','productListing\\stock','',3),(122312,'1638873112','deals','block-122307-2','BlockBox','',4),(122313,'117670','deals','block-122312','productListing\\rating','',2),(122314,'117673','deals','block-122312-2','productListing\\price','',1),(122315,'116760','deals','compare_products','BlockBox','',2),(122316,'116761','deals','block-122315','productListing\\rating','',4),(122317,'116762','deals','block-122315','productListing\\model','',5),(122318,'116763','deals','block-122315','productListing\\compare','',1),(122319,'116764','deals','block-122315','BlockBox','',2),(122320,'116765','deals','block-122319','productListing\\image','',1),(122321,'116766','deals','block-122319-2','productListing\\name','',2),(122322,'116767','deals','block-122315','BlockBox','',3),(122323,'116768','deals','block-122322','productListing\\price','',1),(122324,'116769','deals','block-122322-2','productListing\\buyButton','',1),(122325,'116770','deals','confirmation','BlockBox','',1),(122326,'116771','deals','block-122325','BlockBox','',2),(122327,'116772','deals','block-122326','BlockBox','',4),(122328,'116773','deals','block-122327','BlockBox','',4),(122329,'116774','deals','block-122328','checkout\\EditBtn','',2),(122330,'116775','deals','block-122328','cart\\Products','',3),(122331,'116776','deals','block-122328','Html_box','',1),(122332,'116777','deals','block-122327','BlockBox','',3),(122333,'116778','deals','block-122332','checkout\\EditBtn','',2),(122334,'116779','deals','block-122332','Html_box','',1),(122335,'116780','deals','block-122332','checkout\\CommentsConfirm','',3),(122336,'116782','deals','block-122326','BlockBox','',2),(122337,'116789','deals','block-122336','Html_box','',1),(122338,'1643301641','deals','block-122336','BlockBox','',2),(122339,'116785','deals','block-122338','Html_box','',4),(122340,'116786','deals','block-122338','checkout\\EditBtn','',5),(122341,'116790','deals','block-122338','checkout\\EditBtn','',2),(122342,'116791','deals','block-122338','checkout\\ContactConfirm','',6),(122343,'116792','deals','block-122338','Html_box','',1),(122344,'116793','deals','block-122338','checkout\\ShippingAddressConfirm','',3),(122345,'116783','deals','block-122338-2','checkout\\EditBtn','',2),(122346,'116784','deals','block-122338-2','DelayedDespatch\\CheckoutConfirm','',4),(122347,'116787','deals','block-122338-2','Html_box','',1),(122348,'116788','deals','block-122338-2','checkout\\ShippingConfirm','',3),(122349,'116794','deals','block-122326','BlockBox','',3),(122350,'116799','deals','block-122349','Html_box','',1),(122351,'1643301813','deals','block-122349','BlockBox','',3),(122352,'116796','deals','block-122351','checkout\\EditBtn','',2),(122353,'116800','deals','block-122351','checkout\\BillingAddressConfirm','',3),(122354,'116801','deals','block-122351','Html_box','',1),(122355,'116795','deals','block-122351-2','checkout\\EditBtn','',2),(122356,'116797','deals','block-122351-2','checkout\\PaymentMethodConfirm','',3),(122357,'116798','deals','block-122351-2','Html_box','',1),(122358,'116802','deals','block-122326','UploadCustomerId\\UploadCustomerIdForm','',1),(122359,'116803','deals','block-122326-2','BlockBox','',1),(122360,'116804','deals','block-122359','Html_box','',1),(122361,'116805','deals','block-122359','checkout\\ConfirmBtn','',3),(122362,'116806','deals','block-122359','checkout\\Totals','',2),(122363,'116807','deals','block-122325','Html_box','',1),(122364,'116808','deals','confirmation_free_s','BlockBox','',1),(122365,'116809','deals','block-122364','BlockBox','',2),(122366,'116810','deals','block-122365','BlockBox','',1),(122367,'116811','deals','block-122366','BlockBox','',2),(122368,'116812','deals','block-122367','checkout\\CommentsConfirm','',3),(122369,'116813','deals','block-122367','checkout\\EditBtn','',2),(122370,'116814','deals','block-122367','Html_box','',1),(122371,'116815','deals','block-122366','BlockBox','',3),(122372,'116816','deals','block-122371','checkout\\EditBtn','',3),(122373,'116817','deals','block-122371','Html_box','',1),(122374,'116818','deals','block-122371','sample\\Products','',2),(122375,'116819','deals','block-122366','BlockBox','',1),(122376,'116820','deals','block-122375','BlockBox','',1),(122377,'116821','deals','block-122376','checkout\\EditBtn','',3),(122378,'116822','deals','block-122376','checkout\\ShippingConfirm','',7),(122379,'116823','deals','block-122376','Html_box','',5),(122380,'116824','deals','block-122376','checkout\\EditBtn','',6),(122381,'116825','deals','block-122376','Html_box','',2),(122382,'116826','deals','block-122376','checkout\\ShippingAddressConfirm','',4),(122383,'116827','deals','block-122375-2','BlockBox','',1),(122384,'116828','deals','block-122383','checkout\\ContactConfirm','',3),(122385,'116829','deals','block-122383','DelayedDespatch\\CheckoutConfirm','',4),(122386,'116830','deals','block-122383','checkout\\EditBtn','',2),(122387,'116831','deals','block-122383','Html_box','',1),(122388,'116832','deals','block-122365-2','BlockBox','',1),(122389,'116833','deals','block-122388','checkout\\ConfirmBtn','',3),(122390,'116834','deals','block-122364','Html_box','',1),(122391,'116835','deals','confirmation_no_shipping','BlockBox','',1),(122392,'116836','deals','block-122391','Html_box','',1),(122393,'116837','deals','block-122391','BlockBox','',2),(122394,'116838','deals','block-122393','BlockBox','',1),(122395,'116839','deals','block-122394','BlockBox','',1),(122396,'116840','deals','block-122395','BlockBox','',1),(122397,'116841','deals','block-122396','checkout\\EditBtn','',10),(122398,'116842','deals','block-122396','Html_box','',9),(122399,'116843','deals','block-122396','checkout\\ContactConfirm','',11),(122400,'116844','deals','block-122395-2','BlockBox','',1),(122401,'116845','deals','block-122400','checkout\\PaymentMethodConfirm','',7),(122402,'116846','deals','block-122400','checkout\\EditBtn','',6),(122403,'116847','deals','block-122400','Html_box','',5),(122404,'116848','deals','block-122400','Html_box','',1),(122405,'116849','deals','block-122400','checkout\\EditBtn','',3),(122406,'116850','deals','block-122400','checkout\\BillingAddressConfirm','',4),(122407,'116851','deals','block-122400','Html_box','',2),(122408,'116852','deals','block-122394','BlockBox','',2),(122409,'116853','deals','block-122408','Html_box','',1),(122410,'116854','deals','block-122408','checkout\\CommentsConfirm','',3),(122411,'116855','deals','block-122408','checkout\\EditBtn','',2),(122412,'116856','deals','block-122394','BlockBox','',3),(122413,'116857','deals','block-122412','Html_box','',1),(122414,'116858','deals','block-122412','checkout\\EditBtn','',2),(122415,'116859','deals','block-122412','cart\\Products','',3),(122416,'116860','deals','block-122393-2','BlockBox','',1),(122417,'116861','deals','block-122416','checkout\\ConfirmBtn','',3),(122418,'116862','deals','block-122416','Html_box','',1),(122419,'116863','deals','block-122416','checkout\\Totals','',2),(122420,'116864','deals','confirmation_no_shipping_q','BlockBox','',2),(122421,'116865','deals','block-122420','Html_box','',1),(122422,'116866','deals','block-122420','BlockBox','',2),(122423,'116867','deals','block-122422','BlockBox','',1),(122424,'116868','deals','block-122423','BlockBox','',2),(122425,'116869','deals','block-122424','Html_box','',1),(122426,'116870','deals','block-122424','checkout\\CommentsConfirm','',3),(122427,'116871','deals','block-122424','checkout\\EditBtn','',2),(122428,'116872','deals','block-122423','BlockBox','',1),(122429,'116873','deals','block-122428','BlockBox','',1),(122430,'116874','deals','block-122429','checkout\\EditBtn','',5),(122431,'116875','deals','block-122429','checkout\\ContactConfirm','',6),(122432,'116876','deals','block-122429','checkout\\PaymentMethodConfirm','',3),(122433,'116877','deals','block-122429','checkout\\EditBtn','',2),(122434,'116878','deals','block-122429','Html_box','',4),(122435,'116879','deals','block-122429','Html_box','',1),(122436,'116880','deals','block-122428-2','BlockBox','',1),(122437,'116881','deals','block-122436','checkout\\BillingAddressConfirm','',4),(122438,'116882','deals','block-122436','checkout\\EditBtn','',3),(122439,'116883','deals','block-122436','Html_box','',2),(122440,'116884','deals','block-122423','BlockBox','',3),(122441,'116885','deals','block-122440','checkout\\EditBtn','',2),(122442,'116886','deals','block-122440','Html_box','',1),(122443,'116887','deals','block-122440','quote\\Products','',3),(122444,'116888','deals','block-122422-2','BlockBox','',1),(122445,'116889','deals','block-122444','checkout\\ConfirmBtn','',3),(122446,'116890','deals','block-122444','checkout\\Totals','',2),(122447,'116891','deals','block-122444','Html_box','',1),(122448,'116892','deals','confirmation_q','BlockBox','',1),(122449,'116893','deals','block-122448','Html_box','',1),(122450,'116894','deals','block-122448','BlockBox','',2),(122451,'116895','deals','block-122450','BlockBox','',1),(122452,'116896','deals','block-122451','BlockBox','',3),(122453,'116897','deals','block-122452','quote\\Products','',3),(122454,'116898','deals','block-122452','Html_box','',1),(122455,'116899','deals','block-122452','checkout\\EditBtn','',2),(122456,'116900','deals','block-122451','BlockBox','',1),(122457,'116901','deals','block-122456','BlockBox','',1),(122458,'116902','deals','block-122457','Html_box','',1),(122459,'116903','deals','block-122457','checkout\\EditBtn','',10),(122460,'116904','deals','block-122457','Html_box','',2),(122461,'116905','deals','block-122457','checkout\\ContactConfirm','',11),(122462,'116906','deals','block-122457','checkout\\ShippingAddressConfirm','',4),(122463,'116907','deals','block-122457','checkout\\ShippingConfirm','',7),(122464,'116908','deals','block-122457','checkout\\EditBtn','',3),(122465,'116909','deals','block-122457','DelayedDespatch\\CheckoutConfirm','',8),(122466,'116910','deals','block-122457','Html_box','',9),(122467,'116911','deals','block-122457','Html_box','',5),(122468,'116912','deals','block-122457','checkout\\EditBtn','',6),(122469,'116913','deals','block-122456-2','BlockBox','',1),(122470,'116914','deals','block-122469','checkout\\EditBtn','',3),(122471,'116915','deals','block-122469','checkout\\BillingAddressConfirm','',4),(122472,'116916','deals','block-122469','checkout\\PaymentMethodConfirm','',7),(122473,'116917','deals','block-122469','Html_box','',1),(122474,'116918','deals','block-122469','Html_box','',2),(122475,'116919','deals','block-122469','checkout\\EditBtn','',6),(122476,'116920','deals','block-122469','Html_box','',5),(122477,'116921','deals','block-122451','BlockBox','',2),(122478,'116922','deals','block-122477','checkout\\CommentsConfirm','',3),(122479,'116923','deals','block-122477','Html_box','',1),(122480,'116924','deals','block-122477','checkout\\EditBtn','',2),(122481,'116925','deals','block-122450-2','BlockBox','',1),(122482,'116926','deals','block-122481','Html_box','',1),(122483,'116927','deals','block-122481','checkout\\Totals','',2),(122484,'116928','deals','block-122481','checkout\\ConfirmBtn','',3),(122485,'116929','deals','confirmation_s','BlockBox','',1),(122486,'116930','deals','block-122485','BlockBox','',2),(122487,'116931','deals','block-122486','BlockBox','',1),(122488,'116932','deals','block-122487','BlockBox','',1),(122489,'116933','deals','block-122488','BlockBox','',1),(122490,'116934','deals','block-122489','checkout\\ShippingAddressConfirm','',4),(122491,'116935','deals','block-122489','checkout\\EditBtn','',3),(122492,'116936','deals','block-122489','Html_box','',2),(122493,'116937','deals','block-122489','DelayedDespatch\\CheckoutConfirm','',8),(122494,'116938','deals','block-122489','checkout\\ShippingConfirm','',7),(122495,'116939','deals','block-122489','Html_box','',1),(122496,'116940','deals','block-122489','Html_box','',5),(122497,'116941','deals','block-122489','Html_box','',9),(122498,'116942','deals','block-122489','checkout\\ContactConfirm','',11),(122499,'116943','deals','block-122489','checkout\\EditBtn','',6),(122500,'116944','deals','block-122489','checkout\\EditBtn','',10),(122501,'116945','deals','block-122488-2','BlockBox','',1),(122502,'116946','deals','block-122501','Html_box','',2),(122503,'116947','deals','block-122501','checkout\\BillingAddressConfirm','',4),(122504,'116948','deals','block-122501','checkout\\EditBtn','',3),(122505,'116949','deals','block-122501','checkout\\PaymentMethodConfirm','',7),(122506,'116950','deals','block-122501','checkout\\EditBtn','',6),(122507,'116951','deals','block-122501','Html_box','',1),(122508,'116952','deals','block-122501','Html_box','',5),(122509,'116953','deals','block-122487','BlockBox','',3),(122510,'116954','deals','block-122509','checkout\\EditBtn','',3),(122511,'116955','deals','block-122509','Html_box','',1),(122512,'116956','deals','block-122509','sample\\Products','',2),(122513,'116957','deals','block-122487','BlockBox','',2),(122514,'116958','deals','block-122513','Html_box','',1),(122515,'116959','deals','block-122513','checkout\\EditBtn','',2),(122516,'116960','deals','block-122513','checkout\\CommentsConfirm','',3),(122517,'116961','deals','block-122486-2','BlockBox','',1),(122518,'116962','deals','block-122517','checkout\\Totals','',2),(122519,'116963','deals','block-122517','checkout\\ConfirmBtn','',3),(122520,'116964','deals','block-122517','Html_box','',1),(122521,'116965','deals','block-122485','Html_box','',1),(122522,'116966','deals','contact','BlockBox','info-content',1),(122523,'116967','deals','block-122522','info\\Title','',1),(122524,'116968','deals','block-122522','BlockBox','',2),(122525,'116969','deals','block-122524','contact\\ContactForm','',1),(122526,'116970','deals','block-122524-2','contact\\Contacts','',1),(122527,'116971','deals','created_success','BlockBox','',1),(122528,'116972','deals','block-122527','Html_box','',1),(122529,'116973','deals','block-122527','Html_box','',2),(122530,'116102.000001','deals','credit_amount_history','BlockBox','',1),(122531,'116103.000001','deals','block-122530','BlockBox','',1),(122532,'116104.000001','deals','block-122531','WidgetsAria','',1),(122552,'116109.000001','deals','block-122531-2','Html_box','',1),(122553,'1638895944','deals','block-122531-2','account\\CreditAmountHistory','',2),(122554,'116974','deals','credit_note','invoice\\Container','',1),(122555,'116975','deals','block-122554','BlockBox','',5),(122556,'116976','deals','block-122555','invoice\\StoreAddress','',8),(122557,'116977','deals','block-122555','Text','',1),(122558,'116978','deals','block-122555-2','Text','',2),(122559,'116979','deals','block-122555-2','Logo','',1),(122560,'116980','deals','block-122555-3','Text','',1),(122561,'116981','deals','block-122555-3','BlockBox','',3),(122562,'116982','deals','block-122561','Text','',1),(122563,'116983','deals','block-122561-2','invoice\\StoreEmail','',1),(122564,'116984','deals','block-122555-3','BlockBox','',2),(122565,'116985','deals','block-122564','Text','',1),(122566,'116986','deals','block-122564-2','invoice\\StorePhone','',1),(122567,'116987','deals','block-122554','invoice\\Products','',3),(122568,'116988','deals','block-122554','BlockBox','',1),(122569,'116989','deals','block-122568','Logo','',1),(122570,'116990','deals','block-122568-2','BlockBox','',4),(122571,'116991','deals','block-122570','Text','',1),(122572,'116992','deals','block-122570-2','invoice\\StoreSite','',1),(122573,'116993','deals','block-122568-2','BlockBox','',2),(122574,'116994','deals','block-122573','Text','',1),(122575,'116995','deals','block-122573-2','invoice\\StorePhone','',1),(122576,'116996','deals','block-122568-2','BlockBox','',3),(122577,'116997','deals','block-122576','Text','',1),(122578,'116998','deals','block-122576-2','invoice\\StoreEmail','',1),(122579,'116999','deals','block-122568-2','BlockBox','',1),(122580,'117000','deals','block-122579','invoice\\StoreAddress','',1),(122581,'117001','deals','block-122554','BlockBox','',4),(122582,'117002','deals','block-122581','BlockBox','',1),(122583,'117003','deals','block-122582','invoice\\ShippingAddress','',2),(122584,'117004','deals','block-122582','Text','',1),(122585,'117005','deals','block-122581-2','BlockBox','',1),(122586,'117006','deals','block-122554','BlockBox','',2),(122587,'117007','deals','block-122586','BlockBox','',7),(122588,'117008','deals','block-122587','BlockBox','',1),(122589,'117009','deals','block-122588','Text','',1),(122590,'117010','deals','block-122588','invoice\\BillingAddress','',2),(122591,'117011','deals','block-122587-2','BlockBox','',1),(122592,'117012','deals','block-122591','invoice\\CustomerPhone','',4),(122593,'117013','deals','block-122591','Text','',1),(122594,'117014','deals','block-122591','Text','',3),(122595,'117015','deals','block-122591','invoice\\CustomerName','',2),(122596,'117016','deals','block-122591','invoice\\CustomerEmail','',6),(122597,'117017','deals','block-122591','Text','',5),(122598,'117018','deals','block-122586','BlockBox','',8),(122599,'117019','deals','block-122598','BlockBox','',1),(122600,'117020','deals','block-122599','invoice\\ShippingMethod','',2),(122601,'117021','deals','block-122599','Text','',1),(122602,'117022','deals','block-122598-2','BlockBox','',1),(122603,'117023','deals','block-122602','Text','',1),(122604,'117024','deals','block-122602','invoice\\ShippingMethod','',2),(122605,'117025','deals','block-122586-2','invoice\\OrderId','',1),(122606,'117026','deals','block-122586-2','Text','',2),(122607,'117027','deals','block-122586-2','invoice\\PaymentDate','',3),(122608,'117034','deals','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(122609,'1639155816','deals','delivery-location','BlockBox','',2),(122610,'117028','deals','block-122609','DeliveryLocation\\FeaturedList','',6),(122611,'117029','deals','block-122609','DeliveryLocation\\LocationLongDescription','',3),(122612,'117030','deals','block-122609','DeliveryLocation\\LocationList','',4),(122613,'117031','deals','block-122609','DeliveryLocation\\LocationTitle','',1),(122614,'117032','deals','block-122609','DeliveryLocation\\LocationProducts','',7),(122615,'117033','deals','block-122609','DeliveryLocation\\LocationDescription','',2),(122616,'1639485067','deals','block-122609','DeliveryLocation\\CrossPages','',0),(122617,'1639485089','deals','block-122609','DeliveryLocation\\ProductCategories','',0),(122618,'1639154415','deals','delivery-location-default','BlockBox','',2),(122619,'117035','deals','block-122618','DeliveryLocation\\TopLocationList','',2),(122620,'117036','deals','block-122618','Heading','',1),(122621,'1639419797','deals','block-122618','DeliveryLocation\\ListByPage','',3),(122622,'117037','deals','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(122623,'117038','deals','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(122624,'117039','deals','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(122625,'117040','deals','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(122626,'117041','deals','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(122627,'117042','deals','delivery_loc_2','DeliveryLocation\\LocationList','',7),(122628,'117043','deals','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(122629,'117044','deals','email','email\\BlockBox','',1),(122630,'117045','deals','block-122629','email\\BlockBox','',1),(122631,'117046','deals','block-122630','Copyright','',4),(122632,'117047','deals','block-122630','email\\Content','',3),(122633,'117048','deals','block-122630','email\\BlockBox','',2),(122634,'117049','deals','block-122633','email\\Title','',1),(122635,'117050','deals','block-122633-2','email\\Date','',1),(122636,'117051','deals','block-122630','Logo','',1),(122637,'117052','deals','email_2','email\\BlockBox','',1),(122638,'117053','deals','block-122637','email\\BlockBox','',1),(122639,'117054','deals','block-122638','Copyright','',4),(122640,'117055','deals','block-122638','Logo','',1),(122641,'117056','deals','block-122638','email\\Content','',3),(122642,'117057','deals','block-122638','email\\BlockBox','',2),(122643,'117058','deals','block-122642','email\\Title','',1),(122644,'117059','deals','block-122642-2','email\\Date','',1),(122645,'117060','deals','email_3','email\\BlockBox','',1),(122646,'117061','deals','block-122645','email\\BlockBox','',1),(122647,'117062','deals','block-122646','email\\BlockBox','',2),(122648,'117063','deals','block-122647','email\\Content','',2),(122649,'117064','deals','block-122647','email\\BlockBox','',1),(122650,'117065','deals','block-122649','email\\Title','',1),(122651,'117066','deals','block-122649-2','email\\Date','',1),(122652,'117067','deals','block-122646','Copyright','',3),(122653,'117068','deals','block-122646','Logo','',1),(122654,'117069','deals','email_4','email\\BlockBox','',1),(122655,'117070','deals','block-122654','email\\BlockBox','',1),(122656,'117071','deals','block-122655','Copyright','',2),(122657,'117072','deals','block-122655','email\\BlockBox','',1),(122658,'117073','deals','block-122657','email\\BlockBox','',1),(122659,'117074','deals','block-122658','Logo','',1),(122660,'117075','deals','block-122658-2','email\\Date','',2),(122661,'117076','deals','block-122658-2','email\\Title','',1),(122662,'117077','deals','block-122657','email\\Content','',2),(122663,'121029','deals','filescatalog_category','BlockBox','',1),(122664,'121030','deals','block-122663','FilesCatalog\\widgets\\FilesList','',3),(122665,'121031','deals','block-122663','FilesCatalog\\widgets\\Title','',1),(122666,'121032','deals','block-122663','FilesCatalog\\widgets\\Description','',2),(122667,'121025','deals','filescatalog_index','BlockBox','',1),(122668,'121026','deals','block-122667','Html_box','',1),(122669,'121027','deals','block-122667','FilesCatalog\\widgets\\FilesCatalog','',2),(122670,'117078','deals','footer','BlockBox','footer-content',1),(122671,'120872','deals','block-122670','Banner','',2),(122672,'117094','deals','block-122670','Copyright','',3),(122673,'1641484988','deals','block-122670','BlockBox','footer-content',1),(122674,'117085','deals','block-122673','Menu','Footer',1),(122675,'117091','deals','block-122673-2','Contacts','',1),(122676,'120868','deals','block-122673-2','Logo','',2),(122677,'117096','deals','for_menu','BlockBox','',1),(122678,'117097','deals','block-122677','Html_box','',1),(122679,'117098','deals','block-122677-2','Languages','',1),(122680,'117099','deals','for_menu','BlockBox','',3),(122681,'117100','deals','block-122680','Html_box','',1),(122682,'117101','deals','block-122680-2','Currencies','',1),(122683,'117102','deals','gift','BlockBox','',1),(122684,'117103','deals','block-122683','BlockBox','',3),(122685,'117104','deals','block-122684','BlockBox','',1),(122686,'117105','deals','block-122685','gift\\Card','',1),(122687,'117106','deals','block-122684-2','gift\\Form','',2),(122688,'117107','deals','block-122684-2','Text','',1),(122689,'117108','deals','block-122683','info\\Title','',1),(122690,'117109','deals','gift_card','BlockBox','',1),(122691,'117110','deals','block-122690','BlockBox','',11),(122692,'117111','deals','block-122691','invoice\\StoreEmail','',3),(122693,'117112','deals','block-122691','Text','',1),(122694,'117113','deals','block-122691','invoice\\StorePhone','',2),(122695,'117114','deals','block-122690','Text','',8),(122696,'117115','deals','block-122690','Text','',3),(122697,'117116','deals','block-122690','BlockBox','',10),(122698,'117117','deals','block-122697','Text','',1),(122699,'117118','deals','block-122697-2','gift\\CodeView','',1),(122700,'117119','deals','block-122690','gift\\MessageView','',7),(122701,'117120','deals','block-122690','gift\\AmountView','',5),(122702,'117121','deals','block-122690','Text','',6),(122703,'117123','deals','block-122690','Logo','',1),(122704,'117124','deals','block-122690','Text','',4),(122705,'117125','deals','block-122690','Text','',9),(122706,'117126','deals','gift_card_2','BlockBox','',1),(122707,'117127','deals','block-122706','gift\\AmountView','',4),(122708,'117128','deals','block-122706','BlockBox','',9),(122709,'117129','deals','block-122708','Text','',1),(122710,'117130','deals','block-122708-2','gift\\CodeView','',1),(122711,'117131','deals','block-122706','BlockBox','',10),(122712,'117132','deals','block-122711','invoice\\StoreEmail','',3),(122713,'117133','deals','block-122711','Text','',1),(122714,'117134','deals','block-122711','invoice\\StorePhone','',2),(122715,'117135','deals','block-122706','gift\\MessageView','',6),(122716,'117136','deals','block-122706','Text','',5),(122717,'117137','deals','block-122706','Text','',8),(122718,'117138','deals','block-122706','Text','',3),(122719,'117139','deals','block-122706','Text','',7),(122720,'1638804282','deals','block-122706','Logo','',1),(122721,'117141','deals','gift_card_2_pdf','BlockBox','',1),(122722,'117142','deals','block-122721','BlockBox','',12),(122723,'117143','deals','block-122722','invoice\\StoreEmail','',4),(122724,'117144','deals','block-122722','invoice\\StorePhone','',3),(122725,'117145','deals','block-122722','Html_box','',1),(122726,'117146','deals','block-122721','BlockBox','',11),(122727,'117147','deals','block-122726','Html_box','',1),(122728,'117148','deals','block-122726-2','gift\\CodeViewPdf','',1),(122729,'117149','deals','block-122721','BlockBox','',1),(122730,'117150','deals','block-122729','Text','',4),(122731,'117151','deals','block-122729','Html_box','',1),(122732,'117152','deals','block-122729','Html_box','',2),(122733,'117153','deals','block-122729','gift\\AmountViewPdf','',3),(122734,'117154','deals','block-122729','gift\\MessageViewPdf','',5),(122735,'117155','deals','block-122729','Html_box','',7),(122736,'117156','deals','block-122729','Html_box','',6),(122737,'117158','deals','gift_card_pdf','BlockBox','',1),(122738,'117159','deals','block-122737','BlockBox','',12),(122739,'117160','deals','block-122738','invoice\\StoreEmail','',4),(122740,'117161','deals','block-122738','invoice\\StorePhone','',3),(122741,'117162','deals','block-122738','Html_box','',1),(122742,'117163','deals','block-122737','BlockBox','',11),(122743,'117164','deals','block-122742','Html_box','',1),(122744,'117165','deals','block-122742-2','gift\\CodeViewPdf','',1),(122745,'117166','deals','block-122737','BlockBox','',1),(122746,'117167','deals','block-122745','Text','',5),(122747,'117169','deals','block-122745','Html_box','',3),(122748,'117170','deals','block-122745','gift\\AmountViewPdf','',4),(122749,'117171','deals','block-122745','gift\\MessageViewPdf','',6),(122750,'117172','deals','block-122745','Html_box','',8),(122751,'117173','deals','block-122745','Html_box','',7),(122752,'1638978695','deals','block-122745','Logo','',2),(122753,'117175','deals','gift_certificate','BlockBox','',1),(122754,'117176','deals','block-122753','account\\ApplyCertificate','',2),(122755,'117177','deals','block-122753','Html_box','',1),(122756,'117178','deals','gigt_card_3','BlockBox','',1),(122757,'117179','deals','block-122756','BlockBox','',9),(122758,'117180','deals','block-122757','Text','',1),(122759,'117181','deals','block-122757-2','gift\\CodeView','',1),(122760,'117182','deals','block-122756','Text','',7),(122761,'117184','deals','block-122756','BlockBox','',10),(122762,'117185','deals','block-122761','Text','',1),(122763,'117186','deals','block-122761','invoice\\StoreEmail','',3),(122764,'117187','deals','block-122761','invoice\\StorePhone','',2),(122765,'117188','deals','block-122756','gift\\MessageView','',6),(122766,'117189','deals','block-122756','Text','',3),(122767,'117190','deals','block-122756','Text','',5),(122768,'117191','deals','block-122756','gift\\AmountView','',4),(122769,'117192','deals','block-122756','Text','',8),(122770,'1638804328','deals','block-122756','Logo','',1),(122771,'117193','deals','gigt_card_3_pdf','BlockBox','',1),(122772,'117194','deals','block-122771','BlockBox','',12),(122773,'117195','deals','block-122772','invoice\\StoreEmail','',4),(122774,'117196','deals','block-122772','invoice\\StorePhone','',3),(122775,'117197','deals','block-122772','Html_box','',1),(122776,'117198','deals','block-122771','BlockBox','',11),(122777,'117199','deals','block-122776','Html_box','',1),(122778,'117200','deals','block-122776-2','gift\\CodeViewPdf','',1),(122779,'117201','deals','block-122771','BlockBox','',1),(122780,'117202','deals','block-122779','Text','',4),(122781,'117203','deals','block-122779','Html_box','',1),(122782,'117204','deals','block-122779','Html_box','',2),(122783,'117205','deals','block-122779','gift\\AmountViewPdf','',3),(122784,'117206','deals','block-122779','gift\\MessageViewPdf','',5),(122785,'117207','deals','block-122779','Html_box','',7),(122786,'117208','deals','block-122779','Html_box','',6),(122800,'117224.000001','deals','info','BlockBox','info-content',1),(122801,'117225.000001','deals','block-122800','info\\DescriptionShort','',3),(122802,'117226','deals','block-122800','info\\Content','',6),(122803,'117227.000001','deals','block-122800','info\\Title','',1),(122804,'117228.000001','deals','block-122800','info\\Image','',4),(122805,'1638467467.0001','deals','block-122800','info\\DescriptionShort','',5),(122806,'117229','deals','invoice','invoice\\Container','',1),(122807,'117230','deals','block-122806','BlockBox','',4),(122808,'117231','deals','block-122807','BlockBox','',8),(122809,'117232','deals','block-122808','BlockBox','',1),(122810,'117233','deals','block-122809','invoice\\ShippingMethod','',2),(122811,'117234','deals','block-122809','Text','',1),(122812,'117235','deals','block-122808-2','BlockBox','',1),(122813,'117236','deals','block-122812','Text','',1),(122814,'117237','deals','block-122812','invoice\\ShippingMethod','',2),(122815,'117238','deals','block-122807','BlockBox','',7),(122816,'117239','deals','block-122815','BlockBox','',2),(122817,'117240','deals','block-122816','Text','',1),(122818,'117241','deals','block-122816','invoice\\BillingAddress','',2),(122819,'1639659760','deals','block-122816','GiftWrapMessage\\ShowInfo','',3),(122820,'117242','deals','block-122815-2','BlockBox','',1),(122821,'117243','deals','block-122820','Text','',5),(122822,'117244','deals','block-122820','invoice\\CustomerName','',2),(122823,'117245','deals','block-122820','invoice\\CustomerPhone','',4),(122824,'117246','deals','block-122820','Text','',1),(122825,'117247','deals','block-122820','Text','',3),(122826,'117248','deals','block-122820','invoice\\CustomerEmail','',6),(122827,'117249','deals','block-122807-2','invoice\\PaymentMethod','',6),(122828,'117250','deals','block-122807-2','Text','',5),(122829,'117251','deals','block-122807-2','Text','',3),(122830,'117252','deals','block-122807-2','invoice\\OrderId','',2),(122831,'117253','deals','block-122807-2','invoice\\PaymentDate','',4),(122832,'117254','deals','block-122807-2','invoice\\OrderBarcode','',7),(122833,'117255','deals','block-122806','BlockBox','',8),(122834,'117256','deals','block-122833','invoice\\StoreAddress','',8),(122835,'117257','deals','block-122833','Text','',1),(122836,'117258','deals','block-122833-2','Text','',2),(122837,'117260','deals','block-122833-3','BlockBox','',3),(122838,'117261','deals','block-122837','Text','',1),(122839,'117262','deals','block-122837-2','invoice\\StoreEmail','',1),(122840,'117263','deals','block-122833-3','BlockBox','',2),(122841,'117264','deals','block-122840','Text','',1),(122842,'117265','deals','block-122840-2','invoice\\StorePhone','',1),(122843,'117266','deals','block-122833-3','Text','',1),(122844,'117267','deals','block-122806','invoice\\Products','',5),(122845,'117268','deals','block-122806','BlockBox','',7),(122846,'117269','deals','block-122845','BlockBox','',1),(122847,'117270','deals','block-122846','invoice\\ShippingAddress','',2),(122848,'117271','deals','block-122846','Text','',1),(122849,'117272','deals','block-122845-2','BlockBox','',1),(122850,'117273','deals','block-122849','invoice\\Totals','',1),(122851,'117274','deals','block-122806','BlockBox','',2),(122852,'117275','deals','block-122851','Logo','',1),(122853,'117276','deals','block-122851-2','BlockBox','',4),(122854,'117277','deals','block-122853','Text','',1),(122855,'117278','deals','block-122853-2','invoice\\StoreSite','',1),(122856,'117279','deals','block-122851-2','BlockBox','',3),(122857,'117280','deals','block-122856','Text','',1),(122858,'117281','deals','block-122856-2','invoice\\StoreEmail','',1),(122859,'117282','deals','block-122851-2','BlockBox','',1),(122860,'117283','deals','block-122859','invoice\\StoreAddress','',2),(122861,'117284','deals','block-122851-2','BlockBox','',2),(122862,'117285','deals','block-122861','Text','',1),(122863,'117286','deals','block-122861-2','invoice\\StorePhone','',1),(122864,'1640103567','deals','block-122806','invoice\\StructuredProducts','',6),(122865,'117287','deals','login_account','BlockBox','',1),(122866,'117288','deals','block-122865','Tabs','',2),(122867,'117289','deals','block-122866-1','login\\Returning','',1),(122868,'117292','deals','block-122866-2','BlockBox','',2),(122869,'117293','deals','block-122868','Html_box','',2),(122870,'117294','deals','block-122868','login\\Register','',1),(122871,'117295','deals','block-122865','BlockBox','',1),(122872,'117296','deals','block-122871','Html_box','',5),(122873,'117297','deals','block-122871','Html_box','',1),(122874,'117298','deals','block-122871','login\\Socials','',4),(122875,'117299','deals','login_checkout','BlockBox','',1),(122876,'117300','deals','block-122875','BlockBox','',1),(122877,'117301','deals','block-122876','checkout\\CreateBtn','',4),(122878,'117302','deals','block-122876','checkout\\GuestBtn','',2),(122879,'117303','deals','block-122876','Html_box','',3),(122880,'117304','deals','block-122876','BlockBox','',5),(122881,'117305','deals','block-122880','Html_box','',1),(122882,'117306','deals','block-122880','login\\Socials','',2),(122883,'117307','deals','block-122876','Html_box','',1),(122884,'117308','deals','block-122876-2','login\\Returning','',2),(122885,'117309','deals','block-122876-2','Html_box','',1),(122886,'117310','deals','login_checkout2','BlockBox','',1),(122887,'117311','deals','block-122886','Tabs','',4),(122888,'117312','deals','block-122887-1','BlockBox','',1),(122889,'117313','deals','block-122888','Html_box','',1),(122890,'117314','deals','block-122888-2','BlockBox','',1),(122891,'117315','deals','block-122890','login\\Guest','',1),(122892,'117316','deals','block-122890','Html_box','',2),(122893,'117317','deals','block-122887-2','login\\Returning','',1),(122894,'117318','deals','block-122887-3','BlockBox','',1),(122895,'117319','deals','block-122894','Html_box','',1),(122896,'117320','deals','block-122894-2','BlockBox','',1),(122897,'117321','deals','block-122896','Html_box','',2),(122898,'117322','deals','block-122896','login\\Register','',1),(122899,'117323','deals','block-122886','login\\Socials','',2),(122900,'117324','deals','block-122886','Html_box','',3),(122901,'117325','deals','block-122886','Html_box','',1),(122902,'117326','deals','login_checkout2_q','BlockBox','',1),(122903,'117327','deals','block-122902','Tabs','',4),(122904,'117328','deals','block-122903-1','BlockBox','',1),(122905,'117329','deals','block-122904','Html_box','',1),(122906,'117330','deals','block-122904-2','quote\\FastOrder','',1),(122907,'117331','deals','block-122903-2','login\\Returning','',1),(122908,'117332','deals','block-122903-3','BlockBox','',1),(122909,'117333','deals','block-122908','Html_box','',1),(122910,'117334','deals','block-122908','Import','',2),(122911,'117335','deals','block-122908-2','BlockBox','',1),(122912,'117336','deals','block-122911','login\\Register','',1),(122913,'117337','deals','block-122911','Html_box','',2),(122914,'117338','deals','block-122902','Html_box','',3),(122915,'117339','deals','block-122902','Html_box','',1),(122916,'117340','deals','block-122902','login\\Socials','',2),(122917,'117341','deals','login_checkout2_s','BlockBox','',1),(122918,'117342','deals','block-122917','login\\Socials','',2),(122919,'117343','deals','block-122917','Html_box','',3),(122920,'117344','deals','block-122917','Tabs','',4),(122921,'117345','deals','block-122920-1','BlockBox','',1),(122922,'117346','deals','block-122921','Html_box','',1),(122923,'117347','deals','block-122921-2','quote\\FastOrder','',1),(122924,'117348','deals','block-122920-2','login\\Returning','',1),(122925,'117349','deals','block-122920-3','BlockBox','',1),(122926,'117350','deals','block-122925','Html_box','',1),(122927,'117351','deals','block-122925-2','BlockBox','',1),(122928,'117352','deals','block-122927','login\\Register','',1),(122929,'117353','deals','block-122927','Html_box','',2),(122930,'117354','deals','block-122917','Html_box','',1),(122931,'117355','deals','login_checkout_q','BlockBox','',1),(122932,'117356','deals','block-122931','BlockBox','',1),(122933,'117357','deals','block-122932','BlockBox','',5),(122934,'117358','deals','block-122933','Html_box','',1),(122935,'117359','deals','block-122933','login\\Socials','',2),(122936,'117360','deals','block-122932','checkout\\GuestBtn','',2),(122937,'117361','deals','block-122932','checkout\\CreateBtn','',4),(122938,'117362','deals','block-122932','Html_box','',3),(122939,'117363','deals','block-122932','Html_box','',1),(122940,'117364','deals','block-122932-2','Html_box','',1),(122941,'117365','deals','block-122932-2','login\\Returning','',2),(122942,'117366','deals','login_checkout_s','BlockBox','',1),(122943,'117367','deals','block-122942','BlockBox','',1),(122944,'117368','deals','block-122943','Html_box','',1),(122945,'117369','deals','block-122943','checkout\\GuestBtn','',2),(122946,'117370','deals','block-122943','checkout\\CreateBtn','',4),(122947,'117371','deals','block-122943','Html_box','',3),(122948,'117372','deals','block-122943','BlockBox','',5),(122949,'117373','deals','block-122948','Html_box','',1),(122950,'117374','deals','block-122948','login\\Socials','',2),(122951,'117375','deals','block-122943-2','Html_box','',1),(122952,'117376','deals','block-122943-2','login\\Returning','',2),(122953,'117377','deals','logoff','BlockBox','',1),(122954,'117378','deals','block-122953','Html_box','',1),(122955,'117379','deals','logoff_forever','BlockBox','',1),(122956,'117380','deals','block-122955','Html_box','',1),(122957,'1641480784','deals','main','BlockBox','',5),(122958,'1641480810','deals','block-122957','InfoPage','',0),(122959,'1641549359','deals','main','BlockBox','',3),(122960,'1641549444','deals','block-122959','BlockBox','',0),(122961,'1641549385','deals','block-122960','Banner','',1),(122962,'1641549553','deals','block-122960-2','Banner','',1),(122963,'1641570125','deals','main','BlockBox','main-content',4),(122964,'1641570075','deals','block-122963','TopCategories','',1),(122965,'1683024814.1915','deals','main','Banner','',1),(122967,'117394','deals','manufacturers','BlockBox','',1),(122968,'117395','deals','block-122967','Html_box','',1),(122969,'117396','deals','block-122967','Brands','',2),(122970,'117397','deals','messages-index','BlockBox','',1),(122971,'117398','deals','block-122970','BlockBox','',1),(122972,'117399','deals','block-122971','BlockBox','',1),(122973,'117400','deals','block-122972','Messages\\Sidebar','',1),(122974,'117401','deals','block-122971-2','Messages\\Listing','',1),(122975,'117402','deals','messages-new','BlockBox','',1),(122976,'117403','deals','block-122975','BlockBox','',1),(122977,'117404','deals','block-122976','Messages\\Sidebar','',1),(122978,'117405','deals','block-122976-2','Messages\\NewMessage','',1),(122979,'117406','deals','messages-view','BlockBox','',1),(122980,'117407','deals','block-122979','BlockBox','',1),(122981,'117408','deals','block-122980','Messages\\Sidebar','',1),(122982,'117409','deals','block-122980-2','Messages\\Message','',1),(122983,'117410','deals','my_password','BlockBox','',1),(122984,'117411','deals','block-122983','BlockBox','',1),(122985,'117412','deals','block-122984','WidgetsAria','',1),(123005,'117413','deals','block-122984-2','account\\ChangePassword','',2),(123006,'117414','deals','block-122984-2','Html_box','',1),(123007,'117415','deals','need_login','BlockBox','',1),(123008,'117416','deals','block-123007','Tabs','',2),(123009,'117417','deals','block-123008-1','login\\Returning','',1),(123010,'117418','deals','block-123008-2','BlockBox','',1),(123011,'117419','deals','block-123010','Html_box','',2),(123012,'117420','deals','block-123010-2','BlockBox','',1),(123013,'117421','deals','block-123012','login\\Register','',1),(123014,'117422','deals','block-123012','Html_box','',2),(123015,'117423','deals','block-123007','BlockBox','',1),(123016,'117424','deals','new-topic','BlockBox','',1),(123017,'117425','deals','block-123016','Breadcrumb','',2),(123018,'117426','deals','block-123016','Communication\\NewTopic','',3),(123019,'117427','deals','block-123016','Html_box','',1),(123020,'117428','deals','nnnn','BlockBox','',1),(123021,'117429','deals','block-123020','catalog\\Title','',1),(123022,'117430','deals','block-123020','BlockBox','',2),(123023,'117431','deals','block-123022','Filters','',1),(123024,'117432','deals','block-123022-2','Listing','',5),(123025,'117433','deals','block-123022-2','catalog\\Image','',1),(123026,'117434','deals','block-123022-2','BlockBox','',6),(123027,'117435','deals','block-123026','catalog\\CountsItems','',1),(123028,'117436','deals','block-123026-2','catalog\\Paging','',1),(123029,'117437','deals','block-123022-2','catalog\\ImageMapCategory','',3),(123030,'117438','deals','block-123022-2','Categories','',2),(123031,'117439','deals','block-123022-2','BlockBox','',4),(123032,'117440','deals','block-123031','catalog\\ListingLook','',1),(123033,'117441','deals','block-123031','catalog\\ItemsOnPage','',4),(123034,'117442','deals','block-123031','catalog\\CompareButton','',2),(123035,'117443','deals','block-123031','catalog\\Sorting','',3),(123036,'117444','deals','no-logged','BlockBox','',1),(123037,'117445','deals','block-123036','Communication\\NewTopic','',2),(123038,'117446','deals','block-123036','Html_box','',1),(123039,'117447','deals','no_filters','BlockBox','catalog-content',1),(123040,'117448','deals','block-123039','BlockBox','',4),(123041,'117449','deals','block-123040','catalog\\CountsItems','',1),(123042,'117450','deals','block-123040-2','catalog\\Paging','',1),(123043,'117451','deals','block-123039','Listing','',3),(123044,'117452','deals','block-123039','catalog\\Title','',1),(123045,'117453','deals','block-123039','catalog\\B2bAddButton','',5),(123046,'117454','deals','block-123039','BlockBox','catalog-features',2),(123047,'117455','deals','block-123046','BlockBox','',2),(123048,'117456','deals','block-123047','HeaderStock','',5),(123049,'117457','deals','block-123047','catalog\\ListingLook','',1),(123050,'117458','deals','block-123047','catalog\\CompareButton','',2),(123051,'117459','deals','block-123047','catalog\\ItemsOnPage','',4),(123052,'117460','deals','block-123047','catalog\\Sorting','',3),(123053,'117461','deals','block-123046','catalog\\Image','',1),(123054,'1645207289.476','deals','no_filters','Compare','',2),(123138,'117507','deals','order_pay','BlockBox','',1),(123139,'117508','deals','block-123138','BlockBox','',1),(123140,'117509','deals','block-123139','WidgetsAria','',1),(123160,'117510','deals','block-123139-2','account\\OrderProducts','',4),(123161,'117511','deals','block-123139-2','BlockBox','',2),(123162,'117512','deals','block-123161','BlockBox','',1),(123163,'117513','deals','block-123162','Html_box','',1),(123164,'117514','deals','block-123162','account\\OrderData','',2),(123165,'117515','deals','block-123161','BlockBox','',4),(123166,'117516','deals','block-123165','account\\OrderData','',2),(123167,'117517','deals','block-123165','Html_box','',1),(123168,'117518','deals','block-123161-2','BlockBox','',1),(123169,'117519','deals','block-123168','Html_box','',1),(123170,'117520','deals','block-123168','account\\OrderData','',2),(123171,'117521','deals','block-123161-2','BlockBox','',2),(123172,'117522','deals','block-123171','account\\OrderData','',2),(123173,'117523','deals','block-123171','Html_box','',1),(123174,'117524','deals','block-123161-3','BlockBox','',2),(123175,'117525','deals','block-123174','Html_box','',1),(123176,'117526','deals','block-123174','account\\OrderData','',2),(123177,'117527','deals','block-123161-3','BlockBox','',1),(123178,'117528','deals','block-123177','account\\OrderData','',2),(123179,'117529','deals','block-123177','Html_box','',1),(123180,'117530','deals','block-123139-2','UpdateAndPay\\PayForm','',6),(123181,'117531','deals','block-123139-2','Html_box','',3),(123182,'117532','deals','block-123139-2','account\\OrderHeading','',1),(123183,'117533','deals','block-123139-2','account\\OrderSubTotals','',5),(123184,'117534','deals','packingslip','invoice\\Container','',2),(123185,'117535','deals','block-123184','BlockBox','',2),(123186,'117536','deals','block-123185','Logo','',1),(123187,'117537','deals','block-123185-2','BlockBox','',3),(123188,'117538','deals','block-123187','Text','',2),(123189,'117539','deals','block-123187-2','invoice\\StoreEmail','',1),(123190,'117540','deals','block-123185-2','BlockBox','',2),(123191,'117541','deals','block-123190','Text','',2),(123192,'117542','deals','block-123190-2','invoice\\StorePhone','',1),(123193,'117543','deals','block-123185-2','BlockBox','',1),(123194,'117544','deals','block-123193','invoice\\StoreAddress','',1),(123195,'117545','deals','block-123185-2','BlockBox','',4),(123196,'117546','deals','block-123195','Text','',2),(123197,'117547','deals','block-123195-2','invoice\\StoreSite','',1),(123198,'117548','deals','block-123184','packingslip\\Products','',5),(123199,'117549','deals','block-123184','BlockBox','',6),(123200,'117550','deals','block-123199','invoice\\StoreAddress','',2),(123201,'117551','deals','block-123199','Text','',1),(123202,'117552','deals','block-123184','BlockBox','',3),(123203,'117553','deals','block-123202','BlockBox','',2),(123204,'117554','deals','block-123203','BlockBox','',1),(123205,'117555','deals','block-123204','invoice\\ShippingAddress','',2),(123206,'117556','deals','block-123204','Text','',1),(123207,'117557','deals','block-123203-2','BlockBox','',1),(123208,'117558','deals','block-123207','Text','',1),(123209,'117559','deals','block-123207','invoice\\CustomerName','',2),(123210,'117560','deals','block-123207','invoice\\CustomerEmail','',6),(123211,'117561','deals','block-123207','Text','',3),(123212,'117562','deals','block-123207','invoice\\CustomerPhone','',4),(123213,'117563','deals','block-123207','Text','',5),(123214,'117564','deals','block-123202','BlockBox','',3),(123215,'117565','deals','block-123214','BlockBox','',1),(123216,'117566','deals','block-123215','invoice\\ShippingMethod','',2),(123217,'117567','deals','block-123215','Text','',1),(123218,'117568','deals','block-123214-2','BlockBox','',1),(123219,'117569','deals','block-123218','invoice\\ShippingMethod','',2),(123220,'117570','deals','block-123218','Text','',1),(123221,'117571','deals','block-123202-2','invoice\\AddressQrcode','',1),(123222,'1639660991','deals','block-123184','Neighbour\\PackingSlipInfo','',1),(123223,'1639661081','deals','block-123184','Neighbour\\PackingSlipInfo','',4),(123224,'117572','deals','password_forgotten','BlockBox','',1),(123225,'117573','deals','block-123224','BlockBox','',2),(123226,'1638807246','deals','block-123225','Html_box','',1),(123227,'117574','deals','block-123225-2','Html_box','',1),(123228,'117575','deals','block-123225-2','login\\PasswordForgotten','',2),(123229,'117576','deals','block-123224','Html_box','',1),(123230,'117577','deals','pdf','invoice\\Container','',1),(123231,'117578','deals','block-123230','BlockBox','',1),(123232,'117579','deals','block-123231','BlockBox','',1),(123233,'117580','deals','block-123232','BlockBox','',1),(123234,'117581','deals','block-123233','pdf\\ProductElement','',1),(123235,'117582','deals','block-123232','BlockBox','',2),(123236,'117583','deals','block-123235','pdf\\ProductElement','',1),(123237,'117584','deals','block-123235-2','pdf\\ProductElement','',2),(123238,'117585','deals','block-123235-2','pdf\\ProductElement','',1),(123239,'117586','deals','block-123231-2','BlockBox','',1),(123240,'117587','deals','block-123239','BlockBox','',2),(123241,'117588','deals','block-123240','pdf\\ProductElement','',1),(123242,'117589','deals','block-123240-2','pdf\\ProductElement','',2),(123243,'117590','deals','block-123240-2','pdf\\ProductElement','',1),(123244,'117591','deals','block-123239','BlockBox','',1),(123245,'117592','deals','block-123244','pdf\\ProductElement','',1),(123246,'117593','deals','pdf_category','pdf\\CategoryName','',2),(123247,'117594','deals','pdf_category','pdf\\CategoryImage','',1),(123248,'117595','deals','pdf_cover','invoice\\Container','',1),(123249,'117596','deals','block-123248','Logo','',1),(123250,'117597','deals','block-123248','Text','',3),(123251,'117598','deals','pdf_footer','BlockBox','',1),(123252,'117599','deals','block-123251-2','pdf\\PageNumber','',1),(123253,'117600','deals','pdf_header','pdf\\CategoryName','',1),(123254,'117601','deals','personal_catalog','BlockBox','',1),(123255,'117602','deals','block-123254','BlockBox','',1),(123256,'117603','deals','block-123255','WidgetsAria','',1),(123276,'117604','deals','block-123255-2','Html_box','',1),(123277,'117606','deals','block-123255-2','account\\PersonalCatalog','',2),(123278,'117607','deals','points_earnt_history','BlockBox','',1),(123279,'117608','deals','block-123278','Html_box','',1),(123280,'117609','deals','block-123278','account\\PointsEarntHistory','',2),(123281,'117610','deals','posts','BlockBox','',1),(123282,'117611','deals','block-123281','Breadcrumb','',2),(123283,'117612','deals','block-123281','Html_box','',1),(123284,'117613','deals','block-123281','Communication\\Post','',3),(123285,'1683114469.26259','deals','product','BlockBox','',2),(123286,'1683114469.295895','deals','block-123285','product\\Name','',1),(123287,'1683114469.29722','deals','block-123285','BlockBox','product-content',2),(123288,'1683114469.299773','deals','block-123287','product\\Images','',2),(123289,'1683114469.301198','deals','block-123287','Promotions\\widgets\\PromotionIcons','',1),(123290,'1683114469.302537','deals','block-123287-2','product\\Groups','',3),(123291,'1683114469.30314','deals','block-123287-2','BlockBox','',1),(123292,'1683114469.304286','deals','block-123291','product\\Model','',2),(123293,'1683114469.304862','deals','block-123291','product\\Rating','',1),(123294,'1683114469.306253','deals','block-123291-2','product\\Stock','',2),(123295,'1683114469.307492','deals','block-123291-2','product\\PriceFrom','',1),(123296,'1683114469.3081','deals','block-123287-2','BlockBox','',4),(123297,'1683114469.309625','deals','block-123296','product\\QuantityDiscounts','',4),(123298,'1683114469.310518','deals','block-123296','Html_box','',5),(123299,'1683114469.31285','deals','block-123296','SupportSystem\\ProductFaq','',1),(123300,'1683114469.313585','deals','block-123296','product\\Properties','',6),(123301,'1683114469.319743','deals','block-123296','Promotions\\widgets\\PromotionIconsDesc','',7),(123302,'1683114469.328177','deals','block-123296','product\\Inventory','',3),(123303,'1683114469.329314','deals','block-123296','product\\Groups','',2),(123304,'1683114469.33265','deals','block-123296-2','BlockBox','',1),(123305,'1683114469.333690','deals','block-123304','product\\Price','',1),(123306,'1683114469.334771','deals','block-123304','product\\Quantity','',2),(123307,'1683114469.34343','deals','block-123304','product\\Buttons','',3),(123308,'1683114469.347391','deals','block-123304','product\\PersonalCatalogButton','',4),(123309,'1683114469.351242','deals','block-123287-2','product\\DescriptionShort','',2),(123310,'1683114493.817723','deals','product','BlockBox','',3),(123311,'1683114493.851867','deals','block-123310','product\\Description','',2),(123312,'1683114493.853236','deals','block-123310','product\\Reviews','',6),(123313,'1683114493.85674','deals','block-123310','BlockBox','product-bottom',5),(123314,'1683114493.857344','deals','block-123313','ViewedProducts','4',1),(123315,'1683114493.861475','deals','block-123313','Html_box','',0),(123316,'1683114493.86940','deals','block-123310','BlockBox','',4),(123317,'1683114493.870678','deals','block-123316','product\\Bundle','',1),(123318,'1683114493.875988','deals','block-123316','product\\InBundles','',2),(123319,'117655','deals','product-bottom','product\\Properties','',1),(123320,'117656','deals','product-tabs','product\\Reviews','',2),(123321,'117657','deals','product-tabs','product\\Description','',1),(123322,'117658','deals','product-top-left','product\\Images','',1),(123323,'117659','deals','product-top-right','product\\Price','',2),(123324,'117660','deals','product-top-right','product\\Quantity','',5),(123325,'117661','deals','product-top-right','product\\Quantity','',6),(123326,'117662','deals','product-top-right','product\\Attributes','',3),(123327,'117663','deals','product-top-right','product\\Name','',1),(123328,'117664','deals','product-top-right','product\\Buttons','',6),(123329,'120919.000001','deals','productListing','BlockBox','listing-item',2),(123330,'120895','deals','block-123329','productListing\\viewButton','',14),(123331,'117667','deals','block-123329','productListing\\bonusPoints','',2),(123332,'117668','deals','block-123329','productListing\\description','',10),(123333,'117670.000001','deals','block-123329','productListing\\rating','',11),(123334,'117671.000001','deals','block-123329','productListing\\image','',1),(123335,'117673.000001','deals','block-123329','productListing\\price','',5),(123336,'117675.000001','deals','block-123329','productListing\\name','',4),(123337,'117676.000001','deals','block-123329','productListing\\stock','',3),(123338,'120863','deals','block-123329','productListing\\ratingCounts','',12),(123339,'1639645717','deals','block-123329','productListing\\productGroup','',13),(123341,'1641901973','deals','block-123329','productListing\\compare','',16),(123342,'1641901997','deals','block-123329','productListing\\personalCatalog','',15),(123343,'1641903084','deals','block-123329','productListing\\model','',6),(123344,'1641903101','deals','block-123329','productListing\\properties','',9),(123346,'117678','deals','products','BlockBox','catalog-content',2),(123347,'117683','deals','block-123346','BlockBox','catalog-features',5),(123348,'117685','deals','block-123347','catalog\\ListingLook','',1),(123349,'117687','deals','block-123347','catalog\\CompareButton','',2),(123350,'117691','deals','block-123346','Listing','',6),(123351,'120912','deals','block-123346','BlockBox','',7),(123352,'120913','deals','block-123351','catalog\\CountsItems','',1),(123353,'120914','deals','block-123351-2','catalog\\Paging','',1),(123354,'117692','deals','block-123346','catalog\\Title','',2),(123355,'117693','deals','block-123346','BlockBox','',3),(123356,'117694','deals','block-123355','catalog\\Image','',2),(123357,'1641894402','deals','block-123346','BlockBox','',4),(123358,'1641809968.0001','deals','block-123357','BlockBox','',4),(123359,'116286.000001','deals','block-123358','catalog\\Sorting','',2),(123360,'1641810239.0001','deals','block-123358','Filters','',1),(123361,'121018','deals','products','Compare','',3),(123362,'117695','deals','products-list','packingslip\\AllProductsList','',2),(123363,'117696','deals','promotions','BlockBox','info-content',1),(123364,'117697','deals','block-123363','promotions\\PromoList','',2),(123365,'117698','deals','block-123363','Html_box','',1),(123366,'117699','deals','purchase','invoice\\Container','',1),(123367,'117700','deals','block-123366','invoice\\Products','',3),(123368,'117701','deals','block-123366','BlockBox','',5),(123369,'117702','deals','block-123368','Text','',1),(123370,'117703','deals','block-123368','invoice\\StoreAddress','',8),(123371,'117704','deals','block-123368-2','Text','',2),(123372,'117705','deals','block-123368-2','Logo','',1),(123373,'117706','deals','block-123368-3','BlockBox','',3),(123374,'117707','deals','block-123373','Text','',1),(123375,'117708','deals','block-123373-2','invoice\\StoreEmail','',1),(123376,'117709','deals','block-123368-3','Text','',1),(123377,'117710','deals','block-123368-3','BlockBox','',2),(123378,'117711','deals','block-123377','Text','',1),(123379,'117712','deals','block-123377-2','invoice\\StorePhone','',1),(123380,'117713','deals','block-123366','BlockBox','',1),(123381,'117714','deals','block-123380','Logo','',1),(123382,'117715','deals','block-123380-2','BlockBox','',2),(123383,'117716','deals','block-123382','Text','',1),(123384,'117717','deals','block-123382-2','invoice\\StorePhone','',1),(123385,'117718','deals','block-123380-2','BlockBox','',4),(123386,'117719','deals','block-123385','Text','',1),(123387,'117720','deals','block-123385-2','invoice\\StoreSite','',1),(123388,'117721','deals','block-123380-2','BlockBox','',1),(123389,'117722','deals','block-123388','invoice\\StoreAddress','',1),(123390,'117723','deals','block-123380-2','BlockBox','',3),(123391,'117724','deals','block-123390','Text','',1),(123392,'117725','deals','block-123390-2','invoice\\StoreEmail','',1),(123393,'117726','deals','block-123366','BlockBox','',2),(123394,'117727','deals','block-123393','BlockBox','',7),(123395,'117728','deals','block-123394','BlockBox','',1),(123396,'117729','deals','block-123395','invoice\\BillingAddress','',2),(123397,'117730','deals','block-123395','Text','',1),(123398,'117731','deals','block-123394-2','BlockBox','',1),(123399,'117732','deals','block-123398','invoice\\CustomerEmail','',6),(123400,'117733','deals','block-123398','Text','',5),(123401,'117734','deals','block-123398','invoice\\CustomerPhone','',4),(123402,'117735','deals','block-123398','invoice\\CustomerName','',2),(123403,'117736','deals','block-123398','Text','',3),(123404,'117737','deals','block-123398','Text','',1),(123405,'117738','deals','block-123393-2','invoice\\OrderId','',1),(123406,'117739','deals','block-123393-2','Text','',2),(123407,'117740','deals','block-123393-2','invoice\\PaymentDate','',3),(123408,'117741','deals','block-123366','BlockBox','',4),(123409,'117742','deals','block-123408','BlockBox','',1),(123410,'117743','deals','block-123409','invoice\\ShippingAddress','',2),(123411,'117744','deals','block-123409','Text','',1),(123415,'117745','deals','quotations','BlockBox','',1),(123416,'117746','deals','block-123415','BlockBox','',1),(123417,'117747','deals','block-123416','WidgetsAria','',1),(123437,'117748','deals','block-123416-2','Html_box','',1),(123438,'117749','deals','block-123416-2','Quotations\\QuotationsHistory','',2),(123439,'117750','deals','quotation_info','BlockBox','',1),(123440,'117751','deals','block-123439','BlockBox','',1),(123441,'117752','deals','block-123440','WidgetsAria','',1),(123461,'117753','deals','block-123440-2','BlockBox','',5),(123462,'117754','deals','block-123461','BlockBox','',1),(123463,'117755','deals','block-123462','Quotations\\QuotationData','',2),(123464,'117756','deals','block-123462','Html_box','',1),(123465,'117757','deals','block-123461','BlockBox','',4),(123466,'117758','deals','block-123465','Html_box','',1),(123467,'117759','deals','block-123465','Quotations\\QuotationData','',2),(123468,'117760','deals','block-123461-2','BlockBox','',2),(123469,'117761','deals','block-123468','Html_box','',1),(123470,'117762','deals','block-123468','Quotations\\QuotationData','',2),(123471,'117763','deals','block-123461-2','BlockBox','',1),(123472,'117764','deals','block-123471','Html_box','',1),(123473,'117765','deals','block-123471','Quotations\\QuotationData','',2),(123474,'117766','deals','block-123461-3','BlockBox','',1),(123475,'117767','deals','block-123474','Quotations\\QuotationData','',2),(123476,'117768','deals','block-123474','Html_box','',1),(123477,'117769','deals','block-123461-3','BlockBox','',2),(123478,'117770','deals','block-123477','Quotations\\QuotationData','',2),(123479,'117771','deals','block-123477','Html_box','',1),(123480,'117772','deals','block-123440-2','Html_box','',6),(123481,'117773','deals','block-123440-2','Quotations\\QuotationHistory','',10),(123482,'117774','deals','block-123440-2','Html_box','',9),(123483,'117775','deals','block-123440-2','Quotations\\QuotationProducts','',7),(123484,'117776','deals','block-123440-2','Quotations\\QuotationSubTotal','',8),(123485,'117777','deals','block-123440-2','BlockBox','',12),(123486,'117778','deals','block-123485','account\\AccountLink','',1),(123487,'117779','deals','block-123440-2','Html_box','',4),(123488,'117780','deals','quote','BlockBox','',1),(123489,'117781','deals','block-123488','cart\\CartTabs','',1),(123490,'117782','deals','block-123489','BlockBox','',1),(123491,'117783','deals','block-123490','quote\\Products','',1),(123492,'117784','deals','block-123490-2','BlockBox','',1),(123493,'117785','deals','block-123492','BlockBox','',1),(123494,'117786','deals','block-123493','quote\\CheckoutBtn','',2),(123495,'117787','deals','block-123489','Quotations\\QuotationSubTotal','',2),(123520,'117793','deals','reviews','BlockBox','info-content',1),(123521,'117794','deals','block-123520','reviews\\Heading','',1),(123522,'117795','deals','block-123520','reviews\\Content','',2),(123523,'117796','deals','rma_document','invoice\\Container','',1),(123524,'117797','deals','block-123523','BlockBox','',1),(123525,'117798','deals','block-123524','BlockBox','',1),(123526,'117799','deals','block-123525','BlockBox','',2),(123527,'117800','deals','block-123526','Html_box','',1),(123528,'117801','deals','block-123526-2','Html_box','',1),(123529,'117802','deals','block-123525','BlockBox','',5),(123530,'117803','deals','block-123529','Html_box','',1),(123531,'117804','deals','block-123529-2','Html_box','',1),(123532,'117805','deals','block-123525','BlockBox','',4),(123533,'117806','deals','block-123532','Html_box','',1),(123534,'117807','deals','block-123532-2','Html_box','',1),(123535,'117808','deals','block-123525','BlockBox','',3),(123536,'117809','deals','block-123535','Html_box','',1),(123537,'117810','deals','block-123535-2','Html_box','',1),(123538,'117811','deals','block-123525','BlockBox','',1),(123539,'117812','deals','block-123538','Html_box','',1),(123540,'117813','deals','block-123538','Html_box','',2),(123541,'117814','deals','block-123524-2','BlockBox','',1),(123542,'117815','deals','block-123541','Html_box','',2),(123543,'117816','deals','block-123541','Logo','',1),(123544,'117817','deals','block-123524-2','BlockBox','',2),(123545,'117818','deals','block-123544','BlockBox','',5),(123546,'117819','deals','block-123545','BlockBox','',1),(123547,'117820','deals','block-123546','Html_box','',1),(123548,'117821','deals','block-123546-2','Rma\\DocumentData','',1),(123549,'117822','deals','block-123545-2','BlockBox','',1),(123550,'117823','deals','block-123549','Html_box','',1),(123551,'117824','deals','block-123549-2','Rma\\DocumentData','',1),(123552,'117825','deals','block-123544','BlockBox','',4),(123553,'117826','deals','block-123552','BlockBox','',1),(123554,'117827','deals','block-123553','Html_box','',1),(123555,'117828','deals','block-123553-2','Rma\\DocumentData','',1),(123556,'117829','deals','block-123552-2','BlockBox','',1),(123557,'117830','deals','block-123556','Html_box','',1),(123558,'117831','deals','block-123556-2','Rma\\DocumentData','',1),(123559,'117832','deals','block-123544','BlockBox','',3),(123560,'117833','deals','block-123559','BlockBox','',1),(123561,'117834','deals','block-123560','Html_box','',1),(123562,'117835','deals','block-123560-2','Rma\\DocumentData','',1),(123563,'117836','deals','block-123559-2','BlockBox','',1),(123564,'117837','deals','block-123563','Html_box','',1),(123565,'117838','deals','block-123563-2','Rma\\DocumentData','',1),(123566,'117839','deals','block-123544','BlockBox','',2),(123567,'117840','deals','block-123566','Html_box','',1),(123568,'117841','deals','block-123566-2','Rma\\DocumentData','',1),(123569,'117842','deals','block-123544','BlockBox','',1),(123570,'117843','deals','block-123569','BlockBox','',1),(123571,'117844','deals','block-123570','Html_box','',1),(123572,'117845','deals','block-123570-2','Rma\\DocumentData','',1),(123573,'117846','deals','block-123569-2','BlockBox','',1),(123574,'117847','deals','block-123573','Html_box','',1),(123575,'117848','deals','block-123573-2','Rma\\DocumentData','',1),(123576,'117849','deals','block-123524-2','BlockBox','',3),(123577,'117850','deals','block-123576','BlockBox','',1),(123578,'117851','deals','block-123577','Html_box','',1),(123579,'117852','deals','block-123577-2','Rma\\DocumentData','',1),(123580,'117853','deals','block-123576-2','BlockBox','',1),(123581,'117854','deals','block-123580','Html_box','',1),(123582,'117855','deals','block-123580-2','Rma\\DocumentData','',1),(123583,'117856','deals','block-123523','BlockBox','',2),(123584,'117857','deals','block-123583','Html_box','',1),(123585,'117858','deals','block-123583','Rma\\Products','',2),(123586,'117859','deals','block-123523','BlockBox','',3),(123587,'117860','deals','block-123586','BlockBox','',1),(123588,'117861','deals','block-123587','BlockBox','',1),(123589,'117862','deals','block-123588','BlockBox','',5),(123590,'117863','deals','block-123589','Html_box','',1),(123591,'117864','deals','block-123589-2','invoice\\StoreAddress','',2),(123592,'117865','deals','block-123589-2','Html_box','',1),(123593,'117866','deals','block-123588','BlockBox','',4),(123594,'117867','deals','block-123593','Html_box','',1),(123595,'117868','deals','block-123593-2','Html_box','',1),(123596,'117869','deals','block-123588','BlockBox','',2),(123597,'117870','deals','block-123596','Html_box','',1),(123598,'117871','deals','block-123596-2','Html_box','',1),(123599,'117872','deals','block-123588','BlockBox','',1),(123600,'117873','deals','block-123599','Html_box','',1),(123601,'117874','deals','block-123588','BlockBox','',3),(123602,'117875','deals','block-123601','Html_box','',1),(123603,'117876','deals','block-123601-2','Html_box','',1),(123604,'117877','deals','block-123588','BlockBox','',6),(123605,'117878','deals','block-123604','Html_box','',1),(123606,'117879','deals','block-123587-2','BlockBox','',1),(123607,'117880','deals','block-123606','BlockBox','',1),(123608,'117881','deals','block-123607','BlockBox','',1),(123609,'117882','deals','block-123608','Rma\\DocumentData','',2),(123610,'117883','deals','block-123608-3','BlockBox','',1),(123611,'117884','deals','block-123610','Html_box','',1),(123612,'117885','deals','block-123610-2','Rma\\DocumentData','',1),(123613,'117886','deals','block-123607','BlockBox','',2),(123614,'117887','deals','block-123613-2','invoice\\StoreAddress','',1),(123615,'117888','deals','block-123587-2','BlockBox','',2),(123616,'117889','deals','block-123615','Html_box','',1),(123617,'117890','deals','block-123615','Html_box','',2),(123618,'117891','deals','block-123615','Html_box','',3),(123619,'117892','deals','block-123615','Html_box','',4),(123620,'117893','deals','block-123615','Html_box','',5),(123621,'117894','deals','block-123587-2','BlockBox','',4),(123622,'117895','deals','block-123621','Html_box','',1),(123623,'117896','deals','block-123621-2','Html_box','',1),(123624,'117897','deals','block-123621-3','BlockBox','',1),(123625,'117898','deals','block-123624','Html_box','',1),(123626,'117899','deals','block-123624-2','Html_box','',1),(123627,'117900','deals','block-123587-2','BlockBox','',3),(123628,'117901','deals','block-123627','Html_box','',1),(123629,'117902','deals','block-123627-2','Html_box','',1),(123630,'117903','deals','block-123627-3','BlockBox','',1),(123631,'117904','deals','block-123630','Html_box','',1),(123632,'117905','deals','block-123630-2','Html_box','',1),(123633,'117906.000001','deals','rows','BlockBox','listing-item',1),(123634,'117907.000001','deals','block-123633','BlockBox','',2),(123635,'117908.000001','deals','block-123634','BlockBox','',2),(123636,'117909.000001','deals','block-123635','productListing\\bonusPoints','',2),(123637,'117910.000001','deals','block-123635','productListing\\image','',1),(123638,'117914.000001','deals','block-123635-2','productListing\\name','',1),(123639,'117915.000001','deals','block-123635-2','productListing\\description','',2),(123640,'117916.000001','deals','block-123635-2','productListing\\model','',4),(123641,'117917.000001','deals','block-123635-2','productListing\\attributes','',5),(123642,'120922.000001','deals','block-123635-2','productListing\\properties','',3),(123643,'1639146806','deals','block-123635-2','productListing\\productGroup','',6),(123644,'117918.000001','deals','block-123634-2','BlockBox','',1),(123645,'117911.000001','deals','block-123644','BlockBox','',3),(123646,'117912.000001','deals','block-123645','productListing\\rating','',1),(123647,'117913.000001','deals','block-123645','productListing\\ratingCounts','',2),(123648,'117919.000001','deals','block-123644','productListing\\qtyInput','',4),(123649,'117920.000001','deals','block-123644','productListing\\price','',2),(123650,'117922.000001','deals','block-123644','productListing\\buyButton','',5),(123651,'117924.000001','deals','block-123644','productListing\\stock','',1),(123652,'120924.000001','deals','block-123644','BlockBox','',8),(123653,'120925.000001','deals','block-123652','productListing\\compare','',3),(123654,'120926.000001','deals','block-123652','productListing\\personalCatalog','',2),(123655,'120927.000001','deals','block-123652','productListing\\viewButton','',1),(123656,'117925','deals','sample','BlockBox','',1),(123657,'117926','deals','block-123656','cart\\CartTabs','',1),(123658,'117927','deals','block-123657','BlockBox','',1),(123659,'117928','deals','block-123658','sample\\Products','',1),(123660,'117929','deals','block-123658-2','BlockBox','',1),(123661,'117930','deals','block-123660','BlockBox','',1),(123662,'117931','deals','block-123661','sample\\CheckoutBtn','',1),(123663,'117932','deals','samples','BlockBox','',1),(123664,'117933','deals','block-123663','BlockBox','',1),(123665,'117934','deals','block-123664','WidgetsAria','',1),(123685,'117935','deals','block-123664-2','Html_box','',1),(123686,'117936','deals','block-123664-2','Samples\\SamplesHistory','',2),(123687,'117937','deals','sample_info','BlockBox','',1),(123688,'117938','deals','block-123687','BlockBox','',1),(123689,'117939','deals','block-123688','WidgetsAria','',1),(123709,'117940','deals','block-123688-2','Html_box','',1),(123710,'117941','deals','block-123688-2','BlockBox','',8),(123711,'117942','deals','block-123710','account\\AccountLink','',1),(123712,'117943','deals','block-123688-2','Samples\\SampleHistory','',7),(123713,'117944','deals','block-123688-2','Html_box','',3),(123714,'117945','deals','block-123688-2','Samples\\SampleSubTotal','',5),(123715,'117946','deals','block-123688-2','Samples\\SampleProducts','',4),(123716,'117947','deals','block-123688-2','Html_box','',6),(123717,'117948','deals','block-123688-2','BlockBox','',2),(123718,'117949','deals','block-123717','BlockBox','',4),(123719,'117950','deals','block-123718','Html_box','',1),(123720,'117951','deals','block-123718','Samples\\SampleData','',2),(123721,'117952','deals','block-123717','BlockBox','',1),(123722,'117953','deals','block-123721','Samples\\SampleData','',2),(123723,'117954','deals','block-123721','Html_box','',1),(123724,'117955','deals','block-123717-2','BlockBox','',2),(123725,'117956','deals','block-123724','Samples\\SampleData','',2),(123726,'117957','deals','block-123724','Html_box','',1),(123727,'117958','deals','block-123717-2','BlockBox','',1),(123728,'117959','deals','block-123727','Samples\\SampleData','',2),(123729,'117960','deals','block-123727','Html_box','',1),(123730,'117961','deals','block-123717-3','BlockBox','',2),(123731,'117962','deals','block-123730','Samples\\SampleData','',2),(123732,'117963','deals','block-123730','Html_box','',1),(123733,'117964','deals','block-123717-3','BlockBox','',1),(123734,'117965','deals','block-123733','Samples\\SampleData','',2),(123735,'117966','deals','block-123733','Html_box','',1),(123736,'117967','deals','sitemap','BlockBox','info-content',1),(123737,'117968','deals','block-123736','Html_box','',1),(123738,'117969','deals','block-123736','BlockBox','',2),(123739,'117970','deals','block-123738','Html_box','',1),(123740,'117971','deals','block-123738','Html_box','',5),(123741,'117972','deals','block-123738','Html_box','',3),(123742,'117973','deals','block-123738','sitemap\\InfoPages','',2),(123743,'117974','deals','block-123738','sitemap\\Categories','',4),(123744,'117975','deals','block-123738','Menu','Account box',6),(123745,'117976','deals','block-123738-2','sitemap\\DeliveryLocation','',2),(123746,'117977','deals','block-123738-2','Html_box','',1),(123747,'120878','deals','social','SocialLinks','',1),(123748,'117978','deals','subscribe','BlockBox','',1),(123749,'117979','deals','block-123748','Html_box','',3),(123750,'117980','deals','block-123748','subscribers\\UnsubscribeForm','',4),(123751,'117981','deals','block-123748','Html_box','',1),(123752,'117982','deals','block-123748','subscribers\\SubscribeForm','',2),(123753,'117983','deals','subscribed','BlockBox','',1),(123754,'117984','deals','block-123753','Html_box','',1),(123755,'117985','deals','subscription','BlockBox','',2),(123756,'117986','deals','block-123755','BlockBox','',1),(123757,'117987','deals','block-123756','WidgetsAria','',1),(123777,'117988','deals','block-123756-2','Html_box','',2),(123778,'117989','deals','block-123756-2','Html_box','',3),(123779,'117990','deals','block-123756-2','account\\Subscription','',4),(123780,'1694163942.487488','deals','success','BlockBox','',1),(123781,'1694163942.571966','deals','block-123780','BlockBox','',2),(123782,'1694163942.574743','deals','block-123781','BlockBox','',3),(123783,'1694163942.57618','deals','block-123782','BlockBox','',2),(123784,'1694163942.578938','deals','block-123783','BlockBox','',1),(123785,'1694163942.58174','deals','block-123784','order\\ShippingMethod','',6),(123786,'1694163942.582929','deals','block-123784','order\\DeliveryAddress','',3),(123787,'1694163942.58424','deals','block-123784','Html_box','',7),(123788,'1694163942.58813','deals','block-123784','Html_box','',5),(123789,'1694163942.590','deals','block-123784','Html_box','',1),(123790,'1694163942.591588','deals','block-123784','checkout\\ContactConfirm','',9),(123791,'1694163942.592641','deals','block-123784','Html_box','',2),(123792,'1694163942.594491','deals','block-123783-2','BlockBox','',1),(123793,'1694163942.59612','deals','block-123792','order\\PaymentMethod','',6),(123794,'1694163942.59754','deals','block-123792','order\\BillingAddress','',3),(123795,'1694163942.598173','deals','block-123792','Html_box','',5),(123796,'1694163942.599378','deals','block-123792','Html_box','',1),(123797,'1694163942.600432','deals','block-123792','Html_box','',2),(123798,'1694163942.601780','deals','block-123782','Html_box','',1),(123799,'1694163942.604213','deals','block-123781-2','BlockBox','',1),(123800,'1694163942.605131','deals','block-123799','success\\PrintBtn','',3),(123801,'1694163942.606115','deals','block-123799','success\\ContinueBtn','',4),(123802,'1694163942.607111','deals','block-123799','order\\Products','',1),(123803,'1694163942.608286','deals','block-123799','order\\Totals','',2),(123804,'1694163942.609249','deals','block-123780','BlockBox','',1),(123805,'1694163942.610273','deals','block-123804','Html_box','',2),(123806,'1694163942.611982','deals','block-123804','order\\OrderNumber','',1),(123807,'117997','deals','success_q','BlockBox','',1),(123808,'117998','deals','block-123807','BlockBox','',1),(123809,'117999','deals','block-123808','BlockBox','',2),(123810,'118000','deals','block-123809','success\\ContinueBtn','',2),(123811,'118001','deals','block-123809','success\\PrintBtn','',1),(123812,'118002','deals','block-123808','Html_box','',1),(123817,'118007','deals','ticket','invoice\\Container','',1),(123818,'118008','deals','block-123817','BlockBox','',4),(123819,'118009','deals','block-123818','BlockBox','',1),(123820,'118010','deals','block-123819','invoice\\ShippingAddress','',2),(123821,'118011','deals','block-123819','Text','',1),(123822,'118012','deals','block-123818-2','BlockBox','',1),(123823,'118013','deals','block-123822','invoice\\Totals','',1),(123824,'118014','deals','block-123817','BlockBox','',5),(123825,'118015','deals','block-123824','Text','',1),(123826,'118016','deals','block-123824','invoice\\StoreAddress','',8),(123827,'118018','deals','block-123824-2','Text','',2),(123828,'118019','deals','block-123824-3','Text','',1),(123829,'118020','deals','block-123824-3','BlockBox','',3),(123830,'118021','deals','block-123829','Text','',1),(123831,'118022','deals','block-123829-2','invoice\\StoreEmail','',1),(123832,'118023','deals','block-123824-3','BlockBox','',2),(123833,'118024','deals','block-123832','Text','',1),(123834,'118025','deals','block-123832-2','invoice\\StorePhone','',1),(123835,'118026','deals','block-123817','invoice\\Products','',3),(123836,'118027','deals','block-123817','BlockBox','',1),(123837,'1643890423','deals','block-123836','Logo','',0),(123838,'118028','deals','block-123836-2','BlockBox','',3),(123839,'118029','deals','block-123838','Text','',1),(123840,'118030','deals','block-123838-2','invoice\\StoreEmail','',1),(123841,'118031','deals','block-123836-2','BlockBox','',4),(123842,'118032','deals','block-123841','Text','',1),(123843,'118033','deals','block-123841-2','invoice\\StoreSite','',1),(123844,'118034','deals','block-123836-2','BlockBox','',1),(123845,'118035','deals','block-123844','invoice\\StoreAddress','',1),(123846,'118036','deals','block-123836-2','BlockBox','',2),(123847,'118037','deals','block-123846','Text','',1),(123848,'118038','deals','block-123846-2','invoice\\StorePhone','',1),(123849,'118039','deals','block-123817','BlockBox','',2),(123850,'118040','deals','block-123849','BlockBox','',8),(123851,'118041','deals','block-123850','BlockBox','',1),(123852,'118042','deals','block-123851','Text','',1),(123853,'118043','deals','block-123851','invoice\\ShippingMethod','',2),(123854,'118044','deals','block-123850-2','BlockBox','',1),(123855,'118045','deals','block-123854','Text','',1),(123856,'118046','deals','block-123854','invoice\\ShippingMethod','',2),(123857,'118047','deals','block-123849','BlockBox','',7),(123858,'118048','deals','block-123857','BlockBox','',1),(123859,'118049','deals','block-123858','invoice\\BillingAddress','',2),(123860,'118050','deals','block-123858','Text','',1),(123861,'118051','deals','block-123857-2','BlockBox','',1),(123862,'118052','deals','block-123861','invoice\\CustomerName','',2),(123863,'118053','deals','block-123861','Text','',3),(123864,'118054','deals','block-123861','invoice\\CustomerEmail','',6),(123865,'118055','deals','block-123861','invoice\\CustomerPhone','',4),(123866,'118056','deals','block-123861','Text','',5),(123867,'118057','deals','block-123861','Text','',1),(123868,'118058','deals','block-123849-2','invoice\\PaymentDate','',3),(123869,'118059','deals','block-123849-2','Text','',2),(123870,'118060','deals','block-123849-2','Text','',4),(123871,'118061','deals','block-123849-2','invoice\\OrderId','',1),(123872,'118062','deals','block-123849-2','invoice\\PaymentMethod','',5),(123873,'118063','deals','block-123849-2','invoice\\OrderBarcode','',6),(123874,'118094','deals','tracking_numbers','BlockBox','',1),(123875,'118095','deals','block-123874','Html_box','',1),(123876,'118096','deals','block-123874','account\\OrderTracking','',2),(123877,'118318','deals','unsubscribed','BlockBox','',1),(123878,'118319','deals','block-123877','Html_box','',1),(123879,'118320','deals','update-and-pay-order_confirmation','BlockBox','',1),(123880,'118321','deals','block-123879','BlockBox','',3),(123881,'118322','deals','block-123880','BlockBox','',1),(123882,'118323','deals','block-123881','BlockBox','',1),(123883,'118324','deals','block-123882','BlockBox','',1),(123884,'118325','deals','block-123883','order\\ShippingMethod','',5),(123885,'118326','deals','block-123883','Html_box','',2),(123886,'118327','deals','block-123883','Html_box','',4),(123887,'118328','deals','block-123883','Html_box','',1),(123888,'118329','deals','block-123883','order\\Telephone','',8),(123889,'118330','deals','block-123883','Html_box','',6),(123890,'118331','deals','block-123883','order\\Name','',7),(123891,'118332','deals','block-123883','order\\Email','',9),(123892,'118333','deals','block-123883','order\\DeliveryAddress','',3),(123893,'118334','deals','block-123882-2','BlockBox','',1),(123894,'118335','deals','block-123893','order\\BillingAddress','',3),(123895,'118336','deals','block-123893','UpdateAndPay\\PayConfirm','',5),(123896,'118337','deals','block-123893','Html_box','',1),(123897,'118338','deals','block-123893','Html_box','',2),(123898,'118339','deals','block-123893','Html_box','',4),(123899,'118340','deals','block-123881','BlockBox','',3),(123900,'118341','deals','block-123899','order\\Products','',2),(123901,'118342','deals','block-123899','Html_box','',1),(123902,'118343','deals','block-123880-2','BlockBox','',1),(123903,'118344','deals','block-123902','Html_box','',1),(123904,'118345','deals','block-123902','checkout\\ContinueBtn','',3),(123905,'118346','deals','block-123902','order\\Totals','',2),(123906,'118347','deals','block-123879','account\\OrderHeading','',1),(123907,'118348','deals','update-and-pay-order_pay','BlockBox','',1),(123908,'118349','deals','block-123907','BlockBox','',3),(123909,'118350','deals','block-123908','BlockBox','',1),(123910,'118351','deals','block-123909','BlockBox','',1),(123911,'118352','deals','block-123910','BlockBox','',1),(123912,'118353','deals','block-123911','order\\DeliveryAddress','',4),(123913,'118354','deals','block-123911','order\\Email','',10),(123914,'118355','deals','block-123911','order\\Name','',8),(123915,'118356','deals','block-123911','Html_box','',7),(123916,'118357','deals','block-123911','order\\Telephone','',9),(123917,'118358','deals','block-123911','Html_box','',5),(123918,'118359','deals','block-123911','order\\ShippingMethod','',6),(123919,'118360','deals','block-123911','Html_box','',2),(123920,'118361','deals','block-123911','Html_box','',3),(123921,'1639647774','deals','block-123911','DelayedDespatch\\OrderPay','',1),(123922,'118362','deals','block-123910-2','BlockBox','',1),(123923,'118363','deals','block-123922','Html_box','',1),(123924,'118364','deals','block-123922','Html_box','',2),(123925,'118365','deals','block-123922','Html_box','',4),(123926,'118366','deals','block-123922','order\\BillingAddress','',3),(123927,'118367','deals','block-123922','UpdateAndPay\\PayForm','',5),(123928,'118368','deals','block-123908','BlockBox','',2),(123929,'118369','deals','block-123928','Html_box','',1),(123930,'118370','deals','block-123928','order\\Products','',2),(123931,'118371','deals','block-123908-2','BlockBox','',1),(123932,'118372','deals','block-123931','order\\Totals','',2),(123933,'118373','deals','block-123931','checkout\\ContinueBtn','',3),(123934,'118374','deals','block-123931','Html_box','',1),(123935,'118375','deals','block-123907','account\\OrderHeading','',1),(123936,'118440','deals','wishlist','BlockBox','',1),(123937,'118441','deals','block-123936','BlockBox','',1),(123938,'118442','deals','block-123937','WidgetsAria','',1),(123958,'118443','deals','block-123937-2','account\\Wishlist','',2),(123959,'118444','deals','block-123937-2','Html_box','',1),(123960,'118445','deals','wishlist-cart','BlockBox','',1),(123961,'118446','deals','block-123960','cart\\CartTabs','',1),(123962,'118447','deals','block-123961','account\\Wishlist','',1),(179364,'1712674966.930853','furniture','header','UnsupportedBrowser','',1),(179365,'1712674966.934154','furniture','header','BlockBox','header-content-small',2),(179366,'1712674966.936778','furniture','block-179365','BlockBox','header-content-small-left',1),(179367,'1712674966.939493','furniture','block-179366','Menu','Header menu',1),(179368,'1712674967.04388','furniture','block-179366-2','BlockBox','header-content-small-right',1),(179369,'1712674967.045458','furniture','block-179368','Currencies','',2),(179370,'1712674967.072331','furniture','block-179368','Languages','',1),(179371,'1712674967.095974','furniture','header','BlockBox','header-content',3),(179372,'1712674967.104961','furniture','block-179371','Logo','',1),(179373,'1712674967.10848','furniture','block-179371','Search','',3),(179374,'1712674967.177380','furniture','block-179371','Cart','',4),(179375,'1712674967.300450','furniture','block-179371','Account','',5),(179376,'1712674967.356553','furniture','block-179371','Image','',2),(179377,'1712674967.37028','furniture','header','BlockBox','header-menu',4),(179378,'1712674967.380976','furniture','block-179377','Menu','Categories',1),(179379,'1712679985.656435','watch','header','CookieNotice','',1),(179380,'1712679985.659674','watch','header','BlockBox','header-content-small',2),(179381,'1712679985.661821','watch','block-179380','BlockBox','header-content-small-left',1),(179382,'1712679985.663776','watch','block-179381','Menu','Header menu',1),(179383,'1712679985.705953','watch','block-179381-2','BlockBox','header-content-small-right',5),(179384,'1712679985.707292','watch','block-179383','Cart','',1),(179385,'1712679985.760839','watch','block-179383','Account','',2),(179386,'1712679985.804792','watch','block-179383','Currencies','',4),(179387,'1712679985.832720','watch','block-179383','Languages','',3),(179388,'1712679985.861268','watch','header','BlockBox','header-content',3),(179389,'1712679985.873114','watch','block-179388','Logo','',1),(179390,'1712679985.87751','watch','block-179388','Search','',2),(179391,'1712679985.999727','watch','block-179388','Text','',3),(179392,'1712679986.031228','watch','header','BlockBox','header-menu',4),(179393,'1712679986.036538','watch','block-179392','Menu','Categories',1),(179426,'1712756007.569966','printshop','header','UnsupportedBrowser','',1),(179427,'1712756007.57315','printshop','header','BlockBox','header-content-small',2),(179428,'1712756007.585982','printshop','block-179427','BlockBox','header-content-small-left',1),(179429,'1712756007.5885','printshop','block-179428','Contacts','',2),(179430,'1712756007.589787','printshop','block-179428','Text','',1),(179431,'1712756007.62595','printshop','block-179428-2','BlockBox','header-content-small-right',1),(179432,'1712756007.627579','printshop','block-179431','Menu','Header menu',4),(179433,'1712756007.729922','printshop','block-179431','Chat','',3),(179434,'1712756007.738185','printshop','block-179431','Text','',2),(179435,'1712756007.772518','printshop','block-179431','Contacts','',1),(179436,'1712756007.774661','printshop','header','BlockBox','header-content',3),(179437,'1712756007.779822','printshop','block-179436','Logo','',1),(179438,'1712756007.783714','printshop','block-179436','Search','',4),(179439,'1712756007.85127','printshop','block-179436','Cart','',6),(179440,'1712756007.912178','printshop','block-179436','Account','',5),(179441,'1712756007.950557','printshop','block-179436','BlockBox','header-menu',3),(179442,'1712756007.953578','printshop','block-179441','Menu','Categories',1),(179458,'1712823935.978146','deals','header','BlockBox','',1),(179459,'1712823935.987731','deals','block-179458','BlockBox','header-content',1),(179460,'1712823935.994767','deals','block-179459','Logo','',1),(179461,'1712823935.997331','deals','block-179459','Search','',3),(179462,'1712823936.133379','deals','block-179459','Cart','',5),(179463,'1712823936.18733','deals','block-179459','Account','',4),(179464,'1712823936.243618','deals','block-179459','BlockBox','header-menu',2),(179465,'1712823936.245254','deals','block-179464','Menu','Categories',1),(189014,'1713774131.524999','watch','account','BlockBox','',0),(189015,'1713774131.631466','watch','block-189014','BlockBox','',1),(189016,'1713774131.633419','watch','block-189015','WidgetsAria','',1),(189036,'1713774131.989231','watch','block-189015-2','BlockBox','account-content',1),(189037,'1713774131.990525','watch','block-189036','account\\OrdersHistory','',5),(189038,'1713774131.992548','watch','block-189036','Html_box','',4),(189039,'1713774131.995359','watch','block-189036','Html_box','',1),(189040,'1713774132.011364','watch','block-189036','BlockBox','account-content-top',2),(189041,'1713774132.020828','watch','block-189040','BlockBox','',1),(189042,'1713774132.02226','watch','block-189041','Html_box','',1),(189043,'1713774132.02710','watch','block-189041','account\\LastOrder','',2),(189044,'1713774132.037763','watch','block-189040','BlockBox','',2),(189045,'1713774132.039110','watch','block-189044','Html_box','',1),(189046,'1713774132.04388','watch','block-189044','account\\OrderCount','',2),(189047,'1713774132.045662','watch','block-189044','account\\AccountLink','',3),(189048,'1713774132.047643','watch','block-189040','BlockBox','',3),(189049,'1713774132.048770','watch','block-189048','Html_box','',1),(189050,'1713774132.053414','watch','block-189048','account\\TotalOrdered','',2),(189051,'1713774132.055889','watch','block-189040','BlockBox','',4),(189052,'1713774132.05740','watch','block-189051','Html_box','',1),(189053,'1713774132.061556','watch','block-189051','account\\CreditAmount','',2),(189054,'1713774132.127825','watch','block-189051','account\\AccountLink','',3),(189055,'1713774132.130117','watch','block-189040','BlockBox','',5),(189056,'1713774132.131332','watch','block-189055','account\\AccountLink','',3),(189057,'1713774132.133341','watch','block-189055','BonusActions\\widgets\\PointsEarnt','',2),(189058,'1713774132.13514','watch','block-189055','Html_box','',1),(189059,'1713774132.139570','watch','review','BlockBox','',0),(189060,'1713774132.140834','watch','block-189059','BlockBox','',1),(189061,'1713774132.141911','watch','block-189060','WidgetsAria','',1),(189081,'1713774132.504954','watch','block-189060-2','Html_box','',1),(189082,'1713774132.508462','watch','block-189060-2','account\\Reviews','',2),(189083,'1713774132.514786','watch','order_history_info','BlockBox','',0),(189084,'1713774132.550697','watch','block-189083','BlockBox','',1),(189085,'1713774132.552317','watch','block-189084','WidgetsAria','',1),(189105,'1713774132.898941','watch','block-189084-2','account\\OrderInvoiceButton','',3),(189106,'1713774132.900330','watch','block-189084-2','account\\OrderSubTotals','',10),(189107,'1713774132.901231','watch','block-189084-2','account\\OrderPayButton','',5),(189108,'1713774132.902540','watch','block-189084-2','BlockBox','',13),(189109,'1713774132.903770','watch','block-189108','account\\AccountLink','',1),(189110,'1713774132.90524','watch','block-189108-2','account\\OrderInvoiceButton','',1),(189111,'1713774132.905816','watch','block-189084-2','Html_box','',8),(189112,'1713774132.908463','watch','block-189084-2','account\\OrderHistory','',12),(189113,'1713774132.910483','watch','block-189084-2','account\\OrderCancelAndReorder','',4),(189114,'1713774132.912272','watch','block-189084-2','account\\OrderHeading','',1),(189115,'1713774132.913316','watch','block-189084-2','account\\OrderDownload','',6),(189116,'1713774132.915188','watch','block-189084-2','Html_box','',11),(189117,'1713774132.917477','watch','block-189084-2','account\\OrderProducts','',9),(189118,'1713774132.918550','watch','block-189084-2','account\\OrderReorderButton','',2),(189119,'1713774132.919848','watch','block-189084-2','BlockBox','',7),(189120,'1713774132.921595','watch','block-189119','BlockBox','',2),(189121,'1713774132.92285','watch','block-189120','Html_box','',1),(189122,'1713774132.92519','watch','block-189120','account\\OrderData','',2),(189123,'1713774132.92663','watch','block-189119','BlockBox','',1),(189124,'1713774132.9280','watch','block-189123','Html_box','',1),(189125,'1713774132.932360','watch','block-189123','account\\OrderData','',2),(189126,'1713774132.933540','watch','block-189119','BlockBox','',3),(189127,'1713774132.93487','watch','block-189126','account\\OrderTracking','',2),(189128,'1713774132.936634','watch','block-189126','Html_box','',1),(189129,'1713774132.938818','watch','block-189126','account\\AccountLink','',3),(189130,'1713774132.940770','watch','block-189119-2','BlockBox','',2),(189131,'1713774132.941988','watch','block-189130','account\\OrderData','',2),(189132,'1713774132.94319','watch','block-189130','Html_box','',1),(189133,'1713774132.945272','watch','block-189119-2','BlockBox','',1),(189134,'1713774132.946358','watch','block-189133','account\\OrderData','',2),(189135,'1713774132.947328','watch','block-189133','Html_box','',1),(189136,'1713774132.949323','watch','block-189119-3','BlockBox','',2),(189137,'1713774132.950533','watch','block-189136','account\\OrderData','',2),(189138,'1713774132.951838','watch','block-189136','Html_box','',1),(189139,'1713774132.953990','watch','block-189119-3','BlockBox','',1),(189140,'1713774132.955210','watch','block-189139','Html_box','',1),(189141,'1713774132.957413','watch','block-189139','account\\OrderData','',2),(189142,'1713774132.958422','watch','address_book','BlockBox','',0),(189143,'1713774132.959666','watch','block-189142','BlockBox','',1),(189144,'1713774132.960615','watch','block-189143','WidgetsAria','',1),(189164,'1713774133.357999','watch','block-189143-2','account\\AddressBook','',3),(189165,'1713774133.369549','watch','block-189143-2','Html_box','',1),(189166,'1713774133.371715','watch','block-189143-2','Html_box','',2),(189167,'1713774133.3740','watch','account_edit','BlockBox','',0),(189168,'1713774133.377154','watch','block-189167','BlockBox','',1),(189169,'1713774133.37823','watch','block-189168','WidgetsAria','',1),(189189,'1713774133.709180','watch','block-189168-2','account\\AccountEdit','',2),(189190,'1713774133.710153','watch','block-189168-2','Html_box','',1),(189191,'1713774133.722971','watch','order_history','BlockBox','',0),(189192,'1713774133.772271','watch','block-189191','BlockBox','',1),(189193,'1713774133.773863','watch','block-189192','WidgetsAria','',1),(189213,'1713774134.186274','watch','block-189192-2','Html_box','',1),(189214,'1713774134.188218','watch','block-189192-2','account\\OrdersHistory','',2),(189215,'1713774134.189849','watch','address_book_process','BlockBox','',0),(189216,'1713774134.19293','watch','block-189215','BlockBox','',1),(189217,'1713774134.194197','watch','block-189216','WidgetsAria','',1),(189218,'73374','watch','account-menu','BlockBox','',1),(189219,'73375','watch','block-189218','BlockBox','account-side',1),(189220,'73376','watch','block-189219','Html_box','',16),(189221,'73377','watch','block-189219','account\\AccountLink','',17),(189222,'73378','watch','block-189219','account\\AccountLink','',18),(189223,'73379','watch','block-189219','account\\AccountLink','',1),(189224,'73380','watch','block-189219','Html_box','',2),(189225,'73381','watch','block-189219','account\\AccountLink','',4),(189226,'73382','watch','block-189219','account\\AccountLink','',7),(189227,'73383','watch','block-189219','account\\AccountLink','',11),(189228,'73384','watch','block-189219','Html_box','',6),(189229,'73385','watch','block-189219','account\\AccountLink','',3),(189230,'73386','watch','block-189219','account\\AccountLink','',14),(189231,'73387','watch','block-189219','account\\AccountLink','',8),(189232,'73388','watch','block-189219','account\\AccountLink','',5),(189233,'73389','watch','block-189219','account\\AccountLink','',9),(189234,'73390','watch','block-189219','account\\AccountLink','',12),(189235,'73391','watch','block-189219','Html_box','',10),(189236,'73392','watch','block-189219','account\\AccountLink','',15),(189237,'1713774134.555525','watch','block-189216-2','Html_box','',1),(189238,'1713774134.558117','watch','block-189216-2','account\\EditAddress','',2),(189239,'1713774279.864294','furniture','account','BlockBox','',0),(189240,'1713774279.969680','furniture','block-189239','BlockBox','',1),(189241,'1713774279.971753','furniture','block-189240','WidgetsAria','',1),(189261,'1713774280.297397','furniture','block-189240-2','BlockBox','account-content',1),(189262,'1713774280.298583','furniture','block-189261','account\\OrdersHistory','',5),(189263,'1713774280.300742','furniture','block-189261','Html_box','',4),(189264,'1713774280.304538','furniture','block-189261','Html_box','',1),(189265,'1713774280.32165','furniture','block-189261','BlockBox','account-content-top',2),(189266,'1713774280.334674','furniture','block-189265','BlockBox','',1),(189267,'1713774280.336154','furniture','block-189266','Html_box','',1),(189268,'1713774280.341288','furniture','block-189266','account\\LastOrder','',2),(189269,'1713774280.35188','furniture','block-189265','BlockBox','',2),(189270,'1713774280.352867','furniture','block-189269','Html_box','',1),(189271,'1713774280.356398','furniture','block-189269','account\\OrderCount','',2),(189272,'1713774280.357628','furniture','block-189269','account\\AccountLink','',3),(189273,'1713774280.359356','furniture','block-189265','BlockBox','',3),(189274,'1713774280.360175','furniture','block-189273','Html_box','',1),(189275,'1713774280.362861','furniture','block-189273','account\\TotalOrdered','',2),(189276,'1713774280.364168','furniture','block-189265','BlockBox','',4),(189277,'1713774280.36559','furniture','block-189276','Html_box','',1),(189278,'1713774280.367684','furniture','block-189276','account\\CreditAmount','',2),(189279,'1713774280.368994','furniture','block-189276','account\\AccountLink','',3),(189280,'1713774280.370288','furniture','block-189265','BlockBox','',5),(189281,'1713774280.3715','furniture','block-189280','account\\AccountLink','',3),(189282,'1713774280.372214','furniture','block-189280','BonusActions\\widgets\\PointsEarnt','',2),(189283,'1713774280.373397','furniture','block-189280','Html_box','',1),(189284,'1713774280.375920','furniture','review','BlockBox','',0),(189285,'1713774280.37681','furniture','block-189284','BlockBox','',1),(189286,'1713774280.377779','furniture','block-189285','WidgetsAria','',1),(189306,'1713774280.725312','furniture','block-189285-2','Html_box','',1),(189307,'1713774280.727712','furniture','block-189285-2','account\\Reviews','',2),(189308,'1713774280.733870','furniture','order_history_info','BlockBox','',0),(189309,'1713774280.76691','furniture','block-189308','BlockBox','',1),(189310,'1713774280.768459','furniture','block-189309','WidgetsAria','',1),(189330,'1713774281.071110','furniture','block-189309-2','account\\OrderInvoiceButton','',3),(189331,'1713774281.072459','furniture','block-189309-2','account\\OrderSubTotals','',10),(189332,'1713774281.073313','furniture','block-189309-2','account\\OrderPayButton','',5),(189333,'1713774281.074856','furniture','block-189309-2','BlockBox','',13),(189334,'1713774281.076345','furniture','block-189333','account\\AccountLink','',1),(189335,'1713774281.07759','furniture','block-189333-2','account\\OrderInvoiceButton','',1),(189336,'1713774281.078437','furniture','block-189309-2','Html_box','',8),(189337,'1713774281.080413','furniture','block-189309-2','account\\OrderHistory','',12),(189338,'1713774281.08131','furniture','block-189309-2','account\\OrderCancelAndReorder','',4),(189339,'1713774281.082594','furniture','block-189309-2','account\\OrderHeading','',1),(189340,'1713774281.083285','furniture','block-189309-2','account\\OrderDownload','',6),(189341,'1713774281.086740','furniture','block-189309-2','Html_box','',11),(189342,'1713774281.088888','furniture','block-189309-2','account\\OrderProducts','',9),(189343,'1713774281.089731','furniture','block-189309-2','account\\OrderReorderButton','',2),(189344,'1713774281.090797','furniture','block-189309-2','BlockBox','',7),(189345,'1713774281.092211','furniture','block-189344','BlockBox','',2),(189346,'1713774281.093966','furniture','block-189345','Html_box','',1),(189347,'1713774281.096334','furniture','block-189345','account\\OrderData','',2),(189348,'1713774281.097991','furniture','block-189344','BlockBox','',1),(189349,'1713774281.09931','furniture','block-189348','Html_box','',1),(189350,'1713774281.104376','furniture','block-189348','account\\OrderData','',2),(189351,'1713774281.105683','furniture','block-189344','BlockBox','',3),(189352,'1713774281.10733','furniture','block-189351','account\\OrderTracking','',2),(189353,'1713774281.108498','furniture','block-189351','Html_box','',1),(189354,'1713774281.11113','furniture','block-189351','account\\AccountLink','',3),(189355,'1713774281.113595','furniture','block-189344-2','BlockBox','',2),(189356,'1713774281.114856','furniture','block-189355','account\\OrderData','',2),(189357,'1713774281.116185','furniture','block-189355','Html_box','',1),(189358,'1713774281.118622','furniture','block-189344-2','BlockBox','',1),(189359,'1713774281.120129','furniture','block-189358','account\\OrderData','',2),(189360,'1713774281.121493','furniture','block-189358','Html_box','',1),(189361,'1713774281.123873','furniture','block-189344-3','BlockBox','',2),(189362,'1713774281.124980','furniture','block-189361','account\\OrderData','',2),(189363,'1713774281.126172','furniture','block-189361','Html_box','',1),(189364,'1713774281.128587','furniture','block-189344-3','BlockBox','',1),(189365,'1713774281.129973','furniture','block-189364','Html_box','',1),(189366,'1713774281.132385','furniture','block-189364','account\\OrderData','',2),(189367,'1713774281.133667','furniture','address_book','BlockBox','',0),(189368,'1713774281.13597','furniture','block-189367','BlockBox','',1),(189369,'1713774281.136347','furniture','block-189368','WidgetsAria','',1),(189389,'1713774281.475435','furniture','block-189368-2','account\\AddressBook','',3),(189390,'1713774281.489799','furniture','block-189368-2','Html_box','',1),(189391,'1713774281.493151','furniture','block-189368-2','Html_box','',2),(189392,'1713774281.496820','furniture','account_edit','BlockBox','',0),(189393,'1713774281.501632','furniture','block-189392','BlockBox','',1),(189394,'1713774281.503794','furniture','block-189393','WidgetsAria','',1),(189414,'1713774281.88924','furniture','block-189393-2','account\\AccountEdit','',2),(189415,'1713774281.890686','furniture','block-189393-2','Html_box','',1),(189416,'1713774281.907128','furniture','order_history','BlockBox','',0),(189417,'1713774281.953936','furniture','block-189416','BlockBox','',1),(189418,'1713774281.955250','furniture','block-189417','WidgetsAria','',1),(189438,'1713774282.25493','furniture','block-189417-2','Html_box','',1),(189439,'1713774282.257271','furniture','block-189417-2','account\\OrdersHistory','',2),(189440,'1713774282.2593','furniture','address_book_process','BlockBox','',0),(189441,'1713774282.263247','furniture','block-189440','BlockBox','',1),(189442,'1713774282.264620','furniture','block-189441','WidgetsAria','',1),(189443,'73374','furniture','account-menu','BlockBox','',1),(189444,'73375','furniture','block-189443','BlockBox','account-side',1),(189445,'73376','furniture','block-189444','Html_box','',16),(189446,'73377','furniture','block-189444','account\\AccountLink','',17),(189447,'73378','furniture','block-189444','account\\AccountLink','',18),(189448,'73379','furniture','block-189444','account\\AccountLink','',1),(189449,'73380','furniture','block-189444','Html_box','',2),(189450,'73381','furniture','block-189444','account\\AccountLink','',4),(189451,'73382','furniture','block-189444','account\\AccountLink','',7),(189452,'73383','furniture','block-189444','account\\AccountLink','',11),(189453,'73384','furniture','block-189444','Html_box','',6),(189454,'73385','furniture','block-189444','account\\AccountLink','',3),(189455,'73386','furniture','block-189444','account\\AccountLink','',14),(189456,'73387','furniture','block-189444','account\\AccountLink','',8),(189457,'73388','furniture','block-189444','account\\AccountLink','',5),(189458,'73389','furniture','block-189444','account\\AccountLink','',9),(189459,'73390','furniture','block-189444','account\\AccountLink','',12),(189460,'73391','furniture','block-189444','Html_box','',10),(189461,'73392','furniture','block-189444','account\\AccountLink','',15),(189462,'1713774282.668269','furniture','block-189441-2','Html_box','',1),(189463,'1713774282.671894','furniture','block-189441-2','account\\EditAddress','',2),(189464,'1713774291.283818','printshop','account','BlockBox','',0),(189465,'1713774291.388533','printshop','block-189464','BlockBox','',1),(189466,'1713774291.390348','printshop','block-189465','WidgetsAria','',1),(189486,'1713774291.784653','printshop','block-189465-2','BlockBox','account-content',1),(189487,'1713774291.785492','printshop','block-189486','account\\OrdersHistory','',5),(189488,'1713774291.78762','printshop','block-189486','Html_box','',4),(189489,'1713774291.78938','printshop','block-189486','Html_box','',1),(189490,'1713774291.799772','printshop','block-189486','BlockBox','account-content-top',2),(189491,'1713774291.806860','printshop','block-189490','BlockBox','',1),(189492,'1713774291.807965','printshop','block-189491','Html_box','',1),(189493,'1713774291.811922','printshop','block-189491','account\\LastOrder','',2),(189494,'1713774291.821577','printshop','block-189490','BlockBox','',2),(189495,'1713774291.822426','printshop','block-189494','Html_box','',1),(189496,'1713774291.82580','printshop','block-189494','account\\OrderCount','',2),(189497,'1713774291.82723','printshop','block-189494','account\\AccountLink','',3),(189498,'1713774291.829143','printshop','block-189490','BlockBox','',3),(189499,'1713774291.829944','printshop','block-189498','Html_box','',1),(189500,'1713774291.833740','printshop','block-189498','account\\TotalOrdered','',2),(189501,'1713774291.836366','printshop','block-189490','BlockBox','',4),(189502,'1713774291.837352','printshop','block-189501','Html_box','',1),(189503,'1713774291.840267','printshop','block-189501','account\\CreditAmount','',2),(189504,'1713774291.841825','printshop','block-189501','account\\AccountLink','',3),(189505,'1713774291.843244','printshop','block-189490','BlockBox','',5),(189506,'1713774291.844151','printshop','block-189505','account\\AccountLink','',3),(189507,'1713774291.84543','printshop','block-189505','BonusActions\\widgets\\PointsEarnt','',2),(189508,'1713774291.846868','printshop','block-189505','Html_box','',1),(189509,'1713774291.849925','printshop','review','BlockBox','',0),(189510,'1713774291.850917','printshop','block-189509','BlockBox','',1),(189511,'1713774291.851973','printshop','block-189510','WidgetsAria','',1),(189531,'1713774292.245647','printshop','block-189510-2','Html_box','',1),(189532,'1713774292.247937','printshop','block-189510-2','account\\Reviews','',2),(189533,'1713774292.252957','printshop','order_history_info','BlockBox','',0),(189534,'1713774292.285450','printshop','block-189533','BlockBox','',1),(189535,'1713774292.286894','printshop','block-189534','WidgetsAria','',1),(189555,'1713774292.692796','printshop','block-189534-2','account\\OrderInvoiceButton','',3),(189556,'1713774292.69390','printshop','block-189534-2','account\\OrderSubTotals','',10),(189557,'1713774292.69476','printshop','block-189534-2','account\\OrderPayButton','',5),(189558,'1713774292.695987','printshop','block-189534-2','BlockBox','',13),(189559,'1713774292.697287','printshop','block-189558','account\\AccountLink','',1),(189560,'1713774292.698396','printshop','block-189558-2','account\\OrderInvoiceButton','',1),(189561,'1713774292.699239','printshop','block-189534-2','Html_box','',8),(189562,'1713774292.701481','printshop','block-189534-2','account\\OrderHistory','',12),(189563,'1713774292.702227','printshop','block-189534-2','account\\OrderCancelAndReorder','',4),(189564,'1713774292.703612','printshop','block-189534-2','account\\OrderHeading','',1),(189565,'1713774292.70446','printshop','block-189534-2','account\\OrderDownload','',6),(189566,'1713774292.707596','printshop','block-189534-2','Html_box','',11),(189567,'1713774292.70989','printshop','block-189534-2','account\\OrderProducts','',9),(189568,'1713774292.71080','printshop','block-189534-2','account\\OrderReorderButton','',2),(189569,'1713774292.711955','printshop','block-189534-2','BlockBox','',7),(189570,'1713774292.713627','printshop','block-189569','BlockBox','',2),(189571,'1713774292.71538','printshop','block-189570','Html_box','',1),(189572,'1713774292.717332','printshop','block-189570','account\\OrderData','',2),(189573,'1713774292.718650','printshop','block-189569','BlockBox','',1),(189574,'1713774292.719949','printshop','block-189573','Html_box','',1),(189575,'1713774292.724311','printshop','block-189573','account\\OrderData','',2),(189576,'1713774292.725380','printshop','block-189569','BlockBox','',3),(189577,'1713774292.726372','printshop','block-189576','account\\OrderTracking','',2),(189578,'1713774292.727511','printshop','block-189576','Html_box','',1),(189579,'1713774292.729492','printshop','block-189576','account\\AccountLink','',3),(189580,'1713774292.731181','printshop','block-189569-2','BlockBox','',2),(189581,'1713774292.73246','printshop','block-189580','account\\OrderData','',2),(189582,'1713774292.733650','printshop','block-189580','Html_box','',1),(189583,'1713774292.735925','printshop','block-189569-2','BlockBox','',1),(189584,'1713774292.737241','printshop','block-189583','account\\OrderData','',2),(189585,'1713774292.73836','printshop','block-189583','Html_box','',1),(189586,'1713774292.740656','printshop','block-189569-3','BlockBox','',2),(189587,'1713774292.741632','printshop','block-189586','account\\OrderData','',2),(189588,'1713774292.742836','printshop','block-189586','Html_box','',1),(189589,'1713774292.744670','printshop','block-189569-3','BlockBox','',1),(189590,'1713774292.745537','printshop','block-189589','Html_box','',1),(189591,'1713774292.747421','printshop','block-189589','account\\OrderData','',2),(189592,'1713774292.748453','printshop','address_book','BlockBox','',0),(189593,'1713774292.749515','printshop','block-189592','BlockBox','',1),(189594,'1713774292.750418','printshop','block-189593','WidgetsAria','',1),(189614,'1713774293.082159','printshop','block-189593-2','account\\AddressBook','',3),(189615,'1713774293.096223','printshop','block-189593-2','Html_box','',1),(189616,'1713774293.098979','printshop','block-189593-2','Html_box','',2),(189617,'1713774293.102593','printshop','account_edit','BlockBox','',0),(189618,'1713774293.10637','printshop','block-189617','BlockBox','',1),(189619,'1713774293.107979','printshop','block-189618','WidgetsAria','',1),(189639,'1713774293.506233','printshop','block-189618-2','account\\AccountEdit','',2),(189640,'1713774293.507399','printshop','block-189618-2','Html_box','',1),(189641,'1713774293.523882','printshop','order_history','BlockBox','',0),(189642,'1713774293.577891','printshop','block-189641','BlockBox','',1),(189643,'1713774293.579253','printshop','block-189642','WidgetsAria','',1),(189663,'1713774293.893565','printshop','block-189642-2','Html_box','',1),(189664,'1713774293.895793','printshop','block-189642-2','account\\OrdersHistory','',2),(189665,'1713774293.897327','printshop','address_book_process','BlockBox','',0),(189666,'1713774293.900863','printshop','block-189665','BlockBox','',1),(189667,'1713774293.90289','printshop','block-189666','WidgetsAria','',1),(189668,'73374','printshop','account-menu','BlockBox','',1),(189669,'73375','printshop','block-189668','BlockBox','account-side',1),(189670,'73376','printshop','block-189669','Html_box','',16),(189671,'73377','printshop','block-189669','account\\AccountLink','',17),(189672,'73378','printshop','block-189669','account\\AccountLink','',18),(189673,'73379','printshop','block-189669','account\\AccountLink','',1),(189674,'73380','printshop','block-189669','Html_box','',2),(189675,'73381','printshop','block-189669','account\\AccountLink','',4),(189676,'73382','printshop','block-189669','account\\AccountLink','',7),(189677,'73383','printshop','block-189669','account\\AccountLink','',11),(189678,'73384','printshop','block-189669','Html_box','',6),(189679,'73385','printshop','block-189669','account\\AccountLink','',3),(189680,'73386','printshop','block-189669','account\\AccountLink','',14),(189681,'73387','printshop','block-189669','account\\AccountLink','',8),(189682,'73388','printshop','block-189669','account\\AccountLink','',5),(189683,'73389','printshop','block-189669','account\\AccountLink','',9),(189684,'73390','printshop','block-189669','account\\AccountLink','',12),(189685,'73391','printshop','block-189669','Html_box','',10),(189686,'73392','printshop','block-189669','account\\AccountLink','',15),(189687,'1713774294.238947','printshop','block-189666-2','Html_box','',1),(189688,'1713774294.241221','printshop','block-189666-2','account\\EditAddress','',2),(189689,'1713774302.070365','deals','account','BlockBox','',0),(189690,'1713774302.241660','deals','block-189689','BlockBox','',1),(189691,'1713774302.243252','deals','block-189690','WidgetsAria','',1),(189711,'1713774302.55728','deals','block-189690-2','BlockBox','account-content',1),(189712,'1713774302.558125','deals','block-189711','account\\OrdersHistory','',5),(189713,'1713774302.559810','deals','block-189711','Html_box','',4),(189714,'1713774302.562282','deals','block-189711','Html_box','',1),(189715,'1713774302.575318','deals','block-189711','BlockBox','account-content-top',2),(189716,'1713774302.583346','deals','block-189715','BlockBox','',1),(189717,'1713774302.584585','deals','block-189716','Html_box','',1),(189718,'1713774302.588956','deals','block-189716','account\\LastOrder','',2),(189719,'1713774302.599185','deals','block-189715','BlockBox','',2),(189720,'1713774302.600332','deals','block-189719','Html_box','',1),(189721,'1713774302.604146','deals','block-189719','account\\OrderCount','',2),(189722,'1713774302.605686','deals','block-189719','account\\AccountLink','',3),(189723,'1713774302.607525','deals','block-189715','BlockBox','',3),(189724,'1713774302.608552','deals','block-189723','Html_box','',1),(189725,'1713774302.611730','deals','block-189723','account\\TotalOrdered','',2),(189726,'1713774302.613318','deals','block-189715','BlockBox','',4),(189727,'1713774302.614257','deals','block-189726','Html_box','',1),(189728,'1713774302.618189','deals','block-189726','account\\CreditAmount','',2),(189729,'1713774302.619664','deals','block-189726','account\\AccountLink','',3),(189730,'1713774302.620964','deals','block-189715','BlockBox','',5),(189731,'1713774302.62216','deals','block-189730','account\\AccountLink','',3),(189732,'1713774302.623592','deals','block-189730','BonusActions\\widgets\\PointsEarnt','',2),(189733,'1713774302.625189','deals','block-189730','Html_box','',1),(189734,'1713774302.628368','deals','review','BlockBox','',0),(189735,'1713774302.629597','deals','block-189734','BlockBox','',1),(189736,'1713774302.630510','deals','block-189735','WidgetsAria','',1),(189756,'1713774302.942945','deals','block-189735-2','Html_box','',1),(189757,'1713774302.94546','deals','block-189735-2','account\\Reviews','',2),(189758,'1713774302.951148','deals','order_history_info','BlockBox','',0),(189759,'1713774302.98691','deals','block-189758','BlockBox','',1),(189760,'1713774302.987797','deals','block-189759','WidgetsAria','',1),(189780,'1713774303.355589','deals','block-189759-2','account\\OrderInvoiceButton','',3),(189781,'1713774303.356763','deals','block-189759-2','account\\OrderSubTotals','',10),(189782,'1713774303.357736','deals','block-189759-2','account\\OrderPayButton','',5),(189783,'1713774303.358932','deals','block-189759-2','BlockBox','',13),(189784,'1713774303.362185','deals','block-189783','account\\AccountLink','',1),(189785,'1713774303.365122','deals','block-189783-2','account\\OrderInvoiceButton','',1),(189786,'1713774303.366232','deals','block-189759-2','Html_box','',8),(189787,'1713774303.368612','deals','block-189759-2','account\\OrderHistory','',12),(189788,'1713774303.36967','deals','block-189759-2','account\\OrderCancelAndReorder','',4),(189789,'1713774303.371141','deals','block-189759-2','account\\OrderHeading','',1),(189790,'1713774303.372180','deals','block-189759-2','account\\OrderDownload','',6),(189791,'1713774303.374982','deals','block-189759-2','Html_box','',11),(189792,'1713774303.377716','deals','block-189759-2','account\\OrderProducts','',9),(189793,'1713774303.378529','deals','block-189759-2','account\\OrderReorderButton','',2),(189794,'1713774303.379873','deals','block-189759-2','BlockBox','',7),(189795,'1713774303.38143','deals','block-189794','BlockBox','',2),(189796,'1713774303.383169','deals','block-189795','Html_box','',1),(189797,'1713774303.385376','deals','block-189795','account\\OrderData','',2),(189798,'1713774303.386781','deals','block-189794','BlockBox','',1),(189799,'1713774303.387715','deals','block-189798','Html_box','',1),(189800,'1713774303.392348','deals','block-189798','account\\OrderData','',2),(189801,'1713774303.393461','deals','block-189794','BlockBox','',3),(189802,'1713774303.394715','deals','block-189801','account\\OrderTracking','',2),(189803,'1713774303.3963','deals','block-189801','Html_box','',1),(189804,'1713774303.39839','deals','block-189801','account\\AccountLink','',3),(189805,'1713774303.479','deals','block-189794-2','BlockBox','',2),(189806,'1713774303.401260','deals','block-189805','account\\OrderData','',2),(189807,'1713774303.402194','deals','block-189805','Html_box','',1),(189808,'1713774303.403789','deals','block-189794-2','BlockBox','',1),(189809,'1713774303.404787','deals','block-189808','account\\OrderData','',2),(189810,'1713774303.405697','deals','block-189808','Html_box','',1),(189811,'1713774303.407397','deals','block-189794-3','BlockBox','',2),(189812,'1713774303.408152','deals','block-189811','account\\OrderData','',2),(189813,'1713774303.409138','deals','block-189811','Html_box','',1),(189814,'1713774303.41090','deals','block-189794-3','BlockBox','',1),(189815,'1713774303.411821','deals','block-189814','Html_box','',1),(189816,'1713774303.413853','deals','block-189814','account\\OrderData','',2),(189817,'1713774303.414793','deals','address_book','BlockBox','',0),(189818,'1713774303.415755','deals','block-189817','BlockBox','',1),(189819,'1713774303.416744','deals','block-189818','WidgetsAria','',1),(189839,'1713774303.748485','deals','block-189818-2','account\\AddressBook','',3),(189840,'1713774303.759421','deals','block-189818-2','Html_box','',1),(189841,'1713774303.7624','deals','block-189818-2','Html_box','',2),(189842,'1713774303.76450','deals','account_edit','BlockBox','',0),(189843,'1713774303.768552','deals','block-189842','BlockBox','',1),(189844,'1713774303.770899','deals','block-189843','WidgetsAria','',1),(189864,'1713774304.060984','deals','block-189843-2','account\\AccountEdit','',2),(189865,'1713774304.061861','deals','block-189843-2','Html_box','',1),(189866,'1713774304.077962','deals','order_history','BlockBox','',0),(189867,'1713774304.184488','deals','block-189866','BlockBox','',1),(189868,'1713774304.186275','deals','block-189867','WidgetsAria','',1),(189888,'1713774304.463836','deals','block-189867-2','Html_box','',1),(189889,'1713774304.465929','deals','block-189867-2','account\\OrdersHistory','',2),(189890,'1713774304.467962','deals','address_book_process','BlockBox','',0),(189891,'1713774304.471135','deals','block-189890','BlockBox','',1),(189892,'1713774304.472570','deals','block-189891','WidgetsAria','',1),(189893,'73374','deals','account-menu','BlockBox','',1),(189894,'73375','deals','block-189893','BlockBox','account-side',1),(189895,'73376','deals','block-189894','Html_box','',16),(189896,'73377','deals','block-189894','account\\AccountLink','',17),(189897,'73378','deals','block-189894','account\\AccountLink','',18),(189898,'73379','deals','block-189894','account\\AccountLink','',1),(189899,'73380','deals','block-189894','Html_box','',2),(189900,'73381','deals','block-189894','account\\AccountLink','',4),(189901,'73382','deals','block-189894','account\\AccountLink','',7),(189902,'73383','deals','block-189894','account\\AccountLink','',11),(189903,'73384','deals','block-189894','Html_box','',6),(189904,'73385','deals','block-189894','account\\AccountLink','',3),(189905,'73386','deals','block-189894','account\\AccountLink','',14),(189906,'73387','deals','block-189894','account\\AccountLink','',8),(189907,'73388','deals','block-189894','account\\AccountLink','',5),(189908,'73389','deals','block-189894','account\\AccountLink','',9),(189909,'73390','deals','block-189894','account\\AccountLink','',12),(189910,'73391','deals','block-189894','Html_box','',10),(189911,'73392','deals','block-189894','account\\AccountLink','',15),(189912,'1713774304.752267','deals','block-189891-2','Html_box','',1),(189913,'1713774304.754680','deals','block-189891-2','account\\EditAddress','',2),(189914,'73349','origin','404','Html_box','',1),(189915,'73350','origin','account','BlockBox','',1),(189916,'73351','origin','block-189915','BlockBox','',1),(189917,'73352','origin','block-189916','WidgetsAria','',1),(189937,'1704978704.8413','origin','block-189916-2','BlockBox','account-content',1),(189938,'73353','origin','block-189937','account\\OrdersHistory','',5),(189939,'73354','origin','block-189937','Html_box','',4),(189940,'73357','origin','block-189937','Html_box','',1),(189941,'1705060269.3517','origin','block-189937','BlockBox','account-content-top',2),(189942,'1705060551.6998','origin','block-189941','BlockBox','',1),(189943,'73361','origin','block-189942','Html_box','',1),(189944,'73362','origin','block-189942','account\\LastOrder','',2),(189945,'1705060566.121','origin','block-189941','BlockBox','',2),(189946,'73363','origin','block-189945','Html_box','',1),(189947,'73364','origin','block-189945','account\\OrderCount','',2),(189948,'73365','origin','block-189945','account\\AccountLink','',3),(189949,'1705060582.9285','origin','block-189941','BlockBox','',3),(189950,'73366','origin','block-189949','Html_box','',1),(189951,'73367','origin','block-189949','account\\TotalOrdered','',2),(189952,'1705060591.4402','origin','block-189941','BlockBox','',4),(189953,'73368','origin','block-189952','Html_box','',1),(189954,'73369','origin','block-189952','account\\CreditAmount','',2),(189955,'73370','origin','block-189952','account\\AccountLink','',3),(189956,'1705060602.1936','origin','block-189941','BlockBox','',5),(189957,'73371','origin','block-189956','account\\AccountLink','',3),(189958,'73372','origin','block-189956','BonusActions\\widgets\\PointsEarnt','',2),(189959,'73373','origin','block-189956','Html_box','',1),(189979,'73393','origin','account_edit','BlockBox','',1),(189980,'73394','origin','block-189979','BlockBox','',1),(189981,'73395','origin','block-189980','WidgetsAria','',1),(190001,'73396','origin','block-189980-2','account\\AccountEdit','',2),(190002,'73397','origin','block-189980-2','Html_box','',1),(190003,'73398','origin','address_book','BlockBox','',1),(190004,'73399','origin','block-190003','BlockBox','',1),(190005,'73400','origin','block-190004','WidgetsAria','',1),(190025,'73401','origin','block-190004-2','account\\AddressBook','',3),(190026,'73402','origin','block-190004-2','Html_box','',1),(190027,'73403','origin','block-190004-2','Html_box','',2),(190028,'73404','origin','address_book_process','BlockBox','',1),(190029,'73405','origin','block-190028','BlockBox','',1),(190030,'73406','origin','block-190029','WidgetsAria','',1),(190050,'73407','origin','block-190029-2','Html_box','',1),(190051,'73408','origin','block-190029-2','account\\EditAddress','',2),(190052,'73409','origin','b2b','BlockBox','listing-item',1),(190053,'73410','origin','block-190052','BlockBox','',1),(190054,'73411','origin','block-190053','productListing\\image','',1),(190055,'73412','origin','block-190053-2','productListing\\description','',6),(190056,'73413','origin','block-190053-2','productListing\\model','',5),(190057,'73414','origin','block-190053-2','productListing\\attributes','',3),(190058,'73415','origin','block-190053-2','BlockBox','',4),(190059,'73416','origin','block-190058','BlockBox','',1),(190060,'73417','origin','block-190059','productListing\\price','',1),(190061,'73418','origin','block-190059-2','BonusActions\\widgets\\BonusPointsProductListing','',1),(190062,'73419','origin','block-190058-2','productListing\\qtyInput','',1),(190063,'73420','origin','block-190053-2','productListing\\name','',1),(190064,'73421','origin','block-190053-2','BlockBox','',2),(190065,'73422','origin','block-190064','productListing\\stock','',1),(190066,'73423','origin','block-190064-2','productListing\\rating','',1),(190067,'76000','origin','batch','BlockBox','',1),(190068,'76001','origin','block-190067','productListing\\attributes','',5),(190069,'76002','origin','block-190067','productListing\\price','',6),(190070,'76003','origin','block-190067','productListing\\name','',4),(190071,'76004','origin','block-190067','productListing\\image','',2),(190072,'76005','origin','block-190067','batchSelect','',1),(190073,'76006','origin','batch_selected','BlockBox','',1),(190074,'76007','origin','block-190073','BlockBox','',13),(190075,'76008','origin','block-190074','productListing\\image','',1),(190076,'76009','origin','block-190074-2','batchRemove','',1),(190077,'76010','origin','block-190074-2','productListing\\price','',3),(190078,'76011','origin','block-190074-2','productListing\\name','',2),(190079,'76012','origin','bbbbb','BlockBox','',1),(190080,'76013','origin','block-190079','BlockBox','',2),(190081,'76014','origin','block-190080','Filters','',1),(190082,'76015','origin','block-190080-2','BlockBox','',6),(190083,'76016','origin','block-190082','catalog\\CountsItems','',1),(190084,'76017','origin','block-190082-2','catalog\\Paging','',1),(190085,'76018','origin','block-190080-2','catalog\\Image','',1),(190086,'76019','origin','block-190080-2','Listing','',5),(190087,'76020','origin','block-190080-2','catalog\\ImageMapCategory','',3),(190088,'76021','origin','block-190080-2','BlockBox','',4),(190089,'76022','origin','block-190088','catalog\\ListingLook','',1),(190090,'76023','origin','block-190088','catalog\\CompareButton','',2),(190091,'76024','origin','block-190088','catalog\\ItemsOnPage','',4),(190092,'76025','origin','block-190088','catalog\\Sorting','',3),(190093,'76026','origin','block-190080-2','Categories','',2),(190094,'76027','origin','block-190079','catalog\\Title','',1),(190095,'1683124632.767746','origin','cart','BlockBox','',1),(190096,'1683124632.80670','origin','block-190095','BlockBox','',2),(190097,'1683124632.809680','origin','block-190096','BlockBox','cart-content',4),(190098,'1683124632.816335','origin','block-190096','BlockBox','',1),(190099,'1683124632.817623','origin','block-190098','cart\\Products','',2),(190100,'1683124632.818551','origin','block-190098','BlockBox','',1),(190101,'1683124632.820317','origin','block-190100','MultiCart\\CartSwitcher','',1),(190102,'1683124632.820914','origin','block-190100','MultiCart\\SaveCart','',2),(190103,'1683124632.822588','origin','block-190100-2','MultiCart\\Actions','',1),(190104,'1683124632.823175','origin','block-190098','BlockBox','',3),(190105,'1683124632.825245','origin','block-190104','cart\\CreditAmount','',1),(190106,'1683124632.825649','origin','block-190104-2','BonusActions\\widgets\\BonusPointsCart','',1),(190107,'1683124632.82683','origin','block-190096','BlockBox','',3),(190108,'1683124632.827413','origin','block-190107','cart\\GiveAway','',2),(190109,'1683124632.828374','origin','block-190107','Html_box','',1),(190110,'1683124632.829840','origin','block-190096','BlockBox','',5),(190111,'1683124632.831459','origin','block-190110','Html_box','',1),(190112,'1683124632.832592','origin','block-190110','cart\\ShippingEstimator','',2),(190113,'1683124632.833353','origin','block-190096-2','BlockBox','',1),(190114,'1683124632.834715','origin','block-190113','BlockBox','',2),(190115,'1683124632.835884','origin','block-190114','cart\\DiscountCoupon','',1),(190116,'1683124632.836532','origin','block-190114','Image','',4),(190117,'1683124632.844829','origin','block-190114','cart\\CheckoutBtn','',3),(190118,'1683124632.84681','origin','block-190114','cart\\OrderTotal','',2),(190119,'1683124632.846538','origin','block-190114','cart\\OrderTotal','',0),(190120,'1683124632.84726','origin','block-190113','Html_box','',1),(190121,'94658','origin','cart2','BlockBox','',2),(190122,'94659','origin','block-190121','cart\\CartTabs','',2),(190123,'94660','origin','block-190122','BlockBox','',1),(190124,'94661','origin','block-190123','BlockBox','',4),(190125,'94662','origin','block-190124','cart\\UpSell','6',2),(190126,'94663','origin','block-190124','Html_box','',1),(190127,'94664','origin','block-190123','BlockBox','',1),(190128,'94665','origin','block-190127','cart\\Products','',3),(190129,'94666','origin','block-190127','BlockBox','',2),(190130,'94667','origin','block-190129','MultiCart\\CartSwitcher','',1),(190131,'94668','origin','block-190129','MultiCart\\SaveCart','',2),(190132,'94669','origin','block-190129-2','MultiCart\\Actions','',1),(190133,'94670','origin','block-190123','BlockBox','',3),(190134,'94671','origin','block-190133','cart\\GiveAway','',2),(190135,'94672','origin','block-190133','Html_box','',1),(190136,'94673','origin','block-190123','BlockBox','',2),(190137,'94674','origin','block-190136','Html_box','',1),(190138,'94675','origin','block-190136','BlockBox','',2),(190139,'94676','origin','block-190138','cart\\DiscountCoupon','',1),(190140,'94677','origin','block-190138-2','cart\\CreditAmount','',1),(190141,'94678','origin','block-190138-3','BonusActions\\widgets\\BonusPointsCart','',1),(190142,'94679','origin','block-190123','BlockBox','',5),(190143,'94680','origin','block-190142','Html_box','',1),(190144,'94681','origin','block-190142','cart\\ShippingEstimator','',2),(190145,'94682','origin','block-190123-2','BlockBox','',1),(190146,'94683','origin','block-190145','Html_box','',1),(190147,'94684','origin','block-190145','BlockBox','',2),(190148,'94685','origin','block-190147','Image','',4),(190149,'94686','origin','block-190147','cart\\CheckoutBtn','',2),(190150,'94687','origin','block-190147','cart\\OrderTotal','',1),(190151,'73462','origin','categories','BlockBox','catalog-content',1),(190152,'73463','origin','block-190151','BlockBox','catalog-side',2),(190153,'73464','origin','block-190152','Filters','',1),(190154,'73465','origin','block-190152-2','Listing','',5),(190155,'73466','origin','block-190152-2','catalog\\Image','',1),(190156,'73467','origin','block-190152-2','BlockBox','',6),(190157,'73468','origin','block-190156','catalog\\CountsItems','',1),(190158,'73469','origin','block-190156-2','catalog\\Paging','',1),(190159,'73470','origin','block-190152-2','catalog\\ImageMapCategory','',3),(190160,'73471','origin','block-190152-2','Categories','',2),(190161,'73472','origin','block-190152-2','BlockBox','catalog-features',4),(190162,'73473','origin','block-190161','catalog\\ListingLook','',1),(190163,'73474','origin','block-190161','catalog\\CompareButton','',2),(190164,'73475','origin','block-190161','catalog\\ItemsOnPage','',4),(190165,'73476','origin','block-190161','catalog\\Sorting','',3),(190166,'73477','origin','block-190151','catalog\\Title','',1),(190167,'73478','origin','category','Categories','',1),(190168,'73479','origin','category','Listing','',4),(190169,'73480','origin','category','ListingFunctionality','',2),(190170,'73481','origin','category','PagingBar','',3),(190171,'73482','origin','category','PagingBar','',5),(190172,'94688','origin','category_2','BlockBox','',1),(190173,'94689','origin','block-190172','catalog\\Title','',1),(190174,'94690','origin','block-190172','BlockBox','',2),(190175,'94691','origin','block-190174','Filters','',1),(190176,'94692','origin','block-190174-2','catalog\\Image','',1),(190177,'94693','origin','block-190174-2','Listing','',5),(190178,'94694','origin','block-190174-2','BlockBox','',4),(190179,'94695','origin','block-190178','catalog\\Sorting','',3),(190180,'94696','origin','block-190178','catalog\\ItemsOnPage','',4),(190181,'94697','origin','block-190178','catalog\\CompareButton','',2),(190182,'94698','origin','block-190178','catalog\\ListingLook','',1),(190183,'94699','origin','block-190174-2','catalog\\ImageMapCategory','',3),(190184,'94700','origin','block-190174-2','Categories','',2),(190185,'94701','origin','block-190174-2','BlockBox','',6),(190186,'94702','origin','block-190185','catalog\\CountsItems','',1),(190187,'94703','origin','block-190185-2','catalog\\Paging','',1),(190188,'73483','origin','category_no_filters','BlockBox','',1),(190189,'73484','origin','block-190188','catalog\\Title','',1),(190190,'73485','origin','block-190188','Categories','',3),(190191,'73486','origin','block-190188','BlockBox','catalog-features',4),(190192,'73487','origin','block-190191','catalog\\ItemsOnPage','',4),(190193,'73488','origin','block-190191','catalog\\Sorting','',3),(190194,'73489','origin','block-190191','catalog\\CompareButton','',2),(190195,'73490','origin','block-190191','catalog\\ListingLook','',1),(190196,'73491','origin','block-190191','HeaderStock','',5),(190197,'73492','origin','block-190188','BlockBox','',6),(190198,'73493','origin','block-190197','catalog\\CountsItems','',1),(190199,'73494','origin','block-190197-2','catalog\\Paging','',1),(190200,'73495','origin','block-190188','Listing','',5),(190201,'73496','origin','block-190188','catalog\\Image','',2),(190202,'73497','origin','block-190188','catalog\\B2bAddButton','',7),(190203,'1683125852.345798','origin','checkout','BlockBox','',1),(190204,'1683125852.356555','origin','block-190203','BlockBox','',2),(190205,'1683125852.358412','origin','block-190204','BlockBox','',2),(190206,'1683125852.35982','origin','block-190205','BlockBox','checkout-comments',5),(190207,'1683125852.361569','origin','block-190206','checkout\\Comments','',2),(190208,'1683125852.362847','origin','block-190206','Html_box','',1),(190209,'1683125852.36485','origin','block-190205','BlockBox','checkout-discount',4),(190210,'1683125852.366422','origin','block-190209','Html_box','',1),(190211,'1683125852.367732','origin','block-190209','BlockBox','',2),(190212,'1683125852.36968','origin','block-190211','CouponsAndVauchers\\Checkout','',1),(190213,'1683125852.369745','origin','block-190211-2','checkout\\CreditAmount','',1),(190214,'1683125852.37045','origin','block-190211-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(190215,'1683125852.371233','origin','block-190205','BlockBox','checkout-shipping',2),(190216,'1683125852.37350','origin','block-190215','BlockBox','',3),(190217,'1683125852.374899','origin','block-190216','checkout\\ShippingChoice','',1),(190218,'1683125852.375685','origin','block-190215','Neighbour\\Checkout','',5),(190219,'1683125852.376557','origin','block-190215','BlockBox','',4),(190220,'1683125852.377637','origin','block-190219','BlockBox','',1),(190221,'1683125852.378829','origin','block-190220','checkout\\ShippingAddress','',2),(190222,'1683125852.379375','origin','block-190220','Html_box','',3),(190223,'1683125852.380323','origin','block-190220','checkout\\ContactInformation','',4),(190224,'1683125852.380722','origin','block-190220','UploadCustomerId\\UploadCustomerIdForm','',4),(190225,'1683125852.381183','origin','block-190219-2','BlockBox','',1),(190226,'1683125852.382226','origin','block-190225','checkout\\Shipping','',2),(190227,'1683125852.382635','origin','block-190225','DelayedDespatch\\Checkout','',3),(190228,'1683125852.383516','origin','block-190225','Html_box','',1),(190229,'1683125852.385278','origin','block-190215','Html_box','',2),(190230,'1683125852.386397','origin','block-190205','cart\\Products','',6),(190231,'1683125852.386970','origin','block-190205','checkout\\CreateAccount','',7),(190232,'1683125852.38820','origin','block-190205','BlockBox','checkout-payment',3),(190233,'1683125852.390244','origin','block-190232','Html_box','',1),(190234,'1683125852.391810','origin','block-190232','BlockBox','',2),(190235,'1683125852.393320','origin','block-190234','Html_box','',1),(190236,'1683125852.394747','origin','block-190234','checkout\\BillingAddress','',2),(190237,'1683125852.395767','origin','block-190234-2','BlockBox','',1),(190238,'1683125852.397129','origin','block-190237','checkout\\PaymentMethod','',2),(190239,'1683125852.398588','origin','block-190237','Html_box','',1),(190240,'1683125852.400291','origin','block-190205','BlockBox','',1),(190241,'1683125852.402237','origin','block-190240','checkout\\LoginOnForm','',0),(190242,'1683128325.0836','origin','block-190240','BlockBox','',1),(190243,'1683125852.403563','origin','block-190204-2','BlockBox','checkout-side',1),(190244,'1683125852.405625','origin','block-190243','Html_box','',6),(190245,'1683125852.407666','origin','block-190243','Html_box','',1),(190246,'1683125852.40885','origin','block-190243','checkout\\Terms','',5),(190247,'1683125852.409688','origin','block-190243','checkout\\Totals','',3),(190248,'1683125852.410151','origin','block-190243','checkout\\ContinueBtn','',4),(190249,'1683125852.412647','origin','block-190243','cart\\Products','',2),(190250,'73542','origin','checkout_confirmation','BlockBox','',1),(190251,'73543','origin','block-190250','checkout\\Totals','',8),(190252,'73544','origin','block-190250','Html_box','',5),(190253,'73545','origin','block-190250','checkout\\EditBtn','',6),(190254,'73546','origin','block-190250','BlockBox','',3),(190255,'73547','origin','block-190254','BlockBox','',1),(190256,'73548','origin','block-190255','Html_box','',1),(190257,'73549','origin','block-190255','checkout\\ShippingConfirm','',3),(190258,'73550','origin','block-190254-2','BlockBox','',1),(190259,'73551','origin','block-190258','checkout\\PaymentMethodConfirm','',3),(190260,'73552','origin','block-190258','Html_box','',1),(190261,'73553','origin','block-190250','checkout\\ConfirmBtn','',9),(190262,'73554','origin','block-190250','BlockBox','',2),(190263,'73555','origin','block-190262','BlockBox','',1),(190264,'73556','origin','block-190263','checkout\\ShippingAddressConfirm','',3),(190265,'73557','origin','block-190263','Html_box','',1),(190266,'73558','origin','block-190262-2','BlockBox','',1),(190267,'73559','origin','block-190266','Html_box','',1),(190268,'73560','origin','block-190266','checkout\\BillingAddressConfirm','',3),(190269,'73561','origin','block-190250','checkout\\ConfirmBtn','',4),(190270,'73562','origin','block-190250','cart\\Products','',7),(190271,'73576','origin','checkout_confirmation_no_shipping','BlockBox','',1),(190272,'73577','origin','block-190271','checkout\\ConfirmBtn','',9),(190273,'73578','origin','block-190271','BlockBox','',2),(190274,'73579','origin','block-190273','BlockBox','',1),(190275,'73580','origin','block-190274','Html_box','',1),(190276,'73581','origin','block-190274','checkout\\BillingAddressConfirm','',3),(190277,'73582','origin','block-190273-2','BlockBox','',1),(190278,'73583','origin','block-190277','Html_box','',1),(190279,'73584','origin','block-190277','checkout\\PaymentMethodConfirm','',3),(190280,'73585','origin','block-190271','checkout\\ConfirmBtn','',4),(190281,'73586','origin','block-190271','checkout\\Totals','',8),(190282,'73587','origin','block-190271','cart\\Products','',7),(190283,'73588','origin','block-190271','Html_box','',5),(190284,'73563','origin','checkout_confirmation_no_shipping_q','BlockBox','',1),(190285,'73564','origin','block-190284','quote\\Products','',4),(190286,'73565','origin','block-190284','checkout\\ConfirmBtn','',2),(190287,'73566','origin','block-190284','checkout\\ConfirmBtn','',6),(190288,'73567','origin','block-190284','BlockBox','',1),(190289,'73568','origin','block-190288','BlockBox','',1),(190290,'73569','origin','block-190289','checkout\\BillingAddressConfirm','',3),(190291,'73570','origin','block-190289','Html_box','',1),(190292,'73571','origin','block-190288-2','BlockBox','',1),(190293,'73572','origin','block-190292','checkout\\PaymentMethodConfirm','',3),(190294,'73573','origin','block-190292','Html_box','',1),(190295,'73574','origin','block-190284','Html_box','',3),(190296,'73575','origin','block-190284','checkout\\Totals','',5),(190297,'73589','origin','checkout_confirmation_q','BlockBox','',1),(190298,'73590','origin','block-190297','BlockBox','',1),(190299,'73591','origin','block-190298','BlockBox','',1),(190300,'73592','origin','block-190299','checkout\\ShippingAddressConfirm','',3),(190301,'73593','origin','block-190299','Html_box','',1),(190302,'73594','origin','block-190298-2','BlockBox','',1),(190303,'73595','origin','block-190302','checkout\\BillingAddressConfirm','',3),(190304,'73596','origin','block-190302','Html_box','',1),(190305,'73597','origin','block-190297','checkout\\Totals','',7),(190306,'73598','origin','block-190297','quote\\Products','',6),(190307,'73599','origin','block-190297','Html_box','',4),(190308,'73600','origin','block-190297','checkout\\EditBtn','',5),(190309,'73601','origin','block-190297','checkout\\ConfirmBtn','',8),(190310,'73602','origin','block-190297','checkout\\ConfirmBtn','',3),(190311,'73603','origin','block-190297','BlockBox','',2),(190312,'73604','origin','block-190311','BlockBox','',1),(190313,'73605','origin','block-190312','Html_box','',1),(190314,'73606','origin','block-190312','checkout\\ShippingConfirm','',3),(190315,'73607','origin','block-190311-2','BlockBox','',1),(190316,'73608','origin','block-190315','Html_box','',1),(190317,'73609','origin','block-190315','checkout\\PaymentMethodConfirm','',3),(190318,'73610','origin','checkout_confirmation_title','Html_box','',1),(190319,'73611','origin','checkout_confirmation_title_g','Html_box','',1),(190320,'73613','origin','checkout_confirmation_title_no_shipping','Html_box','',1),(190321,'73612','origin','checkout_confirmation_title_no_shipping_g','Html_box','',1),(190322,'73614','origin','checkout_confirmation_title_q','Html_box','',1),(190323,'73615','origin','checkout_confirmation_title_s','Html_box','',1),(190324,'73616','origin','checkout_delivery','BlockBox','',2),(190325,'73617','origin','block-190324','BlockBox','',1),(190326,'73618','origin','block-190325','Html_box','',1),(190327,'73619','origin','block-190325','checkout\\ContactInformation','',2),(190328,'73620','origin','block-190324-2','BlockBox','',1),(190329,'73621','origin','block-190328','Html_box','',1),(190330,'73622','origin','block-190328','checkout\\Comments','',2),(190331,'73623','origin','checkout_delivery','BlockBox','',3),(190332,'73624','origin','block-190331','Html_box','',1),(190333,'73625','origin','block-190331-2','checkout\\ContinueBtn','',1),(190334,'73626','origin','checkout_delivery','BlockBox','',1),(190335,'73627','origin','block-190334','BlockBox','',1),(190336,'73628','origin','block-190335','Html_box','',1),(190337,'73629','origin','block-190335','checkout\\ShippingAddress','',2),(190338,'73630','origin','block-190334-2','BlockBox','',1),(190339,'73631','origin','block-190338','DelayedDespatch\\Checkout','',3),(190340,'73632','origin','block-190338','checkout\\Shipping','',2),(190341,'73633','origin','block-190338','Html_box','',1),(190342,'73634','origin','block-190338','Neighbour\\Checkout','',4),(190343,'73635','origin','checkout_delivery_g','BlockBox','',2),(190344,'73636','origin','block-190343','BlockBox','',1),(190345,'73637','origin','block-190344','checkout\\ContactInformation','',2),(190346,'73638','origin','block-190344','Html_box','',1),(190347,'73639','origin','block-190343-2','BlockBox','',1),(190348,'73640','origin','block-190347','Html_box','',1),(190349,'73641','origin','block-190347','checkout\\Comments','',2),(190350,'73642','origin','checkout_delivery_g','BlockBox','',3),(190351,'73643','origin','block-190350','Html_box','',1),(190352,'73644','origin','block-190350-2','checkout\\ContinueBtn','',1),(190353,'73645','origin','checkout_delivery_g','BlockBox','',1),(190354,'73646','origin','block-190353','BlockBox','',1),(190355,'73647','origin','block-190354','checkout\\ShippingAddress','',2),(190356,'73648','origin','block-190354','Html_box','',1),(190357,'73649','origin','block-190353-2','BlockBox','',1),(190358,'73650','origin','block-190357','checkout\\Shipping','',2),(190359,'73651','origin','block-190357','Html_box','',1),(190360,'73652','origin','block-190357','DelayedDespatch\\Checkout','',3),(190361,'73653','origin','block-190357','Neighbour\\Checkout','',4),(190362,'73654','origin','checkout_delivery_no_shipping','BlockBox','',2),(190363,'73655','origin','block-190362','Html_box','',1),(190364,'73656','origin','block-190362-2','checkout\\ContinueBtn','',1),(190365,'73657','origin','checkout_delivery_no_shipping','BlockBox','',1),(190366,'73658','origin','block-190365','BlockBox','',1),(190367,'73659','origin','block-190366','checkout\\ContactInformation','',2),(190368,'73660','origin','block-190365-2','BlockBox','',1),(190369,'73661','origin','block-190368','Html_box','',1),(190370,'73662','origin','block-190368','checkout\\Comments','',2),(190371,'73663','origin','checkout_delivery_no_shipping_g','BlockBox','',2),(190372,'73664','origin','block-190371','Html_box','',1),(190373,'73665','origin','block-190371-2','checkout\\ContinueBtn','',1),(190374,'73666','origin','checkout_delivery_no_shipping_g','BlockBox','',1),(190375,'73667','origin','block-190374','BlockBox','',1),(190376,'73668','origin','block-190375','checkout\\ContactInformation','',2),(190377,'73669','origin','block-190374-2','BlockBox','',1),(190378,'73670','origin','block-190377','checkout\\Comments','',2),(190379,'73671','origin','block-190377','Html_box','',1),(190380,'73672','origin','checkout_delivery_title','Html_box','',1),(190381,'73673','origin','checkout_delivery_title_g','Html_box','',1),(190382,'73675','origin','checkout_delivery_title_no_shipping','Html_box','',1),(190383,'73674','origin','checkout_delivery_title_no_shipping_g','Html_box','',1),(190384,'73676','origin','checkout_delivery_title_q','Html_box','',1),(190385,'73677','origin','checkout_delivery_title_s','Html_box','',1),(190386,'73678','origin','checkout_free_s','BlockBox','',1),(190387,'73679','origin','block-190386','BlockBox','',2),(190388,'73680','origin','block-190387','BlockBox','',2),(190389,'73682','origin','block-190388','BlockBox','',6),(190390,'73683','origin','block-190389','sample\\Products','',1),(190391,'73684','origin','block-190389','checkout\\CreateAccount','',3),(190392,'73685','origin','block-190388','BlockBox','',5),(190393,'73686','origin','block-190392','Html_box','',1),(190394,'73687','origin','block-190392','checkout\\Comments','',2),(190395,'73688','origin','block-190388','BlockBox','',2),(190396,'73689','origin','block-190395','BlockBox','',2),(190397,'73690','origin','block-190396','checkout\\ShippingChoice','',1),(190398,'73691','origin','block-190395','Html_box','',1),(190399,'73692','origin','block-190395','BlockBox','',3),(190400,'73693','origin','block-190399','BlockBox','',1),(190401,'73694','origin','block-190400','checkout\\ContactInformation','',4),(190402,'73695','origin','block-190400','checkout\\ShippingAddress','',2),(190403,'73696','origin','block-190400','Html_box','',3),(190404,'73697','origin','block-190399-2','BlockBox','',1),(190405,'73698','origin','block-190404','DelayedDespatch\\Checkout','',3),(190406,'73699','origin','block-190395','Neighbour\\Checkout','',4),(190407,'73700','origin','block-190387-2','BlockBox','',1),(190408,'73701','origin','block-190407','Html_box','',3),(190409,'73702','origin','block-190407','checkout\\ContinueBtn','',1),(190410,'115999','origin','block-190407','checkout\\Terms','',2),(190411,'73703','origin','checkout_no_shipping','BlockBox','',1),(190412,'73704','origin','block-190411','BlockBox','',2),(190413,'73705','origin','block-190412','BlockBox','',1),(190414,'73706','origin','block-190413','BlockBox','',6),(190415,'73707','origin','block-190414','checkout\\CreateAccount','',2),(190416,'73708','origin','block-190414','cart\\Products','',1),(190417,'73709','origin','block-190413','BlockBox','',3),(190418,'73710','origin','block-190417','Html_box','',1),(190419,'73711','origin','block-190417','BlockBox','',2),(190420,'73712','origin','block-190419','checkout\\BillingAddress','',2),(190421,'73713','origin','block-190419','Html_box','',1),(190422,'73714','origin','block-190419-2','BlockBox','',1),(190423,'73715','origin','block-190422','Html_box','',1),(190424,'73716','origin','block-190422','checkout\\PaymentMethod','',2),(190425,'73717','origin','block-190413','BlockBox','',4),(190426,'73718','origin','block-190425','BlockBox','',2),(190427,'73719','origin','block-190426','CouponsAndVauchers\\Checkout','',1),(190428,'73720','origin','block-190426-2','checkout\\CreditAmount','',1),(190429,'73721','origin','block-190426-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(190430,'73722','origin','block-190425','Html_box','',1),(190431,'73723','origin','block-190413','BlockBox','',5),(190432,'73724','origin','block-190431','checkout\\Comments','',2),(190433,'73725','origin','block-190431','Html_box','',1),(190434,'73726','origin','block-190412-2','BlockBox','',1),(190435,'73727','origin','block-190434','Html_box','',1),(190436,'73728','origin','block-190434','Html_box','',5),(190437,'73729','origin','block-190434','checkout\\Totals','',2),(190438,'73730','origin','block-190434','checkout\\ContinueBtn','',3),(190439,'73731','origin','block-190434','checkout\\Terms','',4),(190440,'73732','origin','checkout_no_shipping_g','BlockBox','',1),(190441,'73733','origin','block-190440','checkout\\Totals','',5),(190442,'73734','origin','block-190440','BlockBox','',6),(190443,'73735','origin','block-190442','Html_box','',1),(190444,'73736','origin','block-190442-2','checkout\\ContinueBtn','',1),(190445,'73737','origin','block-190440','BlockBox','',2),(190446,'73738','origin','block-190445','BlockBox','',1),(190447,'73739','origin','block-190446','checkout\\ContactInformation','',2),(190448,'73740','origin','block-190446','Html_box','',1),(190449,'73741','origin','block-190445-2','BlockBox','',1),(190450,'73742','origin','block-190449','checkout\\Comments','',2),(190451,'73743','origin','block-190449','Html_box','',1),(190452,'73744','origin','block-190440','BlockBox','',1),(190453,'73745','origin','block-190452','BlockBox','',1),(190454,'73746','origin','block-190453','Html_box','',1),(190455,'73747','origin','block-190453','checkout\\BillingAddress','',2),(190456,'73748','origin','block-190452-2','BlockBox','',1),(190457,'73749','origin','block-190456','BonusActions\\widgets\\BonusPointsCheckout','',4),(190458,'73750','origin','block-190456','CouponsAndVauchers\\Checkout','',5),(190459,'73751','origin','block-190456','checkout\\PaymentMethod','',2),(190460,'73752','origin','block-190456','checkout\\CreditAmount','',3),(190461,'73753','origin','block-190456','Html_box','',1),(190462,'73754','origin','block-190440','quote\\Products','',3),(190463,'73755','origin','checkout_no_shipping_q','BlockBox','',1),(190464,'73756','origin','block-190463','BlockBox','',2),(190465,'73757','origin','block-190464','BlockBox','',2),(190466,'73758','origin','block-190465','checkout\\Gdpr','',1),(190467,'73759','origin','block-190465','BlockBox','',5),(190468,'73760','origin','block-190467','checkout\\Comments','',2),(190469,'73761','origin','block-190467','Html_box','',1),(190470,'73762','origin','block-190465','BlockBox','',6),(190471,'73763','origin','block-190470','checkout\\CreateAccount','',3),(190472,'73764','origin','block-190470','quote\\Products','',2),(190473,'73765','origin','block-190465','BlockBox','',3),(190474,'73766','origin','block-190473','Html_box','',1),(190475,'73767','origin','block-190473','BlockBox','',2),(190476,'73768','origin','block-190475','Html_box','',1),(190477,'73769','origin','block-190475','checkout\\BillingAddress','',2),(190478,'73770','origin','block-190475-2','BlockBox','',1),(190479,'73771','origin','block-190478','checkout\\PaymentMethod','',2),(190480,'73772','origin','block-190478','Html_box','',1),(190481,'73773','origin','block-190464-2','BlockBox','',1),(190482,'73774','origin','block-190481','checkout\\ContinueBtn','',3),(190483,'73775','origin','block-190481','Html_box','',4),(190484,'73776','origin','block-190481','Html_box','',1),(190485,'73777','origin','block-190481','checkout\\Totals','',2),(190486,'73778','origin','checkout_payment','BlockBox','',1),(190487,'73779','origin','block-190486','BlockBox','',1),(190488,'73780','origin','block-190487','checkout\\BillingAddress','',2),(190489,'73781','origin','block-190487','Html_box','',1),(190490,'73782','origin','block-190486-2','BlockBox','',1),(190491,'73783','origin','block-190490','checkout\\CreditAmount','',3),(190492,'73784','origin','block-190490','BonusActions\\widgets\\BonusPointsCheckout','',4),(190493,'73785','origin','block-190490','CouponsAndVauchers\\Checkout','',5),(190494,'73786','origin','block-190490','checkout\\PaymentMethod','',2),(190495,'73787','origin','block-190490','Html_box','',1),(190496,'73788','origin','checkout_payment','BlockBox','',2),(190497,'73789','origin','block-190496','Html_box','',1),(190498,'73790','origin','block-190496-2','checkout\\ContinueBtn','',1),(190499,'73791','origin','checkout_payment_g','BlockBox','',1),(190500,'73792','origin','block-190499','BlockBox','',1),(190501,'73793','origin','block-190500','checkout\\BillingAddress','',2),(190502,'73794','origin','block-190500','Html_box','',1),(190503,'73795','origin','block-190499-2','BlockBox','',1),(190504,'73796','origin','block-190503','checkout\\CreditAmount','',3),(190505,'73797','origin','block-190503','Html_box','',1),(190506,'73798','origin','block-190503','checkout\\PaymentMethod','',2),(190507,'73799','origin','block-190503','CouponsAndVauchers\\Checkout','',5),(190508,'73800','origin','block-190503','BonusActions\\widgets\\BonusPointsCheckout','',4),(190509,'73801','origin','checkout_payment_g','BlockBox','',2),(190510,'73802','origin','block-190509','Html_box','',1),(190511,'73803','origin','block-190509-2','checkout\\ContinueBtn','',1),(190512,'73804','origin','checkout_payment_no_shipping','BlockBox','',2),(190513,'73805','origin','block-190512','Html_box','',1),(190514,'73806','origin','block-190512-2','checkout\\ContinueBtn','',1),(190515,'73807','origin','checkout_payment_no_shipping','BlockBox','',1),(190516,'73808','origin','block-190515','BlockBox','',1),(190517,'73809','origin','block-190516','Html_box','',1),(190518,'73810','origin','block-190516','checkout\\BillingAddress','',2),(190519,'73811','origin','block-190515-2','BlockBox','',1),(190520,'73812','origin','block-190519','BonusActions\\widgets\\BonusPointsCheckout','',4),(190521,'73813','origin','block-190519','CouponsAndVauchers\\Checkout','',5),(190522,'73814','origin','block-190519','checkout\\PaymentMethod','',2),(190523,'73815','origin','block-190519','checkout\\CreditAmount','',3),(190524,'73816','origin','block-190519','Html_box','',1),(190525,'73817','origin','checkout_payment_no_shipping_g','BlockBox','',2),(190526,'73818','origin','block-190525','Html_box','',1),(190527,'73819','origin','block-190525-2','checkout\\ContinueBtn','',1),(190528,'73820','origin','checkout_payment_no_shipping_g','BlockBox','',1),(190529,'73821','origin','block-190528','BlockBox','',1),(190530,'73822','origin','block-190529','checkout\\BillingAddress','',2),(190531,'73823','origin','block-190529','Html_box','',1),(190532,'73824','origin','block-190528-2','BlockBox','',1),(190533,'73825','origin','block-190532','BonusActions\\widgets\\BonusPointsCheckout','',4),(190534,'73826','origin','block-190532','checkout\\CreditAmount','',3),(190535,'73827','origin','block-190532','checkout\\PaymentMethod','',2),(190536,'73828','origin','block-190532','Html_box','',1),(190537,'73829','origin','block-190532','CouponsAndVauchers\\Checkout','',5),(190538,'73830','origin','checkout_payment_title','Html_box','',1),(190539,'73831','origin','checkout_payment_title_g','Html_box','',1),(190540,'73832','origin','checkout_payment_title_no_shipping','Html_box','',1),(190541,'73833','origin','checkout_payment_title_no_shipping_g','Html_box','',1),(190542,'73834','origin','checkout_payment_title_q','Html_box','',1),(190543,'73835','origin','checkout_payment_title_s','Html_box','',1),(190544,'73836','origin','checkout_q','BlockBox','',1),(190545,'73837','origin','block-190544','BlockBox','',2),(190546,'73838','origin','block-190545','BlockBox','',2),(190547,'73839','origin','block-190546','BlockBox','',6),(190548,'73840','origin','block-190547','checkout\\CreateAccount','',3),(190549,'73841','origin','block-190547','quote\\Products','',2),(190550,'73842','origin','block-190546','BlockBox','',2),(190551,'73843','origin','block-190550','BlockBox','',2),(190552,'73844','origin','block-190551','checkout\\ShippingChoice','',1),(190553,'73845','origin','block-190550','Neighbour\\Checkout','',4),(190554,'73846','origin','block-190550','Html_box','',1),(190555,'73847','origin','block-190550','BlockBox','',3),(190556,'73848','origin','block-190555','BlockBox','',1),(190557,'73849','origin','block-190556','checkout\\ContactInformation','',4),(190558,'73850','origin','block-190556','checkout\\ShippingAddress','',2),(190559,'73851','origin','block-190556','Html_box','',3),(190560,'73852','origin','block-190555-2','BlockBox','',1),(190561,'73853','origin','block-190560','checkout\\Shipping','',2),(190562,'73854','origin','block-190560','Html_box','',1),(190563,'73855','origin','block-190560','DelayedDespatch\\Checkout','',3),(190564,'73856','origin','block-190546','BlockBox','',5),(190565,'73857','origin','block-190564','Html_box','',1),(190566,'73858','origin','block-190564','checkout\\Comments','',2),(190567,'73860','origin','block-190546','BlockBox','',3),(190568,'73861','origin','block-190567','Html_box','',1),(190569,'73862','origin','block-190567','BlockBox','',2),(190570,'73863','origin','block-190569','checkout\\BillingAddress','',2),(190571,'73864','origin','block-190569','Html_box','',1),(190572,'73865','origin','block-190569-2','BlockBox','',1),(190573,'73866','origin','block-190572','checkout\\PaymentMethod','',2),(190574,'73867','origin','block-190572','Html_box','',1),(190575,'73868','origin','block-190545-2','BlockBox','',1),(190576,'73869','origin','block-190575','Html_box','',1),(190577,'73870','origin','block-190575','Html_box','',5),(190578,'73871','origin','block-190575','checkout\\Totals','',2),(190579,'73872','origin','block-190575','checkout\\ContinueBtn','',3),(190580,'115996','origin','block-190575','checkout\\Terms','',4),(190581,'73873','origin','checkout_s','BlockBox','',1),(190582,'73874','origin','block-190581','BlockBox','',2),(190583,'73875','origin','block-190582','BlockBox','',2),(190584,'73876','origin','block-190583','checkout\\Gdpr','',1),(190585,'73877','origin','block-190583','BlockBox','',6),(190586,'73878','origin','block-190585','sample\\Products','',1),(190587,'73879','origin','block-190585','checkout\\CreateAccount','',3),(190588,'73880','origin','block-190583','BlockBox','',2),(190589,'73881','origin','block-190588','Html_box','',1),(190590,'73882','origin','block-190588','Neighbour\\Checkout','',4),(190591,'73883','origin','block-190588','BlockBox','',2),(190592,'73884','origin','block-190591','checkout\\ShippingChoice','',1),(190593,'73885','origin','block-190588','BlockBox','',3),(190594,'73886','origin','block-190593','BlockBox','',1),(190595,'73887','origin','block-190594','checkout\\ShippingAddress','',2),(190596,'73888','origin','block-190594','checkout\\ContactInformation','',4),(190597,'73889','origin','block-190594','Html_box','',3),(190598,'73890','origin','block-190593-2','BlockBox','',1),(190599,'73891','origin','block-190598','checkout\\Shipping','',2),(190600,'73892','origin','block-190598','DelayedDespatch\\Checkout','',3),(190601,'73893','origin','block-190598','Html_box','',1),(190602,'73894','origin','block-190583','BlockBox','',3),(190603,'73895','origin','block-190602','BlockBox','',2),(190604,'73896','origin','block-190603','Html_box','',1),(190605,'73897','origin','block-190603','checkout\\BillingAddress','',2),(190606,'73898','origin','block-190603-2','BlockBox','',1),(190607,'73899','origin','block-190606','Html_box','',1),(190608,'73900','origin','block-190606','checkout\\PaymentMethod','',2),(190609,'73901','origin','block-190602','Html_box','',1),(190610,'73902','origin','block-190583','BlockBox','',5),(190611,'73903','origin','block-190610','Html_box','',1),(190612,'73904','origin','block-190610','checkout\\Comments','',2),(190613,'73905','origin','block-190583','BlockBox','',4),(190614,'73906','origin','block-190613','BlockBox','',2),(190615,'73907','origin','block-190614','CouponsAndVauchers\\Checkout','',1),(190616,'73908','origin','block-190614-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(190617,'73909','origin','block-190614-2','checkout\\CreditAmount','',1),(190618,'73910','origin','block-190613','Html_box','',1),(190619,'73911','origin','block-190582-2','BlockBox','',1),(190620,'73912','origin','block-190619','checkout\\Totals','',2),(190621,'73913','origin','block-190619','Html_box','',5),(190622,'73914','origin','block-190619','Html_box','',1),(190623,'73915','origin','block-190619','checkout\\ContinueBtn','',3),(190624,'115998','origin','block-190619','checkout\\Terms','',4),(190625,'73916','origin','checkout_step_bottom','Html_box','',1),(190626,'73917','origin','checkout_step_bottom','cart\\Products','',2),(190627,'73918','origin','checkout_step_bottom','checkout\\Totals','',3),(190628,'73919','origin','checkout_step_bottom_g','checkout\\Totals','',3),(190629,'73920','origin','checkout_step_bottom_g','quote\\Products','',2),(190630,'73921','origin','checkout_step_bottom_g','Html_box','',1),(190631,'73923','origin','checkout_step_bottom_no_shipping','Html_box','',1),(190632,'73924','origin','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(190633,'73927','origin','checkout_step_bottom_no_shipping','cart\\Products','',2),(190634,'73922','origin','checkout_step_bottom_no_shipping_g','Html_box','',1),(190635,'73925','origin','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(190636,'73926','origin','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(190637,'73928','origin','communication','BlockBox','',1),(190638,'73929','origin','block-190637','Html_box','',2),(190639,'73930','origin','block-190637','Communication\\NewTopicButton','',1),(190640,'73931','origin','block-190637','Communication\\Topic','',3),(190641,'94704','origin','compare','BlockBox','',1),(190642,'94705','origin','block-190641','catalog\\Compare','',1),(190643,'94706','origin','compare_products','BlockBox','',2),(190644,'94707','origin','block-190643','productListing\\rating','',4),(190645,'94708','origin','block-190643','productListing\\model','',5),(190646,'94709','origin','block-190643','productListing\\compare','',1),(190647,'94710','origin','block-190643','BlockBox','',2),(190648,'94711','origin','block-190647','productListing\\image','',1),(190649,'94712','origin','block-190647-2','productListing\\name','',2),(190650,'94713','origin','block-190643','BlockBox','',3),(190651,'94714','origin','block-190650','productListing\\price','',1),(190652,'94715','origin','block-190650-2','productListing\\buyButton','',1),(190653,'73932','origin','confirmation','BlockBox','',1),(190654,'73933','origin','block-190653','BlockBox','',2),(190655,'73934','origin','block-190654','BlockBox','',2),(190656,'73935','origin','block-190655','BlockBox','',3),(190657,'73936','origin','block-190656','checkout\\EditBtn','',2),(190658,'73937','origin','block-190656','cart\\Products','',3),(190659,'73938','origin','block-190656','Html_box','',1),(190660,'73939','origin','block-190655','BlockBox','',2),(190661,'73940','origin','block-190660','checkout\\EditBtn','',2),(190662,'73941','origin','block-190660','Html_box','',1),(190663,'73942','origin','block-190660','checkout\\CommentsConfirm','',3),(190664,'73943','origin','block-190655','BlockBox','',1),(190665,'73944','origin','block-190664','BlockBox','',1),(190666,'73945','origin','block-190665','checkout\\EditBtn','',6),(190667,'73946','origin','block-190665','DelayedDespatch\\CheckoutConfirm','',8),(190668,'73947','origin','block-190665','Html_box','',9),(190669,'73948','origin','block-190665','checkout\\EditBtn','',10),(190670,'73949','origin','block-190665','Html_box','',5),(190671,'73950','origin','block-190665','checkout\\ShippingConfirm','',7),(190672,'73951','origin','block-190665','Html_box','',1),(190673,'73952','origin','block-190665','checkout\\EditBtn','',3),(190674,'73953','origin','block-190665','checkout\\ContactConfirm','',11),(190675,'73954','origin','block-190665','Html_box','',2),(190676,'73955','origin','block-190665','checkout\\ShippingAddressConfirm','',4),(190677,'73956','origin','block-190664-2','BlockBox','',1),(190678,'73957','origin','block-190677','checkout\\EditBtn','',6),(190679,'73958','origin','block-190677','checkout\\EditBtn','',3),(190680,'73959','origin','block-190677','checkout\\PaymentMethodConfirm','',7),(190681,'73960','origin','block-190677','Html_box','',5),(190682,'73961','origin','block-190677','Html_box','',1),(190683,'73962','origin','block-190677','checkout\\BillingAddressConfirm','',4),(190684,'73963','origin','block-190677','Html_box','',2),(190685,'73964','origin','block-190654','UploadCustomerId\\UploadCustomerIdForm','',1),(190686,'73965','origin','block-190654-2','BlockBox','',1),(190687,'73966','origin','block-190686','Html_box','',1),(190688,'73967','origin','block-190686','checkout\\ConfirmBtn','',3),(190689,'73968','origin','block-190686','checkout\\Totals','',2),(190690,'73969','origin','block-190653','Html_box','',1),(190691,'73970','origin','confirmation_free_s','BlockBox','',1),(190692,'73971','origin','block-190691','BlockBox','',2),(190693,'73972','origin','block-190692','BlockBox','',1),(190694,'73973','origin','block-190693','BlockBox','',2),(190695,'73974','origin','block-190694','checkout\\CommentsConfirm','',3),(190696,'73975','origin','block-190694','checkout\\EditBtn','',2),(190697,'73976','origin','block-190694','Html_box','',1),(190698,'73977','origin','block-190693','BlockBox','',3),(190699,'73978','origin','block-190698','checkout\\EditBtn','',3),(190700,'73979','origin','block-190698','Html_box','',1),(190701,'73980','origin','block-190698','sample\\Products','',2),(190702,'73981','origin','block-190693','BlockBox','',1),(190703,'73982','origin','block-190702','BlockBox','',1),(190704,'73983','origin','block-190703','checkout\\EditBtn','',3),(190705,'73984','origin','block-190703','checkout\\ShippingConfirm','',7),(190706,'73985','origin','block-190703','Html_box','',5),(190707,'73986','origin','block-190703','checkout\\EditBtn','',6),(190708,'73987','origin','block-190703','Html_box','',2),(190709,'73988','origin','block-190703','checkout\\ShippingAddressConfirm','',4),(190710,'73989','origin','block-190702-2','BlockBox','',1),(190711,'73990','origin','block-190710','checkout\\ContactConfirm','',3),(190712,'73991','origin','block-190710','DelayedDespatch\\CheckoutConfirm','',4),(190713,'73992','origin','block-190710','checkout\\EditBtn','',2),(190714,'73993','origin','block-190710','Html_box','',1),(190715,'73994','origin','block-190692-2','BlockBox','',1),(190716,'73995','origin','block-190715','checkout\\ConfirmBtn','',3),(190717,'73996','origin','block-190691','Html_box','',1),(190718,'73997','origin','confirmation_no_shipping','BlockBox','',1),(190719,'73998','origin','block-190718','Html_box','',1),(190720,'73999','origin','block-190718','BlockBox','',2),(190721,'74000','origin','block-190720','BlockBox','',1),(190722,'74001','origin','block-190721','BlockBox','',1),(190723,'74002','origin','block-190722','BlockBox','',1),(190724,'74003','origin','block-190723','checkout\\EditBtn','',10),(190725,'74004','origin','block-190723','Html_box','',9),(190726,'74005','origin','block-190723','checkout\\ContactConfirm','',11),(190727,'74006','origin','block-190722-2','BlockBox','',1),(190728,'74007','origin','block-190727','checkout\\PaymentMethodConfirm','',7),(190729,'74008','origin','block-190727','checkout\\EditBtn','',6),(190730,'74009','origin','block-190727','Html_box','',5),(190731,'74010','origin','block-190727','Html_box','',1),(190732,'74011','origin','block-190727','checkout\\EditBtn','',3),(190733,'74012','origin','block-190727','checkout\\BillingAddressConfirm','',4),(190734,'74013','origin','block-190727','Html_box','',2),(190735,'74014','origin','block-190721','BlockBox','',2),(190736,'74015','origin','block-190735','Html_box','',1),(190737,'74016','origin','block-190735','checkout\\CommentsConfirm','',3),(190738,'74017','origin','block-190735','checkout\\EditBtn','',2),(190739,'74018','origin','block-190721','BlockBox','',3),(190740,'74019','origin','block-190739','Html_box','',1),(190741,'74020','origin','block-190739','checkout\\EditBtn','',2),(190742,'74021','origin','block-190739','cart\\Products','',3),(190743,'74022','origin','block-190720-2','BlockBox','',1),(190744,'74023','origin','block-190743','checkout\\ConfirmBtn','',3),(190745,'74024','origin','block-190743','Html_box','',1),(190746,'74025','origin','block-190743','checkout\\Totals','',2),(190747,'74026','origin','confirmation_no_shipping_q','BlockBox','',2),(190748,'74027','origin','block-190747','Html_box','',1),(190749,'74028','origin','block-190747','BlockBox','',2),(190750,'74029','origin','block-190749','BlockBox','',1),(190751,'74030','origin','block-190750','BlockBox','',2),(190752,'74031','origin','block-190751','Html_box','',1),(190753,'74032','origin','block-190751','checkout\\CommentsConfirm','',3),(190754,'74033','origin','block-190751','checkout\\EditBtn','',2),(190755,'74034','origin','block-190750','BlockBox','',1),(190756,'74035','origin','block-190755','BlockBox','',1),(190757,'74036','origin','block-190756','checkout\\EditBtn','',5),(190758,'74037','origin','block-190756','checkout\\ContactConfirm','',6),(190759,'74038','origin','block-190756','checkout\\PaymentMethodConfirm','',3),(190760,'74039','origin','block-190756','checkout\\EditBtn','',2),(190761,'74040','origin','block-190756','Html_box','',4),(190762,'74041','origin','block-190756','Html_box','',1),(190763,'74042','origin','block-190755-2','BlockBox','',1),(190764,'74043','origin','block-190763','checkout\\BillingAddressConfirm','',4),(190765,'74044','origin','block-190763','checkout\\EditBtn','',3),(190766,'74045','origin','block-190763','Html_box','',2),(190767,'74046','origin','block-190750','BlockBox','',3),(190768,'74047','origin','block-190767','checkout\\EditBtn','',2),(190769,'74048','origin','block-190767','Html_box','',1),(190770,'74049','origin','block-190767','quote\\Products','',3),(190771,'74050','origin','block-190749-2','BlockBox','',1),(190772,'74051','origin','block-190771','checkout\\ConfirmBtn','',3),(190773,'74052','origin','block-190771','checkout\\Totals','',2),(190774,'74053','origin','block-190771','Html_box','',1),(190775,'74054','origin','confirmation_q','BlockBox','',1),(190776,'74055','origin','block-190775','Html_box','',1),(190777,'74056','origin','block-190775','BlockBox','',2),(190778,'74057','origin','block-190777','BlockBox','',1),(190779,'74058','origin','block-190778','BlockBox','',3),(190780,'74059','origin','block-190779','quote\\Products','',3),(190781,'74060','origin','block-190779','Html_box','',1),(190782,'74061','origin','block-190779','checkout\\EditBtn','',2),(190783,'74062','origin','block-190778','BlockBox','',1),(190784,'74063','origin','block-190783','BlockBox','',1),(190785,'74064','origin','block-190784','Html_box','',1),(190786,'74065','origin','block-190784','checkout\\EditBtn','',10),(190787,'74066','origin','block-190784','Html_box','',2),(190788,'74067','origin','block-190784','checkout\\ContactConfirm','',11),(190789,'74068','origin','block-190784','checkout\\ShippingAddressConfirm','',4),(190790,'74069','origin','block-190784','checkout\\ShippingConfirm','',7),(190791,'74070','origin','block-190784','checkout\\EditBtn','',3),(190792,'74071','origin','block-190784','DelayedDespatch\\CheckoutConfirm','',8),(190793,'74072','origin','block-190784','Html_box','',9),(190794,'74073','origin','block-190784','Html_box','',5),(190795,'74074','origin','block-190784','checkout\\EditBtn','',6),(190796,'74075','origin','block-190783-2','BlockBox','',1),(190797,'74076','origin','block-190796','checkout\\EditBtn','',3),(190798,'74077','origin','block-190796','checkout\\BillingAddressConfirm','',4),(190799,'74078','origin','block-190796','checkout\\PaymentMethodConfirm','',7),(190800,'74079','origin','block-190796','Html_box','',1),(190801,'74080','origin','block-190796','Html_box','',2),(190802,'74081','origin','block-190796','checkout\\EditBtn','',6),(190803,'74082','origin','block-190796','Html_box','',5),(190804,'74083','origin','block-190778','BlockBox','',2),(190805,'74084','origin','block-190804','checkout\\CommentsConfirm','',3),(190806,'74085','origin','block-190804','Html_box','',1),(190807,'74086','origin','block-190804','checkout\\EditBtn','',2),(190808,'74087','origin','block-190777-2','BlockBox','',1),(190809,'74088','origin','block-190808','Html_box','',1),(190810,'74089','origin','block-190808','checkout\\Totals','',2),(190811,'74090','origin','block-190808','checkout\\ConfirmBtn','',3),(190812,'74091','origin','confirmation_s','BlockBox','',1),(190813,'74092','origin','block-190812','BlockBox','',2),(190814,'74093','origin','block-190813','BlockBox','',1),(190815,'74094','origin','block-190814','BlockBox','',1),(190816,'74095','origin','block-190815','BlockBox','',1),(190817,'74096','origin','block-190816','checkout\\ShippingAddressConfirm','',4),(190818,'74097','origin','block-190816','checkout\\EditBtn','',3),(190819,'74098','origin','block-190816','Html_box','',2),(190820,'74099','origin','block-190816','DelayedDespatch\\CheckoutConfirm','',8),(190821,'74100','origin','block-190816','checkout\\ShippingConfirm','',7),(190822,'74101','origin','block-190816','Html_box','',1),(190823,'74102','origin','block-190816','Html_box','',5),(190824,'74103','origin','block-190816','Html_box','',9),(190825,'74104','origin','block-190816','checkout\\ContactConfirm','',11),(190826,'74105','origin','block-190816','checkout\\EditBtn','',6),(190827,'74106','origin','block-190816','checkout\\EditBtn','',10),(190828,'74107','origin','block-190815-2','BlockBox','',1),(190829,'74108','origin','block-190828','Html_box','',2),(190830,'74109','origin','block-190828','checkout\\BillingAddressConfirm','',4),(190831,'74110','origin','block-190828','checkout\\EditBtn','',3),(190832,'74111','origin','block-190828','checkout\\PaymentMethodConfirm','',7),(190833,'74112','origin','block-190828','checkout\\EditBtn','',6),(190834,'74113','origin','block-190828','Html_box','',1),(190835,'74114','origin','block-190828','Html_box','',5),(190836,'74115','origin','block-190814','BlockBox','',3),(190837,'74116','origin','block-190836','checkout\\EditBtn','',3),(190838,'74117','origin','block-190836','Html_box','',1),(190839,'74118','origin','block-190836','sample\\Products','',2),(190840,'74119','origin','block-190814','BlockBox','',2),(190841,'74120','origin','block-190840','Html_box','',1),(190842,'74121','origin','block-190840','checkout\\EditBtn','',2),(190843,'74122','origin','block-190840','checkout\\CommentsConfirm','',3),(190844,'74123','origin','block-190813-2','BlockBox','',1),(190845,'74124','origin','block-190844','checkout\\Totals','',2),(190846,'74125','origin','block-190844','checkout\\ConfirmBtn','',3),(190847,'74126','origin','block-190844','Html_box','',1),(190848,'74127','origin','block-190812','Html_box','',1),(190849,'74128','origin','contact','BlockBox','',1),(190850,'74132','origin','block-190849','info\\Title','',1),(190851,'74133','origin','block-190849','BlockBox','',3),(190852,'74134','origin','block-190851','contact\\ContactForm','',1),(190853,'74135','origin','block-190851-2','contact\\Contacts','',1),(190854,'74136','origin','created_success','BlockBox','',1),(190855,'74137','origin','block-190854','Html_box','',1),(190856,'74138','origin','block-190854','Html_box','',2),(190857,'74139','origin','credit_note','invoice\\Container','',1),(190858,'74140','origin','block-190857','BlockBox','',5),(190859,'74141','origin','block-190858','invoice\\StoreAddress','',8),(190860,'74142','origin','block-190858','Text','',1),(190861,'74143','origin','block-190858-2','Text','',2),(190862,'74144','origin','block-190858-2','Logo','',1),(190863,'74145','origin','block-190858-3','Text','',1),(190864,'74146','origin','block-190858-3','BlockBox','',3),(190865,'74147','origin','block-190864','Text','',1),(190866,'74148','origin','block-190864-2','invoice\\StoreEmail','',1),(190867,'74149','origin','block-190858-3','BlockBox','',2),(190868,'74150','origin','block-190867','Text','',1),(190869,'74151','origin','block-190867-2','invoice\\StorePhone','',1),(190870,'74152','origin','block-190857','invoice\\Products','',3),(190871,'74153','origin','block-190857','BlockBox','',1),(190872,'74154','origin','block-190871','Logo','',1),(190873,'74155','origin','block-190871-2','BlockBox','',4),(190874,'74156','origin','block-190873','Text','',1),(190875,'74157','origin','block-190873-2','invoice\\StoreSite','',1),(190876,'74158','origin','block-190871-2','BlockBox','',2),(190877,'74159','origin','block-190876','Text','',1),(190878,'74160','origin','block-190876-2','invoice\\StorePhone','',1),(190879,'74161','origin','block-190871-2','BlockBox','',3),(190880,'74162','origin','block-190879','Text','',1),(190881,'74163','origin','block-190879-2','invoice\\StoreEmail','',1),(190882,'74164','origin','block-190871-2','BlockBox','',1),(190883,'74165','origin','block-190882','invoice\\StoreAddress','',1),(190884,'74166','origin','block-190857','BlockBox','',4),(190885,'74167','origin','block-190884','BlockBox','',1),(190886,'74168','origin','block-190885','invoice\\ShippingAddress','',2),(190887,'74169','origin','block-190885','Text','',1),(190888,'74170','origin','block-190884-2','BlockBox','',1),(190889,'74171','origin','block-190857','BlockBox','',2),(190890,'74172','origin','block-190889','BlockBox','',7),(190891,'74173','origin','block-190890','BlockBox','',1),(190892,'74174','origin','block-190891','Text','',1),(190893,'74175','origin','block-190891','invoice\\BillingAddress','',2),(190894,'74176','origin','block-190890-2','BlockBox','',1),(190895,'74177','origin','block-190894','invoice\\CustomerPhone','',4),(190896,'74178','origin','block-190894','Text','',1),(190897,'74179','origin','block-190894','Text','',3),(190898,'74180','origin','block-190894','invoice\\CustomerName','',2),(190899,'74181','origin','block-190894','invoice\\CustomerEmail','',6),(190900,'74182','origin','block-190894','Text','',5),(190901,'74183','origin','block-190889','BlockBox','',8),(190902,'74184','origin','block-190901','BlockBox','',1),(190903,'74185','origin','block-190902','invoice\\ShippingMethod','',2),(190904,'74186','origin','block-190902','Text','',1),(190905,'74187','origin','block-190901-2','BlockBox','',1),(190906,'74188','origin','block-190905','Text','',1),(190907,'74189','origin','block-190905','invoice\\ShippingMethod','',2),(190908,'74190','origin','block-190889-2','invoice\\OrderId','',1),(190909,'74191','origin','block-190889-2','Text','',2),(190910,'74192','origin','block-190889-2','invoice\\PaymentDate','',3),(190911,'74193','origin','delivery-location','DeliveryLocation\\FeaturedList','',6),(190912,'74194','origin','delivery-location','DeliveryLocation\\LocationLongDescription','',5),(190913,'74195','origin','delivery-location','DeliveryLocation\\LocationList','',7),(190914,'74196','origin','delivery-location','DeliveryLocation\\LocationTitle','',2),(190915,'74197','origin','delivery-location','DeliveryLocation\\LocationProducts','',8),(190916,'74198','origin','delivery-location','DeliveryLocation\\LocationDescription','',3),(190917,'74199','origin','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(190918,'74200','origin','delivery-location-default','DeliveryLocation\\TopLocationList','',2),(190919,'74201','origin','delivery-location-default','Heading','',1),(190920,'94716','origin','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(190921,'94717','origin','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(190922,'94718','origin','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(190923,'94719','origin','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(190924,'94720','origin','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(190925,'94721','origin','delivery_loc_2','DeliveryLocation\\LocationList','',7),(190926,'94722','origin','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(190927,'74202','origin','email','email\\BlockBox','',1),(190928,'74203','origin','block-190927','email\\BlockBox','',1),(190929,'74204','origin','block-190928','Copyright','',4),(190930,'74205','origin','block-190928','email\\Content','',3),(190931,'74206','origin','block-190928','email\\BlockBox','',2),(190932,'74207','origin','block-190931','email\\Title','',1),(190933,'74208','origin','block-190931-2','email\\Date','',1),(190934,'74209','origin','block-190928','Logo','',1),(190935,'74210','origin','email_2','email\\BlockBox','',1),(190936,'74211','origin','block-190935','email\\BlockBox','',1),(190937,'74212','origin','block-190936','Copyright','',4),(190938,'74213','origin','block-190936','Logo','',1),(190939,'74214','origin','block-190936','email\\Content','',3),(190940,'74215','origin','block-190936','email\\BlockBox','',2),(190941,'74216','origin','block-190940','email\\Title','',1),(190942,'74217','origin','block-190940-2','email\\Date','',1),(190943,'74218','origin','email_3','email\\BlockBox','',1),(190944,'74219','origin','block-190943','email\\BlockBox','',1),(190945,'74220','origin','block-190944','email\\BlockBox','',2),(190946,'74221','origin','block-190945','email\\Content','',2),(190947,'74222','origin','block-190945','email\\BlockBox','',1),(190948,'74223','origin','block-190947','email\\Title','',1),(190949,'74224','origin','block-190947-2','email\\Date','',1),(190950,'74225','origin','block-190944','Copyright','',3),(190951,'74226','origin','block-190944','Logo','',1),(190952,'74227','origin','email_4','email\\BlockBox','',1),(190953,'74228','origin','block-190952','email\\BlockBox','',1),(190954,'74229','origin','block-190953','Copyright','',2),(190955,'74230','origin','block-190953','email\\BlockBox','',1),(190956,'74231','origin','block-190955','email\\BlockBox','',1),(190957,'74232','origin','block-190956','Logo','',1),(190958,'74233','origin','block-190956-2','email\\Date','',2),(190959,'74234','origin','block-190956-2','email\\Title','',1),(190960,'74235','origin','block-190955','email\\Content','',2),(190961,'74236','origin','footer','BlockBox','',1),(190962,'74237','origin','block-190961','BlockBox','',1),(190963,'74238','origin','block-190962','BlockBox','',1),(190964,'74239','origin','block-190963','Menu','footer3',3),(190965,'1695906739.5696','origin','block-190963','Html_box','',2),(190966,'74241','origin','block-190962-2','BlockBox','',1),(190967,'74243','origin','block-190966','Menu','footer1',3),(190968,'1695906751.0591','origin','block-190966','Html_box','',2),(190969,'74244','origin','block-190962-3','BlockBox','',1),(190970,'74246','origin','block-190969','Menu','footer2',3),(190971,'1695906756.0887','origin','block-190969','Html_box','',2),(190972,'74247','origin','block-190962-4','BlockBox','',1),(190973,'74248','origin','block-190972','Contacts','',4),(190974,'74249','origin','block-190972','Contacts','',3),(190975,'1695906761.6568','origin','block-190972','Html_box','',2),(190976,'74256','origin','block-190961','BlockBox','footer-content',4),(190977,'74257','origin','block-190976','Copyright','',1),(190978,'74258','origin','block-190976-2','invoice\\StoreAddress','',1),(190979,'94723','origin','for_menu','BlockBox','',1),(190980,'94724','origin','block-190979','Html_box','',1),(190981,'94725','origin','block-190979-2','Languages','',1),(190982,'94726','origin','for_menu','BlockBox','',3),(190983,'94727','origin','block-190982','Html_box','',1),(190984,'94728','origin','block-190982-2','Currencies','',1),(190985,'74263','origin','gift','BlockBox','',1),(190986,'74264','origin','block-190985','BlockBox','',3),(190987,'74265','origin','block-190986','BlockBox','',1),(190988,'74266','origin','block-190987','gift\\Card','',1),(190989,'74267','origin','block-190986-2','gift\\Form','',2),(190990,'74268','origin','block-190986-2','Text','',1),(190991,'74269','origin','block-190985','info\\Title','',1),(190992,'74270','origin','gift_card','BlockBox','',1),(190993,'74271','origin','block-190992','BlockBox','',11),(190994,'74272','origin','block-190993','invoice\\StoreEmail','',3),(190995,'74273','origin','block-190993','Text','',1),(190996,'74274','origin','block-190993','invoice\\StorePhone','',2),(190997,'74275','origin','block-190992','Text','',8),(190998,'74276','origin','block-190992','Text','',3),(190999,'74277','origin','block-190992','BlockBox','',10),(191000,'74278','origin','block-190999','Text','',1),(191001,'74279','origin','block-190999-2','gift\\CodeView','',1),(191002,'74280','origin','block-190992','gift\\MessageView','',7),(191003,'74281','origin','block-190992','gift\\AmountView','',5),(191004,'74282','origin','block-190992','Text','',6),(191005,'74284','origin','block-190992','Logo','',1),(191006,'74285','origin','block-190992','Text','',4),(191007,'74286','origin','block-190992','Text','',9),(191008,'74287','origin','gift_card_2','BlockBox','',1),(191009,'74288','origin','block-191008','gift\\AmountView','',3),(191010,'74289','origin','block-191008','BlockBox','',8),(191011,'74290','origin','block-191010','Text','',1),(191012,'74291','origin','block-191010-2','gift\\CodeView','',1),(191013,'74292','origin','block-191008','BlockBox','',9),(191014,'74293','origin','block-191013','invoice\\StoreEmail','',3),(191015,'74294','origin','block-191013','Text','',1),(191016,'74295','origin','block-191013','invoice\\StorePhone','',2),(191017,'74296','origin','block-191008','gift\\MessageView','',5),(191018,'74297','origin','block-191008','Text','',4),(191019,'74298','origin','block-191008','Text','',7),(191020,'74299','origin','block-191008','Text','',2),(191021,'74300','origin','block-191008','Text','',6),(191022,'74301','origin','block-191008','Text','',1),(191023,'94729','origin','gift_card_2_pdf','BlockBox','',1),(191024,'94730','origin','block-191023','BlockBox','',12),(191025,'94731','origin','block-191024','invoice\\StoreEmail','',4),(191026,'94732','origin','block-191024','invoice\\StorePhone','',3),(191027,'94733','origin','block-191024','Html_box','',1),(191028,'94734','origin','block-191023','BlockBox','',11),(191029,'94735','origin','block-191028','Html_box','',1),(191030,'94736','origin','block-191028-2','gift\\CodeViewPdf','',1),(191031,'94737','origin','block-191023','BlockBox','',1),(191032,'94738','origin','block-191031','Text','',4),(191033,'94739','origin','block-191031','Html_box','',1),(191034,'94740','origin','block-191031','Html_box','',2),(191035,'94741','origin','block-191031','gift\\AmountViewPdf','',3),(191036,'94742','origin','block-191031','gift\\MessageViewPdf','',5),(191037,'94743','origin','block-191031','Html_box','',7),(191038,'94744','origin','block-191031','Html_box','',6),(191039,'94746','origin','gift_card_pdf','BlockBox','',1),(191040,'94747','origin','block-191039','BlockBox','',12),(191041,'94748','origin','block-191040','invoice\\StoreEmail','',4),(191042,'94749','origin','block-191040','invoice\\StorePhone','',3),(191043,'94750','origin','block-191040','Html_box','',1),(191044,'94751','origin','block-191039','BlockBox','',11),(191045,'94752','origin','block-191044','Html_box','',1),(191046,'94753','origin','block-191044-2','gift\\CodeViewPdf','',1),(191047,'94754','origin','block-191039','BlockBox','',1),(191048,'94755','origin','block-191047','Text','',5),(191049,'94757','origin','block-191047','Html_box','',3),(191050,'94758','origin','block-191047','gift\\AmountViewPdf','',4),(191051,'94759','origin','block-191047','gift\\MessageViewPdf','',6),(191052,'94760','origin','block-191047','Html_box','',8),(191053,'94761','origin','block-191047','Html_box','',7),(191054,'1707902674.2595','origin','block-191047','Logo','',2),(191055,'94762','origin','gift_card_pdf','Import','',1),(191056,'74302','origin','gift_certificate','BlockBox','',1),(191057,'74303','origin','block-191056','account\\ApplyCertificate','',2),(191058,'74304','origin','block-191056','Html_box','',1),(191059,'74305','origin','gigt_card_3','BlockBox','',1),(191060,'74306','origin','block-191059','BlockBox','',8),(191061,'74307','origin','block-191060','Text','',1),(191062,'74308','origin','block-191060-2','gift\\CodeView','',1),(191063,'74309','origin','block-191059','Text','',6),(191064,'74310','origin','block-191059','Text','',1),(191065,'74311','origin','block-191059','BlockBox','',9),(191066,'74312','origin','block-191065','Text','',1),(191067,'74313','origin','block-191065','invoice\\StoreEmail','',3),(191068,'74314','origin','block-191065','invoice\\StorePhone','',2),(191069,'74315','origin','block-191059','gift\\MessageView','',5),(191070,'74316','origin','block-191059','Text','',2),(191071,'74317','origin','block-191059','Text','',4),(191072,'74318','origin','block-191059','gift\\AmountView','',3),(191073,'74319','origin','block-191059','Text','',7),(191074,'94763','origin','gigt_card_3_pdf','BlockBox','',1),(191075,'94764','origin','block-191074','BlockBox','',12),(191076,'94765','origin','block-191075','invoice\\StoreEmail','',4),(191077,'94766','origin','block-191075','invoice\\StorePhone','',3),(191078,'94767','origin','block-191075','Html_box','',1),(191079,'94768','origin','block-191074','BlockBox','',11),(191080,'94769','origin','block-191079','Html_box','',1),(191081,'94770','origin','block-191079-2','gift\\CodeViewPdf','',1),(191082,'94771','origin','block-191074','BlockBox','',1),(191083,'94772','origin','block-191082','Text','',4),(191084,'94773','origin','block-191082','Html_box','',1),(191085,'94774','origin','block-191082','Html_box','',2),(191086,'94775','origin','block-191082','gift\\AmountViewPdf','',3),(191087,'94776','origin','block-191082','gift\\MessageViewPdf','',5),(191088,'94777','origin','block-191082','Html_box','',7),(191089,'94778','origin','block-191082','Html_box','',6),(191090,'1713770938.449798','origin','header','CookieNotice','',1),(191091,'1713770938.464587','origin','header','BlockBox','header-content-small',2),(191092,'1713770938.467593','origin','block-191091','BlockBox','header-content-small-left',1),(191093,'1713770938.470248','origin','block-191092','Menu','Header menu',1),(191094,'1713770938.51635','origin','block-191092-2','BlockBox','header-content-small-right',5),(191095,'1713770938.51828','origin','block-191094','Cart','',1),(191096,'1713770938.573998','origin','block-191094','Account','',2),(191097,'1713770938.61982','origin','block-191094','Currencies','',4),(191098,'1713770938.663457','origin','block-191094','Languages','',3),(191099,'1713770938.697915','origin','header','BlockBox','header-content',3),(191100,'1713770938.706821','origin','block-191099','Logo','',1),(191101,'1713770938.709156','origin','block-191099','Search','',2),(191102,'1713770938.773998','origin','block-191099','Text','',3),(191103,'1713770938.811953','origin','header','BlockBox','header-menu',4),(191104,'1713770938.81834','origin','block-191103','Menu','Categories',1),(191105,'74346','origin','info','BlockBox','info-content',1),(191106,'74347','origin','block-191105','info\\DescriptionShort','',2),(191107,'74348','origin','block-191105','info\\Content','',4),(191108,'74349','origin','block-191105','info\\Title','',1),(191109,'74350','origin','block-191105','info\\Image','',3),(191110,'74351','origin','invoice','invoice\\Container','',1),(191111,'74352','origin','block-191110','BlockBox','',3),(191112,'74353','origin','block-191111','BlockBox','',8),(191113,'74354','origin','block-191112','BlockBox','',1),(191114,'74355','origin','block-191113','invoice\\ShippingMethod','',2),(191115,'74356','origin','block-191113','Text','',1),(191116,'74357','origin','block-191112-2','BlockBox','',1),(191117,'74358','origin','block-191116','Text','',1),(191118,'74359','origin','block-191116','invoice\\ShippingMethod','',2),(191119,'74360','origin','block-191111','BlockBox','',7),(191120,'74361','origin','block-191119','BlockBox','',1),(191121,'74362','origin','block-191120','Text','',1),(191122,'74363','origin','block-191120','invoice\\BillingAddress','',2),(191123,'74364','origin','block-191119-2','BlockBox','',1),(191124,'74365','origin','block-191123','Text','',5),(191125,'74366','origin','block-191123','invoice\\CustomerName','',2),(191126,'74367','origin','block-191123','invoice\\CustomerPhone','',4),(191127,'74368','origin','block-191123','Text','',1),(191128,'74369','origin','block-191123','Text','',3),(191129,'74370','origin','block-191123','invoice\\CustomerEmail','',6),(191130,'74371','origin','block-191111-2','invoice\\PaymentMethod','',5),(191131,'74372','origin','block-191111-2','Text','',4),(191132,'74373','origin','block-191111-2','Text','',2),(191133,'74374','origin','block-191111-2','invoice\\OrderId','',1),(191134,'74375','origin','block-191111-2','invoice\\PaymentDate','',3),(191135,'74376','origin','block-191111-2','invoice\\OrderBarcode','',6),(191136,'74377','origin','block-191110','BlockBox','',6),(191137,'74378','origin','block-191136','invoice\\StoreAddress','',8),(191138,'74379','origin','block-191136','Text','',1),(191139,'74380','origin','block-191136-2','Text','',2),(191140,'74381','origin','block-191136-2','Logo','',1),(191141,'74382','origin','block-191136-3','BlockBox','',3),(191142,'74383','origin','block-191141','Text','',1),(191143,'74384','origin','block-191141-2','invoice\\StoreEmail','',1),(191144,'74385','origin','block-191136-3','BlockBox','',2),(191145,'74386','origin','block-191144','Text','',1),(191146,'74387','origin','block-191144-2','invoice\\StorePhone','',1),(191147,'74388','origin','block-191136-3','Text','',1),(191148,'74389','origin','block-191110','invoice\\Products','',4),(191149,'74390','origin','block-191110','BlockBox','',5),(191150,'74391','origin','block-191149','BlockBox','',1),(191151,'74392','origin','block-191150','invoice\\ShippingAddress','',2),(191152,'74393','origin','block-191150','Text','',1),(191153,'74394','origin','block-191149-2','BlockBox','',1),(191154,'74395','origin','block-191153','invoice\\Totals','',1),(191155,'74396','origin','block-191110','BlockBox','',2),(191156,'74397','origin','block-191155','Logo','',1),(191157,'74398','origin','block-191155-2','BlockBox','',4),(191158,'74399','origin','block-191157','Text','',1),(191159,'74400','origin','block-191157-2','invoice\\StoreSite','',1),(191160,'74401','origin','block-191155-2','BlockBox','',3),(191161,'74402','origin','block-191160','Text','',1),(191162,'74403','origin','block-191160-2','invoice\\StoreEmail','',1),(191163,'74404','origin','block-191155-2','BlockBox','',1),(191164,'74405','origin','block-191163','invoice\\StoreAddress','',3),(191165,'74406','origin','block-191155-2','BlockBox','',2),(191166,'74407','origin','block-191165','Text','',1),(191167,'74408','origin','block-191165-2','invoice\\StorePhone','',1),(191168,'74409','origin','login_account','BlockBox','',1),(191169,'74410','origin','block-191168','Tabs','',2),(191170,'74411','origin','block-191169-1','login\\Returning','',1),(191171,'74412','origin','block-191169-2','BlockBox','',1),(191172,'74413','origin','block-191171','Html_box','',1),(191173,'74414','origin','block-191171-2','BlockBox','',1),(191174,'74415','origin','block-191173','Html_box','',2),(191175,'74416','origin','block-191173','login\\Register','',1),(191176,'74417','origin','block-191168','BlockBox','',1),(191177,'74418','origin','block-191176','Html_box','',3),(191178,'74419','origin','block-191176','Html_box','',1),(191179,'74420','origin','block-191176','login\\Socials','',2),(191180,'74421','origin','login_checkout','BlockBox','',1),(191181,'74422','origin','block-191180','BlockBox','',1),(191182,'74423','origin','block-191181','checkout\\CreateBtn','',4),(191183,'74424','origin','block-191181','checkout\\GuestBtn','',2),(191184,'74425','origin','block-191181','Html_box','',3),(191185,'74426','origin','block-191181','BlockBox','',5),(191186,'74427','origin','block-191185','Html_box','',1),(191187,'74428','origin','block-191185','login\\Socials','',2),(191188,'74429','origin','block-191181','Html_box','',1),(191189,'74430','origin','block-191181-2','login\\Returning','',2),(191190,'74431','origin','block-191181-2','Html_box','',1),(191191,'74432','origin','login_checkout2','BlockBox','',1),(191192,'74433','origin','block-191191','Tabs','',4),(191193,'74434','origin','block-191192-1','BlockBox','',1),(191194,'74435','origin','block-191193','Html_box','',1),(191195,'74436','origin','block-191193-2','BlockBox','',1),(191196,'74437','origin','block-191195','login\\Guest','',1),(191197,'74438','origin','block-191195','Html_box','',2),(191198,'74439','origin','block-191192-2','login\\Returning','',1),(191199,'74440','origin','block-191192-3','BlockBox','',1),(191200,'74441','origin','block-191199','Html_box','',1),(191201,'74442','origin','block-191199-2','BlockBox','',1),(191202,'74443','origin','block-191201','Html_box','',2),(191203,'74444','origin','block-191201','login\\Register','',1),(191204,'74445','origin','block-191191','login\\Socials','',2),(191205,'74446','origin','block-191191','Html_box','',3),(191206,'74447','origin','block-191191','Html_box','',1),(191207,'74448','origin','login_checkout2_q','BlockBox','',1),(191208,'74449','origin','block-191207','Tabs','',4),(191209,'74450','origin','block-191208-1','BlockBox','',1),(191210,'74451','origin','block-191209','Html_box','',1),(191211,'74452','origin','block-191209-2','quote\\FastOrder','',1),(191212,'74453','origin','block-191208-2','login\\Returning','',1),(191213,'74454','origin','block-191208-3','BlockBox','',1),(191214,'74455','origin','block-191213','Html_box','',1),(191215,'74456','origin','block-191213','Import','',2),(191216,'74457','origin','block-191213-2','BlockBox','',1),(191217,'74458','origin','block-191216','login\\Register','',1),(191218,'74459','origin','block-191216','Html_box','',2),(191219,'74460','origin','block-191207','Html_box','',3),(191220,'74461','origin','block-191207','Html_box','',1),(191221,'74462','origin','block-191207','login\\Socials','',2),(191222,'74463','origin','login_checkout2_s','BlockBox','',1),(191223,'74464','origin','block-191222','login\\Socials','',2),(191224,'74465','origin','block-191222','Html_box','',3),(191225,'74466','origin','block-191222','Tabs','',4),(191226,'74467','origin','block-191225-1','BlockBox','',1),(191227,'74468','origin','block-191226','Html_box','',1),(191228,'74469','origin','block-191226-2','quote\\FastOrder','',1),(191229,'74470','origin','block-191225-2','login\\Returning','',1),(191230,'74471','origin','block-191225-3','BlockBox','',1),(191231,'74472','origin','block-191230','Html_box','',1),(191232,'74473','origin','block-191230-2','BlockBox','',1),(191233,'74474','origin','block-191232','login\\Register','',1),(191234,'74475','origin','block-191232','Html_box','',2),(191235,'74476','origin','block-191222','Html_box','',1),(191236,'74477','origin','login_checkout_q','BlockBox','',1),(191237,'74478','origin','block-191236','BlockBox','',1),(191238,'74479','origin','block-191237','BlockBox','',6),(191239,'74480','origin','block-191238','Html_box','',1),(191240,'74481','origin','block-191238','login\\Socials','',2),(191241,'74482','origin','block-191237','checkout\\GuestBtn','',2),(191242,'74483','origin','block-191237','checkout\\CreateBtn','',5),(191243,'74484','origin','block-191237','Html_box','',4),(191244,'74485','origin','block-191237','Html_box','',1),(191245,'74486','origin','block-191237-2','Html_box','',1),(191246,'74487','origin','block-191237-2','login\\Returning','',2),(191247,'74488','origin','login_checkout_s','BlockBox','',1),(191248,'74489','origin','block-191247','BlockBox','',1),(191249,'74490','origin','block-191248','Html_box','',1),(191250,'74491','origin','block-191248','checkout\\GuestBtn','',2),(191251,'74492','origin','block-191248','checkout\\CreateBtn','',4),(191252,'74493','origin','block-191248','Html_box','',3),(191253,'74494','origin','block-191248','BlockBox','',5),(191254,'74495','origin','block-191253','Html_box','',1),(191255,'74496','origin','block-191253','login\\Socials','',2),(191256,'74497','origin','block-191248-2','Html_box','',1),(191257,'74498','origin','block-191248-2','login\\Returning','',2),(191258,'74499','origin','logoff','BlockBox','',1),(191259,'74500','origin','block-191258','Html_box','',1),(191260,'74501','origin','logoff_forever','BlockBox','',1),(191261,'74502','origin','block-191260','Html_box','',1),(191262,'74503','origin','main','BlockBox','',5),(191263,'74504','origin','block-191262','BlockBox','',1),(191264,'74505','origin','block-191263','Bestsellers','10',1),(191265,'74506','origin','block-191263-2','Reviews','3',1),(191266,'74507','origin','main','Banner','',2),(191267,'74508','origin','main','BlockBox','main-content',4),(191268,'74510','origin','block-191267','Tabs','',4),(191269,'74511','origin','block-191268-1','NewProducts','8',1),(191270,'74512','origin','block-191268-2','SpecialsProducts','',2),(191271,'74513','origin','block-191268-3','FeaturedProducts','4',2),(191272,'74514','origin','block-191267','TopCategories','',3),(191273,'74515','origin','main','Heading','',3),(191274,'1708693901.7617','origin','main','FormBuilder\\widgets\\Form','',6),(191275,'74516','origin','manufacturers','BlockBox','',1),(191276,'74517','origin','block-191275','Html_box','',1),(191277,'74518','origin','block-191275','Brands','',2),(191278,'74519','origin','messages-index','BlockBox','',1),(191279,'74520','origin','block-191278','BlockBox','',1),(191280,'74521','origin','block-191279','BlockBox','',1),(191281,'74522','origin','block-191280','Messages\\Sidebar','',1),(191282,'74523','origin','block-191279-2','Messages\\Listing','',1),(191283,'74524','origin','messages-new','BlockBox','',1),(191284,'74525','origin','block-191283','BlockBox','',1),(191285,'74526','origin','block-191284','Messages\\Sidebar','',1),(191286,'74527','origin','block-191284-2','Messages\\NewMessage','',1),(191287,'74528','origin','messages-view','BlockBox','',1),(191288,'74529','origin','block-191287','BlockBox','',1),(191289,'74530','origin','block-191288','Messages\\Sidebar','',1),(191290,'74531','origin','block-191288-2','Messages\\Message','',1),(191291,'74532','origin','my_password','BlockBox','',1),(191292,'74533','origin','block-191291','BlockBox','',1),(191293,'74534','origin','block-191292','WidgetsAria','',1),(191313,'74535','origin','block-191292-2','account\\ChangePassword','',2),(191314,'74536','origin','block-191292-2','Html_box','',1),(191315,'74537','origin','need_login','BlockBox','',1),(191316,'74538','origin','block-191315','Tabs','',2),(191317,'74539','origin','block-191316-1','login\\Returning','',1),(191318,'74540','origin','block-191316-2','BlockBox','',1),(191319,'74541','origin','block-191318','Html_box','',1),(191320,'74542','origin','block-191318-2','BlockBox','',1),(191321,'74543','origin','block-191320','login\\Register','',1),(191322,'74544','origin','block-191320','Html_box','',2),(191323,'74545','origin','block-191315','BlockBox','',1),(191324,'74546','origin','new-topic','BlockBox','',1),(191325,'74547','origin','block-191324','Breadcrumb','',2),(191326,'74548','origin','block-191324','Communication\\NewTopic','',3),(191327,'74549','origin','block-191324','Html_box','',1),(191328,'94779','origin','nnnn','BlockBox','',1),(191329,'94780','origin','block-191328','catalog\\Title','',1),(191330,'94781','origin','block-191328','BlockBox','',2),(191331,'94782','origin','block-191330','Filters','',1),(191332,'94783','origin','block-191330-2','Listing','',5),(191333,'94784','origin','block-191330-2','catalog\\Image','',1),(191334,'94785','origin','block-191330-2','BlockBox','',6),(191335,'94786','origin','block-191334','catalog\\CountsItems','',1),(191336,'94787','origin','block-191334-2','catalog\\Paging','',1),(191337,'94788','origin','block-191330-2','catalog\\ImageMapCategory','',3),(191338,'94789','origin','block-191330-2','Categories','',2),(191339,'94790','origin','block-191330-2','BlockBox','',4),(191340,'94791','origin','block-191339','catalog\\ListingLook','',1),(191341,'94792','origin','block-191339','catalog\\ItemsOnPage','',4),(191342,'94793','origin','block-191339','catalog\\CompareButton','',2),(191343,'94794','origin','block-191339','catalog\\Sorting','',3),(191344,'74550','origin','no-logged','BlockBox','',1),(191345,'74551','origin','block-191344','Communication\\NewTopic','',2),(191346,'74552','origin','block-191344','Html_box','',1),(191347,'74553','origin','no_filters','BlockBox','catalog-content',1),(191348,'74554','origin','block-191347','BlockBox','',4),(191349,'74555','origin','block-191348','catalog\\CountsItems','',1),(191350,'74556','origin','block-191348-2','catalog\\Paging','',1),(191351,'74557','origin','block-191347','Listing','',3),(191352,'74558','origin','block-191347','catalog\\Title','',1),(191353,'74559','origin','block-191347','catalog\\B2bAddButton','',5),(191354,'74560','origin','block-191347','BlockBox','',2),(191355,'74561','origin','block-191354','BlockBox','catalog-features',3),(191356,'74562','origin','block-191355','HeaderStock','',5),(191357,'74563','origin','block-191355','catalog\\ListingLook','',1),(191358,'74564','origin','block-191355','catalog\\CompareButton','',2),(191359,'74565','origin','block-191355','catalog\\ItemsOnPage','',4),(191360,'74566','origin','block-191355','catalog\\Sorting','',3),(191361,'74567','origin','block-191354','catalog\\Image','',1),(191362,'74568','origin','order_history','BlockBox','',1),(191363,'74569','origin','block-191362','BlockBox','',1),(191364,'74570','origin','block-191363','WidgetsAria','',1),(191384,'74571','origin','block-191363-2','Html_box','',1),(191385,'74572','origin','block-191363-2','account\\OrdersHistory','',2),(191386,'74573','origin','order_history_info','BlockBox','',1),(191387,'74574','origin','block-191386','BlockBox','',1),(191388,'74575','origin','block-191387','WidgetsAria','',1),(191408,'74576','origin','block-191387-2','account\\OrderInvoiceButton','',3),(191409,'74577','origin','block-191387-2','account\\OrderSubTotals','',10),(191410,'74578','origin','block-191387-2','account\\OrderPayButton','',5),(191411,'74579','origin','block-191387-2','BlockBox','',13),(191412,'74580','origin','block-191411','account\\AccountLink','',1),(191413,'74581','origin','block-191411-2','account\\OrderInvoiceButton','',1),(191414,'74582','origin','block-191387-2','Html_box','',8),(191415,'74583','origin','block-191387-2','account\\OrderHistory','',12),(191416,'74584','origin','block-191387-2','account\\OrderCancelAndReorder','',4),(191417,'74585','origin','block-191387-2','account\\OrderHeading','',1),(191418,'74586','origin','block-191387-2','account\\OrderDownload','',6),(191419,'74587','origin','block-191387-2','Html_box','',11),(191420,'74588','origin','block-191387-2','account\\OrderProducts','',9),(191421,'74589','origin','block-191387-2','account\\OrderReorderButton','',2),(191422,'74590','origin','block-191387-2','BlockBox','',7),(191423,'74591','origin','block-191422','BlockBox','',2),(191424,'74592','origin','block-191423','Html_box','',1),(191425,'74593','origin','block-191423','account\\OrderData','',2),(191426,'74594','origin','block-191422','BlockBox','',1),(191427,'74595','origin','block-191426','Html_box','',1),(191428,'74596','origin','block-191426','account\\OrderData','',2),(191429,'74597','origin','block-191422','BlockBox','',3),(191430,'74598','origin','block-191429','account\\OrderTracking','',2),(191431,'74599','origin','block-191429','Html_box','',1),(191432,'74600','origin','block-191429','account\\AccountLink','',3),(191433,'74601','origin','block-191422-2','BlockBox','',2),(191434,'74602','origin','block-191433','account\\OrderData','',2),(191435,'74603','origin','block-191433','Html_box','',1),(191436,'74604','origin','block-191422-2','BlockBox','',1),(191437,'74605','origin','block-191436','account\\OrderData','',2),(191438,'74606','origin','block-191436','Html_box','',1),(191439,'74607','origin','block-191422-3','BlockBox','',2),(191440,'74608','origin','block-191439','account\\OrderData','',2),(191441,'74609','origin','block-191439','Html_box','',1),(191442,'74610','origin','block-191422-3','BlockBox','',1),(191443,'74611','origin','block-191442','Html_box','',1),(191444,'74612','origin','block-191442','account\\OrderData','',2),(191445,'74613','origin','order_pay','BlockBox','',1),(191446,'74614','origin','block-191445','BlockBox','',1),(191447,'74615','origin','block-191446','WidgetsAria','',1),(191467,'74616','origin','block-191446-2','account\\OrderProducts','',4),(191468,'74617','origin','block-191446-2','BlockBox','',2),(191469,'74618','origin','block-191468','BlockBox','',1),(191470,'74619','origin','block-191469','Html_box','',1),(191471,'74620','origin','block-191469','account\\OrderData','',2),(191472,'74621','origin','block-191468','BlockBox','',4),(191473,'74622','origin','block-191472','account\\OrderData','',2),(191474,'74623','origin','block-191472','Html_box','',1),(191475,'74624','origin','block-191468-2','BlockBox','',1),(191476,'74625','origin','block-191475','Html_box','',1),(191477,'74626','origin','block-191475','account\\OrderData','',2),(191478,'74627','origin','block-191468-2','BlockBox','',2),(191479,'74628','origin','block-191478','account\\OrderData','',2),(191480,'74629','origin','block-191478','Html_box','',1),(191481,'74630','origin','block-191468-3','BlockBox','',2),(191482,'74631','origin','block-191481','Html_box','',1),(191483,'74632','origin','block-191481','account\\OrderData','',2),(191484,'74633','origin','block-191468-3','BlockBox','',1),(191485,'74634','origin','block-191484','account\\OrderData','',2),(191486,'74635','origin','block-191484','Html_box','',1),(191487,'74636','origin','block-191446-2','UpdateAndPay\\PayForm','',6),(191488,'74637','origin','block-191446-2','Html_box','',3),(191489,'74638','origin','block-191446-2','account\\OrderHeading','',1),(191490,'74639','origin','block-191446-2','account\\OrderSubTotals','',5),(191491,'74640','origin','packingslip','invoice\\Container','',2),(191492,'74641','origin','block-191491','BlockBox','',1),(191493,'74642','origin','block-191492','Logo','',1),(191494,'74643','origin','block-191492-2','BlockBox','',3),(191495,'74644','origin','block-191494','Text','',2),(191496,'74645','origin','block-191494-2','invoice\\StoreEmail','',1),(191497,'74646','origin','block-191492-2','BlockBox','',2),(191498,'74647','origin','block-191497','Text','',2),(191499,'74648','origin','block-191497-2','invoice\\StorePhone','',1),(191500,'74649','origin','block-191492-2','BlockBox','',1),(191501,'74650','origin','block-191500','invoice\\StoreAddress','',1),(191502,'74651','origin','block-191492-2','BlockBox','',4),(191503,'74652','origin','block-191502','Text','',2),(191504,'74653','origin','block-191502-2','invoice\\StoreSite','',1),(191505,'74654','origin','block-191491','packingslip\\Products','',3),(191506,'74655','origin','block-191491','BlockBox','',4),(191507,'74656','origin','block-191506','invoice\\StoreAddress','',2),(191508,'74657','origin','block-191506','Text','',1),(191509,'74658','origin','block-191491','BlockBox','',2),(191510,'74659','origin','block-191509','BlockBox','',2),(191511,'74660','origin','block-191510','BlockBox','',1),(191512,'74661','origin','block-191511','invoice\\ShippingAddress','',2),(191513,'74662','origin','block-191511','Text','',1),(191514,'74663','origin','block-191510-2','BlockBox','',1),(191515,'74664','origin','block-191514','Text','',1),(191516,'74665','origin','block-191514','invoice\\CustomerName','',2),(191517,'74666','origin','block-191514','invoice\\CustomerEmail','',6),(191518,'74667','origin','block-191514','Text','',3),(191519,'74668','origin','block-191514','invoice\\CustomerPhone','',4),(191520,'74669','origin','block-191514','Text','',5),(191521,'74670','origin','block-191509','BlockBox','',3),(191522,'74671','origin','block-191521','BlockBox','',1),(191523,'74672','origin','block-191522','invoice\\ShippingMethod','',2),(191524,'74673','origin','block-191522','Text','',1),(191525,'74674','origin','block-191521-2','BlockBox','',1),(191526,'74675','origin','block-191525','invoice\\ShippingMethod','',2),(191527,'74676','origin','block-191525','Text','',1),(191528,'74677','origin','block-191509-2','invoice\\AddressQrcode','',1),(191529,'74678','origin','password_forgotten','BlockBox','',1),(191530,'74679','origin','block-191529','BlockBox','',2),(191531,'74680','origin','block-191530-2','Html_box','',1),(191532,'74681','origin','block-191530-2','login\\PasswordForgotten','',2),(191533,'74682','origin','block-191529','Html_box','',1),(191534,'74683','origin','pdf','invoice\\Container','',1),(191535,'74684','origin','block-191534','BlockBox','',1),(191536,'74685','origin','block-191535','BlockBox','',1),(191537,'74686','origin','block-191536','BlockBox','',1),(191538,'74687','origin','block-191537','pdf\\ProductElement','',1),(191539,'74688','origin','block-191536','BlockBox','',2),(191540,'74689','origin','block-191539','pdf\\ProductElement','',1),(191541,'74690','origin','block-191539-2','pdf\\ProductElement','',2),(191542,'74691','origin','block-191539-2','pdf\\ProductElement','',1),(191543,'74692','origin','block-191535-2','BlockBox','',1),(191544,'74693','origin','block-191543','BlockBox','',2),(191545,'74694','origin','block-191544','pdf\\ProductElement','',1),(191546,'74695','origin','block-191544-2','pdf\\ProductElement','',2),(191547,'74696','origin','block-191544-2','pdf\\ProductElement','',1),(191548,'74697','origin','block-191543','BlockBox','',1),(191549,'74698','origin','block-191548','pdf\\ProductElement','',1),(191550,'74699','origin','pdf_category','pdf\\CategoryName','',2),(191551,'74700','origin','pdf_category','pdf\\CategoryImage','',1),(191552,'74701','origin','pdf_cover','invoice\\Container','',1),(191553,'74702','origin','block-191552','Logo','',1),(191554,'74703','origin','block-191552','Text','',3),(191555,'74704','origin','pdf_footer','BlockBox','',1),(191556,'74705','origin','block-191555-2','pdf\\PageNumber','',1),(191557,'74706','origin','pdf_header','pdf\\CategoryName','',1),(191558,'74707','origin','personal_catalog','BlockBox','',1),(191559,'74708','origin','block-191558','BlockBox','',1),(191560,'74709','origin','block-191559','WidgetsAria','',1),(191580,'74710','origin','block-191559-2','Html_box','',1),(191581,'74711','origin','block-191559-2','account\\AccountLink','',3),(191582,'74712','origin','block-191559-2','account\\PersonalCatalog','',2),(191583,'74713','origin','points_earnt_history','BlockBox','',1),(191584,'74714','origin','block-191583','Html_box','',1),(191585,'74715','origin','block-191583','BonusActions\\widgets\\PointsEarntHistory','',2),(191586,'74716','origin','posts','BlockBox','',1),(191587,'74717','origin','block-191586','Breadcrumb','',2),(191588,'74718','origin','block-191586','Html_box','',1),(191589,'74719','origin','block-191586','Communication\\Post','',3),(191590,'74720','origin','product','BlockBox','product-content',2),(191591,'74721','origin','block-191590','product\\CustomersActivity','',11),(191592,'74722','origin','block-191590','BlockBox','product-image',2),(191593,'74724','origin','block-191592','product\\Images','',2),(191594,'74725','origin','block-191592','product\\ImageMapProduct','',4),(191595,'74726','origin','block-191592','product\\PromotionIcons','',1),(191596,'74727','origin','block-191592-2','BlockBox','product-side',10),(191597,'74728','origin','block-191596','product\\ButtonsQuote','',3),(191598,'74729','origin','block-191596','BlockBox','',1),(191599,'74730','origin','block-191598','product\\Price','',1),(191600,'74731','origin','block-191598-2','product\\Quantity','',1),(191601,'74732','origin','block-191596','BonusActions\\widgets\\BonusPointsProduct','',4),(191602,'1694165842.4776','origin','block-191596','product\\QuantityDiscounts','',2),(191603,'74733','origin','block-191596-2','product\\Buttons','',1),(191604,'74734','origin','block-191596-2','product\\ButtonsSample','',2),(191605,'74735','origin','block-191592-2','product\\DescriptionShort','',6),(191606,'74737','origin','block-191592-2','product\\Documents','',5),(191607,'74738','origin','block-191592-2','product\\AvailableInWarehouses','',9),(191608,'74739','origin','block-191592-2','BlockBox','',11),(191609,'74741','origin','block-191608','product\\PersonalCatalogButton','',1),(191610,'74743','origin','block-191592-2','product\\Brand','',4),(191611,'74744','origin','block-191592-2','product\\Model','',3),(191612,'74745','origin','block-191592-2','product\\Name','',2),(191613,'74746','origin','block-191592-2','product\\Stock','',1),(191614,'1642500646.3623','origin','block-191592-2','product\\Attributes','',7),(191615,'74749','origin','block-191590','product\\Configurator','',5),(191616,'74750','origin','block-191590','Breadcrumb','',1),(191617,'74752','origin','block-191590','Tabs','',6),(191618,'74753','origin','block-191617-1','product\\Description','',2),(191619,'74754','origin','block-191617-1','product\\Properties','',1),(191620,'74755','origin','block-191617-2','product\\Reviews','',1),(191621,'74757','origin','block-191590','product\\InBundles','',4),(191622,'74758','origin','block-191590','product\\Bundle','',3),(191623,'1694166186.2638','origin','block-191590','BlockBox','',7),(191624,'74751','origin','block-191623','product\\AlsoPurchased','10',2),(191625,'1694166209.3278','origin','block-191623','Html_box','',1),(191626,'1694166191.5684','origin','block-191590','BlockBox','',9),(191627,'74747','origin','block-191626','ViewedProducts','4',2),(191628,'1694166222.3382','origin','block-191626','Html_box','',1),(191629,'74761','origin','product-bottom','product\\Properties','',1),(191630,'74762','origin','product-tabs','product\\Reviews','',2),(191631,'74763','origin','product-tabs','product\\Description','',1),(191632,'74764','origin','product-top-left','product\\Images','',1),(191633,'74765','origin','product-top-right','product\\Price','',2),(191634,'74766','origin','product-top-right','product\\Quantity','',5),(191635,'74767','origin','product-top-right','product\\Quantity','',6),(191636,'74768','origin','product-top-right','product\\Attributes','',3),(191637,'74769','origin','product-top-right','product\\Name','',1),(191638,'74770','origin','product-top-right','product\\Buttons','',6),(191639,'74771','origin','productListing','BlockBox','listing-item',1),(191640,'74773','origin','block-191639','productListing\\model','',7),(191641,'74774','origin','block-191639','BonusActions\\widgets\\BonusPointsProductListing','',6),(191642,'74775','origin','block-191639','productListing\\description','',5),(191643,'74776','origin','block-191639','productListing\\buyButton','',9),(191644,'74777','origin','block-191639','productListing\\rating','',3),(191645,'74778','origin','block-191639','productListing\\image','',1),(191646,'74779','origin','block-191639','BlockBox','',8),(191647,'74780','origin','block-191646','productListing\\price','',1),(191648,'74781','origin','block-191646-2','productListing\\qtyInput','',1),(191649,'74782','origin','block-191639','productListing\\name','',4),(191650,'74783','origin','block-191639','productListing\\stock','',2),(191651,'75903','origin','block-191639','productListing\\compare','',10),(191652,'74785','origin','products','BlockBox','catalog-content',1),(191653,'74786','origin','block-191652','BlockBox','catalog-side',4),(191654,'74787','origin','block-191653','Filters','',1),(191655,'74788','origin','block-191653','HeaderStock','',2),(191656,'74789','origin','block-191653-2','catalog\\B2bAddButton','',4),(191657,'74790','origin','block-191653-2','BlockBox','catalog-features',2),(191658,'74791','origin','block-191657','catalog\\Sorting','',3),(191659,'74792','origin','block-191657','catalog\\ListingLook','',1),(191660,'74793','origin','block-191657','catalog\\ItemsOnPage','',4),(191661,'74794','origin','block-191657','catalog\\CompareButton','',2),(191662,'74795','origin','block-191653-2','BlockBox','',5),(191663,'74796','origin','block-191662','catalog\\CountsItems','',1),(191664,'74797','origin','block-191662-2','catalog\\Paging','',1),(191665,'74798','origin','block-191653-2','Listing','',3),(191666,'74799','origin','block-191652','catalog\\Title','',1),(191667,'74800','origin','block-191652','BlockBox','',3),(191668,'74801','origin','block-191667','catalog\\Image','',1),(191669,'75886','origin','products-list','packingslip\\AllProductsList','',2),(191670,'74802','origin','promotions','BlockBox','',1),(191671,'74803','origin','block-191670','promotions\\PromoList','',2),(191672,'74804','origin','block-191670','Html_box','',1),(191673,'74805','origin','purchase','invoice\\Container','',1),(191674,'74806','origin','block-191673','invoice\\Products','',3),(191675,'74807','origin','block-191673','BlockBox','',5),(191676,'74808','origin','block-191675','Text','',1),(191677,'74809','origin','block-191675','invoice\\StoreAddress','',8),(191678,'74810','origin','block-191675-2','Text','',2),(191679,'74811','origin','block-191675-2','Logo','',1),(191680,'74812','origin','block-191675-3','BlockBox','',3),(191681,'74813','origin','block-191680','Text','',1),(191682,'74814','origin','block-191680-2','invoice\\StoreEmail','',1),(191683,'74815','origin','block-191675-3','Text','',1),(191684,'74816','origin','block-191675-3','BlockBox','',2),(191685,'74817','origin','block-191684','Text','',1),(191686,'74818','origin','block-191684-2','invoice\\StorePhone','',1),(191687,'74819','origin','block-191673','BlockBox','',1),(191688,'74820','origin','block-191687','Logo','',1),(191689,'74821','origin','block-191687-2','BlockBox','',2),(191690,'74822','origin','block-191689','Text','',1),(191691,'74823','origin','block-191689-2','invoice\\StorePhone','',1),(191692,'74824','origin','block-191687-2','BlockBox','',4),(191693,'74825','origin','block-191692','Text','',1),(191694,'74826','origin','block-191692-2','invoice\\StoreSite','',1),(191695,'74827','origin','block-191687-2','BlockBox','',1),(191696,'74828','origin','block-191695','invoice\\StoreAddress','',1),(191697,'74829','origin','block-191687-2','BlockBox','',3),(191698,'74830','origin','block-191697','Text','',1),(191699,'74831','origin','block-191697-2','invoice\\StoreEmail','',1),(191700,'74832','origin','block-191673','BlockBox','',2),(191701,'74833','origin','block-191700','BlockBox','',7),(191702,'74834','origin','block-191701','BlockBox','',1),(191703,'74835','origin','block-191702','invoice\\BillingAddress','',2),(191704,'74836','origin','block-191702','Text','',1),(191705,'74837','origin','block-191701-2','BlockBox','',1),(191706,'74838','origin','block-191705','invoice\\CustomerEmail','',6),(191707,'74839','origin','block-191705','Text','',5),(191708,'74840','origin','block-191705','invoice\\CustomerPhone','',4),(191709,'74841','origin','block-191705','invoice\\CustomerName','',2),(191710,'74842','origin','block-191705','Text','',3),(191711,'74843','origin','block-191705','Text','',1),(191712,'74844','origin','block-191700-2','invoice\\OrderId','',1),(191713,'74845','origin','block-191700-2','Text','',2),(191714,'74846','origin','block-191700-2','invoice\\PaymentDate','',3),(191715,'74847','origin','block-191673','BlockBox','',4),(191716,'74848','origin','block-191715','BlockBox','',1),(191717,'74849','origin','block-191716','invoice\\ShippingAddress','',2),(191718,'74850','origin','block-191716','Text','',1),(191719,'74851','origin','quotations','BlockBox','',1),(191720,'74852','origin','block-191719','BlockBox','',1),(191721,'74853','origin','block-191720','WidgetsAria','',1),(191741,'74854','origin','block-191720-2','Html_box','',1),(191742,'74855','origin','block-191720-2','Quotations\\QuotationsHistory','',2),(191743,'74856','origin','quotation_info','BlockBox','',1),(191744,'74857','origin','block-191743','BlockBox','',1),(191745,'74858','origin','block-191744','WidgetsAria','',1),(191765,'74859','origin','block-191744-2','BlockBox','',5),(191766,'74860','origin','block-191765','BlockBox','',1),(191767,'74861','origin','block-191766','Quotations\\QuotationData','',2),(191768,'74862','origin','block-191766','Html_box','',1),(191769,'74863','origin','block-191765','BlockBox','',4),(191770,'74864','origin','block-191769','Html_box','',1),(191771,'74865','origin','block-191769','Quotations\\QuotationData','',2),(191772,'74866','origin','block-191765-2','BlockBox','',2),(191773,'74867','origin','block-191772','Html_box','',1),(191774,'74868','origin','block-191772','Quotations\\QuotationData','',2),(191775,'74869','origin','block-191765-2','BlockBox','',1),(191776,'74870','origin','block-191775','Html_box','',1),(191777,'74871','origin','block-191775','Quotations\\QuotationData','',2),(191778,'74872','origin','block-191765-3','BlockBox','',1),(191779,'74873','origin','block-191778','Quotations\\QuotationData','',2),(191780,'74874','origin','block-191778','Html_box','',1),(191781,'74875','origin','block-191765-3','BlockBox','',2),(191782,'74876','origin','block-191781','Quotations\\QuotationData','',2),(191783,'74877','origin','block-191781','Html_box','',1),(191784,'74878','origin','block-191744-2','Html_box','',6),(191785,'74879','origin','block-191744-2','Quotations\\QuotationHistory','',10),(191786,'74880','origin','block-191744-2','Html_box','',9),(191787,'74881','origin','block-191744-2','Quotations\\QuotationProducts','',7),(191788,'74882','origin','block-191744-2','Quotations\\QuotationSubTotal','',8),(191789,'74883','origin','block-191744-2','BlockBox','',12),(191790,'74884','origin','block-191789','account\\AccountLink','',1),(191791,'74885','origin','block-191744-2','Html_box','',4),(191792,'74886','origin','quote','BlockBox','',1),(191793,'74887','origin','block-191792','cart\\CartTabs','',1),(191794,'74888','origin','block-191793','BlockBox','',1),(191795,'74889','origin','block-191794','quote\\Products','',1),(191796,'74890','origin','block-191794-2','BlockBox','',1),(191797,'74891','origin','block-191796','BlockBox','',1),(191798,'74892','origin','block-191797','quote\\CheckoutBtn','',2),(191799,'74893','origin','block-191793','Quotations\\QuotationSubTotal','',2),(191800,'74894','origin','review','BlockBox','',1),(191801,'74895','origin','block-191800','BlockBox','',1),(191802,'74896','origin','block-191801','WidgetsAria','',1),(191822,'74897','origin','block-191801-2','Html_box','',1),(191823,'74898','origin','block-191801-2','account\\Reviews','',2),(191824,'74899','origin','reviews','BlockBox','',1),(191825,'74900','origin','block-191824','reviews\\Heading','',1),(191826,'74901','origin','block-191824','reviews\\Content','',2),(191827,'74902','origin','rma_document','invoice\\Container','',1),(191828,'74903','origin','block-191827','BlockBox','',1),(191829,'74904','origin','block-191828','BlockBox','',1),(191830,'74905','origin','block-191829','BlockBox','',2),(191831,'74906','origin','block-191830','Html_box','',1),(191832,'74907','origin','block-191830-2','Html_box','',1),(191833,'74908','origin','block-191829','BlockBox','',5),(191834,'74909','origin','block-191833','Html_box','',1),(191835,'74910','origin','block-191833-2','Html_box','',1),(191836,'74911','origin','block-191829','BlockBox','',4),(191837,'74912','origin','block-191836','Html_box','',1),(191838,'74913','origin','block-191836-2','Html_box','',1),(191839,'74914','origin','block-191829','BlockBox','',3),(191840,'74915','origin','block-191839','Html_box','',1),(191841,'74916','origin','block-191839-2','Html_box','',1),(191842,'74917','origin','block-191829','BlockBox','',1),(191843,'74918','origin','block-191842','Html_box','',1),(191844,'74919','origin','block-191842','Html_box','',2),(191845,'74920','origin','block-191828-2','BlockBox','',1),(191846,'74921','origin','block-191845','Html_box','',2),(191847,'74922','origin','block-191845','Logo','',1),(191848,'74923','origin','block-191828-2','BlockBox','',2),(191849,'74924','origin','block-191848','BlockBox','',5),(191850,'74925','origin','block-191849','BlockBox','',1),(191851,'74926','origin','block-191850','Html_box','',1),(191852,'74927','origin','block-191850-2','Rma\\DocumentData','',1),(191853,'74928','origin','block-191849-2','BlockBox','',1),(191854,'74929','origin','block-191853','Html_box','',1),(191855,'74930','origin','block-191853-2','Rma\\DocumentData','',1),(191856,'74931','origin','block-191848','BlockBox','',4),(191857,'74932','origin','block-191856','BlockBox','',1),(191858,'74933','origin','block-191857','Html_box','',1),(191859,'74934','origin','block-191857-2','Rma\\DocumentData','',1),(191860,'74935','origin','block-191856-2','BlockBox','',1),(191861,'74936','origin','block-191860','Html_box','',1),(191862,'74937','origin','block-191860-2','Rma\\DocumentData','',1),(191863,'74938','origin','block-191848','BlockBox','',3),(191864,'74939','origin','block-191863','BlockBox','',1),(191865,'74940','origin','block-191864','Html_box','',1),(191866,'74941','origin','block-191864-2','Rma\\DocumentData','',1),(191867,'74942','origin','block-191863-2','BlockBox','',1),(191868,'74943','origin','block-191867','Html_box','',1),(191869,'74944','origin','block-191867-2','Rma\\DocumentData','',1),(191870,'74945','origin','block-191848','BlockBox','',2),(191871,'74946','origin','block-191870','Html_box','',1),(191872,'74947','origin','block-191870-2','Rma\\DocumentData','',1),(191873,'74948','origin','block-191848','BlockBox','',1),(191874,'74949','origin','block-191873','BlockBox','',1),(191875,'74950','origin','block-191874','Html_box','',1),(191876,'74951','origin','block-191874-2','Rma\\DocumentData','',1),(191877,'74952','origin','block-191873-2','BlockBox','',1),(191878,'74953','origin','block-191877','Html_box','',1),(191879,'74954','origin','block-191877-2','Rma\\DocumentData','',1),(191880,'74955','origin','block-191828-2','BlockBox','',3),(191881,'74956','origin','block-191880','BlockBox','',1),(191882,'74957','origin','block-191881','Html_box','',1),(191883,'74958','origin','block-191881-2','Rma\\DocumentData','',1),(191884,'74959','origin','block-191880-2','BlockBox','',1),(191885,'74960','origin','block-191884','Html_box','',1),(191886,'74961','origin','block-191884-2','Rma\\DocumentData','',1),(191887,'74962','origin','block-191827','BlockBox','',2),(191888,'74963','origin','block-191887','Html_box','',1),(191889,'74964','origin','block-191887','Rma\\Products','',2),(191890,'74965','origin','block-191827','BlockBox','',3),(191891,'74966','origin','block-191890','BlockBox','',1),(191892,'74967','origin','block-191891','BlockBox','',1),(191893,'74968','origin','block-191892','BlockBox','',5),(191894,'74969','origin','block-191893','Html_box','',1),(191895,'74970','origin','block-191893-2','invoice\\StoreAddress','',2),(191896,'74971','origin','block-191893-2','Html_box','',1),(191897,'74972','origin','block-191892','BlockBox','',4),(191898,'74973','origin','block-191897','Html_box','',1),(191899,'74974','origin','block-191897-2','Html_box','',1),(191900,'74975','origin','block-191892','BlockBox','',2),(191901,'74976','origin','block-191900','Html_box','',1),(191902,'74977','origin','block-191900-2','Html_box','',1),(191903,'74978','origin','block-191892','BlockBox','',1),(191904,'74979','origin','block-191903','Html_box','',1),(191905,'74980','origin','block-191892','BlockBox','',3),(191906,'74981','origin','block-191905','Html_box','',1),(191907,'74982','origin','block-191905-2','Html_box','',1),(191908,'74983','origin','block-191892','BlockBox','',6),(191909,'74984','origin','block-191908','Html_box','',1),(191910,'74985','origin','block-191891-2','BlockBox','',1),(191911,'74986','origin','block-191910','BlockBox','',1),(191912,'74987','origin','block-191911','BlockBox','',1),(191913,'74988','origin','block-191912','Rma\\DocumentData','',2),(191914,'74989','origin','block-191912-3','BlockBox','',1),(191915,'74990','origin','block-191914','Html_box','',1),(191916,'74991','origin','block-191914-2','Rma\\DocumentData','',1),(191917,'74992','origin','block-191911','BlockBox','',2),(191918,'74993','origin','block-191917-2','invoice\\StoreAddress','',1),(191919,'74994','origin','block-191891-2','BlockBox','',2),(191920,'74995','origin','block-191919','Html_box','',1),(191921,'74996','origin','block-191919','Html_box','',2),(191922,'74997','origin','block-191919','Html_box','',3),(191923,'74998','origin','block-191919','Html_box','',4),(191924,'74999','origin','block-191919','Html_box','',5),(191925,'75000','origin','block-191891-2','BlockBox','',4),(191926,'75001','origin','block-191925','Html_box','',1),(191927,'75002','origin','block-191925-2','Html_box','',1),(191928,'75003','origin','block-191925-3','BlockBox','',1),(191929,'75004','origin','block-191928','Html_box','',1),(191930,'75005','origin','block-191928-2','Html_box','',1),(191931,'75006','origin','block-191891-2','BlockBox','',3),(191932,'75007','origin','block-191931','Html_box','',1),(191933,'75008','origin','block-191931-2','Html_box','',1),(191934,'75009','origin','block-191931-3','BlockBox','',1),(191935,'75010','origin','block-191934','Html_box','',1),(191936,'75011','origin','block-191934-2','Html_box','',1),(191937,'75012','origin','rows','BlockBox','',1),(191938,'75013','origin','block-191937','BlockBox','',2),(191939,'75014','origin','block-191938','BlockBox','',2),(191940,'75015','origin','block-191939','BonusActions\\widgets\\BonusPointsProductListing','',1),(191941,'75016','origin','block-191939','productListing\\image','',2),(191942,'75017','origin','block-191939','BlockBox','',3),(191943,'75018','origin','block-191942','productListing\\rating','',1),(191944,'75019','origin','block-191942','productListing\\ratingCounts','',2),(191945,'75020','origin','block-191939-2','productListing\\name','',1),(191946,'75021','origin','block-191939-2','productListing\\description','',2),(191947,'75022','origin','block-191939-2','productListing\\model','',3),(191948,'75023','origin','block-191939-2','productListing\\attributes','',4),(191949,'75024','origin','block-191938-2','BlockBox','listing-item',1),(191950,'75025','origin','block-191949','productListing\\qtyInput','',3),(191951,'75026','origin','block-191949','productListing\\price','',2),(191952,'75027','origin','block-191949','productListing\\compare','',5),(191953,'75028','origin','block-191949','productListing\\buyButton','',4),(191954,'75030','origin','block-191949','productListing\\stock','',1),(191955,'75031','origin','sample','BlockBox','',1),(191956,'75032','origin','block-191955','cart\\CartTabs','',1),(191957,'75033','origin','block-191956','BlockBox','',1),(191958,'75034','origin','block-191957','sample\\Products','',1),(191959,'75035','origin','block-191957-2','BlockBox','',1),(191960,'75036','origin','block-191959','BlockBox','',1),(191961,'75037','origin','block-191960','sample\\CheckoutBtn','',1),(191962,'75038','origin','samples','BlockBox','',1),(191963,'75039','origin','block-191962','BlockBox','',1),(191964,'75040','origin','block-191963','WidgetsAria','',1),(191984,'75041','origin','block-191963-2','Html_box','',1),(191985,'75042','origin','block-191963-2','Samples\\SamplesHistory','',2),(191986,'75043','origin','sample_info','BlockBox','',1),(191987,'75044','origin','block-191986','BlockBox','',1),(191988,'75045','origin','block-191987','WidgetsAria','',1),(192008,'75046','origin','block-191987-2','Html_box','',1),(192009,'75047','origin','block-191987-2','BlockBox','',8),(192010,'75048','origin','block-192009','account\\AccountLink','',1),(192011,'75049','origin','block-191987-2','Samples\\SampleHistory','',7),(192012,'75050','origin','block-191987-2','Html_box','',3),(192013,'75051','origin','block-191987-2','Samples\\SampleSubTotal','',5),(192014,'75052','origin','block-191987-2','Samples\\SampleProducts','',4),(192015,'75053','origin','block-191987-2','Html_box','',6),(192016,'75054','origin','block-191987-2','BlockBox','',2),(192017,'75055','origin','block-192016','BlockBox','',4),(192018,'75056','origin','block-192017','Html_box','',1),(192019,'75057','origin','block-192017','Samples\\SampleData','',2),(192020,'75058','origin','block-192016','BlockBox','',1),(192021,'75059','origin','block-192020','Samples\\SampleData','',2),(192022,'75060','origin','block-192020','Html_box','',1),(192023,'75061','origin','block-192016-2','BlockBox','',2),(192024,'75062','origin','block-192023','Samples\\SampleData','',2),(192025,'75063','origin','block-192023','Html_box','',1),(192026,'75064','origin','block-192016-2','BlockBox','',1),(192027,'75065','origin','block-192026','Samples\\SampleData','',2),(192028,'75066','origin','block-192026','Html_box','',1),(192029,'75067','origin','block-192016-3','BlockBox','',2),(192030,'75068','origin','block-192029','Samples\\SampleData','',2),(192031,'75069','origin','block-192029','Html_box','',1),(192032,'75070','origin','block-192016-3','BlockBox','',1),(192033,'75071','origin','block-192032','Samples\\SampleData','',2),(192034,'75072','origin','block-192032','Html_box','',1),(192035,'75073','origin','sitemap','BlockBox','',1),(192036,'75074','origin','block-192035','Html_box','',1),(192037,'75075','origin','block-192035','BlockBox','',2),(192038,'75076','origin','block-192037','Html_box','',1),(192039,'75077','origin','block-192037','Html_box','',5),(192040,'75078','origin','block-192037','Html_box','',3),(192041,'75079','origin','block-192037','sitemap\\InfoPages','',2),(192042,'75080','origin','block-192037','sitemap\\Categories','',4),(192043,'75081','origin','block-192037','Menu','Account box',6),(192044,'75082','origin','block-192037-2','sitemap\\DeliveryLocation','',2),(192045,'75083','origin','block-192037-2','Html_box','',1),(192046,'75084','origin','subscribe','BlockBox','',1),(192047,'75085','origin','block-192046','Html_box','',3),(192048,'75086','origin','block-192046','subscribers\\UnsubscribeForm','',4),(192049,'75087','origin','block-192046','Html_box','',1),(192050,'75088','origin','block-192046','subscribers\\SubscribeForm','',2),(192051,'75089','origin','subscribed','BlockBox','',1),(192052,'75090','origin','block-192051','Html_box','',1),(192053,'94795','origin','subscription','BlockBox','',2),(192054,'94796','origin','block-192053','BlockBox','',1),(192055,'94797','origin','block-192054','WidgetsAria','',1),(192075,'94798','origin','block-192054-2','Html_box','',2),(192076,'94799','origin','block-192054-2','Html_box','',3),(192077,'94800','origin','block-192054-2','account\\Subscription','',4),(192078,'1694099590.22143','origin','success','BlockBox','',1),(192079,'1694099590.340695','origin','block-192078','BlockBox','',2),(192080,'1694099590.343733','origin','block-192079','BlockBox','',3),(192081,'1694099590.345212','origin','block-192080','BlockBox','',2),(192082,'1694099590.34749','origin','block-192081','BlockBox','',1),(192083,'1694099590.3531','origin','block-192082','order\\ShippingMethod','',6),(192084,'1694099590.351567','origin','block-192082','order\\DeliveryAddress','',3),(192085,'1694099590.35337','origin','block-192082','Html_box','',7),(192086,'1694099590.360420','origin','block-192082','Html_box','',5),(192087,'1694099590.362714','origin','block-192082','Html_box','',1),(192088,'1694099590.36422','origin','block-192082','checkout\\ContactConfirm','',9),(192089,'1694099590.365625','origin','block-192082','Html_box','',2),(192090,'1694099590.367789','origin','block-192081-2','BlockBox','',1),(192091,'1694099590.369488','origin','block-192090','order\\PaymentMethod','',6),(192092,'1694099590.370690','origin','block-192090','order\\BillingAddress','',3),(192093,'1694099590.371953','origin','block-192090','Html_box','',5),(192094,'1694099590.373633','origin','block-192090','Html_box','',1),(192095,'1694099590.37590','origin','block-192090','Html_box','',2),(192096,'1694099590.376747','origin','block-192080','Html_box','',1),(192097,'1694099590.38020','origin','block-192079-2','BlockBox','',1),(192098,'1694099590.381373','origin','block-192097','success\\PrintBtn','',3),(192099,'1694099590.382864','origin','block-192097','success\\ContinueBtn','',4),(192100,'1694099590.384241','origin','block-192097','order\\Products','',1),(192101,'1694099590.385486','origin','block-192097','order\\Totals','',2),(192102,'1694099590.386683','origin','block-192078','BlockBox','',1),(192103,'1694099590.387673','origin','block-192102','Html_box','',2),(192104,'1694099590.389337','origin','block-192102','order\\OrderNumber','',1),(192105,'75097','origin','success_q','BlockBox','',1),(192106,'75098','origin','block-192105','BlockBox','',1),(192107,'75099','origin','block-192106','BlockBox','',2),(192108,'75100','origin','block-192107','success\\ContinueBtn','',2),(192109,'75101','origin','block-192107','success\\PrintBtn','',1),(192110,'75102','origin','block-192106','Html_box','',1),(192111,'75107','origin','ticket','invoice\\Container','',1),(192112,'75108','origin','block-192111','BlockBox','',4),(192113,'75109','origin','block-192112','BlockBox','',1),(192114,'75110','origin','block-192113','invoice\\ShippingAddress','',2),(192115,'75111','origin','block-192113','Text','',1),(192116,'75112','origin','block-192112-2','BlockBox','',1),(192117,'75113','origin','block-192116','invoice\\Totals','',1),(192118,'75114','origin','block-192111','BlockBox','',5),(192119,'75115','origin','block-192118','Text','',1),(192120,'75116','origin','block-192118','invoice\\StoreAddress','',8),(192121,'75117','origin','block-192118-2','Logo','',1),(192122,'75118','origin','block-192118-2','Text','',2),(192123,'75119','origin','block-192118-3','Text','',1),(192124,'75120','origin','block-192118-3','BlockBox','',3),(192125,'75121','origin','block-192124','Text','',1),(192126,'75122','origin','block-192124-2','invoice\\StoreEmail','',1),(192127,'75123','origin','block-192118-3','BlockBox','',2),(192128,'75124','origin','block-192127','Text','',1),(192129,'75125','origin','block-192127-2','invoice\\StorePhone','',1),(192130,'75126','origin','block-192111','invoice\\Products','',3),(192131,'75127','origin','block-192111','BlockBox','',1),(192132,'75128','origin','block-192131-2','BlockBox','',3),(192133,'75129','origin','block-192132','Text','',1),(192134,'75130','origin','block-192132-2','invoice\\StoreEmail','',1),(192135,'75131','origin','block-192131-2','BlockBox','',4),(192136,'75132','origin','block-192135','Text','',1),(192137,'75133','origin','block-192135-2','invoice\\StoreSite','',1),(192138,'75134','origin','block-192131-2','BlockBox','',1),(192139,'75135','origin','block-192138','invoice\\StoreAddress','',1),(192140,'75136','origin','block-192131-2','BlockBox','',2),(192141,'75137','origin','block-192140','Text','',1),(192142,'75138','origin','block-192140-2','invoice\\StorePhone','',1),(192143,'75139','origin','block-192111','BlockBox','',2),(192144,'75140','origin','block-192143','BlockBox','',8),(192145,'75141','origin','block-192144','BlockBox','',1),(192146,'75142','origin','block-192145','Text','',1),(192147,'75143','origin','block-192145','invoice\\ShippingMethod','',2),(192148,'75144','origin','block-192144-2','BlockBox','',1),(192149,'75145','origin','block-192148','Text','',1),(192150,'75146','origin','block-192148','invoice\\ShippingMethod','',2),(192151,'75147','origin','block-192143','BlockBox','',7),(192152,'75148','origin','block-192151','BlockBox','',1),(192153,'75149','origin','block-192152','invoice\\BillingAddress','',2),(192154,'75150','origin','block-192152','Text','',1),(192155,'75151','origin','block-192151-2','BlockBox','',1),(192156,'75152','origin','block-192155','invoice\\CustomerName','',2),(192157,'75153','origin','block-192155','Text','',3),(192158,'75154','origin','block-192155','invoice\\CustomerEmail','',6),(192159,'75155','origin','block-192155','invoice\\CustomerPhone','',4),(192160,'75156','origin','block-192155','Text','',5),(192161,'75157','origin','block-192155','Text','',1),(192162,'75158','origin','block-192143-2','invoice\\PaymentDate','',3),(192163,'75159','origin','block-192143-2','Text','',2),(192164,'75160','origin','block-192143-2','Text','',4),(192165,'75161','origin','block-192143-2','invoice\\OrderId','',1),(192166,'75162','origin','block-192143-2','invoice\\PaymentMethod','',5),(192167,'75163','origin','block-192143-2','invoice\\OrderBarcode','',6),(192168,'75194','origin','tracking_numbers','BlockBox','',1),(192169,'75195','origin','block-192168','Html_box','',1),(192170,'75196','origin','block-192168','account\\OrderTracking','',2),(192171,'75418','origin','unsubscribed','BlockBox','',1),(192172,'75419','origin','block-192171','Html_box','',1),(192173,'75420','origin','update-and-pay-order_confirmation','BlockBox','',1),(192174,'75421','origin','block-192173','BlockBox','',3),(192175,'75422','origin','block-192174','BlockBox','',1),(192176,'75423','origin','block-192175','BlockBox','',1),(192177,'75424','origin','block-192176','BlockBox','',1),(192178,'75425','origin','block-192177','order\\ShippingMethod','',5),(192179,'75426','origin','block-192177','Html_box','',2),(192180,'75427','origin','block-192177','Html_box','',4),(192181,'75428','origin','block-192177','Html_box','',1),(192182,'75429','origin','block-192177','order\\Telephone','',8),(192183,'75430','origin','block-192177','Html_box','',6),(192184,'75431','origin','block-192177','order\\Name','',7),(192185,'75432','origin','block-192177','order\\Email','',9),(192186,'75433','origin','block-192177','order\\DeliveryAddress','',3),(192187,'75434','origin','block-192176-2','BlockBox','',1),(192188,'75435','origin','block-192187','order\\BillingAddress','',3),(192189,'75436','origin','block-192187','UpdateAndPay\\PayConfirm','',5),(192190,'75437','origin','block-192187','Html_box','',1),(192191,'75438','origin','block-192187','Html_box','',2),(192192,'75439','origin','block-192187','Html_box','',4),(192193,'75440','origin','block-192175','BlockBox','',3),(192194,'75441','origin','block-192193','order\\Products','',2),(192195,'75442','origin','block-192193','Html_box','',1),(192196,'75443','origin','block-192174-2','BlockBox','',1),(192197,'75444','origin','block-192196','Html_box','',1),(192198,'75445','origin','block-192196','checkout\\ContinueBtn','',3),(192199,'75446','origin','block-192196','order\\Totals','',2),(192200,'75447','origin','block-192173','account\\OrderHeading','',1),(192201,'75448','origin','update-and-pay-order_pay','BlockBox','',1),(192202,'75449','origin','block-192201','BlockBox','',3),(192203,'75450','origin','block-192202','BlockBox','',1),(192204,'75451','origin','block-192203','BlockBox','',1),(192205,'75452','origin','block-192204','BlockBox','',1),(192206,'75453','origin','block-192205','order\\DeliveryAddress','',3),(192207,'75454','origin','block-192205','order\\Email','',9),(192208,'75455','origin','block-192205','order\\Name','',7),(192209,'75456','origin','block-192205','Html_box','',6),(192210,'75457','origin','block-192205','order\\Telephone','',8),(192211,'75458','origin','block-192205','Html_box','',4),(192212,'75459','origin','block-192205','order\\ShippingMethod','',5),(192213,'75460','origin','block-192205','Html_box','',1),(192214,'75461','origin','block-192205','Html_box','',2),(192215,'75462','origin','block-192204-2','BlockBox','',1),(192216,'75463','origin','block-192215','Html_box','',1),(192217,'75464','origin','block-192215','Html_box','',2),(192218,'75465','origin','block-192215','Html_box','',4),(192219,'75466','origin','block-192215','order\\BillingAddress','',3),(192220,'75467','origin','block-192215','UpdateAndPay\\PayForm','',5),(192221,'75468','origin','block-192203','BlockBox','',3),(192222,'75469','origin','block-192221','Html_box','',1),(192223,'75470','origin','block-192221','order\\Products','',2),(192224,'75471','origin','block-192202-2','BlockBox','',1),(192225,'75472','origin','block-192224','order\\Totals','',2),(192226,'75473','origin','block-192224','checkout\\ContinueBtn','',3),(192227,'75474','origin','block-192224','Html_box','',1),(192228,'75475','origin','block-192201','account\\OrderHeading','',1),(192229,'75540','origin','wishlist','BlockBox','',1),(192230,'75541','origin','block-192229','BlockBox','',1),(192231,'75542','origin','block-192230','WidgetsAria','',1),(192232,'73374','origin','account-menu','BlockBox','',1),(192233,'73375','origin','block-192232','BlockBox','account-side',1),(192234,'73376','origin','block-192233','Html_box','',16),(192235,'73377','origin','block-192233','account\\AccountLink','',17),(192236,'73378','origin','block-192233','account\\AccountLink','',18),(192237,'73379','origin','block-192233','account\\AccountLink','',1),(192238,'73380','origin','block-192233','Html_box','',2),(192239,'73381','origin','block-192233','account\\AccountLink','',4),(192240,'73382','origin','block-192233','account\\AccountLink','',7),(192241,'73383','origin','block-192233','account\\AccountLink','',11),(192242,'73384','origin','block-192233','Html_box','',6),(192243,'73385','origin','block-192233','account\\AccountLink','',3),(192244,'73386','origin','block-192233','account\\AccountLink','',14),(192245,'73387','origin','block-192233','account\\AccountLink','',8),(192246,'73388','origin','block-192233','account\\AccountLink','',5),(192247,'73389','origin','block-192233','account\\AccountLink','',9),(192248,'73390','origin','block-192233','account\\AccountLink','',12),(192249,'73391','origin','block-192233','Html_box','',10),(192250,'73392','origin','block-192233','account\\AccountLink','',15),(192251,'75543','origin','block-192230-2','account\\Wishlist','',2),(192252,'75544','origin','block-192230-2','Html_box','',1),(192253,'75545','origin','wishlist-cart','BlockBox','',1),(192254,'75546','origin','block-192253','cart\\CartTabs','',1),(192255,'75547','origin','block-192254','account\\Wishlist','',1),(192256,'73349','new_theme','404','Html_box','',1),(192257,'73350','new_theme','account','BlockBox','',1),(192258,'73351','new_theme','block-192257','BlockBox','',1),(192259,'73352','new_theme','block-192258','WidgetsAria','',1),(192279,'1704978704.8413','new_theme','block-192258-2','BlockBox','account-content',1),(192280,'73353','new_theme','block-192279','account\\OrdersHistory','',5),(192281,'73354','new_theme','block-192279','Html_box','',4),(192282,'73357','new_theme','block-192279','Html_box','',1),(192283,'1705060269.3517','new_theme','block-192279','BlockBox','account-content-top',2),(192284,'1705060551.6998','new_theme','block-192283','BlockBox','',1),(192285,'73361','new_theme','block-192284','Html_box','',1),(192286,'73362','new_theme','block-192284','account\\LastOrder','',2),(192287,'1705060566.121','new_theme','block-192283','BlockBox','',2),(192288,'73363','new_theme','block-192287','Html_box','',1),(192289,'73364','new_theme','block-192287','account\\OrderCount','',2),(192290,'73365','new_theme','block-192287','account\\AccountLink','',3),(192291,'1705060582.9285','new_theme','block-192283','BlockBox','',3),(192292,'73366','new_theme','block-192291','Html_box','',1),(192293,'73367','new_theme','block-192291','account\\TotalOrdered','',2),(192294,'1705060591.4402','new_theme','block-192283','BlockBox','',4),(192295,'73368','new_theme','block-192294','Html_box','',1),(192296,'73369','new_theme','block-192294','account\\CreditAmount','',2),(192297,'73370','new_theme','block-192294','account\\AccountLink','',3),(192298,'1705060602.1936','new_theme','block-192283','BlockBox','',5),(192299,'73371','new_theme','block-192298','account\\AccountLink','',3),(192300,'73372','new_theme','block-192298','BonusActions\\widgets\\PointsEarnt','',2),(192301,'73373','new_theme','block-192298','Html_box','',1),(192321,'73393','new_theme','account_edit','BlockBox','',1),(192322,'73394','new_theme','block-192321','BlockBox','',1),(192323,'73395','new_theme','block-192322','WidgetsAria','',1),(192343,'73396','new_theme','block-192322-2','account\\AccountEdit','',2),(192344,'73397','new_theme','block-192322-2','Html_box','',1),(192345,'73398','new_theme','address_book','BlockBox','',1),(192346,'73399','new_theme','block-192345','BlockBox','',1),(192347,'73400','new_theme','block-192346','WidgetsAria','',1),(192367,'73401','new_theme','block-192346-2','account\\AddressBook','',3),(192368,'73402','new_theme','block-192346-2','Html_box','',1),(192369,'73403','new_theme','block-192346-2','Html_box','',2),(192370,'73404','new_theme','address_book_process','BlockBox','',1),(192371,'73405','new_theme','block-192370','BlockBox','',1),(192372,'73406','new_theme','block-192371','WidgetsAria','',1),(192392,'73407','new_theme','block-192371-2','Html_box','',1),(192393,'73408','new_theme','block-192371-2','account\\EditAddress','',2),(192394,'73409','new_theme','b2b','BlockBox','listing-item',1),(192395,'73410','new_theme','block-192394','BlockBox','',1),(192396,'73411','new_theme','block-192395','productListing\\image','',1),(192397,'73412','new_theme','block-192395-2','productListing\\description','',6),(192398,'73413','new_theme','block-192395-2','productListing\\model','',5),(192399,'73414','new_theme','block-192395-2','productListing\\attributes','',3),(192400,'73415','new_theme','block-192395-2','BlockBox','',4),(192401,'73416','new_theme','block-192400','BlockBox','',1),(192402,'73417','new_theme','block-192401','productListing\\price','',1),(192403,'73418','new_theme','block-192401-2','BonusActions\\widgets\\BonusPointsProductListing','',1),(192404,'73419','new_theme','block-192400-2','productListing\\qtyInput','',1),(192405,'73420','new_theme','block-192395-2','productListing\\name','',1),(192406,'73421','new_theme','block-192395-2','BlockBox','',2),(192407,'73422','new_theme','block-192406','productListing\\stock','',1),(192408,'73423','new_theme','block-192406-2','productListing\\rating','',1),(192409,'76000','new_theme','batch','BlockBox','',1),(192410,'76001','new_theme','block-192409','productListing\\attributes','',5),(192411,'76002','new_theme','block-192409','productListing\\price','',6),(192412,'76003','new_theme','block-192409','productListing\\name','',4),(192413,'76004','new_theme','block-192409','productListing\\image','',2),(192414,'76005','new_theme','block-192409','batchSelect','',1),(192415,'76006','new_theme','batch_selected','BlockBox','',1),(192416,'76007','new_theme','block-192415','BlockBox','',13),(192417,'76008','new_theme','block-192416','productListing\\image','',1),(192418,'76009','new_theme','block-192416-2','batchRemove','',1),(192419,'76010','new_theme','block-192416-2','productListing\\price','',3),(192420,'76011','new_theme','block-192416-2','productListing\\name','',2),(192421,'76012','new_theme','bbbbb','BlockBox','',1),(192422,'76013','new_theme','block-192421','BlockBox','',2),(192423,'76014','new_theme','block-192422','Filters','',1),(192424,'76015','new_theme','block-192422-2','BlockBox','',6),(192425,'76016','new_theme','block-192424','catalog\\CountsItems','',1),(192426,'76017','new_theme','block-192424-2','catalog\\Paging','',1),(192427,'76018','new_theme','block-192422-2','catalog\\Image','',1),(192428,'76019','new_theme','block-192422-2','Listing','',5),(192429,'76020','new_theme','block-192422-2','catalog\\ImageMapCategory','',3),(192430,'76021','new_theme','block-192422-2','BlockBox','',4),(192431,'76022','new_theme','block-192430','catalog\\ListingLook','',1),(192432,'76023','new_theme','block-192430','catalog\\CompareButton','',2),(192433,'76024','new_theme','block-192430','catalog\\ItemsOnPage','',4),(192434,'76025','new_theme','block-192430','catalog\\Sorting','',3),(192435,'76026','new_theme','block-192422-2','Categories','',2),(192436,'76027','new_theme','block-192421','catalog\\Title','',1),(192437,'1683124632.767746','new_theme','cart','BlockBox','',1),(192438,'1683124632.80670','new_theme','block-192437','BlockBox','',2),(192439,'1683124632.809680','new_theme','block-192438','BlockBox','cart-content',4),(192440,'1683124632.816335','new_theme','block-192438','BlockBox','',1),(192441,'1683124632.817623','new_theme','block-192440','cart\\Products','',2),(192442,'1683124632.818551','new_theme','block-192440','BlockBox','',1),(192443,'1683124632.820317','new_theme','block-192442','MultiCart\\CartSwitcher','',1),(192444,'1683124632.820914','new_theme','block-192442','MultiCart\\SaveCart','',2),(192445,'1683124632.822588','new_theme','block-192442-2','MultiCart\\Actions','',1),(192446,'1683124632.823175','new_theme','block-192440','BlockBox','',3),(192447,'1683124632.825245','new_theme','block-192446','cart\\CreditAmount','',1),(192448,'1683124632.825649','new_theme','block-192446-2','BonusActions\\widgets\\BonusPointsCart','',1),(192449,'1683124632.82683','new_theme','block-192438','BlockBox','',3),(192450,'1683124632.827413','new_theme','block-192449','cart\\GiveAway','',2),(192451,'1683124632.828374','new_theme','block-192449','Html_box','',1),(192452,'1683124632.829840','new_theme','block-192438','BlockBox','',5),(192453,'1683124632.831459','new_theme','block-192452','Html_box','',1),(192454,'1683124632.832592','new_theme','block-192452','cart\\ShippingEstimator','',2),(192455,'1683124632.833353','new_theme','block-192438-2','BlockBox','',1),(192456,'1683124632.834715','new_theme','block-192455','BlockBox','',2),(192457,'1683124632.835884','new_theme','block-192456','cart\\DiscountCoupon','',1),(192458,'1683124632.836532','new_theme','block-192456','Image','',4),(192459,'1683124632.844829','new_theme','block-192456','cart\\CheckoutBtn','',3),(192460,'1683124632.84681','new_theme','block-192456','cart\\OrderTotal','',2),(192461,'1683124632.846538','new_theme','block-192456','cart\\OrderTotal','',0),(192462,'1683124632.84726','new_theme','block-192455','Html_box','',1),(192463,'94658','new_theme','cart2','BlockBox','',2),(192464,'94659','new_theme','block-192463','cart\\CartTabs','',2),(192465,'94660','new_theme','block-192464','BlockBox','',1),(192466,'94661','new_theme','block-192465','BlockBox','',4),(192467,'94662','new_theme','block-192466','cart\\UpSell','6',2),(192468,'94663','new_theme','block-192466','Html_box','',1),(192469,'94664','new_theme','block-192465','BlockBox','',1),(192470,'94665','new_theme','block-192469','cart\\Products','',3),(192471,'94666','new_theme','block-192469','BlockBox','',2),(192472,'94667','new_theme','block-192471','MultiCart\\CartSwitcher','',1),(192473,'94668','new_theme','block-192471','MultiCart\\SaveCart','',2),(192474,'94669','new_theme','block-192471-2','MultiCart\\Actions','',1),(192475,'94670','new_theme','block-192465','BlockBox','',3),(192476,'94671','new_theme','block-192475','cart\\GiveAway','',2),(192477,'94672','new_theme','block-192475','Html_box','',1),(192478,'94673','new_theme','block-192465','BlockBox','',2),(192479,'94674','new_theme','block-192478','Html_box','',1),(192480,'94675','new_theme','block-192478','BlockBox','',2),(192481,'94676','new_theme','block-192480','cart\\DiscountCoupon','',1),(192482,'94677','new_theme','block-192480-2','cart\\CreditAmount','',1),(192483,'94678','new_theme','block-192480-3','BonusActions\\widgets\\BonusPointsCart','',1),(192484,'94679','new_theme','block-192465','BlockBox','',5),(192485,'94680','new_theme','block-192484','Html_box','',1),(192486,'94681','new_theme','block-192484','cart\\ShippingEstimator','',2),(192487,'94682','new_theme','block-192465-2','BlockBox','',1),(192488,'94683','new_theme','block-192487','Html_box','',1),(192489,'94684','new_theme','block-192487','BlockBox','',2),(192490,'94685','new_theme','block-192489','Image','',4),(192491,'94686','new_theme','block-192489','cart\\CheckoutBtn','',2),(192492,'94687','new_theme','block-192489','cart\\OrderTotal','',1),(192493,'73462','new_theme','categories','BlockBox','catalog-content',1),(192494,'73463','new_theme','block-192493','BlockBox','catalog-side',2),(192495,'73464','new_theme','block-192494','Filters','',1),(192496,'73465','new_theme','block-192494-2','Listing','',5),(192497,'73466','new_theme','block-192494-2','catalog\\Image','',1),(192498,'73467','new_theme','block-192494-2','BlockBox','',6),(192499,'73468','new_theme','block-192498','catalog\\CountsItems','',1),(192500,'73469','new_theme','block-192498-2','catalog\\Paging','',1),(192501,'73470','new_theme','block-192494-2','catalog\\ImageMapCategory','',3),(192502,'73471','new_theme','block-192494-2','Categories','',2),(192503,'73472','new_theme','block-192494-2','BlockBox','catalog-features',4),(192504,'73473','new_theme','block-192503','catalog\\ListingLook','',1),(192505,'73474','new_theme','block-192503','catalog\\CompareButton','',2),(192506,'73475','new_theme','block-192503','catalog\\ItemsOnPage','',4),(192507,'73476','new_theme','block-192503','catalog\\Sorting','',3),(192508,'73477','new_theme','block-192493','catalog\\Title','',1),(192509,'73478','new_theme','category','Categories','',1),(192510,'73479','new_theme','category','Listing','',4),(192511,'73480','new_theme','category','ListingFunctionality','',2),(192512,'73481','new_theme','category','PagingBar','',3),(192513,'73482','new_theme','category','PagingBar','',5),(192514,'94688','new_theme','category_2','BlockBox','',1),(192515,'94689','new_theme','block-192514','catalog\\Title','',1),(192516,'94690','new_theme','block-192514','BlockBox','',2),(192517,'94691','new_theme','block-192516','Filters','',1),(192518,'94692','new_theme','block-192516-2','catalog\\Image','',1),(192519,'94693','new_theme','block-192516-2','Listing','',5),(192520,'94694','new_theme','block-192516-2','BlockBox','',4),(192521,'94695','new_theme','block-192520','catalog\\Sorting','',3),(192522,'94696','new_theme','block-192520','catalog\\ItemsOnPage','',4),(192523,'94697','new_theme','block-192520','catalog\\CompareButton','',2),(192524,'94698','new_theme','block-192520','catalog\\ListingLook','',1),(192525,'94699','new_theme','block-192516-2','catalog\\ImageMapCategory','',3),(192526,'94700','new_theme','block-192516-2','Categories','',2),(192527,'94701','new_theme','block-192516-2','BlockBox','',6),(192528,'94702','new_theme','block-192527','catalog\\CountsItems','',1),(192529,'94703','new_theme','block-192527-2','catalog\\Paging','',1),(192530,'73483','new_theme','category_no_filters','BlockBox','',1),(192531,'73484','new_theme','block-192530','catalog\\Title','',1),(192532,'73485','new_theme','block-192530','Categories','',3),(192533,'73486','new_theme','block-192530','BlockBox','catalog-features',4),(192534,'73487','new_theme','block-192533','catalog\\ItemsOnPage','',4),(192535,'73488','new_theme','block-192533','catalog\\Sorting','',3),(192536,'73489','new_theme','block-192533','catalog\\CompareButton','',2),(192537,'73490','new_theme','block-192533','catalog\\ListingLook','',1),(192538,'73491','new_theme','block-192533','HeaderStock','',5),(192539,'73492','new_theme','block-192530','BlockBox','',6),(192540,'73493','new_theme','block-192539','catalog\\CountsItems','',1),(192541,'73494','new_theme','block-192539-2','catalog\\Paging','',1),(192542,'73495','new_theme','block-192530','Listing','',5),(192543,'73496','new_theme','block-192530','catalog\\Image','',2),(192544,'73497','new_theme','block-192530','catalog\\B2bAddButton','',7),(192545,'1683125852.345798','new_theme','checkout','BlockBox','',1),(192546,'1683125852.356555','new_theme','block-192545','BlockBox','',2),(192547,'1683125852.358412','new_theme','block-192546','BlockBox','',2),(192548,'1683125852.35982','new_theme','block-192547','BlockBox','checkout-comments',5),(192549,'1683125852.361569','new_theme','block-192548','checkout\\Comments','',2),(192550,'1683125852.362847','new_theme','block-192548','Html_box','',1),(192551,'1683125852.36485','new_theme','block-192547','BlockBox','checkout-discount',4),(192552,'1683125852.366422','new_theme','block-192551','Html_box','',1),(192553,'1683125852.367732','new_theme','block-192551','BlockBox','',2),(192554,'1683125852.36968','new_theme','block-192553','CouponsAndVauchers\\Checkout','',1),(192555,'1683125852.369745','new_theme','block-192553-2','checkout\\CreditAmount','',1),(192556,'1683125852.37045','new_theme','block-192553-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(192557,'1683125852.371233','new_theme','block-192547','BlockBox','checkout-shipping',2),(192558,'1683125852.37350','new_theme','block-192557','BlockBox','',3),(192559,'1683125852.374899','new_theme','block-192558','checkout\\ShippingChoice','',1),(192560,'1683125852.375685','new_theme','block-192557','Neighbour\\Checkout','',5),(192561,'1683125852.376557','new_theme','block-192557','BlockBox','',4),(192562,'1683125852.377637','new_theme','block-192561','BlockBox','',1),(192563,'1683125852.378829','new_theme','block-192562','checkout\\ShippingAddress','',2),(192564,'1683125852.379375','new_theme','block-192562','Html_box','',3),(192565,'1683125852.380323','new_theme','block-192562','checkout\\ContactInformation','',4),(192566,'1683125852.380722','new_theme','block-192562','UploadCustomerId\\UploadCustomerIdForm','',4),(192567,'1683125852.381183','new_theme','block-192561-2','BlockBox','',1),(192568,'1683125852.382226','new_theme','block-192567','checkout\\Shipping','',2),(192569,'1683125852.382635','new_theme','block-192567','DelayedDespatch\\Checkout','',3),(192570,'1683125852.383516','new_theme','block-192567','Html_box','',1),(192571,'1683125852.385278','new_theme','block-192557','Html_box','',2),(192572,'1683125852.386397','new_theme','block-192547','cart\\Products','',6),(192573,'1683125852.386970','new_theme','block-192547','checkout\\CreateAccount','',7),(192574,'1683125852.38820','new_theme','block-192547','BlockBox','checkout-payment',3),(192575,'1683125852.390244','new_theme','block-192574','Html_box','',1),(192576,'1683125852.391810','new_theme','block-192574','BlockBox','',2),(192577,'1683125852.393320','new_theme','block-192576','Html_box','',1),(192578,'1683125852.394747','new_theme','block-192576','checkout\\BillingAddress','',2),(192579,'1683125852.395767','new_theme','block-192576-2','BlockBox','',1),(192580,'1683125852.397129','new_theme','block-192579','checkout\\PaymentMethod','',2),(192581,'1683125852.398588','new_theme','block-192579','Html_box','',1),(192582,'1683125852.400291','new_theme','block-192547','BlockBox','',1),(192583,'1683125852.402237','new_theme','block-192582','checkout\\LoginOnForm','',0),(192584,'1683128325.0836','new_theme','block-192582','BlockBox','',1),(192585,'1683125852.403563','new_theme','block-192546-2','BlockBox','checkout-side',1),(192586,'1683125852.405625','new_theme','block-192585','Html_box','',6),(192587,'1683125852.407666','new_theme','block-192585','Html_box','',1),(192588,'1683125852.40885','new_theme','block-192585','checkout\\Terms','',5),(192589,'1683125852.409688','new_theme','block-192585','checkout\\Totals','',3),(192590,'1683125852.410151','new_theme','block-192585','checkout\\ContinueBtn','',4),(192591,'1683125852.412647','new_theme','block-192585','cart\\Products','',2),(192592,'73542','new_theme','checkout_confirmation','BlockBox','',1),(192593,'73543','new_theme','block-192592','checkout\\Totals','',8),(192594,'73544','new_theme','block-192592','Html_box','',5),(192595,'73545','new_theme','block-192592','checkout\\EditBtn','',6),(192596,'73546','new_theme','block-192592','BlockBox','',3),(192597,'73547','new_theme','block-192596','BlockBox','',1),(192598,'73548','new_theme','block-192597','Html_box','',1),(192599,'73549','new_theme','block-192597','checkout\\ShippingConfirm','',3),(192600,'73550','new_theme','block-192596-2','BlockBox','',1),(192601,'73551','new_theme','block-192600','checkout\\PaymentMethodConfirm','',3),(192602,'73552','new_theme','block-192600','Html_box','',1),(192603,'73553','new_theme','block-192592','checkout\\ConfirmBtn','',9),(192604,'73554','new_theme','block-192592','BlockBox','',2),(192605,'73555','new_theme','block-192604','BlockBox','',1),(192606,'73556','new_theme','block-192605','checkout\\ShippingAddressConfirm','',3),(192607,'73557','new_theme','block-192605','Html_box','',1),(192608,'73558','new_theme','block-192604-2','BlockBox','',1),(192609,'73559','new_theme','block-192608','Html_box','',1),(192610,'73560','new_theme','block-192608','checkout\\BillingAddressConfirm','',3),(192611,'73561','new_theme','block-192592','checkout\\ConfirmBtn','',4),(192612,'73562','new_theme','block-192592','cart\\Products','',7),(192613,'73576','new_theme','checkout_confirmation_no_shipping','BlockBox','',1),(192614,'73577','new_theme','block-192613','checkout\\ConfirmBtn','',9),(192615,'73578','new_theme','block-192613','BlockBox','',2),(192616,'73579','new_theme','block-192615','BlockBox','',1),(192617,'73580','new_theme','block-192616','Html_box','',1),(192618,'73581','new_theme','block-192616','checkout\\BillingAddressConfirm','',3),(192619,'73582','new_theme','block-192615-2','BlockBox','',1),(192620,'73583','new_theme','block-192619','Html_box','',1),(192621,'73584','new_theme','block-192619','checkout\\PaymentMethodConfirm','',3),(192622,'73585','new_theme','block-192613','checkout\\ConfirmBtn','',4),(192623,'73586','new_theme','block-192613','checkout\\Totals','',8),(192624,'73587','new_theme','block-192613','cart\\Products','',7),(192625,'73588','new_theme','block-192613','Html_box','',5),(192626,'73563','new_theme','checkout_confirmation_no_shipping_q','BlockBox','',1),(192627,'73564','new_theme','block-192626','quote\\Products','',4),(192628,'73565','new_theme','block-192626','checkout\\ConfirmBtn','',2),(192629,'73566','new_theme','block-192626','checkout\\ConfirmBtn','',6),(192630,'73567','new_theme','block-192626','BlockBox','',1),(192631,'73568','new_theme','block-192630','BlockBox','',1),(192632,'73569','new_theme','block-192631','checkout\\BillingAddressConfirm','',3),(192633,'73570','new_theme','block-192631','Html_box','',1),(192634,'73571','new_theme','block-192630-2','BlockBox','',1),(192635,'73572','new_theme','block-192634','checkout\\PaymentMethodConfirm','',3),(192636,'73573','new_theme','block-192634','Html_box','',1),(192637,'73574','new_theme','block-192626','Html_box','',3),(192638,'73575','new_theme','block-192626','checkout\\Totals','',5),(192639,'73589','new_theme','checkout_confirmation_q','BlockBox','',1),(192640,'73590','new_theme','block-192639','BlockBox','',1),(192641,'73591','new_theme','block-192640','BlockBox','',1),(192642,'73592','new_theme','block-192641','checkout\\ShippingAddressConfirm','',3),(192643,'73593','new_theme','block-192641','Html_box','',1),(192644,'73594','new_theme','block-192640-2','BlockBox','',1),(192645,'73595','new_theme','block-192644','checkout\\BillingAddressConfirm','',3),(192646,'73596','new_theme','block-192644','Html_box','',1),(192647,'73597','new_theme','block-192639','checkout\\Totals','',7),(192648,'73598','new_theme','block-192639','quote\\Products','',6),(192649,'73599','new_theme','block-192639','Html_box','',4),(192650,'73600','new_theme','block-192639','checkout\\EditBtn','',5),(192651,'73601','new_theme','block-192639','checkout\\ConfirmBtn','',8),(192652,'73602','new_theme','block-192639','checkout\\ConfirmBtn','',3),(192653,'73603','new_theme','block-192639','BlockBox','',2),(192654,'73604','new_theme','block-192653','BlockBox','',1),(192655,'73605','new_theme','block-192654','Html_box','',1),(192656,'73606','new_theme','block-192654','checkout\\ShippingConfirm','',3),(192657,'73607','new_theme','block-192653-2','BlockBox','',1),(192658,'73608','new_theme','block-192657','Html_box','',1),(192659,'73609','new_theme','block-192657','checkout\\PaymentMethodConfirm','',3),(192660,'73610','new_theme','checkout_confirmation_title','Html_box','',1),(192661,'73611','new_theme','checkout_confirmation_title_g','Html_box','',1),(192662,'73613','new_theme','checkout_confirmation_title_no_shipping','Html_box','',1),(192663,'73612','new_theme','checkout_confirmation_title_no_shipping_g','Html_box','',1),(192664,'73614','new_theme','checkout_confirmation_title_q','Html_box','',1),(192665,'73615','new_theme','checkout_confirmation_title_s','Html_box','',1),(192666,'73616','new_theme','checkout_delivery','BlockBox','',2),(192667,'73617','new_theme','block-192666','BlockBox','',1),(192668,'73618','new_theme','block-192667','Html_box','',1),(192669,'73619','new_theme','block-192667','checkout\\ContactInformation','',2),(192670,'73620','new_theme','block-192666-2','BlockBox','',1),(192671,'73621','new_theme','block-192670','Html_box','',1),(192672,'73622','new_theme','block-192670','checkout\\Comments','',2),(192673,'73623','new_theme','checkout_delivery','BlockBox','',3),(192674,'73624','new_theme','block-192673','Html_box','',1),(192675,'73625','new_theme','block-192673-2','checkout\\ContinueBtn','',1),(192676,'73626','new_theme','checkout_delivery','BlockBox','',1),(192677,'73627','new_theme','block-192676','BlockBox','',1),(192678,'73628','new_theme','block-192677','Html_box','',1),(192679,'73629','new_theme','block-192677','checkout\\ShippingAddress','',2),(192680,'73630','new_theme','block-192676-2','BlockBox','',1),(192681,'73631','new_theme','block-192680','DelayedDespatch\\Checkout','',3),(192682,'73632','new_theme','block-192680','checkout\\Shipping','',2),(192683,'73633','new_theme','block-192680','Html_box','',1),(192684,'73634','new_theme','block-192680','Neighbour\\Checkout','',4),(192685,'73635','new_theme','checkout_delivery_g','BlockBox','',2),(192686,'73636','new_theme','block-192685','BlockBox','',1),(192687,'73637','new_theme','block-192686','checkout\\ContactInformation','',2),(192688,'73638','new_theme','block-192686','Html_box','',1),(192689,'73639','new_theme','block-192685-2','BlockBox','',1),(192690,'73640','new_theme','block-192689','Html_box','',1),(192691,'73641','new_theme','block-192689','checkout\\Comments','',2),(192692,'73642','new_theme','checkout_delivery_g','BlockBox','',3),(192693,'73643','new_theme','block-192692','Html_box','',1),(192694,'73644','new_theme','block-192692-2','checkout\\ContinueBtn','',1),(192695,'73645','new_theme','checkout_delivery_g','BlockBox','',1),(192696,'73646','new_theme','block-192695','BlockBox','',1),(192697,'73647','new_theme','block-192696','checkout\\ShippingAddress','',2),(192698,'73648','new_theme','block-192696','Html_box','',1),(192699,'73649','new_theme','block-192695-2','BlockBox','',1),(192700,'73650','new_theme','block-192699','checkout\\Shipping','',2),(192701,'73651','new_theme','block-192699','Html_box','',1),(192702,'73652','new_theme','block-192699','DelayedDespatch\\Checkout','',3),(192703,'73653','new_theme','block-192699','Neighbour\\Checkout','',4),(192704,'73654','new_theme','checkout_delivery_no_shipping','BlockBox','',2),(192705,'73655','new_theme','block-192704','Html_box','',1),(192706,'73656','new_theme','block-192704-2','checkout\\ContinueBtn','',1),(192707,'73657','new_theme','checkout_delivery_no_shipping','BlockBox','',1),(192708,'73658','new_theme','block-192707','BlockBox','',1),(192709,'73659','new_theme','block-192708','checkout\\ContactInformation','',2),(192710,'73660','new_theme','block-192707-2','BlockBox','',1),(192711,'73661','new_theme','block-192710','Html_box','',1),(192712,'73662','new_theme','block-192710','checkout\\Comments','',2),(192713,'73663','new_theme','checkout_delivery_no_shipping_g','BlockBox','',2),(192714,'73664','new_theme','block-192713','Html_box','',1),(192715,'73665','new_theme','block-192713-2','checkout\\ContinueBtn','',1),(192716,'73666','new_theme','checkout_delivery_no_shipping_g','BlockBox','',1),(192717,'73667','new_theme','block-192716','BlockBox','',1),(192718,'73668','new_theme','block-192717','checkout\\ContactInformation','',2),(192719,'73669','new_theme','block-192716-2','BlockBox','',1),(192720,'73670','new_theme','block-192719','checkout\\Comments','',2),(192721,'73671','new_theme','block-192719','Html_box','',1),(192722,'73672','new_theme','checkout_delivery_title','Html_box','',1),(192723,'73673','new_theme','checkout_delivery_title_g','Html_box','',1),(192724,'73675','new_theme','checkout_delivery_title_no_shipping','Html_box','',1),(192725,'73674','new_theme','checkout_delivery_title_no_shipping_g','Html_box','',1),(192726,'73676','new_theme','checkout_delivery_title_q','Html_box','',1),(192727,'73677','new_theme','checkout_delivery_title_s','Html_box','',1),(192728,'73678','new_theme','checkout_free_s','BlockBox','',1),(192729,'73679','new_theme','block-192728','BlockBox','',2),(192730,'73680','new_theme','block-192729','BlockBox','',2),(192731,'73682','new_theme','block-192730','BlockBox','',6),(192732,'73683','new_theme','block-192731','sample\\Products','',1),(192733,'73684','new_theme','block-192731','checkout\\CreateAccount','',3),(192734,'73685','new_theme','block-192730','BlockBox','',5),(192735,'73686','new_theme','block-192734','Html_box','',1),(192736,'73687','new_theme','block-192734','checkout\\Comments','',2),(192737,'73688','new_theme','block-192730','BlockBox','',2),(192738,'73689','new_theme','block-192737','BlockBox','',2),(192739,'73690','new_theme','block-192738','checkout\\ShippingChoice','',1),(192740,'73691','new_theme','block-192737','Html_box','',1),(192741,'73692','new_theme','block-192737','BlockBox','',3),(192742,'73693','new_theme','block-192741','BlockBox','',1),(192743,'73694','new_theme','block-192742','checkout\\ContactInformation','',4),(192744,'73695','new_theme','block-192742','checkout\\ShippingAddress','',2),(192745,'73696','new_theme','block-192742','Html_box','',3),(192746,'73697','new_theme','block-192741-2','BlockBox','',1),(192747,'73698','new_theme','block-192746','DelayedDespatch\\Checkout','',3),(192748,'73699','new_theme','block-192737','Neighbour\\Checkout','',4),(192749,'73700','new_theme','block-192729-2','BlockBox','',1),(192750,'73701','new_theme','block-192749','Html_box','',3),(192751,'73702','new_theme','block-192749','checkout\\ContinueBtn','',1),(192752,'115999','new_theme','block-192749','checkout\\Terms','',2),(192753,'73703','new_theme','checkout_no_shipping','BlockBox','',1),(192754,'73704','new_theme','block-192753','BlockBox','',2),(192755,'73705','new_theme','block-192754','BlockBox','',1),(192756,'73706','new_theme','block-192755','BlockBox','',6),(192757,'73707','new_theme','block-192756','checkout\\CreateAccount','',2),(192758,'73708','new_theme','block-192756','cart\\Products','',1),(192759,'73709','new_theme','block-192755','BlockBox','',3),(192760,'73710','new_theme','block-192759','Html_box','',1),(192761,'73711','new_theme','block-192759','BlockBox','',2),(192762,'73712','new_theme','block-192761','checkout\\BillingAddress','',2),(192763,'73713','new_theme','block-192761','Html_box','',1),(192764,'73714','new_theme','block-192761-2','BlockBox','',1),(192765,'73715','new_theme','block-192764','Html_box','',1),(192766,'73716','new_theme','block-192764','checkout\\PaymentMethod','',2),(192767,'73717','new_theme','block-192755','BlockBox','',4),(192768,'73718','new_theme','block-192767','BlockBox','',2),(192769,'73719','new_theme','block-192768','CouponsAndVauchers\\Checkout','',1),(192770,'73720','new_theme','block-192768-2','checkout\\CreditAmount','',1),(192771,'73721','new_theme','block-192768-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(192772,'73722','new_theme','block-192767','Html_box','',1),(192773,'73723','new_theme','block-192755','BlockBox','',5),(192774,'73724','new_theme','block-192773','checkout\\Comments','',2),(192775,'73725','new_theme','block-192773','Html_box','',1),(192776,'73726','new_theme','block-192754-2','BlockBox','',1),(192777,'73727','new_theme','block-192776','Html_box','',1),(192778,'73728','new_theme','block-192776','Html_box','',5),(192779,'73729','new_theme','block-192776','checkout\\Totals','',2),(192780,'73730','new_theme','block-192776','checkout\\ContinueBtn','',3),(192781,'73731','new_theme','block-192776','checkout\\Terms','',4),(192782,'73732','new_theme','checkout_no_shipping_g','BlockBox','',1),(192783,'73733','new_theme','block-192782','checkout\\Totals','',5),(192784,'73734','new_theme','block-192782','BlockBox','',6),(192785,'73735','new_theme','block-192784','Html_box','',1),(192786,'73736','new_theme','block-192784-2','checkout\\ContinueBtn','',1),(192787,'73737','new_theme','block-192782','BlockBox','',2),(192788,'73738','new_theme','block-192787','BlockBox','',1),(192789,'73739','new_theme','block-192788','checkout\\ContactInformation','',2),(192790,'73740','new_theme','block-192788','Html_box','',1),(192791,'73741','new_theme','block-192787-2','BlockBox','',1),(192792,'73742','new_theme','block-192791','checkout\\Comments','',2),(192793,'73743','new_theme','block-192791','Html_box','',1),(192794,'73744','new_theme','block-192782','BlockBox','',1),(192795,'73745','new_theme','block-192794','BlockBox','',1),(192796,'73746','new_theme','block-192795','Html_box','',1),(192797,'73747','new_theme','block-192795','checkout\\BillingAddress','',2),(192798,'73748','new_theme','block-192794-2','BlockBox','',1),(192799,'73749','new_theme','block-192798','BonusActions\\widgets\\BonusPointsCheckout','',4),(192800,'73750','new_theme','block-192798','CouponsAndVauchers\\Checkout','',5),(192801,'73751','new_theme','block-192798','checkout\\PaymentMethod','',2),(192802,'73752','new_theme','block-192798','checkout\\CreditAmount','',3),(192803,'73753','new_theme','block-192798','Html_box','',1),(192804,'73754','new_theme','block-192782','quote\\Products','',3),(192805,'73755','new_theme','checkout_no_shipping_q','BlockBox','',1),(192806,'73756','new_theme','block-192805','BlockBox','',2),(192807,'73757','new_theme','block-192806','BlockBox','',2),(192808,'73758','new_theme','block-192807','checkout\\Gdpr','',1),(192809,'73759','new_theme','block-192807','BlockBox','',5),(192810,'73760','new_theme','block-192809','checkout\\Comments','',2),(192811,'73761','new_theme','block-192809','Html_box','',1),(192812,'73762','new_theme','block-192807','BlockBox','',6),(192813,'73763','new_theme','block-192812','checkout\\CreateAccount','',3),(192814,'73764','new_theme','block-192812','quote\\Products','',2),(192815,'73765','new_theme','block-192807','BlockBox','',3),(192816,'73766','new_theme','block-192815','Html_box','',1),(192817,'73767','new_theme','block-192815','BlockBox','',2),(192818,'73768','new_theme','block-192817','Html_box','',1),(192819,'73769','new_theme','block-192817','checkout\\BillingAddress','',2),(192820,'73770','new_theme','block-192817-2','BlockBox','',1),(192821,'73771','new_theme','block-192820','checkout\\PaymentMethod','',2),(192822,'73772','new_theme','block-192820','Html_box','',1),(192823,'73773','new_theme','block-192806-2','BlockBox','',1),(192824,'73774','new_theme','block-192823','checkout\\ContinueBtn','',3),(192825,'73775','new_theme','block-192823','Html_box','',4),(192826,'73776','new_theme','block-192823','Html_box','',1),(192827,'73777','new_theme','block-192823','checkout\\Totals','',2),(192828,'73778','new_theme','checkout_payment','BlockBox','',1),(192829,'73779','new_theme','block-192828','BlockBox','',1),(192830,'73780','new_theme','block-192829','checkout\\BillingAddress','',2),(192831,'73781','new_theme','block-192829','Html_box','',1),(192832,'73782','new_theme','block-192828-2','BlockBox','',1),(192833,'73783','new_theme','block-192832','checkout\\CreditAmount','',3),(192834,'73784','new_theme','block-192832','BonusActions\\widgets\\BonusPointsCheckout','',4),(192835,'73785','new_theme','block-192832','CouponsAndVauchers\\Checkout','',5),(192836,'73786','new_theme','block-192832','checkout\\PaymentMethod','',2),(192837,'73787','new_theme','block-192832','Html_box','',1),(192838,'73788','new_theme','checkout_payment','BlockBox','',2),(192839,'73789','new_theme','block-192838','Html_box','',1),(192840,'73790','new_theme','block-192838-2','checkout\\ContinueBtn','',1),(192841,'73791','new_theme','checkout_payment_g','BlockBox','',1),(192842,'73792','new_theme','block-192841','BlockBox','',1),(192843,'73793','new_theme','block-192842','checkout\\BillingAddress','',2),(192844,'73794','new_theme','block-192842','Html_box','',1),(192845,'73795','new_theme','block-192841-2','BlockBox','',1),(192846,'73796','new_theme','block-192845','checkout\\CreditAmount','',3),(192847,'73797','new_theme','block-192845','Html_box','',1),(192848,'73798','new_theme','block-192845','checkout\\PaymentMethod','',2),(192849,'73799','new_theme','block-192845','CouponsAndVauchers\\Checkout','',5),(192850,'73800','new_theme','block-192845','BonusActions\\widgets\\BonusPointsCheckout','',4),(192851,'73801','new_theme','checkout_payment_g','BlockBox','',2),(192852,'73802','new_theme','block-192851','Html_box','',1),(192853,'73803','new_theme','block-192851-2','checkout\\ContinueBtn','',1),(192854,'73804','new_theme','checkout_payment_no_shipping','BlockBox','',2),(192855,'73805','new_theme','block-192854','Html_box','',1),(192856,'73806','new_theme','block-192854-2','checkout\\ContinueBtn','',1),(192857,'73807','new_theme','checkout_payment_no_shipping','BlockBox','',1),(192858,'73808','new_theme','block-192857','BlockBox','',1),(192859,'73809','new_theme','block-192858','Html_box','',1),(192860,'73810','new_theme','block-192858','checkout\\BillingAddress','',2),(192861,'73811','new_theme','block-192857-2','BlockBox','',1),(192862,'73812','new_theme','block-192861','BonusActions\\widgets\\BonusPointsCheckout','',4),(192863,'73813','new_theme','block-192861','CouponsAndVauchers\\Checkout','',5),(192864,'73814','new_theme','block-192861','checkout\\PaymentMethod','',2),(192865,'73815','new_theme','block-192861','checkout\\CreditAmount','',3),(192866,'73816','new_theme','block-192861','Html_box','',1),(192867,'73817','new_theme','checkout_payment_no_shipping_g','BlockBox','',2),(192868,'73818','new_theme','block-192867','Html_box','',1),(192869,'73819','new_theme','block-192867-2','checkout\\ContinueBtn','',1),(192870,'73820','new_theme','checkout_payment_no_shipping_g','BlockBox','',1),(192871,'73821','new_theme','block-192870','BlockBox','',1),(192872,'73822','new_theme','block-192871','checkout\\BillingAddress','',2),(192873,'73823','new_theme','block-192871','Html_box','',1),(192874,'73824','new_theme','block-192870-2','BlockBox','',1),(192875,'73825','new_theme','block-192874','BonusActions\\widgets\\BonusPointsCheckout','',4),(192876,'73826','new_theme','block-192874','checkout\\CreditAmount','',3),(192877,'73827','new_theme','block-192874','checkout\\PaymentMethod','',2),(192878,'73828','new_theme','block-192874','Html_box','',1),(192879,'73829','new_theme','block-192874','CouponsAndVauchers\\Checkout','',5),(192880,'73830','new_theme','checkout_payment_title','Html_box','',1),(192881,'73831','new_theme','checkout_payment_title_g','Html_box','',1),(192882,'73832','new_theme','checkout_payment_title_no_shipping','Html_box','',1),(192883,'73833','new_theme','checkout_payment_title_no_shipping_g','Html_box','',1),(192884,'73834','new_theme','checkout_payment_title_q','Html_box','',1),(192885,'73835','new_theme','checkout_payment_title_s','Html_box','',1),(192886,'73836','new_theme','checkout_q','BlockBox','',1),(192887,'73837','new_theme','block-192886','BlockBox','',2),(192888,'73838','new_theme','block-192887','BlockBox','',2),(192889,'73839','new_theme','block-192888','BlockBox','',6),(192890,'73840','new_theme','block-192889','checkout\\CreateAccount','',3),(192891,'73841','new_theme','block-192889','quote\\Products','',2),(192892,'73842','new_theme','block-192888','BlockBox','',2),(192893,'73843','new_theme','block-192892','BlockBox','',2),(192894,'73844','new_theme','block-192893','checkout\\ShippingChoice','',1),(192895,'73845','new_theme','block-192892','Neighbour\\Checkout','',4),(192896,'73846','new_theme','block-192892','Html_box','',1),(192897,'73847','new_theme','block-192892','BlockBox','',3),(192898,'73848','new_theme','block-192897','BlockBox','',1),(192899,'73849','new_theme','block-192898','checkout\\ContactInformation','',4),(192900,'73850','new_theme','block-192898','checkout\\ShippingAddress','',2),(192901,'73851','new_theme','block-192898','Html_box','',3),(192902,'73852','new_theme','block-192897-2','BlockBox','',1),(192903,'73853','new_theme','block-192902','checkout\\Shipping','',2),(192904,'73854','new_theme','block-192902','Html_box','',1),(192905,'73855','new_theme','block-192902','DelayedDespatch\\Checkout','',3),(192906,'73856','new_theme','block-192888','BlockBox','',5),(192907,'73857','new_theme','block-192906','Html_box','',1),(192908,'73858','new_theme','block-192906','checkout\\Comments','',2),(192909,'73860','new_theme','block-192888','BlockBox','',3),(192910,'73861','new_theme','block-192909','Html_box','',1),(192911,'73862','new_theme','block-192909','BlockBox','',2),(192912,'73863','new_theme','block-192911','checkout\\BillingAddress','',2),(192913,'73864','new_theme','block-192911','Html_box','',1),(192914,'73865','new_theme','block-192911-2','BlockBox','',1),(192915,'73866','new_theme','block-192914','checkout\\PaymentMethod','',2),(192916,'73867','new_theme','block-192914','Html_box','',1),(192917,'73868','new_theme','block-192887-2','BlockBox','',1),(192918,'73869','new_theme','block-192917','Html_box','',1),(192919,'73870','new_theme','block-192917','Html_box','',5),(192920,'73871','new_theme','block-192917','checkout\\Totals','',2),(192921,'73872','new_theme','block-192917','checkout\\ContinueBtn','',3),(192922,'115996','new_theme','block-192917','checkout\\Terms','',4),(192923,'73873','new_theme','checkout_s','BlockBox','',1),(192924,'73874','new_theme','block-192923','BlockBox','',2),(192925,'73875','new_theme','block-192924','BlockBox','',2),(192926,'73876','new_theme','block-192925','checkout\\Gdpr','',1),(192927,'73877','new_theme','block-192925','BlockBox','',6),(192928,'73878','new_theme','block-192927','sample\\Products','',1),(192929,'73879','new_theme','block-192927','checkout\\CreateAccount','',3),(192930,'73880','new_theme','block-192925','BlockBox','',2),(192931,'73881','new_theme','block-192930','Html_box','',1),(192932,'73882','new_theme','block-192930','Neighbour\\Checkout','',4),(192933,'73883','new_theme','block-192930','BlockBox','',2),(192934,'73884','new_theme','block-192933','checkout\\ShippingChoice','',1),(192935,'73885','new_theme','block-192930','BlockBox','',3),(192936,'73886','new_theme','block-192935','BlockBox','',1),(192937,'73887','new_theme','block-192936','checkout\\ShippingAddress','',2),(192938,'73888','new_theme','block-192936','checkout\\ContactInformation','',4),(192939,'73889','new_theme','block-192936','Html_box','',3),(192940,'73890','new_theme','block-192935-2','BlockBox','',1),(192941,'73891','new_theme','block-192940','checkout\\Shipping','',2),(192942,'73892','new_theme','block-192940','DelayedDespatch\\Checkout','',3),(192943,'73893','new_theme','block-192940','Html_box','',1),(192944,'73894','new_theme','block-192925','BlockBox','',3),(192945,'73895','new_theme','block-192944','BlockBox','',2),(192946,'73896','new_theme','block-192945','Html_box','',1),(192947,'73897','new_theme','block-192945','checkout\\BillingAddress','',2),(192948,'73898','new_theme','block-192945-2','BlockBox','',1),(192949,'73899','new_theme','block-192948','Html_box','',1),(192950,'73900','new_theme','block-192948','checkout\\PaymentMethod','',2),(192951,'73901','new_theme','block-192944','Html_box','',1),(192952,'73902','new_theme','block-192925','BlockBox','',5),(192953,'73903','new_theme','block-192952','Html_box','',1),(192954,'73904','new_theme','block-192952','checkout\\Comments','',2),(192955,'73905','new_theme','block-192925','BlockBox','',4),(192956,'73906','new_theme','block-192955','BlockBox','',2),(192957,'73907','new_theme','block-192956','CouponsAndVauchers\\Checkout','',1),(192958,'73908','new_theme','block-192956-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(192959,'73909','new_theme','block-192956-2','checkout\\CreditAmount','',1),(192960,'73910','new_theme','block-192955','Html_box','',1),(192961,'73911','new_theme','block-192924-2','BlockBox','',1),(192962,'73912','new_theme','block-192961','checkout\\Totals','',2),(192963,'73913','new_theme','block-192961','Html_box','',5),(192964,'73914','new_theme','block-192961','Html_box','',1),(192965,'73915','new_theme','block-192961','checkout\\ContinueBtn','',3),(192966,'115998','new_theme','block-192961','checkout\\Terms','',4),(192967,'73916','new_theme','checkout_step_bottom','Html_box','',1),(192968,'73917','new_theme','checkout_step_bottom','cart\\Products','',2),(192969,'73918','new_theme','checkout_step_bottom','checkout\\Totals','',3),(192970,'73919','new_theme','checkout_step_bottom_g','checkout\\Totals','',3),(192971,'73920','new_theme','checkout_step_bottom_g','quote\\Products','',2),(192972,'73921','new_theme','checkout_step_bottom_g','Html_box','',1),(192973,'73923','new_theme','checkout_step_bottom_no_shipping','Html_box','',1),(192974,'73924','new_theme','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(192975,'73927','new_theme','checkout_step_bottom_no_shipping','cart\\Products','',2),(192976,'73922','new_theme','checkout_step_bottom_no_shipping_g','Html_box','',1),(192977,'73925','new_theme','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(192978,'73926','new_theme','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(192979,'73928','new_theme','communication','BlockBox','',1),(192980,'73929','new_theme','block-192979','Html_box','',2),(192981,'73930','new_theme','block-192979','Communication\\NewTopicButton','',1),(192982,'73931','new_theme','block-192979','Communication\\Topic','',3),(192983,'94704','new_theme','compare','BlockBox','',1),(192984,'94705','new_theme','block-192983','catalog\\Compare','',1),(192985,'94706','new_theme','compare_products','BlockBox','',2),(192986,'94707','new_theme','block-192985','productListing\\rating','',4),(192987,'94708','new_theme','block-192985','productListing\\model','',5),(192988,'94709','new_theme','block-192985','productListing\\compare','',1),(192989,'94710','new_theme','block-192985','BlockBox','',2),(192990,'94711','new_theme','block-192989','productListing\\image','',1),(192991,'94712','new_theme','block-192989-2','productListing\\name','',2),(192992,'94713','new_theme','block-192985','BlockBox','',3),(192993,'94714','new_theme','block-192992','productListing\\price','',1),(192994,'94715','new_theme','block-192992-2','productListing\\buyButton','',1),(192995,'73932','new_theme','confirmation','BlockBox','',1),(192996,'73933','new_theme','block-192995','BlockBox','',2),(192997,'73934','new_theme','block-192996','BlockBox','',2),(192998,'73935','new_theme','block-192997','BlockBox','',3),(192999,'73936','new_theme','block-192998','checkout\\EditBtn','',2),(193000,'73937','new_theme','block-192998','cart\\Products','',3),(193001,'73938','new_theme','block-192998','Html_box','',1),(193002,'73939','new_theme','block-192997','BlockBox','',2),(193003,'73940','new_theme','block-193002','checkout\\EditBtn','',2),(193004,'73941','new_theme','block-193002','Html_box','',1),(193005,'73942','new_theme','block-193002','checkout\\CommentsConfirm','',3),(193006,'73943','new_theme','block-192997','BlockBox','',1),(193007,'73944','new_theme','block-193006','BlockBox','',1),(193008,'73945','new_theme','block-193007','checkout\\EditBtn','',6),(193009,'73946','new_theme','block-193007','DelayedDespatch\\CheckoutConfirm','',8),(193010,'73947','new_theme','block-193007','Html_box','',9),(193011,'73948','new_theme','block-193007','checkout\\EditBtn','',10),(193012,'73949','new_theme','block-193007','Html_box','',5),(193013,'73950','new_theme','block-193007','checkout\\ShippingConfirm','',7),(193014,'73951','new_theme','block-193007','Html_box','',1),(193015,'73952','new_theme','block-193007','checkout\\EditBtn','',3),(193016,'73953','new_theme','block-193007','checkout\\ContactConfirm','',11),(193017,'73954','new_theme','block-193007','Html_box','',2),(193018,'73955','new_theme','block-193007','checkout\\ShippingAddressConfirm','',4),(193019,'73956','new_theme','block-193006-2','BlockBox','',1),(193020,'73957','new_theme','block-193019','checkout\\EditBtn','',6),(193021,'73958','new_theme','block-193019','checkout\\EditBtn','',3),(193022,'73959','new_theme','block-193019','checkout\\PaymentMethodConfirm','',7),(193023,'73960','new_theme','block-193019','Html_box','',5),(193024,'73961','new_theme','block-193019','Html_box','',1),(193025,'73962','new_theme','block-193019','checkout\\BillingAddressConfirm','',4),(193026,'73963','new_theme','block-193019','Html_box','',2),(193027,'73964','new_theme','block-192996','UploadCustomerId\\UploadCustomerIdForm','',1),(193028,'73965','new_theme','block-192996-2','BlockBox','',1),(193029,'73966','new_theme','block-193028','Html_box','',1),(193030,'73967','new_theme','block-193028','checkout\\ConfirmBtn','',3),(193031,'73968','new_theme','block-193028','checkout\\Totals','',2),(193032,'73969','new_theme','block-192995','Html_box','',1),(193033,'73970','new_theme','confirmation_free_s','BlockBox','',1),(193034,'73971','new_theme','block-193033','BlockBox','',2),(193035,'73972','new_theme','block-193034','BlockBox','',1),(193036,'73973','new_theme','block-193035','BlockBox','',2),(193037,'73974','new_theme','block-193036','checkout\\CommentsConfirm','',3),(193038,'73975','new_theme','block-193036','checkout\\EditBtn','',2),(193039,'73976','new_theme','block-193036','Html_box','',1),(193040,'73977','new_theme','block-193035','BlockBox','',3),(193041,'73978','new_theme','block-193040','checkout\\EditBtn','',3),(193042,'73979','new_theme','block-193040','Html_box','',1),(193043,'73980','new_theme','block-193040','sample\\Products','',2),(193044,'73981','new_theme','block-193035','BlockBox','',1),(193045,'73982','new_theme','block-193044','BlockBox','',1),(193046,'73983','new_theme','block-193045','checkout\\EditBtn','',3),(193047,'73984','new_theme','block-193045','checkout\\ShippingConfirm','',7),(193048,'73985','new_theme','block-193045','Html_box','',5),(193049,'73986','new_theme','block-193045','checkout\\EditBtn','',6),(193050,'73987','new_theme','block-193045','Html_box','',2),(193051,'73988','new_theme','block-193045','checkout\\ShippingAddressConfirm','',4),(193052,'73989','new_theme','block-193044-2','BlockBox','',1),(193053,'73990','new_theme','block-193052','checkout\\ContactConfirm','',3),(193054,'73991','new_theme','block-193052','DelayedDespatch\\CheckoutConfirm','',4),(193055,'73992','new_theme','block-193052','checkout\\EditBtn','',2),(193056,'73993','new_theme','block-193052','Html_box','',1),(193057,'73994','new_theme','block-193034-2','BlockBox','',1),(193058,'73995','new_theme','block-193057','checkout\\ConfirmBtn','',3),(193059,'73996','new_theme','block-193033','Html_box','',1),(193060,'73997','new_theme','confirmation_no_shipping','BlockBox','',1),(193061,'73998','new_theme','block-193060','Html_box','',1),(193062,'73999','new_theme','block-193060','BlockBox','',2),(193063,'74000','new_theme','block-193062','BlockBox','',1),(193064,'74001','new_theme','block-193063','BlockBox','',1),(193065,'74002','new_theme','block-193064','BlockBox','',1),(193066,'74003','new_theme','block-193065','checkout\\EditBtn','',10),(193067,'74004','new_theme','block-193065','Html_box','',9),(193068,'74005','new_theme','block-193065','checkout\\ContactConfirm','',11),(193069,'74006','new_theme','block-193064-2','BlockBox','',1),(193070,'74007','new_theme','block-193069','checkout\\PaymentMethodConfirm','',7),(193071,'74008','new_theme','block-193069','checkout\\EditBtn','',6),(193072,'74009','new_theme','block-193069','Html_box','',5),(193073,'74010','new_theme','block-193069','Html_box','',1),(193074,'74011','new_theme','block-193069','checkout\\EditBtn','',3),(193075,'74012','new_theme','block-193069','checkout\\BillingAddressConfirm','',4),(193076,'74013','new_theme','block-193069','Html_box','',2),(193077,'74014','new_theme','block-193063','BlockBox','',2),(193078,'74015','new_theme','block-193077','Html_box','',1),(193079,'74016','new_theme','block-193077','checkout\\CommentsConfirm','',3),(193080,'74017','new_theme','block-193077','checkout\\EditBtn','',2),(193081,'74018','new_theme','block-193063','BlockBox','',3),(193082,'74019','new_theme','block-193081','Html_box','',1),(193083,'74020','new_theme','block-193081','checkout\\EditBtn','',2),(193084,'74021','new_theme','block-193081','cart\\Products','',3),(193085,'74022','new_theme','block-193062-2','BlockBox','',1),(193086,'74023','new_theme','block-193085','checkout\\ConfirmBtn','',3),(193087,'74024','new_theme','block-193085','Html_box','',1),(193088,'74025','new_theme','block-193085','checkout\\Totals','',2),(193089,'74026','new_theme','confirmation_no_shipping_q','BlockBox','',2),(193090,'74027','new_theme','block-193089','Html_box','',1),(193091,'74028','new_theme','block-193089','BlockBox','',2),(193092,'74029','new_theme','block-193091','BlockBox','',1),(193093,'74030','new_theme','block-193092','BlockBox','',2),(193094,'74031','new_theme','block-193093','Html_box','',1),(193095,'74032','new_theme','block-193093','checkout\\CommentsConfirm','',3),(193096,'74033','new_theme','block-193093','checkout\\EditBtn','',2),(193097,'74034','new_theme','block-193092','BlockBox','',1),(193098,'74035','new_theme','block-193097','BlockBox','',1),(193099,'74036','new_theme','block-193098','checkout\\EditBtn','',5),(193100,'74037','new_theme','block-193098','checkout\\ContactConfirm','',6),(193101,'74038','new_theme','block-193098','checkout\\PaymentMethodConfirm','',3),(193102,'74039','new_theme','block-193098','checkout\\EditBtn','',2),(193103,'74040','new_theme','block-193098','Html_box','',4),(193104,'74041','new_theme','block-193098','Html_box','',1),(193105,'74042','new_theme','block-193097-2','BlockBox','',1),(193106,'74043','new_theme','block-193105','checkout\\BillingAddressConfirm','',4),(193107,'74044','new_theme','block-193105','checkout\\EditBtn','',3),(193108,'74045','new_theme','block-193105','Html_box','',2),(193109,'74046','new_theme','block-193092','BlockBox','',3),(193110,'74047','new_theme','block-193109','checkout\\EditBtn','',2),(193111,'74048','new_theme','block-193109','Html_box','',1),(193112,'74049','new_theme','block-193109','quote\\Products','',3),(193113,'74050','new_theme','block-193091-2','BlockBox','',1),(193114,'74051','new_theme','block-193113','checkout\\ConfirmBtn','',3),(193115,'74052','new_theme','block-193113','checkout\\Totals','',2),(193116,'74053','new_theme','block-193113','Html_box','',1),(193117,'74054','new_theme','confirmation_q','BlockBox','',1),(193118,'74055','new_theme','block-193117','Html_box','',1),(193119,'74056','new_theme','block-193117','BlockBox','',2),(193120,'74057','new_theme','block-193119','BlockBox','',1),(193121,'74058','new_theme','block-193120','BlockBox','',3),(193122,'74059','new_theme','block-193121','quote\\Products','',3),(193123,'74060','new_theme','block-193121','Html_box','',1),(193124,'74061','new_theme','block-193121','checkout\\EditBtn','',2),(193125,'74062','new_theme','block-193120','BlockBox','',1),(193126,'74063','new_theme','block-193125','BlockBox','',1),(193127,'74064','new_theme','block-193126','Html_box','',1),(193128,'74065','new_theme','block-193126','checkout\\EditBtn','',10),(193129,'74066','new_theme','block-193126','Html_box','',2),(193130,'74067','new_theme','block-193126','checkout\\ContactConfirm','',11),(193131,'74068','new_theme','block-193126','checkout\\ShippingAddressConfirm','',4),(193132,'74069','new_theme','block-193126','checkout\\ShippingConfirm','',7),(193133,'74070','new_theme','block-193126','checkout\\EditBtn','',3),(193134,'74071','new_theme','block-193126','DelayedDespatch\\CheckoutConfirm','',8),(193135,'74072','new_theme','block-193126','Html_box','',9),(193136,'74073','new_theme','block-193126','Html_box','',5),(193137,'74074','new_theme','block-193126','checkout\\EditBtn','',6),(193138,'74075','new_theme','block-193125-2','BlockBox','',1),(193139,'74076','new_theme','block-193138','checkout\\EditBtn','',3),(193140,'74077','new_theme','block-193138','checkout\\BillingAddressConfirm','',4),(193141,'74078','new_theme','block-193138','checkout\\PaymentMethodConfirm','',7),(193142,'74079','new_theme','block-193138','Html_box','',1),(193143,'74080','new_theme','block-193138','Html_box','',2),(193144,'74081','new_theme','block-193138','checkout\\EditBtn','',6),(193145,'74082','new_theme','block-193138','Html_box','',5),(193146,'74083','new_theme','block-193120','BlockBox','',2),(193147,'74084','new_theme','block-193146','checkout\\CommentsConfirm','',3),(193148,'74085','new_theme','block-193146','Html_box','',1),(193149,'74086','new_theme','block-193146','checkout\\EditBtn','',2),(193150,'74087','new_theme','block-193119-2','BlockBox','',1),(193151,'74088','new_theme','block-193150','Html_box','',1),(193152,'74089','new_theme','block-193150','checkout\\Totals','',2),(193153,'74090','new_theme','block-193150','checkout\\ConfirmBtn','',3),(193154,'74091','new_theme','confirmation_s','BlockBox','',1),(193155,'74092','new_theme','block-193154','BlockBox','',2),(193156,'74093','new_theme','block-193155','BlockBox','',1),(193157,'74094','new_theme','block-193156','BlockBox','',1),(193158,'74095','new_theme','block-193157','BlockBox','',1),(193159,'74096','new_theme','block-193158','checkout\\ShippingAddressConfirm','',4),(193160,'74097','new_theme','block-193158','checkout\\EditBtn','',3),(193161,'74098','new_theme','block-193158','Html_box','',2),(193162,'74099','new_theme','block-193158','DelayedDespatch\\CheckoutConfirm','',8),(193163,'74100','new_theme','block-193158','checkout\\ShippingConfirm','',7),(193164,'74101','new_theme','block-193158','Html_box','',1),(193165,'74102','new_theme','block-193158','Html_box','',5),(193166,'74103','new_theme','block-193158','Html_box','',9),(193167,'74104','new_theme','block-193158','checkout\\ContactConfirm','',11),(193168,'74105','new_theme','block-193158','checkout\\EditBtn','',6),(193169,'74106','new_theme','block-193158','checkout\\EditBtn','',10),(193170,'74107','new_theme','block-193157-2','BlockBox','',1),(193171,'74108','new_theme','block-193170','Html_box','',2),(193172,'74109','new_theme','block-193170','checkout\\BillingAddressConfirm','',4),(193173,'74110','new_theme','block-193170','checkout\\EditBtn','',3),(193174,'74111','new_theme','block-193170','checkout\\PaymentMethodConfirm','',7),(193175,'74112','new_theme','block-193170','checkout\\EditBtn','',6),(193176,'74113','new_theme','block-193170','Html_box','',1),(193177,'74114','new_theme','block-193170','Html_box','',5),(193178,'74115','new_theme','block-193156','BlockBox','',3),(193179,'74116','new_theme','block-193178','checkout\\EditBtn','',3),(193180,'74117','new_theme','block-193178','Html_box','',1),(193181,'74118','new_theme','block-193178','sample\\Products','',2),(193182,'74119','new_theme','block-193156','BlockBox','',2),(193183,'74120','new_theme','block-193182','Html_box','',1),(193184,'74121','new_theme','block-193182','checkout\\EditBtn','',2),(193185,'74122','new_theme','block-193182','checkout\\CommentsConfirm','',3),(193186,'74123','new_theme','block-193155-2','BlockBox','',1),(193187,'74124','new_theme','block-193186','checkout\\Totals','',2),(193188,'74125','new_theme','block-193186','checkout\\ConfirmBtn','',3),(193189,'74126','new_theme','block-193186','Html_box','',1),(193190,'74127','new_theme','block-193154','Html_box','',1),(193191,'74128','new_theme','contact','BlockBox','',1),(193192,'74132','new_theme','block-193191','info\\Title','',1),(193193,'74133','new_theme','block-193191','BlockBox','',3),(193194,'74134','new_theme','block-193193','contact\\ContactForm','',1),(193195,'74135','new_theme','block-193193-2','contact\\Contacts','',1),(193196,'74136','new_theme','created_success','BlockBox','',1),(193197,'74137','new_theme','block-193196','Html_box','',1),(193198,'74138','new_theme','block-193196','Html_box','',2),(193199,'74139','new_theme','credit_note','invoice\\Container','',1),(193200,'74140','new_theme','block-193199','BlockBox','',5),(193201,'74141','new_theme','block-193200','invoice\\StoreAddress','',8),(193202,'74142','new_theme','block-193200','Text','',1),(193203,'74143','new_theme','block-193200-2','Text','',2),(193204,'74144','new_theme','block-193200-2','Logo','',1),(193205,'74145','new_theme','block-193200-3','Text','',1),(193206,'74146','new_theme','block-193200-3','BlockBox','',3),(193207,'74147','new_theme','block-193206','Text','',1),(193208,'74148','new_theme','block-193206-2','invoice\\StoreEmail','',1),(193209,'74149','new_theme','block-193200-3','BlockBox','',2),(193210,'74150','new_theme','block-193209','Text','',1),(193211,'74151','new_theme','block-193209-2','invoice\\StorePhone','',1),(193212,'74152','new_theme','block-193199','invoice\\Products','',3),(193213,'74153','new_theme','block-193199','BlockBox','',1),(193214,'74154','new_theme','block-193213','Logo','',1),(193215,'74155','new_theme','block-193213-2','BlockBox','',4),(193216,'74156','new_theme','block-193215','Text','',1),(193217,'74157','new_theme','block-193215-2','invoice\\StoreSite','',1),(193218,'74158','new_theme','block-193213-2','BlockBox','',2),(193219,'74159','new_theme','block-193218','Text','',1),(193220,'74160','new_theme','block-193218-2','invoice\\StorePhone','',1),(193221,'74161','new_theme','block-193213-2','BlockBox','',3),(193222,'74162','new_theme','block-193221','Text','',1),(193223,'74163','new_theme','block-193221-2','invoice\\StoreEmail','',1),(193224,'74164','new_theme','block-193213-2','BlockBox','',1),(193225,'74165','new_theme','block-193224','invoice\\StoreAddress','',1),(193226,'74166','new_theme','block-193199','BlockBox','',4),(193227,'74167','new_theme','block-193226','BlockBox','',1),(193228,'74168','new_theme','block-193227','invoice\\ShippingAddress','',2),(193229,'74169','new_theme','block-193227','Text','',1),(193230,'74170','new_theme','block-193226-2','BlockBox','',1),(193231,'74171','new_theme','block-193199','BlockBox','',2),(193232,'74172','new_theme','block-193231','BlockBox','',7),(193233,'74173','new_theme','block-193232','BlockBox','',1),(193234,'74174','new_theme','block-193233','Text','',1),(193235,'74175','new_theme','block-193233','invoice\\BillingAddress','',2),(193236,'74176','new_theme','block-193232-2','BlockBox','',1),(193237,'74177','new_theme','block-193236','invoice\\CustomerPhone','',4),(193238,'74178','new_theme','block-193236','Text','',1),(193239,'74179','new_theme','block-193236','Text','',3),(193240,'74180','new_theme','block-193236','invoice\\CustomerName','',2),(193241,'74181','new_theme','block-193236','invoice\\CustomerEmail','',6),(193242,'74182','new_theme','block-193236','Text','',5),(193243,'74183','new_theme','block-193231','BlockBox','',8),(193244,'74184','new_theme','block-193243','BlockBox','',1),(193245,'74185','new_theme','block-193244','invoice\\ShippingMethod','',2),(193246,'74186','new_theme','block-193244','Text','',1),(193247,'74187','new_theme','block-193243-2','BlockBox','',1),(193248,'74188','new_theme','block-193247','Text','',1),(193249,'74189','new_theme','block-193247','invoice\\ShippingMethod','',2),(193250,'74190','new_theme','block-193231-2','invoice\\OrderId','',1),(193251,'74191','new_theme','block-193231-2','Text','',2),(193252,'74192','new_theme','block-193231-2','invoice\\PaymentDate','',3),(193253,'74193','new_theme','delivery-location','DeliveryLocation\\FeaturedList','',6),(193254,'74194','new_theme','delivery-location','DeliveryLocation\\LocationLongDescription','',5),(193255,'74195','new_theme','delivery-location','DeliveryLocation\\LocationList','',7),(193256,'74196','new_theme','delivery-location','DeliveryLocation\\LocationTitle','',2),(193257,'74197','new_theme','delivery-location','DeliveryLocation\\LocationProducts','',8),(193258,'74198','new_theme','delivery-location','DeliveryLocation\\LocationDescription','',3),(193259,'74199','new_theme','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(193260,'74200','new_theme','delivery-location-default','DeliveryLocation\\TopLocationList','',2),(193261,'74201','new_theme','delivery-location-default','Heading','',1),(193262,'94716','new_theme','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(193263,'94717','new_theme','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(193264,'94718','new_theme','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(193265,'94719','new_theme','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(193266,'94720','new_theme','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(193267,'94721','new_theme','delivery_loc_2','DeliveryLocation\\LocationList','',7),(193268,'94722','new_theme','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(193269,'74202','new_theme','email','email\\BlockBox','',1),(193270,'74203','new_theme','block-193269','email\\BlockBox','',1),(193271,'74204','new_theme','block-193270','Copyright','',4),(193272,'74205','new_theme','block-193270','email\\Content','',3),(193273,'74206','new_theme','block-193270','email\\BlockBox','',2),(193274,'74207','new_theme','block-193273','email\\Title','',1),(193275,'74208','new_theme','block-193273-2','email\\Date','',1),(193276,'74209','new_theme','block-193270','Logo','',1),(193277,'74210','new_theme','email_2','email\\BlockBox','',1),(193278,'74211','new_theme','block-193277','email\\BlockBox','',1),(193279,'74212','new_theme','block-193278','Copyright','',4),(193280,'74213','new_theme','block-193278','Logo','',1),(193281,'74214','new_theme','block-193278','email\\Content','',3),(193282,'74215','new_theme','block-193278','email\\BlockBox','',2),(193283,'74216','new_theme','block-193282','email\\Title','',1),(193284,'74217','new_theme','block-193282-2','email\\Date','',1),(193285,'74218','new_theme','email_3','email\\BlockBox','',1),(193286,'74219','new_theme','block-193285','email\\BlockBox','',1),(193287,'74220','new_theme','block-193286','email\\BlockBox','',2),(193288,'74221','new_theme','block-193287','email\\Content','',2),(193289,'74222','new_theme','block-193287','email\\BlockBox','',1),(193290,'74223','new_theme','block-193289','email\\Title','',1),(193291,'74224','new_theme','block-193289-2','email\\Date','',1),(193292,'74225','new_theme','block-193286','Copyright','',3),(193293,'74226','new_theme','block-193286','Logo','',1),(193294,'74227','new_theme','email_4','email\\BlockBox','',1),(193295,'74228','new_theme','block-193294','email\\BlockBox','',1),(193296,'74229','new_theme','block-193295','Copyright','',2),(193297,'74230','new_theme','block-193295','email\\BlockBox','',1),(193298,'74231','new_theme','block-193297','email\\BlockBox','',1),(193299,'74232','new_theme','block-193298','Logo','',1),(193300,'74233','new_theme','block-193298-2','email\\Date','',2),(193301,'74234','new_theme','block-193298-2','email\\Title','',1),(193302,'74235','new_theme','block-193297','email\\Content','',2),(193303,'74236','new_theme','footer','BlockBox','',1),(193304,'74237','new_theme','block-193303','BlockBox','',1),(193305,'74238','new_theme','block-193304','BlockBox','',1),(193306,'74239','new_theme','block-193305','Menu','footer3',3),(193307,'1695906739.5696','new_theme','block-193305','Html_box','',2),(193308,'74241','new_theme','block-193304-2','BlockBox','',1),(193309,'74243','new_theme','block-193308','Menu','footer1',3),(193310,'1695906751.0591','new_theme','block-193308','Html_box','',2),(193311,'74244','new_theme','block-193304-3','BlockBox','',1),(193312,'74246','new_theme','block-193311','Menu','footer2',3),(193313,'1695906756.0887','new_theme','block-193311','Html_box','',2),(193314,'74247','new_theme','block-193304-4','BlockBox','',1),(193315,'74248','new_theme','block-193314','Contacts','',4),(193316,'74249','new_theme','block-193314','Contacts','',3),(193317,'1695906761.6568','new_theme','block-193314','Html_box','',2),(193318,'74256','new_theme','block-193303','BlockBox','footer-content',4),(193319,'74257','new_theme','block-193318','Copyright','',1),(193320,'74258','new_theme','block-193318-2','invoice\\StoreAddress','',1),(193321,'94723','new_theme','for_menu','BlockBox','',1),(193322,'94724','new_theme','block-193321','Html_box','',1),(193323,'94725','new_theme','block-193321-2','Languages','',1),(193324,'94726','new_theme','for_menu','BlockBox','',3),(193325,'94727','new_theme','block-193324','Html_box','',1),(193326,'94728','new_theme','block-193324-2','Currencies','',1),(193327,'74263','new_theme','gift','BlockBox','',1),(193328,'74264','new_theme','block-193327','BlockBox','',3),(193329,'74265','new_theme','block-193328','BlockBox','',1),(193330,'74266','new_theme','block-193329','gift\\Card','',1),(193331,'74267','new_theme','block-193328-2','gift\\Form','',2),(193332,'74268','new_theme','block-193328-2','Text','',1),(193333,'74269','new_theme','block-193327','info\\Title','',1),(193334,'74270','new_theme','gift_card','BlockBox','',1),(193335,'74271','new_theme','block-193334','BlockBox','',11),(193336,'74272','new_theme','block-193335','invoice\\StoreEmail','',3),(193337,'74273','new_theme','block-193335','Text','',1),(193338,'74274','new_theme','block-193335','invoice\\StorePhone','',2),(193339,'74275','new_theme','block-193334','Text','',8),(193340,'74276','new_theme','block-193334','Text','',3),(193341,'74277','new_theme','block-193334','BlockBox','',10),(193342,'74278','new_theme','block-193341','Text','',1),(193343,'74279','new_theme','block-193341-2','gift\\CodeView','',1),(193344,'74280','new_theme','block-193334','gift\\MessageView','',7),(193345,'74281','new_theme','block-193334','gift\\AmountView','',5),(193346,'74282','new_theme','block-193334','Text','',6),(193347,'74284','new_theme','block-193334','Logo','',1),(193348,'74285','new_theme','block-193334','Text','',4),(193349,'74286','new_theme','block-193334','Text','',9),(193350,'74287','new_theme','gift_card_2','BlockBox','',1),(193351,'74288','new_theme','block-193350','gift\\AmountView','',3),(193352,'74289','new_theme','block-193350','BlockBox','',8),(193353,'74290','new_theme','block-193352','Text','',1),(193354,'74291','new_theme','block-193352-2','gift\\CodeView','',1),(193355,'74292','new_theme','block-193350','BlockBox','',9),(193356,'74293','new_theme','block-193355','invoice\\StoreEmail','',3),(193357,'74294','new_theme','block-193355','Text','',1),(193358,'74295','new_theme','block-193355','invoice\\StorePhone','',2),(193359,'74296','new_theme','block-193350','gift\\MessageView','',5),(193360,'74297','new_theme','block-193350','Text','',4),(193361,'74298','new_theme','block-193350','Text','',7),(193362,'74299','new_theme','block-193350','Text','',2),(193363,'74300','new_theme','block-193350','Text','',6),(193364,'74301','new_theme','block-193350','Text','',1),(193365,'94729','new_theme','gift_card_2_pdf','BlockBox','',1),(193366,'94730','new_theme','block-193365','BlockBox','',12),(193367,'94731','new_theme','block-193366','invoice\\StoreEmail','',4),(193368,'94732','new_theme','block-193366','invoice\\StorePhone','',3),(193369,'94733','new_theme','block-193366','Html_box','',1),(193370,'94734','new_theme','block-193365','BlockBox','',11),(193371,'94735','new_theme','block-193370','Html_box','',1),(193372,'94736','new_theme','block-193370-2','gift\\CodeViewPdf','',1),(193373,'94737','new_theme','block-193365','BlockBox','',1),(193374,'94738','new_theme','block-193373','Text','',4),(193375,'94739','new_theme','block-193373','Html_box','',1),(193376,'94740','new_theme','block-193373','Html_box','',2),(193377,'94741','new_theme','block-193373','gift\\AmountViewPdf','',3),(193378,'94742','new_theme','block-193373','gift\\MessageViewPdf','',5),(193379,'94743','new_theme','block-193373','Html_box','',7),(193380,'94744','new_theme','block-193373','Html_box','',6),(193381,'94746','new_theme','gift_card_pdf','BlockBox','',1),(193382,'94747','new_theme','block-193381','BlockBox','',12),(193383,'94748','new_theme','block-193382','invoice\\StoreEmail','',4),(193384,'94749','new_theme','block-193382','invoice\\StorePhone','',3),(193385,'94750','new_theme','block-193382','Html_box','',1),(193386,'94751','new_theme','block-193381','BlockBox','',11),(193387,'94752','new_theme','block-193386','Html_box','',1),(193388,'94753','new_theme','block-193386-2','gift\\CodeViewPdf','',1),(193389,'94754','new_theme','block-193381','BlockBox','',1),(193390,'94755','new_theme','block-193389','Text','',5),(193391,'94757','new_theme','block-193389','Html_box','',3),(193392,'94758','new_theme','block-193389','gift\\AmountViewPdf','',4),(193393,'94759','new_theme','block-193389','gift\\MessageViewPdf','',6),(193394,'94760','new_theme','block-193389','Html_box','',8),(193395,'94761','new_theme','block-193389','Html_box','',7),(193396,'1707902674.2595','new_theme','block-193389','Logo','',2),(193397,'94762','new_theme','gift_card_pdf','Import','',1),(193398,'74302','new_theme','gift_certificate','BlockBox','',1),(193399,'74303','new_theme','block-193398','account\\ApplyCertificate','',2),(193400,'74304','new_theme','block-193398','Html_box','',1),(193401,'74305','new_theme','gigt_card_3','BlockBox','',1),(193402,'74306','new_theme','block-193401','BlockBox','',8),(193403,'74307','new_theme','block-193402','Text','',1),(193404,'74308','new_theme','block-193402-2','gift\\CodeView','',1),(193405,'74309','new_theme','block-193401','Text','',6),(193406,'74310','new_theme','block-193401','Text','',1),(193407,'74311','new_theme','block-193401','BlockBox','',9),(193408,'74312','new_theme','block-193407','Text','',1),(193409,'74313','new_theme','block-193407','invoice\\StoreEmail','',3),(193410,'74314','new_theme','block-193407','invoice\\StorePhone','',2),(193411,'74315','new_theme','block-193401','gift\\MessageView','',5),(193412,'74316','new_theme','block-193401','Text','',2),(193413,'74317','new_theme','block-193401','Text','',4),(193414,'74318','new_theme','block-193401','gift\\AmountView','',3),(193415,'74319','new_theme','block-193401','Text','',7),(193416,'94763','new_theme','gigt_card_3_pdf','BlockBox','',1),(193417,'94764','new_theme','block-193416','BlockBox','',12),(193418,'94765','new_theme','block-193417','invoice\\StoreEmail','',4),(193419,'94766','new_theme','block-193417','invoice\\StorePhone','',3),(193420,'94767','new_theme','block-193417','Html_box','',1),(193421,'94768','new_theme','block-193416','BlockBox','',11),(193422,'94769','new_theme','block-193421','Html_box','',1),(193423,'94770','new_theme','block-193421-2','gift\\CodeViewPdf','',1),(193424,'94771','new_theme','block-193416','BlockBox','',1),(193425,'94772','new_theme','block-193424','Text','',4),(193426,'94773','new_theme','block-193424','Html_box','',1),(193427,'94774','new_theme','block-193424','Html_box','',2),(193428,'94775','new_theme','block-193424','gift\\AmountViewPdf','',3),(193429,'94776','new_theme','block-193424','gift\\MessageViewPdf','',5),(193430,'94777','new_theme','block-193424','Html_box','',7),(193431,'94778','new_theme','block-193424','Html_box','',6),(193432,'1713770938.449798','new_theme','header','CookieNotice','',1),(193433,'1713770938.464587','new_theme','header','BlockBox','header-content-small',2),(193434,'1713770938.467593','new_theme','block-193433','BlockBox','header-content-small-left',1),(193435,'1713770938.470248','new_theme','block-193434','Menu','Header menu',1),(193436,'1713770938.51635','new_theme','block-193434-2','BlockBox','header-content-small-right',5),(193437,'1713770938.51828','new_theme','block-193436','Cart','',1),(193438,'1713770938.573998','new_theme','block-193436','Account','',2),(193439,'1713770938.61982','new_theme','block-193436','Currencies','',4),(193440,'1713770938.663457','new_theme','block-193436','Languages','',3),(193441,'1713770938.697915','new_theme','header','BlockBox','header-content',3),(193442,'1713770938.706821','new_theme','block-193441','Logo','',1),(193443,'1713770938.709156','new_theme','block-193441','Search','',2),(193444,'1713770938.773998','new_theme','block-193441','Text','',3),(193445,'1713770938.811953','new_theme','header','BlockBox','header-menu',4),(193446,'1713770938.81834','new_theme','block-193445','Menu','Categories',1),(193447,'74346','new_theme','info','BlockBox','info-content',1),(193448,'74347','new_theme','block-193447','info\\DescriptionShort','',2),(193449,'74348','new_theme','block-193447','info\\Content','',4),(193450,'74349','new_theme','block-193447','info\\Title','',1),(193451,'74350','new_theme','block-193447','info\\Image','',3),(193452,'74351','new_theme','invoice','invoice\\Container','',1),(193453,'74352','new_theme','block-193452','BlockBox','',3),(193454,'74353','new_theme','block-193453','BlockBox','',8),(193455,'74354','new_theme','block-193454','BlockBox','',1),(193456,'74355','new_theme','block-193455','invoice\\ShippingMethod','',2),(193457,'74356','new_theme','block-193455','Text','',1),(193458,'74357','new_theme','block-193454-2','BlockBox','',1),(193459,'74358','new_theme','block-193458','Text','',1),(193460,'74359','new_theme','block-193458','invoice\\ShippingMethod','',2),(193461,'74360','new_theme','block-193453','BlockBox','',7),(193462,'74361','new_theme','block-193461','BlockBox','',1),(193463,'74362','new_theme','block-193462','Text','',1),(193464,'74363','new_theme','block-193462','invoice\\BillingAddress','',2),(193465,'74364','new_theme','block-193461-2','BlockBox','',1),(193466,'74365','new_theme','block-193465','Text','',5),(193467,'74366','new_theme','block-193465','invoice\\CustomerName','',2),(193468,'74367','new_theme','block-193465','invoice\\CustomerPhone','',4),(193469,'74368','new_theme','block-193465','Text','',1),(193470,'74369','new_theme','block-193465','Text','',3),(193471,'74370','new_theme','block-193465','invoice\\CustomerEmail','',6),(193472,'74371','new_theme','block-193453-2','invoice\\PaymentMethod','',5),(193473,'74372','new_theme','block-193453-2','Text','',4),(193474,'74373','new_theme','block-193453-2','Text','',2),(193475,'74374','new_theme','block-193453-2','invoice\\OrderId','',1),(193476,'74375','new_theme','block-193453-2','invoice\\PaymentDate','',3),(193477,'74376','new_theme','block-193453-2','invoice\\OrderBarcode','',6),(193478,'74377','new_theme','block-193452','BlockBox','',6),(193479,'74378','new_theme','block-193478','invoice\\StoreAddress','',8),(193480,'74379','new_theme','block-193478','Text','',1),(193481,'74380','new_theme','block-193478-2','Text','',2),(193482,'74381','new_theme','block-193478-2','Logo','',1),(193483,'74382','new_theme','block-193478-3','BlockBox','',3),(193484,'74383','new_theme','block-193483','Text','',1),(193485,'74384','new_theme','block-193483-2','invoice\\StoreEmail','',1),(193486,'74385','new_theme','block-193478-3','BlockBox','',2),(193487,'74386','new_theme','block-193486','Text','',1),(193488,'74387','new_theme','block-193486-2','invoice\\StorePhone','',1),(193489,'74388','new_theme','block-193478-3','Text','',1),(193490,'74389','new_theme','block-193452','invoice\\Products','',4),(193491,'74390','new_theme','block-193452','BlockBox','',5),(193492,'74391','new_theme','block-193491','BlockBox','',1),(193493,'74392','new_theme','block-193492','invoice\\ShippingAddress','',2),(193494,'74393','new_theme','block-193492','Text','',1),(193495,'74394','new_theme','block-193491-2','BlockBox','',1),(193496,'74395','new_theme','block-193495','invoice\\Totals','',1),(193497,'74396','new_theme','block-193452','BlockBox','',2),(193498,'74397','new_theme','block-193497','Logo','',1),(193499,'74398','new_theme','block-193497-2','BlockBox','',4),(193500,'74399','new_theme','block-193499','Text','',1),(193501,'74400','new_theme','block-193499-2','invoice\\StoreSite','',1),(193502,'74401','new_theme','block-193497-2','BlockBox','',3),(193503,'74402','new_theme','block-193502','Text','',1),(193504,'74403','new_theme','block-193502-2','invoice\\StoreEmail','',1),(193505,'74404','new_theme','block-193497-2','BlockBox','',1),(193506,'74405','new_theme','block-193505','invoice\\StoreAddress','',3),(193507,'74406','new_theme','block-193497-2','BlockBox','',2),(193508,'74407','new_theme','block-193507','Text','',1),(193509,'74408','new_theme','block-193507-2','invoice\\StorePhone','',1),(193510,'74409','new_theme','login_account','BlockBox','',1),(193511,'74410','new_theme','block-193510','Tabs','',2),(193512,'74411','new_theme','block-193511-1','login\\Returning','',1),(193513,'74412','new_theme','block-193511-2','BlockBox','',1),(193514,'74413','new_theme','block-193513','Html_box','',1),(193515,'74414','new_theme','block-193513-2','BlockBox','',1),(193516,'74415','new_theme','block-193515','Html_box','',2),(193517,'74416','new_theme','block-193515','login\\Register','',1),(193518,'74417','new_theme','block-193510','BlockBox','',1),(193519,'74418','new_theme','block-193518','Html_box','',3),(193520,'74419','new_theme','block-193518','Html_box','',1),(193521,'74420','new_theme','block-193518','login\\Socials','',2),(193522,'74421','new_theme','login_checkout','BlockBox','',1),(193523,'74422','new_theme','block-193522','BlockBox','',1),(193524,'74423','new_theme','block-193523','checkout\\CreateBtn','',4),(193525,'74424','new_theme','block-193523','checkout\\GuestBtn','',2),(193526,'74425','new_theme','block-193523','Html_box','',3),(193527,'74426','new_theme','block-193523','BlockBox','',5),(193528,'74427','new_theme','block-193527','Html_box','',1),(193529,'74428','new_theme','block-193527','login\\Socials','',2),(193530,'74429','new_theme','block-193523','Html_box','',1),(193531,'74430','new_theme','block-193523-2','login\\Returning','',2),(193532,'74431','new_theme','block-193523-2','Html_box','',1),(193533,'74432','new_theme','login_checkout2','BlockBox','',1),(193534,'74433','new_theme','block-193533','Tabs','',4),(193535,'74434','new_theme','block-193534-1','BlockBox','',1),(193536,'74435','new_theme','block-193535','Html_box','',1),(193537,'74436','new_theme','block-193535-2','BlockBox','',1),(193538,'74437','new_theme','block-193537','login\\Guest','',1),(193539,'74438','new_theme','block-193537','Html_box','',2),(193540,'74439','new_theme','block-193534-2','login\\Returning','',1),(193541,'74440','new_theme','block-193534-3','BlockBox','',1),(193542,'74441','new_theme','block-193541','Html_box','',1),(193543,'74442','new_theme','block-193541-2','BlockBox','',1),(193544,'74443','new_theme','block-193543','Html_box','',2),(193545,'74444','new_theme','block-193543','login\\Register','',1),(193546,'74445','new_theme','block-193533','login\\Socials','',2),(193547,'74446','new_theme','block-193533','Html_box','',3),(193548,'74447','new_theme','block-193533','Html_box','',1),(193549,'74448','new_theme','login_checkout2_q','BlockBox','',1),(193550,'74449','new_theme','block-193549','Tabs','',4),(193551,'74450','new_theme','block-193550-1','BlockBox','',1),(193552,'74451','new_theme','block-193551','Html_box','',1),(193553,'74452','new_theme','block-193551-2','quote\\FastOrder','',1),(193554,'74453','new_theme','block-193550-2','login\\Returning','',1),(193555,'74454','new_theme','block-193550-3','BlockBox','',1),(193556,'74455','new_theme','block-193555','Html_box','',1),(193557,'74456','new_theme','block-193555','Import','',2),(193558,'74457','new_theme','block-193555-2','BlockBox','',1),(193559,'74458','new_theme','block-193558','login\\Register','',1),(193560,'74459','new_theme','block-193558','Html_box','',2),(193561,'74460','new_theme','block-193549','Html_box','',3),(193562,'74461','new_theme','block-193549','Html_box','',1),(193563,'74462','new_theme','block-193549','login\\Socials','',2),(193564,'74463','new_theme','login_checkout2_s','BlockBox','',1),(193565,'74464','new_theme','block-193564','login\\Socials','',2),(193566,'74465','new_theme','block-193564','Html_box','',3),(193567,'74466','new_theme','block-193564','Tabs','',4),(193568,'74467','new_theme','block-193567-1','BlockBox','',1),(193569,'74468','new_theme','block-193568','Html_box','',1),(193570,'74469','new_theme','block-193568-2','quote\\FastOrder','',1),(193571,'74470','new_theme','block-193567-2','login\\Returning','',1),(193572,'74471','new_theme','block-193567-3','BlockBox','',1),(193573,'74472','new_theme','block-193572','Html_box','',1),(193574,'74473','new_theme','block-193572-2','BlockBox','',1),(193575,'74474','new_theme','block-193574','login\\Register','',1),(193576,'74475','new_theme','block-193574','Html_box','',2),(193577,'74476','new_theme','block-193564','Html_box','',1),(193578,'74477','new_theme','login_checkout_q','BlockBox','',1),(193579,'74478','new_theme','block-193578','BlockBox','',1),(193580,'74479','new_theme','block-193579','BlockBox','',6),(193581,'74480','new_theme','block-193580','Html_box','',1),(193582,'74481','new_theme','block-193580','login\\Socials','',2),(193583,'74482','new_theme','block-193579','checkout\\GuestBtn','',2),(193584,'74483','new_theme','block-193579','checkout\\CreateBtn','',5),(193585,'74484','new_theme','block-193579','Html_box','',4),(193586,'74485','new_theme','block-193579','Html_box','',1),(193587,'74486','new_theme','block-193579-2','Html_box','',1),(193588,'74487','new_theme','block-193579-2','login\\Returning','',2),(193589,'74488','new_theme','login_checkout_s','BlockBox','',1),(193590,'74489','new_theme','block-193589','BlockBox','',1),(193591,'74490','new_theme','block-193590','Html_box','',1),(193592,'74491','new_theme','block-193590','checkout\\GuestBtn','',2),(193593,'74492','new_theme','block-193590','checkout\\CreateBtn','',4),(193594,'74493','new_theme','block-193590','Html_box','',3),(193595,'74494','new_theme','block-193590','BlockBox','',5),(193596,'74495','new_theme','block-193595','Html_box','',1),(193597,'74496','new_theme','block-193595','login\\Socials','',2),(193598,'74497','new_theme','block-193590-2','Html_box','',1),(193599,'74498','new_theme','block-193590-2','login\\Returning','',2),(193600,'74499','new_theme','logoff','BlockBox','',1),(193601,'74500','new_theme','block-193600','Html_box','',1),(193602,'74501','new_theme','logoff_forever','BlockBox','',1),(193603,'74502','new_theme','block-193602','Html_box','',1),(193604,'74503','new_theme','main','BlockBox','',5),(193605,'74504','new_theme','block-193604','BlockBox','',1),(193606,'74505','new_theme','block-193605','Bestsellers','10',1),(193607,'74506','new_theme','block-193605-2','Reviews','3',1),(193608,'74507','new_theme','main','Banner','',2),(193609,'74508','new_theme','main','BlockBox','main-content',4),(193610,'74510','new_theme','block-193609','Tabs','',4),(193611,'74511','new_theme','block-193610-1','NewProducts','8',1),(193612,'74512','new_theme','block-193610-2','SpecialsProducts','',2),(193613,'74513','new_theme','block-193610-3','FeaturedProducts','4',2),(193614,'74514','new_theme','block-193609','TopCategories','',3),(193615,'74515','new_theme','main','Heading','',3),(193616,'1708693901.7617','new_theme','main','FormBuilder\\widgets\\Form','',6),(193617,'74516','new_theme','manufacturers','BlockBox','',1),(193618,'74517','new_theme','block-193617','Html_box','',1),(193619,'74518','new_theme','block-193617','Brands','',2),(193620,'74519','new_theme','messages-index','BlockBox','',1),(193621,'74520','new_theme','block-193620','BlockBox','',1),(193622,'74521','new_theme','block-193621','BlockBox','',1),(193623,'74522','new_theme','block-193622','Messages\\Sidebar','',1),(193624,'74523','new_theme','block-193621-2','Messages\\Listing','',1),(193625,'74524','new_theme','messages-new','BlockBox','',1),(193626,'74525','new_theme','block-193625','BlockBox','',1),(193627,'74526','new_theme','block-193626','Messages\\Sidebar','',1),(193628,'74527','new_theme','block-193626-2','Messages\\NewMessage','',1),(193629,'74528','new_theme','messages-view','BlockBox','',1),(193630,'74529','new_theme','block-193629','BlockBox','',1),(193631,'74530','new_theme','block-193630','Messages\\Sidebar','',1),(193632,'74531','new_theme','block-193630-2','Messages\\Message','',1),(193633,'74532','new_theme','my_password','BlockBox','',1),(193634,'74533','new_theme','block-193633','BlockBox','',1),(193635,'74534','new_theme','block-193634','WidgetsAria','',1),(193655,'74535','new_theme','block-193634-2','account\\ChangePassword','',2),(193656,'74536','new_theme','block-193634-2','Html_box','',1),(193657,'74537','new_theme','need_login','BlockBox','',1),(193658,'74538','new_theme','block-193657','Tabs','',2),(193659,'74539','new_theme','block-193658-1','login\\Returning','',1),(193660,'74540','new_theme','block-193658-2','BlockBox','',1),(193661,'74541','new_theme','block-193660','Html_box','',1),(193662,'74542','new_theme','block-193660-2','BlockBox','',1),(193663,'74543','new_theme','block-193662','login\\Register','',1),(193664,'74544','new_theme','block-193662','Html_box','',2),(193665,'74545','new_theme','block-193657','BlockBox','',1),(193666,'74546','new_theme','new-topic','BlockBox','',1),(193667,'74547','new_theme','block-193666','Breadcrumb','',2),(193668,'74548','new_theme','block-193666','Communication\\NewTopic','',3),(193669,'74549','new_theme','block-193666','Html_box','',1),(193670,'94779','new_theme','nnnn','BlockBox','',1),(193671,'94780','new_theme','block-193670','catalog\\Title','',1),(193672,'94781','new_theme','block-193670','BlockBox','',2),(193673,'94782','new_theme','block-193672','Filters','',1),(193674,'94783','new_theme','block-193672-2','Listing','',5),(193675,'94784','new_theme','block-193672-2','catalog\\Image','',1),(193676,'94785','new_theme','block-193672-2','BlockBox','',6),(193677,'94786','new_theme','block-193676','catalog\\CountsItems','',1),(193678,'94787','new_theme','block-193676-2','catalog\\Paging','',1),(193679,'94788','new_theme','block-193672-2','catalog\\ImageMapCategory','',3),(193680,'94789','new_theme','block-193672-2','Categories','',2),(193681,'94790','new_theme','block-193672-2','BlockBox','',4),(193682,'94791','new_theme','block-193681','catalog\\ListingLook','',1),(193683,'94792','new_theme','block-193681','catalog\\ItemsOnPage','',4),(193684,'94793','new_theme','block-193681','catalog\\CompareButton','',2),(193685,'94794','new_theme','block-193681','catalog\\Sorting','',3),(193686,'74550','new_theme','no-logged','BlockBox','',1),(193687,'74551','new_theme','block-193686','Communication\\NewTopic','',2),(193688,'74552','new_theme','block-193686','Html_box','',1),(193689,'74553','new_theme','no_filters','BlockBox','catalog-content',1),(193690,'74554','new_theme','block-193689','BlockBox','',4),(193691,'74555','new_theme','block-193690','catalog\\CountsItems','',1),(193692,'74556','new_theme','block-193690-2','catalog\\Paging','',1),(193693,'74557','new_theme','block-193689','Listing','',3),(193694,'74558','new_theme','block-193689','catalog\\Title','',1),(193695,'74559','new_theme','block-193689','catalog\\B2bAddButton','',5),(193696,'74560','new_theme','block-193689','BlockBox','',2),(193697,'74561','new_theme','block-193696','BlockBox','catalog-features',3),(193698,'74562','new_theme','block-193697','HeaderStock','',5),(193699,'74563','new_theme','block-193697','catalog\\ListingLook','',1),(193700,'74564','new_theme','block-193697','catalog\\CompareButton','',2),(193701,'74565','new_theme','block-193697','catalog\\ItemsOnPage','',4),(193702,'74566','new_theme','block-193697','catalog\\Sorting','',3),(193703,'74567','new_theme','block-193696','catalog\\Image','',1),(193704,'74568','new_theme','order_history','BlockBox','',1),(193705,'74569','new_theme','block-193704','BlockBox','',1),(193706,'74570','new_theme','block-193705','WidgetsAria','',1),(193726,'74571','new_theme','block-193705-2','Html_box','',1),(193727,'74572','new_theme','block-193705-2','account\\OrdersHistory','',2),(193728,'74573','new_theme','order_history_info','BlockBox','',1),(193729,'74574','new_theme','block-193728','BlockBox','',1),(193730,'74575','new_theme','block-193729','WidgetsAria','',1),(193750,'74576','new_theme','block-193729-2','account\\OrderInvoiceButton','',3),(193751,'74577','new_theme','block-193729-2','account\\OrderSubTotals','',10),(193752,'74578','new_theme','block-193729-2','account\\OrderPayButton','',5),(193753,'74579','new_theme','block-193729-2','BlockBox','',13),(193754,'74580','new_theme','block-193753','account\\AccountLink','',1),(193755,'74581','new_theme','block-193753-2','account\\OrderInvoiceButton','',1),(193756,'74582','new_theme','block-193729-2','Html_box','',8),(193757,'74583','new_theme','block-193729-2','account\\OrderHistory','',12),(193758,'74584','new_theme','block-193729-2','account\\OrderCancelAndReorder','',4),(193759,'74585','new_theme','block-193729-2','account\\OrderHeading','',1),(193760,'74586','new_theme','block-193729-2','account\\OrderDownload','',6),(193761,'74587','new_theme','block-193729-2','Html_box','',11),(193762,'74588','new_theme','block-193729-2','account\\OrderProducts','',9),(193763,'74589','new_theme','block-193729-2','account\\OrderReorderButton','',2),(193764,'74590','new_theme','block-193729-2','BlockBox','',7),(193765,'74591','new_theme','block-193764','BlockBox','',2),(193766,'74592','new_theme','block-193765','Html_box','',1),(193767,'74593','new_theme','block-193765','account\\OrderData','',2),(193768,'74594','new_theme','block-193764','BlockBox','',1),(193769,'74595','new_theme','block-193768','Html_box','',1),(193770,'74596','new_theme','block-193768','account\\OrderData','',2),(193771,'74597','new_theme','block-193764','BlockBox','',3),(193772,'74598','new_theme','block-193771','account\\OrderTracking','',2),(193773,'74599','new_theme','block-193771','Html_box','',1),(193774,'74600','new_theme','block-193771','account\\AccountLink','',3),(193775,'74601','new_theme','block-193764-2','BlockBox','',2),(193776,'74602','new_theme','block-193775','account\\OrderData','',2),(193777,'74603','new_theme','block-193775','Html_box','',1),(193778,'74604','new_theme','block-193764-2','BlockBox','',1),(193779,'74605','new_theme','block-193778','account\\OrderData','',2),(193780,'74606','new_theme','block-193778','Html_box','',1),(193781,'74607','new_theme','block-193764-3','BlockBox','',2),(193782,'74608','new_theme','block-193781','account\\OrderData','',2),(193783,'74609','new_theme','block-193781','Html_box','',1),(193784,'74610','new_theme','block-193764-3','BlockBox','',1),(193785,'74611','new_theme','block-193784','Html_box','',1),(193786,'74612','new_theme','block-193784','account\\OrderData','',2),(193787,'74613','new_theme','order_pay','BlockBox','',1),(193788,'74614','new_theme','block-193787','BlockBox','',1),(193789,'74615','new_theme','block-193788','WidgetsAria','',1),(193809,'74616','new_theme','block-193788-2','account\\OrderProducts','',4),(193810,'74617','new_theme','block-193788-2','BlockBox','',2),(193811,'74618','new_theme','block-193810','BlockBox','',1),(193812,'74619','new_theme','block-193811','Html_box','',1),(193813,'74620','new_theme','block-193811','account\\OrderData','',2),(193814,'74621','new_theme','block-193810','BlockBox','',4),(193815,'74622','new_theme','block-193814','account\\OrderData','',2),(193816,'74623','new_theme','block-193814','Html_box','',1),(193817,'74624','new_theme','block-193810-2','BlockBox','',1),(193818,'74625','new_theme','block-193817','Html_box','',1),(193819,'74626','new_theme','block-193817','account\\OrderData','',2),(193820,'74627','new_theme','block-193810-2','BlockBox','',2),(193821,'74628','new_theme','block-193820','account\\OrderData','',2),(193822,'74629','new_theme','block-193820','Html_box','',1),(193823,'74630','new_theme','block-193810-3','BlockBox','',2),(193824,'74631','new_theme','block-193823','Html_box','',1),(193825,'74632','new_theme','block-193823','account\\OrderData','',2),(193826,'74633','new_theme','block-193810-3','BlockBox','',1),(193827,'74634','new_theme','block-193826','account\\OrderData','',2),(193828,'74635','new_theme','block-193826','Html_box','',1),(193829,'74636','new_theme','block-193788-2','UpdateAndPay\\PayForm','',6),(193830,'74637','new_theme','block-193788-2','Html_box','',3),(193831,'74638','new_theme','block-193788-2','account\\OrderHeading','',1),(193832,'74639','new_theme','block-193788-2','account\\OrderSubTotals','',5),(193833,'74640','new_theme','packingslip','invoice\\Container','',2),(193834,'74641','new_theme','block-193833','BlockBox','',1),(193835,'74642','new_theme','block-193834','Logo','',1),(193836,'74643','new_theme','block-193834-2','BlockBox','',3),(193837,'74644','new_theme','block-193836','Text','',2),(193838,'74645','new_theme','block-193836-2','invoice\\StoreEmail','',1),(193839,'74646','new_theme','block-193834-2','BlockBox','',2),(193840,'74647','new_theme','block-193839','Text','',2),(193841,'74648','new_theme','block-193839-2','invoice\\StorePhone','',1),(193842,'74649','new_theme','block-193834-2','BlockBox','',1),(193843,'74650','new_theme','block-193842','invoice\\StoreAddress','',1),(193844,'74651','new_theme','block-193834-2','BlockBox','',4),(193845,'74652','new_theme','block-193844','Text','',2),(193846,'74653','new_theme','block-193844-2','invoice\\StoreSite','',1),(193847,'74654','new_theme','block-193833','packingslip\\Products','',3),(193848,'74655','new_theme','block-193833','BlockBox','',4),(193849,'74656','new_theme','block-193848','invoice\\StoreAddress','',2),(193850,'74657','new_theme','block-193848','Text','',1),(193851,'74658','new_theme','block-193833','BlockBox','',2),(193852,'74659','new_theme','block-193851','BlockBox','',2),(193853,'74660','new_theme','block-193852','BlockBox','',1),(193854,'74661','new_theme','block-193853','invoice\\ShippingAddress','',2),(193855,'74662','new_theme','block-193853','Text','',1),(193856,'74663','new_theme','block-193852-2','BlockBox','',1),(193857,'74664','new_theme','block-193856','Text','',1),(193858,'74665','new_theme','block-193856','invoice\\CustomerName','',2),(193859,'74666','new_theme','block-193856','invoice\\CustomerEmail','',6),(193860,'74667','new_theme','block-193856','Text','',3),(193861,'74668','new_theme','block-193856','invoice\\CustomerPhone','',4),(193862,'74669','new_theme','block-193856','Text','',5),(193863,'74670','new_theme','block-193851','BlockBox','',3),(193864,'74671','new_theme','block-193863','BlockBox','',1),(193865,'74672','new_theme','block-193864','invoice\\ShippingMethod','',2),(193866,'74673','new_theme','block-193864','Text','',1),(193867,'74674','new_theme','block-193863-2','BlockBox','',1),(193868,'74675','new_theme','block-193867','invoice\\ShippingMethod','',2),(193869,'74676','new_theme','block-193867','Text','',1),(193870,'74677','new_theme','block-193851-2','invoice\\AddressQrcode','',1),(193871,'74678','new_theme','password_forgotten','BlockBox','',1),(193872,'74679','new_theme','block-193871','BlockBox','',2),(193873,'74680','new_theme','block-193872-2','Html_box','',1),(193874,'74681','new_theme','block-193872-2','login\\PasswordForgotten','',2),(193875,'74682','new_theme','block-193871','Html_box','',1),(193876,'74683','new_theme','pdf','invoice\\Container','',1),(193877,'74684','new_theme','block-193876','BlockBox','',1),(193878,'74685','new_theme','block-193877','BlockBox','',1),(193879,'74686','new_theme','block-193878','BlockBox','',1),(193880,'74687','new_theme','block-193879','pdf\\ProductElement','',1),(193881,'74688','new_theme','block-193878','BlockBox','',2),(193882,'74689','new_theme','block-193881','pdf\\ProductElement','',1),(193883,'74690','new_theme','block-193881-2','pdf\\ProductElement','',2),(193884,'74691','new_theme','block-193881-2','pdf\\ProductElement','',1),(193885,'74692','new_theme','block-193877-2','BlockBox','',1),(193886,'74693','new_theme','block-193885','BlockBox','',2),(193887,'74694','new_theme','block-193886','pdf\\ProductElement','',1),(193888,'74695','new_theme','block-193886-2','pdf\\ProductElement','',2),(193889,'74696','new_theme','block-193886-2','pdf\\ProductElement','',1),(193890,'74697','new_theme','block-193885','BlockBox','',1),(193891,'74698','new_theme','block-193890','pdf\\ProductElement','',1),(193892,'74699','new_theme','pdf_category','pdf\\CategoryName','',2),(193893,'74700','new_theme','pdf_category','pdf\\CategoryImage','',1),(193894,'74701','new_theme','pdf_cover','invoice\\Container','',1),(193895,'74702','new_theme','block-193894','Logo','',1),(193896,'74703','new_theme','block-193894','Text','',3),(193897,'74704','new_theme','pdf_footer','BlockBox','',1),(193898,'74705','new_theme','block-193897-2','pdf\\PageNumber','',1),(193899,'74706','new_theme','pdf_header','pdf\\CategoryName','',1),(193900,'74707','new_theme','personal_catalog','BlockBox','',1),(193901,'74708','new_theme','block-193900','BlockBox','',1),(193902,'74709','new_theme','block-193901','WidgetsAria','',1),(193922,'74710','new_theme','block-193901-2','Html_box','',1),(193923,'74711','new_theme','block-193901-2','account\\AccountLink','',3),(193924,'74712','new_theme','block-193901-2','account\\PersonalCatalog','',2),(193925,'74713','new_theme','points_earnt_history','BlockBox','',1),(193926,'74714','new_theme','block-193925','Html_box','',1),(193927,'74715','new_theme','block-193925','BonusActions\\widgets\\PointsEarntHistory','',2),(193928,'74716','new_theme','posts','BlockBox','',1),(193929,'74717','new_theme','block-193928','Breadcrumb','',2),(193930,'74718','new_theme','block-193928','Html_box','',1),(193931,'74719','new_theme','block-193928','Communication\\Post','',3),(193932,'74720','new_theme','product','BlockBox','product-content',2),(193933,'74721','new_theme','block-193932','product\\CustomersActivity','',11),(193934,'74722','new_theme','block-193932','BlockBox','product-image',2),(193935,'74724','new_theme','block-193934','product\\Images','',2),(193936,'74725','new_theme','block-193934','product\\ImageMapProduct','',4),(193937,'74726','new_theme','block-193934','product\\PromotionIcons','',1),(193938,'74727','new_theme','block-193934-2','BlockBox','product-side',10),(193939,'74728','new_theme','block-193938','product\\ButtonsQuote','',3),(193940,'74729','new_theme','block-193938','BlockBox','',1),(193941,'74730','new_theme','block-193940','product\\Price','',1),(193942,'74731','new_theme','block-193940-2','product\\Quantity','',1),(193943,'74732','new_theme','block-193938','BonusActions\\widgets\\BonusPointsProduct','',4),(193944,'1694165842.4776','new_theme','block-193938','product\\QuantityDiscounts','',2),(193945,'74733','new_theme','block-193938-2','product\\Buttons','',1),(193946,'74734','new_theme','block-193938-2','product\\ButtonsSample','',2),(193947,'74735','new_theme','block-193934-2','product\\DescriptionShort','',6),(193948,'74737','new_theme','block-193934-2','product\\Documents','',5),(193949,'74738','new_theme','block-193934-2','product\\AvailableInWarehouses','',9),(193950,'74739','new_theme','block-193934-2','BlockBox','',11),(193951,'74741','new_theme','block-193950','product\\PersonalCatalogButton','',1),(193952,'74743','new_theme','block-193934-2','product\\Brand','',4),(193953,'74744','new_theme','block-193934-2','product\\Model','',3),(193954,'74745','new_theme','block-193934-2','product\\Name','',2),(193955,'74746','new_theme','block-193934-2','product\\Stock','',1),(193956,'1642500646.3623','new_theme','block-193934-2','product\\Attributes','',7),(193957,'74749','new_theme','block-193932','product\\Configurator','',5),(193958,'74750','new_theme','block-193932','Breadcrumb','',1),(193959,'74752','new_theme','block-193932','Tabs','',6),(193960,'74753','new_theme','block-193959-1','product\\Description','',2),(193961,'74754','new_theme','block-193959-1','product\\Properties','',1),(193962,'74755','new_theme','block-193959-2','product\\Reviews','',1),(193963,'74757','new_theme','block-193932','product\\InBundles','',4),(193964,'74758','new_theme','block-193932','product\\Bundle','',3),(193965,'1694166186.2638','new_theme','block-193932','BlockBox','',7),(193966,'74751','new_theme','block-193965','product\\AlsoPurchased','10',2),(193967,'1694166209.3278','new_theme','block-193965','Html_box','',1),(193968,'1694166191.5684','new_theme','block-193932','BlockBox','',9),(193969,'74747','new_theme','block-193968','ViewedProducts','4',2),(193970,'1694166222.3382','new_theme','block-193968','Html_box','',1),(193971,'74761','new_theme','product-bottom','product\\Properties','',1),(193972,'74762','new_theme','product-tabs','product\\Reviews','',2),(193973,'74763','new_theme','product-tabs','product\\Description','',1),(193974,'74764','new_theme','product-top-left','product\\Images','',1),(193975,'74765','new_theme','product-top-right','product\\Price','',2),(193976,'74766','new_theme','product-top-right','product\\Quantity','',5),(193977,'74767','new_theme','product-top-right','product\\Quantity','',6),(193978,'74768','new_theme','product-top-right','product\\Attributes','',3),(193979,'74769','new_theme','product-top-right','product\\Name','',1),(193980,'74770','new_theme','product-top-right','product\\Buttons','',6),(193981,'74771','new_theme','productListing','BlockBox','listing-item',1),(193982,'74773','new_theme','block-193981','productListing\\model','',7),(193983,'74774','new_theme','block-193981','BonusActions\\widgets\\BonusPointsProductListing','',6),(193984,'74775','new_theme','block-193981','productListing\\description','',5),(193985,'74776','new_theme','block-193981','productListing\\buyButton','',9),(193986,'74777','new_theme','block-193981','productListing\\rating','',3),(193987,'74778','new_theme','block-193981','productListing\\image','',1),(193988,'74779','new_theme','block-193981','BlockBox','',8),(193989,'74780','new_theme','block-193988','productListing\\price','',1),(193990,'74781','new_theme','block-193988-2','productListing\\qtyInput','',1),(193991,'74782','new_theme','block-193981','productListing\\name','',4),(193992,'74783','new_theme','block-193981','productListing\\stock','',2),(193993,'75903','new_theme','block-193981','productListing\\compare','',10),(193994,'74785','new_theme','products','BlockBox','catalog-content',1),(193995,'74786','new_theme','block-193994','BlockBox','catalog-side',4),(193996,'74787','new_theme','block-193995','Filters','',1),(193997,'74788','new_theme','block-193995','HeaderStock','',2),(193998,'74789','new_theme','block-193995-2','catalog\\B2bAddButton','',4),(193999,'74790','new_theme','block-193995-2','BlockBox','catalog-features',2),(194000,'74791','new_theme','block-193999','catalog\\Sorting','',3),(194001,'74792','new_theme','block-193999','catalog\\ListingLook','',1),(194002,'74793','new_theme','block-193999','catalog\\ItemsOnPage','',4),(194003,'74794','new_theme','block-193999','catalog\\CompareButton','',2),(194004,'74795','new_theme','block-193995-2','BlockBox','',5),(194005,'74796','new_theme','block-194004','catalog\\CountsItems','',1),(194006,'74797','new_theme','block-194004-2','catalog\\Paging','',1),(194007,'74798','new_theme','block-193995-2','Listing','',3),(194008,'74799','new_theme','block-193994','catalog\\Title','',1),(194009,'74800','new_theme','block-193994','BlockBox','',3),(194010,'74801','new_theme','block-194009','catalog\\Image','',1),(194011,'75886','new_theme','products-list','packingslip\\AllProductsList','',2),(194012,'74802','new_theme','promotions','BlockBox','',1),(194013,'74803','new_theme','block-194012','promotions\\PromoList','',2),(194014,'74804','new_theme','block-194012','Html_box','',1),(194015,'74805','new_theme','purchase','invoice\\Container','',1),(194016,'74806','new_theme','block-194015','invoice\\Products','',3),(194017,'74807','new_theme','block-194015','BlockBox','',5),(194018,'74808','new_theme','block-194017','Text','',1),(194019,'74809','new_theme','block-194017','invoice\\StoreAddress','',8),(194020,'74810','new_theme','block-194017-2','Text','',2),(194021,'74811','new_theme','block-194017-2','Logo','',1),(194022,'74812','new_theme','block-194017-3','BlockBox','',3),(194023,'74813','new_theme','block-194022','Text','',1),(194024,'74814','new_theme','block-194022-2','invoice\\StoreEmail','',1),(194025,'74815','new_theme','block-194017-3','Text','',1),(194026,'74816','new_theme','block-194017-3','BlockBox','',2),(194027,'74817','new_theme','block-194026','Text','',1),(194028,'74818','new_theme','block-194026-2','invoice\\StorePhone','',1),(194029,'74819','new_theme','block-194015','BlockBox','',1),(194030,'74820','new_theme','block-194029','Logo','',1),(194031,'74821','new_theme','block-194029-2','BlockBox','',2),(194032,'74822','new_theme','block-194031','Text','',1),(194033,'74823','new_theme','block-194031-2','invoice\\StorePhone','',1),(194034,'74824','new_theme','block-194029-2','BlockBox','',4),(194035,'74825','new_theme','block-194034','Text','',1),(194036,'74826','new_theme','block-194034-2','invoice\\StoreSite','',1),(194037,'74827','new_theme','block-194029-2','BlockBox','',1),(194038,'74828','new_theme','block-194037','invoice\\StoreAddress','',1),(194039,'74829','new_theme','block-194029-2','BlockBox','',3),(194040,'74830','new_theme','block-194039','Text','',1),(194041,'74831','new_theme','block-194039-2','invoice\\StoreEmail','',1),(194042,'74832','new_theme','block-194015','BlockBox','',2),(194043,'74833','new_theme','block-194042','BlockBox','',7),(194044,'74834','new_theme','block-194043','BlockBox','',1),(194045,'74835','new_theme','block-194044','invoice\\BillingAddress','',2),(194046,'74836','new_theme','block-194044','Text','',1),(194047,'74837','new_theme','block-194043-2','BlockBox','',1),(194048,'74838','new_theme','block-194047','invoice\\CustomerEmail','',6),(194049,'74839','new_theme','block-194047','Text','',5),(194050,'74840','new_theme','block-194047','invoice\\CustomerPhone','',4),(194051,'74841','new_theme','block-194047','invoice\\CustomerName','',2),(194052,'74842','new_theme','block-194047','Text','',3),(194053,'74843','new_theme','block-194047','Text','',1),(194054,'74844','new_theme','block-194042-2','invoice\\OrderId','',1),(194055,'74845','new_theme','block-194042-2','Text','',2),(194056,'74846','new_theme','block-194042-2','invoice\\PaymentDate','',3),(194057,'74847','new_theme','block-194015','BlockBox','',4),(194058,'74848','new_theme','block-194057','BlockBox','',1),(194059,'74849','new_theme','block-194058','invoice\\ShippingAddress','',2),(194060,'74850','new_theme','block-194058','Text','',1),(194061,'74851','new_theme','quotations','BlockBox','',1),(194062,'74852','new_theme','block-194061','BlockBox','',1),(194063,'74853','new_theme','block-194062','WidgetsAria','',1),(194083,'74854','new_theme','block-194062-2','Html_box','',1),(194084,'74855','new_theme','block-194062-2','Quotations\\QuotationsHistory','',2),(194085,'74856','new_theme','quotation_info','BlockBox','',1),(194086,'74857','new_theme','block-194085','BlockBox','',1),(194087,'74858','new_theme','block-194086','WidgetsAria','',1),(194107,'74859','new_theme','block-194086-2','BlockBox','',5),(194108,'74860','new_theme','block-194107','BlockBox','',1),(194109,'74861','new_theme','block-194108','Quotations\\QuotationData','',2),(194110,'74862','new_theme','block-194108','Html_box','',1),(194111,'74863','new_theme','block-194107','BlockBox','',4),(194112,'74864','new_theme','block-194111','Html_box','',1),(194113,'74865','new_theme','block-194111','Quotations\\QuotationData','',2),(194114,'74866','new_theme','block-194107-2','BlockBox','',2),(194115,'74867','new_theme','block-194114','Html_box','',1),(194116,'74868','new_theme','block-194114','Quotations\\QuotationData','',2),(194117,'74869','new_theme','block-194107-2','BlockBox','',1),(194118,'74870','new_theme','block-194117','Html_box','',1),(194119,'74871','new_theme','block-194117','Quotations\\QuotationData','',2),(194120,'74872','new_theme','block-194107-3','BlockBox','',1),(194121,'74873','new_theme','block-194120','Quotations\\QuotationData','',2),(194122,'74874','new_theme','block-194120','Html_box','',1),(194123,'74875','new_theme','block-194107-3','BlockBox','',2),(194124,'74876','new_theme','block-194123','Quotations\\QuotationData','',2),(194125,'74877','new_theme','block-194123','Html_box','',1),(194126,'74878','new_theme','block-194086-2','Html_box','',6),(194127,'74879','new_theme','block-194086-2','Quotations\\QuotationHistory','',10),(194128,'74880','new_theme','block-194086-2','Html_box','',9),(194129,'74881','new_theme','block-194086-2','Quotations\\QuotationProducts','',7),(194130,'74882','new_theme','block-194086-2','Quotations\\QuotationSubTotal','',8),(194131,'74883','new_theme','block-194086-2','BlockBox','',12),(194132,'74884','new_theme','block-194131','account\\AccountLink','',1),(194133,'74885','new_theme','block-194086-2','Html_box','',4),(194134,'74886','new_theme','quote','BlockBox','',1),(194135,'74887','new_theme','block-194134','cart\\CartTabs','',1),(194136,'74888','new_theme','block-194135','BlockBox','',1),(194137,'74889','new_theme','block-194136','quote\\Products','',1),(194138,'74890','new_theme','block-194136-2','BlockBox','',1),(194139,'74891','new_theme','block-194138','BlockBox','',1),(194140,'74892','new_theme','block-194139','quote\\CheckoutBtn','',2),(194141,'74893','new_theme','block-194135','Quotations\\QuotationSubTotal','',2),(194142,'74894','new_theme','review','BlockBox','',1),(194143,'74895','new_theme','block-194142','BlockBox','',1),(194144,'74896','new_theme','block-194143','WidgetsAria','',1),(194164,'74897','new_theme','block-194143-2','Html_box','',1),(194165,'74898','new_theme','block-194143-2','account\\Reviews','',2),(194166,'74899','new_theme','reviews','BlockBox','',1),(194167,'74900','new_theme','block-194166','reviews\\Heading','',1),(194168,'74901','new_theme','block-194166','reviews\\Content','',2),(194169,'74902','new_theme','rma_document','invoice\\Container','',1),(194170,'74903','new_theme','block-194169','BlockBox','',1),(194171,'74904','new_theme','block-194170','BlockBox','',1),(194172,'74905','new_theme','block-194171','BlockBox','',2),(194173,'74906','new_theme','block-194172','Html_box','',1),(194174,'74907','new_theme','block-194172-2','Html_box','',1),(194175,'74908','new_theme','block-194171','BlockBox','',5),(194176,'74909','new_theme','block-194175','Html_box','',1),(194177,'74910','new_theme','block-194175-2','Html_box','',1),(194178,'74911','new_theme','block-194171','BlockBox','',4),(194179,'74912','new_theme','block-194178','Html_box','',1),(194180,'74913','new_theme','block-194178-2','Html_box','',1),(194181,'74914','new_theme','block-194171','BlockBox','',3),(194182,'74915','new_theme','block-194181','Html_box','',1),(194183,'74916','new_theme','block-194181-2','Html_box','',1),(194184,'74917','new_theme','block-194171','BlockBox','',1),(194185,'74918','new_theme','block-194184','Html_box','',1),(194186,'74919','new_theme','block-194184','Html_box','',2),(194187,'74920','new_theme','block-194170-2','BlockBox','',1),(194188,'74921','new_theme','block-194187','Html_box','',2),(194189,'74922','new_theme','block-194187','Logo','',1),(194190,'74923','new_theme','block-194170-2','BlockBox','',2),(194191,'74924','new_theme','block-194190','BlockBox','',5),(194192,'74925','new_theme','block-194191','BlockBox','',1),(194193,'74926','new_theme','block-194192','Html_box','',1),(194194,'74927','new_theme','block-194192-2','Rma\\DocumentData','',1),(194195,'74928','new_theme','block-194191-2','BlockBox','',1),(194196,'74929','new_theme','block-194195','Html_box','',1),(194197,'74930','new_theme','block-194195-2','Rma\\DocumentData','',1),(194198,'74931','new_theme','block-194190','BlockBox','',4),(194199,'74932','new_theme','block-194198','BlockBox','',1),(194200,'74933','new_theme','block-194199','Html_box','',1),(194201,'74934','new_theme','block-194199-2','Rma\\DocumentData','',1),(194202,'74935','new_theme','block-194198-2','BlockBox','',1),(194203,'74936','new_theme','block-194202','Html_box','',1),(194204,'74937','new_theme','block-194202-2','Rma\\DocumentData','',1),(194205,'74938','new_theme','block-194190','BlockBox','',3),(194206,'74939','new_theme','block-194205','BlockBox','',1),(194207,'74940','new_theme','block-194206','Html_box','',1),(194208,'74941','new_theme','block-194206-2','Rma\\DocumentData','',1),(194209,'74942','new_theme','block-194205-2','BlockBox','',1),(194210,'74943','new_theme','block-194209','Html_box','',1),(194211,'74944','new_theme','block-194209-2','Rma\\DocumentData','',1),(194212,'74945','new_theme','block-194190','BlockBox','',2),(194213,'74946','new_theme','block-194212','Html_box','',1),(194214,'74947','new_theme','block-194212-2','Rma\\DocumentData','',1),(194215,'74948','new_theme','block-194190','BlockBox','',1),(194216,'74949','new_theme','block-194215','BlockBox','',1),(194217,'74950','new_theme','block-194216','Html_box','',1),(194218,'74951','new_theme','block-194216-2','Rma\\DocumentData','',1),(194219,'74952','new_theme','block-194215-2','BlockBox','',1),(194220,'74953','new_theme','block-194219','Html_box','',1),(194221,'74954','new_theme','block-194219-2','Rma\\DocumentData','',1),(194222,'74955','new_theme','block-194170-2','BlockBox','',3),(194223,'74956','new_theme','block-194222','BlockBox','',1),(194224,'74957','new_theme','block-194223','Html_box','',1),(194225,'74958','new_theme','block-194223-2','Rma\\DocumentData','',1),(194226,'74959','new_theme','block-194222-2','BlockBox','',1),(194227,'74960','new_theme','block-194226','Html_box','',1),(194228,'74961','new_theme','block-194226-2','Rma\\DocumentData','',1),(194229,'74962','new_theme','block-194169','BlockBox','',2),(194230,'74963','new_theme','block-194229','Html_box','',1),(194231,'74964','new_theme','block-194229','Rma\\Products','',2),(194232,'74965','new_theme','block-194169','BlockBox','',3),(194233,'74966','new_theme','block-194232','BlockBox','',1),(194234,'74967','new_theme','block-194233','BlockBox','',1),(194235,'74968','new_theme','block-194234','BlockBox','',5),(194236,'74969','new_theme','block-194235','Html_box','',1),(194237,'74970','new_theme','block-194235-2','invoice\\StoreAddress','',2),(194238,'74971','new_theme','block-194235-2','Html_box','',1),(194239,'74972','new_theme','block-194234','BlockBox','',4),(194240,'74973','new_theme','block-194239','Html_box','',1),(194241,'74974','new_theme','block-194239-2','Html_box','',1),(194242,'74975','new_theme','block-194234','BlockBox','',2),(194243,'74976','new_theme','block-194242','Html_box','',1),(194244,'74977','new_theme','block-194242-2','Html_box','',1),(194245,'74978','new_theme','block-194234','BlockBox','',1),(194246,'74979','new_theme','block-194245','Html_box','',1),(194247,'74980','new_theme','block-194234','BlockBox','',3),(194248,'74981','new_theme','block-194247','Html_box','',1),(194249,'74982','new_theme','block-194247-2','Html_box','',1),(194250,'74983','new_theme','block-194234','BlockBox','',6),(194251,'74984','new_theme','block-194250','Html_box','',1),(194252,'74985','new_theme','block-194233-2','BlockBox','',1),(194253,'74986','new_theme','block-194252','BlockBox','',1),(194254,'74987','new_theme','block-194253','BlockBox','',1),(194255,'74988','new_theme','block-194254','Rma\\DocumentData','',2),(194256,'74989','new_theme','block-194254-3','BlockBox','',1),(194257,'74990','new_theme','block-194256','Html_box','',1),(194258,'74991','new_theme','block-194256-2','Rma\\DocumentData','',1),(194259,'74992','new_theme','block-194253','BlockBox','',2),(194260,'74993','new_theme','block-194259-2','invoice\\StoreAddress','',1),(194261,'74994','new_theme','block-194233-2','BlockBox','',2),(194262,'74995','new_theme','block-194261','Html_box','',1),(194263,'74996','new_theme','block-194261','Html_box','',2),(194264,'74997','new_theme','block-194261','Html_box','',3),(194265,'74998','new_theme','block-194261','Html_box','',4),(194266,'74999','new_theme','block-194261','Html_box','',5),(194267,'75000','new_theme','block-194233-2','BlockBox','',4),(194268,'75001','new_theme','block-194267','Html_box','',1),(194269,'75002','new_theme','block-194267-2','Html_box','',1),(194270,'75003','new_theme','block-194267-3','BlockBox','',1),(194271,'75004','new_theme','block-194270','Html_box','',1),(194272,'75005','new_theme','block-194270-2','Html_box','',1),(194273,'75006','new_theme','block-194233-2','BlockBox','',3),(194274,'75007','new_theme','block-194273','Html_box','',1),(194275,'75008','new_theme','block-194273-2','Html_box','',1),(194276,'75009','new_theme','block-194273-3','BlockBox','',1),(194277,'75010','new_theme','block-194276','Html_box','',1),(194278,'75011','new_theme','block-194276-2','Html_box','',1),(194279,'75012','new_theme','rows','BlockBox','',1),(194280,'75013','new_theme','block-194279','BlockBox','',2),(194281,'75014','new_theme','block-194280','BlockBox','',2),(194282,'75015','new_theme','block-194281','BonusActions\\widgets\\BonusPointsProductListing','',1),(194283,'75016','new_theme','block-194281','productListing\\image','',2),(194284,'75017','new_theme','block-194281','BlockBox','',3),(194285,'75018','new_theme','block-194284','productListing\\rating','',1),(194286,'75019','new_theme','block-194284','productListing\\ratingCounts','',2),(194287,'75020','new_theme','block-194281-2','productListing\\name','',1),(194288,'75021','new_theme','block-194281-2','productListing\\description','',2),(194289,'75022','new_theme','block-194281-2','productListing\\model','',3),(194290,'75023','new_theme','block-194281-2','productListing\\attributes','',4),(194291,'75024','new_theme','block-194280-2','BlockBox','listing-item',1),(194292,'75025','new_theme','block-194291','productListing\\qtyInput','',3),(194293,'75026','new_theme','block-194291','productListing\\price','',2),(194294,'75027','new_theme','block-194291','productListing\\compare','',5),(194295,'75028','new_theme','block-194291','productListing\\buyButton','',4),(194296,'75030','new_theme','block-194291','productListing\\stock','',1),(194297,'75031','new_theme','sample','BlockBox','',1),(194298,'75032','new_theme','block-194297','cart\\CartTabs','',1),(194299,'75033','new_theme','block-194298','BlockBox','',1),(194300,'75034','new_theme','block-194299','sample\\Products','',1),(194301,'75035','new_theme','block-194299-2','BlockBox','',1),(194302,'75036','new_theme','block-194301','BlockBox','',1),(194303,'75037','new_theme','block-194302','sample\\CheckoutBtn','',1),(194304,'75038','new_theme','samples','BlockBox','',1),(194305,'75039','new_theme','block-194304','BlockBox','',1),(194306,'75040','new_theme','block-194305','WidgetsAria','',1),(194326,'75041','new_theme','block-194305-2','Html_box','',1),(194327,'75042','new_theme','block-194305-2','Samples\\SamplesHistory','',2),(194328,'75043','new_theme','sample_info','BlockBox','',1),(194329,'75044','new_theme','block-194328','BlockBox','',1),(194330,'75045','new_theme','block-194329','WidgetsAria','',1),(194350,'75046','new_theme','block-194329-2','Html_box','',1),(194351,'75047','new_theme','block-194329-2','BlockBox','',8),(194352,'75048','new_theme','block-194351','account\\AccountLink','',1),(194353,'75049','new_theme','block-194329-2','Samples\\SampleHistory','',7),(194354,'75050','new_theme','block-194329-2','Html_box','',3),(194355,'75051','new_theme','block-194329-2','Samples\\SampleSubTotal','',5),(194356,'75052','new_theme','block-194329-2','Samples\\SampleProducts','',4),(194357,'75053','new_theme','block-194329-2','Html_box','',6),(194358,'75054','new_theme','block-194329-2','BlockBox','',2),(194359,'75055','new_theme','block-194358','BlockBox','',4),(194360,'75056','new_theme','block-194359','Html_box','',1),(194361,'75057','new_theme','block-194359','Samples\\SampleData','',2),(194362,'75058','new_theme','block-194358','BlockBox','',1),(194363,'75059','new_theme','block-194362','Samples\\SampleData','',2),(194364,'75060','new_theme','block-194362','Html_box','',1),(194365,'75061','new_theme','block-194358-2','BlockBox','',2),(194366,'75062','new_theme','block-194365','Samples\\SampleData','',2),(194367,'75063','new_theme','block-194365','Html_box','',1),(194368,'75064','new_theme','block-194358-2','BlockBox','',1),(194369,'75065','new_theme','block-194368','Samples\\SampleData','',2),(194370,'75066','new_theme','block-194368','Html_box','',1),(194371,'75067','new_theme','block-194358-3','BlockBox','',2),(194372,'75068','new_theme','block-194371','Samples\\SampleData','',2),(194373,'75069','new_theme','block-194371','Html_box','',1),(194374,'75070','new_theme','block-194358-3','BlockBox','',1),(194375,'75071','new_theme','block-194374','Samples\\SampleData','',2),(194376,'75072','new_theme','block-194374','Html_box','',1),(194377,'75073','new_theme','sitemap','BlockBox','',1),(194378,'75074','new_theme','block-194377','Html_box','',1),(194379,'75075','new_theme','block-194377','BlockBox','',2),(194380,'75076','new_theme','block-194379','Html_box','',1),(194381,'75077','new_theme','block-194379','Html_box','',5),(194382,'75078','new_theme','block-194379','Html_box','',3),(194383,'75079','new_theme','block-194379','sitemap\\InfoPages','',2),(194384,'75080','new_theme','block-194379','sitemap\\Categories','',4),(194385,'75081','new_theme','block-194379','Menu','Account box',6),(194386,'75082','new_theme','block-194379-2','sitemap\\DeliveryLocation','',2),(194387,'75083','new_theme','block-194379-2','Html_box','',1),(194388,'75084','new_theme','subscribe','BlockBox','',1),(194389,'75085','new_theme','block-194388','Html_box','',3),(194390,'75086','new_theme','block-194388','subscribers\\UnsubscribeForm','',4),(194391,'75087','new_theme','block-194388','Html_box','',1),(194392,'75088','new_theme','block-194388','subscribers\\SubscribeForm','',2),(194393,'75089','new_theme','subscribed','BlockBox','',1),(194394,'75090','new_theme','block-194393','Html_box','',1),(194395,'94795','new_theme','subscription','BlockBox','',2),(194396,'94796','new_theme','block-194395','BlockBox','',1),(194397,'94797','new_theme','block-194396','WidgetsAria','',1),(194417,'94798','new_theme','block-194396-2','Html_box','',2),(194418,'94799','new_theme','block-194396-2','Html_box','',3),(194419,'94800','new_theme','block-194396-2','account\\Subscription','',4),(194420,'1694099590.22143','new_theme','success','BlockBox','',1),(194421,'1694099590.340695','new_theme','block-194420','BlockBox','',2),(194422,'1694099590.343733','new_theme','block-194421','BlockBox','',3),(194423,'1694099590.345212','new_theme','block-194422','BlockBox','',2),(194424,'1694099590.34749','new_theme','block-194423','BlockBox','',1),(194425,'1694099590.3531','new_theme','block-194424','order\\ShippingMethod','',6),(194426,'1694099590.351567','new_theme','block-194424','order\\DeliveryAddress','',3),(194427,'1694099590.35337','new_theme','block-194424','Html_box','',7),(194428,'1694099590.360420','new_theme','block-194424','Html_box','',5),(194429,'1694099590.362714','new_theme','block-194424','Html_box','',1),(194430,'1694099590.36422','new_theme','block-194424','checkout\\ContactConfirm','',9),(194431,'1694099590.365625','new_theme','block-194424','Html_box','',2),(194432,'1694099590.367789','new_theme','block-194423-2','BlockBox','',1),(194433,'1694099590.369488','new_theme','block-194432','order\\PaymentMethod','',6),(194434,'1694099590.370690','new_theme','block-194432','order\\BillingAddress','',3),(194435,'1694099590.371953','new_theme','block-194432','Html_box','',5),(194436,'1694099590.373633','new_theme','block-194432','Html_box','',1),(194437,'1694099590.37590','new_theme','block-194432','Html_box','',2),(194438,'1694099590.376747','new_theme','block-194422','Html_box','',1),(194439,'1694099590.38020','new_theme','block-194421-2','BlockBox','',1),(194440,'1694099590.381373','new_theme','block-194439','success\\PrintBtn','',3),(194441,'1694099590.382864','new_theme','block-194439','success\\ContinueBtn','',4),(194442,'1694099590.384241','new_theme','block-194439','order\\Products','',1),(194443,'1694099590.385486','new_theme','block-194439','order\\Totals','',2),(194444,'1694099590.386683','new_theme','block-194420','BlockBox','',1),(194445,'1694099590.387673','new_theme','block-194444','Html_box','',2),(194446,'1694099590.389337','new_theme','block-194444','order\\OrderNumber','',1),(194447,'75097','new_theme','success_q','BlockBox','',1),(194448,'75098','new_theme','block-194447','BlockBox','',1),(194449,'75099','new_theme','block-194448','BlockBox','',2),(194450,'75100','new_theme','block-194449','success\\ContinueBtn','',2),(194451,'75101','new_theme','block-194449','success\\PrintBtn','',1),(194452,'75102','new_theme','block-194448','Html_box','',1),(194453,'75107','new_theme','ticket','invoice\\Container','',1),(194454,'75108','new_theme','block-194453','BlockBox','',4),(194455,'75109','new_theme','block-194454','BlockBox','',1),(194456,'75110','new_theme','block-194455','invoice\\ShippingAddress','',2),(194457,'75111','new_theme','block-194455','Text','',1),(194458,'75112','new_theme','block-194454-2','BlockBox','',1),(194459,'75113','new_theme','block-194458','invoice\\Totals','',1),(194460,'75114','new_theme','block-194453','BlockBox','',5),(194461,'75115','new_theme','block-194460','Text','',1),(194462,'75116','new_theme','block-194460','invoice\\StoreAddress','',8),(194463,'75117','new_theme','block-194460-2','Logo','',1),(194464,'75118','new_theme','block-194460-2','Text','',2),(194465,'75119','new_theme','block-194460-3','Text','',1),(194466,'75120','new_theme','block-194460-3','BlockBox','',3),(194467,'75121','new_theme','block-194466','Text','',1),(194468,'75122','new_theme','block-194466-2','invoice\\StoreEmail','',1),(194469,'75123','new_theme','block-194460-3','BlockBox','',2),(194470,'75124','new_theme','block-194469','Text','',1),(194471,'75125','new_theme','block-194469-2','invoice\\StorePhone','',1),(194472,'75126','new_theme','block-194453','invoice\\Products','',3),(194473,'75127','new_theme','block-194453','BlockBox','',1),(194474,'75128','new_theme','block-194473-2','BlockBox','',3),(194475,'75129','new_theme','block-194474','Text','',1),(194476,'75130','new_theme','block-194474-2','invoice\\StoreEmail','',1),(194477,'75131','new_theme','block-194473-2','BlockBox','',4),(194478,'75132','new_theme','block-194477','Text','',1),(194479,'75133','new_theme','block-194477-2','invoice\\StoreSite','',1),(194480,'75134','new_theme','block-194473-2','BlockBox','',1),(194481,'75135','new_theme','block-194480','invoice\\StoreAddress','',1),(194482,'75136','new_theme','block-194473-2','BlockBox','',2),(194483,'75137','new_theme','block-194482','Text','',1),(194484,'75138','new_theme','block-194482-2','invoice\\StorePhone','',1),(194485,'75139','new_theme','block-194453','BlockBox','',2),(194486,'75140','new_theme','block-194485','BlockBox','',8),(194487,'75141','new_theme','block-194486','BlockBox','',1),(194488,'75142','new_theme','block-194487','Text','',1),(194489,'75143','new_theme','block-194487','invoice\\ShippingMethod','',2),(194490,'75144','new_theme','block-194486-2','BlockBox','',1),(194491,'75145','new_theme','block-194490','Text','',1),(194492,'75146','new_theme','block-194490','invoice\\ShippingMethod','',2),(194493,'75147','new_theme','block-194485','BlockBox','',7),(194494,'75148','new_theme','block-194493','BlockBox','',1),(194495,'75149','new_theme','block-194494','invoice\\BillingAddress','',2),(194496,'75150','new_theme','block-194494','Text','',1),(194497,'75151','new_theme','block-194493-2','BlockBox','',1),(194498,'75152','new_theme','block-194497','invoice\\CustomerName','',2),(194499,'75153','new_theme','block-194497','Text','',3),(194500,'75154','new_theme','block-194497','invoice\\CustomerEmail','',6),(194501,'75155','new_theme','block-194497','invoice\\CustomerPhone','',4),(194502,'75156','new_theme','block-194497','Text','',5),(194503,'75157','new_theme','block-194497','Text','',1),(194504,'75158','new_theme','block-194485-2','invoice\\PaymentDate','',3),(194505,'75159','new_theme','block-194485-2','Text','',2),(194506,'75160','new_theme','block-194485-2','Text','',4),(194507,'75161','new_theme','block-194485-2','invoice\\OrderId','',1),(194508,'75162','new_theme','block-194485-2','invoice\\PaymentMethod','',5),(194509,'75163','new_theme','block-194485-2','invoice\\OrderBarcode','',6),(194510,'75194','new_theme','tracking_numbers','BlockBox','',1),(194511,'75195','new_theme','block-194510','Html_box','',1),(194512,'75196','new_theme','block-194510','account\\OrderTracking','',2),(194513,'75418','new_theme','unsubscribed','BlockBox','',1),(194514,'75419','new_theme','block-194513','Html_box','',1),(194515,'75420','new_theme','update-and-pay-order_confirmation','BlockBox','',1),(194516,'75421','new_theme','block-194515','BlockBox','',3),(194517,'75422','new_theme','block-194516','BlockBox','',1),(194518,'75423','new_theme','block-194517','BlockBox','',1),(194519,'75424','new_theme','block-194518','BlockBox','',1),(194520,'75425','new_theme','block-194519','order\\ShippingMethod','',5),(194521,'75426','new_theme','block-194519','Html_box','',2),(194522,'75427','new_theme','block-194519','Html_box','',4),(194523,'75428','new_theme','block-194519','Html_box','',1),(194524,'75429','new_theme','block-194519','order\\Telephone','',8),(194525,'75430','new_theme','block-194519','Html_box','',6),(194526,'75431','new_theme','block-194519','order\\Name','',7),(194527,'75432','new_theme','block-194519','order\\Email','',9),(194528,'75433','new_theme','block-194519','order\\DeliveryAddress','',3),(194529,'75434','new_theme','block-194518-2','BlockBox','',1),(194530,'75435','new_theme','block-194529','order\\BillingAddress','',3),(194531,'75436','new_theme','block-194529','UpdateAndPay\\PayConfirm','',5),(194532,'75437','new_theme','block-194529','Html_box','',1),(194533,'75438','new_theme','block-194529','Html_box','',2),(194534,'75439','new_theme','block-194529','Html_box','',4),(194535,'75440','new_theme','block-194517','BlockBox','',3),(194536,'75441','new_theme','block-194535','order\\Products','',2),(194537,'75442','new_theme','block-194535','Html_box','',1),(194538,'75443','new_theme','block-194516-2','BlockBox','',1),(194539,'75444','new_theme','block-194538','Html_box','',1),(194540,'75445','new_theme','block-194538','checkout\\ContinueBtn','',3),(194541,'75446','new_theme','block-194538','order\\Totals','',2),(194542,'75447','new_theme','block-194515','account\\OrderHeading','',1),(194543,'75448','new_theme','update-and-pay-order_pay','BlockBox','',1),(194544,'75449','new_theme','block-194543','BlockBox','',3),(194545,'75450','new_theme','block-194544','BlockBox','',1),(194546,'75451','new_theme','block-194545','BlockBox','',1),(194547,'75452','new_theme','block-194546','BlockBox','',1),(194548,'75453','new_theme','block-194547','order\\DeliveryAddress','',3),(194549,'75454','new_theme','block-194547','order\\Email','',9),(194550,'75455','new_theme','block-194547','order\\Name','',7),(194551,'75456','new_theme','block-194547','Html_box','',6),(194552,'75457','new_theme','block-194547','order\\Telephone','',8),(194553,'75458','new_theme','block-194547','Html_box','',4),(194554,'75459','new_theme','block-194547','order\\ShippingMethod','',5),(194555,'75460','new_theme','block-194547','Html_box','',1),(194556,'75461','new_theme','block-194547','Html_box','',2),(194557,'75462','new_theme','block-194546-2','BlockBox','',1),(194558,'75463','new_theme','block-194557','Html_box','',1),(194559,'75464','new_theme','block-194557','Html_box','',2),(194560,'75465','new_theme','block-194557','Html_box','',4),(194561,'75466','new_theme','block-194557','order\\BillingAddress','',3),(194562,'75467','new_theme','block-194557','UpdateAndPay\\PayForm','',5),(194563,'75468','new_theme','block-194545','BlockBox','',3),(194564,'75469','new_theme','block-194563','Html_box','',1),(194565,'75470','new_theme','block-194563','order\\Products','',2),(194566,'75471','new_theme','block-194544-2','BlockBox','',1),(194567,'75472','new_theme','block-194566','order\\Totals','',2),(194568,'75473','new_theme','block-194566','checkout\\ContinueBtn','',3),(194569,'75474','new_theme','block-194566','Html_box','',1),(194570,'75475','new_theme','block-194543','account\\OrderHeading','',1),(194571,'75540','new_theme','wishlist','BlockBox','',1),(194572,'75541','new_theme','block-194571','BlockBox','',1),(194573,'75542','new_theme','block-194572','WidgetsAria','',1),(194574,'73374','new_theme','account-menu','BlockBox','',1),(194575,'73375','new_theme','block-194574','BlockBox','account-side',1),(194576,'73376','new_theme','block-194575','Html_box','',16),(194577,'73377','new_theme','block-194575','account\\AccountLink','',17),(194578,'73378','new_theme','block-194575','account\\AccountLink','',18),(194579,'73379','new_theme','block-194575','account\\AccountLink','',1),(194580,'73380','new_theme','block-194575','Html_box','',2),(194581,'73381','new_theme','block-194575','account\\AccountLink','',4),(194582,'73382','new_theme','block-194575','account\\AccountLink','',7),(194583,'73383','new_theme','block-194575','account\\AccountLink','',11),(194584,'73384','new_theme','block-194575','Html_box','',6),(194585,'73385','new_theme','block-194575','account\\AccountLink','',3),(194586,'73386','new_theme','block-194575','account\\AccountLink','',14),(194587,'73387','new_theme','block-194575','account\\AccountLink','',8),(194588,'73388','new_theme','block-194575','account\\AccountLink','',5),(194589,'73389','new_theme','block-194575','account\\AccountLink','',9),(194590,'73390','new_theme','block-194575','account\\AccountLink','',12),(194591,'73391','new_theme','block-194575','Html_box','',10),(194592,'73392','new_theme','block-194575','account\\AccountLink','',15),(194593,'75543','new_theme','block-194572-2','account\\Wishlist','',2),(194594,'75544','new_theme','block-194572-2','Html_box','',1),(194595,'75545','new_theme','wishlist-cart','BlockBox','',1),(194596,'75546','new_theme','block-194595','cart\\CartTabs','',1),(194597,'75547','new_theme','block-194596','account\\Wishlist','',1);
/*!40000 ALTER TABLE `design_boxes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `design_boxes_cache`
--

DROP TABLE IF EXISTS `design_boxes_cache`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `design_boxes_cache` (
  `block_name` varchar(128) CHARACTER SET latin1 COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `theme_name` varchar(128) CHARACTER SET latin1 COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `json` text NOT NULL,
  `serialize` blob NOT NULL,
  `date_modified` datetime DEFAULT NULL,
  PRIMARY KEY (`block_name`,`theme_name`),
  KEY `idx_theme_name2` (`theme_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `design_boxes_cache`
--

LOCK TABLES `design_boxes_cache` WRITE;
/*!40000 ALTER TABLE `design_boxes_cache` DISABLE KEYS */;
INSERT INTO `design_boxes_cache` VALUES ('footer','splash','[]','','[[regtime]]'),('header','splash','[]','','[[regtime]]'),('main','splash','[{\"id\":\"108931\",\"microtime\":\"1640168549.8258\",\"theme_name\":\"splash\",\"block_name\":\"main\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"0\",\"settings\":{\"0\":{\"block_type\":\"1\",\"background_image\":\"themes\\/splash\\/img\\/bg2.jpg\",\"background-size\":\"contain\",\"background-repeat\":\"no-repeat\",\"style_class\":\"mainbg\",\"params\":\"\"},\"colInRowCarousel\":null},\"children\":{\"block-108931\":[{\"id\":\"108932\",\"microtime\":\"1640168603.5833\",\"theme_name\":\"splash\",\"block_name\":\"block-108931\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":{\"0\":{\"block_type\":\"1\",\"params\":\"\"},\"colInRowCarousel\":null},\"children\":{\"block-108932\":[{\"id\":\"108933\",\"microtime\":\"1640168618.7708\",\"theme_name\":\"splash\",\"block_name\":\"block-108932\",\"widget_name\":\"Image\",\"widget_params\":\"\",\"sort_order\":\"0\",\"settings\":{\"1\":{\"logo\":\"themes\\/splash\\/img\\/oscommerce_logo (2).png\"},\"0\":{\"margin-top\":\"30\",\"margin-bottom\":\"30\",\"box_align\":\"2\",\"params\":\"\"},\"2\":{\"logo\":\"themes\\/splash\\/img\\/oscommerce_logo (2).png\"},\"3\":{\"logo\":\"themes\\/splash\\/img\\/oscommerce_logo (2).png\"},\"4\":{\"logo\":\"themes\\/splash\\/img\\/oscommerce_logo (2).png\"},\"colInRowCarousel\":null}}]}},{\"id\":\"108934\",\"microtime\":\"1640181569.3506\",\"theme_name\":\"splash\",\"block_name\":\"block-108931\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"2\",\"settings\":{\"0\":{\"block_type\":\"1\",\"params\":\"\"},\"colInRowCarousel\":null},\"children\":{\"block-108934\":[{\"id\":\"108935\",\"microtime\":\"1640168851.5282\",\"theme_name\":\"splash\",\"block_name\":\"block-108934\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":{\"0\":{\"block_type\":\"3\",\"params\":\"\"},\"visibility\":{\"5107\":[{\"schema\":\"3-6\"}],\"schema\":{\"w900\":\"3-6\"}},\"colInRowCarousel\":null},\"children\":{\"block-108935\":[{\"id\":\"108936\",\"microtime\":\"1640169872.1589\",\"theme_name\":\"splash\",\"block_name\":\"block-108935\",\"widget_name\":\"Image\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":{\"1\":{\"logo\":\"themes\\/splash\\/img\\/Splash_furniture_BGlogo.png\",\"img_link\":\"furniture\\/\",\"target_blank\":\"1\"},\"0\":{\"box_align\":\"2\",\"style_class\":\"scale\",\"params\":\"\"},\"2\":{\"img_link\":\"furniture\\/\",\"logo\":\"themes\\/splash\\/img\\/Splash_furniture_BGlogo.png\",\"target_blank\":\"1\"},\"3\":{\"img_link\":\"furniture\\/\",\"logo\":\"themes\\/splash\\/img\\/Splash_furniture_BGlogo.png\",\"target_blank\":\"1\"},\"4\":{\"img_link\":\"furniture\\/\",\"logo\":\"themes\\/splash\\/img\\/Splash_furniture_BGlogo.png\",\"target_blank\":\"1\"},\"colInRowCarousel\":null}}],\"block-108935-2\":[{\"id\":\"108937\",\"microtime\":\"1640276640.1123\",\"theme_name\":\"splash\",\"block_name\":\"block-108935-2\",\"widget_name\":\"Text\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":{\"1\":{\"text\":\"<h1>osCommerce v4 Splash page<\\/h1>\\r\\n\\r\\n<p>osCommerce supports multiple sales CHANNELS.<\\/p>\\r\\n\\r\\n<p>Your installation of osCommerce comes with &nbsp;&quot;Furniture&quot;, &quot;Watch&quot;, &quot;B2B Supermarket&quot;, and &quot;Print shop&quot; Ecommerce sales channels and &quot;cms&quot; brochure website example.<\\/p>\\r\\n\\r\\n<p>Each sales channel has its own URLs, design, and demo product sets.<\\/p>\\r\\n\\r\\n<p>&quot;Admin&quot; is the back end of your osCommerce.<\\/p>\\r\\n\\r\\n<p>Use osCommerce Wiki to learn how to manage sales channels, &nbsp;assign design themes, and content to the sales channels.<br \\/>\\r\\nThank you for choosing &nbsp;osCommerce - the most powerful on-premise open source Ecommerce platform!<\\/p>\\r\\n\"},\"0\":{\"color\":\"#ffffff\",\"font-size\":\"16\",\"text-align\":\"center\",\"params\":\"\"},\"visibility\":{\"5107\":[{\"padding-top\":\"50\",\"padding-left\":\"30\",\"padding-right\":\"30\",\"padding-bottom\":\"50\"}],\"padding-top\":{\"w900\":\"50\"},\"padding-left\":{\"w900\":\"30\"},\"padding-right\":{\"w900\":\"30\"},\"padding-bottom\":{\"w900\":\"50\"},\"5109\":[{\"font-size\":\"14\"}],\"font-size\":{\"w1250\":\"14\"}},\"2\":{\"text\":\"<h1>osCommerce v4 Splash page<\\/h1>\\r\\n\\r\\n<p>osCommerce supports multiple sales CHANNELS.<\\/p>\\r\\n\\r\\n<p>Your installation of osCommerce comes with &nbsp;&quot;Furniture&quot;, &quot;Watch&quot;, &quot;B2B Supermarket&quot;, and &quot;Print shop&quot; Ecommerce sales channels and &quot;cms&quot; brochure website example.<\\/p>\\r\\n\\r\\n<p>Each sales channel has its own URLs, design, and demo product sets.<\\/p>\\r\\n\\r\\n<p>&quot;Admin&quot; is the back end of your osCommerce.<\\/p>\\r\\n\\r\\n<p>Use osCommerce Wiki to learn how to manage sales channels, &nbsp;assign design themes, and content to the sales channels.<br \\/>\\r\\nThank you for choosing &nbsp;osCommerce - the most powerful on-premise open source Ecommerce platform!<\\/p>\\r\\n\"},\"3\":{\"text\":\"<h1>osCommerce v4 Splash page<\\/h1>\\r\\n\\r\\n<p>osCommerce supports multiple sales CHANNELS.<\\/p>\\r\\n\\r\\n<p>Your installation of osCommerce comes with &nbsp;&quot;Furniture&quot;, &quot;Watch&quot;, &quot;B2B Supermarket&quot;, and &quot;Print shop&quot; Ecommerce sales channels and &quot;cms&quot; brochure website example.<\\/p>\\r\\n\\r\\n<p>Each sales channel has its own URLs, design, and demo product sets.<\\/p>\\r\\n\\r\\n<p>&quot;Admin&quot; is the back end of your osCommerce.<\\/p>\\r\\n\\r\\n<p>Use osCommerce Wiki to learn how to manage sales channels, &nbsp;assign design themes, and content to the sales channels.<br \\/>\\r\\nThank you for choosing &nbsp;osCommerce - the most powerful on-premise open source Ecommerce platform!<\\/p>\\r\\n\"},\"4\":{\"text\":\"<h1>osCommerce v4 Splash page<\\/h1>\\r\\n\\r\\n<p>osCommerce supports multiple sales CHANNELS.<\\/p>\\r\\n\\r\\n<p>Your installation of osCommerce comes with &nbsp;&quot;Furniture&quot;, &quot;Watch&quot;, &quot;B2B Supermarket&quot;, and &quot;Print shop&quot; Ecommerce sales channels and &quot;cms&quot; brochure website example.<\\/p>\\r\\n\\r\\n<p>Each sales channel has its own URLs, design, and demo product sets.<\\/p>\\r\\n\\r\\n<p>&quot;Admin&quot; is the back end of your osCommerce.<\\/p>\\r\\n\\r\\n<p>Use osCommerce Wiki to learn how to manage sales channels, &nbsp;assign design themes, and content to the sales channels.<br \\/>\\r\\nThank you for choosing &nbsp;osCommerce - the most powerful on-premise open source Ecommerce platform!<\\/p>\\r\\n\"},\"colInRowCarousel\":null}}],\"block-108935-3\":[{\"id\":\"108938\",\"microtime\":\"1640170154.7803\",\"theme_name\":\"splash\",\"block_name\":\"block-108935-3\",\"widget_name\":\"Image\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":{\"1\":{\"logo\":\"themes\\/splash\\/img\\/Splash_watch_BGlogo.png\",\"img_link\":\"watch\\/\",\"target_blank\":\"1\"},\"0\":{\"box_align\":\"2\",\"style_class\":\"scale\",\"params\":\"\"},\"visibility\":{\"5107\":[{\"padding-top\":\"30\"}],\"padding-top\":{\"w900\":\"30\"}},\"2\":{\"img_link\":\"watch\\/\",\"logo\":\"themes\\/splash\\/img\\/Splash_watch_BGlogo.png\",\"target_blank\":\"1\"},\"3\":{\"img_link\":\"watch\\/\",\"logo\":\"themes\\/splash\\/img\\/Splash_watch_BGlogo.png\",\"target_blank\":\"1\"},\"4\":{\"img_link\":\"watch\\/\",\"logo\":\"themes\\/splash\\/img\\/Splash_watch_BGlogo.png\",\"target_blank\":\"1\"},\"colInRowCarousel\":null}}]}}]}},{\"id\":\"108939\",\"microtime\":\"1645204049.8114\",\"theme_name\":\"splash\",\"block_name\":\"block-108931\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"3\",\"settings\":{\"0\":{\"block_type\":\"3\",\"params\":\"\"},\"visibility\":{\"5107\":[{\"schema\":\"3-6\"}],\"schema\":{\"w900\":\"3-6\"}},\"colInRowCarousel\":null},\"children\":{\"block-108939\":[{\"id\":\"108940\",\"microtime\":\"1640170023.0001\",\"theme_name\":\"splash\",\"block_name\":\"block-108939\",\"widget_name\":\"Image\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":{\"1\":{\"logo\":\"themes\\/splash\\/img\\/print shop.jpg\",\"img_link\":\"printshop\\/\",\"target_blank\":\"1\"},\"0\":{\"box_align\":\"2\",\"margin-top\":\"30\",\"margin-bottom\":\"30\",\"style_class\":\"scale\",\"params\":\"\"},\"2\":{\"img_link\":\"printshop\\/\",\"logo\":\"themes\\/splash\\/img\\/print shop.jpg\",\"target_blank\":\"1\"},\"3\":{\"img_link\":\"printshop\\/\",\"logo\":\"themes\\/splash\\/img\\/print shop.jpg\",\"target_blank\":\"1\"},\"4\":{\"img_link\":\"printshop\\/\",\"logo\":\"themes\\/splash\\/img\\/print shop.jpg\",\"target_blank\":\"1\"},\"colInRowCarousel\":null}}],\"block-108939-2\":[{\"id\":\"108941\",\"microtime\":\"1640170023.1491\",\"theme_name\":\"splash\",\"block_name\":\"block-108939-2\",\"widget_name\":\"Image\",\"widget_params\":\"\",\"sort_order\":\"2\",\"settings\":{\"1\":{\"logo\":\"themes\\/splash\\/img\\/Splash_admin_BGlogo.png\",\"img_link\":\"admin\\/\",\"target_blank\":\"1\"},\"0\":{\"box_align\":\"2\",\"margin-top\":\"30\",\"margin-bottom\":\"30\",\"style_class\":\"scale\",\"params\":\"\"},\"2\":{\"img_link\":\"admin\\/\",\"logo\":\"themes\\/splash\\/img\\/Splash_admin_BGlogo.png\",\"target_blank\":\"1\"},\"3\":{\"img_link\":\"admin\\/\",\"logo\":\"themes\\/splash\\/img\\/Splash_admin_BGlogo.png\",\"target_blank\":\"1\"},\"4\":{\"img_link\":\"admin\\/\",\"logo\":\"themes\\/splash\\/img\\/Splash_admin_BGlogo.png\",\"target_blank\":\"1\"},\"colInRowCarousel\":null}}],\"block-108939-3\":[{\"id\":\"108942\",\"microtime\":\"1640170023\",\"theme_name\":\"splash\",\"block_name\":\"block-108939-3\",\"widget_name\":\"Image\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":{\"1\":{\"logo\":\"themes\\/splash\\/img\\/b2b supermarket.jpg\",\"img_link\":\"b2b-supermarket\\/\",\"target_blank\":\"1\"},\"0\":{\"box_align\":\"2\",\"margin-top\":\"30\",\"margin-bottom\":\"30\",\"style_class\":\"scale\",\"params\":\"\"},\"2\":{\"img_link\":\"b2b-supermarket\\/\",\"logo\":\"themes\\/splash\\/img\\/b2b supermarket.jpg\",\"target_blank\":\"1\"},\"3\":{\"img_link\":\"b2b-supermarket\\/\",\"logo\":\"themes\\/splash\\/img\\/b2b supermarket.jpg\",\"target_blank\":\"1\"},\"4\":{\"img_link\":\"b2b-supermarket\\/\",\"logo\":\"themes\\/splash\\/img\\/b2b supermarket.jpg\",\"target_blank\":\"1\"},\"colInRowCarousel\":null}}]}}]}}]','','[[regtime]]');
/*!40000 ALTER TABLE `design_boxes_cache` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `design_boxes_groups`
--

DROP TABLE IF EXISTS `design_boxes_groups`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `design_boxes_groups` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL DEFAULT '',
  `file` varchar(255) NOT NULL DEFAULT '',
  `page_type` varchar(255) NOT NULL DEFAULT '',
  `status` int(1) NOT NULL DEFAULT '1',
  `comment` text NOT NULL,
  `sort_order` int(32) NOT NULL DEFAULT '0',
  `date_added` datetime DEFAULT NULL,
  `category` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `design_boxes_groups`
--

LOCK TABLES `design_boxes_groups` WRITE;
/*!40000 ALTER TABLE `design_boxes_groups` DISABLE KEYS */;
INSERT INTO `design_boxes_groups` VALUES (1,'b2b-supermarket invoice','b2b-supermarket invoice.zip','',1,'',0,'2022-07-21 16:33:19',''),(2,'b2b-supermarket packingslip','b2b-supermarket packingslip.zip','',1,'',0,'2022-07-21 20:57:05',''),(3,'b2b-supermarket gift card','b2b-supermarket gift card.zip','',1,'',0,'2022-07-21 20:59:07',''),(4,'b2b-supermarket gift card pdf','b2b-supermarket gift card pdf.zip','',1,'',0,'2022-07-21 21:00:08',''),(5,'furniture gift card','furniture gift card.zip','',1,'',0,'2022-07-22 05:35:42',''),(6,'furniture gift card pdf','furniture gift card pdf.zip','',1,'',0,'2022-07-22 05:36:16',''),(7,'properties','properties.zip','',1,'',0,'2022-07-25 13:13:10','');
/*!40000 ALTER TABLE `design_boxes_groups` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `design_boxes_groups_category`
--

DROP TABLE IF EXISTS `design_boxes_groups_category`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `design_boxes_groups_category` (
  `boxes_group_category_id` int(11) NOT NULL AUTO_INCREMENT,
  `parent_category` varchar(255) NOT NULL DEFAULT '',
  `name` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`boxes_group_category_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `design_boxes_groups_category`
--

LOCK TABLES `design_boxes_groups_category` WRITE;
/*!40000 ALTER TABLE `design_boxes_groups_category` DISABLE KEYS */;
/*!40000 ALTER TABLE `design_boxes_groups_category` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `design_boxes_groups_images`
--

DROP TABLE IF EXISTS `design_boxes_groups_images`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `design_boxes_groups_images` (
  `boxes_group_image_id` int(11) NOT NULL AUTO_INCREMENT,
  `boxes_group_id` int(32) NOT NULL DEFAULT '0',
  `file` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`boxes_group_image_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `design_boxes_groups_images`
--

LOCK TABLES `design_boxes_groups_images` WRITE;
/*!40000 ALTER TABLE `design_boxes_groups_images` DISABLE KEYS */;
/*!40000 ALTER TABLE `design_boxes_groups_images` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `design_boxes_groups_languages`
--

DROP TABLE IF EXISTS `design_boxes_groups_languages`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `design_boxes_groups_languages` (
  `boxes_group_id` int(11) NOT NULL,
  `language_id` int(11) NOT NULL,
  `title` varchar(255) NOT NULL DEFAULT '',
  `description` text NOT NULL,
  PRIMARY KEY (`boxes_group_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `design_boxes_groups_languages`
--

LOCK TABLES `design_boxes_groups_languages` WRITE;
/*!40000 ALTER TABLE `design_boxes_groups_languages` DISABLE KEYS */;
/*!40000 ALTER TABLE `design_boxes_groups_languages` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `design_boxes_settings`
--

DROP TABLE IF EXISTS `design_boxes_settings`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `design_boxes_settings` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `box_id` int(11) DEFAULT NULL,
  `microtime` varchar(32) NOT NULL,
  `theme_name` varchar(128) CHARACTER SET latin1 COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `setting_name` varchar(64) DEFAULT NULL,
  `setting_value` text,
  `language_id` int(11) NOT NULL DEFAULT '0',
  `visibility` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`),
  UNIQUE KEY `language_box_settingname_visibility` (`language_id`,`box_id`,`setting_name`,`visibility`),
  KEY `box_id` (`box_id`),
  KEY `design_boxes_settings_microtime` (`microtime`)
) ENGINE=InnoDB AUTO_INCREMENT=617920 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `design_boxes_settings`
--

LOCK TABLES `design_boxes_settings` WRITE;
/*!40000 ALTER TABLE `design_boxes_settings` DISABLE KEYS */;
INSERT INTO `design_boxes_settings` VALUES (9097,2926,'94814','watch-mobile','text','##TEXT_PAGE_NOT_FOUND##',0,''),(9098,2926,'94814','watch-mobile','text-align','center',0,''),(9099,2926,'94814','watch-mobile','padding-top','100',0,''),(9100,2926,'94814','watch-mobile','padding-bottom','100',0,''),(9101,2927,'94815','watch-mobile','block_type','1',0,''),(9220,2943,'94831','watch-mobile','block_type','1',0,''),(9339,2959,'94847','watch-mobile','block_type','1',0,''),(9458,2975,'94863','watch-mobile','block_type','1',0,''),(9577,2991,'94879','watch-mobile','block_type','1',0,''),(9696,3007,'94895','watch-mobile','block_type','1',0,''),(9815,3023,'94911','watch-mobile','block_type','1',0,''),(9816,3024,'94912','watch-mobile','block_type','6',0,''),(9817,3024,'94912','watch-mobile','schema','6-3',0,''),(9818,3024,'94912','watch-mobile','schema','6-3',0,'299'),(9819,3025,'94913','watch-mobile','aria_name','account-menu',0,''),(9820,3026,'94914','watch-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(9821,3027,'94915','watch-mobile','link','Order History Info',0,''),(9822,3027,'94915','watch-mobile','text','TEXT_VIEW',0,''),(9823,3027,'94915','watch-mobile','max_orders','3',0,''),(9824,3027,'94915','watch-mobile','link_pay','Order pay',0,''),(9825,3027,'94915','watch-mobile','margin-bottom','30',0,''),(9826,3027,'94915','watch-mobile','text_pay','ORDER_PAY',0,''),(9827,3028,'94916','watch-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(9828,3029,'94917','watch-mobile','block_type','15',0,''),(9829,3029,'94917','watch-mobile','margin-bottom','30',0,''),(9830,3029,'94917','watch-mobile','padding-top','20',0,''),(9831,3029,'94917','watch-mobile','padding-left','20',0,''),(9832,3029,'94917','watch-mobile','padding-right','20',0,''),(9833,3029,'94917','watch-mobile','padding-bottom','20',0,''),(9834,3029,'94917','watch-mobile','border-top-width','1',0,''),(9835,3029,'94917','watch-mobile','border-top-color','$border-color-1',0,''),(9836,3029,'94917','watch-mobile','border-left-width','1',0,''),(9837,3029,'94917','watch-mobile','border-right-width','1',0,''),(9838,3029,'94917','watch-mobile','border-bottom-width','1',0,''),(9839,3029,'94917','watch-mobile','border-left-color','$border-color-1',0,''),(9840,3029,'94917','watch-mobile','border-right-color','$border-color-1',0,''),(9841,3029,'94917','watch-mobile','border-bottom-color','$border-color-1',0,''),(9842,3029,'94917','watch-mobile','schema','15-2',0,'299'),(9843,3030,'94918','watch-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(9844,3030,'94918','watch-mobile','font-family','trueloaded',0,'3'),(9845,3030,'94918','watch-mobile','content','\\e920',0,'3'),(9846,3030,'94918','watch-mobile','color','$attention-color',0,'3'),(9847,3030,'94918','watch-mobile','font-size','30',0,'3'),(9848,3030,'94918','watch-mobile','text-align','center',0,'3'),(9849,3030,'94918','watch-mobile','margin-bottom','10',0,'3'),(9850,3030,'94918','watch-mobile','text-align','center',0,''),(9851,3030,'94918','watch-mobile','font-size','16',0,''),(9852,3030,'94918','watch-mobile','text-transform','uppercase',0,''),(9853,3030,'94918','watch-mobile','line-height','1',0,'3'),(9855,3031,'94919','watch-mobile','font-family','$font-1',0,''),(9856,3031,'94919','watch-mobile','color','$attention-color',0,''),(9857,3031,'94919','watch-mobile','font-size','14',0,''),(9858,3031,'94919','watch-mobile','text-align','center',0,''),(9859,3032,'94920','watch-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(9860,3032,'94920','watch-mobile','font-family','trueloaded',0,'3'),(9861,3032,'94920','watch-mobile','content','\\e928',0,'3'),(9862,3032,'94920','watch-mobile','color','$attention-color',0,'3'),(9863,3032,'94920','watch-mobile','font-size','30',0,'3'),(9864,3032,'94920','watch-mobile','text-align','center',0,'3'),(9865,3032,'94920','watch-mobile','text-align','center',0,''),(9866,3032,'94920','watch-mobile','font-size','16',0,''),(9867,3032,'94920','watch-mobile','text-transform','uppercase',0,''),(9868,3032,'94920','watch-mobile','line-height','1',0,'3'),(9870,3033,'94921','watch-mobile','link','download_orders',0,''),(9871,3033,'94921','watch-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(9872,3033,'94921','watch-mobile','hide_link','orders',0,''),(9873,3033,'94921','watch-mobile','text-align','center',0,''),(9874,3033,'94921','watch-mobile','popup','2',0,''),(9875,3033,'94921','watch-mobile','font-size','14',0,''),(9876,3034,'94922','watch-mobile','font-family','$font-1',0,''),(9877,3034,'94922','watch-mobile','color','$attention-color',0,''),(9878,3034,'94922','watch-mobile','font-size','14',0,''),(9879,3034,'94922','watch-mobile','text-align','center',0,''),(9880,3035,'94923','watch-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(9881,3035,'94923','watch-mobile','font-family','trueloaded',0,'3'),(9882,3035,'94923','watch-mobile','content','\\e922',0,'3'),(9883,3035,'94923','watch-mobile','color','$attention-color',0,'3'),(9884,3035,'94923','watch-mobile','font-size','30',0,'3'),(9885,3035,'94923','watch-mobile','line-height','1',0,'3'),(9886,3035,'94923','watch-mobile','font-size','16',0,''),(9887,3035,'94923','watch-mobile','text-align','center',0,''),(9888,3035,'94923','watch-mobile','text-transform','uppercase',0,''),(9890,3036,'94924','watch-mobile','font-family','$font-1',0,''),(9891,3036,'94924','watch-mobile','color','$attention-color',0,''),(9892,3036,'94924','watch-mobile','line-height','1',0,''),(9893,3036,'94924','watch-mobile','text-align','center',0,''),(9894,3036,'94924','watch-mobile','font-size','14',0,''),(9895,3037,'94925','watch-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(9896,3037,'94925','watch-mobile','content','\\e994',0,'3'),(9897,3037,'94925','watch-mobile','font-family','trueloaded',0,'3'),(9898,3037,'94925','watch-mobile','color','$attention-color',0,'3'),(9899,3037,'94925','watch-mobile','font-size','30',0,'3'),(9900,3037,'94925','watch-mobile','line-height','1',0,'3'),(9901,3037,'94925','watch-mobile','font-size','16',0,''),(9902,3037,'94925','watch-mobile','text-align','center',0,''),(9903,3037,'94925','watch-mobile','text-transform','uppercase',0,''),(9905,3038,'94926','watch-mobile','link','Gift Certificate',0,''),(9906,3038,'94926','watch-mobile','text','GIFT_CERTIFICATE',0,''),(9907,3038,'94926','watch-mobile','popup','1',0,''),(9908,3038,'94926','watch-mobile','text-align','center',0,''),(9909,3038,'94926','watch-mobile','font-size','14',0,''),(9910,3039,'94927','watch-mobile','font-family','$font-1',0,''),(9911,3039,'94927','watch-mobile','color','$attention-color',0,''),(9912,3039,'94927','watch-mobile','font-size','14',0,''),(9913,3039,'94927','watch-mobile','text-align','center',0,''),(9914,3040,'94928','watch-mobile','text','TEXT_VIEW_HISTORY',0,''),(9915,3040,'94928','watch-mobile','popup','1',0,''),(9916,3040,'94928','watch-mobile','text-align','center',0,''),(9917,3040,'94928','watch-mobile','link','Points Earnt History',0,''),(9918,3040,'94928','watch-mobile','font-size','14',0,''),(9919,3041,'94929','watch-mobile','font-family','$font-1',0,''),(9920,3041,'94929','watch-mobile','color','$attention-color',0,''),(9921,3041,'94929','watch-mobile','font-size','14',0,''),(9922,3041,'94929','watch-mobile','text-align','center',0,''),(9923,3042,'94930','watch-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(9924,3042,'94930','watch-mobile','content','\\e990',0,'3'),(9925,3042,'94930','watch-mobile','font-family','trueloaded',0,'3'),(9926,3042,'94930','watch-mobile','font-size','30',0,'3'),(9927,3042,'94930','watch-mobile','text-align','center',0,'3'),(9928,3042,'94930','watch-mobile','line-height','1',0,'3'),(9929,3042,'94930','watch-mobile','color','$attention-color',0,'3'),(9930,3042,'94930','watch-mobile','font-size','16',0,''),(9931,3042,'94930','watch-mobile','text-align','center',0,''),(9932,3042,'94930','watch-mobile','text-transform','uppercase',0,''),(9934,3043,'94931','watch-mobile','block_type','1',0,''),(9935,3044,'94932','watch-mobile','hide_parents','2',0,''),(9936,3045,'94933','watch-mobile','text','<div class=\"heading-3\">##TEXT_GIFT_CARDS##</div>',0,''),(9937,3047,'94935','watch-mobile','block_type','1',0,''),(9938,3047,'94935','watch-mobile','padding-top','70',0,''),(9939,3047,'94935','watch-mobile','padding-right','30',0,''),(9940,3047,'94935','watch-mobile','padding-bottom','30',0,''),(9942,3047,'94935','watch-mobile','padding-left','0',0,''),(9945,3048,'94936','watch-mobile','block_type','1',0,''),(9946,3048,'94936','watch-mobile','padding-right','20',0,''),(9947,3048,'94936','watch-mobile','style_class','account-menu',0,''),(9948,3048,'94936','watch-mobile','padding-top','20',0,''),(9949,3048,'94936','watch-mobile','margin-bottom','20',0,''),(9950,3048,'94936','watch-mobile','background-color','$background-6',0,''),(9951,3048,'94936','watch-mobile','padding-left','20',0,''),(9952,3048,'94936','watch-mobile','padding-bottom','20',0,''),(9953,3049,'94937','watch-mobile','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(9954,3049,'94937','watch-mobile','style_class','heading-settings',0,''),(9955,3050,'94938','watch-mobile','link','delete',0,''),(9956,3050,'94938','watch-mobile','text','DELETE_ACCOUNT',0,''),(9957,3051,'94939','watch-mobile','text','TEXT_DASHBOARD',0,''),(9958,3051,'94939','watch-mobile','font-family','$font-1',0,''),(9959,3051,'94939','watch-mobile','font-size','18',0,''),(9960,3051,'94939','watch-mobile','text-transform','uppercase',0,''),(9961,3052,'94940','watch-mobile','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(9962,3052,'94940','watch-mobile','style_class','heading-saved-lists',0,''),(9963,3053,'94941','watch-mobile','link','logoff',0,''),(9964,3054,'94942','watch-mobile','link','Personal Catalog',0,''),(9965,3054,'94942','watch-mobile','text','TEXT_PERSONAL_CATALOG',0,''),(9966,3054,'94942','watch-mobile','hide_link','personal_catalog',0,''),(9967,3055,'94943','watch-mobile','link','Address Book',0,''),(9968,3055,'94943','watch-mobile','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(9969,3056,'94944','watch-mobile','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(9970,3056,'94944','watch-mobile','style_class','heading-ordered-items',0,''),(9971,3057,'94945','watch-mobile','link','Samples',0,''),(9972,3057,'94945','watch-mobile','text','TEXT_HEADING_SAMPLE_CART',0,''),(9973,3057,'94945','watch-mobile','hide_link','samples',0,''),(9974,3058,'94946','watch-mobile','link','Order History',0,''),(9975,3058,'94946','watch-mobile','text','HEADING_ORDER_HISTORY',0,''),(9976,3058,'94946','watch-mobile','active_link','Order History Info,Order pay',0,''),(9977,3059,'94947','watch-mobile','link','My password',0,''),(9978,3059,'94947','watch-mobile','text','TEXT_MY_PASSWORD',0,''),(9979,3060,'94948','watch-mobile','link','Review',0,''),(9980,3060,'94948','watch-mobile','text','REVIEWS',0,''),(9981,3061,'94949','watch-mobile','link','Account edit',0,''),(9982,3061,'94949','watch-mobile','text','ACCOUNT_EDIT',0,''),(9983,3062,'94950','watch-mobile','link','Quotations',0,''),(9984,3062,'94950','watch-mobile','hide_link','quotations',0,''),(9985,3062,'94950','watch-mobile','text','TEXT_HEADING_QUOTE_CART',0,''),(9986,3063,'94951','watch-mobile','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(9987,3063,'94951','watch-mobile','style_class','heading-settings',0,''),(9988,3064,'94952','watch-mobile','link','trade_form',0,''),(9989,3064,'94952','watch-mobile','text','TRADE_FORM',0,''),(9990,3065,'94953','watch-mobile','block_type','1',0,''),(9991,3066,'94954','watch-mobile','block_type','6',0,''),(9992,3066,'94954','watch-mobile','schema','6-3',0,''),(9993,3066,'94954','watch-mobile','schema','6-3',0,'299'),(9994,3067,'94955','watch-mobile','aria_name','account-menu',0,''),(9995,3069,'94957','watch-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(9996,3070,'94958','watch-mobile','text','CANCEL',0,''),(9997,3070,'94958','watch-mobile','like_button','1',0,''),(9998,3070,'94958','watch-mobile','padding-bottom','20',0,''),(9999,3071,'94959','watch-mobile','block_type','1',0,''),(10000,3072,'94960','watch-mobile','block_type','6',0,''),(10001,3072,'94960','watch-mobile','schema','6-3',0,''),(10002,3072,'94960','watch-mobile','schema','6-3',0,'299'),(10003,3073,'94961','watch-mobile','aria_name','account-menu',0,''),(10004,3074,'94962','watch-mobile','padding-top','15',0,''),(10005,3074,'94962','watch-mobile','padding-bottom','15',0,''),(10006,3074,'94962','watch-mobile','link','Address Book Process',0,''),(10007,3074,'94962','watch-mobile','text','EDIT',0,''),(10008,3074,'94962','watch-mobile','link_add','Address Book Process',0,''),(10009,3074,'94962','watch-mobile','like_button_add','2',0,''),(10010,3074,'94962','watch-mobile','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(10011,3075,'94963','watch-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1><div class=\"info-popup bottom-left\">\n<div><ul><li>##PRIMARY_ADDRESS##<br>##PRIMARY_ADDRESS_DESCRIPTION##<br></li><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(10012,3075,'94963','watch-mobile','text-align','center',0,''),(10013,3076,'94964','watch-mobile','block_type','1',0,''),(10014,3077,'94965','watch-mobile','block_type','6',0,''),(10015,3077,'94965','watch-mobile','schema','6-3',0,''),(10016,3077,'94965','watch-mobile','schema','6-3',0,'299'),(10017,3078,'94966','watch-mobile','aria_name','account-menu',0,''),(10018,3080,'94968','watch-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(10019,3081,'94969','watch-mobile','text','CANCEL',0,''),(10020,3081,'94969','watch-mobile','like_button','1',0,''),(10021,3081,'94969','watch-mobile','padding-bottom','20',0,''),(10022,3081,'94969','watch-mobile','link','Address Book',0,''),(10023,3082,'94970','watch-mobile','block_type','1',0,''),(10024,3082,'94970','watch-mobile','style_class','item-holder',0,''),(10025,3082,'94970','watch-mobile','padding-top','25',0,''),(10026,3082,'94970','watch-mobile','padding-bottom','25',0,''),(10027,3082,'94970','watch-mobile','text-align','left',0,''),(10028,3082,'94970','watch-mobile','border-top-color','$border-color-1',0,''),(10029,3082,'94970','watch-mobile','border-top-width','1',0,''),(10030,3083,'94971','watch-mobile','block_type','6',0,''),(10031,3084,'94972','watch-mobile','padding-right','20',0,''),(10032,3085,'94973','watch-mobile','clear','none',0,''),(10033,3087,'94975','watch-mobile','block_type','4',0,''),(10034,3088,'94976','watch-mobile','block_type','2',0,''),(10035,3089,'94977','watch-mobile','margin-bottom','7',0,''),(10036,3090,'94978','watch-mobile','clear','none',0,''),(10037,3091,'94979','watch-mobile','margin-bottom','20',0,''),(10038,3091,'94979','watch-mobile','text-align','right',0,''),(10039,3092,'94980','watch-mobile','description_characters','200',0,''),(10040,3092,'94980','watch-mobile','clear','none',0,''),(10041,3092,'94980','watch-mobile','padding-right','20',0,''),(10042,3093,'94981','watch-mobile','block_type','2',0,''),(10043,3094,'94982','watch-mobile','clear','none',0,''),(10044,3096,'94984','watch-mobile','padding-right','20',0,''),(10045,3097,'94985','watch-mobile','block_type','1',0,''),(10046,3097,'94985','watch-mobile','style_class','item-holder',0,''),(10047,3097,'94985','watch-mobile','padding-top','25',0,''),(10048,3097,'94985','watch-mobile','padding-left','25',0,''),(10049,3097,'94985','watch-mobile','padding-right','25',0,''),(10050,3097,'94985','watch-mobile','padding-bottom','25',0,''),(10051,3097,'94985','watch-mobile','text-align','left',0,''),(10052,3099,'94987','watch-mobile','margin-bottom','7',0,''),(10053,3100,'94988','watch-mobile','clear','both',0,''),(10054,3103,'94991','watch-mobile','block_type','1',0,''),(10055,3103,'94991','watch-mobile','style_class','item-holder',0,''),(10056,3103,'94991','watch-mobile','padding-top','25',0,''),(10057,3103,'94991','watch-mobile','padding-left','25',0,''),(10058,3103,'94991','watch-mobile','padding-right','25',0,''),(10059,3103,'94991','watch-mobile','padding-bottom','25',0,''),(10060,3103,'94991','watch-mobile','text-align','left',0,''),(10061,3104,'94992','watch-mobile','block_type','5',0,''),(10062,3107,'94995','watch-mobile','margin-bottom','7',0,''),(10063,3108,'94996','watch-mobile','clear','both',0,''),(10064,3109,'94997','watch-mobile','block_type','1',0,''),(10065,3110,'94998','watch-mobile','block_type','6',0,''),(10066,3110,'94998','watch-mobile','font-weight','400',0,''),(10067,3110,'94998','watch-mobile','schema','6-2',0,''),(10069,3111,'94999','watch-mobile','font-weight','400',0,''),(10070,3111,'94999','watch-mobile','padding-right','40',0,''),(10073,3112,'95000','watch-mobile','block_type','5',0,''),(10074,3112,'95000','watch-mobile','padding-top','10',0,''),(10075,3112,'95000','watch-mobile','padding-bottom','10',0,''),(10076,3112,'95000','watch-mobile','schema','5-2',0,''),(10077,3112,'95000','watch-mobile','border-top-color','$border-color-1',0,''),(10078,3112,'95000','watch-mobile','border-top-width','1',0,''),(10079,3114,'95002','watch-mobile','float','right',0,''),(10080,3116,'95004','watch-mobile','col_in_row','3',0,''),(10081,3116,'95004','watch-mobile','products_align','left',0,''),(10082,3116,'95004','watch-mobile','font-weight','400',0,''),(10083,3116,'95004','watch-mobile','show_qty_input','0',0,''),(10084,3116,'95004','watch-mobile','listing_type','productListing',0,''),(10085,3116,'95004','watch-mobile','listing_type_rows','no',0,''),(10086,3116,'95004','watch-mobile','show_buy_button_b2b','on',0,''),(10087,3116,'95004','watch-mobile','show_wishlist_button_b2b','1',0,''),(10088,3116,'95004','watch-mobile','show_compare_b2b','1',0,''),(10089,3116,'95004','watch-mobile','show_stock','0',0,''),(10090,3116,'95004','watch-mobile','show_description','0',0,''),(10091,3116,'95004','watch-mobile','show_model','0',0,''),(10092,3116,'95004','watch-mobile','show_properties','0',0,''),(10093,3116,'95004','watch-mobile','show_rating','0',0,''),(10094,3116,'95004','watch-mobile','show_rating_counts','0',0,''),(10095,3116,'95004','watch-mobile','show_price','0',0,''),(10096,3116,'95004','watch-mobile','show_buy_button','0',0,''),(10097,3116,'95004','watch-mobile','show_view_button','0',0,''),(10098,3116,'95004','watch-mobile','show_wishlist_button','0',0,''),(10099,3116,'95004','watch-mobile','show_compare','0',0,''),(10100,3116,'95004','watch-mobile','show_name_rows','0',0,''),(10101,3116,'95004','watch-mobile','show_image_rows','0',0,''),(10102,3116,'95004','watch-mobile','show_stock_rows','0',0,''),(10103,3116,'95004','watch-mobile','show_description_rows','0',0,''),(10104,3116,'95004','watch-mobile','show_model_rows','0',0,''),(10105,3116,'95004','watch-mobile','show_properties_rows','0',0,''),(10106,3116,'95004','watch-mobile','show_rating_rows','0',0,''),(10107,3116,'95004','watch-mobile','show_rating_counts_rows','0',0,''),(10108,3116,'95004','watch-mobile','show_price_rows','0',0,''),(10109,3116,'95004','watch-mobile','show_buy_button_rows','0',0,''),(10110,3116,'95004','watch-mobile','show_qty_input_rows','0',0,''),(10111,3116,'95004','watch-mobile','show_view_button_rows','0',0,''),(10112,3116,'95004','watch-mobile','show_wishlist_button_rows','0',0,''),(10113,3116,'95004','watch-mobile','show_compare_rows','0',0,''),(10114,3116,'95004','watch-mobile','show_name_b2b','0',0,''),(10115,3116,'95004','watch-mobile','show_image_b2b','0',0,''),(10116,3116,'95004','watch-mobile','show_stock_b2b','0',0,''),(10117,3116,'95004','watch-mobile','show_description_b2b','0',0,''),(10118,3116,'95004','watch-mobile','show_model_b2b','0',0,''),(10119,3116,'95004','watch-mobile','show_properties_b2b','0',0,''),(10120,3116,'95004','watch-mobile','show_rating_b2b','0',0,''),(10121,3116,'95004','watch-mobile','show_rating_counts_b2b','0',0,''),(10122,3116,'95004','watch-mobile','show_price_b2b','0',0,''),(10123,3116,'95004','watch-mobile','show_qty_input_b2b','0',0,''),(10124,3116,'95004','watch-mobile','show_view_button_b2b','0',0,''),(10125,3116,'95004','watch-mobile','show_attributes_b2b','0',0,''),(10126,3116,'95004','watch-mobile','items_on_page','9',0,''),(10129,3116,'95004','watch-mobile','product_names_teg','h2',0,''),(10130,3117,'95005','watch-mobile','listing_type','productListing',0,''),(10131,3118,'95006','watch-mobile','block_type','1',0,''),(10132,3118,'95006','watch-mobile','padding-top','10',0,''),(10133,3118,'95006','watch-mobile','padding-bottom','10',0,''),(10134,3118,'95006','watch-mobile','border-bottom-width','1',0,''),(10135,3118,'95006','watch-mobile','border-bottom-color','$border-color-1',0,''),(10136,3118,'95006','watch-mobile','margin-left','0',0,''),(10137,3118,'95006','watch-mobile','margin-right','0',0,''),(10138,3119,'95007','watch-mobile','float','right',0,''),(10139,3119,'95007','watch-mobile','display','none',0,''),(10140,3120,'95008','watch-mobile','margin-right','20',0,''),(10141,3120,'95008','watch-mobile','float','right',0,''),(10142,3120,'95008','watch-mobile','clear','none',0,''),(10143,3120,'95008','watch-mobile','display','none',0,''),(10144,3121,'95009','watch-mobile','float','left',0,''),(10145,3121,'95009','watch-mobile','clear','none',0,''),(10146,3121,'95009','watch-mobile','margin-left','20',0,''),(10147,3121,'95009','watch-mobile','display','none',0,''),(10148,3122,'95010','watch-mobile','float','left',0,''),(10149,3122,'95010','watch-mobile','clear','none',0,''),(10150,3122,'95010','watch-mobile','sort_pos_3','1',0,''),(10151,3122,'95010','watch-mobile','sort_pos_4','2',0,''),(10152,3122,'95010','watch-mobile','sort_pos_10','3',0,''),(10153,3122,'95010','watch-mobile','sort_pos_9','4',0,''),(10154,3122,'95010','watch-mobile','sort_pos_11','5',0,''),(10155,3122,'95010','watch-mobile','sort_pos_12','6',0,''),(10156,3122,'95010','watch-mobile','sort_pos_14','7',0,''),(10157,3122,'95010','watch-mobile','sort_pos_13','8',0,''),(10158,3122,'95010','watch-mobile','sort_pos_8','9',0,''),(10159,3122,'95010','watch-mobile','sort_pos_7','10',0,''),(10160,3122,'95010','watch-mobile','sort_pos_2','11',0,''),(10161,3122,'95010','watch-mobile','sort_pos_1','12',0,''),(10162,3122,'95010','watch-mobile','sort_pos_6','13',0,''),(10163,3122,'95010','watch-mobile','sort_pos_5','14',0,''),(10164,3122,'95010','watch-mobile','sort_pos_0','15',0,''),(10165,3122,'95010','watch-mobile','sort_hide_10','1',0,''),(10166,3122,'95010','watch-mobile','sort_hide_9','1',0,''),(10167,3122,'95010','watch-mobile','hide_icons','1',0,''),(10168,3122,'95010','watch-mobile','sort_hide_16','1',0,''),(10169,3122,'95010','watch-mobile','sort_hide_15','1',0,''),(10170,3122,'95010','watch-mobile','sort_hide_3','0',0,''),(10171,3122,'95010','watch-mobile','sort_hide_4','0',0,''),(10172,3122,'95010','watch-mobile','sort_hide_11','1',0,''),(10173,3122,'95010','watch-mobile','sort_hide_12','1',0,''),(10174,3122,'95010','watch-mobile','sort_hide_14','1',0,''),(10175,3122,'95010','watch-mobile','sort_hide_13','1',0,''),(10176,3122,'95010','watch-mobile','sort_hide_8','0',0,''),(10177,3122,'95010','watch-mobile','sort_hide_7','0',0,''),(10178,3122,'95010','watch-mobile','sort_hide_2','1',0,''),(10179,3122,'95010','watch-mobile','sort_hide_1','1',0,''),(10180,3122,'95010','watch-mobile','sort_hide_6','1',0,''),(10181,3122,'95010','watch-mobile','sort_hide_5','1',0,''),(10182,3122,'95010','watch-mobile','sort_hide_0','1',0,''),(10183,3125,'75559','watch-mobile','block_type','1',0,''),(10184,3126,'75560','watch-mobile','block_type','7',0,''),(10185,3126,'75560','watch-mobile','schema','7-2',0,'317'),(10186,3127,'75561','watch-mobile','padding-top','20',0,''),(10187,3127,'75561','watch-mobile','padding-right','20',0,''),(10188,3128,'75562','watch-mobile','blog_sidebar','1',0,''),(10189,3128,'75562','watch-mobile','padding-top','20',0,''),(10190,3128,'75562','watch-mobile','padding-left','20',0,''),(10191,3129,'113643','watch-mobile','block_type','1',0,''),(10192,3130,'113644','watch-mobile','item_tag','h2',0,''),(10193,3130,'113644','watch-mobile','hTagsInline','inline',0,''),(10194,3134,'115968','watch-mobile','block_type','1',0,''),(10195,3134,'115968','watch-mobile','schema','4-1',0,''),(10197,3134,'115968','watch-mobile','schema','4-1',0,'299'),(10198,3135,'115969','watch-mobile','block_type','1',0,''),(10199,3135,'115969','watch-mobile','background-color','$background-7',0,''),(10200,3135,'115969','watch-mobile','padding-top','20',0,''),(10201,3135,'115969','watch-mobile','padding-bottom','20',0,''),(10202,3135,'115969','watch-mobile','margin-bottom','30',0,''),(10203,3136,'115970','watch-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(10204,3136,'115970','watch-mobile','style_class','bell-ico',0,''),(10205,3137,'115971','watch-mobile','col_in_row','3',0,''),(10206,3137,'115971','watch-mobile','show_description','1',0,''),(10207,3137,'115971','watch-mobile','show_model','1',0,''),(10208,3137,'115971','watch-mobile','show_properties','1',0,''),(10209,3137,'115971','watch-mobile','show_rating','1',0,''),(10210,3137,'115971','watch-mobile','show_rating_counts','1',0,''),(10211,3137,'115971','watch-mobile','show_qty_input','1',0,''),(10212,3137,'115971','watch-mobile','show_view_button','1',0,''),(10213,3137,'115971','watch-mobile','show_wishlist_button','1',0,''),(10214,3137,'115971','watch-mobile','show_compare','1',0,''),(10215,3137,'115971','watch-mobile','view_as','carousel',0,''),(10216,3137,'115971','watch-mobile','hide_parents','2',0,''),(10217,3138,'115972','watch-mobile','block_type','1',0,''),(10218,3138,'115972','watch-mobile','background-color','$background-7',0,''),(10219,3138,'115972','watch-mobile','margin-bottom','30',0,''),(10220,3139,'115973','watch-mobile','padding-top','20',0,''),(10221,3139,'115973','watch-mobile','padding-bottom','20',0,''),(10222,3140,'115974','watch-mobile','block_type','2',0,''),(10223,3140,'115974','watch-mobile','padding-bottom','20',0,''),(10224,3140,'115974','watch-mobile','padding-top','20',0,''),(10225,3140,'115974','watch-mobile','border-bottom-color','$border-color-1',0,''),(10226,3140,'115974','watch-mobile','border-bottom-width','1',0,''),(10227,3140,'115974','watch-mobile','schema','2-2',0,''),(10228,3141,'115976','watch-mobile','padding-top','22',0,''),(10229,3142,'115977','watch-mobile','float','right',0,''),(10230,3142,'115977','watch-mobile','padding-top','26',0,''),(10231,3143,'115975','watch-mobile','float','left',0,''),(10232,3144,'115978','watch-mobile','block_type','1',0,''),(10233,3144,'115978','watch-mobile','padding-top','20',0,''),(10234,3144,'115978','watch-mobile','padding-bottom','20',0,''),(10235,3144,'115978','watch-mobile','background-color','$background-7',0,''),(10236,3144,'115978','watch-mobile','margin-bottom','30',0,''),(10237,3145,'115979','watch-mobile','hide_parents','2',0,''),(10238,3146,'115980','watch-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(10239,3147,'115981','watch-mobile','block_type','1',0,''),(10240,3147,'115981','watch-mobile','background-color','$background-7',0,''),(10241,3147,'115981','watch-mobile','padding-top','20',0,''),(10242,3147,'115981','watch-mobile','padding-bottom','20',0,''),(10243,3147,'115981','watch-mobile','margin-bottom','30',0,''),(10244,3147,'115981','watch-mobile','style_class','closeable-box',0,''),(10245,3148,'115982','watch-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(10246,3148,'115982','watch-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(10247,3149,'115983','watch-mobile','block_type','1',0,''),(10248,3149,'115983','watch-mobile','font-weight','400',0,''),(10249,3149,'115983','watch-mobile','schema','2-2',0,''),(10250,3149,'115983','watch-mobile','style_class','closeable-content',0,''),(10251,3149,'115983','watch-mobile','padding-top','10',0,''),(10252,3150,'115984','watch-mobile','font-weight','400',0,''),(10253,3150,'115984','watch-mobile','padding-top','12',0,''),(10254,3150,'115984','watch-mobile','padding-left','0',0,''),(10255,3153,'115987','watch-mobile','block_type','1',0,''),(10256,3153,'115987','watch-mobile','background-color','$background-7',0,''),(10257,3153,'115987','watch-mobile','padding-top','20',0,''),(10258,3153,'115987','watch-mobile','padding-left','25',0,''),(10259,3153,'115987','watch-mobile','padding-right','25',0,''),(10260,3153,'115987','watch-mobile','padding-bottom','20',0,''),(10261,3153,'115987','watch-mobile','margin-bottom','30',0,''),(10262,3153,'115987','watch-mobile','style_class','closeable-box',0,''),(10263,3153,'115987','watch-mobile','display','none',0,''),(10265,3154,'115988','watch-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(10266,3154,'115988','watch-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(10267,3155,'115989','watch-mobile','font-weight','normal',0,''),(10268,3155,'115989','watch-mobile','style_class','closeable-content',0,''),(10269,3155,'115989','watch-mobile','padding-top','10',0,''),(10270,3155,'115989','watch-mobile','hide_parents','2',0,''),(10271,3156,'115990','watch-mobile','style_class','order-summary',0,''),(10272,3156,'115990','watch-mobile','block_type','1',0,''),(10273,3156,'115990','watch-mobile','margin-left','30',0,''),(10275,3156,'115990','watch-mobile','margin-bottom','30',0,''),(10276,3157,'115991','watch-mobile','block_type','1',0,''),(10277,3157,'115991','watch-mobile','padding-bottom','20',0,''),(10278,3158,'115992','watch-mobile','font-weight','400',0,''),(10279,3158,'115992','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',1,''),(10280,3158,'115992','watch-mobile','padding-top','20',0,''),(10281,3158,'115992','watch-mobile','padding-bottom','10',0,''),(10282,3159,'115993','watch-mobile','font-weight','400',0,''),(10283,3159,'115993','watch-mobile','box_align','4',0,''),(10284,3159,'115993','watch-mobile','text-align','center',0,''),(10285,3159,'115993','watch-mobile','float','none',0,''),(10286,3159,'115993','watch-mobile','width','100',0,''),(10287,3159,'115993','watch-mobile','width_measure','%',0,''),(10288,3161,'115995','watch-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(10289,3162,'113648','watch-mobile','block_type','1',0,''),(10290,3162,'113648','watch-mobile','font-weight','normal',0,''),(10291,3162,'113648','watch-mobile','padding-top','20',0,''),(10292,3162,'113648','watch-mobile','background-color','$background-6',0,''),(10293,3164,'113650','watch-mobile','block_type','4',0,''),(10294,3164,'113650','watch-mobile','schema','4-1',0,''),(10296,3165,'113651','watch-mobile','block_type','1',0,''),(10297,3165,'113651','watch-mobile','background-color','$background-7',0,''),(10298,3165,'113651','watch-mobile','padding-top','20',0,''),(10299,3165,'113651','watch-mobile','padding-bottom','20',0,''),(10300,3165,'113651','watch-mobile','padding-left','25',0,''),(10301,3165,'113651','watch-mobile','padding-right','25',0,''),(10302,3165,'113651','watch-mobile','margin-bottom','30',0,''),(10303,3166,'113652','watch-mobile','col_in_row','3',0,''),(10304,3166,'113652','watch-mobile','show_description','1',0,''),(10305,3166,'113652','watch-mobile','show_model','1',0,''),(10306,3166,'113652','watch-mobile','show_properties','1',0,''),(10307,3166,'113652','watch-mobile','show_rating','1',0,''),(10308,3166,'113652','watch-mobile','show_rating_counts','1',0,''),(10309,3166,'113652','watch-mobile','show_qty_input','1',0,''),(10310,3166,'113652','watch-mobile','show_view_button','1',0,''),(10311,3166,'113652','watch-mobile','show_wishlist_button','1',0,''),(10312,3166,'113652','watch-mobile','show_compare','1',0,''),(10313,3166,'113652','watch-mobile','view_as','carousel',0,''),(10314,3166,'113652','watch-mobile','hide_parents','2',0,''),(10315,3167,'113653','watch-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(10316,3167,'113653','watch-mobile','style_class','bell-ico',0,''),(10317,3168,'113654','watch-mobile','block_type','1',0,''),(10318,3168,'113654','watch-mobile','background-color','$background-7',0,''),(10319,3168,'113654','watch-mobile','margin-bottom','30',0,''),(10320,3169,'113655','watch-mobile','padding-top','20',0,''),(10321,3169,'113655','watch-mobile','padding-left','25',0,''),(10322,3169,'113655','watch-mobile','padding-right','25',0,''),(10323,3169,'113655','watch-mobile','padding-bottom','20',0,''),(10324,3170,'113656','watch-mobile','block_type','2',0,''),(10325,3170,'113656','watch-mobile','padding-bottom','20',0,''),(10326,3170,'113656','watch-mobile','padding-top','20',0,''),(10327,3170,'113656','watch-mobile','padding-left','25',0,''),(10328,3170,'113656','watch-mobile','padding-right','25',0,''),(10329,3170,'113656','watch-mobile','border-bottom-color','$border-color-1',0,''),(10330,3170,'113656','watch-mobile','border-bottom-width','1',0,''),(10331,3170,'113656','watch-mobile','schema','2-2',0,''),(10332,3171,'113657','watch-mobile','float','left',0,''),(10333,3172,'113658','watch-mobile','text-align','right',0,''),(10334,3172,'113658','watch-mobile','clear','none',0,''),(10335,3172,'113658','watch-mobile','float','right',0,''),(10336,3172,'113658','watch-mobile','padding-top','22',0,''),(10337,3173,'113659','watch-mobile','float','right',0,''),(10338,3173,'113659','watch-mobile','padding-top','26',0,''),(10339,3174,'113660','watch-mobile','block_type','1',0,''),(10340,3174,'113660','watch-mobile','padding-top','20',0,''),(10341,3174,'113660','watch-mobile','padding-bottom','20',0,''),(10342,3174,'113660','watch-mobile','padding-left','25',0,''),(10343,3174,'113660','watch-mobile','padding-right','25',0,''),(10344,3174,'113660','watch-mobile','background-color','$background-7',0,''),(10345,3174,'113660','watch-mobile','margin-bottom','30',0,''),(10346,3175,'113661','watch-mobile','hide_parents','2',0,''),(10347,3176,'113662','watch-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(10348,3177,'113663','watch-mobile','block_type','1',0,''),(10349,3177,'113663','watch-mobile','background-color','$background-7',0,''),(10350,3177,'113663','watch-mobile','padding-top','20',0,''),(10351,3177,'113663','watch-mobile','padding-bottom','20',0,''),(10352,3177,'113663','watch-mobile','padding-left','25',0,''),(10353,3177,'113663','watch-mobile','padding-right','25',0,''),(10354,3177,'113663','watch-mobile','margin-bottom','30',0,''),(10355,3177,'113663','watch-mobile','style_class','closeable-box',0,''),(10356,3178,'113664','watch-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(10357,3178,'113664','watch-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(10358,3179,'113665','watch-mobile','block_type','3',0,''),(10359,3179,'113665','watch-mobile','font-weight','400',0,''),(10360,3179,'113665','watch-mobile','schema','2-2',0,''),(10361,3179,'113665','watch-mobile','style_class','closeable-content',0,''),(10362,3179,'113665','watch-mobile','padding-top','10',0,''),(10363,3180,'113666','watch-mobile','font-weight','400',0,''),(10364,3180,'113666','watch-mobile','padding-top','12',0,''),(10365,3180,'113666','watch-mobile','padding-left','0',0,''),(10366,3183,'113669','watch-mobile','block_type','1',0,''),(10367,3183,'113669','watch-mobile','background-color','$background-7',0,''),(10368,3183,'113669','watch-mobile','padding-top','20',0,''),(10369,3183,'113669','watch-mobile','padding-left','25',0,''),(10370,3183,'113669','watch-mobile','padding-right','25',0,''),(10371,3183,'113669','watch-mobile','padding-bottom','20',0,''),(10372,3183,'113669','watch-mobile','margin-bottom','30',0,''),(10373,3183,'113669','watch-mobile','style_class','closeable-box',0,''),(10374,3183,'113669','watch-mobile','display','none',0,''),(10376,3184,'113670','watch-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(10377,3184,'113670','watch-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(10378,3185,'113671','watch-mobile','font-weight','normal',0,''),(10379,3185,'113671','watch-mobile','style_class','closeable-content',0,''),(10380,3185,'113671','watch-mobile','padding-top','10',0,''),(10381,3185,'113671','watch-mobile','hide_parents','2',0,''),(10382,3186,'113672','watch-mobile','style_class','order-summary',0,''),(10383,3186,'113672','watch-mobile','block_type','1',0,''),(10384,3186,'113672','watch-mobile','margin-left','30',0,''),(10386,3186,'113672','watch-mobile','margin-bottom','30',0,''),(10387,3187,'113673','watch-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(10388,3188,'113674','watch-mobile','block_type','1',0,''),(10389,3188,'113674','watch-mobile','padding-left','20',0,''),(10390,3188,'113674','watch-mobile','padding-right','20',0,''),(10391,3188,'113674','watch-mobile','padding-bottom','20',0,''),(10392,3189,'113675','watch-mobile','font-weight','400',0,''),(10393,3189,'113675','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',1,''),(10394,3189,'113675','watch-mobile','padding-top','20',0,''),(10395,3189,'113675','watch-mobile','padding-bottom','10',0,''),(10396,3190,'113676','watch-mobile','font-weight','400',0,''),(10397,3190,'113676','watch-mobile','box_align','4',0,''),(10398,3190,'113676','watch-mobile','text-align','center',0,''),(10399,3190,'113676','watch-mobile','float','none',0,''),(10400,3190,'113676','watch-mobile','width','100',0,''),(10401,3190,'113676','watch-mobile','width_measure','%',0,''),(10402,3192,'75585','watch-mobile','block_type','1',0,''),(10403,3195,'75588','watch-mobile','block_type','1',0,''),(10404,3196,'75589','watch-mobile','col_in_row','2',0,''),(10405,3196,'75589','watch-mobile','products_align','left',0,''),(10406,3196,'75589','watch-mobile','font-weight','400',0,''),(10407,3196,'75589','watch-mobile','show_qty_input','1',0,''),(10408,3196,'75589','watch-mobile','listing_type','productListing',0,''),(10409,3196,'75589','watch-mobile','listing_type_rows','type-1_2',0,''),(10410,3196,'75589','watch-mobile','show_buy_button_b2b','on',0,''),(10411,3196,'75589','watch-mobile','show_wishlist_button_b2b','1',0,''),(10412,3196,'75589','watch-mobile','show_compare_b2b','1',0,''),(10413,3196,'75589','watch-mobile','listing_type_b2b','type-1_3',0,''),(10414,3196,'75589','watch-mobile','show_name','0',0,''),(10415,3196,'75589','watch-mobile','show_image','0',0,''),(10416,3196,'75589','watch-mobile','show_stock','0',0,''),(10417,3196,'75589','watch-mobile','show_description','1',0,''),(10418,3196,'75589','watch-mobile','show_model','1',0,''),(10419,3196,'75589','watch-mobile','show_properties','1',0,''),(10420,3196,'75589','watch-mobile','show_rating_counts','1',0,''),(10421,3196,'75589','watch-mobile','show_price','0',0,''),(10422,3196,'75589','watch-mobile','show_buy_button','1',0,''),(10423,3196,'75589','watch-mobile','show_view_button','1',0,''),(10424,3196,'75589','watch-mobile','show_wishlist_button','1',0,''),(10425,3196,'75589','watch-mobile','show_compare','1',0,''),(10426,3196,'75589','watch-mobile','show_name_rows','0',0,''),(10427,3196,'75589','watch-mobile','show_image_rows','0',0,''),(10428,3196,'75589','watch-mobile','show_stock_rows','0',0,''),(10429,3196,'75589','watch-mobile','show_description_rows','0',0,''),(10430,3196,'75589','watch-mobile','show_model_rows','0',0,''),(10431,3196,'75589','watch-mobile','show_properties_rows','0',0,''),(10432,3196,'75589','watch-mobile','show_rating_rows','0',0,''),(10433,3196,'75589','watch-mobile','show_rating_counts_rows','0',0,''),(10434,3196,'75589','watch-mobile','show_price_rows','0',0,''),(10435,3196,'75589','watch-mobile','show_buy_button_rows','0',0,''),(10436,3196,'75589','watch-mobile','show_qty_input_rows','0',0,''),(10437,3196,'75589','watch-mobile','show_view_button_rows','0',0,''),(10438,3196,'75589','watch-mobile','show_wishlist_button_rows','0',0,''),(10439,3196,'75589','watch-mobile','show_compare_rows','0',0,''),(10440,3196,'75589','watch-mobile','show_name_b2b','0',0,''),(10441,3196,'75589','watch-mobile','show_image_b2b','0',0,''),(10442,3196,'75589','watch-mobile','show_stock_b2b','0',0,''),(10443,3196,'75589','watch-mobile','show_description_b2b','0',0,''),(10444,3196,'75589','watch-mobile','show_model_b2b','0',0,''),(10445,3196,'75589','watch-mobile','show_properties_b2b','0',0,''),(10446,3196,'75589','watch-mobile','show_rating_b2b','0',0,''),(10447,3196,'75589','watch-mobile','show_rating_counts_b2b','0',0,''),(10448,3196,'75589','watch-mobile','show_price_b2b','0',0,''),(10449,3196,'75589','watch-mobile','show_qty_input_b2b','0',0,''),(10450,3196,'75589','watch-mobile','show_view_button_b2b','0',0,''),(10451,3196,'75589','watch-mobile','show_attributes_b2b','0',0,''),(10452,3196,'75589','watch-mobile','items_on_page','10',0,''),(10453,3196,'75589','watch-mobile','product_names_teg','h2',0,''),(10454,3197,'75590','watch-mobile','block_type','2',0,''),(10455,3197,'75590','watch-mobile','margin-bottom','20',0,''),(10456,3198,'75591','watch-mobile','sort_pos_3','1',0,''),(10457,3198,'75591','watch-mobile','sort_pos_4','2',0,''),(10458,3198,'75591','watch-mobile','sort_pos_10','5',0,''),(10459,3198,'75591','watch-mobile','sort_pos_9','6',0,''),(10460,3198,'75591','watch-mobile','sort_pos_11','7',0,''),(10461,3198,'75591','watch-mobile','sort_pos_12','8',0,''),(10462,3198,'75591','watch-mobile','sort_pos_14','9',0,''),(10463,3198,'75591','watch-mobile','sort_pos_13','10',0,''),(10464,3198,'75591','watch-mobile','sort_pos_8','11',0,''),(10465,3198,'75591','watch-mobile','sort_pos_7','12',0,''),(10466,3198,'75591','watch-mobile','sort_pos_2','13',0,''),(10467,3198,'75591','watch-mobile','sort_pos_1','14',0,''),(10468,3198,'75591','watch-mobile','sort_pos_6','15',0,''),(10469,3198,'75591','watch-mobile','sort_pos_5','16',0,''),(10470,3198,'75591','watch-mobile','sort_pos_0','17',0,''),(10471,3198,'75591','watch-mobile','sort_hide_10','1',0,''),(10472,3198,'75591','watch-mobile','sort_hide_9','1',0,''),(10473,3198,'75591','watch-mobile','sort_pos_15','4',0,''),(10474,3198,'75591','watch-mobile','sort_pos_16','3',0,''),(10475,3198,'75591','watch-mobile','sort_hide_3','0',0,''),(10476,3198,'75591','watch-mobile','sort_hide_4','0',0,''),(10477,3198,'75591','watch-mobile','sort_hide_16','1',0,''),(10478,3198,'75591','watch-mobile','sort_hide_15','1',0,''),(10479,3198,'75591','watch-mobile','sort_hide_11','0',0,''),(10480,3198,'75591','watch-mobile','sort_hide_12','0',0,''),(10481,3198,'75591','watch-mobile','sort_hide_14','0',0,''),(10482,3198,'75591','watch-mobile','sort_hide_13','0',0,''),(10483,3198,'75591','watch-mobile','sort_hide_8','0',0,''),(10484,3198,'75591','watch-mobile','sort_hide_7','0',0,''),(10485,3198,'75591','watch-mobile','sort_hide_2','0',0,''),(10486,3198,'75591','watch-mobile','sort_hide_1','0',0,''),(10487,3198,'75591','watch-mobile','sort_hide_6','0',0,''),(10488,3198,'75591','watch-mobile','sort_hide_5','0',0,''),(10489,3198,'75591','watch-mobile','sort_hide_0','0',0,''),(10490,3199,'75592','watch-mobile','text-align','right',0,''),(10491,3199,'75592','watch-mobile','padding-top','10',0,''),(10492,3200,'75593','watch-mobile','text-align','center',0,''),(10493,3200,'75593','watch-mobile','margin-bottom','20',0,''),(10494,3206,'113678','watch-mobile','block_type','1',0,''),(10495,3208,'113680','watch-mobile','block_type','6',0,''),(10496,3208,'113680','watch-mobile','font-weight','400',0,''),(10497,3208,'113680','watch-mobile','schema','6-2',0,''),(10499,3209,'113681','watch-mobile','font-weight','400',0,''),(10500,3209,'113681','watch-mobile','padding-right','40',0,''),(10503,3211,'113683','watch-mobile','col_in_row','3',0,''),(10504,3211,'113683','watch-mobile','products_align','left',0,''),(10505,3211,'113683','watch-mobile','font-weight','400',0,''),(10506,3211,'113683','watch-mobile','show_qty_input','0',0,''),(10507,3211,'113683','watch-mobile','listing_type','productListing',0,''),(10508,3211,'113683','watch-mobile','listing_type_rows','no',0,''),(10509,3211,'113683','watch-mobile','show_buy_button_b2b','on',0,''),(10510,3211,'113683','watch-mobile','show_wishlist_button_b2b','1',0,''),(10511,3211,'113683','watch-mobile','show_compare_b2b','1',0,''),(10512,3211,'113683','watch-mobile','show_stock','0',0,''),(10513,3211,'113683','watch-mobile','show_description','0',0,''),(10514,3211,'113683','watch-mobile','show_model','0',0,''),(10515,3211,'113683','watch-mobile','show_properties','0',0,''),(10516,3211,'113683','watch-mobile','show_rating','0',0,''),(10517,3211,'113683','watch-mobile','show_rating_counts','0',0,''),(10518,3211,'113683','watch-mobile','show_price','0',0,''),(10519,3211,'113683','watch-mobile','show_buy_button','0',0,''),(10520,3211,'113683','watch-mobile','show_view_button','0',0,''),(10521,3211,'113683','watch-mobile','show_wishlist_button','0',0,''),(10522,3211,'113683','watch-mobile','show_compare','0',0,''),(10523,3211,'113683','watch-mobile','show_name_rows','0',0,''),(10524,3211,'113683','watch-mobile','show_image_rows','0',0,''),(10525,3211,'113683','watch-mobile','show_stock_rows','0',0,''),(10526,3211,'113683','watch-mobile','show_description_rows','0',0,''),(10527,3211,'113683','watch-mobile','show_model_rows','0',0,''),(10528,3211,'113683','watch-mobile','show_properties_rows','0',0,''),(10529,3211,'113683','watch-mobile','show_rating_rows','0',0,''),(10530,3211,'113683','watch-mobile','show_rating_counts_rows','0',0,''),(10531,3211,'113683','watch-mobile','show_price_rows','0',0,''),(10532,3211,'113683','watch-mobile','show_buy_button_rows','0',0,''),(10533,3211,'113683','watch-mobile','show_qty_input_rows','0',0,''),(10534,3211,'113683','watch-mobile','show_view_button_rows','0',0,''),(10535,3211,'113683','watch-mobile','show_wishlist_button_rows','0',0,''),(10536,3211,'113683','watch-mobile','show_compare_rows','0',0,''),(10537,3211,'113683','watch-mobile','show_name_b2b','0',0,''),(10538,3211,'113683','watch-mobile','show_image_b2b','0',0,''),(10539,3211,'113683','watch-mobile','show_stock_b2b','0',0,''),(10540,3211,'113683','watch-mobile','show_description_b2b','0',0,''),(10541,3211,'113683','watch-mobile','show_model_b2b','0',0,''),(10542,3211,'113683','watch-mobile','show_properties_b2b','0',0,''),(10543,3211,'113683','watch-mobile','show_rating_b2b','0',0,''),(10544,3211,'113683','watch-mobile','show_rating_counts_b2b','0',0,''),(10545,3211,'113683','watch-mobile','show_price_b2b','0',0,''),(10546,3211,'113683','watch-mobile','show_qty_input_b2b','0',0,''),(10547,3211,'113683','watch-mobile','show_view_button_b2b','0',0,''),(10548,3211,'113683','watch-mobile','show_attributes_b2b','0',0,''),(10549,3211,'113683','watch-mobile','items_on_page','9',0,''),(10552,3211,'113683','watch-mobile','product_names_teg','h2',0,''),(10553,3212,'113684','watch-mobile','block_type','1',0,''),(10554,3212,'113684','watch-mobile','padding-top','10',0,''),(10555,3212,'113684','watch-mobile','padding-bottom','10',0,''),(10556,3212,'113684','watch-mobile','border-bottom-width','1',0,''),(10557,3212,'113684','watch-mobile','border-bottom-color','$border-color-1',0,''),(10558,3212,'113684','watch-mobile','margin-left','0',0,''),(10559,3212,'113684','watch-mobile','margin-right','0',0,''),(10560,3213,'113685','watch-mobile','float','left',0,''),(10561,3213,'113685','watch-mobile','clear','none',0,''),(10562,3213,'113685','watch-mobile','sort_pos_3','1',0,''),(10563,3213,'113685','watch-mobile','sort_pos_4','2',0,''),(10564,3213,'113685','watch-mobile','sort_pos_10','3',0,''),(10565,3213,'113685','watch-mobile','sort_pos_9','4',0,''),(10566,3213,'113685','watch-mobile','sort_pos_11','5',0,''),(10567,3213,'113685','watch-mobile','sort_pos_12','6',0,''),(10568,3213,'113685','watch-mobile','sort_pos_14','7',0,''),(10569,3213,'113685','watch-mobile','sort_pos_13','8',0,''),(10570,3213,'113685','watch-mobile','sort_pos_8','9',0,''),(10571,3213,'113685','watch-mobile','sort_pos_7','10',0,''),(10572,3213,'113685','watch-mobile','sort_pos_2','11',0,''),(10573,3213,'113685','watch-mobile','sort_pos_1','12',0,''),(10574,3213,'113685','watch-mobile','sort_pos_6','13',0,''),(10575,3213,'113685','watch-mobile','sort_pos_5','14',0,''),(10576,3213,'113685','watch-mobile','sort_pos_0','15',0,''),(10577,3213,'113685','watch-mobile','sort_hide_10','1',0,''),(10578,3213,'113685','watch-mobile','sort_hide_9','1',0,''),(10579,3213,'113685','watch-mobile','hide_icons','1',0,''),(10580,3213,'113685','watch-mobile','sort_hide_16','1',0,''),(10581,3213,'113685','watch-mobile','sort_hide_15','1',0,''),(10582,3213,'113685','watch-mobile','sort_hide_3','0',0,''),(10583,3213,'113685','watch-mobile','sort_hide_4','0',0,''),(10584,3213,'113685','watch-mobile','sort_hide_11','1',0,''),(10585,3213,'113685','watch-mobile','sort_hide_12','1',0,''),(10586,3213,'113685','watch-mobile','sort_hide_14','1',0,''),(10587,3213,'113685','watch-mobile','sort_hide_13','1',0,''),(10588,3213,'113685','watch-mobile','sort_hide_8','0',0,''),(10589,3213,'113685','watch-mobile','sort_hide_7','0',0,''),(10590,3213,'113685','watch-mobile','sort_hide_2','1',0,''),(10591,3213,'113685','watch-mobile','sort_hide_1','1',0,''),(10592,3213,'113685','watch-mobile','sort_hide_6','1',0,''),(10593,3213,'113685','watch-mobile','sort_hide_5','1',0,''),(10594,3213,'113685','watch-mobile','sort_hide_0','1',0,''),(10595,3214,'113686','watch-mobile','float','left',0,''),(10596,3214,'113686','watch-mobile','clear','none',0,''),(10597,3214,'113686','watch-mobile','margin-left','20',0,''),(10598,3214,'113686','watch-mobile','display','none',0,''),(10599,3215,'113687','watch-mobile','margin-right','20',0,''),(10600,3215,'113687','watch-mobile','float','right',0,''),(10601,3215,'113687','watch-mobile','clear','none',0,''),(10602,3215,'113687','watch-mobile','display','none',0,''),(10603,3216,'113688','watch-mobile','float','right',0,''),(10604,3216,'113688','watch-mobile','display','none',0,''),(10605,3217,'113689','watch-mobile','listing_type','productListing',0,''),(10606,3219,'113691','watch-mobile','block_type','5',0,''),(10607,3219,'113691','watch-mobile','padding-top','10',0,''),(10608,3219,'113691','watch-mobile','padding-bottom','10',0,''),(10609,3219,'113691','watch-mobile','schema','5-2',0,''),(10610,3219,'113691','watch-mobile','border-top-color','$border-color-1',0,''),(10611,3219,'113691','watch-mobile','border-top-width','1',0,''),(10612,3221,'113693','watch-mobile','float','right',0,''),(10613,3222,'113694','watch-mobile','block_type','1',0,''),(10614,3224,'113696','watch-mobile','block_type','5',0,''),(10615,3224,'113696','watch-mobile','padding-top','10',0,''),(10616,3224,'113696','watch-mobile','padding-bottom','10',0,''),(10617,3224,'113696','watch-mobile','schema','5-2',0,''),(10618,3224,'113696','watch-mobile','border-top-color','$border-color-1',0,''),(10619,3224,'113696','watch-mobile','border-top-width','1',0,''),(10620,3226,'113698','watch-mobile','float','right',0,''),(10621,3227,'113699','watch-mobile','col_in_row','4',0,''),(10622,3227,'113699','watch-mobile','products_align','left',0,''),(10623,3227,'113699','watch-mobile','font-weight','400',0,''),(10624,3227,'113699','watch-mobile','show_qty_input','0',0,''),(10625,3227,'113699','watch-mobile','listing_type','productListing',0,''),(10626,3227,'113699','watch-mobile','listing_type_rows','Rows',0,''),(10627,3227,'113699','watch-mobile','show_buy_button_b2b','on',0,''),(10628,3227,'113699','watch-mobile','show_wishlist_button_b2b','1',0,''),(10629,3227,'113699','watch-mobile','show_compare_b2b','1',0,''),(10630,3227,'113699','watch-mobile','listing_type_b2b','b2b',0,''),(10631,3227,'113699','watch-mobile','show_image','0',0,''),(10632,3227,'113699','watch-mobile','show_stock','0',0,''),(10633,3227,'113699','watch-mobile','show_description','0',0,''),(10634,3227,'113699','watch-mobile','show_model','0',0,''),(10635,3227,'113699','watch-mobile','show_properties','0',0,''),(10636,3227,'113699','watch-mobile','show_rating','0',0,''),(10637,3227,'113699','watch-mobile','show_rating_counts','0',0,''),(10638,3227,'113699','watch-mobile','show_price','0',0,''),(10639,3227,'113699','watch-mobile','show_buy_button','0',0,''),(10640,3227,'113699','watch-mobile','show_view_button','0',0,''),(10641,3227,'113699','watch-mobile','show_wishlist_button','0',0,''),(10642,3227,'113699','watch-mobile','show_compare','0',0,''),(10643,3227,'113699','watch-mobile','show_name_rows','0',0,''),(10644,3227,'113699','watch-mobile','show_image_rows','0',0,''),(10645,3227,'113699','watch-mobile','show_stock_rows','0',0,''),(10646,3227,'113699','watch-mobile','show_description_rows','0',0,''),(10647,3227,'113699','watch-mobile','show_model_rows','0',0,''),(10648,3227,'113699','watch-mobile','show_properties_rows','0',0,''),(10649,3227,'113699','watch-mobile','show_rating_rows','0',0,''),(10650,3227,'113699','watch-mobile','show_rating_counts_rows','0',0,''),(10651,3227,'113699','watch-mobile','show_price_rows','0',0,''),(10652,3227,'113699','watch-mobile','show_buy_button_rows','0',0,''),(10653,3227,'113699','watch-mobile','show_qty_input_rows','0',0,''),(10654,3227,'113699','watch-mobile','show_view_button_rows','0',0,''),(10655,3227,'113699','watch-mobile','show_wishlist_button_rows','0',0,''),(10656,3227,'113699','watch-mobile','show_compare_rows','0',0,''),(10657,3227,'113699','watch-mobile','show_name_b2b','0',0,''),(10658,3227,'113699','watch-mobile','show_image_b2b','0',0,''),(10659,3227,'113699','watch-mobile','show_stock_b2b','0',0,''),(10660,3227,'113699','watch-mobile','show_description_b2b','0',0,''),(10661,3227,'113699','watch-mobile','show_model_b2b','0',0,''),(10662,3227,'113699','watch-mobile','show_properties_b2b','0',0,''),(10663,3227,'113699','watch-mobile','show_rating_b2b','0',0,''),(10664,3227,'113699','watch-mobile','show_rating_counts_b2b','0',0,''),(10665,3227,'113699','watch-mobile','show_price_b2b','0',0,''),(10666,3227,'113699','watch-mobile','show_qty_input_b2b','0',0,''),(10667,3227,'113699','watch-mobile','show_view_button_b2b','0',0,''),(10668,3227,'113699','watch-mobile','show_attributes_b2b','0',0,''),(10669,3227,'113699','watch-mobile','items_on_page','12',0,''),(10672,3227,'113699','watch-mobile','product_names_teg','h2',0,''),(10674,3229,'113701','watch-mobile','block_type','1',0,''),(10675,3229,'113701','watch-mobile','padding-top','10',0,''),(10676,3229,'113701','watch-mobile','padding-bottom','10',0,''),(10677,3229,'113701','watch-mobile','border-bottom-width','1',0,''),(10678,3229,'113701','watch-mobile','border-bottom-color','$border-color-1',0,''),(10679,3229,'113701','watch-mobile','margin-left','0',0,''),(10680,3229,'113701','watch-mobile','margin-right','0',0,''),(10681,3230,'113702','watch-mobile','float','right',0,''),(10682,3230,'113702','watch-mobile','display','none',0,''),(10683,3231,'113703','watch-mobile','margin-right','20',0,''),(10684,3231,'113703','watch-mobile','float','right',0,''),(10685,3231,'113703','watch-mobile','clear','none',0,''),(10686,3231,'113703','watch-mobile','display','none',0,''),(10687,3232,'113704','watch-mobile','clear','none',0,''),(10688,3232,'113704','watch-mobile','float','left',0,''),(10689,3232,'113704','watch-mobile','padding-top','3',0,''),(10690,3232,'113704','watch-mobile','padding-left','20',0,''),(10691,3233,'113705','watch-mobile','float','left',0,''),(10692,3233,'113705','watch-mobile','clear','none',0,''),(10693,3233,'113705','watch-mobile','margin-left','20',0,''),(10694,3233,'113705','watch-mobile','display','none',0,''),(10695,3234,'113706','watch-mobile','float','left',0,''),(10696,3234,'113706','watch-mobile','clear','none',0,''),(10697,3234,'113706','watch-mobile','sort_pos_3','1',0,''),(10698,3234,'113706','watch-mobile','sort_pos_4','2',0,''),(10699,3234,'113706','watch-mobile','sort_pos_10','3',0,''),(10700,3234,'113706','watch-mobile','sort_pos_9','4',0,''),(10701,3234,'113706','watch-mobile','sort_pos_11','5',0,''),(10702,3234,'113706','watch-mobile','sort_pos_12','6',0,''),(10703,3234,'113706','watch-mobile','sort_pos_14','7',0,''),(10704,3234,'113706','watch-mobile','sort_pos_13','8',0,''),(10705,3234,'113706','watch-mobile','sort_pos_8','9',0,''),(10706,3234,'113706','watch-mobile','sort_pos_7','10',0,''),(10707,3234,'113706','watch-mobile','sort_pos_2','11',0,''),(10708,3234,'113706','watch-mobile','sort_pos_1','12',0,''),(10709,3234,'113706','watch-mobile','sort_pos_6','13',0,''),(10710,3234,'113706','watch-mobile','sort_pos_5','14',0,''),(10711,3234,'113706','watch-mobile','sort_pos_0','15',0,''),(10712,3234,'113706','watch-mobile','sort_hide_10','1',0,''),(10713,3234,'113706','watch-mobile','sort_hide_9','1',0,''),(10714,3234,'113706','watch-mobile','hide_icons','1',0,''),(10715,3234,'113706','watch-mobile','sort_hide_16','1',0,''),(10716,3234,'113706','watch-mobile','sort_hide_15','1',0,''),(10717,3234,'113706','watch-mobile','sort_hide_3','0',0,''),(10718,3234,'113706','watch-mobile','sort_hide_4','0',0,''),(10719,3234,'113706','watch-mobile','sort_hide_11','1',0,''),(10720,3234,'113706','watch-mobile','sort_hide_12','1',0,''),(10721,3234,'113706','watch-mobile','sort_hide_14','1',0,''),(10722,3234,'113706','watch-mobile','sort_hide_13','1',0,''),(10723,3234,'113706','watch-mobile','sort_hide_8','0',0,''),(10724,3234,'113706','watch-mobile','sort_hide_7','0',0,''),(10725,3234,'113706','watch-mobile','sort_hide_2','1',0,''),(10726,3234,'113706','watch-mobile','sort_hide_1','1',0,''),(10727,3234,'113706','watch-mobile','sort_hide_6','1',0,''),(10728,3234,'113706','watch-mobile','sort_hide_5','1',0,''),(10729,3234,'113706','watch-mobile','sort_hide_0','1',0,''),(10873,3281,'113753','watch-mobile','block_type','1',0,''),(10874,3282,'113754','watch-mobile','margin-bottom','20',0,''),(10875,3282,'113754','watch-mobile','text-align','center',0,''),(10876,3284,'113756','watch-mobile','block_type','1',0,''),(10877,3284,'113756','watch-mobile','margin-bottom','20',0,''),(10878,3284,'113756','watch-mobile','schema','2-2',0,''),(10879,3285,'113757','watch-mobile','block_type','1',0,''),(10882,3286,'113758','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(10883,3286,'113758','watch-mobile','clear','none',0,''),(10884,3288,'113760','watch-mobile','block_type','1',0,''),(10887,3289,'113761','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(10888,3289,'113761','watch-mobile','clear','none',0,''),(10889,3291,'113763','watch-mobile','text-align','center',0,''),(10890,3291,'113763','watch-mobile','margin-bottom','20',0,''),(10891,3292,'113764','watch-mobile','block_type','1',0,''),(10892,3292,'113764','watch-mobile','margin-bottom','20',0,''),(10893,3292,'113764','watch-mobile','schema','2-2',0,''),(10894,3293,'113765','watch-mobile','block_type','1',0,''),(10897,3294,'113766','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(10898,3294,'113766','watch-mobile','clear','none',0,''),(10900,3296,'113768','watch-mobile','block_type','1',0,''),(10902,3298,'113770','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(10903,3298,'113770','watch-mobile','clear','none',0,''),(10904,3299,'113771','watch-mobile','link','products',0,''),(10905,3299,'113771','watch-mobile','margin-top','-33',0,''),(10906,3299,'113771','watch-mobile','float','right',0,''),(10907,3301,'113773','watch-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(10908,3302,'113774','watch-mobile','block_type','1',0,''),(10909,3303,'113775','watch-mobile','margin-bottom','20',0,''),(10910,3304,'113776','watch-mobile','text-align','right',0,''),(10911,3304,'113776','watch-mobile','margin-bottom','20',0,''),(10912,3305,'113777','watch-mobile','block_type','2',0,''),(10913,3305,'113777','watch-mobile','margin-bottom','20',0,''),(10914,3305,'113777','watch-mobile','schema','2-2',0,''),(10915,3306,'113778','watch-mobile','block_type','1',0,''),(10916,3306,'113778','watch-mobile','padding-right','20',0,''),(10918,3307,'113779','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(10919,3307,'113779','watch-mobile','clear','none',0,''),(10920,3309,'113781','watch-mobile','block_type','1',0,''),(10921,3309,'113781','watch-mobile','padding-left','20',0,''),(10923,3310,'113782','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(10924,3310,'113782','watch-mobile','clear','none',0,''),(10925,3312,'113784','watch-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(10926,3313,'113785','watch-mobile','margin-bottom','20',0,''),(10927,3314,'113786','watch-mobile','margin-bottom','20',0,''),(10928,3314,'113786','watch-mobile','text-align','right',0,''),(10929,3315,'113787','watch-mobile','block_type','1',0,''),(10930,3316,'113788','watch-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(10931,3317,'113789','watch-mobile','margin-bottom','20',0,''),(10932,3317,'113789','watch-mobile','text-align','right',0,''),(10933,3320,'113792','watch-mobile','text-align','right',0,''),(10934,3320,'113792','watch-mobile','margin-bottom','20',0,''),(10935,3321,'113793','watch-mobile','block_type','2',0,''),(10936,3321,'113793','watch-mobile','margin-bottom','20',0,''),(10937,3321,'113793','watch-mobile','schema','2-2',0,''),(10938,3322,'113794','watch-mobile','block_type','1',0,''),(10939,3322,'113794','watch-mobile','padding-right','20',0,''),(10941,3324,'113796','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(10942,3324,'113796','watch-mobile','clear','none',0,''),(10943,3325,'113797','watch-mobile','block_type','1',0,''),(10944,3325,'113797','watch-mobile','padding-left','20',0,''),(10946,3326,'113798','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(10947,3326,'113798','watch-mobile','clear','none',0,''),(10948,3328,'113800','watch-mobile','block_type','1',0,''),(10949,3329,'113801','watch-mobile','block_type','2',0,''),(10950,3329,'113801','watch-mobile','margin-bottom','20',0,''),(10951,3329,'113801','watch-mobile','schema','2-2',0,''),(10952,3330,'113802','watch-mobile','block_type','1',0,''),(10953,3330,'113802','watch-mobile','padding-right','20',0,''),(10955,3332,'113804','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(10956,3332,'113804','watch-mobile','clear','none',0,''),(10957,3333,'113805','watch-mobile','padding-left','20',0,''),(10958,3333,'113805','watch-mobile','block_type','1',0,''),(10960,3334,'113806','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(10961,3334,'113806','watch-mobile','clear','none',0,''),(10962,3336,'113808','watch-mobile','text-align','right',0,''),(10963,3336,'113808','watch-mobile','margin-bottom','20',0,''),(10964,3337,'113809','watch-mobile','margin-bottom','20',0,''),(10965,3337,'113809','watch-mobile','text-align','right',0,''),(10966,3338,'113810','watch-mobile','link','products',0,''),(10967,3338,'113810','watch-mobile','margin-top','-33',0,''),(10968,3338,'113810','watch-mobile','float','right',0,''),(10969,3339,'113811','watch-mobile','margin-bottom','20',0,''),(10970,3340,'113812','watch-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(10971,3341,'113813','watch-mobile','margin-bottom','20',0,''),(10972,3342,'113814','watch-mobile','block_type','2',0,''),(10973,3342,'113814','watch-mobile','margin-bottom','20',0,''),(10974,3342,'113814','watch-mobile','schema','2-2',0,''),(10975,3343,'113815','watch-mobile','block_type','1',0,''),(10976,3343,'113815','watch-mobile','padding-right','20',0,''),(10978,3345,'113817','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(10979,3345,'113817','watch-mobile','clear','none',0,''),(10980,3346,'113818','watch-mobile','block_type','1',0,''),(10981,3346,'113818','watch-mobile','padding-left','20',0,''),(10983,3347,'113819','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(10984,3347,'113819','watch-mobile','clear','none',0,''),(10985,3349,'113821','watch-mobile','text','##TEXT_CONFIRMATION##',0,''),(10986,3350,'113822','watch-mobile','text','##TEXT_CONFIRMATION##',0,''),(10987,3351,'113823','watch-mobile','text','##TEXT_CONFIRMATION##',0,''),(10988,3352,'113824','watch-mobile','text','##TEXT_CONFIRMATION##',0,''),(10989,3353,'113825','watch-mobile','text','##TEXT_CONFIRMATION##',0,''),(10990,3354,'113826','watch-mobile','text','##TEXT_CONFIRMATION##',0,''),(10991,3355,'113827','watch-mobile','block_type','1',0,''),(10992,3356,'113828','watch-mobile','block_type','1',0,''),(10996,3359,'113831','watch-mobile','block_type','1',0,''),(10997,3359,'113831','watch-mobile','padding-right','0',0,''),(10999,3361,'113833','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(11000,3364,'113836','watch-mobile','block_type','1',0,''),(11001,3365,'113837','watch-mobile','block_type','1',0,''),(11003,3366,'113838','watch-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(11004,3368,'113840','watch-mobile','block_type','1',0,''),(11007,3369,'113841','watch-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11008,3371,'113843','watch-mobile','block_type','1',0,''),(11009,3371,'113843','watch-mobile','schema','4-2',0,''),(11010,3372,'113844','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11011,3372,'113844','watch-mobile','text-align','center',0,''),(11012,3372,'113844','watch-mobile','padding-top','10',0,''),(11013,3372,'113844','watch-mobile','font_size_measure','em',0,''),(11014,3372,'113844','watch-mobile','font-size','1.2',0,''),(11015,3373,'113845','watch-mobile','text-align','center',0,''),(11016,3374,'113846','watch-mobile','block_type','2',0,''),(11017,3375,'113847','watch-mobile','block_type','1',0,''),(11018,3375,'113847','watch-mobile','padding-right','20',0,''),(11020,3377,'113849','watch-mobile','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(11021,3378,'113850','watch-mobile','block_type','1',0,''),(11022,3378,'113850','watch-mobile','padding-right','0',0,''),(11023,3378,'113850','watch-mobile','padding-left','20',0,''),(11024,3379,'113851','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(11025,3383,'113855','watch-mobile','block_type','4',0,''),(11026,3383,'113855','watch-mobile','schema','4-2',0,''),(11027,3384,'113856','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11028,3384,'113856','watch-mobile','text-align','right',0,''),(11029,3384,'113856','watch-mobile','padding-top','10',0,''),(11030,3384,'113856','watch-mobile','font_size_measure','em',0,''),(11031,3384,'113856','watch-mobile','font-size','1.2',0,''),(11032,3385,'113857','watch-mobile','text-align','right',0,''),(11033,3386,'113858','watch-mobile','block_type','2',0,''),(11034,3387,'113859','watch-mobile','block_type','1',0,''),(11035,3387,'113859','watch-mobile','padding-right','20',0,''),(11036,3389,'113861','watch-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(11037,3390,'113862','watch-mobile','block_type','1',0,''),(11038,3390,'113862','watch-mobile','padding-left','20',0,''),(11040,3392,'113864','watch-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11041,3393,'113865','watch-mobile','block_type','4',0,''),(11042,3393,'113865','watch-mobile','schema','4-2',0,''),(11043,3394,'113866','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11044,3394,'113866','watch-mobile','text-align','right',0,''),(11045,3394,'113866','watch-mobile','padding-top','10',0,''),(11046,3394,'113866','watch-mobile','font_size_measure','em',0,''),(11047,3394,'113866','watch-mobile','font-size','1.2',0,''),(11048,3395,'113867','watch-mobile','text-align','right',0,''),(11049,3396,'113868','watch-mobile','block_type','2',0,''),(11050,3397,'113869','watch-mobile','block_type','1',0,''),(11051,3397,'113869','watch-mobile','padding-right','20',0,''),(11052,3399,'113871','watch-mobile','block_type','1',0,''),(11053,3399,'113871','watch-mobile','padding-left','20',0,''),(11055,3401,'113873','watch-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11056,3402,'113874','watch-mobile','block_type','2',0,''),(11057,3403,'113875','watch-mobile','block_type','1',0,''),(11058,3403,'113875','watch-mobile','padding-right','20',0,''),(11059,3405,'113877','watch-mobile','block_type','1',0,''),(11060,3405,'113877','watch-mobile','padding-left','20',0,''),(11062,3406,'113878','watch-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11063,3408,'113880','watch-mobile','block_type','4',0,''),(11064,3408,'113880','watch-mobile','schema','4-2',0,''),(11065,3409,'113881','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11066,3409,'113881','watch-mobile','text-align','right',0,''),(11067,3409,'113881','watch-mobile','padding-top','10',0,''),(11068,3409,'113881','watch-mobile','font_size_measure','em',0,''),(11069,3409,'113881','watch-mobile','font-size','1.2',0,''),(11070,3410,'113882','watch-mobile','text-align','right',0,''),(11071,3411,'113883','watch-mobile','text','##DELIVERY_DETAILS##',0,''),(11072,3412,'113884','watch-mobile','text','##DELIVERY_DETAILS##',0,''),(11073,3413,'113885','watch-mobile','text','##CONTACT_INFORMATION##',0,''),(11074,3414,'113886','watch-mobile','text','##CONTACT_INFORMATION##',0,''),(11075,3415,'113887','watch-mobile','text','##DELIVERY_DETAILS##',0,''),(11076,3416,'113888','watch-mobile','text','##DELIVERY_DETAILS##',0,''),(11077,3417,'113889','watch-mobile','block_type','1',0,''),(11078,3417,'113889','watch-mobile','background-color','$background-6',0,''),(11079,3417,'113889','watch-mobile','padding-top','30',0,''),(11080,3417,'113889','watch-mobile','padding-bottom','30',0,''),(11081,3418,'113890','watch-mobile','block_type','1',0,''),(11082,3418,'113890','watch-mobile','schema','4-2',0,''),(11083,3418,'113890','watch-mobile','schema','4-1',0,'299'),(11084,3419,'113891','watch-mobile','block_type','1',0,''),(11085,3419,'113891','watch-mobile','padding-right','40',0,''),(11087,3420,'113892','watch-mobile','background-color','$background-7',0,''),(11088,3420,'113892','watch-mobile','block_type','1',0,''),(11089,3420,'113892','watch-mobile','padding-top','30',0,''),(11090,3420,'113892','watch-mobile','padding-left','30',0,''),(11091,3420,'113892','watch-mobile','padding-right','30',0,''),(11092,3420,'113892','watch-mobile','padding-bottom','30',0,''),(11093,3420,'113892','watch-mobile','margin-bottom','20',0,''),(11094,3420,'113892','watch-mobile','style_class','hiding-box',0,''),(11095,3421,'113893','watch-mobile','background-color','$background-6',0,''),(11096,3421,'113893','watch-mobile','padding-top','10',0,''),(11097,3421,'113893','watch-mobile','padding-left','10',0,''),(11098,3421,'113893','watch-mobile','padding-right','10',0,''),(11099,3421,'113893','watch-mobile','padding-bottom','10',0,''),(11100,3421,'113893','watch-mobile','margin-top','10',0,''),(11101,3422,'113894','watch-mobile','block_type','1',0,''),(11102,3422,'113894','watch-mobile','schema','2-2',0,''),(11103,3422,'113894','watch-mobile','schema','2-1',0,'299'),(11104,3423,'113895','watch-mobile','block_type','1',0,''),(11105,3423,'113895','watch-mobile','padding-left','0',0,''),(11106,3423,'113895','watch-mobile','margin-bottom','20',0,''),(11107,3425,'113897','watch-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(11108,3427,'113899','watch-mobile','block_type','1',0,''),(11109,3427,'113899','watch-mobile','padding-left','20',0,''),(11111,3428,'113900','watch-mobile','border-top-width','1',0,''),(11112,3428,'113900','watch-mobile','border-top-color','$border-color-1',0,''),(11113,3428,'113900','watch-mobile','padding-top','13',0,''),(11114,3428,'113900','watch-mobile','padding-bottom','10',0,''),(11115,3429,'113901','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(11116,3430,'113902','watch-mobile','block_type','1',0,''),(11117,3430,'113902','watch-mobile','content','\\_',0,'3'),(11118,3430,'113902','watch-mobile','border-top-width','1',0,'3'),(11119,3430,'113902','watch-mobile','border-top-color','$border-color-1',0,'3'),(11120,3430,'113902','watch-mobile','display','block',0,'3'),(11121,3430,'113902','watch-mobile','position','absolute',0,'3'),(11122,3430,'113902','watch-mobile','top','19',0,'3'),(11123,3430,'113902','watch-mobile','left','0',0,'3'),(11124,3430,'113902','watch-mobile','right','0',0,'3'),(11125,3430,'113902','watch-mobile','margin-top','-2',0,'3'),(11126,3430,'113902','watch-mobile','position','relative',0,''),(11127,3431,'113903','watch-mobile','box_align','2',0,''),(11128,3431,'113903','watch-mobile','margin-bottom','10',0,''),(11129,3431,'113903','watch-mobile','background-color','$background-7',0,''),(11130,3431,'113903','watch-mobile','position','relative',0,''),(11131,3432,'113904','watch-mobile','block_type','1',0,''),(11132,3432,'113904','watch-mobile','background-color','$background-7',0,''),(11133,3432,'113904','watch-mobile','padding-top','30',0,''),(11134,3432,'113904','watch-mobile','padding-left','30',0,''),(11135,3432,'113904','watch-mobile','padding-right','30',0,''),(11136,3432,'113904','watch-mobile','padding-bottom','14',0,''),(11137,3432,'113904','watch-mobile','margin-bottom','20',0,''),(11138,3432,'113904','watch-mobile','style_class','hiding-box closeable-box',0,''),(11139,3433,'113905','watch-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(11140,3433,'113905','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(11141,3434,'113906','watch-mobile','style_class','closeable-content',0,''),(11142,3434,'113906','watch-mobile','padding-bottom','20',0,''),(11143,3435,'113908','watch-mobile','block_type','1',0,''),(11144,3435,'113908','watch-mobile','background-color','$background-7',0,''),(11145,3435,'113908','watch-mobile','padding-top','30',0,''),(11146,3435,'113908','watch-mobile','padding-left','30',0,''),(11147,3435,'113908','watch-mobile','padding-right','30',0,''),(11148,3435,'113908','watch-mobile','padding-bottom','30',0,''),(11149,3435,'113908','watch-mobile','margin-bottom','20',0,''),(11150,3435,'113908','watch-mobile','style_class','hiding-box',0,''),(11151,3436,'113909','watch-mobile','padding-top','10',0,''),(11152,3436,'113909','watch-mobile','padding-left','20',0,''),(11153,3436,'113909','watch-mobile','padding-right','20',0,''),(11154,3436,'113909','watch-mobile','margin-top','20',0,''),(11155,3436,'113909','watch-mobile','background-color','$background-6',0,''),(11156,3436,'113909','watch-mobile','padding-bottom','8',0,''),(11157,3437,'113910','watch-mobile','margin-bottom','20',0,''),(11158,3438,'113911','watch-mobile','block_type','1',0,''),(11159,3438,'113911','watch-mobile','padding-top','20',0,''),(11160,3438,'113911','watch-mobile','padding-left','20',0,''),(11161,3438,'113911','watch-mobile','padding-right','20',0,''),(11162,3438,'113911','watch-mobile','padding-bottom','20',0,''),(11163,3438,'113911','watch-mobile','background-color','$background-7',0,''),(11164,3438,'113911','watch-mobile','style_class','order-summary',0,''),(11165,3440,'113913','watch-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(11166,3440,'113913','watch-mobile','text-align','center',0,''),(11167,3440,'113913','watch-mobile','font-size','14',0,''),(11168,3440,'113913','watch-mobile','color','$color-font-8',0,''),(11169,3440,'113913','watch-mobile','padding-top','10',0,''),(11170,3441,'116002','watch-mobile','hide_continue_button','1',0,''),(11171,3442,'113914','watch-mobile','block_type','1',0,''),(11172,3442,'113914','watch-mobile','background-color','$background-6',0,''),(11173,3442,'113914','watch-mobile','padding-top','30',0,''),(11174,3442,'113914','watch-mobile','padding-bottom','30',0,''),(11175,3443,'113915','watch-mobile','block_type','4',0,''),(11176,3444,'113916','watch-mobile','block_type','1',0,''),(11177,3444,'113916','watch-mobile','padding-right','40',0,''),(11178,3445,'113917','watch-mobile','block_type','1',0,''),(11179,3445,'113917','watch-mobile','background-color','$background-7',0,''),(11180,3445,'113917','watch-mobile','padding-top','30',0,''),(11181,3445,'113917','watch-mobile','padding-left','30',0,''),(11182,3445,'113917','watch-mobile','padding-right','30',0,''),(11183,3445,'113917','watch-mobile','padding-bottom','14',0,''),(11184,3445,'113917','watch-mobile','margin-bottom','20',0,''),(11185,3445,'113917','watch-mobile','style_class','hiding-box closeable-box',0,''),(11186,3446,'113918','watch-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(11187,3446,'113918','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(11188,3447,'113919','watch-mobile','style_class','closeable-content',0,''),(11189,3447,'113919','watch-mobile','padding-bottom','20',0,''),(11190,3448,'113920','watch-mobile','block_type','1',0,''),(11191,3448,'113920','watch-mobile','padding-top','30',0,''),(11192,3448,'113920','watch-mobile','padding-left','30',0,''),(11193,3448,'113920','watch-mobile','padding-right','30',0,''),(11194,3448,'113920','watch-mobile','padding-bottom','14',0,''),(11195,3448,'113920','watch-mobile','margin-bottom','20',0,''),(11196,3448,'113920','watch-mobile','background-color','$background-7',0,''),(11197,3448,'113920','watch-mobile','style_class','hiding-box closeable-box',0,''),(11198,3449,'113921','watch-mobile','block_type','2',0,''),(11199,3449,'113921','watch-mobile','style_class','closeable-content',0,''),(11200,3450,'113922','watch-mobile','padding-right','20',0,''),(11201,3450,'113922','watch-mobile','padding-bottom','20',0,''),(11202,3451,'113923','watch-mobile','padding-left','20',0,''),(11203,3451,'113923','watch-mobile','padding-bottom','20',0,''),(11204,3452,'113924','watch-mobile','padding-left','20',0,''),(11205,3452,'113924','watch-mobile','padding-bottom','20',0,''),(11206,3453,'113925','watch-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(11207,3453,'113925','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(11208,3454,'113926','watch-mobile','block_type','1',0,''),(11209,3454,'113926','watch-mobile','padding-top','30',0,''),(11210,3454,'113926','watch-mobile','padding-left','30',0,''),(11211,3454,'113926','watch-mobile','padding-right','30',0,''),(11212,3454,'113926','watch-mobile','padding-bottom','23',0,''),(11213,3454,'113926','watch-mobile','margin-bottom','20',0,''),(11214,3454,'113926','watch-mobile','background-color','$background-7',0,''),(11215,3454,'113926','watch-mobile','style_class','hiding-box',0,''),(11216,3455,'113927','watch-mobile','block_type','2',0,''),(11217,3456,'113928','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11218,3457,'113929','watch-mobile','padding-right','20',0,''),(11219,3458,'113930','watch-mobile','block_type','1',0,''),(11220,3458,'113930','watch-mobile','padding-left','20',0,''),(11221,3459,'113931','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11222,3461,'113933','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(11223,3462,'113934','watch-mobile','block_type','1',0,''),(11224,3462,'113934','watch-mobile','background-color','$background-7',0,''),(11225,3462,'113934','watch-mobile','padding-top','30',0,''),(11226,3462,'113934','watch-mobile','padding-left','30',0,''),(11227,3462,'113934','watch-mobile','padding-right','30',0,''),(11228,3462,'113934','watch-mobile','padding-bottom','30',0,''),(11229,3462,'113934','watch-mobile','margin-bottom','20',0,''),(11230,3462,'113934','watch-mobile','style_class','hiding-box',0,''),(11231,3463,'113935','watch-mobile','margin-bottom','20',0,''),(11232,3464,'113936','watch-mobile','padding-top','10',0,''),(11233,3464,'113936','watch-mobile','padding-left','20',0,''),(11234,3464,'113936','watch-mobile','padding-right','20',0,''),(11235,3464,'113936','watch-mobile','margin-top','20',0,''),(11236,3464,'113936','watch-mobile','background-color','$background-6',0,''),(11237,3464,'113936','watch-mobile','padding-bottom','8',0,''),(11238,3465,'113937','watch-mobile','block_type','1',0,''),(11239,3465,'113937','watch-mobile','padding-top','20',0,''),(11240,3465,'113937','watch-mobile','padding-left','20',0,''),(11241,3465,'113937','watch-mobile','padding-right','20',0,''),(11242,3465,'113937','watch-mobile','padding-bottom','20',0,''),(11243,3465,'113937','watch-mobile','background-color','$background-7',0,''),(11244,3465,'113937','watch-mobile','style_class','order-summary hiding-box',0,''),(11245,3466,'113938','watch-mobile','hide_page','1',0,''),(11246,3466,'113938','watch-mobile','hide_continue_button','1',0,''),(11247,3468,'113940','watch-mobile','margin-bottom','10',0,''),(11248,3469,'113941','watch-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(11249,3469,'113941','watch-mobile','text-align','center',0,''),(11250,3469,'113941','watch-mobile','font-size','14',0,''),(11251,3469,'113941','watch-mobile','color','$color-font-8',0,''),(11252,3469,'113941','watch-mobile','padding-top','10',0,''),(11253,3470,'113942','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(11254,3471,'113943','watch-mobile','block_type','1',0,''),(11255,3472,'113944','watch-mobile','margin-bottom','20',0,''),(11256,3473,'113945','watch-mobile','block_type','2',0,''),(11257,3473,'113945','watch-mobile','schema','2-2',0,''),(11258,3474,'113946','watch-mobile','block_type','1',0,''),(11259,3474,'113946','watch-mobile','padding-right','20',0,''),(11261,3476,'113948','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11262,3477,'113949','watch-mobile','block_type','1',0,''),(11263,3477,'113949','watch-mobile','padding-left','20',0,''),(11265,3479,'113951','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11266,3483,'113955','watch-mobile','block_type','2',0,''),(11267,3483,'113955','watch-mobile','schema','2-2',0,''),(11268,3484,'113956','watch-mobile','block_type','1',0,''),(11269,3484,'113956','watch-mobile','padding-right','20',0,''),(11271,3485,'113957','watch-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(11272,3487,'113959','watch-mobile','block_type','1',0,''),(11273,3487,'113959','watch-mobile','padding-left','20',0,''),(11275,3488,'113960','watch-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11276,3490,'113962','watch-mobile','block_type','4',0,''),(11277,3490,'113962','watch-mobile','schema','4-2',0,''),(11278,3491,'113963','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11279,3491,'113963','watch-mobile','text-align','right',0,''),(11280,3491,'113963','watch-mobile','padding-top','10',0,''),(11281,3491,'113963','watch-mobile','font_size_measure','em',0,''),(11282,3491,'113963','watch-mobile','font-size','1.2',0,''),(11283,3492,'113964','watch-mobile','text-align','right',0,''),(11284,3494,'113966','watch-mobile','block_type','1',0,''),(11285,3494,'113966','watch-mobile','background-color','$background-6',0,''),(11286,3494,'113966','watch-mobile','padding-top','30',0,''),(11287,3494,'113966','watch-mobile','padding-bottom','30',0,''),(11288,3495,'113967','watch-mobile','block_type','4',0,''),(11289,3495,'113967','watch-mobile','schema','4-2',0,''),(11290,3496,'113968','watch-mobile','block_type','1',0,''),(11291,3496,'113968','watch-mobile','padding-right','40',0,''),(11293,3497,'113969','watch-mobile','block_type','1',0,''),(11294,3497,'113969','watch-mobile','padding-top','30',0,''),(11295,3497,'113969','watch-mobile','padding-left','30',0,''),(11296,3497,'113969','watch-mobile','padding-right','30',0,''),(11297,3497,'113969','watch-mobile','padding-bottom','23',0,''),(11298,3497,'113969','watch-mobile','margin-bottom','20',0,''),(11299,3497,'113969','watch-mobile','background-color','$background-7',0,''),(11300,3497,'113969','watch-mobile','style_class','hiding-box',0,''),(11301,3498,'113970','watch-mobile','block_type','2',0,''),(11302,3498,'113970','watch-mobile','schema','2-2',0,''),(11303,3499,'113971','watch-mobile','padding-right','20',0,''),(11305,3499,'113971','watch-mobile','padding-bottom','20',0,''),(11306,3500,'113972','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11307,3501,'113973','watch-mobile','block_type','1',0,''),(11308,3501,'113973','watch-mobile','padding-left','20',0,''),(11310,3502,'113974','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11311,3504,'113976','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(11312,3505,'113977','watch-mobile','block_type','1',0,''),(11313,3505,'113977','watch-mobile','background-color','$background-7',0,''),(11314,3505,'113977','watch-mobile','padding-top','30',0,''),(11315,3505,'113977','watch-mobile','padding-left','30',0,''),(11316,3505,'113977','watch-mobile','padding-right','30',0,''),(11317,3505,'113977','watch-mobile','padding-bottom','30',0,''),(11318,3505,'113977','watch-mobile','margin-bottom','20',0,''),(11319,3505,'113977','watch-mobile','style_class','hiding-box',0,''),(11320,3506,'113978','watch-mobile','padding-top','10',0,''),(11321,3506,'113978','watch-mobile','padding-left','20',0,''),(11322,3506,'113978','watch-mobile','padding-right','20',0,''),(11323,3506,'113978','watch-mobile','margin-top','20',0,''),(11324,3506,'113978','watch-mobile','background-color','$background-6',0,''),(11325,3506,'113978','watch-mobile','padding-bottom','8',0,''),(11326,3507,'113979','watch-mobile','margin-bottom','20',0,''),(11327,3508,'113980','watch-mobile','block_type','1',0,''),(11328,3508,'113980','watch-mobile','background-color','$background-7',0,''),(11329,3508,'113980','watch-mobile','padding-top','30',0,''),(11330,3508,'113980','watch-mobile','padding-left','30',0,''),(11331,3508,'113980','watch-mobile','padding-right','30',0,''),(11332,3508,'113980','watch-mobile','padding-bottom','14',0,''),(11333,3508,'113980','watch-mobile','margin-bottom','20',0,''),(11334,3508,'113980','watch-mobile','style_class','hiding-box closeable-box',0,''),(11335,3509,'113981','watch-mobile','style_class','closeable-content',0,''),(11336,3509,'113981','watch-mobile','padding-bottom','20',0,''),(11337,3510,'113982','watch-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(11338,3510,'113982','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(11339,3511,'113983','watch-mobile','background-color','$background-7',0,''),(11340,3511,'113983','watch-mobile','padding-top','30',0,''),(11341,3511,'113983','watch-mobile','padding-left','30',0,''),(11342,3511,'113983','watch-mobile','padding-right','30',0,''),(11343,3511,'113983','watch-mobile','padding-bottom','30',0,''),(11344,3511,'113983','watch-mobile','margin-bottom','20',0,''),(11345,3512,'113984','watch-mobile','block_type','1',0,''),(11346,3512,'113984','watch-mobile','padding-top','20',0,''),(11347,3512,'113984','watch-mobile','padding-left','20',0,''),(11348,3512,'113984','watch-mobile','padding-right','20',0,''),(11349,3512,'113984','watch-mobile','padding-bottom','20',0,''),(11350,3512,'113984','watch-mobile','background-color','$background-7',0,''),(11351,3512,'113984','watch-mobile','style_class','order-summary',0,''),(11352,3513,'113985','watch-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(11353,3513,'113985','watch-mobile','text-align','center',0,''),(11354,3513,'113985','watch-mobile','font-size','14',0,''),(11355,3513,'113985','watch-mobile','color','$color-font-8',0,''),(11356,3513,'113985','watch-mobile','padding-top','10',0,''),(11357,3514,'113986','watch-mobile','margin-bottom','10',0,''),(11358,3516,'113988','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(11359,3517,'113989','watch-mobile','block_type','1',0,''),(11360,3517,'113989','watch-mobile','schema','4-2',0,''),(11361,3518,'113990','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11362,3518,'113990','watch-mobile','text-align','center',0,''),(11363,3518,'113990','watch-mobile','padding-top','10',0,''),(11364,3518,'113990','watch-mobile','font_size_measure','em',0,''),(11365,3518,'113990','watch-mobile','font-size','1.2',0,''),(11366,3519,'113991','watch-mobile','text-align','center',0,''),(11367,3520,'113992','watch-mobile','block_type','1',0,''),(11368,3521,'113993','watch-mobile','block_type','1',0,''),(11369,3521,'113993','watch-mobile','padding-left','0',0,''),(11371,3523,'113995','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11372,3524,'113996','watch-mobile','block_type','1',0,''),(11375,3526,'113998','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11376,3530,'114002','watch-mobile','block_type','2',0,''),(11377,3531,'114003','watch-mobile','block_type','1',0,''),(11378,3531,'114003','watch-mobile','padding-left','0',0,''),(11379,3531,'114003','watch-mobile','padding-right','20',0,''),(11380,3532,'114004','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11381,3534,'114006','watch-mobile','block_type','1',0,''),(11382,3534,'114006','watch-mobile','padding-left','20',0,''),(11384,3536,'114008','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11385,3540,'114012','watch-mobile','block_type','4',0,''),(11386,3540,'114012','watch-mobile','schema','4-2',0,''),(11387,3541,'114013','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11388,3541,'114013','watch-mobile','text-align','right',0,''),(11389,3541,'114013','watch-mobile','padding-top','10',0,''),(11390,3541,'114013','watch-mobile','font_size_measure','em',0,''),(11391,3541,'114013','watch-mobile','font-size','1.2',0,''),(11392,3542,'114014','watch-mobile','text-align','right',0,''),(11393,3543,'114015','watch-mobile','block_type','2',0,''),(11394,3544,'114016','watch-mobile','block_type','1',0,''),(11395,3544,'114016','watch-mobile','padding-left','0',0,''),(11396,3544,'114016','watch-mobile','padding-right','20',0,''),(11397,3545,'114017','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11398,3547,'114019','watch-mobile','block_type','1',0,''),(11399,3547,'114019','watch-mobile','padding-left','20',0,''),(11401,3548,'114020','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11402,3553,'114025','watch-mobile','block_type','4',0,''),(11403,3553,'114025','watch-mobile','schema','4-2',0,''),(11404,3554,'114026','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11405,3554,'114026','watch-mobile','text-align','right',0,''),(11406,3554,'114026','watch-mobile','padding-top','10',0,''),(11407,3554,'114026','watch-mobile','font_size_measure','em',0,''),(11408,3554,'114026','watch-mobile','font-size','1.2',0,''),(11409,3555,'114027','watch-mobile','text-align','right',0,''),(11410,3556,'114028','watch-mobile','block_type','4',0,''),(11411,3556,'114028','watch-mobile','schema','4-2',0,''),(11412,3557,'114029','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11413,3557,'114029','watch-mobile','text-align','right',0,''),(11414,3557,'114029','watch-mobile','padding-top','10',0,''),(11415,3557,'114029','watch-mobile','font_size_measure','em',0,''),(11416,3557,'114029','watch-mobile','font-size','1.2',0,''),(11417,3558,'114030','watch-mobile','text-align','right',0,''),(11418,3559,'114031','watch-mobile','block_type','2',0,''),(11419,3560,'114032','watch-mobile','block_type','1',0,''),(11420,3560,'114032','watch-mobile','padding-left','0',0,''),(11421,3560,'114032','watch-mobile','padding-right','20',0,''),(11422,3562,'114034','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11423,3563,'114035','watch-mobile','block_type','1',0,''),(11424,3563,'114035','watch-mobile','padding-left','20',0,''),(11426,3565,'114037','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11427,3569,'114041','watch-mobile','text','##PAYMENT_DETAILS##',0,''),(11428,3570,'114042','watch-mobile','text','##PAYMENT_DETAILS##',0,''),(11429,3571,'114043','watch-mobile','text','##PAYMENT_DETAILS##',0,''),(11430,3572,'114044','watch-mobile','text','##PAYMENT_DETAILS##',0,''),(11431,3573,'114045','watch-mobile','text','##PAYMENT_DETAILS##',0,''),(11432,3574,'114046','watch-mobile','text','##PAYMENT_DETAILS##',0,''),(11433,3575,'114047','watch-mobile','block_type','1',0,''),(11434,3575,'114047','watch-mobile','background-color','$background-6',0,''),(11435,3575,'114047','watch-mobile','padding-top','30',0,''),(11436,3575,'114047','watch-mobile','padding-bottom','30',0,''),(11437,3576,'114048','watch-mobile','block_type','1',0,''),(11438,3576,'114048','watch-mobile','schema','4-2',0,''),(11439,3576,'114048','watch-mobile','schema','4-2',0,'299'),(11440,3577,'114049','watch-mobile','block_type','1',0,''),(11441,3577,'114049','watch-mobile','padding-right','40',0,''),(11443,3578,'114050','watch-mobile','block_type','1',0,''),(11444,3578,'114050','watch-mobile','padding-top','30',0,''),(11445,3578,'114050','watch-mobile','padding-left','30',0,''),(11446,3578,'114050','watch-mobile','padding-right','30',0,''),(11447,3578,'114050','watch-mobile','padding-bottom','23',0,''),(11448,3578,'114050','watch-mobile','margin-bottom','20',0,''),(11449,3578,'114050','watch-mobile','background-color','$background-7',0,''),(11450,3578,'114050','watch-mobile','style_class','hiding-box',0,''),(11451,3579,'114051','watch-mobile','block_type','1',0,''),(11452,3579,'114051','watch-mobile','schema','2-2',0,''),(11453,3580,'114052','watch-mobile','padding-right','20',0,''),(11455,3580,'114052','watch-mobile','padding-bottom','20',0,''),(11456,3581,'114053','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11457,3582,'114054','watch-mobile','block_type','1',0,''),(11458,3582,'114054','watch-mobile','padding-left','20',0,''),(11460,3583,'114055','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11461,3585,'114057','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(11462,3586,'114058','watch-mobile','block_type','1',0,''),(11463,3586,'114058','watch-mobile','background-color','$background-7',0,''),(11464,3586,'114058','watch-mobile','padding-top','30',0,''),(11465,3586,'114058','watch-mobile','padding-left','30',0,''),(11466,3586,'114058','watch-mobile','padding-right','30',0,''),(11467,3586,'114058','watch-mobile','padding-bottom','14',0,''),(11468,3586,'114058','watch-mobile','margin-bottom','20',0,''),(11469,3586,'114058','watch-mobile','style_class','hiding-box closeable-box',0,''),(11470,3587,'114059','watch-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(11471,3587,'114059','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(11472,3588,'114060','watch-mobile','style_class','closeable-content',0,''),(11473,3588,'114060','watch-mobile','padding-bottom','20',0,''),(11474,3589,'114062','watch-mobile','background-color','$background-7',0,''),(11475,3589,'114062','watch-mobile','block_type','1',0,''),(11476,3589,'114062','watch-mobile','padding-top','30',0,''),(11477,3589,'114062','watch-mobile','padding-left','30',0,''),(11478,3589,'114062','watch-mobile','padding-right','30',0,''),(11479,3589,'114062','watch-mobile','padding-bottom','30',0,''),(11480,3589,'114062','watch-mobile','margin-bottom','20',0,''),(11481,3589,'114062','watch-mobile','style_class','hiding-box',0,''),(11482,3590,'114063','watch-mobile','block_type','1',0,''),(11483,3590,'114063','watch-mobile','schema','2-2',0,''),(11484,3590,'114063','watch-mobile','schema','2-1',0,'299'),(11485,3591,'114064','watch-mobile','block_type','1',0,''),(11486,3591,'114064','watch-mobile','padding-left','0',0,''),(11487,3591,'114064','watch-mobile','margin-bottom','20',0,''),(11488,3592,'114065','watch-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(11489,3595,'114068','watch-mobile','block_type','1',0,''),(11490,3595,'114068','watch-mobile','padding-left','20',0,''),(11492,3596,'114069','watch-mobile','border-top-width','1',0,''),(11493,3596,'114069','watch-mobile','border-top-color','$border-color-1',0,''),(11494,3596,'114069','watch-mobile','padding-top','13',0,''),(11495,3596,'114069','watch-mobile','padding-bottom','10',0,''),(11496,3597,'114070','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(11497,3599,'114072','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(11498,3600,'114073','watch-mobile','background-color','$background-6',0,''),(11499,3600,'114073','watch-mobile','padding-top','10',0,''),(11500,3600,'114073','watch-mobile','padding-left','10',0,''),(11501,3600,'114073','watch-mobile','padding-right','10',0,''),(11502,3600,'114073','watch-mobile','padding-bottom','10',0,''),(11503,3600,'114073','watch-mobile','margin-top','10',0,''),(11504,3601,'114074','watch-mobile','block_type','1',0,''),(11505,3601,'114074','watch-mobile','content','\\_',0,'3'),(11506,3601,'114074','watch-mobile','border-top-width','1',0,'3'),(11507,3601,'114074','watch-mobile','border-top-color','$border-color-1',0,'3'),(11508,3601,'114074','watch-mobile','display','block',0,'3'),(11509,3601,'114074','watch-mobile','position','absolute',0,'3'),(11510,3601,'114074','watch-mobile','top','19',0,'3'),(11511,3601,'114074','watch-mobile','left','0',0,'3'),(11512,3601,'114074','watch-mobile','right','0',0,'3'),(11513,3601,'114074','watch-mobile','margin-top','-2',0,'3'),(11514,3601,'114074','watch-mobile','position','relative',0,''),(11515,3602,'114075','watch-mobile','box_align','2',0,''),(11516,3602,'114075','watch-mobile','margin-bottom','10',0,''),(11517,3602,'114075','watch-mobile','background-color','$background-7',0,''),(11518,3602,'114075','watch-mobile','position','relative',0,''),(11519,3603,'114076','watch-mobile','block_type','1',0,''),(11520,3603,'114076','watch-mobile','background-color','$background-7',0,''),(11521,3603,'114076','watch-mobile','padding-top','30',0,''),(11522,3603,'114076','watch-mobile','padding-left','30',0,''),(11523,3603,'114076','watch-mobile','padding-right','30',0,''),(11524,3603,'114076','watch-mobile','padding-bottom','30',0,''),(11525,3603,'114076','watch-mobile','margin-bottom','20',0,''),(11526,3603,'114076','watch-mobile','style_class','hiding-box',0,''),(11527,3604,'114077','watch-mobile','margin-bottom','20',0,''),(11528,3605,'114078','watch-mobile','padding-top','10',0,''),(11529,3605,'114078','watch-mobile','padding-left','20',0,''),(11530,3605,'114078','watch-mobile','padding-right','20',0,''),(11531,3605,'114078','watch-mobile','margin-top','20',0,''),(11532,3605,'114078','watch-mobile','background-color','$background-6',0,''),(11533,3605,'114078','watch-mobile','padding-bottom','8',0,''),(11534,3606,'114079','watch-mobile','block_type','1',0,''),(11535,3606,'114079','watch-mobile','padding-top','20',0,''),(11536,3606,'114079','watch-mobile','padding-left','20',0,''),(11537,3606,'114079','watch-mobile','padding-right','20',0,''),(11538,3606,'114079','watch-mobile','padding-bottom','20',0,''),(11539,3606,'114079','watch-mobile','background-color','$background-7',0,''),(11540,3606,'114079','watch-mobile','style_class','order-summary',0,''),(11541,3608,'114081','watch-mobile','margin-bottom','10',0,''),(11542,3609,'114082','watch-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(11543,3609,'114082','watch-mobile','text-align','center',0,''),(11544,3609,'114082','watch-mobile','font-size','14',0,''),(11545,3609,'114082','watch-mobile','color','$color-font-8',0,''),(11546,3609,'114082','watch-mobile','padding-top','10',0,''),(11547,3610,'114083','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(11548,3611,'116000','watch-mobile','hide_continue_button','1',0,''),(11549,3612,'114084','watch-mobile','block_type','1',0,''),(11550,3612,'114084','watch-mobile','padding-top','30',0,''),(11551,3612,'114084','watch-mobile','padding-bottom','30',0,''),(11552,3612,'114084','watch-mobile','background-color','$background-6',0,''),(11553,3613,'114085','watch-mobile','block_type','1',0,''),(11554,3613,'114085','watch-mobile','schema','4-2',0,''),(11555,3613,'114085','watch-mobile','schema','4-1',0,'299'),(11556,3614,'114086','watch-mobile','block_type','1',0,''),(11557,3614,'114086','watch-mobile','padding-right','40',0,''),(11559,3615,'114093','watch-mobile','block_type','1',0,''),(11560,3615,'114093','watch-mobile','padding-top','30',0,''),(11561,3615,'114093','watch-mobile','padding-left','30',0,''),(11562,3615,'114093','watch-mobile','padding-right','30',0,''),(11563,3615,'114093','watch-mobile','padding-bottom','23',0,''),(11564,3615,'114093','watch-mobile','margin-bottom','20',0,''),(11565,3615,'114093','watch-mobile','background-color','$background-7',0,''),(11566,3615,'114093','watch-mobile','style_class','hiding-box',0,''),(11567,3616,'114094','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(11568,3617,'114095','watch-mobile','block_type','1',0,''),(11569,3617,'114095','watch-mobile','schema','2-2',0,''),(11570,3618,'114096','watch-mobile','padding-right','20',0,''),(11572,3618,'114096','watch-mobile','padding-bottom','20',0,''),(11573,3619,'114097','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11574,3620,'114098','watch-mobile','block_type','1',0,''),(11575,3620,'114098','watch-mobile','padding-left','20',0,''),(11577,3622,'114100','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11578,3623,'114101','watch-mobile','block_type','1',0,''),(11579,3623,'114101','watch-mobile','background-color','$background-7',0,''),(11580,3623,'114101','watch-mobile','padding-top','30',0,''),(11581,3623,'114101','watch-mobile','padding-left','30',0,''),(11582,3623,'114101','watch-mobile','padding-right','30',0,''),(11583,3623,'114101','watch-mobile','padding-bottom','14',0,''),(11584,3623,'114101','watch-mobile','margin-bottom','20',0,''),(11585,3623,'114101','watch-mobile','style_class','hiding-box closeable-box',0,''),(11586,3624,'114102','watch-mobile','style_class','closeable-content',0,''),(11587,3624,'114102','watch-mobile','padding-bottom','20',0,''),(11588,3625,'114103','watch-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(11589,3625,'114103','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(11590,3626,'114104','watch-mobile','background-color','$background-7',0,''),(11591,3626,'114104','watch-mobile','block_type','1',0,''),(11592,3626,'114104','watch-mobile','padding-top','30',0,''),(11593,3626,'114104','watch-mobile','padding-left','30',0,''),(11594,3626,'114104','watch-mobile','padding-right','30',0,''),(11595,3626,'114104','watch-mobile','padding-bottom','30',0,''),(11596,3626,'114104','watch-mobile','margin-bottom','20',0,''),(11597,3626,'114104','watch-mobile','style_class','hiding-box',0,''),(11598,3627,'114105','watch-mobile','block_type','1',0,''),(11599,3627,'114105','watch-mobile','content','\\_',0,'3'),(11600,3627,'114105','watch-mobile','border-top-width','1',0,'3'),(11601,3627,'114105','watch-mobile','border-top-color','$border-color-1',0,'3'),(11602,3627,'114105','watch-mobile','display','block',0,'3'),(11603,3627,'114105','watch-mobile','position','absolute',0,'3'),(11604,3627,'114105','watch-mobile','top','19',0,'3'),(11605,3627,'114105','watch-mobile','left','0',0,'3'),(11606,3627,'114105','watch-mobile','right','0',0,'3'),(11607,3627,'114105','watch-mobile','margin-top','-2',0,'3'),(11608,3627,'114105','watch-mobile','position','relative',0,''),(11609,3628,'114106','watch-mobile','box_align','2',0,''),(11610,3628,'114106','watch-mobile','margin-bottom','10',0,''),(11611,3628,'114106','watch-mobile','background-color','$background-7',0,''),(11612,3628,'114106','watch-mobile','position','relative',0,''),(11613,3629,'114107','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(11614,3630,'114108','watch-mobile','block_type','2',0,''),(11615,3630,'114108','watch-mobile','schema','2-2',0,''),(11616,3630,'114108','watch-mobile','schema','2-2',0,'299'),(11617,3631,'114109','watch-mobile','block_type','1',0,''),(11618,3631,'114109','watch-mobile','padding-left','0',0,''),(11619,3631,'114109','watch-mobile','margin-bottom','20',0,''),(11620,3633,'114111','watch-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(11621,3635,'114113','watch-mobile','block_type','1',0,''),(11622,3635,'114113','watch-mobile','padding-left','20',0,''),(11624,3636,'114114','watch-mobile','border-top-width','1',0,''),(11625,3636,'114114','watch-mobile','border-top-color','$border-color-1',0,''),(11626,3636,'114114','watch-mobile','padding-top','13',0,''),(11627,3636,'114114','watch-mobile','padding-bottom','10',0,''),(11628,3637,'114115','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(11629,3639,'114117','watch-mobile','background-color','$background-6',0,''),(11630,3639,'114117','watch-mobile','padding-top','10',0,''),(11631,3639,'114117','watch-mobile','padding-left','10',0,''),(11632,3639,'114117','watch-mobile','padding-right','10',0,''),(11633,3639,'114117','watch-mobile','padding-bottom','10',0,''),(11634,3639,'114117','watch-mobile','margin-top','10',0,''),(11635,3640,'114118','watch-mobile','block_type','1',0,''),(11636,3640,'114118','watch-mobile','background-color','$background-7',0,''),(11637,3640,'114118','watch-mobile','padding-top','30',0,''),(11638,3640,'114118','watch-mobile','padding-left','30',0,''),(11639,3640,'114118','watch-mobile','padding-right','30',0,''),(11640,3640,'114118','watch-mobile','padding-bottom','30',0,''),(11641,3640,'114118','watch-mobile','margin-bottom','20',0,''),(11642,3640,'114118','watch-mobile','style_class','hiding-box',0,''),(11643,3641,'114119','watch-mobile','padding-top','10',0,''),(11644,3641,'114119','watch-mobile','padding-left','20',0,''),(11645,3641,'114119','watch-mobile','padding-right','20',0,''),(11646,3641,'114119','watch-mobile','margin-top','20',0,''),(11647,3641,'114119','watch-mobile','background-color','$background-6',0,''),(11648,3641,'114119','watch-mobile','padding-bottom','8',0,''),(11649,3642,'114120','watch-mobile','margin-bottom','20',0,''),(11650,3643,'114122','watch-mobile','block_type','1',0,''),(11651,3643,'114122','watch-mobile','padding-top','20',0,''),(11652,3643,'114122','watch-mobile','padding-left','20',0,''),(11653,3643,'114122','watch-mobile','padding-right','20',0,''),(11654,3643,'114122','watch-mobile','padding-bottom','20',0,''),(11655,3643,'114122','watch-mobile','background-color','$background-7',0,''),(11656,3643,'114122','watch-mobile','style_class','order-summary',0,''),(11657,3644,'114123','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(11658,3646,'114125','watch-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(11659,3646,'114125','watch-mobile','text-align','center',0,''),(11660,3646,'114125','watch-mobile','font-size','14',0,''),(11661,3646,'114125','watch-mobile','color','$color-font-8',0,''),(11662,3646,'114125','watch-mobile','padding-top','10',0,''),(11663,3647,'114126','watch-mobile','margin-bottom','10',0,''),(11664,3648,'116001','watch-mobile','hide_continue_button','1',0,''),(11665,3651,'114129','watch-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(11666,3654,'114132','watch-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(11667,3655,'114133','watch-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(11668,3658,'114136','watch-mobile','style_class','order-summary',0,''),(11669,3658,'114136','watch-mobile','box_align','3',0,''),(11670,3658,'114136','watch-mobile','width','400',0,''),(11671,3659,'114137','watch-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(11672,3661,'114139','watch-mobile','block_type','1',0,''),(11673,3662,'114140','watch-mobile','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(11674,3663,'114141','watch-mobile','margin-bottom','30',0,''),(11675,3664,'114142','watch-mobile','float','right',0,''),(11676,3664,'114142','watch-mobile','position','relative',0,''),(11677,3664,'114142','watch-mobile','z-index','1',0,''),(11678,3664,'114142','watch-mobile','top','30',0,''),(11679,3664,'114142','watch-mobile','margin-bottom','-20',0,''),(11680,3665,'114143','watch-mobile','block_type','1',0,''),(11681,3666,'114144','watch-mobile','listing_type','Compare Products',0,''),(11682,3667,'114145','watch-mobile','block_type','1',0,''),(11683,3667,'114145','watch-mobile','style_class','item-holder',0,''),(11684,3667,'114145','watch-mobile','padding-top','10',0,''),(11685,3667,'114145','watch-mobile','padding-left','20',0,''),(11686,3667,'114145','watch-mobile','padding-right','20',0,''),(11687,3667,'114145','watch-mobile','padding-bottom','10',0,''),(11688,3667,'114145','watch-mobile','text-align','left',0,''),(11689,3670,'114148','watch-mobile','margin-bottom','10',0,''),(11690,3671,'114149','watch-mobile','block_type','5',0,''),(11691,3673,'114151','watch-mobile','clear','both',0,''),(11692,3674,'114152','watch-mobile','block_type','2',0,''),(11693,3675,'114153','watch-mobile','margin-bottom','7',0,''),(11694,3676,'114154','watch-mobile','text-align','right',0,''),(11695,3676,'114154','watch-mobile','margin-bottom','10',0,''),(11696,3676,'114154','watch-mobile','float','right',0,''),(11697,3677,'114155','watch-mobile','block_type','1',0,''),(11698,3677,'114155','watch-mobile','background-color','$background-6',0,''),(11699,3677,'114155','watch-mobile','padding-bottom','30',0,''),(11700,3678,'114156','watch-mobile','block_type','1',0,''),(11701,3678,'114156','watch-mobile','schema','4-2',0,''),(11702,3678,'114156','watch-mobile','schema','4-2',0,'299'),(11703,3680,'114158','watch-mobile','block_type','1',0,''),(11706,3681,'114159','watch-mobile','block_type','1',0,''),(11707,3681,'114159','watch-mobile','margin-bottom','20',0,''),(11708,3681,'114159','watch-mobile','schema','2-2',0,''),(11709,3681,'114159','watch-mobile','background-color','$background-7',0,''),(11710,3682,'114160','watch-mobile','block_type','1',0,''),(11715,3682,'114160','watch-mobile','padding-top','20',0,''),(11717,3682,'114160','watch-mobile','padding-bottom','20',0,''),(11720,3682,'114160','watch-mobile','margin-bottom','20',0,''),(11723,3683,'114161','watch-mobile','margin-bottom','20',0,''),(11724,3684,'114162','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(11725,3685,'114163','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(11726,3685,'114163','watch-mobile','clear','none',0,''),(11727,3687,'114165','watch-mobile','link','shipping_address',0,''),(11728,3687,'114165','watch-mobile','float','right',0,''),(11729,3687,'114165','watch-mobile','margin-top','-31',0,''),(11730,3688,'114166','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(11731,3688,'114166','watch-mobile','clear','none',0,''),(11732,3690,'114168','watch-mobile','link','contact_information',0,''),(11733,3690,'114168','watch-mobile','margin-top','-31',0,''),(11734,3690,'114168','watch-mobile','float','right',0,''),(11735,3691,'114169','watch-mobile','link','shipping_method',0,''),(11736,3691,'114169','watch-mobile','float','right',0,''),(11737,3691,'114169','watch-mobile','margin-top','-31',0,''),(11738,3692,'114170','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(11739,3692,'114170','watch-mobile','padding-top','20',0,''),(11740,3694,'114172','watch-mobile','block_type','1',0,''),(11741,3694,'114172','watch-mobile','padding-left','30',0,''),(11744,3694,'114172','watch-mobile','margin-left','-10',0,''),(11745,3694,'114172','watch-mobile','padding-right','30',0,''),(11746,3694,'114172','watch-mobile','padding-top','20',0,''),(11747,3694,'114172','watch-mobile','padding-bottom','20',0,''),(11749,3695,'114173','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11750,3695,'114173','watch-mobile','clear','none',0,''),(11751,3696,'114174','watch-mobile','margin-bottom','20',0,''),(11752,3697,'114175','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11753,3697,'114175','watch-mobile','clear','none',0,''),(11754,3699,'114177','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(11755,3700,'114178','watch-mobile','link','billing_address',0,''),(11756,3700,'114178','watch-mobile','float','right',0,''),(11757,3700,'114178','watch-mobile','margin-top','-31',0,''),(11758,3701,'114179','watch-mobile','link','payment_method',0,''),(11759,3701,'114179','watch-mobile','float','right',0,''),(11760,3701,'114179','watch-mobile','margin-top','-31',0,''),(11761,3702,'114180','watch-mobile','block_type','1',0,''),(11762,3702,'114180','watch-mobile','padding-right','30',0,''),(11763,3702,'114180','watch-mobile','background-color','$background-7',0,''),(11764,3702,'114180','watch-mobile','padding-top','20',0,''),(11765,3702,'114180','watch-mobile','padding-left','30',0,''),(11766,3702,'114180','watch-mobile','padding-bottom','20',0,''),(11769,3703,'114181','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(11770,3704,'114182','watch-mobile','link','products',0,''),(11771,3704,'114182','watch-mobile','float','right',0,''),(11772,3704,'114182','watch-mobile','margin-top','-37',0,''),(11773,3706,'114184','watch-mobile','block_type','1',0,''),(11774,3706,'114184','watch-mobile','background-color','$background-7',0,''),(11775,3706,'114184','watch-mobile','padding-top','20',0,''),(11776,3706,'114184','watch-mobile','padding-bottom','20',0,''),(11777,3706,'114184','watch-mobile','padding-left','30',0,''),(11778,3706,'114184','watch-mobile','padding-right','30',0,''),(11779,3706,'114184','watch-mobile','margin-bottom','20',0,''),(11780,3707,'114185','watch-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11781,3708,'114186','watch-mobile','hide_parents','2',0,''),(11782,3709,'114187','watch-mobile','float','right',0,''),(11783,3709,'114187','watch-mobile','margin-top','-37',0,''),(11784,3709,'114187','watch-mobile','link','comments',0,''),(11785,3710,'114188','watch-mobile','block_type','1',0,''),(11786,3710,'114188','watch-mobile','padding-top','20',0,''),(11787,3710,'114188','watch-mobile','padding-left','20',0,''),(11788,3710,'114188','watch-mobile','padding-right','20',0,''),(11789,3710,'114188','watch-mobile','padding-bottom','20',0,''),(11790,3710,'114188','watch-mobile','background-color','$background-7',0,''),(11791,3710,'114188','watch-mobile','style_class','order-summary2 hiding-box',0,''),(11792,3712,'114190','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(11793,3713,'114191','watch-mobile','margin-bottom','20',0,''),(11794,3713,'114191','watch-mobile','text-align','center',0,''),(11795,3714,'114192','watch-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(11796,3715,'114193','watch-mobile','block_type','1',0,''),(11797,3715,'114193','watch-mobile','background-color','$background-6',0,''),(11798,3715,'114193','watch-mobile','padding-bottom','30',0,''),(11799,3716,'114194','watch-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(11800,3717,'114195','watch-mobile','block_type','1',0,''),(11801,3717,'114195','watch-mobile','schema','4-2',0,''),(11802,3717,'114195','watch-mobile','schema','4-1',0,'299'),(11803,3718,'114196','watch-mobile','block_type','1',0,''),(11804,3718,'114196','watch-mobile','padding-right','40',0,''),(11806,3719,'114197','watch-mobile','block_type','1',0,''),(11807,3719,'114197','watch-mobile','margin-bottom','20',0,''),(11808,3719,'114197','watch-mobile','schema','2-2',0,''),(11809,3719,'114197','watch-mobile','background-color','$background-7',0,''),(11810,3720,'114198','watch-mobile','block_type','1',0,''),(11811,3720,'114198','watch-mobile','border-right-width','20',0,''),(11812,3720,'114198','watch-mobile','border-right-color','$border-color-1',0,''),(11813,3720,'114198','watch-mobile','margin-right','-10',0,''),(11814,3720,'114198','watch-mobile','padding-right','30',0,''),(11815,3720,'114198','watch-mobile','padding-top','20',0,''),(11816,3720,'114198','watch-mobile','padding-left','30',0,''),(11817,3720,'114198','watch-mobile','padding-bottom','20',0,''),(11820,3720,'114198','watch-mobile','margin-bottom','20',0,''),(11823,3721,'114199','watch-mobile','link','shipping_method',0,''),(11824,3721,'114199','watch-mobile','float','right',0,''),(11825,3721,'114199','watch-mobile','margin-top','-31',0,''),(11826,3722,'114200','watch-mobile','margin-bottom','20',0,''),(11827,3723,'114201','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(11828,3723,'114201','watch-mobile','clear','none',0,''),(11829,3725,'114203','watch-mobile','link','shipping_address',0,''),(11830,3725,'114203','watch-mobile','float','right',0,''),(11831,3725,'114203','watch-mobile','margin-top','-31',0,''),(11832,3726,'114204','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(11833,3726,'114204','watch-mobile','clear','none',0,''),(11834,3727,'114205','watch-mobile','block_type','1',0,''),(11835,3727,'114205','watch-mobile','padding-left','30',0,''),(11836,3727,'114205','watch-mobile','border-left-width','20',0,''),(11837,3727,'114205','watch-mobile','border-left-color','$border-color-1',0,''),(11838,3727,'114205','watch-mobile','margin-left','-10',0,''),(11839,3727,'114205','watch-mobile','padding-right','30',0,''),(11840,3727,'114205','watch-mobile','padding-top','20',0,''),(11841,3727,'114205','watch-mobile','padding-bottom','20',0,''),(11843,3728,'114206','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(11844,3729,'114207','watch-mobile','link','contact_information',0,''),(11845,3729,'114207','watch-mobile','margin-top','-31',0,''),(11846,3729,'114207','watch-mobile','float','right',0,''),(11847,3732,'114210','watch-mobile','block_type','1',0,''),(11848,3732,'114210','watch-mobile','background-color','$background-7',0,''),(11849,3732,'114210','watch-mobile','padding-top','20',0,''),(11850,3732,'114210','watch-mobile','padding-bottom','20',0,''),(11851,3732,'114210','watch-mobile','padding-left','30',0,''),(11852,3732,'114210','watch-mobile','padding-right','30',0,''),(11853,3732,'114210','watch-mobile','margin-bottom','20',0,''),(11854,3733,'114211','watch-mobile','hide_parents','2',0,''),(11855,3734,'114212','watch-mobile','float','right',0,''),(11856,3734,'114212','watch-mobile','margin-top','-37',0,''),(11857,3734,'114212','watch-mobile','link','comments',0,''),(11858,3735,'114213','watch-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11859,3736,'114214','watch-mobile','block_type','1',0,''),(11860,3736,'114214','watch-mobile','padding-right','30',0,''),(11861,3736,'114214','watch-mobile','background-color','$background-7',0,''),(11862,3736,'114214','watch-mobile','padding-top','20',0,''),(11863,3736,'114214','watch-mobile','padding-left','30',0,''),(11864,3736,'114214','watch-mobile','padding-bottom','20',0,''),(11867,3738,'114216','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(11868,3739,'114217','watch-mobile','link','products',0,''),(11869,3739,'114217','watch-mobile','float','right',0,''),(11870,3739,'114217','watch-mobile','margin-top','-37',0,''),(11871,3740,'114218','watch-mobile','block_type','1',0,''),(11872,3740,'114218','watch-mobile','padding-top','20',0,''),(11873,3740,'114218','watch-mobile','padding-left','20',0,''),(11874,3740,'114218','watch-mobile','padding-right','20',0,''),(11875,3740,'114218','watch-mobile','padding-bottom','20',0,''),(11876,3740,'114218','watch-mobile','background-color','$background-7',0,''),(11877,3740,'114218','watch-mobile','style_class','order-summary',0,''),(11878,3741,'114219','watch-mobile','margin-bottom','20',0,''),(11879,3741,'114219','watch-mobile','text-align','right',0,''),(11880,3742,'114220','watch-mobile','block_type','1',0,''),(11881,3742,'114220','watch-mobile','background-color','$background-6',0,''),(11882,3742,'114220','watch-mobile','padding-bottom','30',0,''),(11883,3743,'114221','watch-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(11884,3744,'114222','watch-mobile','block_type','4',0,''),(11885,3745,'114223','watch-mobile','block_type','1',0,''),(11886,3745,'114223','watch-mobile','padding-right','40',0,''),(11887,3746,'114224','watch-mobile','block_type','1',0,''),(11888,3746,'114224','watch-mobile','padding-right','30',0,''),(11890,3746,'114224','watch-mobile','background-color','$background-7',0,''),(11891,3746,'114224','watch-mobile','padding-top','20',0,''),(11892,3746,'114224','watch-mobile','padding-left','30',0,''),(11893,3746,'114224','watch-mobile','padding-bottom','20',0,''),(11894,3747,'114225','watch-mobile','link','products',0,''),(11895,3747,'114225','watch-mobile','float','right',0,''),(11896,3747,'114225','watch-mobile','margin-top','-37',0,''),(11897,3748,'114226','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(11898,3750,'114228','watch-mobile','block_type','1',0,''),(11899,3750,'114228','watch-mobile','background-color','$background-7',0,''),(11900,3750,'114228','watch-mobile','padding-top','20',0,''),(11901,3750,'114228','watch-mobile','padding-bottom','20',0,''),(11902,3750,'114228','watch-mobile','padding-left','30',0,''),(11903,3750,'114228','watch-mobile','padding-right','30',0,''),(11904,3750,'114228','watch-mobile','margin-bottom','20',0,''),(11905,3751,'114229','watch-mobile','float','right',0,''),(11906,3751,'114229','watch-mobile','margin-top','-37',0,''),(11907,3751,'114229','watch-mobile','link','comments',0,''),(11908,3752,'114230','watch-mobile','hide_parents','2',0,''),(11909,3753,'114231','watch-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11910,3754,'114232','watch-mobile','block_type','2',0,''),(11911,3754,'114232','watch-mobile','margin-bottom','20',0,''),(11912,3754,'114232','watch-mobile','schema','2-2',0,''),(11913,3754,'114232','watch-mobile','background-color','$background-7',0,''),(11914,3755,'114233','watch-mobile','block_type','1',0,''),(11915,3755,'114233','watch-mobile','padding-right','0',0,''),(11916,3755,'114233','watch-mobile','border-right-width','20',0,''),(11917,3755,'114233','watch-mobile','border-right-color','$border-color-1',0,''),(11918,3755,'114233','watch-mobile','margin-right','-10',0,''),(11920,3755,'114233','watch-mobile','padding-top','20',0,''),(11921,3755,'114233','watch-mobile','padding-left','30',0,''),(11922,3755,'114233','watch-mobile','padding-bottom','20',0,''),(11923,3756,'114234','watch-mobile','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(11924,3756,'114234','watch-mobile','padding-top','20',0,''),(11925,3758,'114236','watch-mobile','link','contact_information',0,''),(11926,3758,'114236','watch-mobile','margin-top','-37',0,''),(11927,3758,'114236','watch-mobile','float','right',0,''),(11928,3759,'114237','watch-mobile','block_type','1',0,''),(11929,3759,'114237','watch-mobile','padding-left','30',0,''),(11931,3759,'114237','watch-mobile','border-left-width','20',0,''),(11932,3759,'114237','watch-mobile','border-left-color','$border-color-1',0,''),(11933,3759,'114237','watch-mobile','margin-left','-10',0,''),(11934,3759,'114237','watch-mobile','padding-right','30',0,''),(11935,3759,'114237','watch-mobile','padding-top','20',0,''),(11936,3759,'114237','watch-mobile','padding-bottom','20',0,''),(11937,3760,'114238','watch-mobile','link','billing_address',0,''),(11938,3760,'114238','watch-mobile','float','right',0,''),(11939,3760,'114238','watch-mobile','margin-top','-31',0,''),(11940,3761,'114239','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11941,3761,'114239','watch-mobile','clear','none',0,''),(11942,3762,'114240','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(11943,3763,'114241','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11944,3763,'114241','watch-mobile','clear','none',0,''),(11945,3764,'114242','watch-mobile','margin-bottom','20',0,''),(11946,3766,'114244','watch-mobile','link','payment_method',0,''),(11947,3766,'114244','watch-mobile','float','right',0,''),(11948,3766,'114244','watch-mobile','margin-top','-31',0,''),(11949,3767,'114245','watch-mobile','block_type','1',0,''),(11950,3767,'114245','watch-mobile','padding-top','20',0,''),(11951,3767,'114245','watch-mobile','padding-left','20',0,''),(11952,3767,'114245','watch-mobile','padding-right','20',0,''),(11953,3767,'114245','watch-mobile','padding-bottom','20',0,''),(11954,3767,'114245','watch-mobile','background-color','$background-7',0,''),(11955,3767,'114245','watch-mobile','style_class','order-summary2 hiding-box',0,''),(11956,3768,'114246','watch-mobile','margin-bottom','20',0,''),(11957,3768,'114246','watch-mobile','text-align','right',0,''),(11958,3770,'114248','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(11959,3771,'114249','watch-mobile','block_type','1',0,''),(11960,3771,'114249','watch-mobile','background-color','$background-6',0,''),(11961,3771,'114249','watch-mobile','padding-bottom','30',0,''),(11962,3772,'114250','watch-mobile','block_type','4',0,''),(11963,3772,'114250','watch-mobile','schema','4-2',0,''),(11964,3773,'114251','watch-mobile','block_type','1',0,''),(11965,3773,'114251','watch-mobile','padding-right','40',0,''),(11967,3774,'114252','watch-mobile','block_type','1',0,''),(11968,3774,'114252','watch-mobile','padding-right','30',0,''),(11969,3774,'114252','watch-mobile','background-color','$background-7',0,''),(11970,3774,'114252','watch-mobile','padding-top','20',0,''),(11971,3774,'114252','watch-mobile','padding-left','30',0,''),(11972,3774,'114252','watch-mobile','padding-bottom','20',0,''),(11975,3775,'114253','watch-mobile','margin-bottom','20',0,''),(11976,3776,'114254','watch-mobile','link','products',0,''),(11977,3776,'114254','watch-mobile','float','right',0,''),(11978,3776,'114254','watch-mobile','margin-top','-37',0,''),(11979,3777,'114255','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(11980,3778,'114256','watch-mobile','block_type','2',0,''),(11981,3778,'114256','watch-mobile','margin-bottom','20',0,''),(11982,3778,'114256','watch-mobile','schema','2-2',0,''),(11983,3778,'114256','watch-mobile','background-color','$background-7',0,''),(11984,3779,'114257','watch-mobile','block_type','1',0,''),(11985,3779,'114257','watch-mobile','border-right-width','20',0,''),(11986,3779,'114257','watch-mobile','border-right-color','$border-color-1',0,''),(11987,3779,'114257','watch-mobile','margin-right','-10',0,''),(11988,3779,'114257','watch-mobile','padding-right','30',0,''),(11989,3779,'114257','watch-mobile','padding-top','20',0,''),(11990,3779,'114257','watch-mobile','padding-left','30',0,''),(11991,3779,'114257','watch-mobile','padding-bottom','20',0,''),(11994,3779,'114257','watch-mobile','margin-bottom','20',0,''),(11997,3780,'114258','watch-mobile','link','payment_method',0,''),(11998,3780,'114258','watch-mobile','float','right',0,''),(11999,3780,'114258','watch-mobile','margin-top','-31',0,''),(12000,3781,'114259','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(12001,3781,'114259','watch-mobile','clear','none',0,''),(12002,3782,'114260','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(12003,3782,'114260','watch-mobile','padding-top','20',0,''),(12004,3784,'114262','watch-mobile','link','contact_information',0,''),(12005,3784,'114262','watch-mobile','margin-top','-31',0,''),(12006,3784,'114262','watch-mobile','float','right',0,''),(12007,3786,'114264','watch-mobile','block_type','1',0,''),(12008,3786,'114264','watch-mobile','padding-left','30',0,''),(12009,3786,'114264','watch-mobile','border-left-width','20',0,''),(12010,3786,'114264','watch-mobile','border-left-color','$border-color-1',0,''),(12011,3786,'114264','watch-mobile','margin-left','-10',0,''),(12012,3786,'114264','watch-mobile','padding-right','30',0,''),(12013,3786,'114264','watch-mobile','padding-top','20',0,''),(12014,3786,'114264','watch-mobile','padding-bottom','20',0,''),(12016,3787,'114265','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(12017,3787,'114265','watch-mobile','clear','none',0,''),(12018,3788,'114266','watch-mobile','link','billing_address',0,''),(12019,3788,'114266','watch-mobile','float','right',0,''),(12020,3788,'114266','watch-mobile','margin-top','-31',0,''),(12021,3789,'114267','watch-mobile','margin-bottom','20',0,''),(12022,3790,'114268','watch-mobile','block_type','1',0,''),(12023,3790,'114268','watch-mobile','background-color','$background-7',0,''),(12024,3790,'114268','watch-mobile','padding-top','20',0,''),(12025,3790,'114268','watch-mobile','padding-bottom','20',0,''),(12026,3790,'114268','watch-mobile','padding-left','30',0,''),(12027,3790,'114268','watch-mobile','padding-right','30',0,''),(12028,3790,'114268','watch-mobile','margin-bottom','20',0,''),(12029,3791,'114269','watch-mobile','hide_parents','2',0,''),(12030,3792,'114270','watch-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(12031,3793,'114271','watch-mobile','float','right',0,''),(12032,3793,'114271','watch-mobile','margin-top','-37',0,''),(12033,3793,'114271','watch-mobile','link','comments',0,''),(12034,3794,'114272','watch-mobile','block_type','1',0,''),(12035,3794,'114272','watch-mobile','padding-top','20',0,''),(12036,3794,'114272','watch-mobile','padding-left','20',0,''),(12037,3794,'114272','watch-mobile','padding-right','20',0,''),(12038,3794,'114272','watch-mobile','padding-bottom','20',0,''),(12039,3794,'114272','watch-mobile','background-color','$background-7',0,''),(12040,3794,'114272','watch-mobile','style_class','order-summary',0,''),(12041,3795,'114273','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(12042,3797,'114275','watch-mobile','margin-bottom','20',0,''),(12043,3797,'114275','watch-mobile','text-align','right',0,''),(12044,3798,'114276','watch-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(12045,3799,'114277','watch-mobile','block_type','1',0,''),(12046,3799,'114277','watch-mobile','background-color','$background-6',0,''),(12047,3799,'114277','watch-mobile','padding-bottom','30',0,''),(12048,3800,'114278','watch-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(12049,3801,'114279','watch-mobile','block_type','1',0,''),(12050,3801,'114279','watch-mobile','schema','4-2',0,''),(12051,3801,'114279','watch-mobile','schema','4-1',0,'299'),(12052,3802,'114280','watch-mobile','block_type','1',0,''),(12053,3802,'114280','watch-mobile','padding-right','40',0,''),(12055,3803,'114281','watch-mobile','block_type','1',0,''),(12056,3803,'114281','watch-mobile','padding-right','30',0,''),(12057,3803,'114281','watch-mobile','background-color','$background-7',0,''),(12058,3803,'114281','watch-mobile','padding-top','20',0,''),(12059,3803,'114281','watch-mobile','padding-left','30',0,''),(12060,3803,'114281','watch-mobile','padding-bottom','20',0,''),(12063,3804,'114282','watch-mobile','link','products',0,''),(12064,3804,'114282','watch-mobile','float','right',0,''),(12065,3804,'114282','watch-mobile','margin-top','-37',0,''),(12066,3805,'114283','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(12067,3807,'114285','watch-mobile','block_type','1',0,''),(12068,3807,'114285','watch-mobile','background-color','$background-7',0,''),(12069,3807,'114285','watch-mobile','padding-top','20',0,''),(12070,3807,'114285','watch-mobile','padding-bottom','20',0,''),(12071,3807,'114285','watch-mobile','padding-left','30',0,''),(12072,3807,'114285','watch-mobile','padding-right','30',0,''),(12073,3807,'114285','watch-mobile','margin-bottom','20',0,''),(12074,3808,'114286','watch-mobile','float','right',0,''),(12075,3808,'114286','watch-mobile','margin-top','-37',0,''),(12076,3808,'114286','watch-mobile','link','comments',0,''),(12077,3809,'114287','watch-mobile','hide_parents','2',0,''),(12078,3810,'114288','watch-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(12079,3811,'114289','watch-mobile','block_type','1',0,''),(12080,3811,'114289','watch-mobile','margin-bottom','20',0,''),(12081,3811,'114289','watch-mobile','schema','2-2',0,''),(12082,3811,'114289','watch-mobile','background-color','$background-7',0,''),(12083,3812,'114290','watch-mobile','block_type','1',0,''),(12084,3812,'114290','watch-mobile','border-right-width','20',0,''),(12085,3812,'114290','watch-mobile','border-right-color','$border-color-1',0,''),(12086,3812,'114290','watch-mobile','margin-right','-10',0,''),(12087,3812,'114290','watch-mobile','padding-right','30',0,''),(12088,3812,'114290','watch-mobile','padding-top','20',0,''),(12089,3812,'114290','watch-mobile','padding-left','30',0,''),(12090,3812,'114290','watch-mobile','padding-bottom','20',0,''),(12093,3812,'114290','watch-mobile','margin-bottom','20',0,''),(12096,3813,'114291','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(12097,3813,'114291','watch-mobile','clear','none',0,''),(12098,3814,'114292','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(12099,3814,'114292','watch-mobile','padding-top','20',0,''),(12100,3815,'114293','watch-mobile','link','shipping_method',0,''),(12101,3815,'114293','watch-mobile','float','right',0,''),(12102,3815,'114293','watch-mobile','margin-top','-31',0,''),(12103,3817,'114295','watch-mobile','link','shipping_address',0,''),(12104,3817,'114295','watch-mobile','float','right',0,''),(12105,3817,'114295','watch-mobile','margin-top','-31',0,''),(12106,3819,'114297','watch-mobile','margin-bottom','20',0,''),(12107,3821,'114299','watch-mobile','link','contact_information',0,''),(12108,3821,'114299','watch-mobile','margin-top','-31',0,''),(12109,3821,'114299','watch-mobile','float','right',0,''),(12110,3822,'114300','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(12111,3822,'114300','watch-mobile','clear','none',0,''),(12112,3823,'114301','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(12113,3824,'114302','watch-mobile','block_type','1',0,''),(12114,3824,'114302','watch-mobile','padding-left','30',0,''),(12115,3824,'114302','watch-mobile','border-left-width','20',0,''),(12116,3824,'114302','watch-mobile','border-left-color','$border-color-1',0,''),(12117,3824,'114302','watch-mobile','margin-left','-10',0,''),(12118,3824,'114302','watch-mobile','padding-right','30',0,''),(12119,3824,'114302','watch-mobile','padding-top','20',0,''),(12120,3824,'114302','watch-mobile','padding-bottom','20',0,''),(12122,3825,'114303','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(12123,3826,'114304','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(12124,3826,'114304','watch-mobile','clear','none',0,''),(12125,3828,'114306','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(12126,3828,'114306','watch-mobile','clear','none',0,''),(12127,3829,'114307','watch-mobile','margin-bottom','20',0,''),(12128,3830,'114308','watch-mobile','link','payment_method',0,''),(12129,3830,'114308','watch-mobile','float','right',0,''),(12130,3830,'114308','watch-mobile','margin-top','-31',0,''),(12131,3831,'114309','watch-mobile','link','billing_address',0,''),(12132,3831,'114309','watch-mobile','float','right',0,''),(12133,3831,'114309','watch-mobile','margin-top','-31',0,''),(12134,3832,'114310','watch-mobile','block_type','1',0,''),(12135,3832,'114310','watch-mobile','padding-top','20',0,''),(12136,3832,'114310','watch-mobile','padding-left','20',0,''),(12137,3832,'114310','watch-mobile','padding-right','20',0,''),(12138,3832,'114310','watch-mobile','padding-bottom','20',0,''),(12139,3832,'114310','watch-mobile','background-color','$background-7',0,''),(12140,3832,'114310','watch-mobile','style_class','order-summary',0,''),(12141,3833,'114311','watch-mobile','margin-bottom','20',0,''),(12142,3833,'114311','watch-mobile','text-align','right',0,''),(12143,3834,'114312','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(12144,3836,'114314','watch-mobile','block_type','1',0,''),(12145,3836,'114314','watch-mobile','background-color','$background-6',0,''),(12146,3836,'114314','watch-mobile','padding-bottom','30',0,''),(12147,3837,'114315','watch-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(12148,3838,'114316','watch-mobile','block_type','1',0,''),(12149,3838,'114316','watch-mobile','schema','4-2',0,''),(12150,3838,'114316','watch-mobile','schema','4-1',0,'299'),(12151,3839,'114317','watch-mobile','block_type','1',0,''),(12152,3839,'114317','watch-mobile','padding-right','40',0,''),(12154,3840,'114318','watch-mobile','block_type','1',0,''),(12155,3840,'114318','watch-mobile','background-color','$background-7',0,''),(12156,3840,'114318','watch-mobile','padding-top','20',0,''),(12157,3840,'114318','watch-mobile','padding-bottom','20',0,''),(12158,3840,'114318','watch-mobile','padding-left','30',0,''),(12159,3840,'114318','watch-mobile','padding-right','30',0,''),(12160,3840,'114318','watch-mobile','margin-bottom','20',0,''),(12161,3841,'114319','watch-mobile','hide_parents','2',0,''),(12162,3842,'114320','watch-mobile','float','right',0,''),(12163,3842,'114320','watch-mobile','margin-top','-37',0,''),(12164,3842,'114320','watch-mobile','link','comments',0,''),(12165,3843,'114321','watch-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(12166,3844,'114322','watch-mobile','block_type','1',0,''),(12167,3844,'114322','watch-mobile','padding-right','30',0,''),(12168,3844,'114322','watch-mobile','background-color','$background-7',0,''),(12169,3844,'114322','watch-mobile','padding-top','20',0,''),(12170,3844,'114322','watch-mobile','padding-left','30',0,''),(12171,3844,'114322','watch-mobile','padding-bottom','20',0,''),(12174,3846,'114324','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(12175,3847,'114325','watch-mobile','link','products',0,''),(12176,3847,'114325','watch-mobile','float','right',0,''),(12177,3847,'114325','watch-mobile','margin-top','-37',0,''),(12178,3848,'114326','watch-mobile','block_type','1',0,''),(12179,3848,'114326','watch-mobile','margin-bottom','20',0,''),(12180,3848,'114326','watch-mobile','schema','2-2',0,''),(12181,3848,'114326','watch-mobile','background-color','$background-7',0,''),(12182,3849,'114327','watch-mobile','block_type','1',0,''),(12183,3849,'114327','watch-mobile','border-right-width','20',0,''),(12184,3849,'114327','watch-mobile','border-right-color','$border-color-1',0,''),(12185,3849,'114327','watch-mobile','margin-right','-10',0,''),(12186,3849,'114327','watch-mobile','padding-right','30',0,''),(12187,3849,'114327','watch-mobile','padding-top','20',0,''),(12188,3849,'114327','watch-mobile','padding-left','30',0,''),(12189,3849,'114327','watch-mobile','padding-bottom','20',0,''),(12192,3849,'114327','watch-mobile','margin-bottom','20',0,''),(12195,3850,'114328','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(12196,3850,'114328','watch-mobile','padding-top','20',0,''),(12197,3852,'114330','watch-mobile','link','shipping_method',0,''),(12198,3852,'114330','watch-mobile','float','right',0,''),(12199,3852,'114330','watch-mobile','margin-top','-31',0,''),(12200,3853,'114331','watch-mobile','link','contact_information',0,''),(12201,3853,'114331','watch-mobile','margin-top','-31',0,''),(12202,3853,'114331','watch-mobile','float','right',0,''),(12203,3854,'114332','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(12204,3856,'114334','watch-mobile','link','shipping_address',0,''),(12205,3856,'114334','watch-mobile','float','right',0,''),(12206,3856,'114334','watch-mobile','margin-top','-31',0,''),(12207,3857,'114335','watch-mobile','margin-bottom','20',0,''),(12208,3858,'114336','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(12209,3858,'114336','watch-mobile','clear','none',0,''),(12210,3859,'114337','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(12211,3859,'114337','watch-mobile','clear','none',0,''),(12212,3861,'114339','watch-mobile','block_type','1',0,''),(12213,3861,'114339','watch-mobile','padding-left','30',0,''),(12214,3861,'114339','watch-mobile','border-left-width','20',0,''),(12215,3861,'114339','watch-mobile','border-left-color','$border-color-1',0,''),(12216,3861,'114339','watch-mobile','margin-left','-10',0,''),(12217,3861,'114339','watch-mobile','padding-right','30',0,''),(12218,3861,'114339','watch-mobile','padding-top','20',0,''),(12219,3861,'114339','watch-mobile','padding-bottom','20',0,''),(12221,3862,'114340','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(12222,3862,'114340','watch-mobile','clear','none',0,''),(12223,3863,'114341','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(12224,3864,'114342','watch-mobile','link','payment_method',0,''),(12225,3864,'114342','watch-mobile','float','right',0,''),(12226,3864,'114342','watch-mobile','margin-top','-31',0,''),(12227,3865,'114343','watch-mobile','margin-bottom','20',0,''),(12228,3866,'114344','watch-mobile','link','billing_address',0,''),(12229,3866,'114344','watch-mobile','float','right',0,''),(12230,3866,'114344','watch-mobile','margin-top','-31',0,''),(12231,3867,'114345','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(12232,3867,'114345','watch-mobile','clear','none',0,''),(12233,3869,'114347','watch-mobile','block_type','1',0,''),(12234,3869,'114347','watch-mobile','padding-top','20',0,''),(12235,3869,'114347','watch-mobile','padding-left','20',0,''),(12236,3869,'114347','watch-mobile','padding-right','20',0,''),(12237,3869,'114347','watch-mobile','padding-bottom','20',0,''),(12238,3869,'114347','watch-mobile','background-color','$background-7',0,''),(12239,3869,'114347','watch-mobile','style_class','order-summary',0,''),(12240,3871,'114349','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(12241,3872,'114350','watch-mobile','margin-bottom','20',0,''),(12242,3872,'114350','watch-mobile','text-align','right',0,''),(12243,3873,'75599','watch-mobile','block_type','1',0,''),(12244,3874,'75600','watch-mobile','block_type','2',0,''),(12245,3874,'75600','watch-mobile','font-weight','400',0,''),(12246,3874,'75600','watch-mobile','padding-bottom','20',0,''),(12247,3874,'75600','watch-mobile','schema','2-2',0,''),(12248,3874,'75600','watch-mobile','schema','2-2',0,'291'),(12249,3876,'75602','watch-mobile','street_heading','90',0,''),(12250,3877,'75603','watch-mobile','block_type','2',0,''),(12251,3877,'75603','watch-mobile','font-weight','400',0,''),(12252,3877,'75603','watch-mobile','padding-bottom','20',0,''),(12253,3877,'75603','watch-mobile','schema','2-2',0,'291'),(12254,3878,'75604','watch-mobile','show_captcha','on',0,''),(12255,3879,'75605','watch-mobile','font-weight','400',0,''),(12256,3879,'75605','watch-mobile','padding-left','40',0,''),(12257,3879,'75605','watch-mobile','time_format','24',0,''),(12258,3879,'75605','watch-mobile','show_icons','on',0,''),(12259,3879,'75605','watch-mobile','padding-left','0',0,'291'),(12260,3881,'114351','watch-mobile','block_type','1',0,''),(12261,3882,'114352','watch-mobile','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(12262,3882,'114352','watch-mobile','margin-bottom','40',0,''),(12263,3883,'114353','watch-mobile','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(12264,3884,'114354','watch-mobile','width','680',0,''),(12265,3884,'114354','watch-mobile','font-weight','normal',0,''),(12266,3884,'114354','watch-mobile','font-size','12',0,''),(12267,3884,'114354','watch-mobile','padding-top','20',0,''),(12268,3884,'114354','watch-mobile','padding-bottom','20',0,''),(12269,3884,'114354','watch-mobile','color','$color-font-7',0,''),(12270,3885,'114355','watch-mobile','block_type','4',0,''),(12271,3885,'114355','watch-mobile','font-weight','normal',0,''),(12272,3885,'114355','watch-mobile','border-top-width','1',0,''),(12273,3885,'114355','watch-mobile','border-top-color','$border-color-1',0,''),(12274,3885,'114355','watch-mobile','border-left-width','1',0,''),(12275,3885,'114355','watch-mobile','border-left-color','$border-color-1',0,''),(12276,3885,'114355','watch-mobile','border-right-width','1',0,''),(12277,3885,'114355','watch-mobile','border-right-color','$border-color-1',0,''),(12278,3885,'114355','watch-mobile','border-bottom-width','1',0,''),(12279,3885,'114355','watch-mobile','border-bottom-color','$border-color-1',0,''),(12280,3886,'114356','watch-mobile','block_type','2',0,''),(12281,3886,'114356','watch-mobile','font-weight','normal',0,''),(12282,3886,'114356','watch-mobile','border-top-width','1',0,''),(12283,3886,'114356','watch-mobile','border-top-color','$border-color-1',0,''),(12284,3886,'114356','watch-mobile','border-right-width','1',0,''),(12285,3886,'114356','watch-mobile','border-right-color','$border-color-1',0,''),(12286,3887,'114357','watch-mobile','block_type','1',0,''),(12287,3887,'114357','watch-mobile','font-weight','normal',0,''),(12288,3887,'114357','watch-mobile','padding-top','10',0,''),(12289,3887,'114357','watch-mobile','padding-left','10',0,''),(12290,3887,'114357','watch-mobile','padding-right','10',0,''),(12291,3887,'114357','watch-mobile','padding-bottom','10',0,''),(12292,3887,'114357','watch-mobile','border-right-width','1',0,''),(12293,3887,'114357','watch-mobile','border-right-color','$border-color-1',0,''),(12294,3888,'114358','watch-mobile','text','<p>Shipping via</p>',1,''),(12295,3888,'114358','watch-mobile','font-weight','bold',0,''),(12296,3888,'114358','watch-mobile','font-size','14',0,''),(12297,3890,'114360','watch-mobile','block_type','1',0,''),(12298,3890,'114360','watch-mobile','font-weight','normal',0,''),(12299,3890,'114360','watch-mobile','padding-top','10',0,''),(12300,3890,'114360','watch-mobile','padding-left','10',0,''),(12301,3890,'114360','watch-mobile','padding-right','10',0,''),(12302,3890,'114360','watch-mobile','padding-bottom','10',0,''),(12303,3892,'114362','watch-mobile','text','<p>Shipping service</p>',1,''),(12304,3892,'114362','watch-mobile','font-weight','bold',0,''),(12305,3892,'114362','watch-mobile','font-size','14',0,''),(12306,3893,'114363','watch-mobile','block_type','2',0,''),(12307,3893,'114363','watch-mobile','font-weight','normal',0,''),(12308,3893,'114363','watch-mobile','border-right-width','1',0,''),(12309,3893,'114363','watch-mobile','border-right-color','$border-color-1',0,''),(12310,3894,'114364','watch-mobile','block_type','1',0,''),(12311,3894,'114364','watch-mobile','font-weight','400',0,''),(12312,3894,'114364','watch-mobile','background-color','$background-6',0,''),(12313,3894,'114364','watch-mobile','padding-top','10',0,''),(12314,3894,'114364','watch-mobile','padding-left','10',0,''),(12315,3894,'114364','watch-mobile','padding-right','10',0,''),(12316,3894,'114364','watch-mobile','padding-bottom','30',0,''),(12317,3895,'114365','watch-mobile','font-size','12',0,''),(12318,3896,'114366','watch-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(12319,3896,'114366','watch-mobile','font-size','14',0,''),(12320,3896,'114366','watch-mobile','font-weight','bold',0,''),(12321,3897,'114367','watch-mobile','block_type','1',0,''),(12322,3897,'114367','watch-mobile','font-weight','normal',0,''),(12323,3897,'114367','watch-mobile','padding-top','10',0,''),(12324,3897,'114367','watch-mobile','padding-left','10',0,''),(12325,3897,'114367','watch-mobile','padding-right','10',0,''),(12326,3897,'114367','watch-mobile','padding-bottom','10',0,''),(12327,3898,'114368','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(12328,3898,'114368','watch-mobile','font-weight','bold',0,''),(12329,3898,'114368','watch-mobile','font-size','14',0,''),(12330,3898,'114368','watch-mobile','padding-top','10',0,''),(12331,3899,'114369','watch-mobile','font-weight','normal',0,''),(12332,3901,'114371','watch-mobile','text','<p>PHONE NUMBER:</p>',1,''),(12333,3901,'114371','watch-mobile','font-size','14',0,''),(12334,3901,'114371','watch-mobile','font-weight','bold',0,''),(12335,3901,'114371','watch-mobile','padding-top','10',0,''),(12336,3902,'114372','watch-mobile','text','<p>CUSTOMER:</p>',1,''),(12337,3902,'114372','watch-mobile','font-size','13',0,''),(12338,3902,'114372','watch-mobile','font-weight','bold',0,''),(12339,3903,'114373','watch-mobile','font-weight','normal',0,''),(12340,3904,'114374','watch-mobile','font-weight','normal',0,''),(12341,3904,'114374','watch-mobile','text-align','center',0,''),(12342,3904,'114374','watch-mobile','padding-bottom','10',0,''),(12343,3905,'114375','watch-mobile','text','<p>Payment date:</p>',1,''),(12344,3905,'114375','watch-mobile','font-weight','bold',0,''),(12345,3905,'114375','watch-mobile','text-align','center',0,''),(12346,3905,'114375','watch-mobile','font-size','12',0,''),(12347,3906,'114376','watch-mobile','font-size','14',0,''),(12348,3906,'114376','watch-mobile','font-weight','bold',0,''),(12349,3906,'114376','watch-mobile','text-align','center',0,''),(12350,3906,'114376','watch-mobile','padding-bottom','10',0,''),(12351,3906,'114376','watch-mobile','padding-top','10',0,''),(12352,3907,'114377','watch-mobile','block_type','5',0,''),(12353,3907,'114377','watch-mobile','font-weight','normal',0,''),(12354,3907,'114377','watch-mobile','border-bottom-width','1',0,''),(12355,3907,'114377','watch-mobile','border-bottom-color','$border-color-1',0,''),(12356,3907,'114377','watch-mobile','border-top-width','1',0,''),(12357,3907,'114377','watch-mobile','border-top-color','$border-color-1',0,''),(12358,3907,'114377','watch-mobile','border-left-color','$border-color-1',0,''),(12359,3907,'114377','watch-mobile','border-left-width','1',0,''),(12360,3908,'114378','watch-mobile','block_type','1',0,''),(12361,3908,'114378','watch-mobile','font-weight','normal',0,''),(12362,3908,'114378','watch-mobile','padding-top','10',0,''),(12363,3908,'114378','watch-mobile','padding-left','10',0,''),(12364,3908,'114378','watch-mobile','padding-right','10',0,''),(12365,3909,'114379','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(12366,3909,'114379','watch-mobile','font-size','14',0,''),(12367,3909,'114379','watch-mobile','font-weight','bold',0,''),(12368,3909,'114379','watch-mobile','padding-bottom','10',0,''),(12369,3910,'114380','watch-mobile','font-weight','400',0,''),(12370,3910,'114380','watch-mobile','line-height','120',0,''),(12371,3910,'114380','watch-mobile','line_height_measure','%',0,''),(12372,3910,'114380','watch-mobile','font-size','12',0,''),(12373,3911,'114381','watch-mobile','block_type','1',0,''),(12374,3911,'114381','watch-mobile','background-color','$background-6',0,''),(12375,3911,'114381','watch-mobile','padding-top','20',0,''),(12376,3911,'114381','watch-mobile','padding-left','10',0,''),(12377,3911,'114381','watch-mobile','padding-right','10',0,''),(12378,3911,'114381','watch-mobile','padding-bottom','20',0,''),(12379,3911,'114381','watch-mobile','font-size','14',0,''),(12380,3912,'114382','watch-mobile','block_type','2',0,''),(12381,3912,'114382','watch-mobile','font-weight','normal',0,''),(12382,3912,'114382','watch-mobile','padding-bottom','20',0,''),(12383,3913,'114383','watch-mobile','font-weight','400',0,''),(12384,3913,'114383','watch-mobile','padding-top','20',0,''),(12386,3914,'114384','watch-mobile','block_type','1',0,''),(12387,3915,'114385','watch-mobile','font-weight','normal',0,''),(12388,3915,'114385','watch-mobile','text-align','right',0,''),(12389,3915,'114385','watch-mobile','padding-bottom','10',0,''),(12390,3915,'114385','watch-mobile','address_spacer',',',0,''),(12391,3915,'114385','watch-mobile','font-size','12',0,''),(12392,3916,'114386','watch-mobile','block_type','11',0,''),(12393,3916,'114386','watch-mobile','font-weight','normal',0,''),(12394,3917,'114387','watch-mobile','text','<p>Email:</p>',1,''),(12395,3917,'114387','watch-mobile','font-weight','normal',0,''),(12396,3917,'114387','watch-mobile','text-align','right',0,''),(12397,3918,'114388','watch-mobile','font-weight','normal',0,''),(12398,3918,'114388','watch-mobile','text-align','right',0,''),(12399,3919,'114389','watch-mobile','block_type','11',0,''),(12400,3919,'114389','watch-mobile','font-weight','normal',0,''),(12401,3920,'114390','watch-mobile','text','<p>Phone:</p>',1,''),(12402,3920,'114390','watch-mobile','font-weight','normal',0,''),(12403,3920,'114390','watch-mobile','text-align','right',0,''),(12404,3921,'114391','watch-mobile','font-weight','normal',0,''),(12405,3921,'114391','watch-mobile','text-align','right',0,''),(12406,3922,'114392','watch-mobile','block_type','11',0,''),(12407,3922,'114392','watch-mobile','font-weight','normal',0,''),(12408,3923,'114393','watch-mobile','text','<p>Web:</p>',1,''),(12409,3923,'114393','watch-mobile','font-weight','normal',0,''),(12410,3923,'114393','watch-mobile','text-align','right',0,''),(12411,3924,'114394','watch-mobile','font-weight','normal',0,''),(12412,3924,'114394','watch-mobile','text-align','right',0,''),(12413,3925,'114395','watch-mobile','font-weight','400',0,''),(12414,3925,'114395','watch-mobile','padding-top','20',0,''),(12415,3925,'114395','watch-mobile','padding-bottom','0',0,''),(12416,3925,'114395','watch-mobile','font-size','12',0,''),(12417,3926,'114396','watch-mobile','block_type','3',0,''),(12418,3926,'114396','watch-mobile','font-weight','normal',0,''),(12419,3926,'114396','watch-mobile','padding-top','20',0,''),(12420,3927,'114397','watch-mobile','font-size','12',0,''),(12421,3928,'114398','watch-mobile','text','<p>If undelivered please return to:</p>',1,''),(12422,3928,'114398','watch-mobile','font-size','12',0,''),(12423,3928,'114398','watch-mobile','font-weight','bold',0,''),(12424,3929,'114399','watch-mobile','text','<p>Thank you for your order</p>',1,''),(12425,3929,'114399','watch-mobile','color','$color-font-10',0,''),(12426,3929,'114399','watch-mobile','font-size','13',0,''),(12427,3929,'114399','watch-mobile','font-weight','bold',0,''),(12428,3929,'114399','watch-mobile','padding-top','5',0,''),(12429,3929,'114399','watch-mobile','text-align','center',0,''),(12430,3930,'114400','watch-mobile','font-weight','400',0,''),(12431,3930,'114400','watch-mobile','text-align','center',0,''),(12432,3930,'114400','watch-mobile','padding-top','0',0,''),(12434,3930,'114400','watch-mobile','padding-left','20',0,''),(12435,3930,'114400','watch-mobile','padding-right','20',0,''),(12436,3931,'114401','watch-mobile','block_type','6',0,''),(12437,3931,'114401','watch-mobile','font-weight','normal',0,''),(12438,3931,'114401','watch-mobile','font-size','16',0,''),(12439,3932,'114402','watch-mobile','text','<p>Phone:</p>',1,''),(12440,3932,'114402','watch-mobile','font-weight','normal',0,''),(12441,3932,'114402','watch-mobile','text-align','right',0,''),(12442,3932,'114402','watch-mobile','font-size','12',0,''),(12443,3933,'114403','watch-mobile','font-weight','normal',0,''),(12444,3933,'114403','watch-mobile','text-align','right',0,''),(12445,3933,'114403','watch-mobile','font-size','12',0,''),(12446,3934,'114404','watch-mobile','block_type','6',0,''),(12447,3934,'114404','watch-mobile','font-weight','normal',0,''),(12448,3934,'114404','watch-mobile','font-size','16',0,''),(12449,3935,'114405','watch-mobile','text','<p>Email:</p>',1,''),(12450,3935,'114405','watch-mobile','font-weight','normal',0,''),(12451,3935,'114405','watch-mobile','text-align','right',0,''),(12452,3935,'114405','watch-mobile','font-size','12',0,''),(12453,3936,'114406','watch-mobile','font-weight','normal',0,''),(12454,3936,'114406','watch-mobile','text-align','right',0,''),(12455,3936,'114406','watch-mobile','font-size','12',0,''),(12456,3937,'114407','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(12457,3937,'114407','watch-mobile','font-size','12',0,''),(12458,3937,'114407','watch-mobile','font-weight','bold',0,''),(12459,3937,'114407','watch-mobile','text-align','right',0,''),(12460,3940,'75609','watch-mobile','text-align','center',0,''),(12461,3940,'75609','watch-mobile','padding-top','10',0,''),(12462,3946,'75615','watch-mobile','heading_type','h1',0,''),(12463,3949,'114410','watch-mobile','text-align','center',0,''),(12464,3949,'114410','watch-mobile','padding-top','10',0,''),(12465,3954,'75616','watch-mobile','font-weight','normal',0,''),(12466,3954,'75616','watch-mobile','padding-top','20',0,''),(12467,3954,'75616','watch-mobile','padding-left','10',0,''),(12468,3954,'75616','watch-mobile','padding-right','10',0,''),(12469,3954,'75616','watch-mobile','padding-bottom','20',0,''),(12470,3954,'75616','watch-mobile','color','$color-font-7',0,''),(12471,3954,'75616','watch-mobile','font-size','14',0,''),(12472,3955,'75617','watch-mobile','block_type','2',0,''),(12473,3955,'75617','watch-mobile','font-weight','normal',0,''),(12474,3956,'75618','watch-mobile','font-weight','normal',0,''),(12475,3956,'75618','watch-mobile','padding-bottom','20',0,''),(12476,3956,'75618','watch-mobile','logo','themes/watch-mobile/img/watchlogo-1-1.png',1,''),(12477,3957,'75619','watch-mobile','color','$color-font-7',0,''),(12478,3957,'75619','watch-mobile','font-size','14',0,''),(12479,3957,'75619','watch-mobile','padding-top','20',0,''),(12480,3957,'75619','watch-mobile','padding-bottom','20',0,''),(12481,3957,'75619','watch-mobile','border-top-width','1',0,''),(12482,3957,'75619','watch-mobile','border-top-color','$border-color-10',0,''),(12483,3958,'75620','watch-mobile','block_type','1',0,''),(12484,3959,'75621','watch-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',1,''),(12485,3959,'75621','watch-mobile','font-weight','normal',0,''),(12486,3959,'75621','watch-mobile','color','$color-font-7',0,''),(12487,3959,'75621','watch-mobile','font-size','14',0,''),(12488,3960,'75622','watch-mobile','block_type','2',0,''),(12489,3960,'75622','watch-mobile','font-weight','normal',0,''),(12490,3960,'75622','watch-mobile','background-color','$background-2',0,''),(12491,3960,'75622','watch-mobile','padding-top','5',0,''),(12492,3960,'75622','watch-mobile','padding-left','10',0,''),(12493,3960,'75622','watch-mobile','padding-right','10',0,''),(12494,3960,'75622','watch-mobile','padding-bottom','5',0,''),(12495,3961,'75623','watch-mobile','color','$color-font-1',0,''),(12496,3961,'75623','watch-mobile','font-size','14',0,''),(12497,3961,'75623','watch-mobile','font-weight','normal',0,''),(12498,3962,'75624','watch-mobile','font-weight','normal',0,''),(12499,3962,'75624','watch-mobile','text-align','right',0,''),(12500,3962,'75624','watch-mobile','color','$color-font-1',0,''),(12501,3962,'75624','watch-mobile','font-size','12',0,''),(12502,3963,'114415','watch-mobile','block_type','1',0,''),(12503,3964,'114416','watch-mobile','block_type','1',0,''),(12504,3964,'114416','watch-mobile','max-width','800',0,''),(12505,3964,'114416','watch-mobile','margin','0 auto',0,''),(12506,3964,'114416','watch-mobile','background-color','$background-7',0,''),(12507,3965,'114417','watch-mobile','font-weight','normal',0,''),(12508,3965,'114417','watch-mobile','padding-top','20',0,''),(12509,3965,'114417','watch-mobile','padding-left','10',0,''),(12510,3965,'114417','watch-mobile','padding-right','10',0,''),(12511,3965,'114417','watch-mobile','padding-bottom','20',0,''),(12512,3965,'114417','watch-mobile','color','$color-font-7',0,''),(12513,3965,'114417','watch-mobile','font-size','14',0,''),(12514,3966,'114418','watch-mobile','block_type','7',0,''),(12515,3966,'114418','watch-mobile','font-weight','normal',0,''),(12516,3966,'114418','watch-mobile','background-color','$background-2',0,''),(12517,3966,'114418','watch-mobile','padding-top','5',0,''),(12518,3966,'114418','watch-mobile','padding-left','10',0,''),(12519,3966,'114418','watch-mobile','padding-right','10',0,''),(12520,3966,'114418','watch-mobile','padding-bottom','5',0,''),(12521,3967,'114419','watch-mobile','color','$color-font-1',0,''),(12522,3967,'114419','watch-mobile','font-size','15',0,''),(12523,3967,'114419','watch-mobile','font-weight','700',0,''),(12524,3968,'114420','watch-mobile','font-weight','normal',0,''),(12525,3968,'114420','watch-mobile','text-align','right',0,''),(12526,3968,'114420','watch-mobile','color','$color-font-8',0,''),(12527,3968,'114420','watch-mobile','font-size','12',0,''),(12528,3969,'114421','watch-mobile','color','$color-font-7',0,''),(12529,3969,'114421','watch-mobile','font-size','12',0,''),(12530,3969,'114421','watch-mobile','padding-top','20',0,''),(12531,3969,'114421','watch-mobile','padding-bottom','20',0,''),(12532,3969,'114421','watch-mobile','border-top-width','1',0,''),(12533,3969,'114421','watch-mobile','border-top-color','$border-color-1',0,''),(12534,3970,'114422','watch-mobile','font-weight','normal',0,''),(12535,3970,'114422','watch-mobile','padding-bottom','10',0,''),(12536,3970,'114422','watch-mobile','background-color','$background-2',0,''),(12537,3970,'114422','watch-mobile','logo','themes/watch-mobile/img/logo-white-1.png',1,''),(12538,3970,'114422','watch-mobile','padding-left','20',0,''),(12539,3970,'114422','watch-mobile','padding-top','10',0,''),(12540,3971,'114423','watch-mobile','block_type','1',0,''),(12541,3971,'114423','watch-mobile','background-color','$background-6',0,''),(12542,3972,'114424','watch-mobile','block_type','1',0,''),(12543,3972,'114424','watch-mobile','max-width','800',0,''),(12544,3972,'114424','watch-mobile','margin','0 auto',0,''),(12545,3973,'114425','watch-mobile','font-weight','normal',0,''),(12546,3973,'114425','watch-mobile','padding-bottom','10',0,''),(12547,3973,'114425','watch-mobile','padding-top','10',0,''),(12548,3973,'114425','watch-mobile','text-align','center',0,''),(12549,3973,'114425','watch-mobile','logo_from','theme',0,''),(12550,3974,'114426','watch-mobile','color','$color-font-8',0,''),(12551,3974,'114426','watch-mobile','font-size','12',0,''),(12552,3974,'114426','watch-mobile','padding-top','20',0,''),(12553,3974,'114426','watch-mobile','padding-bottom','20',0,''),(12554,3974,'114426','watch-mobile','text-align','center',0,''),(12555,3975,'114427','watch-mobile','block_type','1',0,''),(12556,3975,'114427','watch-mobile','background-color','$background-7',0,''),(12557,3975,'114427','watch-mobile','padding-top','20',0,''),(12558,3975,'114427','watch-mobile','padding-left','20',0,''),(12559,3975,'114427','watch-mobile','padding-right','20',0,''),(12560,3975,'114427','watch-mobile','padding-bottom','20',0,''),(12561,3976,'114428','watch-mobile','block_type','7',0,''),(12562,3976,'114428','watch-mobile','font-weight','normal',0,''),(12563,3976,'114428','watch-mobile','padding-left','10',0,''),(12564,3976,'114428','watch-mobile','padding-right','10',0,''),(12565,3976,'114428','watch-mobile','padding-bottom','15',0,''),(12566,3976,'114428','watch-mobile','border-bottom-width','1',0,''),(12567,3976,'114428','watch-mobile','border-bottom-color','$border-color-1',0,''),(12568,3977,'114429','watch-mobile','color','$color-font-7',0,''),(12569,3977,'114429','watch-mobile','font-size','14',0,''),(12570,3977,'114429','watch-mobile','font-weight','700',0,''),(12571,3978,'114430','watch-mobile','font-weight','normal',0,''),(12572,3978,'114430','watch-mobile','text-align','right',0,''),(12573,3978,'114430','watch-mobile','color','$color-font-8',0,''),(12574,3978,'114430','watch-mobile','font-size','11',0,''),(12575,3978,'114430','watch-mobile','text-transform','uppercase',0,''),(12576,3979,'114431','watch-mobile','font-weight','normal',0,''),(12577,3979,'114431','watch-mobile','padding-top','20',0,''),(12578,3979,'114431','watch-mobile','padding-bottom','20',0,''),(12579,3979,'114431','watch-mobile','color','$color-font-7',0,''),(12580,3979,'114431','watch-mobile','font-size','14',0,''),(12581,3980,'114432','watch-mobile','block_type','1',0,''),(12582,3980,'114432','watch-mobile','background-color','$background-6',0,''),(12583,3980,'114432','watch-mobile','padding-top','20',0,''),(12584,3980,'114432','watch-mobile','padding-bottom','20',0,''),(12585,3981,'114433','watch-mobile','block_type','1',0,''),(12586,3981,'114433','watch-mobile','max-width','800',0,''),(12587,3981,'114433','watch-mobile','margin','0 auto',0,''),(12588,3982,'114434','watch-mobile','block_type','1',0,''),(12589,3982,'114434','watch-mobile','background-color','$background-7',0,''),(12590,3982,'114434','watch-mobile','padding-top','20',0,''),(12591,3982,'114434','watch-mobile','padding-left','20',0,''),(12592,3982,'114434','watch-mobile','padding-right','20',0,''),(12593,3982,'114434','watch-mobile','padding-bottom','20',0,''),(12594,3982,'114434','watch-mobile','border-top-width','1',0,''),(12595,3982,'114434','watch-mobile','border-left-width','1',0,''),(12596,3982,'114434','watch-mobile','border-right-width','1',0,''),(12597,3982,'114434','watch-mobile','border-bottom-width','1',0,''),(12598,3982,'114434','watch-mobile','border-top-color','$border-color-1',0,''),(12599,3982,'114434','watch-mobile','border-left-color','$border-color-1',0,''),(12600,3982,'114434','watch-mobile','border-bottom-color','$border-color-1',0,''),(12601,3982,'114434','watch-mobile','border-right-color','$border-color-1',0,''),(12602,3983,'114435','watch-mobile','font-weight','normal',0,''),(12603,3983,'114435','watch-mobile','padding-top','20',0,''),(12604,3983,'114435','watch-mobile','padding-bottom','20',0,''),(12605,3983,'114435','watch-mobile','color','$color-font-7',0,''),(12606,3983,'114435','watch-mobile','font-size','14',0,''),(12607,3984,'114436','watch-mobile','block_type','2',0,''),(12608,3985,'114437','watch-mobile','font-weight','normal',0,''),(12609,3985,'114437','watch-mobile','padding-bottom','10',0,''),(12610,3985,'114437','watch-mobile','padding-top','10',0,''),(12611,3985,'114437','watch-mobile','logo_from','theme',0,''),(12612,3986,'114438','watch-mobile','color','$color-font-7',0,''),(12613,3986,'114438','watch-mobile','font-size','14',0,''),(12614,3986,'114438','watch-mobile','font-weight','700',0,''),(12615,3986,'114438','watch-mobile','text-align','right',0,''),(12616,3987,'114439','watch-mobile','font-weight','normal',0,''),(12617,3987,'114439','watch-mobile','text-align','right',0,''),(12618,3987,'114439','watch-mobile','color','$color-font-8',0,''),(12619,3987,'114439','watch-mobile','font-size','11',0,''),(12620,3987,'114439','watch-mobile','text-transform','uppercase',0,''),(12621,3988,'114440','watch-mobile','color','$color-font-8',0,''),(12622,3988,'114440','watch-mobile','font-size','12',0,''),(12623,3988,'114440','watch-mobile','padding-top','20',0,''),(12624,3988,'114440','watch-mobile','padding-bottom','20',0,''),(12625,3988,'114440','watch-mobile','text-align','left',0,''),(12626,3989,'75625','watch-mobile','block_type','1',0,''),(12627,3989,'75625','watch-mobile','font-weight','normal',0,''),(12628,3989,'75625','watch-mobile','margin-top','40',0,''),(12629,3990,'75628','watch-mobile','block_type','1',0,''),(12630,3991,'75629','watch-mobile','text','Account',1,''),(12631,3991,'75629','watch-mobile','style_class','footerTitle',0,''),(12632,3991,'75629','watch-mobile','font-family','$font-1',0,''),(12633,3991,'75629','watch-mobile','font-size','18',0,''),(12634,3991,'75629','watch-mobile','text-transform','uppercase',0,''),(12635,3992,'75630','watch-mobile','class','menu-style-2',0,''),(12636,3992,'75630','watch-mobile','padding-top','10',0,''),(12637,3992,'75630','watch-mobile','padding-bottom','20',0,''),(12638,3993,'75632','watch-mobile','border-top-width','1',0,''),(12639,3993,'75632','watch-mobile','border-top-color','$border-color-1',0,''),(12640,3993,'75632','watch-mobile','padding-top','20',0,''),(12641,3994,'75633','watch-mobile','block_type','1',0,''),(12642,3995,'75634','watch-mobile','class','menu-style-2',0,''),(12643,3995,'75634','watch-mobile','padding-top','10',0,''),(12644,3995,'75634','watch-mobile','padding-bottom','20',0,''),(12645,3996,'75635','watch-mobile','text','Shop',1,''),(12646,3996,'75635','watch-mobile','style_class','footerTitle',0,''),(12649,3996,'75635','watch-mobile','font-family','$font-1',0,''),(12650,3996,'75635','watch-mobile','font-size','18',0,''),(12651,3996,'75635','watch-mobile','text-transform','uppercase',0,''),(12652,3997,'75636','watch-mobile','block_type','1',0,''),(12653,3998,'75637','watch-mobile','text','Products',1,''),(12654,3998,'75637','watch-mobile','style_class','footerTitle',0,''),(12657,3998,'75637','watch-mobile','font-family','$font-1',0,''),(12658,3998,'75637','watch-mobile','text-transform','uppercase',0,''),(12659,3998,'75637','watch-mobile','font-size','18',0,''),(12660,3999,'75638','watch-mobile','class','menu-style-2',0,''),(12661,3999,'75638','watch-mobile','padding-top','10',0,''),(12662,3999,'75638','watch-mobile','padding-bottom','20',0,''),(12663,4000,'75640','watch-mobile','block_type','1',0,''),(12664,4001,'75641','watch-mobile','view_item','address',0,''),(12665,4001,'75641','watch-mobile','address_spacer',',<span> </span>',0,''),(12666,4001,'75641','watch-mobile','padding-top','10',0,''),(12667,4001,'75641','watch-mobile','padding-bottom','20',0,''),(12668,4002,'75642','watch-mobile','text','Contact Us',1,''),(12669,4002,'75642','watch-mobile','style_class','footerTitle',0,''),(12672,4002,'75642','watch-mobile','font-family','$font-1',0,''),(12673,4002,'75642','watch-mobile','font-size','18',0,''),(12674,4002,'75642','watch-mobile','text-transform','uppercase',0,''),(12675,4003,'114441','watch-mobile','block_type','5',0,''),(12676,4004,'114442','watch-mobile','text','##TEXT_LANGUAGE##',0,''),(12677,4006,'114444','watch-mobile','block_type','5',0,''),(12678,4007,'114445','watch-mobile','text','##TEXT_CURRENCY##',0,''),(12679,4009,'75650','watch-mobile','block_type','1',0,''),(12680,4009,'75650','watch-mobile','font-weight','normal',0,''),(12681,4010,'75651','watch-mobile','block_type','2',0,''),(12682,4010,'75651','watch-mobile','font-weight','normal',0,''),(12683,4010,'75651','watch-mobile','padding-bottom','20',0,''),(12684,4011,'75652','watch-mobile','block_type','1',0,''),(12685,4011,'75652','watch-mobile','margin-right','20',0,''),(12686,4012,'75653','watch-mobile','block_type','1',0,''),(12687,4012,'75653','watch-mobile','font-weight','normal',0,''),(12688,4012,'75653','watch-mobile','style_class','gift-card-view',0,''),(12689,4012,'75653','watch-mobile','text-align','center',0,''),(12690,4012,'75653','watch-mobile','padding-bottom','20',0,''),(12691,4012,'75653','watch-mobile','background-color','$background-2',0,''),(12692,4012,'75653','watch-mobile','padding-left','20',0,''),(12693,4012,'75653','watch-mobile','padding-right','20',0,''),(12694,4012,'75653','watch-mobile','color','$color-font-2',0,''),(12695,4013,'75654','watch-mobile','block_type','1',0,''),(12696,4013,'75654','watch-mobile','font-weight','normal',0,''),(12697,4013,'75654','watch-mobile','padding-top','10',0,''),(12698,4014,'75655','watch-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(12699,4014,'75655','watch-mobile','font-weight','normal',0,''),(12700,4014,'75655','watch-mobile','text-align','center',0,''),(12701,4014,'75655','watch-mobile','font-size','12',0,''),(12702,4014,'75655','watch-mobile','padding-top','10',0,''),(12703,4014,'75655','watch-mobile','padding-bottom','5',0,''),(12704,4014,'75655','watch-mobile','border-top-width','1',0,''),(12705,4014,'75655','watch-mobile','border-top-color','$border-color-7',0,''),(12706,4015,'75656','watch-mobile','font-size','12',0,''),(12707,4015,'75656','watch-mobile','font-weight','bold',0,''),(12708,4015,'75656','watch-mobile','text-align','center',0,''),(12709,4015,'75656','watch-mobile','style_class','email',0,''),(12710,4016,'75657','watch-mobile','font-size','12',0,''),(12711,4016,'75657','watch-mobile','font-weight','bold',0,''),(12712,4016,'75657','watch-mobile','text-align','center',0,''),(12713,4016,'75657','watch-mobile','style_class','phone',0,''),(12714,4016,'75657','watch-mobile','padding-bottom','5',0,''),(12715,4017,'75658','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(12716,4017,'75658','watch-mobile','font-weight','normal',0,''),(12717,4017,'75658','watch-mobile','text-align','center',0,''),(12718,4017,'75658','watch-mobile','padding-top','20',0,''),(12719,4017,'75658','watch-mobile','padding-bottom','10',0,''),(12720,4017,'75658','watch-mobile','style_class','question-ico',0,''),(12721,4017,'75658','watch-mobile','border-top-width','1',0,''),(12722,4017,'75658','watch-mobile','border-top-color','$border-color-7',0,''),(12723,4017,'75658','watch-mobile','font-size','18',0,''),(12724,4018,'75659','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(12725,4018,'75659','watch-mobile','font-size','18',0,''),(12726,4018,'75659','watch-mobile','font-weight','normal',0,''),(12727,4018,'75659','watch-mobile','text-align','center',0,''),(12728,4018,'75659','watch-mobile','padding-top','20',0,''),(12729,4018,'75659','watch-mobile','padding-bottom','10',0,''),(12730,4018,'75659','watch-mobile','border-top-width','1',0,''),(12731,4018,'75659','watch-mobile','border-top-color','$border-color-7',0,''),(12732,4019,'75660','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(12733,4019,'75660','watch-mobile','font-weight','normal',0,''),(12734,4019,'75660','watch-mobile','text-align','center',0,''),(12735,4019,'75660','watch-mobile','padding-bottom','10',0,''),(12736,4019,'75660','watch-mobile','font-size','14',0,''),(12737,4020,'75661','watch-mobile','text','<p>GIFT CARD</p>',1,''),(12738,4020,'75661','watch-mobile','font-size','30',0,''),(12739,4020,'75661','watch-mobile','font-weight','normal',0,''),(12740,4020,'75661','watch-mobile','border-top-width','1',0,''),(12741,4020,'75661','watch-mobile','border-top-color','$border-color-7',0,''),(12742,4020,'75661','watch-mobile','style_class','gift-ico',0,''),(12743,4020,'75661','watch-mobile','text-align','center',0,''),(12744,4020,'75661','watch-mobile','padding-top','15',0,''),(12745,4021,'75662','watch-mobile','block_type','4',0,''),(12746,4021,'75662','watch-mobile','color','$color-font-1',0,''),(12747,4021,'75662','watch-mobile','font-size','30',0,''),(12748,4021,'75662','watch-mobile','font-weight','normal',0,''),(12749,4021,'75662','watch-mobile','background-color','$background-5',0,''),(12750,4021,'75662','watch-mobile','padding-top','5',0,''),(12751,4021,'75662','watch-mobile','padding-left','10',0,''),(12752,4021,'75662','watch-mobile','padding-right','10',0,''),(12753,4021,'75662','watch-mobile','padding-bottom','5',0,''),(12754,4022,'75663','watch-mobile','text','<p>Your code is:</p>',1,''),(12755,4022,'75663','watch-mobile','font-weight','normal',0,''),(12756,4024,'75665','watch-mobile','font-weight','normal',0,''),(12757,4024,'75665','watch-mobile','text-align','center',0,''),(12758,4024,'75665','watch-mobile','padding-bottom','20',0,''),(12759,4025,'75666','watch-mobile','font-size','60',0,''),(12760,4025,'75666','watch-mobile','font-weight','bold',0,''),(12761,4025,'75666','watch-mobile','text-align','center',0,''),(12762,4025,'75666','watch-mobile','line-height','100',0,''),(12763,4025,'75666','watch-mobile','padding-bottom','20',0,''),(12764,4025,'75666','watch-mobile','line_height_measure','px',0,''),(12765,4026,'75667','watch-mobile','text','<p>HOLBI</p>',1,''),(12766,4026,'75667','watch-mobile','font-family','$font-1',0,''),(12767,4026,'75667','watch-mobile','font-size','24',0,''),(12768,4026,'75667','watch-mobile','font-weight','normal',0,''),(12769,4026,'75667','watch-mobile','text-align','center',0,''),(12770,4026,'75667','watch-mobile','padding-top','10',0,''),(12771,4026,'75667','watch-mobile','padding-bottom','20',0,''),(12772,4028,'75669','watch-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(12773,4028,'75669','watch-mobile','font-weight','normal',0,''),(12774,4028,'75669','watch-mobile','padding-bottom','20',0,''),(12775,4030,'114447','watch-mobile','block_type','1',0,''),(12776,4030,'114447','watch-mobile','font-weight','normal',0,''),(12777,4030,'114447','watch-mobile','style_class','gift-card-view',0,''),(12778,4030,'114447','watch-mobile','text-align','center',0,''),(12779,4030,'114447','watch-mobile','padding-bottom','20',0,''),(12780,4030,'114447','watch-mobile','background-color','$background-2',0,''),(12781,4030,'114447','watch-mobile','padding-left','20',0,''),(12782,4030,'114447','watch-mobile','padding-right','20',0,''),(12783,4030,'114447','watch-mobile','color','$color-font-2',0,''),(12784,4031,'114448','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(12785,4031,'114448','watch-mobile','font-weight','normal',0,''),(12786,4031,'114448','watch-mobile','text-align','center',0,''),(12787,4031,'114448','watch-mobile','padding-bottom','10',0,''),(12788,4031,'114448','watch-mobile','font-size','14',0,''),(12789,4032,'114449','watch-mobile','text','<p>GIFT CARD</p>',1,''),(12790,4032,'114449','watch-mobile','font-size','30',0,''),(12791,4032,'114449','watch-mobile','font-weight','normal',0,''),(12792,4032,'114449','watch-mobile','border-top-width','1',0,''),(12793,4032,'114449','watch-mobile','border-top-color','$border-color-7',0,''),(12794,4032,'114449','watch-mobile','style_class','gift-ico',0,''),(12795,4032,'114449','watch-mobile','text-align','center',0,''),(12796,4032,'114449','watch-mobile','padding-top','15',0,''),(12797,4033,'114450','watch-mobile','logo','themes/watch-mobile/img/logo-1.png',1,''),(12798,4034,'114451','watch-mobile','logo','themes/watch-mobile/img/bestseller-1.png',1,''),(12799,4035,'114452','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(12800,4035,'114452','watch-mobile','font-size','18',0,''),(12801,4035,'114452','watch-mobile','font-weight','normal',0,''),(12802,4035,'114452','watch-mobile','text-align','center',0,''),(12803,4035,'114452','watch-mobile','padding-top','20',0,''),(12804,4035,'114452','watch-mobile','padding-bottom','10',0,''),(12805,4035,'114452','watch-mobile','border-top-width','1',0,''),(12806,4035,'114452','watch-mobile','border-top-color','$border-color-7',0,''),(12807,4036,'114453','watch-mobile','font-size','60',0,''),(12808,4036,'114453','watch-mobile','font-weight','bold',0,''),(12809,4036,'114453','watch-mobile','text-align','center',0,''),(12810,4036,'114453','watch-mobile','line-height','100',0,''),(12811,4036,'114453','watch-mobile','padding-bottom','20',0,''),(12812,4036,'114453','watch-mobile','line_height_measure','px',0,''),(12813,4037,'114454','watch-mobile','font-weight','normal',0,''),(12814,4037,'114454','watch-mobile','text-align','center',0,''),(12815,4037,'114454','watch-mobile','padding-bottom','20',0,''),(12816,4038,'114455','watch-mobile','block_type','4',0,''),(12817,4038,'114455','watch-mobile','color','$color-font-1',0,''),(12818,4038,'114455','watch-mobile','font-size','30',0,''),(12819,4038,'114455','watch-mobile','font-weight','normal',0,''),(12820,4038,'114455','watch-mobile','background-color','$background-5',0,''),(12821,4038,'114455','watch-mobile','padding-top','5',0,''),(12822,4038,'114455','watch-mobile','padding-left','10',0,''),(12823,4038,'114455','watch-mobile','padding-right','10',0,''),(12824,4038,'114455','watch-mobile','padding-bottom','5',0,''),(12825,4039,'114456','watch-mobile','text','<p>Your code is:</p>',1,''),(12826,4039,'114456','watch-mobile','font-weight','normal',0,''),(12827,4041,'114458','watch-mobile','text','<p>HOLBI</p>',1,''),(12828,4041,'114458','watch-mobile','font-family','$font-1',0,''),(12829,4041,'114458','watch-mobile','font-size','24',0,''),(12830,4041,'114458','watch-mobile','font-weight','normal',0,''),(12831,4041,'114458','watch-mobile','text-align','center',0,''),(12832,4041,'114458','watch-mobile','padding-top','10',0,''),(12833,4041,'114458','watch-mobile','padding-bottom','20',0,''),(12834,4042,'114459','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(12835,4042,'114459','watch-mobile','font-weight','normal',0,''),(12836,4042,'114459','watch-mobile','text-align','center',0,''),(12837,4042,'114459','watch-mobile','padding-top','20',0,''),(12838,4042,'114459','watch-mobile','padding-bottom','10',0,''),(12839,4042,'114459','watch-mobile','style_class','question-ico',0,''),(12840,4042,'114459','watch-mobile','border-top-width','1',0,''),(12841,4042,'114459','watch-mobile','border-top-color','$border-color-7',0,''),(12842,4042,'114459','watch-mobile','font-size','18',0,''),(12843,4043,'114460','watch-mobile','block_type','1',0,''),(12844,4043,'114460','watch-mobile','font-weight','normal',0,''),(12845,4043,'114460','watch-mobile','padding-top','10',0,''),(12846,4044,'114461','watch-mobile','font-size','12',0,''),(12847,4044,'114461','watch-mobile','font-weight','bold',0,''),(12848,4044,'114461','watch-mobile','text-align','center',0,''),(12849,4044,'114461','watch-mobile','style_class','phone',0,''),(12850,4044,'114461','watch-mobile','padding-bottom','5',0,''),(12851,4045,'114462','watch-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(12852,4045,'114462','watch-mobile','font-weight','normal',0,''),(12853,4045,'114462','watch-mobile','text-align','center',0,''),(12854,4045,'114462','watch-mobile','font-size','12',0,''),(12855,4045,'114462','watch-mobile','padding-top','10',0,''),(12856,4045,'114462','watch-mobile','padding-bottom','5',0,''),(12857,4045,'114462','watch-mobile','border-top-width','1',0,''),(12858,4045,'114462','watch-mobile','border-top-color','$border-color-7',0,''),(12859,4046,'114463','watch-mobile','font-size','12',0,''),(12860,4046,'114463','watch-mobile','font-weight','bold',0,''),(12861,4046,'114463','watch-mobile','text-align','center',0,''),(12862,4046,'114463','watch-mobile','style_class','email',0,''),(12863,4047,'114464','watch-mobile','block_type','1',0,''),(12864,4047,'114464','watch-mobile','font-weight','normal',0,''),(12865,4047,'114464','watch-mobile','style_class','gift-card-view',0,''),(12866,4047,'114464','watch-mobile','text-align','center',0,''),(12867,4047,'114464','watch-mobile','padding-bottom','20',0,''),(12868,4047,'114464','watch-mobile','background-color','$background-2',0,''),(12869,4047,'114464','watch-mobile','padding-left','20',0,''),(12870,4047,'114464','watch-mobile','padding-right','20',0,''),(12871,4047,'114464','watch-mobile','color','$color-font-2',0,''),(12872,4048,'114465','watch-mobile','text','<p>HOLBI</p>',1,''),(12873,4048,'114465','watch-mobile','font-family','$font-1',0,''),(12874,4048,'114465','watch-mobile','font-size','24',0,''),(12875,4048,'114465','watch-mobile','font-weight','normal',0,''),(12876,4048,'114465','watch-mobile','text-align','center',0,''),(12877,4048,'114465','watch-mobile','padding-top','10',0,''),(12878,4048,'114465','watch-mobile','padding-bottom','20',0,''),(12879,4049,'114466','watch-mobile','text','<p>GIFT CARD</p>',1,''),(12880,4049,'114466','watch-mobile','font-size','30',0,''),(12881,4049,'114466','watch-mobile','font-weight','normal',0,''),(12882,4049,'114466','watch-mobile','border-top-width','1',0,''),(12883,4049,'114466','watch-mobile','border-top-color','$border-color-7',0,''),(12884,4049,'114466','watch-mobile','style_class','gift-ico',0,''),(12885,4049,'114466','watch-mobile','text-align','center',0,''),(12886,4049,'114466','watch-mobile','padding-top','15',0,''),(12887,4050,'114467','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(12888,4050,'114467','watch-mobile','font-weight','normal',0,''),(12889,4050,'114467','watch-mobile','text-align','center',0,''),(12890,4050,'114467','watch-mobile','padding-top','20',0,''),(12891,4050,'114467','watch-mobile','padding-bottom','10',0,''),(12892,4050,'114467','watch-mobile','style_class','question-ico',0,''),(12893,4050,'114467','watch-mobile','border-top-width','1',0,''),(12894,4050,'114467','watch-mobile','border-top-color','$border-color-7',0,''),(12895,4050,'114467','watch-mobile','font-size','18',0,''),(12896,4051,'114468','watch-mobile','font-weight','normal',0,''),(12897,4051,'114468','watch-mobile','text-align','center',0,''),(12898,4051,'114468','watch-mobile','padding-bottom','20',0,''),(12899,4052,'114469','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(12900,4052,'114469','watch-mobile','font-weight','normal',0,''),(12901,4052,'114469','watch-mobile','text-align','center',0,''),(12902,4052,'114469','watch-mobile','padding-bottom','10',0,''),(12903,4052,'114469','watch-mobile','font-size','14',0,''),(12904,4053,'114470','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(12905,4053,'114470','watch-mobile','font-size','18',0,''),(12906,4053,'114470','watch-mobile','font-weight','normal',0,''),(12907,4053,'114470','watch-mobile','text-align','center',0,''),(12908,4053,'114470','watch-mobile','padding-top','20',0,''),(12909,4053,'114470','watch-mobile','padding-bottom','10',0,''),(12911,4053,'114470','watch-mobile','border-top-color','$border-color-7',0,''),(12912,4054,'114471','watch-mobile','block_type','1',0,''),(12913,4054,'114471','watch-mobile','font-weight','normal',0,''),(12914,4054,'114471','watch-mobile','padding-top','10',0,''),(12915,4055,'114472','watch-mobile','font-size','12',0,''),(12916,4055,'114472','watch-mobile','font-weight','bold',0,''),(12917,4055,'114472','watch-mobile','text-align','center',0,''),(12918,4055,'114472','watch-mobile','style_class','phone',0,''),(12919,4055,'114472','watch-mobile','padding-bottom','5',0,''),(12920,4056,'114473','watch-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(12921,4056,'114473','watch-mobile','font-weight','normal',0,''),(12922,4056,'114473','watch-mobile','text-align','center',0,''),(12923,4056,'114473','watch-mobile','font-size','12',0,''),(12924,4056,'114473','watch-mobile','padding-top','10',0,''),(12925,4056,'114473','watch-mobile','padding-bottom','5',0,''),(12927,4056,'114473','watch-mobile','border-top-color','$border-color-7',0,''),(12928,4057,'114474','watch-mobile','font-size','12',0,''),(12929,4057,'114474','watch-mobile','font-weight','bold',0,''),(12930,4057,'114474','watch-mobile','text-align','center',0,''),(12931,4057,'114474','watch-mobile','style_class','email',0,''),(12932,4058,'114475','watch-mobile','block_type','4',0,''),(12933,4058,'114475','watch-mobile','color','$color-font-1',0,''),(12934,4058,'114475','watch-mobile','font-size','30',0,''),(12935,4058,'114475','watch-mobile','font-weight','normal',0,''),(12936,4058,'114475','watch-mobile','background-color','$background-5',0,''),(12937,4058,'114475','watch-mobile','padding-top','5',0,''),(12938,4058,'114475','watch-mobile','padding-left','10',0,''),(12939,4058,'114475','watch-mobile','padding-right','10',0,''),(12940,4058,'114475','watch-mobile','padding-bottom','5',0,''),(12941,4059,'114476','watch-mobile','text','<p>Your code is:</p>',1,''),(12943,4061,'114478','watch-mobile','font-size','60',0,''),(12944,4061,'114478','watch-mobile','font-weight','bold',0,''),(12945,4061,'114478','watch-mobile','text-align','center',0,''),(12946,4061,'114478','watch-mobile','line-height','100',0,''),(12947,4061,'114478','watch-mobile','padding-bottom','20',0,''),(12948,4061,'114478','watch-mobile','line_height_measure','px',0,''),(12949,4062,'114479','watch-mobile','block_type','1',0,''),(12950,4062,'114479','watch-mobile','font-weight','normal',0,''),(12951,4062,'114479','watch-mobile','style_class','gift-card-view',0,''),(12952,4062,'114479','watch-mobile','text-align','center',0,''),(12953,4062,'114479','watch-mobile','padding-bottom','20',0,''),(12954,4062,'114479','watch-mobile','background-color','$background-2',0,''),(12955,4062,'114479','watch-mobile','padding-left','20',0,''),(12956,4062,'114479','watch-mobile','padding-right','20',0,''),(12957,4062,'114479','watch-mobile','color','$color-font-2',0,''),(12959,4063,'114480','watch-mobile','font-weight','normal',0,''),(12960,4063,'114480','watch-mobile','padding-top','10',0,''),(12961,4064,'114481','watch-mobile','font-size','12',0,''),(12962,4064,'114481','watch-mobile','font-weight','bold',0,''),(12963,4064,'114481','watch-mobile','text-align','center',0,''),(12964,4064,'114481','watch-mobile','style_class','email',0,''),(12965,4064,'114481','watch-mobile','color','$color-font-1',0,''),(12966,4065,'114482','watch-mobile','font-size','12',0,''),(12967,4065,'114482','watch-mobile','font-weight','bold',0,''),(12968,4065,'114482','watch-mobile','text-align','center',0,''),(12969,4065,'114482','watch-mobile','style_class','phone',0,''),(12970,4065,'114482','watch-mobile','padding-bottom','5',0,''),(12971,4065,'114482','watch-mobile','color','$color-font-1',0,''),(12972,4066,'114483','watch-mobile','text','If you require further assistance please contact us',0,''),(12973,4066,'114483','watch-mobile','font-size','12',0,''),(12975,4066,'114483','watch-mobile','text-align','center',0,''),(12976,4066,'114483','watch-mobile','padding-top','10',0,''),(12977,4067,'114484','watch-mobile','block_type','4',0,''),(12978,4067,'114484','watch-mobile','color','$color-font-1',0,''),(12979,4067,'114484','watch-mobile','font-size','30',0,''),(12980,4067,'114484','watch-mobile','font-weight','normal',0,''),(12981,4067,'114484','watch-mobile','background-color','$background-5',0,''),(12982,4067,'114484','watch-mobile','padding-top','5',0,''),(12983,4067,'114484','watch-mobile','padding-left','10',0,''),(12984,4067,'114484','watch-mobile','padding-right','10',0,''),(12985,4067,'114484','watch-mobile','padding-bottom','5',0,''),(12986,4068,'114485','watch-mobile','text','Your code is:',0,''),(12987,4068,'114485','watch-mobile','font-size','30',0,''),(12988,4068,'114485','watch-mobile','color','$color-font-1',0,''),(12989,4069,'114486','watch-mobile','color','$color-font-1',0,''),(12991,4070,'114487','watch-mobile','block_type','1',0,''),(12992,4071,'114488','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(12993,4071,'114488','watch-mobile','font-size','18',0,''),(12994,4071,'114488','watch-mobile','font-weight','normal',0,''),(12995,4071,'114488','watch-mobile','text-align','center',0,''),(12996,4071,'114488','watch-mobile','padding-top','20',0,''),(12997,4071,'114488','watch-mobile','padding-bottom','10',0,''),(12998,4071,'114488','watch-mobile','border-top-width','1',0,''),(12999,4071,'114488','watch-mobile','border-top-color','$border-color-7',0,''),(13000,4072,'114489','watch-mobile','text','HOLBI',0,''),(13001,4072,'114489','watch-mobile','color','$color-font-1',0,''),(13002,4072,'114489','watch-mobile','font-size','24',0,''),(13003,4072,'114489','watch-mobile','padding-top','20',0,''),(13004,4072,'114489','watch-mobile','text-align','center',0,''),(13005,4072,'114489','watch-mobile','padding-bottom','20',0,''),(13006,4073,'114490','watch-mobile','border-top-color','$border-color-7',0,''),(13007,4073,'114490','watch-mobile','border-top-width','1',0,''),(13008,4073,'114490','watch-mobile','padding-top','20',0,''),(13009,4073,'114490','watch-mobile','font-size','30',0,''),(13010,4073,'114490','watch-mobile','text-align','center',0,''),(13011,4073,'114490','watch-mobile','color','$color-font-1',0,''),(13012,4073,'114490','watch-mobile','text','GIFT CARD',0,''),(13013,4074,'114491','watch-mobile','text-align','center',0,''),(13014,4074,'114491','watch-mobile','font-weight','bold',0,''),(13015,4074,'114491','watch-mobile','font-size','60',0,''),(13016,4074,'114491','watch-mobile','color','$color-font-1',0,''),(13017,4075,'114492','watch-mobile','font-size','20',0,''),(13018,4075,'114492','watch-mobile','text-align','center',0,''),(13019,4075,'114492','watch-mobile','color','$color-font-1',0,''),(13020,4075,'114492','watch-mobile','padding-top','20',0,''),(13021,4075,'114492','watch-mobile','padding-bottom','20',0,''),(13022,4076,'114493','watch-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(13023,4076,'114493','watch-mobile','text-align','center',0,''),(13024,4076,'114493','watch-mobile','color','$color-font-1',0,''),(13025,4076,'114493','watch-mobile','font-size','14',0,''),(13026,4076,'114493','watch-mobile','padding-bottom','20',0,''),(13027,4077,'114494','watch-mobile','text','WHAT TO DO NEXT:',0,''),(13028,4077,'114494','watch-mobile','font-size','18',0,''),(13029,4077,'114494','watch-mobile','text-align','center',0,''),(13030,4077,'114494','watch-mobile','color','$color-font-1',0,''),(13031,4077,'114494','watch-mobile','padding-top','20',0,''),(13032,4077,'114494','watch-mobile','padding-bottom','10',0,''),(13033,4077,'114494','watch-mobile','border-top-width','1',0,''),(13034,4077,'114494','watch-mobile','border-top-color','$border-color-7',0,''),(13035,4079,'114496','watch-mobile','block_type','1',0,''),(13036,4079,'114496','watch-mobile','font-weight','normal',0,''),(13037,4079,'114496','watch-mobile','style_class','gift-card-view',0,''),(13038,4079,'114496','watch-mobile','text-align','center',0,''),(13039,4079,'114496','watch-mobile','padding-bottom','20',0,''),(13040,4079,'114496','watch-mobile','background-color','$background-2',0,''),(13041,4079,'114496','watch-mobile','padding-left','20',0,''),(13042,4079,'114496','watch-mobile','padding-right','20',0,''),(13043,4079,'114496','watch-mobile','color','$color-font-2',0,''),(13044,4080,'114497','watch-mobile','block_type','1',0,''),(13045,4080,'114497','watch-mobile','font-weight','normal',0,''),(13046,4080,'114497','watch-mobile','padding-top','10',0,''),(13047,4081,'114498','watch-mobile','font-size','12',0,''),(13048,4081,'114498','watch-mobile','font-weight','bold',0,''),(13049,4081,'114498','watch-mobile','text-align','center',0,''),(13050,4081,'114498','watch-mobile','style_class','email',0,''),(13051,4081,'114498','watch-mobile','color','$color-font-1',0,''),(13052,4082,'114499','watch-mobile','font-size','12',0,''),(13053,4082,'114499','watch-mobile','font-weight','bold',0,''),(13054,4082,'114499','watch-mobile','text-align','center',0,''),(13055,4082,'114499','watch-mobile','style_class','phone',0,''),(13056,4082,'114499','watch-mobile','padding-bottom','5',0,''),(13057,4082,'114499','watch-mobile','color','$color-font-1',0,''),(13058,4083,'114500','watch-mobile','text','If you require further assistance please contact us',0,''),(13059,4083,'114500','watch-mobile','font-size','12',0,''),(13060,4083,'114500','watch-mobile','color','$color-font-1',0,''),(13061,4083,'114500','watch-mobile','text-align','center',0,''),(13062,4083,'114500','watch-mobile','padding-top','10',0,''),(13063,4084,'114501','watch-mobile','block_type','4',0,''),(13064,4084,'114501','watch-mobile','color','$color-font-1',0,''),(13065,4084,'114501','watch-mobile','font-size','30',0,''),(13066,4084,'114501','watch-mobile','font-weight','normal',0,''),(13067,4084,'114501','watch-mobile','background-color','$background-5',0,''),(13068,4084,'114501','watch-mobile','padding-top','5',0,''),(13069,4084,'114501','watch-mobile','padding-left','10',0,''),(13070,4084,'114501','watch-mobile','padding-right','10',0,''),(13071,4084,'114501','watch-mobile','padding-bottom','5',0,''),(13072,4085,'114502','watch-mobile','text','Your code is:',0,''),(13073,4085,'114502','watch-mobile','font-size','30',0,''),(13074,4085,'114502','watch-mobile','color','$color-font-1',0,''),(13075,4086,'114503','watch-mobile','color','$color-font-1',0,''),(13076,4086,'114503','watch-mobile','font-size','30',0,''),(13077,4087,'114504','watch-mobile','block_type','1',0,''),(13078,4088,'114505','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(13079,4088,'114505','watch-mobile','font-size','18',0,''),(13080,4088,'114505','watch-mobile','font-weight','normal',0,''),(13081,4088,'114505','watch-mobile','text-align','center',0,''),(13082,4088,'114505','watch-mobile','padding-top','20',0,''),(13083,4088,'114505','watch-mobile','padding-bottom','10',0,''),(13084,4088,'114505','watch-mobile','border-top-width','1',0,''),(13085,4088,'114505','watch-mobile','border-top-color','$border-color-7',0,''),(13086,4089,'114506','watch-mobile','text','HOLBI',0,''),(13087,4089,'114506','watch-mobile','color','$color-font-1',0,''),(13088,4089,'114506','watch-mobile','font-size','24',0,''),(13089,4089,'114506','watch-mobile','padding-top','20',0,''),(13090,4089,'114506','watch-mobile','text-align','center',0,''),(13091,4089,'114506','watch-mobile','padding-bottom','20',0,''),(13092,4090,'114507','watch-mobile','border-top-color','$border-color-7',0,''),(13093,4090,'114507','watch-mobile','border-top-width','1',0,''),(13094,4090,'114507','watch-mobile','padding-top','20',0,''),(13095,4090,'114507','watch-mobile','font-size','30',0,''),(13096,4090,'114507','watch-mobile','text-align','center',0,''),(13097,4090,'114507','watch-mobile','color','$color-font-1',0,''),(13098,4090,'114507','watch-mobile','text','GIFT CARD',0,''),(13099,4091,'114508','watch-mobile','text-align','center',0,''),(13100,4091,'114508','watch-mobile','font-weight','bold',0,''),(13101,4091,'114508','watch-mobile','font-size','60',0,''),(13102,4091,'114508','watch-mobile','color','$color-font-1',0,''),(13103,4092,'114509','watch-mobile','font-size','20',0,''),(13104,4092,'114509','watch-mobile','text-align','center',0,''),(13105,4092,'114509','watch-mobile','color','$color-font-1',0,''),(13106,4092,'114509','watch-mobile','padding-top','20',0,''),(13107,4092,'114509','watch-mobile','padding-bottom','20',0,''),(13108,4093,'114510','watch-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(13109,4093,'114510','watch-mobile','text-align','center',0,''),(13110,4093,'114510','watch-mobile','color','$color-font-1',0,''),(13111,4093,'114510','watch-mobile','font-size','14',0,''),(13112,4093,'114510','watch-mobile','padding-bottom','20',0,''),(13113,4094,'114511','watch-mobile','text','WHAT TO DO NEXT:',0,''),(13114,4094,'114511','watch-mobile','font-size','18',0,''),(13115,4094,'114511','watch-mobile','text-align','center',0,''),(13116,4094,'114511','watch-mobile','color','$color-font-1',0,''),(13117,4094,'114511','watch-mobile','padding-top','20',0,''),(13118,4094,'114511','watch-mobile','padding-bottom','10',0,''),(13119,4094,'114511','watch-mobile','border-top-width','1',0,''),(13120,4094,'114511','watch-mobile','border-top-color','$border-color-7',0,''),(13121,4096,'114513','watch-mobile','block_type','1',0,''),(13122,4098,'114515','watch-mobile','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(13123,4098,'114515','watch-mobile','text-align','center',0,''),(13124,4099,'114516','watch-mobile','block_type','1',0,''),(13125,4099,'114516','watch-mobile','font-weight','normal',0,''),(13126,4099,'114516','watch-mobile','style_class','gift-card-view',0,''),(13127,4099,'114516','watch-mobile','text-align','center',0,''),(13128,4099,'114516','watch-mobile','padding-bottom','20',0,''),(13129,4099,'114516','watch-mobile','background-color','$message-color',0,''),(13130,4099,'114516','watch-mobile','padding-left','20',0,''),(13131,4099,'114516','watch-mobile','padding-right','20',0,''),(13132,4099,'114516','watch-mobile','color','$color-font-2',0,''),(13133,4100,'114517','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(13134,4100,'114517','watch-mobile','font-weight','normal',0,''),(13135,4100,'114517','watch-mobile','text-align','center',0,''),(13136,4100,'114517','watch-mobile','padding-bottom','10',0,''),(13137,4100,'114517','watch-mobile','font-size','14',0,''),(13138,4101,'114518','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(13139,4101,'114518','watch-mobile','font-size','18',0,''),(13140,4101,'114518','watch-mobile','font-weight','normal',0,''),(13141,4101,'114518','watch-mobile','text-align','center',0,''),(13142,4101,'114518','watch-mobile','padding-top','20',0,''),(13143,4101,'114518','watch-mobile','padding-bottom','10',0,''),(13144,4101,'114518','watch-mobile','border-top-width','1',0,''),(13145,4101,'114518','watch-mobile','border-top-color','$border-color-7',0,''),(13146,4102,'114519','watch-mobile','font-size','60',0,''),(13147,4102,'114519','watch-mobile','font-weight','bold',0,''),(13148,4102,'114519','watch-mobile','text-align','center',0,''),(13149,4102,'114519','watch-mobile','line-height','100',0,''),(13150,4102,'114519','watch-mobile','padding-bottom','20',0,''),(13151,4102,'114519','watch-mobile','line_height_measure','px',0,''),(13152,4103,'114520','watch-mobile','text','<p>GIFT CARD</p>',1,''),(13153,4103,'114520','watch-mobile','font-size','30',0,''),(13154,4103,'114520','watch-mobile','font-weight','normal',0,''),(13155,4103,'114520','watch-mobile','border-top-width','1',0,''),(13156,4103,'114520','watch-mobile','border-top-color','$border-color-7',0,''),(13157,4103,'114520','watch-mobile','style_class','gift-ico',0,''),(13158,4103,'114520','watch-mobile','text-align','center',0,''),(13159,4103,'114520','watch-mobile','padding-top','15',0,''),(13160,4104,'114521','watch-mobile','font-weight','normal',0,''),(13161,4104,'114521','watch-mobile','text-align','center',0,''),(13162,4104,'114521','watch-mobile','padding-bottom','20',0,''),(13163,4105,'114522','watch-mobile','text','<p>HOLBI</p>',1,''),(13164,4105,'114522','watch-mobile','font-family','$font-1',0,''),(13165,4105,'114522','watch-mobile','font-size','24',0,''),(13166,4105,'114522','watch-mobile','font-weight','normal',0,''),(13167,4105,'114522','watch-mobile','text-align','center',0,''),(13168,4105,'114522','watch-mobile','padding-top','10',0,''),(13169,4105,'114522','watch-mobile','padding-bottom','20',0,''),(13170,4106,'114523','watch-mobile','block_type','1',0,''),(13171,4106,'114523','watch-mobile','font-weight','normal',0,''),(13172,4106,'114523','watch-mobile','padding-top','10',0,''),(13173,4107,'114524','watch-mobile','font-size','12',0,''),(13174,4107,'114524','watch-mobile','font-weight','bold',0,''),(13175,4107,'114524','watch-mobile','text-align','center',0,''),(13176,4107,'114524','watch-mobile','style_class','email',0,''),(13177,4108,'114525','watch-mobile','font-size','12',0,''),(13178,4108,'114525','watch-mobile','font-weight','bold',0,''),(13179,4108,'114525','watch-mobile','text-align','center',0,''),(13180,4108,'114525','watch-mobile','style_class','phone',0,''),(13181,4108,'114525','watch-mobile','padding-bottom','5',0,''),(13182,4109,'114526','watch-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(13183,4109,'114526','watch-mobile','font-weight','normal',0,''),(13184,4109,'114526','watch-mobile','text-align','center',0,''),(13185,4109,'114526','watch-mobile','font-size','12',0,''),(13186,4109,'114526','watch-mobile','padding-top','10',0,''),(13187,4109,'114526','watch-mobile','padding-bottom','5',0,''),(13188,4109,'114526','watch-mobile','border-top-width','1',0,''),(13189,4109,'114526','watch-mobile','border-top-color','$border-color-7',0,''),(13190,4110,'114527','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(13191,4110,'114527','watch-mobile','font-weight','normal',0,''),(13192,4110,'114527','watch-mobile','text-align','center',0,''),(13193,4110,'114527','watch-mobile','padding-top','20',0,''),(13194,4110,'114527','watch-mobile','padding-bottom','10',0,''),(13195,4110,'114527','watch-mobile','style_class','question-ico',0,''),(13196,4110,'114527','watch-mobile','border-top-width','1',0,''),(13197,4110,'114527','watch-mobile','border-top-color','$border-color-7',0,''),(13198,4110,'114527','watch-mobile','font-size','18',0,''),(13199,4111,'114528','watch-mobile','block_type','4',0,''),(13200,4111,'114528','watch-mobile','color','$color-font-1',0,''),(13201,4111,'114528','watch-mobile','font-size','30',0,''),(13202,4111,'114528','watch-mobile','font-weight','normal',0,''),(13203,4111,'114528','watch-mobile','background-color','$background-5',0,''),(13204,4111,'114528','watch-mobile','padding-top','5',0,''),(13205,4111,'114528','watch-mobile','padding-left','10',0,''),(13206,4111,'114528','watch-mobile','padding-right','10',0,''),(13207,4111,'114528','watch-mobile','padding-bottom','5',0,''),(13208,4112,'114529','watch-mobile','text','<p>Your code is:</p>',1,''),(13209,4112,'114529','watch-mobile','font-weight','normal',0,''),(13210,4114,'114531','watch-mobile','block_type','1',0,''),(13211,4114,'114531','watch-mobile','font-weight','normal',0,''),(13212,4114,'114531','watch-mobile','style_class','gift-card-view',0,''),(13213,4114,'114531','watch-mobile','text-align','center',0,''),(13214,4114,'114531','watch-mobile','padding-bottom','20',0,''),(13215,4114,'114531','watch-mobile','background-color','$message-color',0,''),(13216,4114,'114531','watch-mobile','padding-left','20',0,''),(13217,4114,'114531','watch-mobile','padding-right','20',0,''),(13218,4114,'114531','watch-mobile','color','$color-font-2',0,''),(13219,4115,'114532','watch-mobile','block_type','1',0,''),(13220,4115,'114532','watch-mobile','font-weight','normal',0,''),(13221,4115,'114532','watch-mobile','padding-top','10',0,''),(13222,4116,'114533','watch-mobile','font-size','12',0,''),(13223,4116,'114533','watch-mobile','font-weight','bold',0,''),(13224,4116,'114533','watch-mobile','text-align','center',0,''),(13225,4116,'114533','watch-mobile','style_class','email',0,''),(13226,4116,'114533','watch-mobile','color','$color-font-1',0,''),(13227,4117,'114534','watch-mobile','font-size','12',0,''),(13228,4117,'114534','watch-mobile','font-weight','bold',0,''),(13229,4117,'114534','watch-mobile','text-align','center',0,''),(13230,4117,'114534','watch-mobile','style_class','phone',0,''),(13231,4117,'114534','watch-mobile','padding-bottom','5',0,''),(13232,4117,'114534','watch-mobile','color','$color-font-1',0,''),(13233,4118,'114535','watch-mobile','text','If you require further assistance please contact us',0,''),(13234,4118,'114535','watch-mobile','font-size','12',0,''),(13235,4118,'114535','watch-mobile','color','$color-font-1',0,''),(13236,4118,'114535','watch-mobile','text-align','center',0,''),(13237,4118,'114535','watch-mobile','padding-top','10',0,''),(13238,4119,'114536','watch-mobile','block_type','4',0,''),(13239,4119,'114536','watch-mobile','color','$color-font-1',0,''),(13240,4119,'114536','watch-mobile','font-size','30',0,''),(13241,4119,'114536','watch-mobile','font-weight','normal',0,''),(13242,4119,'114536','watch-mobile','background-color','$background-5',0,''),(13243,4119,'114536','watch-mobile','padding-top','5',0,''),(13244,4119,'114536','watch-mobile','padding-left','10',0,''),(13245,4119,'114536','watch-mobile','padding-right','10',0,''),(13246,4119,'114536','watch-mobile','padding-bottom','5',0,''),(13247,4120,'114537','watch-mobile','text','Your code is:',0,''),(13248,4120,'114537','watch-mobile','font-size','30',0,''),(13249,4120,'114537','watch-mobile','color','$color-font-1',0,''),(13250,4121,'114538','watch-mobile','color','$color-font-1',0,''),(13251,4121,'114538','watch-mobile','font-size','30',0,''),(13252,4122,'114539','watch-mobile','block_type','1',0,''),(13253,4123,'114540','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(13254,4123,'114540','watch-mobile','font-size','18',0,''),(13255,4123,'114540','watch-mobile','font-weight','normal',0,''),(13256,4123,'114540','watch-mobile','text-align','center',0,''),(13257,4123,'114540','watch-mobile','padding-top','20',0,''),(13258,4123,'114540','watch-mobile','padding-bottom','10',0,''),(13259,4123,'114540','watch-mobile','border-top-width','1',0,''),(13260,4123,'114540','watch-mobile','border-top-color','$border-color-7',0,''),(13261,4124,'114541','watch-mobile','text','HOLBI',0,''),(13262,4124,'114541','watch-mobile','color','$color-font-1',0,''),(13263,4124,'114541','watch-mobile','font-size','24',0,''),(13264,4124,'114541','watch-mobile','padding-top','20',0,''),(13265,4124,'114541','watch-mobile','text-align','center',0,''),(13266,4124,'114541','watch-mobile','padding-bottom','20',0,''),(13267,4125,'114542','watch-mobile','border-top-color','$border-color-7',0,''),(13268,4125,'114542','watch-mobile','border-top-width','1',0,''),(13269,4125,'114542','watch-mobile','padding-top','20',0,''),(13270,4125,'114542','watch-mobile','font-size','30',0,''),(13271,4125,'114542','watch-mobile','text-align','center',0,''),(13272,4125,'114542','watch-mobile','color','$color-font-1',0,''),(13273,4125,'114542','watch-mobile','text','GIFT CARD',0,''),(13274,4126,'114543','watch-mobile','text-align','center',0,''),(13275,4126,'114543','watch-mobile','font-weight','bold',0,''),(13276,4126,'114543','watch-mobile','font-size','60',0,''),(13277,4126,'114543','watch-mobile','color','$color-font-1',0,''),(13278,4127,'114544','watch-mobile','font-size','20',0,''),(13279,4127,'114544','watch-mobile','text-align','center',0,''),(13280,4127,'114544','watch-mobile','color','$color-font-1',0,''),(13281,4127,'114544','watch-mobile','padding-top','20',0,''),(13282,4127,'114544','watch-mobile','padding-bottom','20',0,''),(13283,4128,'114545','watch-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(13284,4128,'114545','watch-mobile','text-align','center',0,''),(13285,4128,'114545','watch-mobile','color','$color-font-1',0,''),(13286,4128,'114545','watch-mobile','font-size','14',0,''),(13287,4128,'114545','watch-mobile','padding-bottom','20',0,''),(13288,4129,'114546','watch-mobile','text','WHAT TO DO NEXT:',0,''),(13289,4129,'114546','watch-mobile','font-size','18',0,''),(13290,4129,'114546','watch-mobile','text-align','center',0,''),(13291,4129,'114546','watch-mobile','color','$color-font-1',0,''),(13292,4129,'114546','watch-mobile','padding-top','20',0,''),(13293,4129,'114546','watch-mobile','padding-bottom','10',0,''),(13294,4129,'114546','watch-mobile','border-top-width','1',0,''),(13295,4129,'114546','watch-mobile','border-top-color','$border-color-7',0,''),(13296,4130,'75671','watch-mobile','logo','themes/watch-mobile/img/oscommerce_logo.png',1,''),(13297,4130,'75671','watch-mobile','text-align','center',0,''),(13298,4130,'75671','watch-mobile','padding-top','10',0,''),(13299,4130,'75671','watch-mobile','padding-left','60',0,''),(13300,4130,'75671','watch-mobile','padding-right','60',0,''),(13301,4130,'75671','watch-mobile','padding-bottom','10',0,''),(13302,4131,'75672','watch-mobile','text-align','center',0,''),(13303,4131,'75672','watch-mobile','margin-bottom','20',0,''),(13304,4132,'75681','watch-mobile','block_type','14',0,''),(13305,4132,'75681','watch-mobile','font-weight','400',0,''),(13306,4132,'75681','watch-mobile','background-color','$background-2',0,''),(13307,4133,'75682','watch-mobile','class','menu-style-1',0,''),(13308,4133,'75682','watch-mobile','box_align','4',0,''),(13309,4133,'75682','watch-mobile','font-weight','400',0,''),(13310,4133,'75682','watch-mobile','hide_menu','on',0,''),(13311,4133,'75682','watch-mobile','color','$color-font-1',0,''),(13312,4133,'75682','watch-mobile','hide_menu','1',0,'292'),(13313,4133,'75682','watch-mobile','show_new','1',0,''),(13314,4137,'75686','watch-mobile','block_type','1',0,''),(13315,4140,'75689','watch-mobile','width','680',0,''),(13316,4140,'75689','watch-mobile','font-weight','normal',0,''),(13317,4140,'75689','watch-mobile','font-size','12',0,''),(13318,4140,'75689','watch-mobile','padding-top','20',0,''),(13319,4140,'75689','watch-mobile','padding-bottom','20',0,''),(13320,4140,'75689','watch-mobile','color','$color-font-7',0,''),(13321,4141,'75690','watch-mobile','block_type','5',0,''),(13322,4141,'75690','watch-mobile','font-weight','normal',0,''),(13323,4141,'75690','watch-mobile','border-bottom-width','1',0,''),(13324,4141,'75690','watch-mobile','border-bottom-color','$border-color-1',0,''),(13325,4141,'75690','watch-mobile','border-top-width','1',0,''),(13326,4141,'75690','watch-mobile','border-top-color','$border-color-1',0,''),(13327,4141,'75690','watch-mobile','border-left-color','$border-color-1',0,''),(13328,4141,'75690','watch-mobile','border-left-width','1',0,''),(13329,4142,'75691','watch-mobile','block_type','1',0,''),(13330,4142,'75691','watch-mobile','font-weight','normal',0,''),(13331,4142,'75691','watch-mobile','padding-top','10',0,''),(13332,4142,'75691','watch-mobile','padding-left','10',0,''),(13333,4142,'75691','watch-mobile','padding-right','10',0,''),(13334,4143,'75692','watch-mobile','font-weight','400',0,''),(13335,4143,'75692','watch-mobile','line-height','120',0,''),(13336,4143,'75692','watch-mobile','line_height_measure','%',0,''),(13337,4144,'75693','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(13338,4144,'75693','watch-mobile','font-size','14',0,''),(13339,4144,'75693','watch-mobile','font-weight','bold',0,''),(13340,4144,'75693','watch-mobile','padding-bottom','10',0,''),(13341,4145,'75694','watch-mobile','block_type','1',0,''),(13342,4145,'75694','watch-mobile','background-color','$background-6',0,''),(13343,4145,'75694','watch-mobile','padding-top','40',0,''),(13344,4145,'75694','watch-mobile','padding-left','10',0,''),(13345,4145,'75694','watch-mobile','padding-right','10',0,''),(13346,4145,'75694','watch-mobile','padding-bottom','40',0,''),(13347,4146,'75695','watch-mobile','font-weight','normal',0,''),(13348,4146,'75695','watch-mobile','line-height','200',0,''),(13349,4146,'75695','watch-mobile','text-align','right',0,''),(13350,4146,'75695','watch-mobile','font-size','14',0,''),(13351,4146,'75695','watch-mobile','box_align','3',0,''),(13352,4147,'75696','watch-mobile','font-weight','400',0,''),(13353,4147,'75696','watch-mobile','padding-top','20',0,''),(13354,4147,'75696','watch-mobile','padding-bottom','20',0,''),(13355,4147,'75696','watch-mobile','font-size','12',0,''),(13356,4148,'75697','watch-mobile','block_type','2',0,''),(13357,4148,'75697','watch-mobile','font-weight','normal',0,''),(13358,4148,'75697','watch-mobile','padding-bottom','20',0,''),(13359,4149,'75698','watch-mobile','font-weight','400',0,''),(13360,4149,'75698','watch-mobile','padding-top','20',0,''),(13361,4149,'75698','watch-mobile','logo','themes/watch-mobile/img/watchlogo-2-1.png',1,''),(13362,4150,'75699','watch-mobile','block_type','11',0,''),(13363,4150,'75699','watch-mobile','font-weight','normal',0,''),(13364,4151,'75700','watch-mobile','text','<p>Phone:</p>',1,''),(13365,4151,'75700','watch-mobile','font-weight','normal',0,''),(13366,4151,'75700','watch-mobile','text-align','right',0,''),(13367,4152,'75701','watch-mobile','font-weight','normal',0,''),(13368,4152,'75701','watch-mobile','text-align','right',0,''),(13369,4153,'75702','watch-mobile','block_type','1',0,''),(13370,4154,'75703','watch-mobile','font-weight','normal',0,''),(13371,4154,'75703','watch-mobile','text-align','right',0,''),(13372,4154,'75703','watch-mobile','padding-bottom','10',0,''),(13373,4154,'75703','watch-mobile','address_spacer',',',0,''),(13374,4155,'75704','watch-mobile','block_type','11',0,''),(13375,4155,'75704','watch-mobile','font-weight','normal',0,''),(13376,4156,'75705','watch-mobile','text','<p>Web:</p>',1,''),(13377,4156,'75705','watch-mobile','font-weight','normal',0,''),(13378,4156,'75705','watch-mobile','text-align','right',0,''),(13379,4157,'75706','watch-mobile','font-weight','normal',0,''),(13380,4157,'75706','watch-mobile','text-align','right',0,''),(13381,4158,'75707','watch-mobile','block_type','11',0,''),(13382,4158,'75707','watch-mobile','font-weight','normal',0,''),(13383,4159,'75708','watch-mobile','text','<p>Email:</p>',1,''),(13384,4159,'75708','watch-mobile','font-weight','normal',0,''),(13385,4159,'75708','watch-mobile','text-align','right',0,''),(13386,4160,'75709','watch-mobile','font-weight','normal',0,''),(13387,4160,'75709','watch-mobile','text-align','right',0,''),(13388,4161,'75710','watch-mobile','block_type','3',0,''),(13389,4161,'75710','watch-mobile','font-weight','normal',0,''),(13390,4161,'75710','watch-mobile','padding-top','20',0,''),(13391,4162,'75711','watch-mobile','text','<p>If undelivered please return to:</p>',1,''),(13392,4162,'75711','watch-mobile','font-size','15',0,''),(13393,4162,'75711','watch-mobile','font-weight','bold',0,''),(13394,4163,'75712','watch-mobile','font-size','14',0,''),(13395,4164,'75713','watch-mobile','text','<p>Thank you for your order</p>',1,''),(13396,4164,'75713','watch-mobile','color','$color-font-10',0,''),(13397,4164,'75713','watch-mobile','font-size','16',0,''),(13398,4164,'75713','watch-mobile','font-weight','bold',0,''),(13399,4164,'75713','watch-mobile','padding-top','5',0,''),(13400,4164,'75713','watch-mobile','text-align','center',0,''),(13401,4165,'75714','watch-mobile','font-weight','400',0,''),(13402,4165,'75714','watch-mobile','text-align','center',0,''),(13403,4165,'75714','watch-mobile','padding-top','0',0,''),(13405,4165,'75714','watch-mobile','padding-left','20',0,''),(13406,4165,'75714','watch-mobile','padding-right','20',0,''),(13407,4166,'75715','watch-mobile','block_type','6',0,''),(13408,4166,'75715','watch-mobile','font-weight','normal',0,''),(13409,4166,'75715','watch-mobile','font-size','16',0,''),(13410,4167,'75716','watch-mobile','text','<p>Email:</p>',1,''),(13411,4167,'75716','watch-mobile','font-weight','normal',0,''),(13412,4167,'75716','watch-mobile','text-align','right',0,''),(13413,4167,'75716','watch-mobile','font-size','14',0,''),(13414,4168,'75717','watch-mobile','font-weight','normal',0,''),(13415,4168,'75717','watch-mobile','text-align','right',0,''),(13416,4168,'75717','watch-mobile','font-size','14',0,''),(13417,4169,'75718','watch-mobile','block_type','6',0,''),(13418,4169,'75718','watch-mobile','font-weight','normal',0,''),(13419,4169,'75718','watch-mobile','font-size','16',0,''),(13420,4170,'75719','watch-mobile','text','<p>Phone:</p>',1,''),(13421,4170,'75719','watch-mobile','font-weight','normal',0,''),(13422,4170,'75719','watch-mobile','text-align','right',0,''),(13423,4170,'75719','watch-mobile','font-size','14',0,''),(13424,4171,'75720','watch-mobile','font-weight','normal',0,''),(13425,4171,'75720','watch-mobile','text-align','right',0,''),(13426,4171,'75720','watch-mobile','font-size','14',0,''),(13427,4172,'75721','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(13428,4172,'75721','watch-mobile','font-size','14',0,''),(13429,4172,'75721','watch-mobile','font-weight','bold',0,''),(13430,4172,'75721','watch-mobile','text-align','right',0,''),(13431,4173,'75722','watch-mobile','block_type','4',0,''),(13432,4173,'75722','watch-mobile','font-weight','normal',0,''),(13433,4173,'75722','watch-mobile','border-top-width','1',0,''),(13434,4173,'75722','watch-mobile','border-top-color','$border-color-1',0,''),(13435,4173,'75722','watch-mobile','border-left-width','1',0,''),(13436,4173,'75722','watch-mobile','border-left-color','$border-color-1',0,''),(13437,4173,'75722','watch-mobile','border-right-width','1',0,''),(13438,4173,'75722','watch-mobile','border-right-color','$border-color-1',0,''),(13439,4173,'75722','watch-mobile','border-bottom-width','1',0,''),(13440,4173,'75722','watch-mobile','border-bottom-color','$border-color-1',0,''),(13441,4174,'75723','watch-mobile','block_type','2',0,''),(13442,4174,'75723','watch-mobile','font-weight','normal',0,''),(13443,4174,'75723','watch-mobile','border-top-width','1',0,''),(13444,4174,'75723','watch-mobile','border-top-color','$border-color-1',0,''),(13445,4174,'75723','watch-mobile','border-right-width','1',0,''),(13446,4174,'75723','watch-mobile','border-right-color','$border-color-1',0,''),(13447,4175,'75724','watch-mobile','block_type','1',0,''),(13448,4175,'75724','watch-mobile','font-weight','normal',0,''),(13449,4175,'75724','watch-mobile','padding-top','10',0,''),(13450,4175,'75724','watch-mobile','padding-left','10',0,''),(13451,4175,'75724','watch-mobile','padding-right','10',0,''),(13452,4175,'75724','watch-mobile','padding-bottom','10',0,''),(13453,4175,'75724','watch-mobile','border-right-width','1',0,''),(13454,4175,'75724','watch-mobile','border-right-color','$border-color-1',0,''),(13455,4176,'75725','watch-mobile','text','<p>Shipping via</p>',1,''),(13456,4176,'75725','watch-mobile','font-weight','bold',0,''),(13457,4178,'75727','watch-mobile','block_type','1',0,''),(13458,4178,'75727','watch-mobile','font-weight','normal',0,''),(13459,4178,'75727','watch-mobile','padding-top','10',0,''),(13460,4178,'75727','watch-mobile','padding-left','10',0,''),(13461,4178,'75727','watch-mobile','padding-right','10',0,''),(13462,4178,'75727','watch-mobile','padding-bottom','10',0,''),(13463,4180,'75729','watch-mobile','text','<p>Shipping service</p>',1,''),(13464,4180,'75729','watch-mobile','font-weight','bold',0,''),(13465,4181,'75730','watch-mobile','block_type','2',0,''),(13466,4181,'75730','watch-mobile','font-weight','normal',0,''),(13467,4181,'75730','watch-mobile','border-right-width','1',0,''),(13468,4181,'75730','watch-mobile','border-right-color','$border-color-1',0,''),(13469,4182,'75731','watch-mobile','block_type','1',0,''),(13470,4182,'75731','watch-mobile','font-weight','400',0,''),(13471,4182,'75731','watch-mobile','background-color','$background-6',0,''),(13472,4182,'75731','watch-mobile','padding-top','10',0,''),(13473,4182,'75731','watch-mobile','padding-left','10',0,''),(13474,4182,'75731','watch-mobile','padding-right','10',0,''),(13475,4182,'75731','watch-mobile','padding-bottom','50',0,''),(13476,4183,'75732','watch-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(13477,4183,'75732','watch-mobile','font-size','16',0,''),(13478,4183,'75732','watch-mobile','font-weight','bold',0,''),(13479,4185,'75734','watch-mobile','block_type','1',0,''),(13480,4185,'75734','watch-mobile','font-weight','normal',0,''),(13481,4185,'75734','watch-mobile','padding-top','10',0,''),(13482,4185,'75734','watch-mobile','padding-left','10',0,''),(13483,4185,'75734','watch-mobile','padding-right','10',0,''),(13484,4185,'75734','watch-mobile','padding-bottom','10',0,''),(13485,4186,'75735','watch-mobile','font-weight','normal',0,''),(13486,4187,'75736','watch-mobile','text','<p>CUSTOMER:</p>',1,''),(13487,4187,'75736','watch-mobile','font-size','14',0,''),(13488,4187,'75736','watch-mobile','font-weight','bold',0,''),(13489,4188,'75737','watch-mobile','font-weight','normal',0,''),(13490,4189,'75738','watch-mobile','text','<p>PHONE NUMBER:</p>',1,''),(13491,4189,'75738','watch-mobile','font-size','14',0,''),(13492,4189,'75738','watch-mobile','font-weight','bold',0,''),(13493,4189,'75738','watch-mobile','padding-top','10',0,''),(13494,4190,'75739','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(13495,4190,'75739','watch-mobile','font-weight','bold',0,''),(13496,4190,'75739','watch-mobile','font-size','14',0,''),(13497,4190,'75739','watch-mobile','padding-top','10',0,''),(13498,4192,'75741','watch-mobile','font-weight','normal',0,''),(13499,4192,'75741','watch-mobile','text-align','center',0,''),(13500,4192,'75741','watch-mobile','padding-bottom','20',0,''),(13501,4193,'75742','watch-mobile','font-weight','normal',0,''),(13502,4193,'75742','watch-mobile','text-align','center',0,''),(13503,4193,'75742','watch-mobile','padding-bottom','10',0,''),(13504,4194,'75743','watch-mobile','font-size','16',0,''),(13505,4194,'75743','watch-mobile','font-weight','bold',0,''),(13506,4194,'75743','watch-mobile','text-align','center',0,''),(13507,4194,'75743','watch-mobile','padding-bottom','10',0,''),(13508,4194,'75743','watch-mobile','padding-top','10',0,''),(13509,4195,'75744','watch-mobile','font-weight','normal',0,''),(13510,4195,'75744','watch-mobile','text-align','center',0,''),(13511,4196,'75745','watch-mobile','text','<p>Payment date:</p>',1,''),(13512,4196,'75745','watch-mobile','font-weight','bold',0,''),(13513,4196,'75745','watch-mobile','text-align','center',0,''),(13514,4197,'75746','watch-mobile','text','<p>Payment Method:</p>',1,''),(13515,4197,'75746','watch-mobile','font-weight','bold',0,''),(13516,4197,'75746','watch-mobile','text-align','center',0,''),(13517,4198,'94802','watch-mobile','block_type','1',0,''),(13518,4198,'94802','watch-mobile','padding-top','20',0,''),(13519,4199,'94803','watch-mobile','tab_1','RETURNING CUSTOMER',1,''),(13520,4199,'94803','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(13521,4202,'94810','watch-mobile','block_type','1',0,''),(13522,4203,'94811','watch-mobile','text','##TEXT_OR##',0,''),(13523,4203,'94811','watch-mobile','font-size','18',0,''),(13524,4203,'94811','watch-mobile','font-weight','700',0,''),(13525,4203,'94811','watch-mobile','padding-top','15',0,''),(13526,4203,'94811','watch-mobile','text-align','center',0,''),(13527,4203,'94811','watch-mobile','content','\\_',0,'3'),(13528,4203,'94811','watch-mobile','height','5',0,'3'),(13529,4203,'94811','watch-mobile','width','70',0,'3'),(13530,4203,'94811','watch-mobile','display','inline-block',0,'3'),(13531,4203,'94811','watch-mobile','border-top-width','1',0,'3'),(13532,4203,'94811','watch-mobile','border-top-color','$border-color-1',0,'3'),(13533,4203,'94811','watch-mobile','margin-left','10',0,'3'),(13534,4203,'94811','watch-mobile','margin-right','10',0,'3'),(13535,4203,'94811','watch-mobile','content','\\_',0,'4'),(13536,4203,'94811','watch-mobile','display','inline-block',0,'4'),(13537,4203,'94811','watch-mobile','width','70',0,'4'),(13538,4203,'94811','watch-mobile','height','5',0,'4'),(13539,4203,'94811','watch-mobile','border-top-width','1',0,'4'),(13540,4203,'94811','watch-mobile','border-top-color','$border-color-1',0,'4'),(13541,4203,'94811','watch-mobile','margin-left','10',0,'4'),(13542,4203,'94811','watch-mobile','margin-right','10',0,'4'),(13543,4203,'94811','watch-mobile','position','relative',0,''),(13544,4203,'94811','watch-mobile','top','-10',0,''),(13545,4204,'94812','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13546,4204,'94812','watch-mobile','font-size','26',0,''),(13547,4204,'94812','watch-mobile','font-family','$font-1',0,''),(13548,4204,'94812','watch-mobile','padding-top','15',0,''),(13549,4204,'94812','watch-mobile','padding-bottom','15',0,''),(13550,4204,'94812','watch-mobile','text-align','center',0,''),(13551,4205,'94813','watch-mobile','text-align','center',0,''),(13552,4205,'94813','watch-mobile','hide_parents','2',0,''),(13553,4206,'114547','watch-mobile','block_type','1',0,''),(13554,4206,'114547','watch-mobile','padding-top','40',0,''),(13555,4206,'114547','watch-mobile','background-color','$background-6',0,''),(13556,4206,'114547','watch-mobile','padding-bottom','40',0,''),(13557,4207,'114548','watch-mobile','block_type','1',0,''),(13558,4207,'114548','watch-mobile','background-color','$background-7',0,''),(13559,4207,'114548','watch-mobile','max-width','830',0,''),(13560,4207,'114548','watch-mobile','margin_left_measure','auto',0,''),(13561,4207,'114548','watch-mobile','margin_right_measure','auto',0,''),(13562,4207,'114548','watch-mobile','padding-top','40',0,''),(13563,4207,'114548','watch-mobile','padding-bottom','40',0,''),(13564,4207,'114548','watch-mobile','schema','2-3',0,''),(13565,4208,'114549','watch-mobile','text','##NEW_CUSTOMER##',0,''),(13566,4208,'114549','watch-mobile','font-size','18',0,''),(13567,4208,'114549','watch-mobile','font-family','$font-1',0,''),(13568,4208,'114549','watch-mobile','text-align','center',0,''),(13569,4208,'114549','watch-mobile','text-transform','uppercase',0,''),(13570,4208,'114549','watch-mobile','margin-bottom','10',0,''),(13571,4209,'114550','watch-mobile','text-align','center',0,''),(13572,4209,'114550','watch-mobile','margin-bottom','40',0,''),(13573,4210,'114551','watch-mobile','text-align','center',0,''),(13574,4211,'114552','watch-mobile','text','##TEXT_OR##',0,''),(13575,4211,'114552','watch-mobile','font-size','18',0,''),(13576,4211,'114552','watch-mobile','font-weight','700',0,''),(13577,4211,'114552','watch-mobile','text-align','center',0,''),(13578,4211,'114552','watch-mobile','content','\\_',0,'3'),(13579,4211,'114552','watch-mobile','height','5',0,'3'),(13580,4211,'114552','watch-mobile','width','70',0,'3'),(13581,4211,'114552','watch-mobile','display','inline-block',0,'3'),(13582,4211,'114552','watch-mobile','border-top-width','1',0,'3'),(13583,4211,'114552','watch-mobile','border-top-color','$border-color-1',0,'3'),(13584,4211,'114552','watch-mobile','margin-left','10',0,'3'),(13585,4211,'114552','watch-mobile','margin-right','10',0,'3'),(13586,4211,'114552','watch-mobile','content','\\_',0,'4'),(13587,4211,'114552','watch-mobile','display','inline-block',0,'4'),(13588,4211,'114552','watch-mobile','width','70',0,'4'),(13589,4211,'114552','watch-mobile','height','5',0,'4'),(13590,4211,'114552','watch-mobile','border-top-width','1',0,'4'),(13591,4211,'114552','watch-mobile','border-top-color','$border-color-1',0,'4'),(13592,4211,'114552','watch-mobile','margin-left','10',0,'4'),(13593,4211,'114552','watch-mobile','margin-right','10',0,'4'),(13594,4211,'114552','watch-mobile','position','relative',0,''),(13595,4211,'114552','watch-mobile','padding-top','10',0,''),(13596,4211,'114552','watch-mobile','padding-bottom','10',0,''),(13597,4212,'114553','watch-mobile','block_type','1',0,''),(13598,4213,'114554','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13599,4213,'114554','watch-mobile','font-size','18',0,''),(13600,4213,'114554','watch-mobile','font-family','$font-1',0,''),(13601,4213,'114554','watch-mobile','padding-top','15',0,''),(13602,4213,'114554','watch-mobile','padding-bottom','15',0,''),(13603,4213,'114554','watch-mobile','text-align','center',0,''),(13604,4213,'114554','watch-mobile','text-transform','uppercase',0,''),(13605,4214,'114555','watch-mobile','text-align','center',0,''),(13606,4214,'114555','watch-mobile','hide_parents','2',0,''),(13607,4215,'114556','watch-mobile','max-width','230',0,''),(13608,4215,'114556','watch-mobile','margin_left_measure','auto',0,''),(13609,4215,'114556','watch-mobile','margin_right_measure','auto',0,''),(13610,4216,'114557','watch-mobile','text','##RETURNING_CUSTOMER##',0,''),(13611,4216,'114557','watch-mobile','font-size','18',0,''),(13612,4216,'114557','watch-mobile','font-family','$font-1',0,''),(13613,4216,'114557','watch-mobile','text-transform','uppercase',0,''),(13614,4216,'114557','watch-mobile','text-align','center',0,''),(13615,4217,'114558','watch-mobile','block_type','1',0,''),(13616,4217,'114558','watch-mobile','padding-top','20',0,''),(13617,4218,'114559','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13618,4218,'114559','watch-mobile','font-size','26',0,''),(13619,4218,'114559','watch-mobile','font-family','$font-1',0,''),(13620,4218,'114559','watch-mobile','padding-top','15',0,''),(13621,4218,'114559','watch-mobile','padding-bottom','15',0,''),(13622,4218,'114559','watch-mobile','text-align','center',0,''),(13623,4219,'114560','watch-mobile','text','##TEXT_OR##',0,''),(13624,4219,'114560','watch-mobile','font-size','18',0,''),(13625,4219,'114560','watch-mobile','font-weight','700',0,''),(13626,4219,'114560','watch-mobile','padding-top','15',0,''),(13627,4219,'114560','watch-mobile','text-align','center',0,''),(13628,4219,'114560','watch-mobile','content','\\_',0,'3'),(13629,4219,'114560','watch-mobile','height','5',0,'3'),(13630,4219,'114560','watch-mobile','width','70',0,'3'),(13631,4219,'114560','watch-mobile','display','inline-block',0,'3'),(13632,4219,'114560','watch-mobile','border-top-width','1',0,'3'),(13633,4219,'114560','watch-mobile','border-top-color','$border-color-1',0,'3'),(13634,4219,'114560','watch-mobile','margin-left','10',0,'3'),(13635,4219,'114560','watch-mobile','margin-right','10',0,'3'),(13636,4219,'114560','watch-mobile','content','\\_',0,'4'),(13637,4219,'114560','watch-mobile','display','inline-block',0,'4'),(13638,4219,'114560','watch-mobile','width','70',0,'4'),(13639,4219,'114560','watch-mobile','height','5',0,'4'),(13640,4219,'114560','watch-mobile','border-top-width','1',0,'4'),(13641,4219,'114560','watch-mobile','border-top-color','$border-color-1',0,'4'),(13642,4219,'114560','watch-mobile','margin-left','10',0,'4'),(13643,4219,'114560','watch-mobile','margin-right','10',0,'4'),(13644,4219,'114560','watch-mobile','position','relative',0,''),(13645,4219,'114560','watch-mobile','top','-10',0,''),(13646,4220,'114561','watch-mobile','text-align','center',0,''),(13647,4221,'114562','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(13648,4221,'114562','watch-mobile','tab_2','RETURNING CUSTOMER',1,''),(13649,4221,'114562','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(13650,4222,'114563','watch-mobile','block_type','8',0,''),(13651,4223,'114564','watch-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(13652,4224,'114565','watch-mobile','block_type','1',0,''),(13653,4224,'114565','watch-mobile','padding-left','20',0,''),(13654,4224,'114565','watch-mobile','padding-right','20',0,''),(13655,4225,'114566','watch-mobile','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(13656,4225,'114566','watch-mobile','border-top-width','1',0,''),(13657,4225,'114566','watch-mobile','border-top-color','$border-color-1',0,''),(13658,4228,'114569','watch-mobile','block_type','8',0,''),(13659,4229,'114570','watch-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(13660,4230,'114571','watch-mobile','block_type','1',0,''),(13661,4230,'114571','watch-mobile','padding-left','20',0,''),(13662,4230,'114571','watch-mobile','padding-right','20',0,''),(13663,4232,'114573','watch-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(13664,4233,'114574','watch-mobile','block_type','1',0,''),(13665,4233,'114574','watch-mobile','padding-top','20',0,''),(13666,4234,'114575','watch-mobile','text-align','center',0,''),(13667,4235,'114576','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13668,4235,'114576','watch-mobile','font-size','26',0,''),(13669,4235,'114576','watch-mobile','font-family','$font-1',0,''),(13670,4235,'114576','watch-mobile','padding-top','15',0,''),(13671,4235,'114576','watch-mobile','padding-bottom','15',0,''),(13672,4235,'114576','watch-mobile','text-align','center',0,''),(13673,4236,'114577','watch-mobile','text','##TEXT_OR##',0,''),(13674,4236,'114577','watch-mobile','font-size','18',0,''),(13675,4236,'114577','watch-mobile','font-weight','700',0,''),(13676,4236,'114577','watch-mobile','padding-top','15',0,''),(13677,4236,'114577','watch-mobile','text-align','center',0,''),(13678,4236,'114577','watch-mobile','content','\\_',0,'3'),(13679,4236,'114577','watch-mobile','height','5',0,'3'),(13680,4236,'114577','watch-mobile','width','70',0,'3'),(13681,4236,'114577','watch-mobile','display','inline-block',0,'3'),(13682,4236,'114577','watch-mobile','border-top-width','1',0,'3'),(13683,4236,'114577','watch-mobile','border-top-color','$border-color-1',0,'3'),(13684,4236,'114577','watch-mobile','margin-left','10',0,'3'),(13685,4236,'114577','watch-mobile','margin-right','10',0,'3'),(13686,4236,'114577','watch-mobile','content','\\_',0,'4'),(13687,4236,'114577','watch-mobile','display','inline-block',0,'4'),(13688,4236,'114577','watch-mobile','width','70',0,'4'),(13689,4236,'114577','watch-mobile','height','5',0,'4'),(13690,4236,'114577','watch-mobile','border-top-width','1',0,'4'),(13691,4236,'114577','watch-mobile','border-top-color','$border-color-1',0,'4'),(13692,4236,'114577','watch-mobile','margin-left','10',0,'4'),(13693,4236,'114577','watch-mobile','margin-right','10',0,'4'),(13694,4236,'114577','watch-mobile','position','relative',0,''),(13695,4236,'114577','watch-mobile','top','-10',0,''),(13696,4237,'114578','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(13697,4237,'114578','watch-mobile','tab_2','RETURNING CUSTOMER',1,''),(13698,4237,'114578','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(13699,4238,'114579','watch-mobile','block_type','8',0,''),(13700,4239,'114580','watch-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(13701,4242,'114583','watch-mobile','block_type','8',0,''),(13702,4243,'114584','watch-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(13703,4245,'114586','watch-mobile','block_type','1',0,''),(13704,4245,'114586','watch-mobile','padding-left','20',0,''),(13705,4245,'114586','watch-mobile','padding-right','20',0,''),(13706,4246,'114587','watch-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(13707,4248,'114589','watch-mobile','block_type','1',0,''),(13708,4248,'114589','watch-mobile','padding-top','20',0,''),(13709,4249,'114590','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13710,4249,'114590','watch-mobile','font-size','26',0,''),(13711,4249,'114590','watch-mobile','font-family','$font-1',0,''),(13712,4249,'114590','watch-mobile','padding-top','15',0,''),(13713,4249,'114590','watch-mobile','padding-bottom','15',0,''),(13714,4249,'114590','watch-mobile','text-align','center',0,''),(13715,4250,'114591','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(13716,4250,'114591','watch-mobile','tab_2','RETURNING CUSTOMER',1,''),(13717,4250,'114591','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(13718,4251,'114592','watch-mobile','block_type','8',0,''),(13719,4252,'114593','watch-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(13720,4255,'114596','watch-mobile','block_type','8',0,''),(13721,4256,'114597','watch-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(13722,4257,'114598','watch-mobile','block_type','1',0,''),(13723,4257,'114598','watch-mobile','padding-left','20',0,''),(13724,4257,'114598','watch-mobile','padding-right','20',0,''),(13725,4258,'114599','watch-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(13726,4260,'114601','watch-mobile','text-align','center',0,''),(13727,4261,'114602','watch-mobile','text','##TEXT_OR##',0,''),(13728,4261,'114602','watch-mobile','font-size','18',0,''),(13729,4261,'114602','watch-mobile','font-weight','700',0,''),(13730,4261,'114602','watch-mobile','padding-top','15',0,''),(13731,4261,'114602','watch-mobile','text-align','center',0,''),(13732,4261,'114602','watch-mobile','content','\\_',0,'3'),(13733,4261,'114602','watch-mobile','height','5',0,'3'),(13734,4261,'114602','watch-mobile','width','70',0,'3'),(13735,4261,'114602','watch-mobile','display','inline-block',0,'3'),(13736,4261,'114602','watch-mobile','border-top-width','1',0,'3'),(13737,4261,'114602','watch-mobile','border-top-color','$border-color-1',0,'3'),(13738,4261,'114602','watch-mobile','margin-left','10',0,'3'),(13739,4261,'114602','watch-mobile','margin-right','10',0,'3'),(13740,4261,'114602','watch-mobile','content','\\_',0,'4'),(13741,4261,'114602','watch-mobile','display','inline-block',0,'4'),(13742,4261,'114602','watch-mobile','width','70',0,'4'),(13743,4261,'114602','watch-mobile','height','5',0,'4'),(13744,4261,'114602','watch-mobile','border-top-width','1',0,'4'),(13745,4261,'114602','watch-mobile','border-top-color','$border-color-1',0,'4'),(13746,4261,'114602','watch-mobile','margin-left','10',0,'4'),(13747,4261,'114602','watch-mobile','margin-right','10',0,'4'),(13748,4261,'114602','watch-mobile','position','relative',0,''),(13749,4261,'114602','watch-mobile','top','-10',0,''),(13750,4262,'114603','watch-mobile','block_type','1',0,''),(13751,4262,'114603','watch-mobile','padding-top','40',0,''),(13752,4262,'114603','watch-mobile','background-color','$background-6',0,''),(13753,4262,'114603','watch-mobile','padding-bottom','40',0,''),(13754,4263,'114604','watch-mobile','block_type','2',0,''),(13755,4263,'114604','watch-mobile','background-color','$background-7',0,''),(13756,4263,'114604','watch-mobile','max-width','830',0,''),(13757,4263,'114604','watch-mobile','margin_left_measure','auto',0,''),(13758,4263,'114604','watch-mobile','margin_right_measure','auto',0,''),(13759,4263,'114604','watch-mobile','padding-top','40',0,''),(13760,4263,'114604','watch-mobile','padding-bottom','40',0,''),(13761,4264,'114605','watch-mobile','text-align','center',0,''),(13762,4264,'114605','watch-mobile','margin-bottom','40',0,''),(13763,4265,'114606','watch-mobile','text-align','center',0,''),(13764,4266,'114607','watch-mobile','text','##NEW_CUSTOMER##',0,''),(13765,4266,'114607','watch-mobile','font-size','18',0,''),(13766,4266,'114607','watch-mobile','font-family','$font-1',0,''),(13767,4266,'114607','watch-mobile','text-align','center',0,''),(13768,4266,'114607','watch-mobile','text-transform','uppercase',0,''),(13769,4266,'114607','watch-mobile','margin-bottom','10',0,''),(13770,4267,'114608','watch-mobile','text','##TEXT_OR##',0,''),(13771,4267,'114608','watch-mobile','font-size','18',0,''),(13772,4267,'114608','watch-mobile','font-weight','700',0,''),(13773,4267,'114608','watch-mobile','text-align','center',0,''),(13774,4267,'114608','watch-mobile','content','\\_',0,'3'),(13775,4267,'114608','watch-mobile','height','5',0,'3'),(13776,4267,'114608','watch-mobile','width','70',0,'3'),(13777,4267,'114608','watch-mobile','display','inline-block',0,'3'),(13778,4267,'114608','watch-mobile','border-top-width','1',0,'3'),(13779,4267,'114608','watch-mobile','border-top-color','$border-color-1',0,'3'),(13780,4267,'114608','watch-mobile','margin-left','10',0,'3'),(13781,4267,'114608','watch-mobile','margin-right','10',0,'3'),(13782,4267,'114608','watch-mobile','content','\\_',0,'4'),(13783,4267,'114608','watch-mobile','display','inline-block',0,'4'),(13784,4267,'114608','watch-mobile','width','70',0,'4'),(13785,4267,'114608','watch-mobile','height','5',0,'4'),(13786,4267,'114608','watch-mobile','border-top-width','1',0,'4'),(13787,4267,'114608','watch-mobile','border-top-color','$border-color-1',0,'4'),(13788,4267,'114608','watch-mobile','margin-left','10',0,'4'),(13789,4267,'114608','watch-mobile','margin-right','10',0,'4'),(13790,4267,'114608','watch-mobile','position','relative',0,''),(13791,4267,'114608','watch-mobile','padding-top','10',0,''),(13792,4267,'114608','watch-mobile','padding-bottom','10',0,''),(13793,4268,'114609','watch-mobile','block_type','1',0,''),(13794,4269,'114610','watch-mobile','text-align','center',0,''),(13795,4269,'114610','watch-mobile','hide_parents','2',0,''),(13796,4270,'114611','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13797,4270,'114611','watch-mobile','font-size','18',0,''),(13798,4270,'114611','watch-mobile','font-family','$font-1',0,''),(13799,4270,'114611','watch-mobile','padding-top','15',0,''),(13800,4270,'114611','watch-mobile','padding-bottom','15',0,''),(13801,4270,'114611','watch-mobile','text-align','center',0,''),(13802,4270,'114611','watch-mobile','text-transform','uppercase',0,''),(13803,4271,'114612','watch-mobile','max-width','230',0,''),(13804,4271,'114612','watch-mobile','margin_left_measure','auto',0,''),(13805,4271,'114612','watch-mobile','margin_right_measure','auto',0,''),(13806,4272,'114613','watch-mobile','text','##RETURNING_CUSTOMER##',0,''),(13807,4272,'114613','watch-mobile','font-size','18',0,''),(13808,4272,'114613','watch-mobile','font-family','$font-1',0,''),(13809,4272,'114613','watch-mobile','text-transform','uppercase',0,''),(13810,4272,'114613','watch-mobile','text-align','center',0,''),(13811,4273,'114614','watch-mobile','block_type','1',0,''),(13812,4273,'114614','watch-mobile','padding-top','40',0,''),(13813,4273,'114614','watch-mobile','background-color','$background-6',0,''),(13814,4273,'114614','watch-mobile','padding-bottom','40',0,''),(13815,4274,'114615','watch-mobile','block_type','2',0,''),(13816,4274,'114615','watch-mobile','background-color','$background-7',0,''),(13817,4274,'114615','watch-mobile','max-width','830',0,''),(13818,4274,'114615','watch-mobile','margin_left_measure','auto',0,''),(13819,4274,'114615','watch-mobile','margin_right_measure','auto',0,''),(13820,4274,'114615','watch-mobile','padding-top','40',0,''),(13821,4274,'114615','watch-mobile','padding-bottom','40',0,''),(13822,4275,'114616','watch-mobile','block_type','1',0,''),(13823,4276,'114617','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13824,4276,'114617','watch-mobile','font-size','18',0,''),(13825,4276,'114617','watch-mobile','font-family','$font-1',0,''),(13826,4276,'114617','watch-mobile','padding-top','15',0,''),(13827,4276,'114617','watch-mobile','padding-bottom','15',0,''),(13828,4276,'114617','watch-mobile','text-align','center',0,''),(13829,4276,'114617','watch-mobile','text-transform','uppercase',0,''),(13830,4277,'114618','watch-mobile','text-align','center',0,''),(13831,4277,'114618','watch-mobile','hide_parents','2',0,''),(13832,4278,'114619','watch-mobile','text','##TEXT_OR##',0,''),(13833,4278,'114619','watch-mobile','font-size','18',0,''),(13834,4278,'114619','watch-mobile','font-weight','700',0,''),(13835,4278,'114619','watch-mobile','text-align','center',0,''),(13836,4278,'114619','watch-mobile','content','\\_',0,'3'),(13837,4278,'114619','watch-mobile','height','5',0,'3'),(13838,4278,'114619','watch-mobile','width','70',0,'3'),(13839,4278,'114619','watch-mobile','display','inline-block',0,'3'),(13840,4278,'114619','watch-mobile','border-top-width','1',0,'3'),(13841,4278,'114619','watch-mobile','border-top-color','$border-color-1',0,'3'),(13842,4278,'114619','watch-mobile','margin-left','10',0,'3'),(13843,4278,'114619','watch-mobile','margin-right','10',0,'3'),(13844,4278,'114619','watch-mobile','content','\\_',0,'4'),(13845,4278,'114619','watch-mobile','display','inline-block',0,'4'),(13846,4278,'114619','watch-mobile','width','70',0,'4'),(13847,4278,'114619','watch-mobile','height','5',0,'4'),(13848,4278,'114619','watch-mobile','border-top-width','1',0,'4'),(13849,4278,'114619','watch-mobile','border-top-color','$border-color-1',0,'4'),(13850,4278,'114619','watch-mobile','margin-left','10',0,'4'),(13851,4278,'114619','watch-mobile','margin-right','10',0,'4'),(13852,4278,'114619','watch-mobile','position','relative',0,''),(13853,4278,'114619','watch-mobile','padding-top','10',0,''),(13854,4278,'114619','watch-mobile','padding-bottom','10',0,''),(13855,4279,'114620','watch-mobile','text-align','center',0,''),(13856,4279,'114620','watch-mobile','margin-bottom','40',0,''),(13857,4280,'114621','watch-mobile','text','##NEW_CUSTOMER##',0,''),(13858,4280,'114621','watch-mobile','font-size','18',0,''),(13859,4280,'114621','watch-mobile','font-family','$font-1',0,''),(13860,4280,'114621','watch-mobile','text-align','center',0,''),(13861,4280,'114621','watch-mobile','text-transform','uppercase',0,''),(13862,4280,'114621','watch-mobile','margin-bottom','10',0,''),(13863,4281,'114622','watch-mobile','text-align','center',0,''),(13864,4282,'114623','watch-mobile','text','##RETURNING_CUSTOMER##',0,''),(13865,4282,'114623','watch-mobile','font-size','18',0,''),(13866,4282,'114623','watch-mobile','font-family','$font-1',0,''),(13867,4282,'114623','watch-mobile','text-transform','uppercase',0,''),(13868,4282,'114623','watch-mobile','text-align','center',0,''),(13869,4283,'114624','watch-mobile','max-width','230',0,''),(13870,4283,'114624','watch-mobile','margin_left_measure','auto',0,''),(13871,4283,'114624','watch-mobile','margin_right_measure','auto',0,''),(13872,4284,'114625','watch-mobile','block_type','1',0,''),(13873,4285,'114626','watch-mobile','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(13874,4285,'114626','watch-mobile','margin-bottom','30',0,''),(13875,4286,'114627','watch-mobile','block_type','1',0,''),(13876,4287,'114628','watch-mobile','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(13877,4287,'114628','watch-mobile','margin-bottom','30',0,''),(13878,4288,'75747','watch-mobile','block_type','1',0,''),(13879,4288,'75747','watch-mobile','font-weight','normal',0,''),(13880,4290,'75749','watch-mobile','box_align','4',0,''),(13881,4290,'75749','watch-mobile','margin-bottom','30',0,''),(13882,4291,'75750','watch-mobile','tab_1','New products',1,''),(13883,4291,'75750','watch-mobile','tab_2','Specials products',1,''),(13884,4291,'75750','watch-mobile','font-weight','normal',0,''),(13885,4291,'75750','watch-mobile','tab_3','Featured',1,''),(13886,4291,'75750','watch-mobile','accordion','1',0,'290'),(13887,4292,'75751','watch-mobile','font-weight','400',0,''),(13888,4292,'75751','watch-mobile','listing_type','productListing',0,''),(13889,4292,'75751','watch-mobile','show_compare','1',0,''),(13890,4292,'75751','watch-mobile','show_model','1',0,''),(13891,4292,'75751','watch-mobile','show_properties','1',0,''),(13892,4292,'75751','watch-mobile','col_in_row','2',0,''),(13893,4292,'75751','watch-mobile','show_name','0',0,''),(13894,4292,'75751','watch-mobile','show_image','0',0,''),(13895,4292,'75751','watch-mobile','show_stock','0',0,''),(13896,4292,'75751','watch-mobile','show_description','0',0,''),(13897,4292,'75751','watch-mobile','show_rating','0',0,''),(13898,4292,'75751','watch-mobile','show_rating_counts','0',0,''),(13899,4292,'75751','watch-mobile','show_price','0',0,''),(13900,4292,'75751','watch-mobile','show_buy_button','0',0,''),(13901,4292,'75751','watch-mobile','show_qty_input','0',0,''),(13902,4292,'75751','watch-mobile','show_view_button','0',0,''),(13903,4292,'75751','watch-mobile','show_wishlist_button','0',0,''),(13904,4292,'75751','watch-mobile','col_in_row','2',0,'291'),(13905,4292,'75751','watch-mobile','col_in_row','1',0,'315'),(13906,4292,'75751','watch-mobile','view_as','carousel',0,''),(13907,4292,'75751','watch-mobile','col_in_row','3',0,'299'),(13908,4293,'75752','watch-mobile','font-weight','400',0,''),(13909,4293,'75752','watch-mobile','show_compare','1',0,''),(13910,4293,'75752','watch-mobile','listing_type','productListing',0,''),(13911,4293,'75752','watch-mobile','show_model','1',0,''),(13912,4293,'75752','watch-mobile','show_properties','1',0,''),(13913,4293,'75752','watch-mobile','col_in_row','2',0,''),(13914,4293,'75752','watch-mobile','show_name','0',0,''),(13915,4293,'75752','watch-mobile','show_image','0',0,''),(13916,4293,'75752','watch-mobile','show_stock','0',0,''),(13917,4293,'75752','watch-mobile','show_description','0',0,''),(13918,4293,'75752','watch-mobile','show_rating','0',0,''),(13919,4293,'75752','watch-mobile','show_rating_counts','0',0,''),(13920,4293,'75752','watch-mobile','show_price','0',0,''),(13921,4293,'75752','watch-mobile','show_buy_button','0',0,''),(13922,4293,'75752','watch-mobile','show_qty_input','0',0,''),(13923,4293,'75752','watch-mobile','show_view_button','0',0,''),(13924,4293,'75752','watch-mobile','show_wishlist_button','0',0,''),(13925,4293,'75752','watch-mobile','col_in_row','2',0,'291'),(13926,4293,'75752','watch-mobile','col_in_row','1',0,'315'),(13927,4293,'75752','watch-mobile','view_as','carousel',0,''),(13928,4293,'75752','watch-mobile','col_in_row','3',0,'299'),(13929,4293,'75752','watch-mobile','product_names_teg','h2',0,''),(13930,4294,'75753','watch-mobile','font-weight','400',0,''),(13931,4294,'75753','watch-mobile','show_compare','1',0,''),(13932,4294,'75753','watch-mobile','listing_type','productListing',0,''),(13933,4294,'75753','watch-mobile','show_model','1',0,''),(13934,4294,'75753','watch-mobile','show_properties','1',0,''),(13935,4294,'75753','watch-mobile','col_in_row','2',0,''),(13936,4294,'75753','watch-mobile','show_name','0',0,''),(13937,4294,'75753','watch-mobile','show_image','0',0,''),(13938,4294,'75753','watch-mobile','show_stock','0',0,''),(13939,4294,'75753','watch-mobile','show_description','0',0,''),(13940,4294,'75753','watch-mobile','show_rating','0',0,''),(13941,4294,'75753','watch-mobile','show_rating_counts','0',0,''),(13942,4294,'75753','watch-mobile','show_price','0',0,''),(13943,4294,'75753','watch-mobile','show_buy_button','0',0,''),(13944,4294,'75753','watch-mobile','show_qty_input','0',0,''),(13945,4294,'75753','watch-mobile','show_view_button','0',0,''),(13946,4294,'75753','watch-mobile','show_wishlist_button','0',0,''),(13947,4294,'75753','watch-mobile','col_in_row','2',0,'291'),(13948,4294,'75753','watch-mobile','col_in_row','1',0,'315'),(13949,4294,'75753','watch-mobile','view_as','carousel',0,''),(13950,4294,'75753','watch-mobile','col_in_row','3',0,'299'),(13951,4295,'75754','watch-mobile','heading_type','h1',0,''),(13952,4296,'75755','watch-mobile','block_type','1',0,''),(13953,4296,'75755','watch-mobile','background-color','$background-6',0,''),(13954,4296,'75755','watch-mobile','padding-top','20',0,''),(13955,4296,'75755','watch-mobile','padding-bottom','20',0,''),(13956,4296,'75755','watch-mobile','font-weight','400',0,''),(13957,4296,'75755','watch-mobile','visibility_product','1',0,''),(13958,4296,'75755','watch-mobile','visibility_catalog','1',0,''),(13959,4296,'75755','watch-mobile','visibility_info','1',0,''),(13960,4296,'75755','watch-mobile','visibility_cart','1',0,''),(13961,4296,'75755','watch-mobile','visibility_checkout','1',0,''),(13962,4296,'75755','watch-mobile','visibility_success','1',0,''),(13963,4296,'75755','watch-mobile','visibility_account','1',0,''),(13964,4296,'75755','watch-mobile','visibility_login','1',0,''),(13965,4296,'75755','watch-mobile','visibility_other','1',0,''),(13966,4296,'75755','watch-mobile','margin-bottom','20',0,''),(13967,4296,'75755','watch-mobile','display_none','on',0,'291'),(13968,4297,'75756','watch-mobile','block_type','2',0,''),(13969,4297,'75756','watch-mobile','font-weight','normal',0,''),(13970,4298,'75757','watch-mobile','font-weight','400',0,''),(13971,4298,'75757','watch-mobile','visibility_product','1',0,''),(13972,4298,'75757','watch-mobile','show_name','0',0,''),(13973,4298,'75757','watch-mobile','show_image','1',0,''),(13974,4298,'75757','watch-mobile','show_stock','1',0,''),(13975,4298,'75757','watch-mobile','show_description','1',0,''),(13976,4298,'75757','watch-mobile','show_model','1',0,''),(13977,4298,'75757','watch-mobile','show_rating','1',0,''),(13978,4298,'75757','watch-mobile','show_rating_counts','1',0,''),(13979,4298,'75757','watch-mobile','show_price','1',0,''),(13980,4298,'75757','watch-mobile','show_buy_button','1',0,''),(13981,4298,'75757','watch-mobile','show_qty_input','1',0,''),(13982,4298,'75757','watch-mobile','show_view_button','1',0,''),(13983,4298,'75757','watch-mobile','show_wishlist_button','1',0,''),(13984,4298,'75757','watch-mobile','show_compare','1',0,''),(13985,4298,'75757','watch-mobile','listing_type','type-1',0,''),(13986,4298,'75757','watch-mobile','show_properties','1',0,''),(13987,4299,'75758','watch-mobile','font-weight','normal',0,''),(13988,4299,'75758','watch-mobile','visibility_product','1',0,''),(13989,4300,'114629','watch-mobile','block_type','1',0,''),(13990,4301,'114630','watch-mobile','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(13991,4303,'114632','watch-mobile','block_type','1',0,''),(13992,4303,'114632','watch-mobile','padding-top','40',0,''),(13993,4303,'114632','watch-mobile','padding-bottom','80',0,''),(13994,4304,'114633','watch-mobile','block_type','6',0,''),(13995,4305,'114634','watch-mobile','block_type','1',0,''),(13996,4305,'114634','watch-mobile','padding-top','20',0,''),(13997,4305,'114634','watch-mobile','padding-left','20',0,''),(13998,4305,'114634','watch-mobile','padding-right','20',0,''),(13999,4305,'114634','watch-mobile','padding-bottom','20',0,''),(14000,4305,'114634','watch-mobile','border-top-width','1',0,''),(14001,4305,'114634','watch-mobile','border-left-width','1',0,''),(14002,4305,'114634','watch-mobile','border-right-width','1',0,''),(14003,4305,'114634','watch-mobile','border-bottom-width','1',0,''),(14004,4305,'114634','watch-mobile','border-top-color','$border-color-1',0,''),(14005,4305,'114634','watch-mobile','border-left-color','$border-color-1',0,''),(14006,4305,'114634','watch-mobile','border-right-color','$border-color-1',0,''),(14007,4305,'114634','watch-mobile','border-bottom-color','$border-color-1',0,''),(14008,4305,'114634','watch-mobile','margin-right','20',0,''),(14009,4308,'114637','watch-mobile','block_type','1',0,''),(14010,4308,'114637','watch-mobile','padding-top','20',0,''),(14011,4309,'114638','watch-mobile','block_type','6',0,''),(14012,4310,'114639','watch-mobile','padding-right','20',0,''),(14013,4312,'114641','watch-mobile','block_type','1',0,''),(14014,4312,'114641','watch-mobile','padding-top','20',0,''),(14015,4313,'114642','watch-mobile','block_type','6',0,''),(14016,4314,'114643','watch-mobile','padding-right','20',0,''),(14017,4316,'114645','watch-mobile','block_type','1',0,''),(14018,4317,'114646','watch-mobile','block_type','6',0,''),(14019,4317,'114646','watch-mobile','schema','6-3',0,''),(14020,4317,'114646','watch-mobile','schema','6-3',0,'299'),(14021,4318,'114647','watch-mobile','aria_name','account-menu',0,''),(14022,4320,'114649','watch-mobile','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(14023,4321,'114650','watch-mobile','text','CANCEL',0,''),(14024,4321,'114650','watch-mobile','like_button','1',0,''),(14025,4321,'114650','watch-mobile','padding-bottom','20',0,''),(14026,4322,'114651','watch-mobile','block_type','1',0,''),(14027,4322,'114651','watch-mobile','padding-top','20',0,''),(14028,4323,'114652','watch-mobile','block_type','1',0,''),(14029,4324,'114653','watch-mobile','tab_1','RETURNING CUSTOMER',1,''),(14030,4324,'114653','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(14031,4326,'114655','watch-mobile','block_type','8',0,''),(14032,4327,'114656','watch-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(14033,4328,'114657','watch-mobile','block_type','1',0,''),(14034,4328,'114657','watch-mobile','padding-left','20',0,''),(14035,4328,'114657','watch-mobile','padding-right','20',0,''),(14036,4330,'114659','watch-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(14037,4331,'114660','watch-mobile','block_type','1',0,''),(14038,4332,'114661','watch-mobile','margin-bottom','30',0,''),(14039,4333,'114662','watch-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(14040,4334,'114663','watch-mobile','margin_left_measure','auto',0,''),(14041,4334,'114663','watch-mobile','margin_right_measure','auto',0,''),(14042,4334,'114663','watch-mobile','max-width','560',0,''),(14043,4335,'114664','watch-mobile','block_type','1',0,''),(14044,4337,'114666','watch-mobile','block_type','6',0,''),(14045,4337,'114666','watch-mobile','font-weight','400',0,''),(14046,4337,'114666','watch-mobile','schema','6-2',0,''),(14048,4338,'114667','watch-mobile','font-weight','400',0,''),(14049,4338,'114667','watch-mobile','padding-right','40',0,''),(14052,4339,'114668','watch-mobile','col_in_row','3',0,''),(14053,4339,'114668','watch-mobile','products_align','left',0,''),(14054,4339,'114668','watch-mobile','font-weight','400',0,''),(14055,4339,'114668','watch-mobile','show_qty_input','0',0,''),(14056,4339,'114668','watch-mobile','listing_type','productListing',0,''),(14057,4339,'114668','watch-mobile','listing_type_rows','no',0,''),(14058,4339,'114668','watch-mobile','show_buy_button_b2b','on',0,''),(14059,4339,'114668','watch-mobile','show_wishlist_button_b2b','1',0,''),(14060,4339,'114668','watch-mobile','show_compare_b2b','1',0,''),(14061,4339,'114668','watch-mobile','show_stock','0',0,''),(14062,4339,'114668','watch-mobile','show_description','0',0,''),(14063,4339,'114668','watch-mobile','show_model','0',0,''),(14064,4339,'114668','watch-mobile','show_properties','0',0,''),(14065,4339,'114668','watch-mobile','show_rating','0',0,''),(14066,4339,'114668','watch-mobile','show_rating_counts','0',0,''),(14067,4339,'114668','watch-mobile','show_price','0',0,''),(14068,4339,'114668','watch-mobile','show_buy_button','0',0,''),(14069,4339,'114668','watch-mobile','show_view_button','0',0,''),(14070,4339,'114668','watch-mobile','show_wishlist_button','0',0,''),(14071,4339,'114668','watch-mobile','show_compare','0',0,''),(14072,4339,'114668','watch-mobile','show_name_rows','0',0,''),(14073,4339,'114668','watch-mobile','show_image_rows','0',0,''),(14074,4339,'114668','watch-mobile','show_stock_rows','0',0,''),(14075,4339,'114668','watch-mobile','show_description_rows','0',0,''),(14076,4339,'114668','watch-mobile','show_model_rows','0',0,''),(14077,4339,'114668','watch-mobile','show_properties_rows','0',0,''),(14078,4339,'114668','watch-mobile','show_rating_rows','0',0,''),(14079,4339,'114668','watch-mobile','show_rating_counts_rows','0',0,''),(14080,4339,'114668','watch-mobile','show_price_rows','0',0,''),(14081,4339,'114668','watch-mobile','show_buy_button_rows','0',0,''),(14082,4339,'114668','watch-mobile','show_qty_input_rows','0',0,''),(14083,4339,'114668','watch-mobile','show_view_button_rows','0',0,''),(14084,4339,'114668','watch-mobile','show_wishlist_button_rows','0',0,''),(14085,4339,'114668','watch-mobile','show_compare_rows','0',0,''),(14086,4339,'114668','watch-mobile','show_name_b2b','0',0,''),(14087,4339,'114668','watch-mobile','show_image_b2b','0',0,''),(14088,4339,'114668','watch-mobile','show_stock_b2b','0',0,''),(14089,4339,'114668','watch-mobile','show_description_b2b','0',0,''),(14090,4339,'114668','watch-mobile','show_model_b2b','0',0,''),(14091,4339,'114668','watch-mobile','show_properties_b2b','0',0,''),(14092,4339,'114668','watch-mobile','show_rating_b2b','0',0,''),(14093,4339,'114668','watch-mobile','show_rating_counts_b2b','0',0,''),(14094,4339,'114668','watch-mobile','show_price_b2b','0',0,''),(14095,4339,'114668','watch-mobile','show_qty_input_b2b','0',0,''),(14096,4339,'114668','watch-mobile','show_view_button_b2b','0',0,''),(14097,4339,'114668','watch-mobile','show_attributes_b2b','0',0,''),(14098,4339,'114668','watch-mobile','items_on_page','9',0,''),(14101,4339,'114668','watch-mobile','product_names_teg','h2',0,''),(14102,4341,'114670','watch-mobile','block_type','5',0,''),(14103,4341,'114670','watch-mobile','padding-top','10',0,''),(14104,4341,'114670','watch-mobile','padding-bottom','10',0,''),(14105,4341,'114670','watch-mobile','schema','5-2',0,''),(14106,4341,'114670','watch-mobile','border-top-color','$border-color-1',0,''),(14107,4341,'114670','watch-mobile','border-top-width','1',0,''),(14108,4343,'114672','watch-mobile','float','right',0,''),(14109,4344,'114673','watch-mobile','listing_type','productListing',0,''),(14110,4346,'114675','watch-mobile','block_type','1',0,''),(14111,4346,'114675','watch-mobile','padding-top','10',0,''),(14112,4346,'114675','watch-mobile','padding-bottom','10',0,''),(14113,4346,'114675','watch-mobile','border-bottom-width','1',0,''),(14114,4346,'114675','watch-mobile','border-bottom-color','$border-color-1',0,''),(14115,4346,'114675','watch-mobile','margin-left','0',0,''),(14116,4346,'114675','watch-mobile','margin-right','0',0,''),(14117,4347,'114676','watch-mobile','float','right',0,''),(14118,4347,'114676','watch-mobile','display','none',0,''),(14119,4348,'114677','watch-mobile','float','left',0,''),(14120,4348,'114677','watch-mobile','clear','none',0,''),(14121,4348,'114677','watch-mobile','margin-left','20',0,''),(14122,4348,'114677','watch-mobile','display','none',0,''),(14123,4349,'114678','watch-mobile','margin-right','20',0,''),(14124,4349,'114678','watch-mobile','float','right',0,''),(14125,4349,'114678','watch-mobile','clear','none',0,''),(14126,4349,'114678','watch-mobile','display','none',0,''),(14127,4350,'114679','watch-mobile','float','left',0,''),(14128,4350,'114679','watch-mobile','clear','none',0,''),(14129,4350,'114679','watch-mobile','sort_pos_3','1',0,''),(14130,4350,'114679','watch-mobile','sort_pos_4','2',0,''),(14131,4350,'114679','watch-mobile','sort_pos_10','3',0,''),(14132,4350,'114679','watch-mobile','sort_pos_9','4',0,''),(14133,4350,'114679','watch-mobile','sort_pos_11','5',0,''),(14134,4350,'114679','watch-mobile','sort_pos_12','6',0,''),(14135,4350,'114679','watch-mobile','sort_pos_14','7',0,''),(14136,4350,'114679','watch-mobile','sort_pos_13','8',0,''),(14137,4350,'114679','watch-mobile','sort_pos_8','9',0,''),(14138,4350,'114679','watch-mobile','sort_pos_7','10',0,''),(14139,4350,'114679','watch-mobile','sort_pos_2','11',0,''),(14140,4350,'114679','watch-mobile','sort_pos_1','12',0,''),(14141,4350,'114679','watch-mobile','sort_pos_6','13',0,''),(14142,4350,'114679','watch-mobile','sort_pos_5','14',0,''),(14143,4350,'114679','watch-mobile','sort_pos_0','15',0,''),(14144,4350,'114679','watch-mobile','sort_hide_10','1',0,''),(14145,4350,'114679','watch-mobile','sort_hide_9','1',0,''),(14146,4350,'114679','watch-mobile','hide_icons','1',0,''),(14147,4350,'114679','watch-mobile','sort_hide_16','1',0,''),(14148,4350,'114679','watch-mobile','sort_hide_15','1',0,''),(14149,4350,'114679','watch-mobile','sort_hide_3','0',0,''),(14150,4350,'114679','watch-mobile','sort_hide_4','0',0,''),(14151,4350,'114679','watch-mobile','sort_hide_11','1',0,''),(14152,4350,'114679','watch-mobile','sort_hide_12','1',0,''),(14153,4350,'114679','watch-mobile','sort_hide_14','1',0,''),(14154,4350,'114679','watch-mobile','sort_hide_13','1',0,''),(14155,4350,'114679','watch-mobile','sort_hide_8','0',0,''),(14156,4350,'114679','watch-mobile','sort_hide_7','0',0,''),(14157,4350,'114679','watch-mobile','sort_hide_2','1',0,''),(14158,4350,'114679','watch-mobile','sort_hide_1','1',0,''),(14159,4350,'114679','watch-mobile','sort_hide_6','1',0,''),(14160,4350,'114679','watch-mobile','sort_hide_5','1',0,''),(14161,4350,'114679','watch-mobile','sort_hide_0','1',0,''),(14162,4351,'114680','watch-mobile','block_type','1',0,''),(14163,4352,'114681','watch-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(14164,4353,'114682','watch-mobile','margin-bottom','30',0,''),(14165,4354,'114683','watch-mobile','block_type','1',0,''),(14166,4355,'114684','watch-mobile','block_type','1',0,''),(14167,4356,'114685','watch-mobile','margin-bottom','20',0,''),(14168,4357,'114686','watch-mobile','block_type','1',0,''),(14169,4357,'114686','watch-mobile','padding-top','10',0,''),(14170,4357,'114686','watch-mobile','padding-bottom','10',0,''),(14171,4357,'114686','watch-mobile','border-bottom-width','1',0,''),(14172,4357,'114686','watch-mobile','border-bottom-color','$border-color-1',0,''),(14173,4357,'114686','watch-mobile','margin-left','0',0,''),(14174,4357,'114686','watch-mobile','margin-right','0',0,''),(14175,4358,'114687','watch-mobile','float','left',0,''),(14176,4358,'114687','watch-mobile','clear','none',0,''),(14177,4358,'114687','watch-mobile','sort_pos_3','2',0,''),(14178,4358,'114687','watch-mobile','sort_pos_4','1',0,''),(14179,4358,'114687','watch-mobile','sort_pos_10','5',0,''),(14180,4358,'114687','watch-mobile','sort_pos_9','6',0,''),(14181,4358,'114687','watch-mobile','sort_pos_11','7',0,''),(14182,4358,'114687','watch-mobile','sort_pos_12','8',0,''),(14183,4358,'114687','watch-mobile','sort_pos_14','9',0,''),(14184,4358,'114687','watch-mobile','sort_pos_13','10',0,''),(14185,4358,'114687','watch-mobile','sort_pos_8','11',0,''),(14186,4358,'114687','watch-mobile','sort_pos_7','12',0,''),(14187,4358,'114687','watch-mobile','sort_pos_2','13',0,''),(14188,4358,'114687','watch-mobile','sort_pos_1','14',0,''),(14189,4358,'114687','watch-mobile','sort_pos_6','15',0,''),(14190,4358,'114687','watch-mobile','sort_pos_5','16',0,''),(14191,4358,'114687','watch-mobile','sort_pos_0','17',0,''),(14192,4358,'114687','watch-mobile','sort_hide_10','1',0,''),(14193,4358,'114687','watch-mobile','sort_hide_9','1',0,''),(14194,4358,'114687','watch-mobile','sort_pos_15','4',0,''),(14195,4358,'114687','watch-mobile','sort_pos_16','3',0,''),(14196,4358,'114687','watch-mobile','sort_hide_4','0',0,''),(14197,4358,'114687','watch-mobile','sort_hide_3','0',0,''),(14198,4358,'114687','watch-mobile','sort_hide_16','1',0,''),(14199,4358,'114687','watch-mobile','sort_hide_15','1',0,''),(14200,4358,'114687','watch-mobile','sort_hide_11','1',0,''),(14201,4358,'114687','watch-mobile','sort_hide_12','1',0,''),(14202,4358,'114687','watch-mobile','sort_hide_14','1',0,''),(14203,4358,'114687','watch-mobile','sort_hide_13','1',0,''),(14204,4358,'114687','watch-mobile','sort_hide_8','0',0,''),(14205,4358,'114687','watch-mobile','sort_hide_7','0',0,''),(14206,4358,'114687','watch-mobile','sort_hide_2','1',0,''),(14207,4358,'114687','watch-mobile','sort_hide_1','1',0,''),(14208,4358,'114687','watch-mobile','sort_hide_6','1',0,''),(14209,4358,'114687','watch-mobile','sort_hide_5','1',0,''),(14210,4358,'114687','watch-mobile','sort_hide_0','1',0,''),(14211,4358,'114687','watch-mobile','hide_icons','1',0,''),(14212,4359,'114688','watch-mobile','float','left',0,''),(14213,4359,'114688','watch-mobile','clear','none',0,''),(14214,4359,'114688','watch-mobile','margin-left','20',0,''),(14215,4359,'114688','watch-mobile','display','none',0,''),(14216,4360,'114689','watch-mobile','clear','none',0,''),(14217,4360,'114689','watch-mobile','float','left',0,''),(14218,4360,'114689','watch-mobile','padding-top','3',0,''),(14219,4360,'114689','watch-mobile','margin-left','20',0,''),(14220,4361,'114690','watch-mobile','margin-right','20',0,''),(14221,4361,'114690','watch-mobile','float','right',0,''),(14222,4361,'114690','watch-mobile','clear','none',0,''),(14223,4361,'114690','watch-mobile','display','none',0,''),(14224,4362,'114691','watch-mobile','float','right',0,''),(14225,4362,'114691','watch-mobile','display','none',0,''),(14226,4363,'114692','watch-mobile','block_type','5',0,''),(14227,4363,'114692','watch-mobile','padding-top','10',0,''),(14228,4363,'114692','watch-mobile','padding-bottom','10',0,''),(14229,4363,'114692','watch-mobile','schema','5-2',0,''),(14230,4363,'114692','watch-mobile','border-top-color','$border-color-1',0,''),(14231,4363,'114692','watch-mobile','border-top-width','1',0,''),(14232,4364,'114693','watch-mobile','padding-top','3',0,''),(14233,4365,'114694','watch-mobile','float','right',0,''),(14234,4365,'114694','watch-mobile','height','31',0,''),(14235,4368,'114697','watch-mobile','col_in_row','4',0,''),(14236,4368,'114697','watch-mobile','products_align','left',0,''),(14237,4368,'114697','watch-mobile','font-weight','400',0,''),(14238,4368,'114697','watch-mobile','listing_type','productListing',0,''),(14239,4368,'114697','watch-mobile','listing_type_rows','Rows',0,''),(14240,4368,'114697','watch-mobile','show_buy_button_b2b','on',0,''),(14241,4368,'114697','watch-mobile','show_wishlist_button_b2b','1',0,''),(14242,4368,'114697','watch-mobile','show_compare_b2b','1',0,''),(14243,4368,'114697','watch-mobile','listing_type_b2b','b2b',0,''),(14244,4368,'114697','watch-mobile','show_image','0',0,''),(14245,4368,'114697','watch-mobile','show_stock','0',0,''),(14246,4368,'114697','watch-mobile','show_description','0',0,''),(14247,4368,'114697','watch-mobile','show_model','0',0,''),(14248,4368,'114697','watch-mobile','show_properties','0',0,''),(14249,4368,'114697','watch-mobile','show_rating','0',0,''),(14250,4368,'114697','watch-mobile','show_rating_counts','0',0,''),(14251,4368,'114697','watch-mobile','show_price','0',0,''),(14252,4368,'114697','watch-mobile','show_buy_button','0',0,''),(14253,4368,'114697','watch-mobile','show_view_button','0',0,''),(14254,4368,'114697','watch-mobile','show_wishlist_button','0',0,''),(14255,4368,'114697','watch-mobile','show_compare','0',0,''),(14256,4368,'114697','watch-mobile','show_name_rows','0',0,''),(14257,4368,'114697','watch-mobile','show_image_rows','0',0,''),(14258,4368,'114697','watch-mobile','show_stock_rows','0',0,''),(14259,4368,'114697','watch-mobile','show_description_rows','0',0,''),(14260,4368,'114697','watch-mobile','show_model_rows','0',0,''),(14261,4368,'114697','watch-mobile','show_properties_rows','0',0,''),(14262,4368,'114697','watch-mobile','show_rating_rows','0',0,''),(14263,4368,'114697','watch-mobile','show_rating_counts_rows','0',0,''),(14264,4368,'114697','watch-mobile','show_price_rows','0',0,''),(14265,4368,'114697','watch-mobile','show_buy_button_rows','0',0,''),(14266,4368,'114697','watch-mobile','show_qty_input_rows','0',0,''),(14267,4368,'114697','watch-mobile','show_view_button_rows','0',0,''),(14268,4368,'114697','watch-mobile','show_wishlist_button_rows','0',0,''),(14269,4368,'114697','watch-mobile','show_compare_rows','0',0,''),(14270,4368,'114697','watch-mobile','show_name_b2b','0',0,''),(14271,4368,'114697','watch-mobile','show_image_b2b','0',0,''),(14272,4368,'114697','watch-mobile','show_stock_b2b','0',0,''),(14273,4368,'114697','watch-mobile','show_description_b2b','0',0,''),(14274,4368,'114697','watch-mobile','show_model_b2b','0',0,''),(14275,4368,'114697','watch-mobile','show_properties_b2b','0',0,''),(14276,4368,'114697','watch-mobile','show_rating_b2b','0',0,''),(14277,4368,'114697','watch-mobile','show_rating_counts_b2b','0',0,''),(14278,4368,'114697','watch-mobile','show_price_b2b','0',0,''),(14279,4368,'114697','watch-mobile','show_qty_input_b2b','0',0,''),(14280,4368,'114697','watch-mobile','show_view_button_b2b','0',0,''),(14281,4368,'114697','watch-mobile','show_attributes_b2b','0',0,''),(14282,4368,'114697','watch-mobile','items_on_page','12',0,''),(14285,4368,'114697','watch-mobile','product_names_teg','h2',0,''),(14286,4369,'114698','watch-mobile','block_type','1',0,''),(14287,4370,'114699','watch-mobile','block_type','6',0,''),(14288,4370,'114699','watch-mobile','schema','6-3',0,''),(14289,4370,'114699','watch-mobile','schema','6-3',0,'299'),(14290,4371,'114700','watch-mobile','aria_name','account-menu',0,''),(14291,4372,'114701','watch-mobile','link','Order History Info',0,''),(14292,4372,'114701','watch-mobile','text','TEXT_VIEW',0,''),(14293,4372,'114701','watch-mobile','show_pagenation','1',0,''),(14294,4372,'114701','watch-mobile','link_pay','Order pay',0,''),(14295,4372,'114701','watch-mobile','margin-bottom','20',0,''),(14296,4373,'114702','watch-mobile','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(14297,4374,'114703','watch-mobile','block_type','1',0,''),(14298,4375,'114704','watch-mobile','block_type','6',0,''),(14299,4375,'114704','watch-mobile','schema','6-3',0,'299'),(14300,4376,'114705','watch-mobile','aria_name','account-menu',0,''),(14301,4377,'114706','watch-mobile','float','left',0,''),(14302,4378,'114707','watch-mobile','block_type','3',0,''),(14303,4378,'114707','watch-mobile','clear','both',0,''),(14304,4378,'114707','watch-mobile','padding-top','20',0,''),(14305,4378,'114707','watch-mobile','schema','3-4',0,'299'),(14306,4379,'114708','watch-mobile','block_type','1',0,''),(14307,4379,'114708','watch-mobile','padding-right','20',0,''),(14308,4379,'114708','watch-mobile','margin-bottom','20',0,''),(14309,4380,'114709','watch-mobile','link','Tracking numbers',0,''),(14310,4380,'114709','watch-mobile','text','MORE_TRACKING_NUMBER',0,''),(14311,4380,'114709','watch-mobile','popup','1',0,''),(14312,4380,'114709','watch-mobile','order_id','1',0,''),(14313,4380,'114709','watch-mobile','popup_class','tracking-numbers-popup',0,''),(14314,4380,'114709','watch-mobile','font-weight','700',0,''),(14315,4380,'114709','watch-mobile','font-size','18',0,''),(14316,4381,'114710','watch-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(14317,4382,'114711','watch-mobile','short_view','1',0,''),(14318,4382,'114711','watch-mobile','hide_parents','2',0,''),(14319,4383,'114712','watch-mobile','block_type','1',0,''),(14320,4383,'114712','watch-mobile','margin-bottom','20',0,''),(14321,4383,'114712','watch-mobile','padding-right','20',0,''),(14322,4384,'114713','watch-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(14323,4385,'114714','watch-mobile','padding-left','30',0,''),(14324,4385,'114714','watch-mobile','orders_data','telephone',0,''),(14325,4385,'114714','watch-mobile','hide_parents','2',0,''),(14326,4386,'114715','watch-mobile','block_type','1',0,''),(14327,4386,'114715','watch-mobile','padding-right','20',0,''),(14328,4386,'114715','watch-mobile','padding-bottom','20',0,''),(14329,4387,'114716','watch-mobile','orders_data','name',0,''),(14330,4387,'114716','watch-mobile','padding-left','30',0,''),(14331,4388,'114717','watch-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(14332,4389,'114718','watch-mobile','block_type','1',0,''),(14333,4389,'114718','watch-mobile','padding-right','20',0,''),(14334,4389,'114718','watch-mobile','padding-bottom','20',0,''),(14335,4390,'114719','watch-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(14336,4391,'114720','watch-mobile','orders_data','delivery_address',0,''),(14337,4391,'114720','watch-mobile','padding-left','30',0,''),(14338,4392,'114721','watch-mobile','block_type','1',0,''),(14339,4392,'114721','watch-mobile','padding-right','20',0,''),(14340,4393,'114722','watch-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(14341,4394,'114723','watch-mobile','orders_data','shipping_method',0,''),(14342,4394,'114723','watch-mobile','padding-left','30',0,''),(14343,4395,'114724','watch-mobile','block_type','1',0,''),(14344,4395,'114724','watch-mobile','padding-bottom','20',0,''),(14345,4396,'114725','watch-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(14346,4397,'114726','watch-mobile','orders_data','billing_address',0,''),(14347,4397,'114726','watch-mobile','padding-left','30',0,''),(14348,4398,'114727','watch-mobile','block_type','1',0,''),(14349,4399,'114728','watch-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(14350,4400,'114729','watch-mobile','orders_data','payment_method',0,''),(14351,4400,'114729','watch-mobile','padding-left','30',0,''),(14352,4401,'114730','watch-mobile','float','right',0,''),(14353,4403,'114732','watch-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(14354,4406,'114735','watch-mobile','float','right',0,''),(14355,4406,'114735','watch-mobile','clear','none',0,''),(14356,4406,'114735','watch-mobile','margin-left','20',0,''),(14357,4407,'114736','watch-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(14358,4409,'114738','watch-mobile','float','right',0,''),(14359,4409,'114738','watch-mobile','clear','none',0,''),(14360,4409,'114738','watch-mobile','like_button','2',0,''),(14361,4409,'114738','watch-mobile','link','Order pay',0,''),(14362,4410,'114739','watch-mobile','float','right',0,''),(14363,4410,'114739','watch-mobile','clear','none',0,''),(14364,4410,'114739','watch-mobile','margin-left','20',0,''),(14365,4411,'114740','watch-mobile','block_type','2',0,''),(14366,4411,'114740','watch-mobile','padding-top','20',0,''),(14367,4411,'114740','watch-mobile','margin-bottom','20',0,''),(14368,4412,'114741','watch-mobile','like_button','1',0,''),(14369,4412,'114741','watch-mobile','text','IMAGE_BUTTON_BACK',0,''),(14370,4412,'114741','watch-mobile','link','Order History',0,''),(14371,4413,'114742','watch-mobile','text-align','right',0,''),(14372,4414,'114743','watch-mobile','block_type','1',0,''),(14373,4415,'114744','watch-mobile','block_type','6',0,''),(14374,4415,'114744','watch-mobile','schema','6-3',0,''),(14375,4415,'114744','watch-mobile','schema','6-3',0,'299'),(14376,4416,'114745','watch-mobile','aria_name','account-menu',0,''),(14377,4419,'114748','watch-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(14378,4420,'114749','watch-mobile','margin-bottom','20',0,''),(14379,4421,'114750','watch-mobile','block_type','3',0,''),(14380,4421,'114750','watch-mobile','schema','3-4',0,'299'),(14381,4422,'114751','watch-mobile','block_type','1',0,''),(14382,4423,'114752','watch-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(14383,4424,'114753','watch-mobile','padding-left','30',0,''),(14384,4425,'114754','watch-mobile','block_type','1',0,''),(14385,4425,'114754','watch-mobile','padding-right','20',0,''),(14386,4425,'114754','watch-mobile','padding-bottom','20',0,''),(14387,4426,'114755','watch-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(14388,4427,'114756','watch-mobile','orders_data','name',0,''),(14389,4427,'114756','watch-mobile','padding-left','30',0,''),(14390,4428,'114757','watch-mobile','block_type','1',0,''),(14391,4428,'114757','watch-mobile','padding-right','20',0,''),(14392,4429,'114758','watch-mobile','orders_data','shipping_method',0,''),(14393,4429,'114758','watch-mobile','padding-left','30',0,''),(14394,4430,'114759','watch-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(14395,4431,'114760','watch-mobile','block_type','1',0,''),(14396,4431,'114760','watch-mobile','padding-right','20',0,''),(14397,4431,'114760','watch-mobile','padding-bottom','20',0,''),(14398,4432,'114761','watch-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(14399,4433,'114762','watch-mobile','orders_data','delivery_address',0,''),(14400,4433,'114762','watch-mobile','padding-left','30',0,''),(14401,4434,'114763','watch-mobile','block_type','1',0,''),(14402,4435,'114764','watch-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(14403,4436,'114765','watch-mobile','orders_data','payment_method',0,''),(14404,4436,'114765','watch-mobile','padding-left','30',0,''),(14405,4437,'114766','watch-mobile','block_type','1',0,''),(14406,4437,'114766','watch-mobile','padding-bottom','20',0,''),(14407,4438,'114767','watch-mobile','orders_data','billing_address',0,''),(14408,4438,'114767','watch-mobile','padding-left','30',0,''),(14409,4439,'114768','watch-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(14410,4441,'75759','watch-mobile','width','680',0,''),(14411,4441,'75759','watch-mobile','font-weight','400',0,''),(14412,4441,'75759','watch-mobile','font-size','12',0,''),(14413,4441,'75759','watch-mobile','padding-top','20',0,''),(14414,4441,'75759','watch-mobile','padding-bottom','20',0,''),(14415,4442,'75760','watch-mobile','font-weight','normal',0,''),(14416,4442,'75760','watch-mobile','padding-top','20',0,''),(14417,4442,'75760','watch-mobile','font-size','12',0,''),(14418,4443,'75761','watch-mobile','block_type','4',0,''),(14419,4443,'75761','watch-mobile','font-weight','400',0,''),(14420,4443,'75761','watch-mobile','border-top-width','1',0,''),(14421,4443,'75761','watch-mobile','border-top-color','$border-color-1',0,''),(14422,4443,'75761','watch-mobile','border-left-width','1',0,''),(14423,4443,'75761','watch-mobile','border-left-color','$border-color-1',0,''),(14424,4443,'75761','watch-mobile','border-right-width','1',0,''),(14425,4443,'75761','watch-mobile','border-right-color','$border-color-1',0,''),(14426,4443,'75761','watch-mobile','border-bottom-width','1',0,''),(14427,4443,'75761','watch-mobile','border-bottom-color','$border-color-1',0,''),(14428,4444,'75762','watch-mobile','block_type','2',0,''),(14429,4444,'75762','watch-mobile','font-weight','normal',0,''),(14430,4444,'75762','watch-mobile','border-right-width','1',0,''),(14431,4444,'75762','watch-mobile','border-right-color','$border-color-1',0,''),(14432,4445,'75763','watch-mobile','block_type','1',0,''),(14433,4445,'75763','watch-mobile','font-weight','normal',0,''),(14434,4445,'75763','watch-mobile','border-right-width','1',0,''),(14435,4445,'75763','watch-mobile','border-right-color','$border-color-1',0,''),(14436,4445,'75763','watch-mobile','background-color','$background-6',0,''),(14437,4445,'75763','watch-mobile','padding-top','10',0,''),(14438,4445,'75763','watch-mobile','padding-left','10',0,''),(14439,4445,'75763','watch-mobile','padding-right','10',0,''),(14440,4445,'75763','watch-mobile','padding-bottom','10',0,''),(14441,4446,'75764','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(14442,4446,'75764','watch-mobile','font-size','16',0,''),(14443,4446,'75764','watch-mobile','font-weight','bold',0,''),(14444,4446,'75764','watch-mobile','padding-bottom','10',0,''),(14445,4447,'75765','watch-mobile','font-size','16',0,''),(14446,4447,'75765','watch-mobile','font-weight','normal',0,''),(14447,4448,'75766','watch-mobile','block_type','1',0,''),(14448,4448,'75766','watch-mobile','font-weight','normal',0,''),(14449,4448,'75766','watch-mobile','padding-top','10',0,''),(14450,4448,'75766','watch-mobile','padding-left','10',0,''),(14451,4448,'75766','watch-mobile','padding-right','10',0,''),(14452,4448,'75766','watch-mobile','padding-bottom','10',0,''),(14453,4452,'75770','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(14454,4452,'75770','watch-mobile','font-size','14',0,''),(14455,4452,'75770','watch-mobile','font-weight','bold',0,''),(14456,4452,'75770','watch-mobile','padding-top','10',0,''),(14457,4453,'75771','watch-mobile','text','<p>CUSTOMER:</p>',1,''),(14458,4453,'75771','watch-mobile','font-size','14',0,''),(14459,4453,'75771','watch-mobile','font-weight','bold',0,''),(14460,4454,'75772','watch-mobile','text','<p>PHONE NUMBER:</p>',1,''),(14461,4454,'75772','watch-mobile','font-size','14',0,''),(14462,4454,'75772','watch-mobile','font-weight','bold',0,''),(14463,4454,'75772','watch-mobile','padding-top','10',0,''),(14464,4455,'75773','watch-mobile','block_type','2',0,''),(14465,4455,'75773','watch-mobile','font-weight','normal',0,''),(14466,4455,'75773','watch-mobile','border-right-width','1',0,''),(14467,4455,'75773','watch-mobile','border-right-color','$border-color-1',0,''),(14468,4455,'75773','watch-mobile','border-top-width','1',0,''),(14469,4455,'75773','watch-mobile','border-top-color','$border-color-1',0,''),(14470,4456,'75774','watch-mobile','block_type','1',0,''),(14471,4456,'75774','watch-mobile','font-weight','normal',0,''),(14472,4456,'75774','watch-mobile','padding-top','10',0,''),(14473,4456,'75774','watch-mobile','padding-left','10',0,''),(14474,4456,'75774','watch-mobile','padding-right','10',0,''),(14475,4456,'75774','watch-mobile','padding-bottom','10',0,''),(14476,4456,'75774','watch-mobile','border-right-width','1',0,''),(14477,4456,'75774','watch-mobile','border-right-color','$border-color-1',0,''),(14478,4458,'75776','watch-mobile','text','<p>Shipping via</p>',1,''),(14479,4458,'75776','watch-mobile','font-weight','bold',0,''),(14480,4459,'75777','watch-mobile','block_type','1',0,''),(14481,4459,'75777','watch-mobile','font-weight','normal',0,''),(14482,4459,'75777','watch-mobile','padding-top','10',0,''),(14483,4459,'75777','watch-mobile','padding-left','10',0,''),(14484,4459,'75777','watch-mobile','padding-right','10',0,''),(14485,4459,'75777','watch-mobile','padding-bottom','10',0,''),(14486,4460,'75778','watch-mobile','text','<p>Shipping service</p>',1,''),(14487,4460,'75778','watch-mobile','font-weight','bold',0,''),(14488,4462,'75780','watch-mobile','font-weight','normal',0,''),(14489,4462,'75780','watch-mobile','text-align','center',0,''),(14490,4462,'75780','watch-mobile','padding-top','40',0,''),(14491,4463,'75781','watch-mobile','block_type','1',0,''),(14492,4463,'75781','watch-mobile','font-weight','normal',0,''),(14493,4463,'75781','watch-mobile','padding-top','10',0,''),(14494,4463,'75781','watch-mobile','padding-bottom','10',0,''),(14495,4464,'75782','watch-mobile','text','<p>If undelivered please return to:</p>',1,''),(14496,4464,'75782','watch-mobile','font-weight','bold',0,''),(14497,4466,'75784','watch-mobile','block_type','2',0,''),(14498,4466,'75784','watch-mobile','font-weight','normal',0,''),(14499,4466,'75784','watch-mobile','padding-bottom','20',0,''),(14500,4467,'75785','watch-mobile','font-weight','400',0,''),(14501,4467,'75785','watch-mobile','text-align','center',0,''),(14502,4467,'75785','watch-mobile','padding-top','10',0,''),(14503,4467,'75785','watch-mobile','logo','themes/watch-mobile/img/watchlogo-3.png',1,''),(14504,4468,'75786','watch-mobile','block_type','1',0,''),(14505,4469,'75787','watch-mobile','font-weight','400',0,''),(14506,4469,'75787','watch-mobile','text-align','right',0,''),(14507,4469,'75787','watch-mobile','padding-bottom','10',0,''),(14508,4469,'75787','watch-mobile','address_spacer',',',0,''),(14509,4470,'75788','watch-mobile','block_type','11',0,''),(14510,4470,'75788','watch-mobile','font-weight','normal',0,''),(14511,4471,'75789','watch-mobile','text','<p>Phone:</p>',1,''),(14512,4471,'75789','watch-mobile','font-weight','normal',0,''),(14513,4471,'75789','watch-mobile','text-align','right',0,''),(14514,4472,'75790','watch-mobile','font-weight','normal',0,''),(14515,4472,'75790','watch-mobile','text-align','right',0,''),(14516,4473,'75791','watch-mobile','block_type','11',0,''),(14517,4473,'75791','watch-mobile','font-weight','400',0,''),(14518,4474,'75792','watch-mobile','text','<p>Web:</p>',1,''),(14519,4474,'75792','watch-mobile','font-weight','400',0,''),(14520,4474,'75792','watch-mobile','text-align','right',0,''),(14521,4475,'75793','watch-mobile','font-weight','normal',0,''),(14522,4475,'75793','watch-mobile','text-align','right',0,''),(14523,4476,'75794','watch-mobile','block_type','11',0,''),(14524,4476,'75794','watch-mobile','font-weight','normal',0,''),(14525,4477,'75795','watch-mobile','text','<p>Email:</p>',1,''),(14526,4477,'75795','watch-mobile','font-weight','normal',0,''),(14527,4477,'75795','watch-mobile','text-align','right',0,''),(14528,4478,'75796','watch-mobile','font-weight','normal',0,''),(14529,4478,'75796','watch-mobile','text-align','right',0,''),(14530,4479,'114770','watch-mobile','block_type','1',0,''),(14531,4480,'114771','watch-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(14532,4481,'114772','watch-mobile','block_type','8',0,''),(14533,4482,'114773','watch-mobile','margin-bottom','20',0,''),(14534,4483,'114774','watch-mobile','text','##TEXT_MAIN##',0,''),(14535,4483,'114774','watch-mobile','margin-bottom','20',0,''),(14536,4483,'114774','watch-mobile','text-align','center',0,''),(14537,4485,'75798','watch-mobile','block_type','2',0,''),(14538,4486,'75799','watch-mobile','block_type','1',0,''),(14539,4486,'75799','watch-mobile','style_class','product',0,''),(14540,4486,'75799','watch-mobile','padding-right','10',0,''),(14541,4486,'75799','watch-mobile','padding-bottom','20',0,''),(14542,4487,'75800','watch-mobile','block_type','2',0,''),(14543,4488,'75801','watch-mobile','product_element','image',0,''),(14544,4488,'75801','watch-mobile','padding-right','10',0,''),(14545,4489,'75802','watch-mobile','product_element','products_price_old',0,''),(14546,4489,'75802','watch-mobile','font-family','$font-1',0,''),(14547,4489,'75802','watch-mobile','font-size','14',0,''),(14548,4489,'75802','watch-mobile','text-decoration','line-through',0,''),(14549,4490,'75803','watch-mobile','product_element','products_price',0,''),(14550,4490,'75803','watch-mobile','font-family','$font-1',0,''),(14551,4490,'75803','watch-mobile','font-size','20',0,''),(14552,4490,'75803','watch-mobile','padding-top','20',0,''),(14553,4491,'75804','watch-mobile','block_type','1',0,''),(14554,4492,'75805','watch-mobile','product_element','products_name',0,''),(14555,4492,'75805','watch-mobile','font-family','$font-1',0,''),(14556,4492,'75805','watch-mobile','padding-bottom','10',0,''),(14557,4492,'75805','watch-mobile','font-size','16',0,''),(14558,4493,'75806','watch-mobile','block_type','1',0,''),(14559,4493,'75806','watch-mobile','style_class','product',0,''),(14560,4493,'75806','watch-mobile','padding-left','10',0,''),(14561,4493,'75806','watch-mobile','padding-bottom','20',0,''),(14562,4494,'75807','watch-mobile','block_type','1',0,''),(14563,4495,'75808','watch-mobile','product_element','products_name',0,''),(14564,4495,'75808','watch-mobile','font-family','$font-1',0,''),(14565,4495,'75808','watch-mobile','font-size','16',0,''),(14566,4495,'75808','watch-mobile','padding-bottom','10',0,''),(14567,4496,'75809','watch-mobile','block_type','2',0,''),(14568,4497,'75810','watch-mobile','product_element','image',0,''),(14569,4497,'75810','watch-mobile','padding-right','10',0,''),(14570,4498,'75811','watch-mobile','font-size','14',0,''),(14571,4498,'75811','watch-mobile','font-family','$font-1',0,''),(14572,4498,'75811','watch-mobile','text-decoration','line-through',0,''),(14573,4498,'75811','watch-mobile','product_element','products_price_old',0,''),(14574,4499,'75812','watch-mobile','product_element','products_price',0,''),(14575,4499,'75812','watch-mobile','font-family','$font-1',0,''),(14576,4499,'75812','watch-mobile','font-size','20',0,''),(14577,4499,'75812','watch-mobile','padding-top','20',0,''),(14578,4500,'75813','watch-mobile','font-size','30',0,''),(14579,4500,'75813','watch-mobile','font-family','$font-1',0,''),(14580,4500,'75813','watch-mobile','text-align','center',0,''),(14581,4500,'75813','watch-mobile','padding-bottom','50',0,''),(14582,4501,'75814','watch-mobile','padding-bottom','20',0,''),(14583,4501,'75814','watch-mobile','text-align','center',0,''),(14584,4502,'75815','watch-mobile','width','680',0,''),(14585,4503,'75816','watch-mobile','padding-top','200',0,''),(14586,4503,'75816','watch-mobile','padding-left','200',0,''),(14588,4504,'75817','watch-mobile','text','osCommerce 4',1,''),(14589,4504,'75817','watch-mobile','font-family','$font-1',0,''),(14590,4504,'75817','watch-mobile','font-size','40',0,''),(14591,4504,'75817','watch-mobile','padding-top','50',0,''),(14592,4504,'75817','watch-mobile','text-align','center',0,''),(14593,4505,'75818','watch-mobile','block_type','2',0,''),(14594,4505,'75818','watch-mobile','border-top-width','1',0,''),(14595,4505,'75818','watch-mobile','border-top-color','$border-color-1',0,''),(14596,4506,'75819','watch-mobile','text-align','right',0,''),(14597,4506,'75819','watch-mobile','padding-top','15',0,''),(14598,4506,'75819','watch-mobile','padding-bottom','15',0,''),(14599,4506,'75819','watch-mobile','font-size','14',0,''),(14600,4507,'75820','watch-mobile','font-family','$font-1',0,''),(14601,4507,'75820','watch-mobile','text-align','center',0,''),(14602,4507,'75820','watch-mobile','font-size','20',0,''),(14603,4507,'75820','watch-mobile','color','$color-font-6',0,''),(14604,4507,'75820','watch-mobile','border-bottom-width','1',0,''),(14605,4507,'75820','watch-mobile','border-bottom-color','$border-color-10',0,''),(14606,4507,'75820','watch-mobile','padding-top','10',0,''),(14607,4507,'75820','watch-mobile','padding-bottom','10',0,''),(14608,4508,'114775','watch-mobile','block_type','1',0,''),(14609,4509,'114776','watch-mobile','block_type','6',0,''),(14610,4509,'114776','watch-mobile','schema','6-3',0,''),(14611,4509,'114776','watch-mobile','schema','6-3',0,'299'),(14612,4510,'114777','watch-mobile','aria_name','account-menu',0,''),(14613,4511,'114778','watch-mobile','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(14614,4512,'114779','watch-mobile','max_items','10',0,''),(14615,4513,'114780','watch-mobile','block_type','1',0,''),(14616,4513,'114780','watch-mobile','padding-top','20',0,''),(14617,4513,'114780','watch-mobile','padding-left','20',0,''),(14618,4513,'114780','watch-mobile','padding-right','20',0,''),(14619,4513,'114780','watch-mobile','padding-bottom','20',0,''),(14620,4514,'114781','watch-mobile','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(14621,4516,'114783','watch-mobile','block_type','1',0,''),(14622,4517,'114784','watch-mobile','margin_left_measure','auto',0,''),(14623,4517,'114784','watch-mobile','margin_right_measure','auto',0,''),(14624,4517,'114784','watch-mobile','max-width','560',0,''),(14625,4518,'114785','watch-mobile','margin-bottom','30',0,''),(14626,4519,'114786','watch-mobile','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(14627,4520,'75821','watch-mobile','block_type','1',0,''),(14628,4521,'75822','watch-mobile','block_type','2',0,''),(14629,4521,'75822','watch-mobile','border-top-width','1',0,''),(14630,4521,'75822','watch-mobile','border-top-color','$border-color-1',0,''),(14631,4521,'75822','watch-mobile','padding-top','15',0,''),(14632,4521,'75822','watch-mobile','padding-bottom','15',0,''),(14633,4523,'75824','watch-mobile','font-size','30',0,''),(14634,4523,'75824','watch-mobile','font-weight','400',0,''),(14635,4523,'75824','watch-mobile','line-height','35',0,''),(14636,4523,'75824','watch-mobile','font-family','$font-1',0,''),(14637,4523,'75824','watch-mobile','line_height_measure','px',0,''),(14638,4524,'75825','watch-mobile','font-weight','400',0,''),(14639,4525,'75826','watch-mobile','font-weight','normal',0,''),(14640,4525,'75826','watch-mobile','padding-bottom','20',0,''),(14641,4526,'75827','watch-mobile','padding-right','0',0,''),(14642,4526,'75827','watch-mobile','align_position','horizontal',0,''),(14643,4528,'75829','watch-mobile','text-align','right',0,''),(14644,4528,'75829','watch-mobile','width','100',0,'290'),(14645,4528,'75829','watch-mobile','width_measure','%',0,'290'),(14646,4528,'75829','watch-mobile','float','none',0,'290'),(14647,4528,'75829','watch-mobile','margin-bottom','20',0,''),(14648,4529,'75830','watch-mobile','font-weight','400',0,''),(14649,4529,'75830','watch-mobile','box_align','4',0,''),(14650,4529,'75830','watch-mobile','align_position','horizontal',0,''),(14651,4529,'75830','watch-mobile','margin-bottom','30',0,''),(14652,4530,'75831','watch-mobile','font-weight','400',0,''),(14653,4531,'75832','watch-mobile','block_type','1',0,''),(14654,4531,'75832','watch-mobile','style_class','personal-buttons',0,''),(14655,4531,'75832','watch-mobile','margin-bottom','20',0,''),(14656,4531,'75832','watch-mobile','border-bottom-width','1',0,''),(14657,4531,'75832','watch-mobile','border-bottom-color','$border-color-1',0,''),(14658,4531,'75832','watch-mobile','padding-left','30',0,''),(14659,4536,'75837','watch-mobile','font-weight','normal',0,''),(14660,4536,'75837','watch-mobile','padding-bottom','20',0,''),(14661,4536,'75837','watch-mobile','show_qty_input','1',0,''),(14662,4536,'75837','watch-mobile','show_compare','1',0,''),(14663,4536,'75837','watch-mobile','col_in_row','1',0,''),(14664,4536,'75837','watch-mobile','view_as','carousel',0,''),(14665,4536,'75837','watch-mobile','listing_type','productListing',0,''),(14666,4537,'75838','watch-mobile','font-weight','400',0,''),(14667,4537,'75838','watch-mobile','padding-bottom','20',0,''),(14668,4537,'75838','watch-mobile','show_qty_input','1',0,''),(14669,4537,'75838','watch-mobile','show_compare','1',0,''),(14670,4537,'75838','watch-mobile','listing_type','type-1',0,''),(14671,4537,'75838','watch-mobile','view_as','carousel',0,''),(14672,4537,'75838','watch-mobile','show_name','0',0,''),(14673,4537,'75838','watch-mobile','show_image','0',0,''),(14674,4537,'75838','watch-mobile','show_stock','0',0,''),(14675,4537,'75838','watch-mobile','show_description','0',0,''),(14676,4537,'75838','watch-mobile','show_model','0',0,''),(14677,4537,'75838','watch-mobile','show_properties','0',0,''),(14678,4537,'75838','watch-mobile','show_rating','0',0,''),(14679,4537,'75838','watch-mobile','show_rating_counts','0',0,''),(14680,4537,'75838','watch-mobile','show_price','0',0,''),(14681,4537,'75838','watch-mobile','show_buy_button','0',0,''),(14682,4537,'75838','watch-mobile','show_view_button','0',0,''),(14683,4537,'75838','watch-mobile','show_wishlist_button','0',0,''),(14684,4537,'75838','watch-mobile','display','none',0,'291'),(14685,4537,'75838','watch-mobile','product_names_teg','h2',0,''),(14686,4538,'75839','watch-mobile','font-weight','normal',0,''),(14687,4538,'75839','watch-mobile','padding-bottom','20',0,''),(14688,4539,'75840','watch-mobile','tab_1','Description',1,''),(14689,4539,'75840','watch-mobile','tab_2','Reviews',1,''),(14690,4539,'75840','watch-mobile','font-weight','400',0,''),(14691,4539,'75840','watch-mobile','margin-top','20',0,''),(14692,4542,'75843','watch-mobile','padding-bottom','10',0,''),(14693,4542,'75843','watch-mobile','padding-top','5',0,''),(14694,4543,'75844','watch-mobile','font-weight','normal',0,''),(14695,4543,'75844','watch-mobile','padding-top','20',0,''),(14696,4543,'75844','watch-mobile','padding-bottom','20',0,''),(14697,4543,'75844','watch-mobile','border-top-width','1',0,''),(14698,4543,'75844','watch-mobile','border-top-color','$border-color-10',0,''),(14699,4545,'75846','watch-mobile','font-weight','400',0,''),(14700,4545,'75846','watch-mobile','padding-bottom','20',0,''),(14701,4545,'75846','watch-mobile','show_qty_input','1',0,''),(14702,4545,'75846','watch-mobile','show_compare','1',0,''),(14703,4545,'75846','watch-mobile','show_name','0',0,''),(14704,4545,'75846','watch-mobile','show_image','0',0,''),(14705,4545,'75846','watch-mobile','show_stock','0',0,''),(14706,4545,'75846','watch-mobile','show_description','0',0,''),(14707,4545,'75846','watch-mobile','show_model','0',0,''),(14708,4545,'75846','watch-mobile','show_properties','0',0,''),(14709,4545,'75846','watch-mobile','show_rating','0',0,''),(14710,4545,'75846','watch-mobile','show_rating_counts','0',0,''),(14711,4545,'75846','watch-mobile','show_price','0',0,''),(14712,4545,'75846','watch-mobile','show_buy_button','0',0,''),(14713,4545,'75846','watch-mobile','show_view_button','0',0,''),(14714,4545,'75846','watch-mobile','show_wishlist_button','0',0,''),(14715,4545,'75846','watch-mobile','listing_type','productListing',0,''),(14716,4545,'75846','watch-mobile','col_in_row','1',0,''),(14717,4545,'75846','watch-mobile','view_as','carousel',0,''),(14718,4556,'75888','watch-mobile','block_type','1',0,''),(14719,4556,'75888','watch-mobile','style_class','item-holder',0,''),(14720,4556,'75888','watch-mobile','padding-top','25',0,''),(14721,4556,'75888','watch-mobile','padding-left','25',0,''),(14722,4556,'75888','watch-mobile','padding-right','25',0,''),(14723,4556,'75888','watch-mobile','padding-bottom','25',0,''),(14724,4556,'75888','watch-mobile','text-align','left',0,''),(14725,4559,'75892','watch-mobile','description_characters','90',0,''),(14726,4560,'75893','watch-mobile','text-align','right',0,''),(14727,4560,'75893','watch-mobile','margin-bottom','10',0,''),(14728,4561,'75894','watch-mobile','text-align','right',0,''),(14729,4561,'75894','watch-mobile','clear','none',0,''),(14730,4561,'75894','watch-mobile','float','left',0,''),(14731,4563,'75896','watch-mobile','block_type','2',0,''),(14732,4564,'75897','watch-mobile','margin-bottom','7',0,''),(14733,4565,'75898','watch-mobile','margin-bottom','10',0,''),(14734,4565,'75898','watch-mobile','text-align','right',0,''),(14735,4565,'75898','watch-mobile','float','right',0,''),(14736,4566,'75899','watch-mobile','clear','both',0,''),(14737,4567,'75900','watch-mobile','float','left',0,''),(14738,4567,'75900','watch-mobile','margin-right','20',0,''),(14739,4567,'75900','watch-mobile','margin-bottom','5',0,''),(14740,4568,'75857','watch-mobile','block_type','1',0,''),(14741,4569,'75858','watch-mobile','font-weight','400',0,''),(14742,4569,'75858','watch-mobile','padding-right','40',0,''),(14743,4569,'75858','watch-mobile','padding-right','0',0,'315'),(14744,4569,'75858','watch-mobile','padding-right','0',0,'317'),(14745,4569,'75858','watch-mobile','margin-bottom','20',0,''),(14746,4570,'75859','watch-mobile','text-align','center',0,''),(14747,4570,'75859','watch-mobile','margin-bottom','20',0,''),(14748,4572,'75861','watch-mobile','margin-bottom','20',0,''),(14749,4572,'75861','watch-mobile','text-align','center',0,''),(14750,4573,'75862','watch-mobile','block_type','2',0,''),(14751,4573,'75862','watch-mobile','margin-bottom','20',0,''),(14752,4574,'75863','watch-mobile','sort_pos_3','1',0,''),(14753,4574,'75863','watch-mobile','sort_pos_4','2',0,''),(14754,4574,'75863','watch-mobile','sort_pos_10','5',0,''),(14755,4574,'75863','watch-mobile','sort_pos_9','6',0,''),(14756,4574,'75863','watch-mobile','sort_pos_11','7',0,''),(14757,4574,'75863','watch-mobile','sort_pos_12','8',0,''),(14758,4574,'75863','watch-mobile','sort_pos_14','9',0,''),(14759,4574,'75863','watch-mobile','sort_pos_13','10',0,''),(14760,4574,'75863','watch-mobile','sort_pos_8','11',0,''),(14761,4574,'75863','watch-mobile','sort_pos_7','12',0,''),(14762,4574,'75863','watch-mobile','sort_pos_2','13',0,''),(14763,4574,'75863','watch-mobile','sort_pos_1','14',0,''),(14764,4574,'75863','watch-mobile','sort_pos_6','15',0,''),(14765,4574,'75863','watch-mobile','sort_pos_5','16',0,''),(14766,4574,'75863','watch-mobile','sort_pos_0','17',0,''),(14767,4574,'75863','watch-mobile','sort_hide_10','1',0,''),(14768,4574,'75863','watch-mobile','sort_hide_9','1',0,''),(14769,4574,'75863','watch-mobile','sort_pos_15','4',0,''),(14770,4574,'75863','watch-mobile','sort_pos_16','3',0,''),(14771,4574,'75863','watch-mobile','sort_hide_3','0',0,''),(14772,4574,'75863','watch-mobile','sort_hide_4','0',0,''),(14773,4574,'75863','watch-mobile','sort_hide_16','1',0,''),(14774,4574,'75863','watch-mobile','sort_hide_15','1',0,''),(14775,4574,'75863','watch-mobile','sort_hide_11','0',0,''),(14776,4574,'75863','watch-mobile','sort_hide_12','0',0,''),(14777,4574,'75863','watch-mobile','sort_hide_14','0',0,''),(14778,4574,'75863','watch-mobile','sort_hide_13','0',0,''),(14779,4574,'75863','watch-mobile','sort_hide_8','0',0,''),(14780,4574,'75863','watch-mobile','sort_hide_7','0',0,''),(14781,4574,'75863','watch-mobile','sort_hide_2','0',0,''),(14782,4574,'75863','watch-mobile','sort_hide_1','0',0,''),(14783,4574,'75863','watch-mobile','sort_hide_6','0',0,''),(14784,4574,'75863','watch-mobile','sort_hide_5','0',0,''),(14785,4574,'75863','watch-mobile','sort_hide_0','0',0,''),(14786,4575,'75864','watch-mobile','text-align','right',0,''),(14787,4575,'75864','watch-mobile','padding-top','10',0,''),(14788,4576,'75865','watch-mobile','col_in_row','2',0,''),(14789,4576,'75865','watch-mobile','products_align','left',0,''),(14790,4576,'75865','watch-mobile','font-weight','400',0,''),(14791,4576,'75865','watch-mobile','show_qty_input','1',0,''),(14792,4576,'75865','watch-mobile','listing_type','productListing',0,''),(14793,4576,'75865','watch-mobile','listing_type_rows','type-1_2',0,''),(14794,4576,'75865','watch-mobile','show_buy_button_b2b','on',0,''),(14795,4576,'75865','watch-mobile','show_wishlist_button_b2b','1',0,''),(14796,4576,'75865','watch-mobile','show_compare_b2b','1',0,''),(14797,4576,'75865','watch-mobile','listing_type_b2b','type-1_3',0,''),(14798,4576,'75865','watch-mobile','show_name','0',0,''),(14799,4576,'75865','watch-mobile','show_image','0',0,''),(14800,4576,'75865','watch-mobile','show_stock','0',0,''),(14801,4576,'75865','watch-mobile','show_description','1',0,''),(14802,4576,'75865','watch-mobile','show_model','1',0,''),(14803,4576,'75865','watch-mobile','show_properties','1',0,''),(14804,4576,'75865','watch-mobile','show_rating_counts','1',0,''),(14805,4576,'75865','watch-mobile','show_price','0',0,''),(14806,4576,'75865','watch-mobile','show_buy_button','1',0,''),(14807,4576,'75865','watch-mobile','show_view_button','1',0,''),(14808,4576,'75865','watch-mobile','show_wishlist_button','1',0,''),(14809,4576,'75865','watch-mobile','show_compare','1',0,''),(14810,4576,'75865','watch-mobile','show_name_rows','0',0,''),(14811,4576,'75865','watch-mobile','show_image_rows','0',0,''),(14812,4576,'75865','watch-mobile','show_stock_rows','0',0,''),(14813,4576,'75865','watch-mobile','show_description_rows','0',0,''),(14814,4576,'75865','watch-mobile','show_model_rows','0',0,''),(14815,4576,'75865','watch-mobile','show_properties_rows','0',0,''),(14816,4576,'75865','watch-mobile','show_rating_rows','0',0,''),(14817,4576,'75865','watch-mobile','show_rating_counts_rows','0',0,''),(14818,4576,'75865','watch-mobile','show_price_rows','0',0,''),(14819,4576,'75865','watch-mobile','show_buy_button_rows','0',0,''),(14820,4576,'75865','watch-mobile','show_qty_input_rows','0',0,''),(14821,4576,'75865','watch-mobile','show_view_button_rows','0',0,''),(14822,4576,'75865','watch-mobile','show_wishlist_button_rows','0',0,''),(14823,4576,'75865','watch-mobile','show_compare_rows','0',0,''),(14824,4576,'75865','watch-mobile','show_name_b2b','0',0,''),(14825,4576,'75865','watch-mobile','show_image_b2b','0',0,''),(14826,4576,'75865','watch-mobile','show_stock_b2b','0',0,''),(14827,4576,'75865','watch-mobile','show_description_b2b','0',0,''),(14828,4576,'75865','watch-mobile','show_model_b2b','0',0,''),(14829,4576,'75865','watch-mobile','show_properties_b2b','0',0,''),(14830,4576,'75865','watch-mobile','show_rating_b2b','0',0,''),(14831,4576,'75865','watch-mobile','show_rating_counts_b2b','0',0,''),(14832,4576,'75865','watch-mobile','show_price_b2b','0',0,''),(14833,4576,'75865','watch-mobile','show_qty_input_b2b','0',0,''),(14834,4576,'75865','watch-mobile','show_view_button_b2b','0',0,''),(14835,4576,'75865','watch-mobile','show_attributes_b2b','0',0,''),(14836,4576,'75865','watch-mobile','items_on_page','10',0,''),(14837,4576,'75865','watch-mobile','product_names_teg','h2',0,''),(14838,4578,'114788','watch-mobile','block_type','1',0,''),(14839,4580,'114790','watch-mobile','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(14840,4581,'114791','watch-mobile','width','680',0,''),(14841,4581,'114791','watch-mobile','font-weight','normal',0,''),(14842,4581,'114791','watch-mobile','font-size','12',0,''),(14843,4581,'114791','watch-mobile','padding-top','20',0,''),(14844,4581,'114791','watch-mobile','padding-bottom','20',0,''),(14845,4581,'114791','watch-mobile','color','$color-font-7',0,''),(14846,4582,'114792','watch-mobile','block_type','5',0,''),(14847,4582,'114792','watch-mobile','font-weight','normal',0,''),(14848,4582,'114792','watch-mobile','border-bottom-width','1',0,''),(14849,4582,'114792','watch-mobile','border-bottom-color','$border-color-1',0,''),(14850,4582,'114792','watch-mobile','border-top-width','1',0,''),(14851,4582,'114792','watch-mobile','border-top-color','$border-color-1',0,''),(14852,4582,'114792','watch-mobile','border-left-color','$border-color-1',0,''),(14853,4582,'114792','watch-mobile','border-left-width','1',0,''),(14854,4583,'114793','watch-mobile','block_type','1',0,''),(14855,4583,'114793','watch-mobile','font-weight','normal',0,''),(14856,4583,'114793','watch-mobile','padding-top','10',0,''),(14857,4583,'114793','watch-mobile','padding-left','10',0,''),(14858,4583,'114793','watch-mobile','padding-right','10',0,''),(14859,4584,'114794','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(14860,4584,'114794','watch-mobile','font-size','14',0,''),(14861,4584,'114794','watch-mobile','font-weight','bold',0,''),(14862,4584,'114794','watch-mobile','padding-bottom','10',0,''),(14863,4585,'114795','watch-mobile','font-weight','400',0,''),(14864,4585,'114795','watch-mobile','line-height','120',0,''),(14865,4585,'114795','watch-mobile','line_height_measure','%',0,''),(14866,4585,'114795','watch-mobile','font-size','12',0,''),(14867,4586,'114796','watch-mobile','block_type','4',0,''),(14868,4586,'114796','watch-mobile','font-weight','normal',0,''),(14869,4586,'114796','watch-mobile','border-top-width','1',0,''),(14870,4586,'114796','watch-mobile','border-top-color','$border-color-1',0,''),(14871,4586,'114796','watch-mobile','border-left-width','1',0,''),(14872,4586,'114796','watch-mobile','border-left-color','$border-color-1',0,''),(14873,4586,'114796','watch-mobile','border-right-width','1',0,''),(14874,4586,'114796','watch-mobile','border-right-color','$border-color-1',0,''),(14875,4586,'114796','watch-mobile','border-bottom-width','1',0,''),(14876,4586,'114796','watch-mobile','border-bottom-color','$border-color-1',0,''),(14877,4587,'114797','watch-mobile','block_type','2',0,''),(14878,4587,'114797','watch-mobile','font-weight','normal',0,''),(14879,4587,'114797','watch-mobile','border-right-width','1',0,''),(14880,4587,'114797','watch-mobile','border-right-color','$border-color-1',0,''),(14881,4588,'114798','watch-mobile','block_type','1',0,''),(14882,4588,'114798','watch-mobile','font-weight','400',0,''),(14883,4588,'114798','watch-mobile','background-color','$background-6',0,''),(14884,4588,'114798','watch-mobile','padding-top','10',0,''),(14885,4588,'114798','watch-mobile','padding-left','10',0,''),(14886,4588,'114798','watch-mobile','padding-right','10',0,''),(14887,4588,'114798','watch-mobile','padding-bottom','30',0,''),(14888,4589,'114799','watch-mobile','text','<p>ADDRESS:</p>\n',1,''),(14889,4589,'114799','watch-mobile','font-size','14',0,''),(14890,4589,'114799','watch-mobile','font-weight','bold',0,''),(14891,4590,'114800','watch-mobile','font-size','12',0,''),(14892,4591,'114801','watch-mobile','block_type','1',0,''),(14893,4591,'114801','watch-mobile','font-weight','normal',0,''),(14894,4591,'114801','watch-mobile','padding-top','10',0,''),(14895,4591,'114801','watch-mobile','padding-left','10',0,''),(14896,4591,'114801','watch-mobile','padding-right','10',0,''),(14897,4591,'114801','watch-mobile','padding-bottom','10',0,''),(14898,4592,'114802','watch-mobile','text','<p>CUSTOMER:</p>',1,''),(14899,4592,'114802','watch-mobile','font-size','13',0,''),(14900,4592,'114802','watch-mobile','font-weight','bold',0,''),(14901,4593,'114803','watch-mobile','text','<p>PHONE NUMBER:</p>',1,''),(14902,4593,'114803','watch-mobile','font-size','14',0,''),(14903,4593,'114803','watch-mobile','font-weight','bold',0,''),(14904,4593,'114803','watch-mobile','padding-top','10',0,''),(14905,4594,'114804','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(14906,4594,'114804','watch-mobile','font-weight','bold',0,''),(14907,4594,'114804','watch-mobile','font-size','14',0,''),(14908,4594,'114804','watch-mobile','padding-top','10',0,''),(14909,4595,'114805','watch-mobile','font-weight','normal',0,''),(14910,4596,'114806','watch-mobile','font-weight','normal',0,''),(14911,4598,'114808','watch-mobile','text','<p>Order date:</p>\n',1,''),(14912,4598,'114808','watch-mobile','font-weight','bold',0,''),(14913,4598,'114808','watch-mobile','text-align','center',0,''),(14914,4598,'114808','watch-mobile','font-size','12',0,''),(14915,4599,'114809','watch-mobile','font-weight','normal',0,''),(14916,4599,'114809','watch-mobile','text-align','center',0,''),(14917,4599,'114809','watch-mobile','padding-bottom','10',0,''),(14918,4600,'114810','watch-mobile','font-size','14',0,''),(14919,4600,'114810','watch-mobile','font-weight','bold',0,''),(14920,4600,'114810','watch-mobile','text-align','center',0,''),(14921,4600,'114810','watch-mobile','padding-bottom','10',0,''),(14922,4600,'114810','watch-mobile','padding-top','10',0,''),(14923,4601,'114811','watch-mobile','block_type','2',0,''),(14924,4601,'114811','watch-mobile','font-weight','normal',0,''),(14925,4601,'114811','watch-mobile','padding-bottom','20',0,''),(14926,4602,'114812','watch-mobile','font-weight','400',0,''),(14927,4602,'114812','watch-mobile','padding-top','20',0,''),(14929,4603,'114813','watch-mobile','block_type','1',0,''),(14930,4604,'114814','watch-mobile','font-weight','normal',0,''),(14931,4604,'114814','watch-mobile','text-align','right',0,''),(14932,4604,'114814','watch-mobile','padding-bottom','10',0,''),(14933,4604,'114814','watch-mobile','address_spacer',',',0,''),(14934,4604,'114814','watch-mobile','font-size','12',0,''),(14935,4605,'114815','watch-mobile','block_type','11',0,''),(14936,4605,'114815','watch-mobile','font-weight','normal',0,''),(14937,4606,'114816','watch-mobile','text','<p>Email:</p>',1,''),(14938,4606,'114816','watch-mobile','font-weight','normal',0,''),(14939,4606,'114816','watch-mobile','text-align','right',0,''),(14940,4607,'114817','watch-mobile','font-weight','normal',0,''),(14941,4607,'114817','watch-mobile','text-align','right',0,''),(14942,4608,'114818','watch-mobile','block_type','11',0,''),(14943,4608,'114818','watch-mobile','font-weight','normal',0,''),(14944,4609,'114819','watch-mobile','text','<p>Web:</p>',1,''),(14945,4609,'114819','watch-mobile','font-weight','normal',0,''),(14946,4609,'114819','watch-mobile','text-align','right',0,''),(14947,4610,'114820','watch-mobile','font-weight','normal',0,''),(14948,4610,'114820','watch-mobile','text-align','right',0,''),(14949,4611,'114821','watch-mobile','block_type','11',0,''),(14950,4611,'114821','watch-mobile','font-weight','normal',0,''),(14951,4612,'114822','watch-mobile','text','<p>Phone:</p>',1,''),(14952,4612,'114822','watch-mobile','font-weight','normal',0,''),(14953,4612,'114822','watch-mobile','text-align','right',0,''),(14954,4613,'114823','watch-mobile','font-weight','normal',0,''),(14955,4613,'114823','watch-mobile','text-align','right',0,''),(14956,4614,'114824','watch-mobile','block_type','3',0,''),(14957,4614,'114824','watch-mobile','font-weight','normal',0,''),(14958,4614,'114824','watch-mobile','padding-top','20',0,''),(14959,4615,'114825','watch-mobile','font-size','12',0,''),(14960,4616,'114826','watch-mobile','text','<p>If undelivered please return to:</p>',1,''),(14961,4616,'114826','watch-mobile','font-size','12',0,''),(14962,4616,'114826','watch-mobile','font-weight','bold',0,''),(14963,4617,'114827','watch-mobile','text','<p>Thank you for your order</p>',1,''),(14964,4617,'114827','watch-mobile','color','$color-font-10',0,''),(14965,4617,'114827','watch-mobile','font-size','13',0,''),(14966,4617,'114827','watch-mobile','font-weight','bold',0,''),(14967,4617,'114827','watch-mobile','padding-top','5',0,''),(14968,4617,'114827','watch-mobile','text-align','center',0,''),(14969,4618,'114828','watch-mobile','font-weight','400',0,''),(14970,4618,'114828','watch-mobile','text-align','center',0,''),(14971,4618,'114828','watch-mobile','padding-top','0',0,''),(14973,4618,'114828','watch-mobile','padding-left','20',0,''),(14974,4618,'114828','watch-mobile','padding-right','20',0,''),(14975,4619,'114829','watch-mobile','block_type','6',0,''),(14976,4619,'114829','watch-mobile','font-weight','normal',0,''),(14977,4619,'114829','watch-mobile','font-size','16',0,''),(14978,4620,'114830','watch-mobile','text','<p>Phone:</p>',1,''),(14979,4620,'114830','watch-mobile','font-weight','normal',0,''),(14980,4620,'114830','watch-mobile','text-align','right',0,''),(14981,4620,'114830','watch-mobile','font-size','12',0,''),(14982,4621,'114831','watch-mobile','font-weight','normal',0,''),(14983,4621,'114831','watch-mobile','text-align','right',0,''),(14984,4621,'114831','watch-mobile','font-size','12',0,''),(14985,4622,'114832','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(14986,4622,'114832','watch-mobile','font-size','12',0,''),(14987,4622,'114832','watch-mobile','font-weight','bold',0,''),(14988,4622,'114832','watch-mobile','text-align','right',0,''),(14989,4623,'114833','watch-mobile','block_type','6',0,''),(14990,4623,'114833','watch-mobile','font-weight','normal',0,''),(14991,4623,'114833','watch-mobile','font-size','16',0,''),(14992,4624,'114834','watch-mobile','text','<p>Email:</p>',1,''),(14993,4624,'114834','watch-mobile','font-weight','normal',0,''),(14994,4624,'114834','watch-mobile','text-align','right',0,''),(14995,4624,'114834','watch-mobile','font-size','12',0,''),(14996,4625,'114835','watch-mobile','font-weight','normal',0,''),(14997,4625,'114835','watch-mobile','text-align','right',0,''),(14998,4625,'114835','watch-mobile','font-size','12',0,''),(14999,4626,'114836','watch-mobile','font-weight','400',0,''),(15000,4626,'114836','watch-mobile','padding-top','20',0,''),(15001,4626,'114836','watch-mobile','padding-bottom','0',0,''),(15002,4626,'114836','watch-mobile','font-size','12',0,''),(15003,4627,'114837','watch-mobile','block_type','1',0,''),(15004,4628,'114838','watch-mobile','block_type','6',0,''),(15005,4628,'114838','watch-mobile','schema','6-3',0,'299'),(15006,4629,'114839','watch-mobile','aria_name','account-menu',0,''),(15007,4630,'114840','watch-mobile','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(15008,4631,'114841','watch-mobile','link','Quotation Info',0,''),(15009,4631,'114841','watch-mobile','margin-bottom','20',0,''),(15010,4632,'114842','watch-mobile','block_type','1',0,''),(15011,4633,'114843','watch-mobile','block_type','6',0,''),(15012,4633,'114843','watch-mobile','schema','6-3',0,''),(15013,4633,'114843','watch-mobile','schema','6-3',0,'299'),(15014,4634,'114844','watch-mobile','aria_name','account-menu',0,''),(15015,4637,'114847','watch-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(15016,4638,'114848','watch-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(15017,4640,'114850','watch-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(15018,4641,'114851','watch-mobile','block_type','2',0,''),(15019,4641,'114851','watch-mobile','padding-top','20',0,''),(15020,4641,'114851','watch-mobile','margin-bottom','20',0,''),(15021,4642,'114852','watch-mobile','like_button','1',0,''),(15022,4642,'114852','watch-mobile','text','IMAGE_BUTTON_BACK',0,''),(15023,4642,'114852','watch-mobile','link','Quotations',0,''),(15024,4643,'114853','watch-mobile','block_type','3',0,''),(15025,4643,'114853','watch-mobile','schema','3-4',0,'299'),(15026,4644,'114854','watch-mobile','block_type','1',0,''),(15027,4644,'114854','watch-mobile','padding-right','20',0,''),(15028,4644,'114854','watch-mobile','padding-bottom','20',0,''),(15029,4645,'114855','watch-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(15030,4646,'114856','watch-mobile','orders_data','telephone',0,''),(15031,4647,'114857','watch-mobile','block_type','1',0,''),(15032,4647,'114857','watch-mobile','padding-right','20',0,''),(15033,4647,'114857','watch-mobile','padding-bottom','20',0,''),(15034,4648,'114858','watch-mobile','orders_data','name',0,''),(15035,4649,'114859','watch-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(15036,4650,'114860','watch-mobile','block_type','1',0,''),(15037,4650,'114860','watch-mobile','padding-right','20',0,''),(15038,4651,'114861','watch-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(15039,4652,'114862','watch-mobile','orders_data','shipping_method',0,''),(15040,4653,'114863','watch-mobile','block_type','1',0,''),(15041,4653,'114863','watch-mobile','padding-right','20',0,''),(15042,4653,'114863','watch-mobile','padding-bottom','20',0,''),(15043,4654,'114864','watch-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(15044,4655,'114865','watch-mobile','orders_data','delivery_address',0,''),(15045,4656,'114866','watch-mobile','block_type','1',0,''),(15046,4656,'114866','watch-mobile','padding-bottom','20',0,''),(15047,4657,'114867','watch-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(15048,4658,'114868','watch-mobile','orders_data','billing_address',0,''),(15049,4659,'114869','watch-mobile','block_type','1',0,''),(15050,4660,'114870','watch-mobile','orders_data','payment_method',0,''),(15051,4661,'114871','watch-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(15052,4664,'75868','watch-mobile','text','<h1>Quotations</h1>',1,''),(15053,4665,'114872','watch-mobile','block_type','1',0,''),(15054,4666,'114873','watch-mobile','block_type','6',0,''),(15055,4666,'114873','watch-mobile','schema','6-3',0,''),(15056,4666,'114873','watch-mobile','schema','6-3',0,'299'),(15057,4667,'114874','watch-mobile','aria_name','account-menu',0,''),(15058,4668,'114875','watch-mobile','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(15059,4669,'114876','watch-mobile','margin-bottom','20',0,''),(15060,4670,'114877','watch-mobile','block_type','1',0,''),(15061,4671,'114878','watch-mobile','pagination','bottom',0,''),(15062,4673,'114880','watch-mobile','width','800',0,''),(15063,4674,'114881','watch-mobile','block_type','1',0,''),(15064,4674,'114881','watch-mobile','border-top-width','1',0,''),(15065,4674,'114881','watch-mobile','border-left-width','1',0,''),(15066,4674,'114881','watch-mobile','border-right-width','1',0,''),(15067,4674,'114881','watch-mobile','border-bottom-width','1',0,''),(15068,4674,'114881','watch-mobile','border-top-color','$border-color-6',0,''),(15069,4674,'114881','watch-mobile','border-left-color','$border-color-6',0,''),(15070,4674,'114881','watch-mobile','border-right-color','$border-color-6',0,''),(15071,4674,'114881','watch-mobile','border-bottom-color','$border-color-6',0,''),(15072,4675,'114882','watch-mobile','block_type','11',0,''),(15073,4676,'114883','watch-mobile','block_type','1',0,''),(15074,4676,'114883','watch-mobile','padding-top','10',0,''),(15075,4676,'114883','watch-mobile','padding-right','10',0,''),(15076,4676,'114883','watch-mobile','padding-bottom','10',0,''),(15077,4676,'114883','watch-mobile','border-right-width','1',0,''),(15078,4676,'114883','watch-mobile','border-right-color','$border-color-6',0,''),(15079,4677,'114884','watch-mobile','block_type','1',0,''),(15080,4677,'114884','watch-mobile','padding-left','10',0,''),(15081,4677,'114884','watch-mobile','padding-right','10',0,''),(15082,4677,'114884','watch-mobile','padding-bottom','10',0,''),(15083,4678,'114885','watch-mobile','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(15084,4678,'114885','watch-mobile','font-size','11',0,''),(15085,4678,'114885','watch-mobile','font-style','italic',0,''),(15086,4679,'114886','watch-mobile','block_type','9',0,''),(15087,4680,'114887','watch-mobile','text','2.',0,''),(15088,4680,'114887','watch-mobile','font-size','12',0,''),(15089,4680,'114887','watch-mobile','text-align','right',0,''),(15090,4680,'114887','watch-mobile','padding-right','5',0,''),(15091,4681,'114888','watch-mobile','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(15092,4681,'114888','watch-mobile','font-size','12',0,''),(15093,4681,'114888','watch-mobile','padding-bottom','10',0,''),(15094,4682,'114889','watch-mobile','block_type','1',0,''),(15095,4683,'114890','watch-mobile','text','Shipping Instructions:',0,''),(15096,4683,'114890','watch-mobile','font-weight','bold',0,''),(15097,4683,'114890','watch-mobile','font-size','14',0,''),(15098,4683,'114890','watch-mobile','padding-bottom','5',0,''),(15099,4683,'114890','watch-mobile','padding-left','10',0,''),(15100,4684,'114891','watch-mobile','block_type','9',0,''),(15101,4685,'114892','watch-mobile','text','1.',0,''),(15102,4685,'114892','watch-mobile','font-size','12',0,''),(15103,4685,'114892','watch-mobile','text-align','right',0,''),(15104,4685,'114892','watch-mobile','padding-right','5',0,''),(15105,4686,'114893','watch-mobile','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(15106,4686,'114893','watch-mobile','font-size','12',0,''),(15107,4686,'114893','watch-mobile','padding-bottom','10',0,''),(15108,4687,'114894','watch-mobile','block_type','9',0,''),(15109,4688,'114895','watch-mobile','text','3.',0,''),(15110,4688,'114895','watch-mobile','font-size','12',0,''),(15111,4688,'114895','watch-mobile','text-align','right',0,''),(15112,4688,'114895','watch-mobile','padding-right','5',0,''),(15113,4689,'114896','watch-mobile','text','Ship only the items that are authorized.',0,''),(15114,4689,'114896','watch-mobile','font-size','12',0,''),(15115,4689,'114896','watch-mobile','padding-bottom','10',0,''),(15116,4690,'114897','watch-mobile','block_type','9',0,''),(15117,4691,'114898','watch-mobile','text','4.',0,''),(15118,4691,'114898','watch-mobile','font-size','12',0,''),(15119,4691,'114898','watch-mobile','text-align','right',0,''),(15120,4691,'114898','watch-mobile','padding-right','5',0,''),(15121,4692,'114899','watch-mobile','text','Ship returned items to:',0,''),(15122,4692,'114899','watch-mobile','font-size','12',0,''),(15123,4692,'114899','watch-mobile','padding-bottom','5',0,''),(15124,4693,'114900','watch-mobile','font-size','11',0,''),(15125,4693,'114900','watch-mobile','font-style','italic',0,''),(15126,4693,'114900','watch-mobile','padding-bottom','5',0,''),(15127,4694,'114901','watch-mobile','block_type','3',0,''),(15128,4694,'114901','watch-mobile','padding-right','10',0,''),(15129,4695,'114902','watch-mobile','text','Customer Signature:',0,''),(15130,4695,'114902','watch-mobile','font-weight','bold',0,''),(15131,4695,'114902','watch-mobile','font-size','11',0,''),(15132,4695,'114902','watch-mobile','padding-top','5',0,''),(15133,4695,'114902','watch-mobile','padding-left','10',0,''),(15134,4696,'114903','watch-mobile','text','&nbsp;',0,''),(15135,4696,'114903','watch-mobile','border-bottom-width','1',0,''),(15136,4696,'114903','watch-mobile','border-bottom-color','$border-color-6',0,''),(15137,4697,'114904','watch-mobile','block_type','5',0,''),(15138,4698,'114905','watch-mobile','text','Date:',0,''),(15139,4698,'114905','watch-mobile','padding-top','5',0,''),(15140,4698,'114905','watch-mobile','font-size','11',0,''),(15141,4698,'114905','watch-mobile','font-weight','bold',0,''),(15142,4698,'114905','watch-mobile','padding-left','5',0,''),(15143,4699,'114906','watch-mobile','text','&nbsp;',0,''),(15144,4699,'114906','watch-mobile','border-bottom-width','1',0,''),(15145,4699,'114906','watch-mobile','border-bottom-color','$border-color-6',0,''),(15146,4700,'114907','watch-mobile','block_type','3',0,''),(15147,4700,'114907','watch-mobile','padding-top','10',0,''),(15148,4700,'114907','watch-mobile','padding-bottom','10',0,''),(15149,4700,'114907','watch-mobile','padding-right','10',0,''),(15150,4701,'114908','watch-mobile','font-size','11',0,''),(15151,4701,'114908','watch-mobile','font-weight','bold',0,''),(15152,4701,'114908','watch-mobile','text','Return Approval:',0,''),(15153,4701,'114908','watch-mobile','padding-top','5',0,''),(15154,4701,'114908','watch-mobile','padding-left','10',0,''),(15155,4702,'114909','watch-mobile','border-bottom-width','1',0,''),(15156,4702,'114909','watch-mobile','border-bottom-color','$border-color-6',0,''),(15157,4702,'114909','watch-mobile','text','&nbsp;',0,''),(15158,4703,'114910','watch-mobile','block_type','5',0,''),(15159,4704,'114911','watch-mobile','text','Date:',0,''),(15160,4704,'114911','watch-mobile','padding-top','5',0,''),(15161,4704,'114911','watch-mobile','font-size','11',0,''),(15162,4704,'114911','watch-mobile','font-weight','bold',0,''),(15163,4704,'114911','watch-mobile','padding-left','5',0,''),(15164,4705,'114912','watch-mobile','text','&nbsp;',0,''),(15165,4705,'114912','watch-mobile','border-bottom-width','1',0,''),(15166,4705,'114912','watch-mobile','border-bottom-color','$border-color-6',0,''),(15167,4706,'114913','watch-mobile','block_type','1',0,''),(15168,4706,'114913','watch-mobile','padding-left','10',0,''),(15169,4706,'114913','watch-mobile','padding-right','10',0,''),(15170,4706,'114913','watch-mobile','padding-bottom','10',0,''),(15171,4707,'114914','watch-mobile','text','Use this space for additional Comments:',0,''),(15172,4707,'114914','watch-mobile','font-size','11',0,''),(15173,4707,'114914','watch-mobile','font-style','italic',0,''),(15174,4708,'114915','watch-mobile','text','&nbsp;',0,''),(15175,4708,'114915','watch-mobile','border-bottom-width','1',0,''),(15176,4708,'114915','watch-mobile','border-bottom-color','$border-color-6',0,''),(15177,4709,'114916','watch-mobile','text','&nbsp;',0,''),(15178,4709,'114916','watch-mobile','border-bottom-width','1',0,''),(15179,4709,'114916','watch-mobile','border-bottom-color','$border-color-6',0,''),(15180,4709,'114916','watch-mobile','padding-top','5',0,''),(15181,4710,'114917','watch-mobile','text','&nbsp;',0,''),(15182,4710,'114917','watch-mobile','border-bottom-width','1',0,''),(15183,4710,'114917','watch-mobile','border-bottom-color','$border-color-6',0,''),(15184,4710,'114917','watch-mobile','padding-top','5',0,''),(15185,4711,'114918','watch-mobile','text','&nbsp;',0,''),(15186,4711,'114918','watch-mobile','border-bottom-width','1',0,''),(15187,4711,'114918','watch-mobile','border-bottom-color','$border-color-6',0,''),(15188,4711,'114918','watch-mobile','padding-top','5',0,''),(15189,4712,'114919','watch-mobile','block_type','1',0,''),(15190,4712,'114919','watch-mobile','padding-top','10',0,''),(15191,4712,'114919','watch-mobile','padding-left','40',0,''),(15192,4712,'114919','watch-mobile','padding-right','40',0,''),(15193,4712,'114919','watch-mobile','padding-bottom','10',0,''),(15194,4713,'114920','watch-mobile','block_type','1',0,''),(15195,4713,'114920','watch-mobile','padding-top','10',0,''),(15196,4713,'114920','watch-mobile','padding-left','10',0,''),(15197,4713,'114920','watch-mobile','padding-right','10',0,''),(15198,4713,'114920','watch-mobile','padding-bottom','10',0,''),(15199,4713,'114920','watch-mobile','border-top-width','1',0,''),(15200,4713,'114920','watch-mobile','border-left-width','1',0,''),(15201,4713,'114920','watch-mobile','border-right-width','1',0,''),(15202,4713,'114920','watch-mobile','border-bottom-width','1',0,''),(15203,4713,'114920','watch-mobile','border-top-color','$border-color-6',0,''),(15204,4713,'114920','watch-mobile','border-left-color','$border-color-6',0,''),(15205,4713,'114920','watch-mobile','border-right-color','$border-color-6',0,''),(15206,4713,'114920','watch-mobile','border-bottom-color','$border-color-6',0,''),(15207,4714,'114921','watch-mobile','block_type','3',0,''),(15208,4715,'114922','watch-mobile','data','rrDelivery_name',0,''),(15209,4715,'114922','watch-mobile','font-size','9',0,''),(15210,4716,'114923','watch-mobile','block_type','2',0,''),(15211,4717,'114924','watch-mobile','text','RMA#:',0,''),(15212,4717,'114924','watch-mobile','font-size','10',0,''),(15213,4718,'114925','watch-mobile','data','rrNumber',0,''),(15214,4718,'114925','watch-mobile','font-size','9',0,''),(15215,4719,'114926','watch-mobile','block_type','5',0,''),(15216,4720,'114927','watch-mobile','font-size','9',0,''),(15217,4721,'114928','watch-mobile','block_type','1',0,''),(15218,4723,'114930','watch-mobile','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(15219,4723,'114930','watch-mobile','font-size','12',0,''),(15220,4723,'114930','watch-mobile','font-style','italic',0,''),(15221,4723,'114930','watch-mobile','padding-bottom','20',0,''),(15222,4724,'114931','watch-mobile','block_type','11',0,''),(15223,4724,'114931','watch-mobile','border-top-width','1',0,''),(15224,4724,'114931','watch-mobile','border-left-width','1',0,''),(15225,4724,'114931','watch-mobile','border-right-width','1',0,''),(15226,4724,'114931','watch-mobile','border-bottom-width','1',0,''),(15227,4724,'114931','watch-mobile','border-top-color','$border-color-6',0,''),(15228,4724,'114931','watch-mobile','border-left-color','$border-color-6',0,''),(15229,4724,'114931','watch-mobile','border-right-color','$border-color-6',0,''),(15230,4724,'114931','watch-mobile','border-bottom-color','$border-color-6',0,''),(15231,4725,'114932','watch-mobile','block_type','1',0,''),(15232,4725,'114932','watch-mobile','border-right-width','1',0,''),(15233,4725,'114932','watch-mobile','border-right-color','$border-color-6',0,''),(15234,4725,'114932','watch-mobile','padding-top','10',0,''),(15235,4725,'114932','watch-mobile','padding-right','10',0,''),(15236,4725,'114932','watch-mobile','padding-bottom','10',0,''),(15237,4726,'114933','watch-mobile','block_type','1',0,''),(15238,4726,'114933','watch-mobile','padding-left','15',0,''),(15239,4727,'114934','watch-mobile','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(15240,4727,'114934','watch-mobile','font-size','11',0,''),(15241,4727,'114934','watch-mobile','font-style','italic',0,''),(15242,4727,'114934','watch-mobile','padding-bottom','5',0,''),(15243,4728,'114935','watch-mobile','text','Replacement Policy:',0,''),(15244,4728,'114935','watch-mobile','font-size','14',0,''),(15245,4728,'114935','watch-mobile','padding-bottom','5',0,''),(15246,4728,'114935','watch-mobile','font-weight','bold',0,''),(15247,4729,'114936','watch-mobile','block_type','9',0,''),(15248,4730,'114937','watch-mobile','text','2.',0,''),(15249,4730,'114937','watch-mobile','font-size','12',0,''),(15250,4730,'114937','watch-mobile','text-align','right',0,''),(15251,4730,'114937','watch-mobile','margin-right','5',0,''),(15252,4731,'114938','watch-mobile','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(15253,4731,'114938','watch-mobile','font-size','12',0,''),(15254,4731,'114938','watch-mobile','padding-bottom','5',0,''),(15255,4732,'114939','watch-mobile','block_type','9',0,''),(15256,4733,'114940','watch-mobile','text','1.',0,''),(15257,4733,'114940','watch-mobile','font-size','12',0,''),(15258,4733,'114940','watch-mobile','text-align','right',0,''),(15259,4733,'114940','watch-mobile','padding-right','5',0,''),(15260,4734,'114941','watch-mobile','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(15261,4734,'114941','watch-mobile','font-size','12',0,''),(15262,4734,'114941','watch-mobile','padding-bottom','5',0,''),(15263,4735,'114942','watch-mobile','block_type','9',0,''),(15264,4736,'114943','watch-mobile','text','3.',0,''),(15265,4736,'114943','watch-mobile','font-size','12',0,''),(15266,4736,'114943','watch-mobile','text-align','right',0,''),(15267,4736,'114943','watch-mobile','margin-right','5',0,''),(15268,4737,'114944','watch-mobile','text','Return the authorized item(s) per shipping instructions.',0,''),(15269,4737,'114944','watch-mobile','font-size','12',0,''),(15270,4737,'114944','watch-mobile','padding-bottom','5',0,''),(15271,4738,'114945','watch-mobile','block_type','9',0,''),(15272,4739,'114946','watch-mobile','text','4.',0,''),(15273,4739,'114946','watch-mobile','font-size','12',0,''),(15274,4739,'114946','watch-mobile','text-align','right',0,''),(15275,4739,'114946','watch-mobile','margin-right','5',0,''),(15276,4740,'114947','watch-mobile','text','Our Replacement Department will process your request.',0,''),(15277,4740,'114947','watch-mobile','font-size','12',0,''),(15278,4740,'114947','watch-mobile','padding-bottom','5',0,''),(15279,4741,'114948','watch-mobile','block_type','2',0,''),(15280,4741,'114948','watch-mobile','padding-left','10',0,''),(15281,4741,'114948','watch-mobile','padding-top','20',0,''),(15282,4741,'114948','watch-mobile','padding-right','10',0,''),(15283,4742,'114949','watch-mobile','block_type','5',0,''),(15284,4743,'114950','watch-mobile','text','RMA No:',0,''),(15285,4743,'114950','watch-mobile','font-size','12',0,''),(15286,4743,'114950','watch-mobile','font-weight','bold',0,''),(15287,4744,'114951','watch-mobile','data','rrNumber',0,''),(15288,4744,'114951','watch-mobile','font-size','12',0,''),(15289,4744,'114951','watch-mobile','font-weight','bold',0,''),(15290,4745,'114952','watch-mobile','block_type','2',0,''),(15291,4746,'114953','watch-mobile','text','Date Issued:',0,''),(15292,4746,'114953','watch-mobile','font-size','12',0,''),(15293,4746,'114953','watch-mobile','font-weight','bold',0,''),(15294,4747,'114954','watch-mobile','data','rrDateCreate',0,''),(15295,4747,'114954','watch-mobile','font-size','12',0,''),(15296,4747,'114954','watch-mobile','font-weight','bold',0,''),(15297,4748,'114955','watch-mobile','block_type','1',0,''),(15298,4748,'114955','watch-mobile','padding-top','10',0,''),(15299,4748,'114955','watch-mobile','padding-left','10',0,''),(15300,4748,'114955','watch-mobile','padding-right','10',0,''),(15301,4748,'114955','watch-mobile','padding-bottom','10',0,''),(15302,4749,'114956','watch-mobile','block_type','2',0,''),(15303,4750,'114957','watch-mobile','block_type','11',0,''),(15304,4751,'114958','watch-mobile','text','Company:',0,''),(15305,4751,'114958','watch-mobile','font-size','12',0,''),(15306,4752,'114959','watch-mobile','data','rrDelivery_company',0,''),(15307,4752,'114959','watch-mobile','font-size','12',0,''),(15308,4753,'114960','watch-mobile','block_type','2',0,''),(15309,4754,'114961','watch-mobile','text','Contact Name:',0,''),(15310,4754,'114961','watch-mobile','font-size','12',0,''),(15311,4755,'114962','watch-mobile','data','rrDelivery_name',0,''),(15312,4755,'114962','watch-mobile','font-size','12',0,''),(15313,4756,'114963','watch-mobile','block_type','9',0,''),(15314,4756,'114963','watch-mobile','padding-top','5',0,''),(15315,4757,'114964','watch-mobile','text','Address:',0,''),(15316,4757,'114964','watch-mobile','font-size','12',0,''),(15317,4758,'114965','watch-mobile','data','rrDelivery_street_address',0,''),(15318,4758,'114965','watch-mobile','font-size','12',0,''),(15319,4759,'114966','watch-mobile','block_type','2',0,''),(15320,4759,'114966','watch-mobile','padding-top','5',0,''),(15321,4760,'114967','watch-mobile','block_type','11',0,''),(15322,4761,'114968','watch-mobile','text','City:',0,''),(15323,4761,'114968','watch-mobile','font-size','12',0,''),(15324,4762,'114969','watch-mobile','data','rrDelivery_city',0,''),(15325,4762,'114969','watch-mobile','font-size','12',0,''),(15326,4763,'114970','watch-mobile','block_type','11',0,''),(15327,4764,'114971','watch-mobile','text','State:',0,''),(15328,4764,'114971','watch-mobile','font-size','12',0,''),(15329,4765,'114972','watch-mobile','data','rrDelivery_state',0,''),(15330,4765,'114972','watch-mobile','font-size','12',0,''),(15331,4766,'114973','watch-mobile','block_type','2',0,''),(15332,4766,'114973','watch-mobile','padding-top','5',0,''),(15333,4767,'114974','watch-mobile','block_type','11',0,''),(15334,4768,'114975','watch-mobile','text','Country:',0,''),(15335,4768,'114975','watch-mobile','font-size','12',0,''),(15336,4769,'114976','watch-mobile','data','rrDelivery_country',0,''),(15337,4769,'114976','watch-mobile','font-size','12',0,''),(15338,4770,'114977','watch-mobile','block_type','11',0,''),(15339,4771,'114978','watch-mobile','text','Postcode:',0,''),(15340,4771,'114978','watch-mobile','font-size','12',0,''),(15341,4772,'114979','watch-mobile','data','rrDelivery_postcode',0,''),(15342,4772,'114979','watch-mobile','font-size','12',0,''),(15343,4773,'114980','watch-mobile','block_type','2',0,''),(15344,4773,'114980','watch-mobile','padding-top','5',0,''),(15345,4774,'114981','watch-mobile','block_type','11',0,''),(15346,4775,'114982','watch-mobile','text','Email:',0,''),(15347,4775,'114982','watch-mobile','font-size','12',0,''),(15348,4776,'114983','watch-mobile','data','rrDelivery_email_address',0,''),(15349,4776,'114983','watch-mobile','font-size','12',0,''),(15350,4777,'114984','watch-mobile','block_type','11',0,''),(15351,4778,'114985','watch-mobile','text','Phone:',0,''),(15352,4778,'114985','watch-mobile','font-size','12',0,''),(15353,4779,'114986','watch-mobile','data','rrDelivery_telephone',0,''),(15354,4779,'114986','watch-mobile','font-size','12',0,''),(15355,4780,'114987','watch-mobile','block_type','1',0,''),(15356,4780,'114987','watch-mobile','border-bottom-width','1',0,''),(15357,4780,'114987','watch-mobile','border-bottom-color','$border-color-6',0,''),(15358,4781,'114988','watch-mobile','text-align','center',0,''),(15359,4781,'114988','watch-mobile','logo','themes/watch-mobile/img/Furntech-1.jpg',1,''),(15360,4781,'114988','watch-mobile','padding-top','10',0,''),(15361,4781,'114988','watch-mobile','padding-bottom','10',0,''),(15362,4782,'114989','watch-mobile','text','Return Material Authorization (RMA) Form',0,''),(15363,4782,'114989','watch-mobile','text-align','center',0,''),(15364,4782,'114989','watch-mobile','font-size','12',0,''),(15365,4782,'114989','watch-mobile','font-weight','bold',0,''),(15366,4782,'114989','watch-mobile','font-family','$font-1',0,''),(15367,4783,'114990','watch-mobile','block_type','1',0,''),(15368,4783,'114990','watch-mobile','style_class','item-holder',0,''),(15369,4783,'114990','watch-mobile','padding-top','25',0,''),(15370,4783,'114990','watch-mobile','padding-bottom','25',0,''),(15371,4783,'114990','watch-mobile','text-align','left',0,''),(15372,4783,'114990','watch-mobile','border-top-width','1',0,''),(15373,4783,'114990','watch-mobile','border-top-color','$border-color-1',0,''),(15374,4784,'114991','watch-mobile','block_type','7',0,''),(15375,4784,'114991','watch-mobile','schema','7-2',0,''),(15376,4785,'114992','watch-mobile','block_type','5',0,''),(15377,4785,'114992','watch-mobile','schema','5-2',0,''),(15378,4786,'114993','watch-mobile','block_type','1',0,''),(15379,4787,'114994','watch-mobile','text-align','right',0,''),(15380,4787,'114994','watch-mobile','margin-top','4',0,''),(15381,4787,'114994','watch-mobile','margin-bottom','7',0,''),(15382,4787,'114994','watch-mobile','float','left',0,''),(15383,4788,'114995','watch-mobile','padding-top','6',0,''),(15384,4788,'114995','watch-mobile','padding-left','5',0,''),(15385,4788,'114995','watch-mobile','float','left',0,''),(15386,4788,'114995','watch-mobile','clear','none',0,''),(15387,4789,'114996','watch-mobile','clear','none',0,''),(15388,4789,'114996','watch-mobile','padding-right','20',0,''),(15389,4790,'114997','watch-mobile','padding-right','20',0,''),(15390,4790,'114997','watch-mobile','max-width','300',0,''),(15391,4790,'114997','watch-mobile','margin_left_measure','auto',0,''),(15392,4790,'114997','watch-mobile','margin_right_measure','auto',0,''),(15393,4791,'114998','watch-mobile','clear','none',0,''),(15394,4792,'114999','watch-mobile','padding-right','20',0,''),(15395,4793,'115000','watch-mobile','description_characters','200',0,''),(15396,4793,'115000','watch-mobile','clear','none',0,''),(15397,4793,'115000','watch-mobile','padding-right','20',0,''),(15398,4794,'115001','watch-mobile','margin-bottom','20',0,''),(15399,4795,'115002','watch-mobile','block_type','1',0,''),(15400,4795,'115002','watch-mobile','padding-left','40',0,''),(15401,4795,'115002','watch-mobile','style_class','right-aria',0,''),(15403,4796,'115003','watch-mobile','text-align','right',0,''),(15404,4796,'115003','watch-mobile','margin-bottom','10',0,''),(15405,4797,'115004','watch-mobile','margin-bottom','10',0,''),(15406,4797,'115004','watch-mobile','text-align','right',0,''),(15407,4799,'115006','watch-mobile','margin-bottom','15',0,''),(15408,4799,'115006','watch-mobile','text-align','right',0,''),(15409,4800,'115007','watch-mobile','margin-bottom','10',0,''),(15410,4801,'115008','watch-mobile','text-align','right',0,''),(15411,4801,'115008','watch-mobile','margin-bottom','15',0,''),(15412,4802,'75869','watch-mobile','block_type','1',0,''),(15413,4803,'75870','watch-mobile','padding-bottom','20',0,''),(15414,4804,'75871','watch-mobile','text-align','right',0,''),(15415,4804,'75871','watch-mobile','margin-bottom','40',0,''),(15416,4805,'75872','watch-mobile','text','<h1>Samples</h1>',1,''),(15417,4806,'115009','watch-mobile','block_type','1',0,''),(15418,4807,'115010','watch-mobile','block_type','6',0,''),(15419,4807,'115010','watch-mobile','schema','6-3',0,''),(15420,4807,'115010','watch-mobile','schema','6-3',0,'299'),(15421,4808,'115011','watch-mobile','aria_name','account-menu',0,''),(15422,4809,'115012','watch-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(15423,4810,'115013','watch-mobile','show_pagenation','1',0,''),(15424,4810,'115013','watch-mobile','link','Sample Info',0,''),(15425,4810,'115013','watch-mobile','margin-bottom','20',0,''),(15426,4811,'115014','watch-mobile','block_type','1',0,''),(15427,4812,'115015','watch-mobile','block_type','6',0,''),(15428,4813,'115016','watch-mobile','aria_name','account-menu',0,''),(15429,4814,'115017','watch-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(15430,4815,'115018','watch-mobile','block_type','3',0,''),(15431,4816,'115019','watch-mobile','block_type','1',0,''),(15432,4816,'115019','watch-mobile','padding-right','20',0,''),(15433,4816,'115019','watch-mobile','padding-bottom','20',0,''),(15434,4817,'115020','watch-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(15435,4818,'115021','watch-mobile','orders_data','telephone',0,''),(15436,4819,'115022','watch-mobile','block_type','1',0,''),(15437,4819,'115022','watch-mobile','padding-right','20',0,''),(15438,4819,'115022','watch-mobile','padding-bottom','20',0,''),(15439,4820,'115023','watch-mobile','orders_data','name',0,''),(15440,4821,'115024','watch-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(15441,4822,'115025','watch-mobile','block_type','1',0,''),(15442,4822,'115025','watch-mobile','padding-right','20',0,''),(15443,4822,'115025','watch-mobile','padding-bottom','20',0,''),(15444,4823,'115026','watch-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(15445,4824,'115027','watch-mobile','orders_data','delivery_address',0,''),(15446,4825,'115028','watch-mobile','block_type','1',0,''),(15447,4825,'115028','watch-mobile','padding-right','20',0,''),(15448,4826,'115029','watch-mobile','orders_data','shipping_method',0,''),(15449,4827,'115030','watch-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(15450,4828,'115031','watch-mobile','block_type','1',0,''),(15451,4828,'115031','watch-mobile','padding-bottom','20',0,''),(15452,4829,'115032','watch-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(15453,4830,'115033','watch-mobile','orders_data','billing_address',0,''),(15454,4831,'115034','watch-mobile','block_type','1',0,''),(15455,4832,'115035','watch-mobile','orders_data','payment_method',0,''),(15456,4833,'115036','watch-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(15457,4834,'115037','watch-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(15458,4837,'115040','watch-mobile','block_type','2',0,''),(15459,4837,'115040','watch-mobile','padding-top','20',0,''),(15460,4837,'115040','watch-mobile','margin-bottom','20',0,''),(15461,4838,'115041','watch-mobile','like_button','1',0,''),(15462,4838,'115041','watch-mobile','text','IMAGE_BUTTON_BACK',0,''),(15463,4838,'115041','watch-mobile','link','Samples',0,''),(15464,4840,'115043','watch-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(15465,4841,'115715','watch-mobile','block_type','1',0,''),(15466,4842,'115716','watch-mobile','block_type','6',0,''),(15467,4842,'115716','watch-mobile','schema','6-3',0,''),(15468,4842,'115716','watch-mobile','schema','6-3',0,'299'),(15469,4843,'115717','watch-mobile','aria_name','account-menu',0,''),(15470,4844,'115718','watch-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(15471,4845,'115719','watch-mobile','link','Order History Info',0,''),(15472,4845,'115719','watch-mobile','text','TEXT_VIEW',0,''),(15473,4845,'115719','watch-mobile','max_orders','3',0,''),(15474,4845,'115719','watch-mobile','link_pay','Order pay',0,''),(15475,4845,'115719','watch-mobile','margin-bottom','30',0,''),(15476,4845,'115719','watch-mobile','text_pay','ORDER_PAY',0,''),(15477,4846,'115720','watch-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(15478,4847,'115721','watch-mobile','block_type','15',0,''),(15479,4847,'115721','watch-mobile','margin-bottom','30',0,''),(15480,4847,'115721','watch-mobile','padding-top','20',0,''),(15481,4847,'115721','watch-mobile','padding-left','20',0,''),(15482,4847,'115721','watch-mobile','padding-right','20',0,''),(15483,4847,'115721','watch-mobile','padding-bottom','20',0,''),(15484,4847,'115721','watch-mobile','border-top-width','1',0,''),(15485,4847,'115721','watch-mobile','border-top-color','$border-color-1',0,''),(15486,4847,'115721','watch-mobile','border-left-width','1',0,''),(15487,4847,'115721','watch-mobile','border-right-width','1',0,''),(15488,4847,'115721','watch-mobile','border-bottom-width','1',0,''),(15489,4847,'115721','watch-mobile','border-left-color','$border-color-1',0,''),(15490,4847,'115721','watch-mobile','border-right-color','$border-color-1',0,''),(15491,4847,'115721','watch-mobile','border-bottom-color','$border-color-1',0,''),(15492,4847,'115721','watch-mobile','schema','15-2',0,'299'),(15493,4848,'115722','watch-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(15494,4848,'115722','watch-mobile','font-family','trueloaded',0,'3'),(15495,4848,'115722','watch-mobile','content','\\e920',0,'3'),(15496,4848,'115722','watch-mobile','color','$attention-color',0,'3'),(15497,4848,'115722','watch-mobile','font-size','30',0,'3'),(15498,4848,'115722','watch-mobile','text-align','center',0,'3'),(15499,4848,'115722','watch-mobile','margin-bottom','10',0,'3'),(15500,4848,'115722','watch-mobile','text-align','center',0,''),(15501,4848,'115722','watch-mobile','font-size','16',0,''),(15502,4848,'115722','watch-mobile','text-transform','uppercase',0,''),(15503,4848,'115722','watch-mobile','line-height','1',0,'3'),(15505,4849,'115723','watch-mobile','font-family','$font-1',0,''),(15506,4849,'115723','watch-mobile','color','$attention-color',0,''),(15507,4849,'115723','watch-mobile','font-size','14',0,''),(15508,4849,'115723','watch-mobile','text-align','center',0,''),(15509,4850,'115724','watch-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(15510,4850,'115724','watch-mobile','font-family','trueloaded',0,'3'),(15511,4850,'115724','watch-mobile','content','\\e928',0,'3'),(15512,4850,'115724','watch-mobile','color','$attention-color',0,'3'),(15513,4850,'115724','watch-mobile','font-size','30',0,'3'),(15514,4850,'115724','watch-mobile','text-align','center',0,'3'),(15515,4850,'115724','watch-mobile','text-align','center',0,''),(15516,4850,'115724','watch-mobile','font-size','16',0,''),(15517,4850,'115724','watch-mobile','text-transform','uppercase',0,''),(15518,4850,'115724','watch-mobile','line-height','1',0,'3'),(15520,4851,'115725','watch-mobile','link','download_orders',0,''),(15521,4851,'115725','watch-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(15522,4851,'115725','watch-mobile','hide_link','orders',0,''),(15523,4851,'115725','watch-mobile','text-align','center',0,''),(15524,4851,'115725','watch-mobile','popup','2',0,''),(15525,4851,'115725','watch-mobile','font-size','14',0,''),(15526,4852,'115726','watch-mobile','font-family','$font-1',0,''),(15527,4852,'115726','watch-mobile','color','$attention-color',0,''),(15528,4852,'115726','watch-mobile','font-size','14',0,''),(15529,4852,'115726','watch-mobile','text-align','center',0,''),(15530,4853,'115727','watch-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(15531,4853,'115727','watch-mobile','font-family','trueloaded',0,'3'),(15532,4853,'115727','watch-mobile','content','\\e922',0,'3'),(15533,4853,'115727','watch-mobile','color','$attention-color',0,'3'),(15534,4853,'115727','watch-mobile','font-size','30',0,'3'),(15535,4853,'115727','watch-mobile','line-height','1',0,'3'),(15536,4853,'115727','watch-mobile','font-size','16',0,''),(15537,4853,'115727','watch-mobile','text-align','center',0,''),(15538,4853,'115727','watch-mobile','text-transform','uppercase',0,''),(15540,4854,'115728','watch-mobile','font-family','$font-1',0,''),(15541,4854,'115728','watch-mobile','color','$attention-color',0,''),(15542,4854,'115728','watch-mobile','line-height','1',0,''),(15543,4854,'115728','watch-mobile','text-align','center',0,''),(15544,4854,'115728','watch-mobile','font-size','14',0,''),(15545,4855,'115729','watch-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(15546,4855,'115729','watch-mobile','content','\\e994',0,'3'),(15547,4855,'115729','watch-mobile','font-family','trueloaded',0,'3'),(15548,4855,'115729','watch-mobile','color','$attention-color',0,'3'),(15549,4855,'115729','watch-mobile','font-size','30',0,'3'),(15550,4855,'115729','watch-mobile','line-height','1',0,'3'),(15551,4855,'115729','watch-mobile','font-size','16',0,''),(15552,4855,'115729','watch-mobile','text-align','center',0,''),(15553,4855,'115729','watch-mobile','text-transform','uppercase',0,''),(15555,4856,'115730','watch-mobile','link','Gift Certificate',0,''),(15556,4856,'115730','watch-mobile','text','GIFT_CERTIFICATE',0,''),(15557,4856,'115730','watch-mobile','popup','1',0,''),(15558,4856,'115730','watch-mobile','text-align','center',0,''),(15559,4856,'115730','watch-mobile','font-size','14',0,''),(15560,4857,'115731','watch-mobile','font-family','$font-1',0,''),(15561,4857,'115731','watch-mobile','color','$attention-color',0,''),(15562,4857,'115731','watch-mobile','font-size','14',0,''),(15563,4857,'115731','watch-mobile','text-align','center',0,''),(15564,4858,'115732','watch-mobile','text','TEXT_VIEW_HISTORY',0,''),(15565,4858,'115732','watch-mobile','popup','1',0,''),(15566,4858,'115732','watch-mobile','text-align','center',0,''),(15567,4858,'115732','watch-mobile','link','Points Earnt History',0,''),(15568,4858,'115732','watch-mobile','font-size','14',0,''),(15569,4859,'115733','watch-mobile','font-family','$font-1',0,''),(15570,4859,'115733','watch-mobile','color','$attention-color',0,''),(15571,4859,'115733','watch-mobile','font-size','14',0,''),(15572,4859,'115733','watch-mobile','text-align','center',0,''),(15573,4860,'115734','watch-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(15574,4860,'115734','watch-mobile','content','\\e990',0,'3'),(15575,4860,'115734','watch-mobile','font-family','trueloaded',0,'3'),(15576,4860,'115734','watch-mobile','font-size','30',0,'3'),(15577,4860,'115734','watch-mobile','text-align','center',0,'3'),(15578,4860,'115734','watch-mobile','line-height','1',0,'3'),(15579,4860,'115734','watch-mobile','color','$attention-color',0,'3'),(15580,4860,'115734','watch-mobile','font-size','16',0,''),(15581,4860,'115734','watch-mobile','text-align','center',0,''),(15582,4860,'115734','watch-mobile','text-transform','uppercase',0,''),(15584,4861,'115735','watch-mobile','block_type','1',0,''),(15585,4862,'115736','watch-mobile','hide_parents','2',0,''),(15586,4863,'115737','watch-mobile','text','<div class=\"heading-3\">##TEXT_GIFT_CARDS##</div>',0,''),(15587,4865,'115044','watch-mobile','block_type','1',0,''),(15588,4866,'115045','watch-mobile','block_type','6',0,''),(15589,4867,'115046','watch-mobile','class','menu-simple',0,''),(15590,4869,'115048','watch-mobile','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(15591,4871,'115050','watch-mobile','text','<div class=\"heading-4\">Categories</div>',0,''),(15592,4872,'115051','watch-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(15593,4873,'115052','watch-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(15594,4875,'115054','watch-mobile','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(15595,4876,'115055','watch-mobile','block_type','1',0,''),(15596,4877,'115056','watch-mobile','style_class','middle-form',0,''),(15597,4877,'115056','watch-mobile','margin-bottom','30',0,''),(15598,4878,'115057','watch-mobile','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(15599,4879,'115058','watch-mobile','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(15600,4879,'115058','watch-mobile','style_class','middle-form',0,''),(15601,4880,'115059','watch-mobile','style_class','middle-form',0,''),(15602,4881,'115060','watch-mobile','block_type','1',0,''),(15603,4882,'115061','watch-mobile','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(15604,4882,'115061','watch-mobile','padding-top','100',0,''),(15605,4882,'115061','watch-mobile','margin-bottom','100',0,''),(15606,4882,'115061','watch-mobile','text-align','center',0,''),(15607,4882,'115061','watch-mobile','font-size','20',0,''),(15608,4883,'115062','watch-mobile','block_type','1',0,''),(15609,4884,'115063','watch-mobile','block_type','6',0,''),(15610,4884,'115063','watch-mobile','schema','6-3',0,''),(15611,4884,'115063','watch-mobile','schema','6-3',0,'299'),(15612,4885,'115064','watch-mobile','aria_name','account-menu',0,''),(15613,4886,'115065','watch-mobile','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(15614,4887,'115066','watch-mobile','text','##SUBSCRIPTION_TEXT##',0,''),(15615,4889,'75873','watch-mobile','block_type','1',0,''),(15616,4890,'75874','watch-mobile','block_type','1',0,''),(15617,4890,'75874','watch-mobile','font-weight','normal',0,''),(15618,4891,'75875','watch-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',1,''),(15619,4891,'75875','watch-mobile','font-weight','400',0,''),(15620,4892,'75876','watch-mobile','block_type','3',0,''),(15621,4892,'75876','watch-mobile','font-weight','400',0,''),(15622,4892,'75876','watch-mobile','schema','3-4',0,'291'),(15623,4893,'75877','watch-mobile','text','&nbsp;',0,''),(15624,4893,'75877','watch-mobile','font-weight','normal',0,''),(15625,4894,'75878','watch-mobile','font-weight','normal',0,''),(15626,4894,'75878','watch-mobile','box_align','2',0,''),(15627,4894,'75878','watch-mobile','padding-top','40',0,''),(15628,4895,'75879','watch-mobile','font-weight','400',0,''),(15629,4895,'75879','watch-mobile','text-align','right',0,''),(15630,4895,'75879','watch-mobile','padding-top','40',0,''),(15631,4895,'75879','watch-mobile','padding-bottom','100',0,''),(15632,4895,'75879','watch-mobile','text-align','center',0,'291'),(15633,4895,'75879','watch-mobile','float','none',0,'291'),(15634,4896,'115068','watch-mobile','block_type','1',0,''),(15635,4897,'115069','watch-mobile','block_type','1',0,''),(15636,4897,'115069','watch-mobile','font-weight','normal',0,''),(15637,4898,'115070','watch-mobile','block_type','1',0,''),(15638,4898,'115070','watch-mobile','text-align','center',0,''),(15639,4898,'115070','watch-mobile','padding-top','30',0,''),(15640,4898,'115070','watch-mobile','margin-bottom','200',0,''),(15641,4899,'115071','watch-mobile','display','inline-block',0,''),(15642,4900,'115072','watch-mobile','display','inline-block',0,''),(15643,4900,'115072','watch-mobile','clear','none',0,''),(15644,4900,'115072','watch-mobile','margin-left','20',0,''),(15645,4901,'115073','watch-mobile','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(15647,4905,'115074','watch-mobile','width','680',0,''),(15648,4905,'115074','watch-mobile','font-weight','normal',0,''),(15649,4905,'115074','watch-mobile','font-size','12',0,''),(15650,4905,'115074','watch-mobile','padding-top','20',0,''),(15651,4905,'115074','watch-mobile','padding-bottom','20',0,''),(15652,4905,'115074','watch-mobile','color','$color-font-7',0,''),(15653,4906,'115075','watch-mobile','block_type','2',0,''),(15654,4906,'115075','watch-mobile','font-weight','normal',0,''),(15655,4906,'115075','watch-mobile','padding-bottom','20',0,''),(15656,4907,'115076','watch-mobile','block_type','1',0,''),(15657,4908,'115077','watch-mobile','font-weight','normal',0,''),(15658,4908,'115077','watch-mobile','text-align','right',0,''),(15659,4908,'115077','watch-mobile','padding-bottom','10',0,''),(15660,4908,'115077','watch-mobile','address_spacer',',',0,''),(15661,4908,'115077','watch-mobile','font-size','12',0,''),(15662,4909,'115078','watch-mobile','block_type','11',0,''),(15663,4909,'115078','watch-mobile','font-weight','normal',0,''),(15664,4910,'115079','watch-mobile','text','<p>Phone:</p>',1,''),(15665,4910,'115079','watch-mobile','font-weight','normal',0,''),(15666,4910,'115079','watch-mobile','text-align','right',0,''),(15667,4911,'115080','watch-mobile','font-weight','normal',0,''),(15668,4911,'115080','watch-mobile','text-align','right',0,''),(15669,4912,'115081','watch-mobile','block_type','11',0,''),(15670,4912,'115081','watch-mobile','font-weight','normal',0,''),(15671,4913,'115082','watch-mobile','text','<p>Web:</p>',1,''),(15672,4913,'115082','watch-mobile','font-weight','normal',0,''),(15673,4913,'115082','watch-mobile','text-align','right',0,''),(15674,4914,'115083','watch-mobile','font-weight','normal',0,''),(15675,4914,'115083','watch-mobile','text-align','right',0,''),(15676,4915,'115084','watch-mobile','block_type','11',0,''),(15677,4915,'115084','watch-mobile','font-weight','normal',0,''),(15678,4916,'115085','watch-mobile','text','<p>Email:</p>',1,''),(15679,4916,'115085','watch-mobile','font-weight','normal',0,''),(15680,4916,'115085','watch-mobile','text-align','right',0,''),(15681,4917,'115086','watch-mobile','font-weight','normal',0,''),(15682,4917,'115086','watch-mobile','text-align','right',0,''),(15683,4918,'115087','watch-mobile','block_type','4',0,''),(15684,4918,'115087','watch-mobile','font-weight','normal',0,''),(15685,4918,'115087','watch-mobile','border-top-width','1',0,''),(15686,4918,'115087','watch-mobile','border-top-color','$border-color-1',0,''),(15687,4918,'115087','watch-mobile','border-left-width','1',0,''),(15688,4918,'115087','watch-mobile','border-left-color','$border-color-1',0,''),(15689,4918,'115087','watch-mobile','border-right-width','1',0,''),(15690,4918,'115087','watch-mobile','border-right-color','$border-color-1',0,''),(15691,4918,'115087','watch-mobile','border-bottom-width','1',0,''),(15692,4918,'115087','watch-mobile','border-bottom-color','$border-color-1',0,''),(15693,4919,'115088','watch-mobile','block_type','2',0,''),(15694,4919,'115088','watch-mobile','font-weight','normal',0,''),(15695,4919,'115088','watch-mobile','border-right-width','1',0,''),(15696,4919,'115088','watch-mobile','border-right-color','$border-color-1',0,''),(15697,4920,'115089','watch-mobile','block_type','1',0,''),(15698,4920,'115089','watch-mobile','font-weight','400',0,''),(15699,4920,'115089','watch-mobile','background-color','$background-6',0,''),(15700,4920,'115089','watch-mobile','padding-top','10',0,''),(15701,4920,'115089','watch-mobile','padding-left','10',0,''),(15702,4920,'115089','watch-mobile','padding-right','10',0,''),(15703,4920,'115089','watch-mobile','padding-bottom','30',0,''),(15704,4921,'115090','watch-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(15705,4921,'115090','watch-mobile','font-size','14',0,''),(15706,4921,'115090','watch-mobile','font-weight','bold',0,''),(15707,4922,'115091','watch-mobile','font-size','12',0,''),(15708,4923,'115092','watch-mobile','block_type','1',0,''),(15709,4923,'115092','watch-mobile','font-weight','normal',0,''),(15710,4923,'115092','watch-mobile','padding-top','10',0,''),(15711,4923,'115092','watch-mobile','padding-left','10',0,''),(15712,4923,'115092','watch-mobile','padding-right','10',0,''),(15713,4923,'115092','watch-mobile','padding-bottom','10',0,''),(15714,4924,'115093','watch-mobile','text','<p>PHONE NUMBER:</p>',1,''),(15715,4924,'115093','watch-mobile','font-size','14',0,''),(15716,4924,'115093','watch-mobile','font-weight','bold',0,''),(15717,4924,'115093','watch-mobile','padding-top','10',0,''),(15718,4925,'115094','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(15719,4925,'115094','watch-mobile','font-weight','bold',0,''),(15720,4925,'115094','watch-mobile','font-size','14',0,''),(15721,4925,'115094','watch-mobile','padding-top','10',0,''),(15722,4926,'115095','watch-mobile','text','<p>CUSTOMER:</p>',1,''),(15723,4926,'115095','watch-mobile','font-size','13',0,''),(15724,4926,'115095','watch-mobile','font-weight','bold',0,''),(15725,4927,'115096','watch-mobile','font-weight','normal',0,''),(15726,4928,'115097','watch-mobile','font-weight','normal',0,''),(15727,4930,'115099','watch-mobile','block_type','2',0,''),(15728,4930,'115099','watch-mobile','font-weight','normal',0,''),(15729,4930,'115099','watch-mobile','border-top-width','1',0,''),(15730,4930,'115099','watch-mobile','border-top-color','$border-color-1',0,''),(15731,4930,'115099','watch-mobile','border-right-width','1',0,''),(15732,4930,'115099','watch-mobile','border-right-color','$border-color-1',0,''),(15733,4931,'115100','watch-mobile','block_type','1',0,''),(15734,4931,'115100','watch-mobile','font-weight','normal',0,''),(15735,4931,'115100','watch-mobile','padding-top','10',0,''),(15736,4931,'115100','watch-mobile','padding-left','10',0,''),(15737,4931,'115100','watch-mobile','padding-right','10',0,''),(15738,4931,'115100','watch-mobile','padding-bottom','10',0,''),(15739,4931,'115100','watch-mobile','border-right-width','1',0,''),(15740,4931,'115100','watch-mobile','border-right-color','$border-color-1',0,''),(15741,4932,'115101','watch-mobile','text','<p>Shipping via</p>',1,''),(15742,4932,'115101','watch-mobile','font-weight','bold',0,''),(15743,4932,'115101','watch-mobile','font-size','14',0,''),(15744,4934,'115103','watch-mobile','block_type','1',0,''),(15745,4934,'115103','watch-mobile','font-weight','normal',0,''),(15746,4934,'115103','watch-mobile','padding-top','10',0,''),(15747,4934,'115103','watch-mobile','padding-left','10',0,''),(15748,4934,'115103','watch-mobile','padding-right','10',0,''),(15749,4934,'115103','watch-mobile','padding-bottom','10',0,''),(15750,4936,'115105','watch-mobile','text','<p>Shipping service</p>',1,''),(15751,4936,'115105','watch-mobile','font-weight','bold',0,''),(15752,4936,'115105','watch-mobile','font-size','14',0,''),(15753,4937,'115106','watch-mobile','text','<p>Payment date:</p>',1,''),(15754,4937,'115106','watch-mobile','font-weight','bold',0,''),(15755,4937,'115106','watch-mobile','text-align','center',0,''),(15756,4937,'115106','watch-mobile','font-size','12',0,''),(15757,4938,'115107','watch-mobile','font-weight','normal',0,''),(15758,4938,'115107','watch-mobile','text-align','center',0,''),(15759,4939,'115108','watch-mobile','text','<p>Payment Method:</p>',1,''),(15760,4939,'115108','watch-mobile','font-weight','bold',0,''),(15761,4939,'115108','watch-mobile','text-align','center',0,''),(15762,4940,'115109','watch-mobile','font-size','14',0,''),(15763,4940,'115109','watch-mobile','font-weight','bold',0,''),(15764,4940,'115109','watch-mobile','text-align','center',0,''),(15765,4940,'115109','watch-mobile','padding-bottom','10',0,''),(15766,4940,'115109','watch-mobile','padding-top','10',0,''),(15767,4941,'115110','watch-mobile','font-weight','normal',0,''),(15768,4941,'115110','watch-mobile','text-align','center',0,''),(15769,4941,'115110','watch-mobile','padding-bottom','10',0,''),(15770,4942,'115111','watch-mobile','font-weight','normal',0,''),(15771,4942,'115111','watch-mobile','text-align','center',0,''),(15772,4942,'115111','watch-mobile','padding-bottom','20',0,''),(15773,4943,'115112','watch-mobile','block_type','3',0,''),(15774,4943,'115112','watch-mobile','font-weight','normal',0,''),(15775,4943,'115112','watch-mobile','padding-top','20',0,''),(15776,4944,'115113','watch-mobile','text','<p>If undelivered please return to:</p>',1,''),(15777,4944,'115113','watch-mobile','font-size','12',0,''),(15778,4944,'115113','watch-mobile','font-weight','bold',0,''),(15779,4945,'115114','watch-mobile','font-size','12',0,''),(15780,4946,'115115','watch-mobile','font-weight','400',0,''),(15781,4946,'115115','watch-mobile','text-align','center',0,''),(15782,4946,'115115','watch-mobile','padding-top','0',0,''),(15784,4946,'115115','watch-mobile','padding-left','20',0,''),(15785,4946,'115115','watch-mobile','padding-right','20',0,''),(15786,4947,'115116','watch-mobile','text','<p>Thank you for your order</p>',1,''),(15787,4947,'115116','watch-mobile','color','$color-font-10',0,''),(15788,4947,'115116','watch-mobile','font-size','13',0,''),(15789,4947,'115116','watch-mobile','font-weight','bold',0,''),(15790,4947,'115116','watch-mobile','padding-top','5',0,''),(15791,4947,'115116','watch-mobile','text-align','center',0,''),(15792,4948,'115117','watch-mobile','block_type','6',0,''),(15793,4948,'115117','watch-mobile','font-weight','normal',0,''),(15794,4948,'115117','watch-mobile','font-size','16',0,''),(15795,4949,'115118','watch-mobile','text','<p>Phone:</p>',1,''),(15796,4949,'115118','watch-mobile','font-weight','normal',0,''),(15797,4949,'115118','watch-mobile','text-align','right',0,''),(15798,4949,'115118','watch-mobile','font-size','12',0,''),(15799,4950,'115119','watch-mobile','font-weight','normal',0,''),(15800,4950,'115119','watch-mobile','text-align','right',0,''),(15801,4950,'115119','watch-mobile','font-size','12',0,''),(15802,4951,'115120','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(15803,4951,'115120','watch-mobile','font-size','12',0,''),(15804,4951,'115120','watch-mobile','font-weight','bold',0,''),(15805,4951,'115120','watch-mobile','text-align','right',0,''),(15806,4952,'115121','watch-mobile','block_type','6',0,''),(15807,4952,'115121','watch-mobile','font-weight','normal',0,''),(15808,4952,'115121','watch-mobile','font-size','16',0,''),(15809,4953,'115122','watch-mobile','text','<p>Email:</p>',1,''),(15810,4953,'115122','watch-mobile','font-weight','normal',0,''),(15811,4953,'115122','watch-mobile','text-align','right',0,''),(15812,4953,'115122','watch-mobile','font-size','12',0,''),(15813,4954,'115123','watch-mobile','font-weight','normal',0,''),(15814,4954,'115123','watch-mobile','text-align','right',0,''),(15815,4954,'115123','watch-mobile','font-size','12',0,''),(15816,4955,'115124','watch-mobile','font-weight','400',0,''),(15817,4955,'115124','watch-mobile','padding-top','20',0,''),(15818,4955,'115124','watch-mobile','padding-bottom','0',0,''),(15819,4955,'115124','watch-mobile','font-size','12',0,''),(15820,4956,'115125','watch-mobile','block_type','5',0,''),(15821,4956,'115125','watch-mobile','font-weight','normal',0,''),(15822,4956,'115125','watch-mobile','border-bottom-width','1',0,''),(15823,4956,'115125','watch-mobile','border-bottom-color','$border-color-1',0,''),(15824,4956,'115125','watch-mobile','border-top-width','1',0,''),(15825,4956,'115125','watch-mobile','border-top-color','$border-color-1',0,''),(15826,4956,'115125','watch-mobile','border-left-color','$border-color-1',0,''),(15827,4956,'115125','watch-mobile','border-left-width','1',0,''),(15828,4957,'115126','watch-mobile','block_type','1',0,''),(15829,4957,'115126','watch-mobile','font-weight','normal',0,''),(15830,4957,'115126','watch-mobile','padding-top','10',0,''),(15831,4957,'115126','watch-mobile','padding-left','10',0,''),(15832,4957,'115126','watch-mobile','padding-right','10',0,''),(15833,4958,'115127','watch-mobile','font-weight','400',0,''),(15834,4958,'115127','watch-mobile','line-height','120',0,''),(15835,4958,'115127','watch-mobile','line_height_measure','%',0,''),(15836,4958,'115127','watch-mobile','font-size','12',0,''),(15837,4959,'115128','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(15838,4959,'115128','watch-mobile','font-size','14',0,''),(15839,4959,'115128','watch-mobile','font-weight','bold',0,''),(15840,4959,'115128','watch-mobile','padding-bottom','10',0,''),(15841,4960,'115129','watch-mobile','block_type','1',0,''),(15842,4960,'115129','watch-mobile','background-color','$background-6',0,''),(15843,4960,'115129','watch-mobile','padding-top','20',0,''),(15844,4960,'115129','watch-mobile','padding-left','10',0,''),(15845,4960,'115129','watch-mobile','padding-right','10',0,''),(15846,4960,'115129','watch-mobile','padding-bottom','20',0,''),(15847,4960,'115129','watch-mobile','font-size','14',0,''),(15848,4961,'115130','watch-mobile','font-weight','normal',0,''),(15849,4961,'115130','watch-mobile','text-align','right',0,''),(15850,4961,'115130','watch-mobile','font-size','14',0,''),(15851,4961,'115130','watch-mobile','box_align','3',0,''),(15852,4962,'115131','watch-mobile','block_type','1',0,''),(15853,4962,'115131','watch-mobile','padding-top','35',0,''),(15854,4962,'115131','watch-mobile','padding-bottom','35',0,''),(15855,4963,'115132','watch-mobile','block_type','7',0,''),(15856,4963,'115132','watch-mobile','schema','7-2',0,''),(15857,4964,'115133','watch-mobile','block_type','1',0,''),(15858,4964,'115133','watch-mobile','style_class','blog_list_content',0,''),(15859,4966,'115135','watch-mobile','text-align','center',0,''),(15860,4967,'115136','watch-mobile','aria_name','blogsidebar',0,''),(15861,4967,'115136','watch-mobile','style_class','blogsidebar',0,''),(15862,4968,'115137','watch-mobile','block_type','1',0,''),(15863,4968,'115137','watch-mobile','padding-top','35',0,''),(15864,4968,'115137','watch-mobile','padding-bottom','35',0,''),(15865,4969,'115138','watch-mobile','block_type','7',0,''),(15866,4969,'115138','watch-mobile','schema','7-1',0,''),(15868,4970,'115139','watch-mobile','block_type','1',0,''),(15869,4970,'115139','watch-mobile','style_class','blog_list_content',0,''),(15870,4971,'115140','watch-mobile','items_on_page','12',0,''),(15871,4971,'115140','watch-mobile','items_cut_off','200',0,''),(15872,4972,'115141','watch-mobile','text-align','center',0,''),(15873,4972,'115141','watch-mobile','hide_parents','1',0,''),(15874,4973,'115142','watch-mobile','aria_name','blogsidebar',0,''),(15875,4973,'115142','watch-mobile','padding-left','35',0,''),(15876,4973,'115142','watch-mobile','style_class','blogsidebar',0,''),(15878,4974,'115143','watch-mobile','banners_group','blog',0,''),(15879,4974,'115143','watch-mobile','margin-bottom','40',0,''),(15880,4975,'115144','watch-mobile','block_type','1',0,''),(15881,4975,'115144','watch-mobile','padding-top','35',0,''),(15882,4975,'115144','watch-mobile','padding-bottom','35',0,''),(15883,4976,'115145','watch-mobile','block_type','7',0,''),(15884,4976,'115145','watch-mobile','schema','7-2',0,''),(15885,4978,'115147','watch-mobile','block_type','1',0,''),(15886,4979,'115148','watch-mobile','text','<div class=\"heading-3\">##TEXT_BLOG_RELATED_PRODUCTS##</div>',0,''),(15887,4980,'115149','watch-mobile','count_products','8',0,''),(15888,4980,'115149','watch-mobile','col_in_row','4',0,''),(15889,4980,'115149','watch-mobile','view_as','carousel',0,''),(15890,4980,'115149','watch-mobile','show_stock','1',0,''),(15891,4980,'115149','watch-mobile','show_description','1',0,''),(15892,4980,'115149','watch-mobile','show_properties','1',0,''),(15893,4980,'115149','watch-mobile','show_rating','1',0,''),(15894,4980,'115149','watch-mobile','show_rating_counts','1',0,''),(15895,4980,'115149','watch-mobile','show_qty_input','1',0,''),(15896,4980,'115149','watch-mobile','show_wishlist_button','1',0,''),(15897,4980,'115149','watch-mobile','show_compare','1',0,''),(15901,4980,'115149','watch-mobile','listing_type','productListing',0,''),(15902,4980,'115149','watch-mobile','hide_parents','2',0,''),(15903,4981,'115150','watch-mobile','block_type','1',0,''),(15904,4981,'115150','watch-mobile','style_class','blog-white-bg',0,''),(15905,4981,'115150','watch-mobile','padding-bottom','20',0,''),(15906,4985,'115154','watch-mobile','block_type','1',0,''),(15907,4985,'115154','watch-mobile','padding-top','20',0,''),(15908,4985,'115154','watch-mobile','margin-top','20',0,''),(15909,4985,'115154','watch-mobile','border-top-width','1',0,''),(15910,4985,'115154','watch-mobile','border-top-color','$border-color-1',0,''),(15911,4985,'115154','watch-mobile','clear','both',0,''),(15912,4986,'115155','watch-mobile','box_align','4',0,''),(15913,4986,'115155','watch-mobile','text-align','center',0,''),(15914,4987,'115156','watch-mobile','text-align','center',0,''),(15915,4988,'115157','watch-mobile','aria_name','blogsidebar',0,''),(15916,4988,'115157','watch-mobile','style_class','blogsidebar',0,''),(15917,4989,'115158','watch-mobile','block_type','1',0,''),(15918,4989,'115158','watch-mobile','padding-top','35',0,''),(15919,4989,'115158','watch-mobile','padding-bottom','35',0,''),(15920,4990,'115159','watch-mobile','block_type','7',0,''),(15921,4990,'115159','watch-mobile','schema','7-2',0,''),(15922,4991,'115160','watch-mobile','block_type','1',0,''),(15923,4991,'115160','watch-mobile','style_class','blog_list_content',0,''),(15924,4993,'115162','watch-mobile','text-align','center',0,''),(15925,4993,'115162','watch-mobile','hide_parents','1',0,''),(15926,4994,'115163','watch-mobile','aria_name','blogsidebar',0,''),(15927,4994,'115163','watch-mobile','style_class','blogsidebar',0,''),(15928,4995,'115164','watch-mobile','block_type','1',0,''),(15929,4997,'115166','watch-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(15930,4998,'115167','watch-mobile','block_type','1',0,''),(15931,4999,'115168','watch-mobile','block_type','2',0,''),(15932,4999,'115168','watch-mobile','margin-bottom','20',0,''),(15933,5000,'115169','watch-mobile','block_type','1',0,''),(15934,5000,'115169','watch-mobile','padding-right','20',0,''),(15935,5001,'115170','watch-mobile','field','50',0,''),(15936,5002,'115171','watch-mobile','field','49',0,''),(15937,5003,'115172','watch-mobile','block_type','2',0,''),(15938,5005,'115174','watch-mobile','float','right',0,''),(15939,5005,'115174','watch-mobile','clear','none',0,''),(15940,5006,'115175','watch-mobile','float','right',0,''),(15941,5006,'115175','watch-mobile','margin-left','20',0,''),(15942,5007,'115176','watch-mobile','block_type','2',0,''),(15943,5007,'115176','watch-mobile','margin-bottom','20',0,''),(15944,5008,'115177','watch-mobile','block_type','1',0,''),(15945,5008,'115177','watch-mobile','padding-right','20',0,''),(15946,5009,'115178','watch-mobile','field','66',0,''),(15947,5010,'115179','watch-mobile','block_type','1',0,''),(15948,5010,'115179','watch-mobile','padding-left','20',0,''),(15949,5011,'115180','watch-mobile','field','67',0,''),(15950,5012,'115181','watch-mobile','text','<div class=\"heading-2\">##TRADE_REFERENCES##</div>',0,''),(15951,5012,'115181','watch-mobile','text-align','center',0,''),(15952,5013,'115182','watch-mobile','text','<div class=\"heading-2\">##BANK_ACCOUNT_DETAILS##</div>',0,''),(15953,5013,'115182','watch-mobile','text-align','center',0,''),(15954,5014,'115183','watch-mobile','text','<div class=\"heading-2\">##TEXT_DECLARATION##</div>',0,''),(15955,5014,'115183','watch-mobile','text-align','center',0,''),(15956,5015,'115184','watch-mobile','block_type','2',0,''),(15957,5015,'115184','watch-mobile','margin-bottom','20',0,''),(15958,5016,'115185','watch-mobile','block_type','1',0,''),(15959,5016,'115185','watch-mobile','padding-right','20',0,''),(15960,5017,'115186','watch-mobile','field','62',0,''),(15961,5018,'115187','watch-mobile','field','60',0,''),(15962,5019,'115188','watch-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 1</div>',0,''),(15963,5020,'115189','watch-mobile','field','61',0,''),(15964,5021,'115190','watch-mobile','block_type','1',0,''),(15965,5021,'115190','watch-mobile','padding-left','20',0,''),(15966,5022,'115191','watch-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 2</div>',0,''),(15967,5023,'115192','watch-mobile','field','64',0,''),(15968,5024,'115193','watch-mobile','field','63',0,''),(15969,5025,'115194','watch-mobile','field','65',0,''),(15970,5026,'115195','watch-mobile','block_type','2',0,''),(15971,5026,'115195','watch-mobile','margin-bottom','20',0,''),(15972,5027,'115196','watch-mobile','block_type','1',0,''),(15973,5027,'115196','watch-mobile','padding-right','20',0,''),(15974,5028,'115197','watch-mobile','field','52',0,''),(15975,5029,'115198','watch-mobile','field','51',0,''),(15976,5030,'115199','watch-mobile','block_type','2',0,''),(15977,5031,'115200','watch-mobile','block_type','1',0,''),(15978,5031,'115200','watch-mobile','padding-right','20',0,''),(15979,5032,'115201','watch-mobile','group','15',0,''),(15980,5033,'115202','watch-mobile','text','<div class=\"heading-3\">##CATEGORY_COMPANY##</div>',0,''),(15981,5035,'115204','watch-mobile','block_type','2',0,''),(15982,5036,'115205','watch-mobile','field','68',0,''),(15983,5036,'115205','watch-mobile','padding-right','10',0,''),(15984,5037,'115206','watch-mobile','block_type','2',0,''),(15985,5037,'115206','watch-mobile','border-bottom-width','1',0,''),(15986,5037,'115206','watch-mobile','border-bottom-color','$border-color-1',0,''),(15987,5037,'115206','watch-mobile','padding-bottom','10',0,''),(15988,5037,'115206','watch-mobile','margin-bottom','20',0,''),(15989,5038,'115207','watch-mobile','block_type','1',0,''),(15990,5038,'115207','watch-mobile','padding-right','10',0,''),(15991,5039,'115208','watch-mobile','field','69',0,''),(15992,5040,'115209','watch-mobile','field','75',0,''),(15993,5041,'115210','watch-mobile','field','71',0,''),(15994,5042,'115211','watch-mobile','field','73',0,''),(15995,5043,'115212','watch-mobile','block_type','1',0,''),(15996,5043,'115212','watch-mobile','padding-left','10',0,''),(15997,5044,'115213','watch-mobile','field','76',0,''),(15998,5045,'115214','watch-mobile','field','74',0,''),(15999,5046,'115215','watch-mobile','field','72',0,''),(16000,5047,'115216','watch-mobile','field','70',0,''),(16001,5048,'115217','watch-mobile','block_type','1',0,''),(16002,5048,'115217','watch-mobile','padding-left','20',0,''),(16003,5049,'115218','watch-mobile','group','16',0,''),(16004,5050,'115219','watch-mobile','block_type','2',0,''),(16005,5051,'115220','watch-mobile','block_type','1',0,''),(16006,5051,'115220','watch-mobile','padding-right','10',0,''),(16007,5052,'115221','watch-mobile','field','77',0,''),(16008,5053,'115222','watch-mobile','field','79',0,''),(16009,5054,'115223','watch-mobile','block_type','1',0,''),(16010,5054,'115223','watch-mobile','padding-left','10',0,''),(16011,5055,'115224','watch-mobile','field','78',0,''),(16012,5056,'115225','watch-mobile','block_type','2',0,''),(16013,5057,'115226','watch-mobile','block_type','1',0,''),(16014,5057,'115226','watch-mobile','padding-right','10',0,''),(16015,5058,'115227','watch-mobile','field','82',0,''),(16016,5059,'115228','watch-mobile','field','80',0,''),(16017,5060,'115229','watch-mobile','field','84',0,''),(16018,5061,'115230','watch-mobile','block_type','1',0,''),(16019,5061,'115230','watch-mobile','padding-left','10',0,''),(16020,5062,'115231','watch-mobile','field','83',0,''),(16021,5063,'115232','watch-mobile','field','81',0,''),(16022,5064,'115233','watch-mobile','field','85',0,''),(16023,5065,'115234','watch-mobile','text','<div class=\"heading-3\">##OWNERS_DETAILS##</div>',0,''),(16024,5066,'115235','watch-mobile','block_type','2',0,''),(16025,5066,'115235','watch-mobile','margin-bottom','20',0,''),(16026,5067,'115236','watch-mobile','block_type','1',0,''),(16027,5067,'115236','watch-mobile','padding-right','20',0,''),(16028,5068,'115237','watch-mobile','field','53',0,''),(16029,5069,'115238','watch-mobile','field','54',0,''),(16030,5070,'115239','watch-mobile','block_type','1',0,''),(16031,5070,'115239','watch-mobile','padding-left','20',0,''),(16032,5071,'115240','watch-mobile','field','55',0,''),(16033,5072,'115241','watch-mobile','text','<div class=\"heading-2\">##TEXT_CUSTOMER_DETAILS##</div>',0,''),(16034,5072,'115241','watch-mobile','text-align','center',0,''),(16035,5073,'115242','watch-mobile','block_type','2',0,''),(16036,5073,'115242','watch-mobile','margin-bottom','20',0,''),(16037,5074,'115243','watch-mobile','block_type','1',0,''),(16038,5074,'115243','watch-mobile','padding-right','20',0,''),(16039,5075,'115244','watch-mobile','field','56',0,''),(16040,5076,'115245','watch-mobile','field','57',0,''),(16041,5077,'115246','watch-mobile','block_type','1',0,''),(16042,5077,'115246','watch-mobile','padding-left','20',0,''),(16043,5078,'115247','watch-mobile','field','58',0,''),(16044,5079,'115248','watch-mobile','field','59',0,''),(16045,5080,'115249','watch-mobile','text','<h1>##TRADE_FORM##</h1>',0,''),(16046,5081,'115250','watch-mobile','text','<div class=\"heading-2\">##DISCOUNT##</div>',0,''),(16047,5081,'115250','watch-mobile','text-align','center',0,''),(16048,5082,'115251','watch-mobile','block_type','1',0,''),(16049,5083,'115252','watch-mobile','block_type','6',0,''),(16050,5084,'115253','watch-mobile','text','Telephone No.',0,''),(16051,5084,'115253','watch-mobile','text-align','right',0,''),(16052,5085,'115254','watch-mobile','field','79',0,''),(16053,5085,'115254','watch-mobile','border-bottom-width','1',0,''),(16054,5085,'115254','watch-mobile','border-bottom-color','$border-color-6',0,''),(16055,5085,'115254','watch-mobile','padding-left','10',0,''),(16056,5086,'115255','watch-mobile','block_type','6',0,''),(16057,5087,'115256','watch-mobile','text','Address',0,''),(16058,5087,'115256','watch-mobile','text-align','right',0,''),(16059,5088,'115257','watch-mobile','fields','company_street_address, company_suburb, company_city',0,''),(16060,5088,'115257','watch-mobile','padding-left','10',0,''),(16061,5088,'115257','watch-mobile','border-bottom-width','1',0,''),(16062,5088,'115257','watch-mobile','border-bottom-color','$border-color-6',0,''),(16063,5089,'115258','watch-mobile','block_type','6',0,''),(16064,5090,'115259','watch-mobile','text','Postcode',0,''),(16065,5090,'115259','watch-mobile','text-align','right',0,''),(16066,5091,'115260','watch-mobile','field','80',0,''),(16067,5091,'115260','watch-mobile','border-bottom-width','1',0,''),(16068,5091,'115260','watch-mobile','border-bottom-color','$border-color-6',0,''),(16069,5091,'115260','watch-mobile','padding-left','10',0,''),(16070,5092,'115261','watch-mobile','block_type','6',0,''),(16071,5093,'115262','watch-mobile','text','Address',0,''),(16072,5093,'115262','watch-mobile','text-align','right',0,''),(16073,5094,'115263','watch-mobile','fields','oner_street_address, owner_suburb, owner_city',0,''),(16074,5094,'115263','watch-mobile','padding-left','10',0,''),(16075,5094,'115263','watch-mobile','border-bottom-width','1',0,''),(16076,5094,'115263','watch-mobile','border-bottom-color','$border-color-6',0,''),(16077,5095,'115264','watch-mobile','block_type','6',0,''),(16078,5095,'115264','watch-mobile','margin-top','20',0,''),(16079,5096,'115265','watch-mobile','text','Owner’s Name',0,''),(16080,5096,'115265','watch-mobile','text-align','right',0,''),(16081,5097,'115266','watch-mobile','fields','owner_firstname owner_lastname',0,''),(16082,5097,'115266','watch-mobile','padding-left','10',0,''),(16083,5097,'115266','watch-mobile','border-bottom-width','1',0,''),(16084,5097,'115266','watch-mobile','border-bottom-color','$border-color-6',0,''),(16085,5098,'115267','watch-mobile','block_type','6',0,''),(16086,5099,'115268','watch-mobile','text','Email',0,''),(16087,5099,'115268','watch-mobile','text-align','right',0,''),(16088,5100,'115269','watch-mobile','field','70',0,''),(16089,5100,'115269','watch-mobile','border-bottom-width','1',0,''),(16090,5100,'115269','watch-mobile','border-bottom-color','$border-color-6',0,''),(16091,5100,'115269','watch-mobile','padding-left','10',0,''),(16092,5101,'115270','watch-mobile','block_type','6',0,''),(16093,5101,'115270','watch-mobile','padding-bottom','20',0,''),(16094,5102,'115271','watch-mobile','text','Telephone No.',0,''),(16095,5102,'115271','watch-mobile','text-align','right',0,''),(16096,5103,'115272','watch-mobile','block_type','11',0,''),(16097,5104,'115273','watch-mobile','field','69',0,''),(16098,5104,'115273','watch-mobile','border-bottom-width','1',0,''),(16099,5104,'115273','watch-mobile','border-bottom-color','$border-color-6',0,''),(16100,5104,'115273','watch-mobile','padding-left','10',0,''),(16101,5105,'115274','watch-mobile','block_type','5',0,''),(16102,5106,'115275','watch-mobile','text','Fax No.',0,''),(16103,5106,'115275','watch-mobile','text-align','right',0,''),(16104,5107,'115276','watch-mobile','field','51',0,''),(16105,5107,'115276','watch-mobile','padding-left','10',0,''),(16106,5107,'115276','watch-mobile','border-bottom-width','1',0,''),(16107,5107,'115276','watch-mobile','border-bottom-color','$border-color-6',0,''),(16108,5108,'115277','watch-mobile','block_type','1',0,''),(16109,5109,'115278','watch-mobile','background-color','$background-1',0,''),(16110,5109,'115278','watch-mobile','color','$color-font-1',0,''),(16111,5109,'115278','watch-mobile','font-size','20',0,''),(16112,5109,'115278','watch-mobile','text','Customer Details',0,''),(16113,5109,'115278','watch-mobile','padding-left','10',0,''),(16114,5109,'115278','watch-mobile','padding-right','10',0,''),(16115,5110,'115279','watch-mobile','block_type','2',0,''),(16116,5110,'115279','watch-mobile','color','$color-font-1',0,''),(16117,5110,'115279','watch-mobile','background-color','$background-1',0,''),(16118,5111,'115280','watch-mobile','view_item','name',0,''),(16119,5111,'115280','watch-mobile','color','$color-font-1',0,''),(16120,5111,'115280','watch-mobile','font-size','40',0,''),(16121,5112,'115281','watch-mobile','text','New Account Form',0,''),(16122,5112,'115281','watch-mobile','font-size','20',0,''),(16123,5112,'115281','watch-mobile','color','$color-font-1',0,''),(16124,5112,'115281','watch-mobile','padding-top','20',0,''),(16125,5113,'115282','watch-mobile','block_type','2',0,''),(16126,5114,'115283','watch-mobile','block_type','2',0,''),(16127,5114,'115283','watch-mobile','padding-top','5',0,''),(16128,5115,'115284','watch-mobile','block_type','10',0,''),(16129,5116,'115285','watch-mobile','text','Limited Company',0,''),(16130,5116,'115285','watch-mobile','font-size','16',0,''),(16131,5117,'115286','watch-mobile','field','49',0,''),(16132,5117,'115286','watch-mobile','padding-left','5',0,''),(16133,5118,'115287','watch-mobile','block_type','10',0,''),(16134,5119,'115288','watch-mobile','text','Sole Trader',0,''),(16135,5119,'115288','watch-mobile','text-align','center',0,''),(16136,5120,'115289','watch-mobile','field','50',0,''),(16137,5120,'115289','watch-mobile','padding-left','5',0,''),(16138,5121,'115290','watch-mobile','block_type','5',0,''),(16139,5122,'115291','watch-mobile','view_item','data_format',0,''),(16140,5122,'115291','watch-mobile','data_format_content','##STREET_ADDRESS##, ##SUBURB##,\n##CITY##, ##POSTCODE##\nTel: ##TELEPHONE##\nEmail: ##EMAIL_ADDRESS##\n',0,''),(16141,5122,'115291','watch-mobile','font-size','14',0,''),(16142,5123,'115292','watch-mobile','block_type','6',0,''),(16143,5124,'115293','watch-mobile','text','Postcode',0,''),(16144,5124,'115293','watch-mobile','text-align','right',0,''),(16145,5125,'115294','watch-mobile','field','71',0,''),(16146,5125,'115294','watch-mobile','border-bottom-width','1',0,''),(16147,5125,'115294','watch-mobile','border-bottom-color','$border-color-6',0,''),(16148,5125,'115294','watch-mobile','padding-left','10',0,''),(16149,5126,'115295','watch-mobile','block_type','6',0,''),(16150,5127,'115296','watch-mobile','text','Business Name',0,''),(16151,5127,'115296','watch-mobile','text-align','right',0,''),(16152,5128,'115297','watch-mobile','field','68',0,''),(16153,5128,'115297','watch-mobile','border-bottom-width','1',0,''),(16154,5128,'115297','watch-mobile','border-bottom-color','$border-color-6',0,''),(16155,5128,'115297','watch-mobile','padding-left','10',0,''),(16156,5129,'115298','watch-mobile','block_type','6',0,''),(16157,5129,'115298','watch-mobile','padding-bottom','20',0,''),(16158,5130,'115299','watch-mobile','text','Nature of Business',0,''),(16159,5130,'115299','watch-mobile','text-align','right',0,''),(16160,5131,'115300','watch-mobile','field','52',0,''),(16161,5131,'115300','watch-mobile','border-bottom-width','1',0,''),(16162,5131,'115300','watch-mobile','border-bottom-color','$border-color-6',0,''),(16163,5131,'115300','watch-mobile','padding-left','10',0,''),(16164,5132,'115301','watch-mobile','block_type','6',0,''),(16165,5133,'115302','watch-mobile','text','Bank Name',0,''),(16166,5133,'115302','watch-mobile','text-align','right',0,''),(16167,5133,'115302','watch-mobile','font-size','16',0,''),(16168,5134,'115303','watch-mobile','field','53',0,''),(16169,5134,'115303','watch-mobile','border-bottom-width','1',0,''),(16170,5134,'115303','watch-mobile','border-bottom-color','$border-color-6',0,''),(16171,5134,'115303','watch-mobile','padding-left','10',0,''),(16172,5135,'115304','watch-mobile','block_type','1',0,''),(16173,5135,'115304','watch-mobile','padding-top','20',0,''),(16174,5135,'115304','watch-mobile','padding-bottom','10',0,''),(16175,5136,'115305','watch-mobile','background-color','$background-1',0,''),(16176,5136,'115305','watch-mobile','color','$color-font-1',0,''),(16177,5136,'115305','watch-mobile','font-size','20',0,''),(16178,5136,'115305','watch-mobile','text','Discount (%)',0,''),(16179,5136,'115305','watch-mobile','padding-left','10',0,''),(16180,5136,'115305','watch-mobile','padding-right','10',0,''),(16181,5137,'115306','watch-mobile','block_type','1',0,''),(16182,5137,'115306','watch-mobile','padding-bottom','10',0,''),(16183,5138,'115307','watch-mobile','background-color','$background-1',0,''),(16184,5138,'115307','watch-mobile','color','$color-font-1',0,''),(16185,5138,'115307','watch-mobile','font-size','20',0,''),(16186,5138,'115307','watch-mobile','text','Bank Account Details',0,''),(16187,5138,'115307','watch-mobile','padding-left','10',0,''),(16188,5138,'115307','watch-mobile','padding-right','10',0,''),(16189,5139,'115308','watch-mobile','block_type','6',0,''),(16190,5139,'115308','watch-mobile','padding-bottom','20',0,''),(16191,5140,'115309','watch-mobile','text','Account No',0,''),(16192,5140,'115309','watch-mobile','text-align','right',0,''),(16193,5141,'115310','watch-mobile','field','54',0,''),(16194,5141,'115310','watch-mobile','border-bottom-width','1',0,''),(16195,5141,'115310','watch-mobile','border-bottom-color','$border-color-6',0,''),(16196,5141,'115310','watch-mobile','padding-left','10',0,''),(16197,5142,'115311','watch-mobile','block_type','6',0,''),(16198,5143,'115312','watch-mobile','text','Address',0,''),(16199,5143,'115312','watch-mobile','text-align','right',0,''),(16200,5144,'115313','watch-mobile','field','55',0,''),(16201,5144,'115313','watch-mobile','border-bottom-width','1',0,''),(16202,5144,'115313','watch-mobile','border-bottom-color','$border-color-6',0,''),(16203,5144,'115313','watch-mobile','padding-left','10',0,''),(16204,5145,'115314','watch-mobile','block_type','14',0,''),(16205,5145,'115314','watch-mobile','padding-bottom','20',0,''),(16206,5146,'115315','watch-mobile','text','33.33% Sale or Return',0,''),(16207,5146,'115315','watch-mobile','text-align','right',0,''),(16208,5146,'115315','watch-mobile','font-size','16',0,''),(16209,5147,'115316','watch-mobile','block_type','13',0,''),(16210,5148,'115317','watch-mobile','field','56',0,''),(16211,5148,'115317','watch-mobile','padding-left','10',0,''),(16212,5149,'115318','watch-mobile','text','35% Firm',0,''),(16213,5149,'115318','watch-mobile','text-align','right',0,''),(16214,5150,'115319','watch-mobile','field','58',0,''),(16215,5150,'115319','watch-mobile','padding-left','10',0,''),(16216,5151,'115320','watch-mobile','block_type','10',0,''),(16217,5152,'115321','watch-mobile','block_type','6',0,''),(16218,5153,'115322','watch-mobile','text','Address',0,''),(16219,5153,'115322','watch-mobile','text-align','right',0,''),(16220,5154,'115323','watch-mobile','field','61',0,''),(16221,5154,'115323','watch-mobile','border-bottom-width','1',0,''),(16222,5154,'115323','watch-mobile','border-bottom-color','$border-color-6',0,''),(16223,5154,'115323','watch-mobile','padding-left','10',0,''),(16224,5155,'115324','watch-mobile','block_type','1',0,''),(16225,5155,'115324','watch-mobile','padding-bottom','10',0,''),(16226,5156,'115325','watch-mobile','background-color','$background-1',0,''),(16227,5156,'115325','watch-mobile','color','$color-font-1',0,''),(16228,5156,'115325','watch-mobile','font-size','20',0,''),(16229,5156,'115325','watch-mobile','text','Trade References',0,''),(16230,5156,'115325','watch-mobile','padding-left','10',0,''),(16231,5156,'115325','watch-mobile','padding-right','10',0,''),(16232,5157,'115326','watch-mobile','block_type','1',0,''),(16233,5158,'115327','watch-mobile','text','I would like to open a trade account with Vladislav B. Malyshev and agree to abide by their General Terms & Conditions –\na signed copy of which is returned to them with this form in the supplied SAE. I have retained a copy for my reference. I\nam authorised to sign on behalf of the company I represent.',0,''),(16234,5158,'115327','watch-mobile','font-size','15',0,''),(16235,5158,'115327','watch-mobile','padding-left','10',0,''),(16236,5158,'115327','watch-mobile','padding-right','10',0,''),(16237,5159,'115328','watch-mobile','block_type','6',0,''),(16238,5159,'115328','watch-mobile','padding-bottom','20',0,''),(16239,5160,'115329','watch-mobile','text','Telephone No.',0,''),(16240,5160,'115329','watch-mobile','text-align','right',0,''),(16241,5161,'115330','watch-mobile','field','62',0,''),(16242,5161,'115330','watch-mobile','border-bottom-width','1',0,''),(16243,5161,'115330','watch-mobile','border-bottom-color','$border-color-6',0,''),(16244,5161,'115330','watch-mobile','padding-left','10',0,''),(16245,5162,'115331','watch-mobile','block_type','1',0,''),(16246,5162,'115331','watch-mobile','padding-bottom','10',0,''),(16247,5163,'115332','watch-mobile','background-color','$background-1',0,''),(16248,5163,'115332','watch-mobile','color','$color-font-1',0,''),(16249,5163,'115332','watch-mobile','font-size','20',0,''),(16250,5163,'115332','watch-mobile','text','Customer Details',0,''),(16251,5163,'115332','watch-mobile','padding-left','10',0,''),(16252,5163,'115332','watch-mobile','padding-right','10',0,''),(16253,5164,'115333','watch-mobile','block_type','6',0,''),(16254,5165,'115334','watch-mobile','text','Name',0,''),(16255,5165,'115334','watch-mobile','text-align','right',0,''),(16256,5165,'115334','watch-mobile','font-size','16',0,''),(16257,5166,'115335','watch-mobile','field','60',0,''),(16258,5166,'115335','watch-mobile','border-bottom-width','1',0,''),(16259,5166,'115335','watch-mobile','border-bottom-color','$border-color-6',0,''),(16260,5166,'115335','watch-mobile','padding-left','10',0,''),(16261,5167,'115336','watch-mobile','block_type','14',0,''),(16262,5168,'115337','watch-mobile','text','Signed',0,''),(16263,5168,'115337','watch-mobile','text-align','right',0,''),(16264,5169,'115338','watch-mobile','text','&nbsp;',0,''),(16265,5169,'115338','watch-mobile','border-bottom-width','1',0,''),(16266,5169,'115338','watch-mobile','border-bottom-color','$border-color-6',0,''),(16267,5170,'115339','watch-mobile','text','Date',0,''),(16268,5170,'115339','watch-mobile','text-align','right',0,''),(16269,5171,'115340','watch-mobile','text','&nbsp;',0,''),(16270,5171,'115340','watch-mobile','border-bottom-width','1',0,''),(16271,5171,'115340','watch-mobile','border-bottom-color','$border-color-6',0,''),(16272,5172,'115341','watch-mobile','block_type','14',0,''),(16273,5173,'115342','watch-mobile','text','Name in Full',0,''),(16274,5173,'115342','watch-mobile','text-align','right',0,''),(16275,5174,'115343','watch-mobile','field','66',0,''),(16276,5174,'115343','watch-mobile','padding-left','10',0,''),(16277,5174,'115343','watch-mobile','border-bottom-width','1',0,''),(16278,5174,'115343','watch-mobile','border-bottom-color','$border-color-6',0,''),(16279,5175,'115344','watch-mobile','text','Position',0,''),(16280,5175,'115344','watch-mobile','text-align','right',0,''),(16281,5176,'115345','watch-mobile','field','67',0,''),(16282,5176,'115345','watch-mobile','border-bottom-width','1',0,''),(16283,5176,'115345','watch-mobile','border-bottom-color','$border-color-6',0,''),(16284,5176,'115345','watch-mobile','padding-left','10',0,''),(16285,5177,'115346','watch-mobile','block_type','1',0,''),(16286,5178,'115347','watch-mobile','text','Scottish books of exceptional value',0,''),(16287,5178,'115347','watch-mobile','font-size','20',0,''),(16288,5178,'115347','watch-mobile','text-align','center',0,''),(16289,5178,'115347','watch-mobile','padding-top','20',0,''),(16290,5179,'115348','watch-mobile','block_type','1',0,''),(16291,5180,'115349','watch-mobile','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(16292,5180,'115349','watch-mobile','padding-top','100',0,''),(16293,5180,'115349','watch-mobile','margin-bottom','100',0,''),(16294,5180,'115349','watch-mobile','text-align','center',0,''),(16295,5180,'115349','watch-mobile','font-size','20',0,''),(16296,5181,'115350','watch-mobile','block_type','1',0,''),(16297,5181,'115350','watch-mobile','background-color','$background-6',0,''),(16298,5181,'115350','watch-mobile','padding-bottom','30',0,''),(16299,5182,'115351','watch-mobile','block_type','4',0,''),(16300,5182,'115351','watch-mobile','schema','4-2',0,''),(16301,5183,'115352','watch-mobile','block_type','1',0,''),(16302,5183,'115352','watch-mobile','padding-right','40',0,''),(16304,5184,'115353','watch-mobile','block_type','2',0,''),(16305,5184,'115353','watch-mobile','margin-bottom','20',0,''),(16306,5184,'115353','watch-mobile','schema','2-2',0,''),(16307,5184,'115353','watch-mobile','background-color','$background-7',0,''),(16308,5185,'115354','watch-mobile','block_type','1',0,''),(16309,5185,'115354','watch-mobile','border-right-width','20',0,''),(16310,5185,'115354','watch-mobile','border-right-color','$border-color-1',0,''),(16311,5185,'115354','watch-mobile','margin-right','-10',0,''),(16312,5185,'115354','watch-mobile','padding-right','30',0,''),(16313,5185,'115354','watch-mobile','padding-top','20',0,''),(16314,5185,'115354','watch-mobile','padding-left','30',0,''),(16315,5185,'115354','watch-mobile','padding-bottom','20',0,''),(16318,5185,'115354','watch-mobile','margin-bottom','20',0,''),(16321,5186,'115355','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(16322,5186,'115355','watch-mobile','clear','none',0,''),(16323,5187,'115356','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(16324,5187,'115356','watch-mobile','clear','none',0,''),(16325,5188,'115357','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(16326,5190,'115359','watch-mobile','margin-bottom','20',0,''),(16327,5194,'115363','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(16328,5194,'115363','watch-mobile','padding-top','20',0,''),(16329,5195,'115364','watch-mobile','block_type','1',0,''),(16330,5195,'115364','watch-mobile','padding-left','30',0,''),(16331,5195,'115364','watch-mobile','border-left-width','20',0,''),(16332,5195,'115364','watch-mobile','border-left-color','$border-color-1',0,''),(16333,5195,'115364','watch-mobile','margin-left','-10',0,''),(16334,5195,'115364','watch-mobile','padding-right','30',0,''),(16335,5195,'115364','watch-mobile','padding-top','20',0,''),(16336,5195,'115364','watch-mobile','padding-bottom','20',0,''),(16338,5196,'115365','watch-mobile','margin-bottom','20',0,''),(16339,5198,'115367','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(16340,5199,'115368','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(16341,5199,'115368','watch-mobile','clear','none',0,''),(16342,5200,'115369','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(16343,5200,'115369','watch-mobile','clear','none',0,''),(16344,5201,'115370','watch-mobile','block_type','1',0,''),(16345,5201,'115370','watch-mobile','padding-right','30',0,''),(16346,5201,'115370','watch-mobile','background-color','$background-7',0,''),(16347,5201,'115370','watch-mobile','padding-top','20',0,''),(16348,5201,'115370','watch-mobile','padding-left','30',0,''),(16349,5201,'115370','watch-mobile','padding-bottom','20',0,''),(16352,5203,'115372','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(16353,5204,'115373','watch-mobile','block_type','1',0,''),(16354,5204,'115373','watch-mobile','padding-top','20',0,''),(16355,5204,'115373','watch-mobile','padding-left','20',0,''),(16356,5204,'115373','watch-mobile','padding-right','20',0,''),(16357,5204,'115373','watch-mobile','padding-bottom','20',0,''),(16358,5204,'115373','watch-mobile','background-color','$background-7',0,''),(16359,5204,'115373','watch-mobile','style_class','order-summary',0,''),(16360,5205,'115374','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(16361,5209,'115378','watch-mobile','block_type','1',0,''),(16362,5209,'115378','watch-mobile','background-color','$background-6',0,''),(16363,5209,'115378','watch-mobile','padding-bottom','30',0,''),(16364,5210,'115379','watch-mobile','block_type','4',0,''),(16365,5210,'115379','watch-mobile','schema','4-2',0,''),(16366,5211,'115380','watch-mobile','block_type','1',0,''),(16367,5211,'115380','watch-mobile','padding-right','40',0,''),(16369,5212,'115381','watch-mobile','block_type','1',0,''),(16370,5212,'115381','watch-mobile','padding-right','30',0,''),(16371,5212,'115381','watch-mobile','background-color','$background-7',0,''),(16372,5212,'115381','watch-mobile','padding-top','20',0,''),(16373,5212,'115381','watch-mobile','padding-left','30',0,''),(16374,5212,'115381','watch-mobile','padding-bottom','20',0,''),(16377,5213,'115382','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(16378,5215,'115384','watch-mobile','block_type','2',0,''),(16379,5215,'115384','watch-mobile','margin-bottom','20',0,''),(16380,5215,'115384','watch-mobile','schema','2-2',0,''),(16381,5215,'115384','watch-mobile','background-color','$background-7',0,''),(16382,5216,'115385','watch-mobile','block_type','1',0,''),(16383,5216,'115385','watch-mobile','border-right-width','20',0,''),(16384,5216,'115385','watch-mobile','border-right-color','$border-color-1',0,''),(16385,5216,'115385','watch-mobile','margin-right','-10',0,''),(16386,5216,'115385','watch-mobile','padding-right','30',0,''),(16387,5216,'115385','watch-mobile','padding-top','20',0,''),(16388,5216,'115385','watch-mobile','padding-left','30',0,''),(16389,5216,'115385','watch-mobile','padding-bottom','20',0,''),(16392,5216,'115385','watch-mobile','margin-bottom','20',0,''),(16395,5219,'115388','watch-mobile','margin-bottom','20',0,''),(16396,5220,'115389','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(16397,5220,'115389','watch-mobile','padding-top','20',0,''),(16398,5222,'115391','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(16399,5222,'115391','watch-mobile','clear','none',0,''),(16400,5224,'115393','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(16401,5224,'115393','watch-mobile','clear','none',0,''),(16402,5225,'115394','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(16403,5226,'115395','watch-mobile','block_type','1',0,''),(16404,5226,'115395','watch-mobile','padding-left','30',0,''),(16405,5226,'115395','watch-mobile','border-left-width','20',0,''),(16406,5226,'115395','watch-mobile','border-left-color','$border-color-1',0,''),(16407,5226,'115395','watch-mobile','margin-left','-10',0,''),(16408,5226,'115395','watch-mobile','padding-right','30',0,''),(16409,5226,'115395','watch-mobile','padding-top','20',0,''),(16410,5226,'115395','watch-mobile','padding-bottom','20',0,''),(16412,5227,'115396','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(16413,5227,'115396','watch-mobile','clear','none',0,''),(16414,5228,'115397','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(16415,5229,'115398','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(16416,5229,'115398','watch-mobile','clear','none',0,''),(16417,5230,'115399','watch-mobile','margin-bottom','20',0,''),(16418,5232,'115401','watch-mobile','block_type','1',0,''),(16419,5232,'115401','watch-mobile','padding-top','20',0,''),(16420,5232,'115401','watch-mobile','padding-left','20',0,''),(16421,5232,'115401','watch-mobile','padding-right','20',0,''),(16422,5232,'115401','watch-mobile','padding-bottom','20',0,''),(16423,5232,'115401','watch-mobile','background-color','$background-7',0,''),(16424,5232,'115401','watch-mobile','style_class','order-summary',0,''),(16425,5234,'115403','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(16426,5237,'115406','watch-mobile','block_type','1',0,''),(16427,5237,'115406','watch-mobile','background_image','themes/watch-mobile/img/wedding-registry-page-1-1.jpg',0,''),(16428,5237,'115406','watch-mobile','background-position','top center',0,''),(16429,5237,'115406','watch-mobile','background-repeat','no-repeat',0,''),(16430,5237,'115406','watch-mobile','background-size','cover',0,''),(16431,5237,'115406','watch-mobile','padding-top','50',0,''),(16432,5237,'115406','watch-mobile','padding-bottom','50',0,''),(16433,5237,'115406','watch-mobile','margin-bottom','30',0,''),(16434,5238,'115407','watch-mobile','background-color','$background-7',0,''),(16435,5238,'115407','watch-mobile','block_type','1',0,''),(16436,5238,'115407','watch-mobile','max-width','700',0,''),(16437,5238,'115407','watch-mobile','margin_left_measure','auto',0,''),(16438,5238,'115407','watch-mobile','margin_right_measure','auto',0,''),(16439,5239,'115408','watch-mobile','text-align','center',0,''),(16440,5239,'115408','watch-mobile','margin-bottom','30',0,''),(16441,5240,'115409','watch-mobile','padding-bottom','30',0,''),(16442,5240,'115409','watch-mobile','text-align','center',0,''),(16443,5241,'115410','watch-mobile','heading_type','h1',0,''),(16444,5242,'115411','watch-mobile','block_type','13',0,''),(16445,5242,'115411','watch-mobile','margin-bottom','20',0,''),(16446,5242,'115411','watch-mobile','schema','13-2',0,''),(16447,5243,'115412','watch-mobile','position','relative',0,''),(16448,5243,'115412','watch-mobile','margin-top','-100',0,''),(16450,5244,'115413','watch-mobile','font-family','$font-1',0,''),(16451,5244,'115413','watch-mobile','font-size','30',0,''),(16452,5244,'115413','watch-mobile','text-transform','uppercase',0,''),(16453,5244,'115413','watch-mobile','text-align','center',0,''),(16455,5245,'115414','watch-mobile','block_type','1',0,''),(16456,5245,'115414','watch-mobile','float','left',0,''),(16458,5246,'115415','watch-mobile','display','inline-block',0,''),(16459,5246,'115415','watch-mobile','font-weight','700',0,''),(16460,5247,'115416','watch-mobile','clear','none',0,''),(16461,5247,'115416','watch-mobile','padding-left','20',0,''),(16462,5247,'115416','watch-mobile','font-weight','700',0,''),(16463,5247,'115416','watch-mobile','display','inline-block',0,''),(16464,5248,'115417','watch-mobile','font-weight','700',0,''),(16465,5248,'115417','watch-mobile','clear','none',0,''),(16466,5248,'115417','watch-mobile','padding-left','20',0,''),(16467,5248,'115417','watch-mobile','display','inline-block',0,''),(16468,5249,'115418','watch-mobile','font-family','$font-1',0,''),(16469,5249,'115418','watch-mobile','font-size','18',0,''),(16470,5249,'115418','watch-mobile','margin-bottom','10',0,''),(16471,5249,'115418','watch-mobile','text-align','center',0,''),(16472,5250,'115419','watch-mobile','font-weight','700',0,''),(16473,5250,'115419','watch-mobile','text-align','right',0,''),(16474,5250,'115419','watch-mobile','max-width','110',0,''),(16475,5250,'115419','watch-mobile','float','right',0,''),(16476,5251,'115420','watch-mobile','margin-bottom','10',0,''),(16477,5252,'115421','watch-mobile','like_button','1',0,''),(16478,5252,'115421','watch-mobile','text-align','center',0,''),(16479,5252,'115421','watch-mobile','margin-bottom','20',0,''),(16480,5252,'115421','watch-mobile','margin-top','20',0,''),(16481,5252,'115421','watch-mobile','padding-top','30',0,''),(16482,5252,'115421','watch-mobile','border-top-width','1',0,''),(16483,5252,'115421','watch-mobile','border-top-color','$border-color-1',0,''),(16491,5257,'115423','watch-mobile','block_type','1',0,''),(16492,5257,'115423','watch-mobile','padding-top','20',0,''),(16493,5257,'115423','watch-mobile','padding-bottom','20',0,''),(16494,5259,'115425','watch-mobile','padding-top','10',0,''),(16495,5259,'115425','watch-mobile','padding-bottom','10',0,''),(16496,5259,'115425','watch-mobile','border-top-width','1',0,''),(16497,5259,'115425','watch-mobile','border-top-color','$border-color-1',0,''),(16498,5259,'115425','watch-mobile','text-align','right',0,''),(16499,5260,'115426','watch-mobile','block_type','1',0,''),(16500,5260,'115426','watch-mobile','border-top-width','1',0,''),(16501,5260,'115426','watch-mobile','border-left-width','1',0,''),(16502,5260,'115426','watch-mobile','border-right-width','1',0,''),(16503,5260,'115426','watch-mobile','border-bottom-width','1',0,''),(16504,5260,'115426','watch-mobile','border-top-color','$border-color-1',0,''),(16505,5260,'115426','watch-mobile','border-left-color','$border-color-1',0,''),(16506,5260,'115426','watch-mobile','border-right-color','$border-color-1',0,''),(16507,5260,'115426','watch-mobile','border-bottom-color','$border-color-1',0,''),(16508,5260,'115426','watch-mobile','padding-top','15',0,''),(16509,5260,'115426','watch-mobile','padding-left','15',0,''),(16510,5260,'115426','watch-mobile','padding-right','15',0,''),(16511,5260,'115426','watch-mobile','padding-bottom','15',0,''),(16512,5260,'115426','watch-mobile','margin-bottom','50',0,''),(16513,5261,'115427','watch-mobile','block_type','1',0,''),(16514,5261,'115427','watch-mobile','padding-top','20',0,''),(16515,5261,'115427','watch-mobile','padding-left','20',0,''),(16516,5261,'115427','watch-mobile','padding-right','20',0,''),(16517,5261,'115427','watch-mobile','background-color','$background-7',0,''),(16518,5263,'115429','watch-mobile','text','<h1>##FIND_REGISTRY##</h1>',0,''),(16519,5264,'115430','watch-mobile','block_type','1',0,''),(16520,5265,'115431','watch-mobile','block_type','8',0,''),(16521,5265,'115431','watch-mobile','schema','8-6',0,''),(16522,5266,'115432','watch-mobile','text','<div class=\"heading-3\">##INVITE_GUESTS##</div>',0,''),(16523,5267,'115433','watch-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_PERSONALIZED_URL##</div>',0,''),(16524,5268,'115434','watch-mobile','margin-bottom','30',0,''),(16525,5271,'115437','watch-mobile','margin-top','-100',0,''),(16526,5272,'115438','watch-mobile','text','<h1>##SHARE_YOUR_WEDDING_REGISTRY##</h1>',0,''),(16527,5272,'115438','watch-mobile','margin-top','-80',0,''),(16529,5273,'115439','watch-mobile','text','<h1>##CREATE_WR_SUCCESS_MESSAGE##</h1>',0,''),(16530,5275,'115441','watch-mobile','block_type','2',0,''),(16531,5275,'115441','watch-mobile','schema','2-2',0,''),(16532,5276,'115442','watch-mobile','block_type','1',0,''),(16533,5276,'115442','watch-mobile','padding-right','15',0,''),(16535,5277,'115443','watch-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_REGISTRY##</div>',0,''),(16536,5278,'115444','watch-mobile','text','<div class=\"heading-3\">##TEXT_WEDDING_DETAILS##</div>',0,''),(16537,5279,'115445','watch-mobile','margin-bottom','20',0,''),(16538,5280,'115446','watch-mobile','margin-bottom','20',0,''),(16539,5281,'115447','watch-mobile','text','<div class=\"heading-3\">##TEXT_NAMES##</div>',0,''),(16540,5282,'115448','watch-mobile','padding-bottom','20',0,''),(16541,5283,'115449','watch-mobile','block_type','1',0,''),(16542,5283,'115449','watch-mobile','padding-left','15',0,''),(16544,5284,'115450','watch-mobile','margin-bottom','20',0,''),(16545,5285,'115451','watch-mobile','text','<div class=\"heading-3\">##TEXT_SHIPPING_DETAILS##</div>',0,''),(16546,5286,'115452','watch-mobile','text','<div class=\"heading-3\">##UPLOAD_PHOTO##</div>',0,''),(16547,5287,'115453','watch-mobile','margin-bottom','20',0,''),(16548,5287,'115453','watch-mobile','padding-left','1',0,''),(16549,5288,'115454','watch-mobile','text','<div class=\"heading-3\">##TEXT_ADDITIONAL_INFORMATION##</div>',0,''),(16550,5289,'115455','watch-mobile','margin-bottom','20',0,''),(16551,5290,'115456','watch-mobile','text','<h1>##WEDDING_REGISTRY_FORM_HEADING##</h1>',0,''),(16552,5291,'115457','watch-mobile','block_type','2',0,''),(16553,5291,'115457','watch-mobile','margin-bottom','20',0,''),(16554,5293,'115459','watch-mobile','text-align','right',0,''),(16555,5295,'115461','watch-mobile','block_type','13',0,''),(16556,5295,'115461','watch-mobile','margin-bottom','20',0,''),(16557,5296,'115462','watch-mobile','position','relative',0,''),(16558,5296,'115462','watch-mobile','margin-top','-100',0,''),(16559,5297,'115463','watch-mobile','font-family','$font-1',0,''),(16560,5297,'115463','watch-mobile','font-size','18',0,''),(16561,5297,'115463','watch-mobile','margin-bottom','10',0,''),(16562,5298,'115464','watch-mobile','font-family','$font-1',0,''),(16563,5298,'115464','watch-mobile','font-size','30',0,''),(16564,5298,'115464','watch-mobile','text-transform','uppercase',0,''),(16565,5299,'115465','watch-mobile','font-weight','700',0,''),(16566,5299,'115465','watch-mobile','text-align','right',0,''),(16567,5301,'115467','watch-mobile','block_type','1',0,''),(16568,5302,'115468','watch-mobile','block_type','6',0,''),(16569,5302,'115468','watch-mobile','schema','6-3',0,''),(16570,5303,'115469','watch-mobile','aria_name','account-menu',0,''),(16571,5304,'115470','watch-mobile','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(16572,5305,'115471','watch-mobile','margin-bottom','20',0,''),(16573,5306,'115472','watch-mobile','block_type','1',0,''),(16574,5306,'115472','watch-mobile','padding-top','20',0,''),(16575,5306,'115472','watch-mobile','padding-bottom','20',0,''),(16576,5308,'115474','watch-mobile','padding-top','20',0,''),(16577,5308,'115474','watch-mobile','padding-bottom','20',0,''),(40273,12909,'118459','printshop-mobile','text','##TEXT_PAGE_NOT_FOUND##',0,''),(40274,12909,'118459','printshop-mobile','text-align','center',0,''),(40275,12909,'118459','printshop-mobile','padding-top','100',0,''),(40276,12909,'118459','printshop-mobile','padding-bottom','100',0,''),(40277,12910,'118460','printshop-mobile','block_type','1',0,''),(40396,12926,'118476','printshop-mobile','block_type','1',0,''),(40515,12942,'118492','printshop-mobile','block_type','1',0,''),(40634,12958,'118508','printshop-mobile','block_type','1',0,''),(40753,12974,'118524','printshop-mobile','block_type','1',0,''),(40872,12990,'118540','printshop-mobile','block_type','1',0,''),(40991,13006,'118556','printshop-mobile','block_type','1',0,''),(40992,13007,'118557','printshop-mobile','block_type','6',0,''),(40993,13007,'118557','printshop-mobile','schema','6-3',0,''),(40994,13007,'118557','printshop-mobile','schema','6-3',0,'702'),(40995,13008,'118558','printshop-mobile','aria_name','account-menu',0,''),(40996,13009,'118559','printshop-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(40997,13010,'118560','printshop-mobile','link','Order History Info',0,''),(40998,13010,'118560','printshop-mobile','text','TEXT_VIEW',0,''),(40999,13010,'118560','printshop-mobile','max_orders','3',0,''),(41000,13010,'118560','printshop-mobile','link_pay','Order pay',0,''),(41001,13010,'118560','printshop-mobile','margin-bottom','30',0,''),(41002,13010,'118560','printshop-mobile','text_pay','ORDER_PAY',0,''),(41003,13011,'118561','printshop-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(41004,13012,'118562','printshop-mobile','block_type','15',0,''),(41005,13012,'118562','printshop-mobile','margin-bottom','30',0,''),(41006,13012,'118562','printshop-mobile','padding-top','20',0,''),(41007,13012,'118562','printshop-mobile','padding-left','20',0,''),(41008,13012,'118562','printshop-mobile','padding-right','20',0,''),(41009,13012,'118562','printshop-mobile','padding-bottom','20',0,''),(41010,13012,'118562','printshop-mobile','border-top-width','1',0,''),(41011,13012,'118562','printshop-mobile','border-top-color','#e0e0e0',0,''),(41012,13012,'118562','printshop-mobile','border-left-width','1',0,''),(41013,13012,'118562','printshop-mobile','border-right-width','1',0,''),(41014,13012,'118562','printshop-mobile','border-bottom-width','1',0,''),(41015,13012,'118562','printshop-mobile','border-left-color','#e0e0e0',0,''),(41016,13012,'118562','printshop-mobile','border-right-color','#e0e0e0',0,''),(41017,13012,'118562','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(41018,13012,'118562','printshop-mobile','schema','15-2',0,'702'),(41019,13013,'118563','printshop-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(41020,13013,'118563','printshop-mobile','font-family','trueloaded',0,'3'),(41021,13013,'118563','printshop-mobile','content','\\e920',0,'3'),(41022,13013,'118563','printshop-mobile','color','#ee4225',0,'3'),(41023,13013,'118563','printshop-mobile','font-size','30',0,'3'),(41024,13013,'118563','printshop-mobile','text-align','center',0,'3'),(41025,13013,'118563','printshop-mobile','margin-bottom','10',0,'3'),(41026,13013,'118563','printshop-mobile','text-align','center',0,''),(41027,13013,'118563','printshop-mobile','font-size','16',0,''),(41028,13013,'118563','printshop-mobile','text-transform','uppercase',0,''),(41029,13013,'118563','printshop-mobile','line-height','1',0,'3'),(41031,13014,'118564','printshop-mobile','font-family','Varela Round',0,''),(41032,13014,'118564','printshop-mobile','color','#ee4225',0,''),(41033,13014,'118564','printshop-mobile','font-size','14',0,''),(41034,13014,'118564','printshop-mobile','text-align','center',0,''),(41035,13015,'118565','printshop-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(41036,13015,'118565','printshop-mobile','font-family','trueloaded',0,'3'),(41037,13015,'118565','printshop-mobile','content','\\e928',0,'3'),(41038,13015,'118565','printshop-mobile','color','#ee4225',0,'3'),(41039,13015,'118565','printshop-mobile','font-size','30',0,'3'),(41040,13015,'118565','printshop-mobile','text-align','center',0,'3'),(41041,13015,'118565','printshop-mobile','text-align','center',0,''),(41042,13015,'118565','printshop-mobile','font-size','16',0,''),(41043,13015,'118565','printshop-mobile','text-transform','uppercase',0,''),(41044,13015,'118565','printshop-mobile','line-height','1',0,'3'),(41046,13016,'118566','printshop-mobile','link','download_orders',0,''),(41047,13016,'118566','printshop-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(41048,13016,'118566','printshop-mobile','hide_link','orders',0,''),(41049,13016,'118566','printshop-mobile','text-align','center',0,''),(41050,13016,'118566','printshop-mobile','popup','2',0,''),(41051,13016,'118566','printshop-mobile','font-size','14',0,''),(41052,13017,'118567','printshop-mobile','font-family','Varela Round',0,''),(41053,13017,'118567','printshop-mobile','color','#ee4225',0,''),(41054,13017,'118567','printshop-mobile','font-size','14',0,''),(41055,13017,'118567','printshop-mobile','text-align','center',0,''),(41056,13018,'118568','printshop-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(41057,13018,'118568','printshop-mobile','font-family','trueloaded',0,'3'),(41058,13018,'118568','printshop-mobile','content','\\e922',0,'3'),(41059,13018,'118568','printshop-mobile','color','#ee4225',0,'3'),(41060,13018,'118568','printshop-mobile','font-size','30',0,'3'),(41061,13018,'118568','printshop-mobile','line-height','1',0,'3'),(41062,13018,'118568','printshop-mobile','font-size','16',0,''),(41063,13018,'118568','printshop-mobile','text-align','center',0,''),(41064,13018,'118568','printshop-mobile','text-transform','uppercase',0,''),(41066,13019,'118569','printshop-mobile','font-family','Varela Round',0,''),(41067,13019,'118569','printshop-mobile','color','#ee4225',0,''),(41068,13019,'118569','printshop-mobile','line-height','1',0,''),(41069,13019,'118569','printshop-mobile','text-align','center',0,''),(41070,13019,'118569','printshop-mobile','font-size','14',0,''),(41071,13020,'118570','printshop-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(41072,13020,'118570','printshop-mobile','content','\\e994',0,'3'),(41073,13020,'118570','printshop-mobile','font-family','trueloaded',0,'3'),(41074,13020,'118570','printshop-mobile','color','#ee4225',0,'3'),(41075,13020,'118570','printshop-mobile','font-size','30',0,'3'),(41076,13020,'118570','printshop-mobile','line-height','1',0,'3'),(41077,13020,'118570','printshop-mobile','font-size','16',0,''),(41078,13020,'118570','printshop-mobile','text-align','center',0,''),(41079,13020,'118570','printshop-mobile','text-transform','uppercase',0,''),(41081,13021,'118571','printshop-mobile','link','Gift Certificate',0,''),(41082,13021,'118571','printshop-mobile','text','GIFT_CERTIFICATE',0,''),(41083,13021,'118571','printshop-mobile','popup','1',0,''),(41084,13021,'118571','printshop-mobile','text-align','center',0,''),(41085,13021,'118571','printshop-mobile','font-size','14',0,''),(41086,13022,'118572','printshop-mobile','font-family','Varela Round',0,''),(41087,13022,'118572','printshop-mobile','color','#ee4225',0,''),(41088,13022,'118572','printshop-mobile','font-size','14',0,''),(41089,13022,'118572','printshop-mobile','text-align','center',0,''),(41090,13023,'118573','printshop-mobile','text','TEXT_VIEW_HISTORY',0,''),(41091,13023,'118573','printshop-mobile','popup','1',0,''),(41092,13023,'118573','printshop-mobile','text-align','center',0,''),(41093,13023,'118573','printshop-mobile','link','Points Earnt History',0,''),(41094,13023,'118573','printshop-mobile','font-size','14',0,''),(41095,13024,'118574','printshop-mobile','font-family','Varela Round',0,''),(41096,13024,'118574','printshop-mobile','color','#ee4225',0,''),(41097,13024,'118574','printshop-mobile','font-size','14',0,''),(41098,13024,'118574','printshop-mobile','text-align','center',0,''),(41099,13025,'118575','printshop-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(41100,13025,'118575','printshop-mobile','content','\\e990',0,'3'),(41101,13025,'118575','printshop-mobile','font-family','trueloaded',0,'3'),(41102,13025,'118575','printshop-mobile','font-size','30',0,'3'),(41103,13025,'118575','printshop-mobile','text-align','center',0,'3'),(41104,13025,'118575','printshop-mobile','line-height','1',0,'3'),(41105,13025,'118575','printshop-mobile','color','#ee4225',0,'3'),(41106,13025,'118575','printshop-mobile','font-size','16',0,''),(41107,13025,'118575','printshop-mobile','text-align','center',0,''),(41108,13025,'118575','printshop-mobile','text-transform','uppercase',0,''),(41110,13026,'118576','printshop-mobile','block_type','1',0,''),(41111,13027,'118577','printshop-mobile','hide_parents','2',0,''),(41112,13028,'118578','printshop-mobile','text','<div class=\"heading-3\">##TEXT_GIFT_CARDS##</div>',0,''),(41113,13030,'118580','printshop-mobile','block_type','1',0,''),(41114,13030,'118580','printshop-mobile','padding-top','70',0,''),(41115,13030,'118580','printshop-mobile','padding-right','30',0,''),(41116,13030,'118580','printshop-mobile','padding-bottom','30',0,''),(41118,13030,'118580','printshop-mobile','padding-left','0',0,''),(41121,13031,'118581','printshop-mobile','block_type','1',0,''),(41122,13031,'118581','printshop-mobile','padding-right','20',0,''),(41123,13031,'118581','printshop-mobile','style_class','account-menu',0,''),(41124,13031,'118581','printshop-mobile','padding-top','20',0,''),(41125,13031,'118581','printshop-mobile','margin-bottom','20',0,''),(41126,13031,'118581','printshop-mobile','background-color','#eeeeee',0,''),(41127,13031,'118581','printshop-mobile','padding-left','20',0,''),(41128,13031,'118581','printshop-mobile','padding-bottom','20',0,''),(41129,13032,'118582','printshop-mobile','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(41130,13032,'118582','printshop-mobile','style_class','heading-settings',0,''),(41131,13033,'118583','printshop-mobile','link','delete',0,''),(41132,13033,'118583','printshop-mobile','text','DELETE_ACCOUNT',0,''),(41133,13034,'118584','printshop-mobile','text','TEXT_DASHBOARD',0,''),(41134,13034,'118584','printshop-mobile','font-family','Varela Round',0,''),(41135,13034,'118584','printshop-mobile','font-size','18',0,''),(41136,13034,'118584','printshop-mobile','text-transform','uppercase',0,''),(41137,13035,'118585','printshop-mobile','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(41138,13035,'118585','printshop-mobile','style_class','heading-saved-lists',0,''),(41139,13036,'118586','printshop-mobile','link','logoff',0,''),(41140,13037,'118587','printshop-mobile','link','Personal Catalog',0,''),(41141,13037,'118587','printshop-mobile','text','TEXT_PERSONAL_CATALOG',0,''),(41142,13037,'118587','printshop-mobile','hide_link','personal_catalog',0,''),(41143,13038,'118588','printshop-mobile','link','Address Book',0,''),(41144,13038,'118588','printshop-mobile','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(41145,13039,'118589','printshop-mobile','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(41146,13039,'118589','printshop-mobile','style_class','heading-ordered-items',0,''),(41147,13040,'118590','printshop-mobile','link','Samples',0,''),(41148,13040,'118590','printshop-mobile','text','TEXT_HEADING_SAMPLE_CART',0,''),(41149,13040,'118590','printshop-mobile','hide_link','samples',0,''),(41150,13041,'118591','printshop-mobile','link','Order History',0,''),(41151,13041,'118591','printshop-mobile','text','HEADING_ORDER_HISTORY',0,''),(41152,13041,'118591','printshop-mobile','active_link','Order History Info,Order pay',0,''),(41153,13042,'118592','printshop-mobile','link','My password',0,''),(41154,13042,'118592','printshop-mobile','text','TEXT_MY_PASSWORD',0,''),(41155,13043,'118593','printshop-mobile','link','Review',0,''),(41156,13043,'118593','printshop-mobile','text','REVIEWS',0,''),(41157,13044,'118594','printshop-mobile','link','Account edit',0,''),(41158,13044,'118594','printshop-mobile','text','ACCOUNT_EDIT',0,''),(41159,13045,'118595','printshop-mobile','link','Quotations',0,''),(41160,13045,'118595','printshop-mobile','hide_link','quotations',0,''),(41161,13045,'118595','printshop-mobile','text','TEXT_HEADING_QUOTE_CART',0,''),(41162,13046,'118596','printshop-mobile','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(41163,13046,'118596','printshop-mobile','style_class','heading-settings',0,''),(41164,13047,'118597','printshop-mobile','link','trade_form',0,''),(41165,13047,'118597','printshop-mobile','text','TRADE_FORM',0,''),(41166,13048,'118598','printshop-mobile','block_type','1',0,''),(41167,13049,'118599','printshop-mobile','block_type','6',0,''),(41168,13049,'118599','printshop-mobile','schema','6-3',0,''),(41169,13049,'118599','printshop-mobile','schema','6-3',0,'702'),(41170,13050,'118600','printshop-mobile','aria_name','account-menu',0,''),(41171,13052,'118602','printshop-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(41172,13053,'118603','printshop-mobile','text','CANCEL',0,''),(41173,13053,'118603','printshop-mobile','like_button','1',0,''),(41174,13053,'118603','printshop-mobile','padding-bottom','20',0,''),(41175,13054,'118604','printshop-mobile','block_type','1',0,''),(41176,13055,'118605','printshop-mobile','block_type','6',0,''),(41177,13055,'118605','printshop-mobile','schema','6-3',0,''),(41178,13055,'118605','printshop-mobile','schema','6-3',0,'702'),(41179,13056,'118606','printshop-mobile','aria_name','account-menu',0,''),(41180,13057,'118607','printshop-mobile','padding-top','15',0,''),(41181,13057,'118607','printshop-mobile','padding-bottom','15',0,''),(41182,13057,'118607','printshop-mobile','link','Address Book Process',0,''),(41183,13057,'118607','printshop-mobile','text','EDIT',0,''),(41184,13057,'118607','printshop-mobile','link_add','Address Book Process',0,''),(41185,13057,'118607','printshop-mobile','like_button_add','2',0,''),(41186,13057,'118607','printshop-mobile','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(41187,13058,'118608','printshop-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1><div class=\"info-popup bottom-left\">\n<div><ul><li>##PRIMARY_ADDRESS##<br>##PRIMARY_ADDRESS_DESCRIPTION##<br></li><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(41188,13058,'118608','printshop-mobile','text-align','center',0,''),(41189,13059,'118609','printshop-mobile','block_type','1',0,''),(41190,13060,'118610','printshop-mobile','block_type','6',0,''),(41191,13060,'118610','printshop-mobile','schema','6-3',0,''),(41192,13060,'118610','printshop-mobile','schema','6-3',0,'702'),(41193,13061,'118611','printshop-mobile','aria_name','account-menu',0,''),(41194,13063,'118613','printshop-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(41195,13064,'118614','printshop-mobile','text','CANCEL',0,''),(41196,13064,'118614','printshop-mobile','like_button','1',0,''),(41197,13064,'118614','printshop-mobile','padding-bottom','20',0,''),(41198,13064,'118614','printshop-mobile','link','Address Book',0,''),(41199,13065,'118615','printshop-mobile','block_type','1',0,''),(41200,13065,'118615','printshop-mobile','style_class','item-holder',0,''),(41201,13065,'118615','printshop-mobile','padding-top','25',0,''),(41202,13065,'118615','printshop-mobile','padding-bottom','25',0,''),(41203,13065,'118615','printshop-mobile','text-align','left',0,''),(41204,13065,'118615','printshop-mobile','border-top-color','#e0e0e0',0,''),(41205,13065,'118615','printshop-mobile','border-top-width','1',0,''),(41206,13066,'118616','printshop-mobile','block_type','6',0,''),(41207,13067,'118617','printshop-mobile','padding-right','20',0,''),(41208,13068,'118618','printshop-mobile','clear','none',0,''),(41209,13070,'118620','printshop-mobile','block_type','4',0,''),(41210,13071,'118621','printshop-mobile','block_type','2',0,''),(41211,13072,'118622','printshop-mobile','margin-bottom','7',0,''),(41212,13073,'118623','printshop-mobile','clear','none',0,''),(41213,13074,'118624','printshop-mobile','margin-bottom','20',0,''),(41214,13074,'118624','printshop-mobile','text-align','right',0,''),(41215,13075,'118625','printshop-mobile','description_characters','200',0,''),(41216,13075,'118625','printshop-mobile','clear','none',0,''),(41217,13075,'118625','printshop-mobile','padding-right','20',0,''),(41218,13076,'118626','printshop-mobile','block_type','2',0,''),(41219,13077,'118627','printshop-mobile','clear','none',0,''),(41220,13079,'118629','printshop-mobile','padding-right','20',0,''),(41221,13080,'118630','printshop-mobile','block_type','1',0,''),(41222,13080,'118630','printshop-mobile','style_class','item-holder',0,''),(41223,13080,'118630','printshop-mobile','padding-top','25',0,''),(41224,13080,'118630','printshop-mobile','padding-left','25',0,''),(41225,13080,'118630','printshop-mobile','padding-right','25',0,''),(41226,13080,'118630','printshop-mobile','padding-bottom','25',0,''),(41227,13080,'118630','printshop-mobile','text-align','left',0,''),(41228,13082,'118632','printshop-mobile','margin-bottom','7',0,''),(41229,13083,'118633','printshop-mobile','clear','both',0,''),(41230,13086,'118636','printshop-mobile','block_type','1',0,''),(41231,13086,'118636','printshop-mobile','style_class','item-holder',0,''),(41232,13086,'118636','printshop-mobile','padding-top','25',0,''),(41233,13086,'118636','printshop-mobile','padding-left','25',0,''),(41234,13086,'118636','printshop-mobile','padding-right','25',0,''),(41235,13086,'118636','printshop-mobile','padding-bottom','25',0,''),(41236,13086,'118636','printshop-mobile','text-align','left',0,''),(41237,13087,'118637','printshop-mobile','block_type','5',0,''),(41238,13090,'118640','printshop-mobile','margin-bottom','7',0,''),(41239,13091,'118641','printshop-mobile','clear','both',0,''),(41240,13092,'118642','printshop-mobile','block_type','1',0,''),(41241,13093,'118643','printshop-mobile','block_type','6',0,''),(41242,13093,'118643','printshop-mobile','font-weight','400',0,''),(41243,13093,'118643','printshop-mobile','schema','6-2',0,''),(41245,13094,'118644','printshop-mobile','font-weight','400',0,''),(41246,13094,'118644','printshop-mobile','padding-right','40',0,''),(41249,13095,'118645','printshop-mobile','block_type','5',0,''),(41250,13095,'118645','printshop-mobile','padding-top','10',0,''),(41251,13095,'118645','printshop-mobile','padding-bottom','10',0,''),(41252,13095,'118645','printshop-mobile','schema','5-2',0,''),(41253,13095,'118645','printshop-mobile','border-top-color','#e0e0e0',0,''),(41254,13095,'118645','printshop-mobile','border-top-width','1',0,''),(41255,13097,'118647','printshop-mobile','float','right',0,''),(41256,13099,'118649','printshop-mobile','col_in_row','3',0,''),(41257,13099,'118649','printshop-mobile','products_align','left',0,''),(41258,13099,'118649','printshop-mobile','font-weight','400',0,''),(41259,13099,'118649','printshop-mobile','show_qty_input','0',0,''),(41260,13099,'118649','printshop-mobile','listing_type','productListing',0,''),(41261,13099,'118649','printshop-mobile','listing_type_rows','no',0,''),(41262,13099,'118649','printshop-mobile','show_buy_button_b2b','on',0,''),(41263,13099,'118649','printshop-mobile','show_wishlist_button_b2b','1',0,''),(41264,13099,'118649','printshop-mobile','show_compare_b2b','1',0,''),(41265,13099,'118649','printshop-mobile','show_stock','0',0,''),(41266,13099,'118649','printshop-mobile','show_description','0',0,''),(41267,13099,'118649','printshop-mobile','show_model','0',0,''),(41268,13099,'118649','printshop-mobile','show_properties','0',0,''),(41269,13099,'118649','printshop-mobile','show_rating','0',0,''),(41270,13099,'118649','printshop-mobile','show_rating_counts','0',0,''),(41271,13099,'118649','printshop-mobile','show_price','0',0,''),(41272,13099,'118649','printshop-mobile','show_buy_button','0',0,''),(41273,13099,'118649','printshop-mobile','show_view_button','0',0,''),(41274,13099,'118649','printshop-mobile','show_wishlist_button','0',0,''),(41275,13099,'118649','printshop-mobile','show_compare','0',0,''),(41276,13099,'118649','printshop-mobile','show_name_rows','0',0,''),(41277,13099,'118649','printshop-mobile','show_image_rows','0',0,''),(41278,13099,'118649','printshop-mobile','show_stock_rows','0',0,''),(41279,13099,'118649','printshop-mobile','show_description_rows','0',0,''),(41280,13099,'118649','printshop-mobile','show_model_rows','0',0,''),(41281,13099,'118649','printshop-mobile','show_properties_rows','0',0,''),(41282,13099,'118649','printshop-mobile','show_rating_rows','0',0,''),(41283,13099,'118649','printshop-mobile','show_rating_counts_rows','0',0,''),(41284,13099,'118649','printshop-mobile','show_price_rows','0',0,''),(41285,13099,'118649','printshop-mobile','show_buy_button_rows','0',0,''),(41286,13099,'118649','printshop-mobile','show_qty_input_rows','0',0,''),(41287,13099,'118649','printshop-mobile','show_view_button_rows','0',0,''),(41288,13099,'118649','printshop-mobile','show_wishlist_button_rows','0',0,''),(41289,13099,'118649','printshop-mobile','show_compare_rows','0',0,''),(41290,13099,'118649','printshop-mobile','show_name_b2b','0',0,''),(41291,13099,'118649','printshop-mobile','show_image_b2b','0',0,''),(41292,13099,'118649','printshop-mobile','show_stock_b2b','0',0,''),(41293,13099,'118649','printshop-mobile','show_description_b2b','0',0,''),(41294,13099,'118649','printshop-mobile','show_model_b2b','0',0,''),(41295,13099,'118649','printshop-mobile','show_properties_b2b','0',0,''),(41296,13099,'118649','printshop-mobile','show_rating_b2b','0',0,''),(41297,13099,'118649','printshop-mobile','show_rating_counts_b2b','0',0,''),(41298,13099,'118649','printshop-mobile','show_price_b2b','0',0,''),(41299,13099,'118649','printshop-mobile','show_qty_input_b2b','0',0,''),(41300,13099,'118649','printshop-mobile','show_view_button_b2b','0',0,''),(41301,13099,'118649','printshop-mobile','show_attributes_b2b','0',0,''),(41302,13099,'118649','printshop-mobile','items_on_page','9',0,''),(41305,13099,'118649','printshop-mobile','product_names_teg','h2',0,''),(41306,13100,'118650','printshop-mobile','listing_type','productListing',0,''),(41307,13101,'118651','printshop-mobile','block_type','1',0,''),(41308,13101,'118651','printshop-mobile','padding-top','10',0,''),(41309,13101,'118651','printshop-mobile','padding-bottom','10',0,''),(41310,13101,'118651','printshop-mobile','border-bottom-width','1',0,''),(41311,13101,'118651','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(41312,13101,'118651','printshop-mobile','margin-left','0',0,''),(41313,13101,'118651','printshop-mobile','margin-right','0',0,''),(41314,13102,'118652','printshop-mobile','float','right',0,''),(41315,13102,'118652','printshop-mobile','display','none',0,''),(41316,13103,'118653','printshop-mobile','margin-right','20',0,''),(41317,13103,'118653','printshop-mobile','float','right',0,''),(41318,13103,'118653','printshop-mobile','clear','none',0,''),(41319,13103,'118653','printshop-mobile','display','none',0,''),(41320,13104,'118654','printshop-mobile','float','left',0,''),(41321,13104,'118654','printshop-mobile','clear','none',0,''),(41322,13104,'118654','printshop-mobile','margin-left','20',0,''),(41323,13104,'118654','printshop-mobile','display','none',0,''),(41324,13105,'118655','printshop-mobile','float','left',0,''),(41325,13105,'118655','printshop-mobile','clear','none',0,''),(41326,13105,'118655','printshop-mobile','sort_pos_3','1',0,''),(41327,13105,'118655','printshop-mobile','sort_pos_4','2',0,''),(41328,13105,'118655','printshop-mobile','sort_pos_10','3',0,''),(41329,13105,'118655','printshop-mobile','sort_pos_9','4',0,''),(41330,13105,'118655','printshop-mobile','sort_pos_11','5',0,''),(41331,13105,'118655','printshop-mobile','sort_pos_12','6',0,''),(41332,13105,'118655','printshop-mobile','sort_pos_14','7',0,''),(41333,13105,'118655','printshop-mobile','sort_pos_13','8',0,''),(41334,13105,'118655','printshop-mobile','sort_pos_8','9',0,''),(41335,13105,'118655','printshop-mobile','sort_pos_7','10',0,''),(41336,13105,'118655','printshop-mobile','sort_pos_2','11',0,''),(41337,13105,'118655','printshop-mobile','sort_pos_1','12',0,''),(41338,13105,'118655','printshop-mobile','sort_pos_6','13',0,''),(41339,13105,'118655','printshop-mobile','sort_pos_5','14',0,''),(41340,13105,'118655','printshop-mobile','sort_pos_0','15',0,''),(41341,13105,'118655','printshop-mobile','sort_hide_10','1',0,''),(41342,13105,'118655','printshop-mobile','sort_hide_9','1',0,''),(41343,13105,'118655','printshop-mobile','hide_icons','1',0,''),(41344,13105,'118655','printshop-mobile','sort_hide_16','1',0,''),(41345,13105,'118655','printshop-mobile','sort_hide_15','1',0,''),(41346,13105,'118655','printshop-mobile','sort_hide_3','0',0,''),(41347,13105,'118655','printshop-mobile','sort_hide_4','0',0,''),(41348,13105,'118655','printshop-mobile','sort_hide_11','1',0,''),(41349,13105,'118655','printshop-mobile','sort_hide_12','1',0,''),(41350,13105,'118655','printshop-mobile','sort_hide_14','1',0,''),(41351,13105,'118655','printshop-mobile','sort_hide_13','1',0,''),(41352,13105,'118655','printshop-mobile','sort_hide_8','0',0,''),(41353,13105,'118655','printshop-mobile','sort_hide_7','0',0,''),(41354,13105,'118655','printshop-mobile','sort_hide_2','1',0,''),(41355,13105,'118655','printshop-mobile','sort_hide_1','1',0,''),(41356,13105,'118655','printshop-mobile','sort_hide_6','1',0,''),(41357,13105,'118655','printshop-mobile','sort_hide_5','1',0,''),(41358,13105,'118655','printshop-mobile','sort_hide_0','1',0,''),(41359,13108,'118658','printshop-mobile','block_type','1',0,''),(41360,13109,'118659','printshop-mobile','block_type','7',0,''),(41361,13109,'118659','printshop-mobile','schema','7-2',0,'720'),(41362,13110,'118660','printshop-mobile','padding-top','20',0,''),(41363,13110,'118660','printshop-mobile','padding-right','20',0,''),(41364,13111,'118661','printshop-mobile','blog_sidebar','1',0,''),(41365,13111,'118661','printshop-mobile','padding-top','20',0,''),(41366,13111,'118661','printshop-mobile','padding-left','20',0,''),(41367,13112,'118662','printshop-mobile','block_type','1',0,''),(41368,13113,'118663','printshop-mobile','item_tag','h2',0,''),(41369,13113,'118663','printshop-mobile','hTagsInline','inline',0,''),(41370,13117,'118667','printshop-mobile','block_type','1',0,''),(41371,13117,'118667','printshop-mobile','schema','4-1',0,''),(41373,13117,'118667','printshop-mobile','schema','4-1',0,'702'),(41374,13118,'118668','printshop-mobile','block_type','1',0,''),(41375,13118,'118668','printshop-mobile','background-color','#ffffff',0,''),(41376,13118,'118668','printshop-mobile','padding-top','20',0,''),(41377,13118,'118668','printshop-mobile','padding-bottom','20',0,''),(41378,13118,'118668','printshop-mobile','margin-bottom','30',0,''),(41379,13119,'118669','printshop-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(41380,13119,'118669','printshop-mobile','style_class','bell-ico',0,''),(41381,13120,'118670','printshop-mobile','col_in_row','3',0,''),(41382,13120,'118670','printshop-mobile','show_description','1',0,''),(41383,13120,'118670','printshop-mobile','show_model','1',0,''),(41384,13120,'118670','printshop-mobile','show_properties','1',0,''),(41385,13120,'118670','printshop-mobile','show_rating','1',0,''),(41386,13120,'118670','printshop-mobile','show_rating_counts','1',0,''),(41387,13120,'118670','printshop-mobile','show_qty_input','1',0,''),(41388,13120,'118670','printshop-mobile','show_view_button','1',0,''),(41389,13120,'118670','printshop-mobile','show_wishlist_button','1',0,''),(41390,13120,'118670','printshop-mobile','show_compare','1',0,''),(41391,13120,'118670','printshop-mobile','view_as','carousel',0,''),(41392,13120,'118670','printshop-mobile','hide_parents','2',0,''),(41393,13121,'118671','printshop-mobile','block_type','1',0,''),(41394,13121,'118671','printshop-mobile','background-color','#ffffff',0,''),(41395,13121,'118671','printshop-mobile','margin-bottom','30',0,''),(41396,13122,'118672','printshop-mobile','padding-top','20',0,''),(41397,13122,'118672','printshop-mobile','padding-bottom','20',0,''),(41398,13123,'118673','printshop-mobile','block_type','2',0,''),(41399,13123,'118673','printshop-mobile','padding-bottom','20',0,''),(41400,13123,'118673','printshop-mobile','padding-top','20',0,''),(41401,13123,'118673','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(41402,13123,'118673','printshop-mobile','border-bottom-width','1',0,''),(41403,13123,'118673','printshop-mobile','schema','2-2',0,''),(41404,13124,'118674','printshop-mobile','padding-top','22',0,''),(41405,13125,'118675','printshop-mobile','float','right',0,''),(41406,13125,'118675','printshop-mobile','padding-top','26',0,''),(41407,13126,'118676','printshop-mobile','float','left',0,''),(41408,13127,'118677','printshop-mobile','block_type','1',0,''),(41409,13127,'118677','printshop-mobile','padding-top','20',0,''),(41410,13127,'118677','printshop-mobile','padding-bottom','20',0,''),(41411,13127,'118677','printshop-mobile','background-color','#ffffff',0,''),(41412,13127,'118677','printshop-mobile','margin-bottom','30',0,''),(41413,13128,'118678','printshop-mobile','hide_parents','2',0,''),(41414,13129,'118679','printshop-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(41415,13130,'118680','printshop-mobile','block_type','1',0,''),(41416,13130,'118680','printshop-mobile','background-color','#ffffff',0,''),(41417,13130,'118680','printshop-mobile','padding-top','20',0,''),(41418,13130,'118680','printshop-mobile','padding-bottom','20',0,''),(41419,13130,'118680','printshop-mobile','margin-bottom','30',0,''),(41420,13130,'118680','printshop-mobile','style_class','closeable-box',0,''),(41421,13131,'118681','printshop-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(41422,13131,'118681','printshop-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(41423,13132,'118682','printshop-mobile','block_type','1',0,''),(41424,13132,'118682','printshop-mobile','font-weight','400',0,''),(41425,13132,'118682','printshop-mobile','schema','2-2',0,''),(41426,13132,'118682','printshop-mobile','style_class','closeable-content',0,''),(41427,13132,'118682','printshop-mobile','padding-top','10',0,''),(41428,13133,'118683','printshop-mobile','font-weight','400',0,''),(41429,13133,'118683','printshop-mobile','padding-top','12',0,''),(41430,13133,'118683','printshop-mobile','padding-left','0',0,''),(41431,13136,'118686','printshop-mobile','block_type','1',0,''),(41432,13136,'118686','printshop-mobile','background-color','#ffffff',0,''),(41433,13136,'118686','printshop-mobile','padding-top','20',0,''),(41434,13136,'118686','printshop-mobile','padding-left','25',0,''),(41435,13136,'118686','printshop-mobile','padding-right','25',0,''),(41436,13136,'118686','printshop-mobile','padding-bottom','20',0,''),(41437,13136,'118686','printshop-mobile','margin-bottom','30',0,''),(41438,13136,'118686','printshop-mobile','style_class','closeable-box',0,''),(41439,13136,'118686','printshop-mobile','display','none',0,''),(41441,13137,'118687','printshop-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(41442,13137,'118687','printshop-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(41443,13138,'118688','printshop-mobile','font-weight','normal',0,''),(41444,13138,'118688','printshop-mobile','style_class','closeable-content',0,''),(41445,13138,'118688','printshop-mobile','padding-top','10',0,''),(41446,13138,'118688','printshop-mobile','hide_parents','2',0,''),(41447,13139,'118689','printshop-mobile','style_class','order-summary',0,''),(41448,13139,'118689','printshop-mobile','block_type','1',0,''),(41449,13139,'118689','printshop-mobile','margin-left','30',0,''),(41451,13139,'118689','printshop-mobile','margin-bottom','30',0,''),(41452,13140,'118690','printshop-mobile','block_type','1',0,''),(41453,13140,'118690','printshop-mobile','padding-bottom','20',0,''),(41454,13141,'118691','printshop-mobile','font-weight','400',0,''),(41455,13141,'118691','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',1,''),(41456,13141,'118691','printshop-mobile','padding-top','20',0,''),(41457,13141,'118691','printshop-mobile','padding-bottom','10',0,''),(41458,13142,'118692','printshop-mobile','font-weight','400',0,''),(41459,13142,'118692','printshop-mobile','box_align','4',0,''),(41460,13142,'118692','printshop-mobile','text-align','center',0,''),(41461,13142,'118692','printshop-mobile','float','none',0,''),(41462,13142,'118692','printshop-mobile','width','100',0,''),(41463,13142,'118692','printshop-mobile','width_measure','%',0,''),(41464,13144,'118694','printshop-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(41465,13145,'118695','printshop-mobile','block_type','1',0,''),(41466,13145,'118695','printshop-mobile','font-weight','normal',0,''),(41467,13145,'118695','printshop-mobile','padding-top','20',0,''),(41468,13145,'118695','printshop-mobile','background-color','#eeeeee',0,''),(41469,13147,'118697','printshop-mobile','block_type','4',0,''),(41470,13147,'118697','printshop-mobile','schema','4-1',0,''),(41472,13148,'118698','printshop-mobile','block_type','1',0,''),(41473,13148,'118698','printshop-mobile','background-color','#ffffff',0,''),(41474,13148,'118698','printshop-mobile','padding-top','20',0,''),(41475,13148,'118698','printshop-mobile','padding-bottom','20',0,''),(41476,13148,'118698','printshop-mobile','padding-left','25',0,''),(41477,13148,'118698','printshop-mobile','padding-right','25',0,''),(41478,13148,'118698','printshop-mobile','margin-bottom','30',0,''),(41479,13149,'118699','printshop-mobile','col_in_row','3',0,''),(41480,13149,'118699','printshop-mobile','show_description','1',0,''),(41481,13149,'118699','printshop-mobile','show_model','1',0,''),(41482,13149,'118699','printshop-mobile','show_properties','1',0,''),(41483,13149,'118699','printshop-mobile','show_rating','1',0,''),(41484,13149,'118699','printshop-mobile','show_rating_counts','1',0,''),(41485,13149,'118699','printshop-mobile','show_qty_input','1',0,''),(41486,13149,'118699','printshop-mobile','show_view_button','1',0,''),(41487,13149,'118699','printshop-mobile','show_wishlist_button','1',0,''),(41488,13149,'118699','printshop-mobile','show_compare','1',0,''),(41489,13149,'118699','printshop-mobile','view_as','carousel',0,''),(41490,13149,'118699','printshop-mobile','hide_parents','2',0,''),(41491,13150,'118700','printshop-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(41492,13150,'118700','printshop-mobile','style_class','bell-ico',0,''),(41493,13151,'118701','printshop-mobile','block_type','1',0,''),(41494,13151,'118701','printshop-mobile','background-color','#ffffff',0,''),(41495,13151,'118701','printshop-mobile','margin-bottom','30',0,''),(41496,13152,'118702','printshop-mobile','padding-top','20',0,''),(41497,13152,'118702','printshop-mobile','padding-left','25',0,''),(41498,13152,'118702','printshop-mobile','padding-right','25',0,''),(41499,13152,'118702','printshop-mobile','padding-bottom','20',0,''),(41500,13153,'118703','printshop-mobile','block_type','2',0,''),(41501,13153,'118703','printshop-mobile','padding-bottom','20',0,''),(41502,13153,'118703','printshop-mobile','padding-top','20',0,''),(41503,13153,'118703','printshop-mobile','padding-left','25',0,''),(41504,13153,'118703','printshop-mobile','padding-right','25',0,''),(41505,13153,'118703','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(41506,13153,'118703','printshop-mobile','border-bottom-width','1',0,''),(41507,13153,'118703','printshop-mobile','schema','2-2',0,''),(41508,13154,'118704','printshop-mobile','float','left',0,''),(41509,13155,'118705','printshop-mobile','text-align','right',0,''),(41510,13155,'118705','printshop-mobile','clear','none',0,''),(41511,13155,'118705','printshop-mobile','float','right',0,''),(41512,13155,'118705','printshop-mobile','padding-top','22',0,''),(41513,13156,'118706','printshop-mobile','float','right',0,''),(41514,13156,'118706','printshop-mobile','padding-top','26',0,''),(41515,13157,'118707','printshop-mobile','block_type','1',0,''),(41516,13157,'118707','printshop-mobile','padding-top','20',0,''),(41517,13157,'118707','printshop-mobile','padding-bottom','20',0,''),(41518,13157,'118707','printshop-mobile','padding-left','25',0,''),(41519,13157,'118707','printshop-mobile','padding-right','25',0,''),(41520,13157,'118707','printshop-mobile','background-color','#ffffff',0,''),(41521,13157,'118707','printshop-mobile','margin-bottom','30',0,''),(41522,13158,'118708','printshop-mobile','hide_parents','2',0,''),(41523,13159,'118709','printshop-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(41524,13160,'118710','printshop-mobile','block_type','1',0,''),(41525,13160,'118710','printshop-mobile','background-color','#ffffff',0,''),(41526,13160,'118710','printshop-mobile','padding-top','20',0,''),(41527,13160,'118710','printshop-mobile','padding-bottom','20',0,''),(41528,13160,'118710','printshop-mobile','padding-left','25',0,''),(41529,13160,'118710','printshop-mobile','padding-right','25',0,''),(41530,13160,'118710','printshop-mobile','margin-bottom','30',0,''),(41531,13160,'118710','printshop-mobile','style_class','closeable-box',0,''),(41532,13161,'118711','printshop-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(41533,13161,'118711','printshop-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(41534,13162,'118712','printshop-mobile','block_type','3',0,''),(41535,13162,'118712','printshop-mobile','font-weight','400',0,''),(41536,13162,'118712','printshop-mobile','schema','2-2',0,''),(41537,13162,'118712','printshop-mobile','style_class','closeable-content',0,''),(41538,13162,'118712','printshop-mobile','padding-top','10',0,''),(41539,13163,'118713','printshop-mobile','font-weight','400',0,''),(41540,13163,'118713','printshop-mobile','padding-top','12',0,''),(41541,13163,'118713','printshop-mobile','padding-left','0',0,''),(41542,13166,'118716','printshop-mobile','block_type','1',0,''),(41543,13166,'118716','printshop-mobile','background-color','#ffffff',0,''),(41544,13166,'118716','printshop-mobile','padding-top','20',0,''),(41545,13166,'118716','printshop-mobile','padding-left','25',0,''),(41546,13166,'118716','printshop-mobile','padding-right','25',0,''),(41547,13166,'118716','printshop-mobile','padding-bottom','20',0,''),(41548,13166,'118716','printshop-mobile','margin-bottom','30',0,''),(41549,13166,'118716','printshop-mobile','style_class','closeable-box',0,''),(41550,13166,'118716','printshop-mobile','display','none',0,''),(41552,13167,'118717','printshop-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(41553,13167,'118717','printshop-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(41554,13168,'118718','printshop-mobile','font-weight','normal',0,''),(41555,13168,'118718','printshop-mobile','style_class','closeable-content',0,''),(41556,13168,'118718','printshop-mobile','padding-top','10',0,''),(41557,13168,'118718','printshop-mobile','hide_parents','2',0,''),(41558,13169,'118719','printshop-mobile','style_class','order-summary',0,''),(41559,13169,'118719','printshop-mobile','block_type','1',0,''),(41560,13169,'118719','printshop-mobile','margin-left','30',0,''),(41562,13169,'118719','printshop-mobile','margin-bottom','30',0,''),(41563,13170,'118720','printshop-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(41564,13171,'118721','printshop-mobile','block_type','1',0,''),(41565,13171,'118721','printshop-mobile','padding-left','20',0,''),(41566,13171,'118721','printshop-mobile','padding-right','20',0,''),(41567,13171,'118721','printshop-mobile','padding-bottom','20',0,''),(41568,13172,'118722','printshop-mobile','font-weight','400',0,''),(41569,13172,'118722','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',1,''),(41570,13172,'118722','printshop-mobile','padding-top','20',0,''),(41571,13172,'118722','printshop-mobile','padding-bottom','10',0,''),(41572,13173,'118723','printshop-mobile','font-weight','400',0,''),(41573,13173,'118723','printshop-mobile','box_align','4',0,''),(41574,13173,'118723','printshop-mobile','text-align','center',0,''),(41575,13173,'118723','printshop-mobile','float','none',0,''),(41576,13173,'118723','printshop-mobile','width','100',0,''),(41577,13173,'118723','printshop-mobile','width_measure','%',0,''),(41578,13175,'118725','printshop-mobile','block_type','1',0,''),(41579,13178,'118728','printshop-mobile','block_type','1',0,''),(41580,13179,'118729','printshop-mobile','col_in_row','2',0,''),(41581,13179,'118729','printshop-mobile','products_align','left',0,''),(41582,13179,'118729','printshop-mobile','font-weight','400',0,''),(41583,13179,'118729','printshop-mobile','show_qty_input','1',0,''),(41584,13179,'118729','printshop-mobile','listing_type','productListing',0,''),(41585,13179,'118729','printshop-mobile','listing_type_rows','type-1_2',0,''),(41586,13179,'118729','printshop-mobile','show_buy_button_b2b','on',0,''),(41587,13179,'118729','printshop-mobile','show_wishlist_button_b2b','1',0,''),(41588,13179,'118729','printshop-mobile','show_compare_b2b','1',0,''),(41589,13179,'118729','printshop-mobile','listing_type_b2b','type-1_3',0,''),(41590,13179,'118729','printshop-mobile','show_name','0',0,''),(41591,13179,'118729','printshop-mobile','show_image','0',0,''),(41592,13179,'118729','printshop-mobile','show_stock','0',0,''),(41593,13179,'118729','printshop-mobile','show_description','1',0,''),(41594,13179,'118729','printshop-mobile','show_model','1',0,''),(41595,13179,'118729','printshop-mobile','show_properties','1',0,''),(41596,13179,'118729','printshop-mobile','show_rating_counts','1',0,''),(41597,13179,'118729','printshop-mobile','show_price','0',0,''),(41598,13179,'118729','printshop-mobile','show_buy_button','1',0,''),(41599,13179,'118729','printshop-mobile','show_view_button','1',0,''),(41600,13179,'118729','printshop-mobile','show_wishlist_button','1',0,''),(41601,13179,'118729','printshop-mobile','show_compare','1',0,''),(41602,13179,'118729','printshop-mobile','show_name_rows','0',0,''),(41603,13179,'118729','printshop-mobile','show_image_rows','0',0,''),(41604,13179,'118729','printshop-mobile','show_stock_rows','0',0,''),(41605,13179,'118729','printshop-mobile','show_description_rows','0',0,''),(41606,13179,'118729','printshop-mobile','show_model_rows','0',0,''),(41607,13179,'118729','printshop-mobile','show_properties_rows','0',0,''),(41608,13179,'118729','printshop-mobile','show_rating_rows','0',0,''),(41609,13179,'118729','printshop-mobile','show_rating_counts_rows','0',0,''),(41610,13179,'118729','printshop-mobile','show_price_rows','0',0,''),(41611,13179,'118729','printshop-mobile','show_buy_button_rows','0',0,''),(41612,13179,'118729','printshop-mobile','show_qty_input_rows','0',0,''),(41613,13179,'118729','printshop-mobile','show_view_button_rows','0',0,''),(41614,13179,'118729','printshop-mobile','show_wishlist_button_rows','0',0,''),(41615,13179,'118729','printshop-mobile','show_compare_rows','0',0,''),(41616,13179,'118729','printshop-mobile','show_name_b2b','0',0,''),(41617,13179,'118729','printshop-mobile','show_image_b2b','0',0,''),(41618,13179,'118729','printshop-mobile','show_stock_b2b','0',0,''),(41619,13179,'118729','printshop-mobile','show_description_b2b','0',0,''),(41620,13179,'118729','printshop-mobile','show_model_b2b','0',0,''),(41621,13179,'118729','printshop-mobile','show_properties_b2b','0',0,''),(41622,13179,'118729','printshop-mobile','show_rating_b2b','0',0,''),(41623,13179,'118729','printshop-mobile','show_rating_counts_b2b','0',0,''),(41624,13179,'118729','printshop-mobile','show_price_b2b','0',0,''),(41625,13179,'118729','printshop-mobile','show_qty_input_b2b','0',0,''),(41626,13179,'118729','printshop-mobile','show_view_button_b2b','0',0,''),(41627,13179,'118729','printshop-mobile','show_attributes_b2b','0',0,''),(41628,13179,'118729','printshop-mobile','items_on_page','10',0,''),(41629,13179,'118729','printshop-mobile','product_names_teg','h2',0,''),(41630,13180,'118730','printshop-mobile','block_type','2',0,''),(41631,13180,'118730','printshop-mobile','margin-bottom','20',0,''),(41632,13181,'118731','printshop-mobile','sort_pos_3','1',0,''),(41633,13181,'118731','printshop-mobile','sort_pos_4','2',0,''),(41634,13181,'118731','printshop-mobile','sort_pos_10','5',0,''),(41635,13181,'118731','printshop-mobile','sort_pos_9','6',0,''),(41636,13181,'118731','printshop-mobile','sort_pos_11','7',0,''),(41637,13181,'118731','printshop-mobile','sort_pos_12','8',0,''),(41638,13181,'118731','printshop-mobile','sort_pos_14','9',0,''),(41639,13181,'118731','printshop-mobile','sort_pos_13','10',0,''),(41640,13181,'118731','printshop-mobile','sort_pos_8','11',0,''),(41641,13181,'118731','printshop-mobile','sort_pos_7','12',0,''),(41642,13181,'118731','printshop-mobile','sort_pos_2','13',0,''),(41643,13181,'118731','printshop-mobile','sort_pos_1','14',0,''),(41644,13181,'118731','printshop-mobile','sort_pos_6','15',0,''),(41645,13181,'118731','printshop-mobile','sort_pos_5','16',0,''),(41646,13181,'118731','printshop-mobile','sort_pos_0','17',0,''),(41647,13181,'118731','printshop-mobile','sort_hide_10','1',0,''),(41648,13181,'118731','printshop-mobile','sort_hide_9','1',0,''),(41649,13181,'118731','printshop-mobile','sort_pos_15','4',0,''),(41650,13181,'118731','printshop-mobile','sort_pos_16','3',0,''),(41651,13181,'118731','printshop-mobile','sort_hide_3','0',0,''),(41652,13181,'118731','printshop-mobile','sort_hide_4','0',0,''),(41653,13181,'118731','printshop-mobile','sort_hide_16','1',0,''),(41654,13181,'118731','printshop-mobile','sort_hide_15','1',0,''),(41655,13181,'118731','printshop-mobile','sort_hide_11','0',0,''),(41656,13181,'118731','printshop-mobile','sort_hide_12','0',0,''),(41657,13181,'118731','printshop-mobile','sort_hide_14','0',0,''),(41658,13181,'118731','printshop-mobile','sort_hide_13','0',0,''),(41659,13181,'118731','printshop-mobile','sort_hide_8','0',0,''),(41660,13181,'118731','printshop-mobile','sort_hide_7','0',0,''),(41661,13181,'118731','printshop-mobile','sort_hide_2','0',0,''),(41662,13181,'118731','printshop-mobile','sort_hide_1','0',0,''),(41663,13181,'118731','printshop-mobile','sort_hide_6','0',0,''),(41664,13181,'118731','printshop-mobile','sort_hide_5','0',0,''),(41665,13181,'118731','printshop-mobile','sort_hide_0','0',0,''),(41666,13182,'118732','printshop-mobile','text-align','right',0,''),(41667,13182,'118732','printshop-mobile','padding-top','10',0,''),(41668,13183,'118733','printshop-mobile','text-align','center',0,''),(41669,13183,'118733','printshop-mobile','margin-bottom','20',0,''),(41670,13189,'118739','printshop-mobile','block_type','1',0,''),(41671,13191,'118741','printshop-mobile','block_type','6',0,''),(41672,13191,'118741','printshop-mobile','font-weight','400',0,''),(41673,13191,'118741','printshop-mobile','schema','6-2',0,''),(41675,13192,'118742','printshop-mobile','font-weight','400',0,''),(41676,13192,'118742','printshop-mobile','padding-right','40',0,''),(41679,13194,'118744','printshop-mobile','col_in_row','3',0,''),(41680,13194,'118744','printshop-mobile','products_align','left',0,''),(41681,13194,'118744','printshop-mobile','font-weight','400',0,''),(41682,13194,'118744','printshop-mobile','show_qty_input','0',0,''),(41683,13194,'118744','printshop-mobile','listing_type','productListing',0,''),(41684,13194,'118744','printshop-mobile','listing_type_rows','no',0,''),(41685,13194,'118744','printshop-mobile','show_buy_button_b2b','on',0,''),(41686,13194,'118744','printshop-mobile','show_wishlist_button_b2b','1',0,''),(41687,13194,'118744','printshop-mobile','show_compare_b2b','1',0,''),(41688,13194,'118744','printshop-mobile','show_stock','0',0,''),(41689,13194,'118744','printshop-mobile','show_description','0',0,''),(41690,13194,'118744','printshop-mobile','show_model','0',0,''),(41691,13194,'118744','printshop-mobile','show_properties','0',0,''),(41692,13194,'118744','printshop-mobile','show_rating','0',0,''),(41693,13194,'118744','printshop-mobile','show_rating_counts','0',0,''),(41694,13194,'118744','printshop-mobile','show_price','0',0,''),(41695,13194,'118744','printshop-mobile','show_buy_button','0',0,''),(41696,13194,'118744','printshop-mobile','show_view_button','0',0,''),(41697,13194,'118744','printshop-mobile','show_wishlist_button','0',0,''),(41698,13194,'118744','printshop-mobile','show_compare','0',0,''),(41699,13194,'118744','printshop-mobile','show_name_rows','0',0,''),(41700,13194,'118744','printshop-mobile','show_image_rows','0',0,''),(41701,13194,'118744','printshop-mobile','show_stock_rows','0',0,''),(41702,13194,'118744','printshop-mobile','show_description_rows','0',0,''),(41703,13194,'118744','printshop-mobile','show_model_rows','0',0,''),(41704,13194,'118744','printshop-mobile','show_properties_rows','0',0,''),(41705,13194,'118744','printshop-mobile','show_rating_rows','0',0,''),(41706,13194,'118744','printshop-mobile','show_rating_counts_rows','0',0,''),(41707,13194,'118744','printshop-mobile','show_price_rows','0',0,''),(41708,13194,'118744','printshop-mobile','show_buy_button_rows','0',0,''),(41709,13194,'118744','printshop-mobile','show_qty_input_rows','0',0,''),(41710,13194,'118744','printshop-mobile','show_view_button_rows','0',0,''),(41711,13194,'118744','printshop-mobile','show_wishlist_button_rows','0',0,''),(41712,13194,'118744','printshop-mobile','show_compare_rows','0',0,''),(41713,13194,'118744','printshop-mobile','show_name_b2b','0',0,''),(41714,13194,'118744','printshop-mobile','show_image_b2b','0',0,''),(41715,13194,'118744','printshop-mobile','show_stock_b2b','0',0,''),(41716,13194,'118744','printshop-mobile','show_description_b2b','0',0,''),(41717,13194,'118744','printshop-mobile','show_model_b2b','0',0,''),(41718,13194,'118744','printshop-mobile','show_properties_b2b','0',0,''),(41719,13194,'118744','printshop-mobile','show_rating_b2b','0',0,''),(41720,13194,'118744','printshop-mobile','show_rating_counts_b2b','0',0,''),(41721,13194,'118744','printshop-mobile','show_price_b2b','0',0,''),(41722,13194,'118744','printshop-mobile','show_qty_input_b2b','0',0,''),(41723,13194,'118744','printshop-mobile','show_view_button_b2b','0',0,''),(41724,13194,'118744','printshop-mobile','show_attributes_b2b','0',0,''),(41725,13194,'118744','printshop-mobile','items_on_page','9',0,''),(41728,13194,'118744','printshop-mobile','product_names_teg','h2',0,''),(41729,13195,'118745','printshop-mobile','block_type','1',0,''),(41730,13195,'118745','printshop-mobile','padding-top','10',0,''),(41731,13195,'118745','printshop-mobile','padding-bottom','10',0,''),(41732,13195,'118745','printshop-mobile','border-bottom-width','1',0,''),(41733,13195,'118745','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(41734,13195,'118745','printshop-mobile','margin-left','0',0,''),(41735,13195,'118745','printshop-mobile','margin-right','0',0,''),(41736,13196,'118746','printshop-mobile','float','left',0,''),(41737,13196,'118746','printshop-mobile','clear','none',0,''),(41738,13196,'118746','printshop-mobile','sort_pos_3','1',0,''),(41739,13196,'118746','printshop-mobile','sort_pos_4','2',0,''),(41740,13196,'118746','printshop-mobile','sort_pos_10','3',0,''),(41741,13196,'118746','printshop-mobile','sort_pos_9','4',0,''),(41742,13196,'118746','printshop-mobile','sort_pos_11','5',0,''),(41743,13196,'118746','printshop-mobile','sort_pos_12','6',0,''),(41744,13196,'118746','printshop-mobile','sort_pos_14','7',0,''),(41745,13196,'118746','printshop-mobile','sort_pos_13','8',0,''),(41746,13196,'118746','printshop-mobile','sort_pos_8','9',0,''),(41747,13196,'118746','printshop-mobile','sort_pos_7','10',0,''),(41748,13196,'118746','printshop-mobile','sort_pos_2','11',0,''),(41749,13196,'118746','printshop-mobile','sort_pos_1','12',0,''),(41750,13196,'118746','printshop-mobile','sort_pos_6','13',0,''),(41751,13196,'118746','printshop-mobile','sort_pos_5','14',0,''),(41752,13196,'118746','printshop-mobile','sort_pos_0','15',0,''),(41753,13196,'118746','printshop-mobile','sort_hide_10','1',0,''),(41754,13196,'118746','printshop-mobile','sort_hide_9','1',0,''),(41755,13196,'118746','printshop-mobile','hide_icons','1',0,''),(41756,13196,'118746','printshop-mobile','sort_hide_16','1',0,''),(41757,13196,'118746','printshop-mobile','sort_hide_15','1',0,''),(41758,13196,'118746','printshop-mobile','sort_hide_3','0',0,''),(41759,13196,'118746','printshop-mobile','sort_hide_4','0',0,''),(41760,13196,'118746','printshop-mobile','sort_hide_11','1',0,''),(41761,13196,'118746','printshop-mobile','sort_hide_12','1',0,''),(41762,13196,'118746','printshop-mobile','sort_hide_14','1',0,''),(41763,13196,'118746','printshop-mobile','sort_hide_13','1',0,''),(41764,13196,'118746','printshop-mobile','sort_hide_8','0',0,''),(41765,13196,'118746','printshop-mobile','sort_hide_7','0',0,''),(41766,13196,'118746','printshop-mobile','sort_hide_2','1',0,''),(41767,13196,'118746','printshop-mobile','sort_hide_1','1',0,''),(41768,13196,'118746','printshop-mobile','sort_hide_6','1',0,''),(41769,13196,'118746','printshop-mobile','sort_hide_5','1',0,''),(41770,13196,'118746','printshop-mobile','sort_hide_0','1',0,''),(41771,13197,'118747','printshop-mobile','float','left',0,''),(41772,13197,'118747','printshop-mobile','clear','none',0,''),(41773,13197,'118747','printshop-mobile','margin-left','20',0,''),(41774,13197,'118747','printshop-mobile','display','none',0,''),(41775,13198,'118748','printshop-mobile','margin-right','20',0,''),(41776,13198,'118748','printshop-mobile','float','right',0,''),(41777,13198,'118748','printshop-mobile','clear','none',0,''),(41778,13198,'118748','printshop-mobile','display','none',0,''),(41779,13199,'118749','printshop-mobile','float','right',0,''),(41780,13199,'118749','printshop-mobile','display','none',0,''),(41781,13200,'118750','printshop-mobile','listing_type','productListing',0,''),(41782,13202,'118752','printshop-mobile','block_type','5',0,''),(41783,13202,'118752','printshop-mobile','padding-top','10',0,''),(41784,13202,'118752','printshop-mobile','padding-bottom','10',0,''),(41785,13202,'118752','printshop-mobile','schema','5-2',0,''),(41786,13202,'118752','printshop-mobile','border-top-color','#e0e0e0',0,''),(41787,13202,'118752','printshop-mobile','border-top-width','1',0,''),(41788,13204,'118754','printshop-mobile','float','right',0,''),(41789,13205,'118755','printshop-mobile','block_type','1',0,''),(41790,13207,'118757','printshop-mobile','block_type','5',0,''),(41791,13207,'118757','printshop-mobile','padding-top','10',0,''),(41792,13207,'118757','printshop-mobile','padding-bottom','10',0,''),(41793,13207,'118757','printshop-mobile','schema','5-2',0,''),(41794,13207,'118757','printshop-mobile','border-top-color','#e0e0e0',0,''),(41795,13207,'118757','printshop-mobile','border-top-width','1',0,''),(41796,13209,'118759','printshop-mobile','float','right',0,''),(41797,13210,'118760','printshop-mobile','col_in_row','4',0,''),(41798,13210,'118760','printshop-mobile','products_align','left',0,''),(41799,13210,'118760','printshop-mobile','font-weight','400',0,''),(41800,13210,'118760','printshop-mobile','show_qty_input','0',0,''),(41801,13210,'118760','printshop-mobile','listing_type','productListing',0,''),(41802,13210,'118760','printshop-mobile','listing_type_rows','Rows',0,''),(41803,13210,'118760','printshop-mobile','show_buy_button_b2b','on',0,''),(41804,13210,'118760','printshop-mobile','show_wishlist_button_b2b','1',0,''),(41805,13210,'118760','printshop-mobile','show_compare_b2b','1',0,''),(41806,13210,'118760','printshop-mobile','listing_type_b2b','b2b',0,''),(41807,13210,'118760','printshop-mobile','show_image','0',0,''),(41808,13210,'118760','printshop-mobile','show_stock','0',0,''),(41809,13210,'118760','printshop-mobile','show_description','0',0,''),(41810,13210,'118760','printshop-mobile','show_model','0',0,''),(41811,13210,'118760','printshop-mobile','show_properties','0',0,''),(41812,13210,'118760','printshop-mobile','show_rating','0',0,''),(41813,13210,'118760','printshop-mobile','show_rating_counts','0',0,''),(41814,13210,'118760','printshop-mobile','show_price','0',0,''),(41815,13210,'118760','printshop-mobile','show_buy_button','0',0,''),(41816,13210,'118760','printshop-mobile','show_view_button','0',0,''),(41817,13210,'118760','printshop-mobile','show_wishlist_button','0',0,''),(41818,13210,'118760','printshop-mobile','show_compare','0',0,''),(41819,13210,'118760','printshop-mobile','show_name_rows','0',0,''),(41820,13210,'118760','printshop-mobile','show_image_rows','0',0,''),(41821,13210,'118760','printshop-mobile','show_stock_rows','0',0,''),(41822,13210,'118760','printshop-mobile','show_description_rows','0',0,''),(41823,13210,'118760','printshop-mobile','show_model_rows','0',0,''),(41824,13210,'118760','printshop-mobile','show_properties_rows','0',0,''),(41825,13210,'118760','printshop-mobile','show_rating_rows','0',0,''),(41826,13210,'118760','printshop-mobile','show_rating_counts_rows','0',0,''),(41827,13210,'118760','printshop-mobile','show_price_rows','0',0,''),(41828,13210,'118760','printshop-mobile','show_buy_button_rows','0',0,''),(41829,13210,'118760','printshop-mobile','show_qty_input_rows','0',0,''),(41830,13210,'118760','printshop-mobile','show_view_button_rows','0',0,''),(41831,13210,'118760','printshop-mobile','show_wishlist_button_rows','0',0,''),(41832,13210,'118760','printshop-mobile','show_compare_rows','0',0,''),(41833,13210,'118760','printshop-mobile','show_name_b2b','0',0,''),(41834,13210,'118760','printshop-mobile','show_image_b2b','0',0,''),(41835,13210,'118760','printshop-mobile','show_stock_b2b','0',0,''),(41836,13210,'118760','printshop-mobile','show_description_b2b','0',0,''),(41837,13210,'118760','printshop-mobile','show_model_b2b','0',0,''),(41838,13210,'118760','printshop-mobile','show_properties_b2b','0',0,''),(41839,13210,'118760','printshop-mobile','show_rating_b2b','0',0,''),(41840,13210,'118760','printshop-mobile','show_rating_counts_b2b','0',0,''),(41841,13210,'118760','printshop-mobile','show_price_b2b','0',0,''),(41842,13210,'118760','printshop-mobile','show_qty_input_b2b','0',0,''),(41843,13210,'118760','printshop-mobile','show_view_button_b2b','0',0,''),(41844,13210,'118760','printshop-mobile','show_attributes_b2b','0',0,''),(41845,13210,'118760','printshop-mobile','items_on_page','12',0,''),(41848,13210,'118760','printshop-mobile','product_names_teg','h2',0,''),(41850,13212,'118762','printshop-mobile','block_type','1',0,''),(41851,13212,'118762','printshop-mobile','padding-top','10',0,''),(41852,13212,'118762','printshop-mobile','padding-bottom','10',0,''),(41853,13212,'118762','printshop-mobile','border-bottom-width','1',0,''),(41854,13212,'118762','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(41855,13212,'118762','printshop-mobile','margin-left','0',0,''),(41856,13212,'118762','printshop-mobile','margin-right','0',0,''),(41857,13213,'118763','printshop-mobile','float','right',0,''),(41858,13213,'118763','printshop-mobile','display','none',0,''),(41859,13214,'118764','printshop-mobile','margin-right','20',0,''),(41860,13214,'118764','printshop-mobile','float','right',0,''),(41861,13214,'118764','printshop-mobile','clear','none',0,''),(41862,13214,'118764','printshop-mobile','display','none',0,''),(41863,13215,'118765','printshop-mobile','clear','none',0,''),(41864,13215,'118765','printshop-mobile','float','left',0,''),(41865,13215,'118765','printshop-mobile','padding-top','3',0,''),(41866,13215,'118765','printshop-mobile','padding-left','20',0,''),(41867,13216,'118766','printshop-mobile','float','left',0,''),(41868,13216,'118766','printshop-mobile','clear','none',0,''),(41869,13216,'118766','printshop-mobile','margin-left','20',0,''),(41870,13216,'118766','printshop-mobile','display','none',0,''),(41871,13217,'118767','printshop-mobile','float','left',0,''),(41872,13217,'118767','printshop-mobile','clear','none',0,''),(41873,13217,'118767','printshop-mobile','sort_pos_3','1',0,''),(41874,13217,'118767','printshop-mobile','sort_pos_4','2',0,''),(41875,13217,'118767','printshop-mobile','sort_pos_10','3',0,''),(41876,13217,'118767','printshop-mobile','sort_pos_9','4',0,''),(41877,13217,'118767','printshop-mobile','sort_pos_11','5',0,''),(41878,13217,'118767','printshop-mobile','sort_pos_12','6',0,''),(41879,13217,'118767','printshop-mobile','sort_pos_14','7',0,''),(41880,13217,'118767','printshop-mobile','sort_pos_13','8',0,''),(41881,13217,'118767','printshop-mobile','sort_pos_8','9',0,''),(41882,13217,'118767','printshop-mobile','sort_pos_7','10',0,''),(41883,13217,'118767','printshop-mobile','sort_pos_2','11',0,''),(41884,13217,'118767','printshop-mobile','sort_pos_1','12',0,''),(41885,13217,'118767','printshop-mobile','sort_pos_6','13',0,''),(41886,13217,'118767','printshop-mobile','sort_pos_5','14',0,''),(41887,13217,'118767','printshop-mobile','sort_pos_0','15',0,''),(41888,13217,'118767','printshop-mobile','sort_hide_10','1',0,''),(41889,13217,'118767','printshop-mobile','sort_hide_9','1',0,''),(41890,13217,'118767','printshop-mobile','hide_icons','1',0,''),(41891,13217,'118767','printshop-mobile','sort_hide_16','1',0,''),(41892,13217,'118767','printshop-mobile','sort_hide_15','1',0,''),(41893,13217,'118767','printshop-mobile','sort_hide_3','0',0,''),(41894,13217,'118767','printshop-mobile','sort_hide_4','0',0,''),(41895,13217,'118767','printshop-mobile','sort_hide_11','1',0,''),(41896,13217,'118767','printshop-mobile','sort_hide_12','1',0,''),(41897,13217,'118767','printshop-mobile','sort_hide_14','1',0,''),(41898,13217,'118767','printshop-mobile','sort_hide_13','1',0,''),(41899,13217,'118767','printshop-mobile','sort_hide_8','0',0,''),(41900,13217,'118767','printshop-mobile','sort_hide_7','0',0,''),(41901,13217,'118767','printshop-mobile','sort_hide_2','1',0,''),(41902,13217,'118767','printshop-mobile','sort_hide_1','1',0,''),(41903,13217,'118767','printshop-mobile','sort_hide_6','1',0,''),(41904,13217,'118767','printshop-mobile','sort_hide_5','1',0,''),(41905,13217,'118767','printshop-mobile','sort_hide_0','1',0,''),(41906,13220,'118770','printshop-mobile','block_type','1',0,''),(41907,13220,'118770','printshop-mobile','background-color','#eeeeee',0,''),(41908,13220,'118770','printshop-mobile','padding-top','30',0,''),(41909,13220,'118770','printshop-mobile','padding-bottom','30',0,''),(41910,13221,'118771','printshop-mobile','block_type','1',0,''),(41911,13221,'118771','printshop-mobile','schema','4-2',0,''),(41912,13221,'118771','printshop-mobile','schema','4-1',0,'702'),(41913,13222,'118772','printshop-mobile','block_type','1',0,''),(41914,13222,'118772','printshop-mobile','padding-right','40',0,''),(41916,13223,'118773','printshop-mobile','block_type','1',0,''),(41917,13223,'118773','printshop-mobile','padding-top','30',0,''),(41918,13223,'118773','printshop-mobile','padding-left','30',0,''),(41919,13223,'118773','printshop-mobile','padding-right','30',0,''),(41920,13223,'118773','printshop-mobile','padding-bottom','23',0,''),(41921,13223,'118773','printshop-mobile','margin-bottom','20',0,''),(41922,13223,'118773','printshop-mobile','background-color','#ffffff',0,''),(41923,13223,'118773','printshop-mobile','style_class','hiding-box',0,''),(41924,13224,'118774','printshop-mobile','block_type','2',0,''),(41925,13224,'118774','printshop-mobile','schema','2-2',0,''),(41926,13224,'118774','printshop-mobile','schema','2-2',0,'702'),(41927,13225,'118775','printshop-mobile','padding-right','20',0,''),(41929,13225,'118775','printshop-mobile','padding-bottom','20',0,''),(41930,13225,'118775','printshop-mobile','address_in','popup',0,''),(41931,13226,'118776','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(41932,13227,'118777','printshop-mobile','block_type','1',0,''),(41933,13227,'118777','printshop-mobile','padding-left','20',0,''),(41935,13228,'118778','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(41936,13230,'118780','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(41937,13231,'118781','printshop-mobile','block_type','1',0,''),(41938,13231,'118781','printshop-mobile','background-color','#ffffff',0,''),(41939,13231,'118781','printshop-mobile','padding-top','30',0,''),(41940,13231,'118781','printshop-mobile','padding-left','30',0,''),(41941,13231,'118781','printshop-mobile','padding-right','30',0,''),(41942,13231,'118781','printshop-mobile','padding-bottom','30',0,''),(41943,13231,'118781','printshop-mobile','margin-bottom','20',0,''),(41944,13231,'118781','printshop-mobile','style_class','hiding-box',0,''),(41945,13232,'118782','printshop-mobile','padding-top','10',0,''),(41946,13232,'118782','printshop-mobile','padding-left','20',0,''),(41947,13232,'118782','printshop-mobile','padding-right','20',0,''),(41948,13232,'118782','printshop-mobile','margin-top','20',0,''),(41949,13232,'118782','printshop-mobile','background-color','#eeeeee',0,''),(41950,13232,'118782','printshop-mobile','padding-bottom','8',0,''),(41951,13233,'118783','printshop-mobile','margin-bottom','20',0,''),(41952,13234,'118784','printshop-mobile','background-color','#ffffff',0,''),(41953,13234,'118784','printshop-mobile','block_type','1',0,''),(41954,13234,'118784','printshop-mobile','padding-top','30',0,''),(41955,13234,'118784','printshop-mobile','padding-left','30',0,''),(41956,13234,'118784','printshop-mobile','padding-right','30',0,''),(41957,13234,'118784','printshop-mobile','padding-bottom','30',0,''),(41958,13234,'118784','printshop-mobile','margin-bottom','20',0,''),(41959,13234,'118784','printshop-mobile','style_class','hiding-box',0,''),(41960,13235,'118785','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(41961,13236,'118786','printshop-mobile','block_type','1',0,''),(41962,13236,'118786','printshop-mobile','schema','2-2',0,''),(41963,13236,'118786','printshop-mobile','schema','2-1',0,'702'),(41964,13237,'118787','printshop-mobile','block_type','1',0,''),(41965,13237,'118787','printshop-mobile','padding-left','0',0,''),(41966,13237,'118787','printshop-mobile','margin-bottom','20',0,''),(41967,13240,'118790','printshop-mobile','address_in','popup',0,''),(41968,13241,'118791','printshop-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(41969,13242,'118792','printshop-mobile','block_type','1',0,''),(41970,13242,'118792','printshop-mobile','padding-left','20',0,''),(41972,13243,'118793','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(41973,13244,'118794','printshop-mobile','border-top-width','1',0,''),(41974,13244,'118794','printshop-mobile','border-top-color','#e0e0e0',0,''),(41975,13244,'118794','printshop-mobile','padding-top','13',0,''),(41976,13244,'118794','printshop-mobile','padding-bottom','10',0,''),(41977,13246,'118796','printshop-mobile','background-color','#eeeeee',0,''),(41978,13246,'118796','printshop-mobile','padding-top','10',0,''),(41979,13246,'118796','printshop-mobile','padding-left','10',0,''),(41980,13246,'118796','printshop-mobile','padding-right','10',0,''),(41981,13246,'118796','printshop-mobile','padding-bottom','10',0,''),(41982,13246,'118796','printshop-mobile','margin-top','10',0,''),(41983,13247,'118797','printshop-mobile','block_type','1',0,''),(41984,13247,'118797','printshop-mobile','content','\\_',0,'3'),(41985,13247,'118797','printshop-mobile','border-top-width','1',0,'3'),(41986,13247,'118797','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(41987,13247,'118797','printshop-mobile','display','block',0,'3'),(41988,13247,'118797','printshop-mobile','position','absolute',0,'3'),(41989,13247,'118797','printshop-mobile','top','19',0,'3'),(41990,13247,'118797','printshop-mobile','left','0',0,'3'),(41991,13247,'118797','printshop-mobile','right','0',0,'3'),(41992,13247,'118797','printshop-mobile','margin-top','-2',0,'3'),(41993,13247,'118797','printshop-mobile','position','relative',0,''),(41994,13248,'118798','printshop-mobile','box_align','2',0,''),(41995,13248,'118798','printshop-mobile','margin-bottom','10',0,''),(41996,13248,'118798','printshop-mobile','background-color','#ffffff',0,''),(41997,13248,'118798','printshop-mobile','position','relative',0,''),(41998,13249,'118799','printshop-mobile','block_type','1',0,''),(41999,13249,'118799','printshop-mobile','padding-top','30',0,''),(42000,13249,'118799','printshop-mobile','padding-left','30',0,''),(42001,13249,'118799','printshop-mobile','padding-right','30',0,''),(42002,13249,'118799','printshop-mobile','padding-bottom','14',0,''),(42003,13249,'118799','printshop-mobile','margin-bottom','20',0,''),(42004,13249,'118799','printshop-mobile','background-color','#ffffff',0,''),(42005,13249,'118799','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42006,13250,'118800','printshop-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(42007,13250,'118800','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42008,13251,'118801','printshop-mobile','block_type','2',0,''),(42009,13251,'118801','printshop-mobile','style_class','closeable-content',0,''),(42010,13251,'118801','printshop-mobile','schema','2-2',0,''),(42011,13251,'118801','printshop-mobile','schema','2-2',0,'702'),(42012,13252,'118802','printshop-mobile','padding-right','20',0,''),(42013,13252,'118802','printshop-mobile','padding-bottom','20',0,''),(42015,13253,'118803','printshop-mobile','padding-left','20',0,''),(42016,13253,'118803','printshop-mobile','padding-bottom','20',0,''),(42018,13254,'118804','printshop-mobile','padding-left','20',0,''),(42019,13254,'118804','printshop-mobile','padding-bottom','20',0,''),(42021,13255,'118805','printshop-mobile','block_type','1',0,''),(42022,13255,'118805','printshop-mobile','background-color','#ffffff',0,''),(42023,13255,'118805','printshop-mobile','padding-top','30',0,''),(42024,13255,'118805','printshop-mobile','padding-left','30',0,''),(42025,13255,'118805','printshop-mobile','padding-right','30',0,''),(42026,13255,'118805','printshop-mobile','padding-bottom','14',0,''),(42027,13255,'118805','printshop-mobile','margin-bottom','20',0,''),(42028,13255,'118805','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42029,13256,'118806','printshop-mobile','style_class','closeable-content',0,''),(42030,13256,'118806','printshop-mobile','padding-bottom','20',0,''),(42031,13257,'118807','printshop-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(42032,13257,'118807','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42033,13258,'118808','printshop-mobile','block_type','1',0,''),(42034,13258,'118808','printshop-mobile','padding-top','20',0,''),(42035,13258,'118808','printshop-mobile','padding-left','20',0,''),(42036,13258,'118808','printshop-mobile','padding-right','20',0,''),(42037,13258,'118808','printshop-mobile','padding-bottom','20',0,''),(42038,13258,'118808','printshop-mobile','background-color','#ffffff',0,''),(42039,13258,'118808','printshop-mobile','style_class','order-summary',0,''),(42040,13259,'118809','printshop-mobile','margin-bottom','10',0,''),(42041,13261,'118811','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(42042,13262,'118812','printshop-mobile','hide_page','1',0,''),(42043,13262,'118812','printshop-mobile','hide_continue_button','1',0,''),(42044,13263,'118813','printshop-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(42045,13263,'118813','printshop-mobile','text-align','center',0,''),(42046,13263,'118813','printshop-mobile','font-size','14',0,''),(42047,13263,'118813','printshop-mobile','color','#757575',0,''),(42048,13263,'118813','printshop-mobile','padding-top','10',0,''),(42049,13264,'118814','printshop-mobile','block_type','1',0,''),(42050,13265,'118815','printshop-mobile','margin-bottom','20',0,''),(42051,13265,'118815','printshop-mobile','text-align','right',0,''),(42052,13267,'118817','printshop-mobile','block_type','2',0,''),(42053,13267,'118817','printshop-mobile','margin-bottom','20',0,''),(42054,13267,'118817','printshop-mobile','schema','2-2',0,''),(42055,13268,'118818','printshop-mobile','block_type','1',0,''),(42056,13268,'118818','printshop-mobile','padding-right','20',0,''),(42058,13269,'118819','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(42059,13269,'118819','printshop-mobile','clear','none',0,''),(42060,13271,'118821','printshop-mobile','block_type','1',0,''),(42061,13271,'118821','printshop-mobile','padding-left','20',0,''),(42063,13272,'118822','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42064,13272,'118822','printshop-mobile','clear','none',0,''),(42065,13274,'118824','printshop-mobile','text-align','right',0,''),(42066,13274,'118824','printshop-mobile','margin-bottom','20',0,''),(42067,13275,'118825','printshop-mobile','block_type','2',0,''),(42068,13275,'118825','printshop-mobile','margin-bottom','20',0,''),(42069,13275,'118825','printshop-mobile','schema','2-2',0,''),(42070,13276,'118826','printshop-mobile','block_type','1',0,''),(42071,13276,'118826','printshop-mobile','padding-right','20',0,''),(42073,13277,'118827','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42074,13277,'118827','printshop-mobile','clear','none',0,''),(42075,13279,'118829','printshop-mobile','padding-left','20',0,''),(42076,13279,'118829','printshop-mobile','block_type','1',0,''),(42078,13281,'118831','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42079,13281,'118831','printshop-mobile','clear','none',0,''),(42080,13282,'118832','printshop-mobile','link','products',0,''),(42081,13282,'118832','printshop-mobile','margin-top','-33',0,''),(42082,13282,'118832','printshop-mobile','float','right',0,''),(42083,13284,'118834','printshop-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(42084,13285,'118835','printshop-mobile','block_type','1',0,''),(42085,13286,'118836','printshop-mobile','margin-bottom','20',0,''),(42086,13287,'118837','printshop-mobile','text-align','right',0,''),(42087,13287,'118837','printshop-mobile','margin-bottom','20',0,''),(42088,13288,'118838','printshop-mobile','block_type','2',0,''),(42089,13288,'118838','printshop-mobile','margin-bottom','20',0,''),(42090,13288,'118838','printshop-mobile','schema','2-2',0,''),(42091,13289,'118839','printshop-mobile','block_type','1',0,''),(42092,13289,'118839','printshop-mobile','padding-right','20',0,''),(42094,13290,'118840','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42095,13290,'118840','printshop-mobile','clear','none',0,''),(42096,13292,'118842','printshop-mobile','block_type','1',0,''),(42097,13292,'118842','printshop-mobile','padding-left','20',0,''),(42099,13293,'118843','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42100,13293,'118843','printshop-mobile','clear','none',0,''),(42101,13295,'118845','printshop-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(42102,13296,'118846','printshop-mobile','margin-bottom','20',0,''),(42103,13297,'118847','printshop-mobile','margin-bottom','20',0,''),(42104,13297,'118847','printshop-mobile','text-align','right',0,''),(42105,13298,'118848','printshop-mobile','block_type','1',0,''),(42106,13299,'118849','printshop-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(42107,13300,'118850','printshop-mobile','margin-bottom','20',0,''),(42108,13300,'118850','printshop-mobile','text-align','right',0,''),(42109,13303,'118853','printshop-mobile','text-align','right',0,''),(42110,13303,'118853','printshop-mobile','margin-bottom','20',0,''),(42111,13304,'118854','printshop-mobile','block_type','2',0,''),(42112,13304,'118854','printshop-mobile','margin-bottom','20',0,''),(42113,13304,'118854','printshop-mobile','schema','2-2',0,''),(42114,13305,'118855','printshop-mobile','block_type','1',0,''),(42115,13305,'118855','printshop-mobile','padding-right','20',0,''),(42117,13307,'118857','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42118,13307,'118857','printshop-mobile','clear','none',0,''),(42119,13308,'118858','printshop-mobile','block_type','1',0,''),(42120,13308,'118858','printshop-mobile','padding-left','20',0,''),(42122,13309,'118859','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42123,13309,'118859','printshop-mobile','clear','none',0,''),(42124,13311,'118861','printshop-mobile','block_type','1',0,''),(42125,13312,'118862','printshop-mobile','block_type','2',0,''),(42126,13312,'118862','printshop-mobile','margin-bottom','20',0,''),(42127,13312,'118862','printshop-mobile','schema','2-2',0,''),(42128,13313,'118863','printshop-mobile','block_type','1',0,''),(42129,13313,'118863','printshop-mobile','padding-right','20',0,''),(42131,13315,'118865','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42132,13315,'118865','printshop-mobile','clear','none',0,''),(42133,13316,'118866','printshop-mobile','padding-left','20',0,''),(42134,13316,'118866','printshop-mobile','block_type','1',0,''),(42136,13317,'118867','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42137,13317,'118867','printshop-mobile','clear','none',0,''),(42138,13319,'118869','printshop-mobile','text-align','right',0,''),(42139,13319,'118869','printshop-mobile','margin-bottom','20',0,''),(42140,13320,'118870','printshop-mobile','margin-bottom','20',0,''),(42141,13320,'118870','printshop-mobile','text-align','right',0,''),(42142,13321,'118871','printshop-mobile','link','products',0,''),(42143,13321,'118871','printshop-mobile','margin-top','-33',0,''),(42144,13321,'118871','printshop-mobile','float','right',0,''),(42145,13322,'118872','printshop-mobile','margin-bottom','20',0,''),(42146,13323,'118873','printshop-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(42147,13324,'118874','printshop-mobile','margin-bottom','20',0,''),(42148,13325,'118875','printshop-mobile','block_type','2',0,''),(42149,13325,'118875','printshop-mobile','margin-bottom','20',0,''),(42150,13325,'118875','printshop-mobile','schema','2-2',0,''),(42151,13326,'118876','printshop-mobile','block_type','1',0,''),(42152,13326,'118876','printshop-mobile','padding-right','20',0,''),(42154,13328,'118878','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(42155,13328,'118878','printshop-mobile','clear','none',0,''),(42156,13329,'118879','printshop-mobile','block_type','1',0,''),(42157,13329,'118879','printshop-mobile','padding-left','20',0,''),(42159,13330,'118880','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42160,13330,'118880','printshop-mobile','clear','none',0,''),(42161,13332,'118882','printshop-mobile','text','##TEXT_CONFIRMATION##',0,''),(42162,13333,'118883','printshop-mobile','text','##TEXT_CONFIRMATION##',0,''),(42163,13334,'118884','printshop-mobile','text','##TEXT_CONFIRMATION##',0,''),(42164,13335,'118885','printshop-mobile','text','##TEXT_CONFIRMATION##',0,''),(42165,13336,'118886','printshop-mobile','text','##TEXT_CONFIRMATION##',0,''),(42166,13337,'118887','printshop-mobile','text','##TEXT_CONFIRMATION##',0,''),(42167,13338,'118888','printshop-mobile','block_type','2',0,''),(42168,13339,'118889','printshop-mobile','block_type','1',0,''),(42169,13339,'118889','printshop-mobile','padding-right','20',0,''),(42171,13341,'118891','printshop-mobile','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(42172,13342,'118892','printshop-mobile','block_type','1',0,''),(42173,13342,'118892','printshop-mobile','padding-right','0',0,''),(42174,13342,'118892','printshop-mobile','padding-left','20',0,''),(42175,13344,'118894','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42176,13347,'118897','printshop-mobile','block_type','2',0,''),(42177,13348,'118898','printshop-mobile','block_type','1',0,''),(42178,13348,'118898','printshop-mobile','padding-right','20',0,''),(42179,13349,'118899','printshop-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(42180,13351,'118901','printshop-mobile','block_type','1',0,''),(42181,13351,'118901','printshop-mobile','padding-left','20',0,''),(42183,13352,'118902','printshop-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(42184,13354,'118904','printshop-mobile','block_type','4',0,''),(42185,13354,'118904','printshop-mobile','schema','4-2',0,''),(42186,13355,'118905','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42187,13355,'118905','printshop-mobile','text-align','right',0,''),(42188,13355,'118905','printshop-mobile','padding-top','10',0,''),(42189,13355,'118905','printshop-mobile','font_size_measure','em',0,''),(42190,13355,'118905','printshop-mobile','font-size','1.2',0,''),(42191,13356,'118906','printshop-mobile','text-align','right',0,''),(42192,13357,'118907','printshop-mobile','block_type','2',0,''),(42193,13358,'118908','printshop-mobile','block_type','1',0,''),(42194,13358,'118908','printshop-mobile','padding-right','20',0,''),(42196,13360,'118910','printshop-mobile','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(42197,13361,'118911','printshop-mobile','block_type','1',0,''),(42198,13361,'118911','printshop-mobile','padding-right','0',0,''),(42199,13361,'118911','printshop-mobile','padding-left','20',0,''),(42200,13362,'118912','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42201,13366,'118916','printshop-mobile','block_type','4',0,''),(42202,13366,'118916','printshop-mobile','schema','4-2',0,''),(42203,13367,'118917','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42204,13367,'118917','printshop-mobile','text-align','right',0,''),(42205,13367,'118917','printshop-mobile','padding-top','10',0,''),(42206,13367,'118917','printshop-mobile','font_size_measure','em',0,''),(42207,13367,'118917','printshop-mobile','font-size','1.2',0,''),(42208,13368,'118918','printshop-mobile','text-align','right',0,''),(42209,13369,'118919','printshop-mobile','block_type','2',0,''),(42210,13370,'118920','printshop-mobile','block_type','1',0,''),(42211,13370,'118920','printshop-mobile','padding-right','20',0,''),(42212,13372,'118922','printshop-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(42213,13373,'118923','printshop-mobile','block_type','1',0,''),(42214,13373,'118923','printshop-mobile','padding-left','20',0,''),(42216,13375,'118925','printshop-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(42217,13376,'118926','printshop-mobile','block_type','4',0,''),(42218,13376,'118926','printshop-mobile','schema','4-2',0,''),(42219,13377,'118927','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42220,13377,'118927','printshop-mobile','text-align','right',0,''),(42221,13377,'118927','printshop-mobile','padding-top','10',0,''),(42222,13377,'118927','printshop-mobile','font_size_measure','em',0,''),(42223,13377,'118927','printshop-mobile','font-size','1.2',0,''),(42224,13378,'118928','printshop-mobile','text-align','right',0,''),(42225,13379,'118929','printshop-mobile','block_type','2',0,''),(42226,13380,'118930','printshop-mobile','block_type','1',0,''),(42227,13380,'118930','printshop-mobile','padding-right','20',0,''),(42228,13382,'118932','printshop-mobile','block_type','1',0,''),(42229,13382,'118932','printshop-mobile','padding-left','20',0,''),(42231,13384,'118934','printshop-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(42232,13385,'118935','printshop-mobile','block_type','2',0,''),(42233,13386,'118936','printshop-mobile','block_type','1',0,''),(42234,13386,'118936','printshop-mobile','padding-right','20',0,''),(42235,13388,'118938','printshop-mobile','block_type','1',0,''),(42236,13388,'118938','printshop-mobile','padding-left','20',0,''),(42238,13389,'118939','printshop-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(42239,13391,'118941','printshop-mobile','block_type','4',0,''),(42240,13391,'118941','printshop-mobile','schema','4-2',0,''),(42241,13392,'118942','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42242,13392,'118942','printshop-mobile','text-align','right',0,''),(42243,13392,'118942','printshop-mobile','padding-top','10',0,''),(42244,13392,'118942','printshop-mobile','font_size_measure','em',0,''),(42245,13392,'118942','printshop-mobile','font-size','1.2',0,''),(42246,13393,'118943','printshop-mobile','text-align','right',0,''),(42247,13394,'118944','printshop-mobile','text','##DELIVERY_DETAILS##',0,''),(42248,13395,'118945','printshop-mobile','text','##DELIVERY_DETAILS##',0,''),(42249,13396,'118946','printshop-mobile','text','##CONTACT_INFORMATION##',0,''),(42250,13397,'118947','printshop-mobile','text','##CONTACT_INFORMATION##',0,''),(42251,13398,'118948','printshop-mobile','text','##DELIVERY_DETAILS##',0,''),(42252,13399,'118949','printshop-mobile','text','##DELIVERY_DETAILS##',0,''),(42253,13400,'118950','printshop-mobile','block_type','1',0,''),(42254,13400,'118950','printshop-mobile','background-color','#eeeeee',0,''),(42255,13400,'118950','printshop-mobile','padding-top','30',0,''),(42256,13400,'118950','printshop-mobile','padding-bottom','30',0,''),(42257,13401,'118951','printshop-mobile','block_type','4',0,''),(42258,13401,'118951','printshop-mobile','schema','4-2',0,''),(42259,13402,'118952','printshop-mobile','block_type','1',0,''),(42260,13402,'118952','printshop-mobile','padding-right','40',0,''),(42262,13403,'118953','printshop-mobile','background-color','#ffffff',0,''),(42263,13403,'118953','printshop-mobile','block_type','1',0,''),(42264,13403,'118953','printshop-mobile','padding-top','30',0,''),(42265,13403,'118953','printshop-mobile','padding-left','30',0,''),(42266,13403,'118953','printshop-mobile','padding-right','30',0,''),(42267,13403,'118953','printshop-mobile','padding-bottom','30',0,''),(42268,13403,'118953','printshop-mobile','margin-bottom','20',0,''),(42269,13403,'118953','printshop-mobile','style_class','hiding-box',0,''),(42270,13404,'118954','printshop-mobile','background-color','#eeeeee',0,''),(42271,13404,'118954','printshop-mobile','padding-top','10',0,''),(42272,13404,'118954','printshop-mobile','padding-left','10',0,''),(42273,13404,'118954','printshop-mobile','padding-right','10',0,''),(42274,13404,'118954','printshop-mobile','padding-bottom','10',0,''),(42275,13404,'118954','printshop-mobile','margin-top','10',0,''),(42276,13405,'118955','printshop-mobile','block_type','2',0,''),(42277,13405,'118955','printshop-mobile','schema','2-2',0,''),(42278,13406,'118956','printshop-mobile','block_type','1',0,''),(42279,13406,'118956','printshop-mobile','padding-right','20',0,''),(42280,13406,'118956','printshop-mobile','padding-left','0',0,''),(42281,13406,'118956','printshop-mobile','margin-bottom','20',0,''),(42282,13408,'118958','printshop-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(42283,13410,'118960','printshop-mobile','block_type','1',0,''),(42284,13410,'118960','printshop-mobile','padding-left','20',0,''),(42286,13411,'118961','printshop-mobile','border-top-width','1',0,''),(42287,13411,'118961','printshop-mobile','border-top-color','#e0e0e0',0,''),(42288,13411,'118961','printshop-mobile','padding-top','13',0,''),(42289,13411,'118961','printshop-mobile','padding-bottom','10',0,''),(42290,13412,'118962','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(42291,13413,'118963','printshop-mobile','block_type','1',0,''),(42292,13413,'118963','printshop-mobile','content','\\_',0,'3'),(42293,13413,'118963','printshop-mobile','border-top-width','1',0,'3'),(42294,13413,'118963','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(42295,13413,'118963','printshop-mobile','display','block',0,'3'),(42296,13413,'118963','printshop-mobile','position','absolute',0,'3'),(42297,13413,'118963','printshop-mobile','top','19',0,'3'),(42298,13413,'118963','printshop-mobile','left','0',0,'3'),(42299,13413,'118963','printshop-mobile','right','0',0,'3'),(42300,13413,'118963','printshop-mobile','margin-top','-2',0,'3'),(42301,13413,'118963','printshop-mobile','position','relative',0,''),(42302,13414,'118964','printshop-mobile','box_align','2',0,''),(42303,13414,'118964','printshop-mobile','margin-bottom','10',0,''),(42304,13414,'118964','printshop-mobile','background-color','#ffffff',0,''),(42305,13414,'118964','printshop-mobile','position','relative',0,''),(42306,13415,'118965','printshop-mobile','block_type','1',0,''),(42307,13415,'118965','printshop-mobile','background-color','#ffffff',0,''),(42308,13415,'118965','printshop-mobile','padding-top','30',0,''),(42309,13415,'118965','printshop-mobile','padding-left','30',0,''),(42310,13415,'118965','printshop-mobile','padding-right','30',0,''),(42311,13415,'118965','printshop-mobile','padding-bottom','14',0,''),(42312,13415,'118965','printshop-mobile','margin-bottom','20',0,''),(42313,13415,'118965','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42314,13416,'118966','printshop-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(42315,13416,'118966','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42316,13417,'118967','printshop-mobile','style_class','closeable-content',0,''),(42317,13417,'118967','printshop-mobile','padding-bottom','20',0,''),(42318,13418,'118968','printshop-mobile','background-color','#ffffff',0,''),(42319,13418,'118968','printshop-mobile','padding-top','30',0,''),(42320,13418,'118968','printshop-mobile','padding-left','30',0,''),(42321,13418,'118968','printshop-mobile','padding-right','30',0,''),(42322,13418,'118968','printshop-mobile','padding-bottom','30',0,''),(42323,13418,'118968','printshop-mobile','margin-bottom','20',0,''),(42324,13419,'118969','printshop-mobile','block_type','1',0,''),(42325,13419,'118969','printshop-mobile','background-color','#ffffff',0,''),(42326,13419,'118969','printshop-mobile','padding-top','30',0,''),(42327,13419,'118969','printshop-mobile','padding-left','30',0,''),(42328,13419,'118969','printshop-mobile','padding-right','30',0,''),(42329,13419,'118969','printshop-mobile','padding-bottom','30',0,''),(42330,13419,'118969','printshop-mobile','margin-bottom','20',0,''),(42331,13419,'118969','printshop-mobile','style_class','hiding-box',0,''),(42332,13420,'118970','printshop-mobile','padding-top','10',0,''),(42333,13420,'118970','printshop-mobile','padding-left','20',0,''),(42334,13420,'118970','printshop-mobile','padding-right','20',0,''),(42335,13420,'118970','printshop-mobile','margin-top','20',0,''),(42336,13420,'118970','printshop-mobile','background-color','#eeeeee',0,''),(42337,13420,'118970','printshop-mobile','padding-bottom','8',0,''),(42338,13421,'118971','printshop-mobile','margin-bottom','20',0,''),(42339,13422,'118972','printshop-mobile','block_type','1',0,''),(42340,13422,'118972','printshop-mobile','padding-top','20',0,''),(42341,13422,'118972','printshop-mobile','padding-left','20',0,''),(42342,13422,'118972','printshop-mobile','padding-right','20',0,''),(42343,13422,'118972','printshop-mobile','padding-bottom','20',0,''),(42344,13422,'118972','printshop-mobile','background-color','#ffffff',0,''),(42345,13422,'118972','printshop-mobile','style_class','order-summary',0,''),(42346,13424,'118974','printshop-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(42347,13424,'118974','printshop-mobile','text-align','center',0,''),(42348,13424,'118974','printshop-mobile','font-size','14',0,''),(42349,13424,'118974','printshop-mobile','color','#757575',0,''),(42350,13424,'118974','printshop-mobile','padding-top','10',0,''),(42351,13425,'118975','printshop-mobile','block_type','1',0,''),(42352,13425,'118975','printshop-mobile','background-color','#eeeeee',0,''),(42353,13425,'118975','printshop-mobile','padding-top','30',0,''),(42354,13425,'118975','printshop-mobile','padding-bottom','30',0,''),(42355,13426,'118976','printshop-mobile','block_type','4',0,''),(42356,13427,'118977','printshop-mobile','block_type','1',0,''),(42357,13427,'118977','printshop-mobile','padding-right','40',0,''),(42358,13428,'118978','printshop-mobile','block_type','1',0,''),(42359,13428,'118978','printshop-mobile','background-color','#ffffff',0,''),(42360,13428,'118978','printshop-mobile','padding-top','30',0,''),(42361,13428,'118978','printshop-mobile','padding-left','30',0,''),(42362,13428,'118978','printshop-mobile','padding-right','30',0,''),(42363,13428,'118978','printshop-mobile','padding-bottom','14',0,''),(42364,13428,'118978','printshop-mobile','margin-bottom','20',0,''),(42365,13428,'118978','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42366,13429,'118979','printshop-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(42367,13429,'118979','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42368,13430,'118980','printshop-mobile','style_class','closeable-content',0,''),(42369,13430,'118980','printshop-mobile','padding-bottom','20',0,''),(42370,13431,'118981','printshop-mobile','block_type','1',0,''),(42371,13431,'118981','printshop-mobile','padding-top','30',0,''),(42372,13431,'118981','printshop-mobile','padding-left','30',0,''),(42373,13431,'118981','printshop-mobile','padding-right','30',0,''),(42374,13431,'118981','printshop-mobile','padding-bottom','14',0,''),(42375,13431,'118981','printshop-mobile','margin-bottom','20',0,''),(42376,13431,'118981','printshop-mobile','background-color','#ffffff',0,''),(42377,13431,'118981','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42378,13432,'118982','printshop-mobile','block_type','2',0,''),(42379,13432,'118982','printshop-mobile','style_class','closeable-content',0,''),(42380,13433,'118983','printshop-mobile','padding-right','20',0,''),(42381,13433,'118983','printshop-mobile','padding-bottom','20',0,''),(42382,13434,'118984','printshop-mobile','padding-left','20',0,''),(42383,13434,'118984','printshop-mobile','padding-bottom','20',0,''),(42384,13435,'118985','printshop-mobile','padding-left','20',0,''),(42385,13435,'118985','printshop-mobile','padding-bottom','20',0,''),(42386,13436,'118986','printshop-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(42387,13436,'118986','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42388,13437,'118987','printshop-mobile','block_type','1',0,''),(42389,13437,'118987','printshop-mobile','padding-top','30',0,''),(42390,13437,'118987','printshop-mobile','padding-left','30',0,''),(42391,13437,'118987','printshop-mobile','padding-right','30',0,''),(42392,13437,'118987','printshop-mobile','padding-bottom','23',0,''),(42393,13437,'118987','printshop-mobile','margin-bottom','20',0,''),(42394,13437,'118987','printshop-mobile','background-color','#ffffff',0,''),(42395,13437,'118987','printshop-mobile','style_class','hiding-box',0,''),(42396,13438,'118988','printshop-mobile','block_type','2',0,''),(42397,13439,'118989','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42398,13440,'118990','printshop-mobile','padding-right','20',0,''),(42399,13441,'118991','printshop-mobile','block_type','1',0,''),(42400,13441,'118991','printshop-mobile','padding-left','20',0,''),(42401,13442,'118992','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42402,13444,'118994','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(42403,13445,'118995','printshop-mobile','block_type','1',0,''),(42404,13445,'118995','printshop-mobile','background-color','#ffffff',0,''),(42405,13445,'118995','printshop-mobile','padding-top','30',0,''),(42406,13445,'118995','printshop-mobile','padding-left','30',0,''),(42407,13445,'118995','printshop-mobile','padding-right','30',0,''),(42408,13445,'118995','printshop-mobile','padding-bottom','30',0,''),(42409,13445,'118995','printshop-mobile','margin-bottom','20',0,''),(42410,13445,'118995','printshop-mobile','style_class','hiding-box',0,''),(42411,13446,'118996','printshop-mobile','margin-bottom','20',0,''),(42412,13447,'118997','printshop-mobile','padding-top','10',0,''),(42413,13447,'118997','printshop-mobile','padding-left','20',0,''),(42414,13447,'118997','printshop-mobile','padding-right','20',0,''),(42415,13447,'118997','printshop-mobile','margin-top','20',0,''),(42416,13447,'118997','printshop-mobile','background-color','#eeeeee',0,''),(42417,13447,'118997','printshop-mobile','padding-bottom','8',0,''),(42418,13448,'118998','printshop-mobile','block_type','1',0,''),(42419,13448,'118998','printshop-mobile','padding-top','20',0,''),(42420,13448,'118998','printshop-mobile','padding-left','20',0,''),(42421,13448,'118998','printshop-mobile','padding-right','20',0,''),(42422,13448,'118998','printshop-mobile','padding-bottom','20',0,''),(42423,13448,'118998','printshop-mobile','background-color','#ffffff',0,''),(42424,13448,'118998','printshop-mobile','style_class','order-summary hiding-box',0,''),(42425,13449,'118999','printshop-mobile','hide_page','1',0,''),(42426,13449,'118999','printshop-mobile','hide_continue_button','1',0,''),(42427,13451,'119001','printshop-mobile','margin-bottom','10',0,''),(42428,13452,'119002','printshop-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(42429,13452,'119002','printshop-mobile','text-align','center',0,''),(42430,13452,'119002','printshop-mobile','font-size','14',0,''),(42431,13452,'119002','printshop-mobile','color','#757575',0,''),(42432,13452,'119002','printshop-mobile','padding-top','10',0,''),(42433,13453,'119003','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(42434,13454,'119004','printshop-mobile','block_type','1',0,''),(42435,13455,'119005','printshop-mobile','margin-bottom','20',0,''),(42436,13456,'119006','printshop-mobile','block_type','2',0,''),(42437,13456,'119006','printshop-mobile','schema','2-2',0,''),(42438,13457,'119007','printshop-mobile','block_type','1',0,''),(42439,13457,'119007','printshop-mobile','padding-right','20',0,''),(42441,13459,'119009','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42442,13460,'119010','printshop-mobile','block_type','1',0,''),(42443,13460,'119010','printshop-mobile','padding-left','20',0,''),(42445,13462,'119012','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42446,13466,'119016','printshop-mobile','block_type','2',0,''),(42447,13466,'119016','printshop-mobile','schema','2-2',0,''),(42448,13467,'119017','printshop-mobile','block_type','1',0,''),(42449,13467,'119017','printshop-mobile','padding-right','20',0,''),(42451,13468,'119018','printshop-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(42452,13470,'119020','printshop-mobile','block_type','1',0,''),(42453,13470,'119020','printshop-mobile','padding-left','20',0,''),(42455,13471,'119021','printshop-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(42456,13473,'119023','printshop-mobile','block_type','4',0,''),(42457,13473,'119023','printshop-mobile','schema','4-2',0,''),(42458,13474,'119024','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42459,13474,'119024','printshop-mobile','text-align','right',0,''),(42460,13474,'119024','printshop-mobile','padding-top','10',0,''),(42461,13474,'119024','printshop-mobile','font_size_measure','em',0,''),(42462,13474,'119024','printshop-mobile','font-size','1.2',0,''),(42463,13475,'119025','printshop-mobile','text-align','right',0,''),(42464,13477,'119027','printshop-mobile','block_type','1',0,''),(42465,13477,'119027','printshop-mobile','background-color','#eeeeee',0,''),(42466,13477,'119027','printshop-mobile','padding-top','30',0,''),(42467,13477,'119027','printshop-mobile','padding-bottom','30',0,''),(42468,13478,'119028','printshop-mobile','block_type','4',0,''),(42469,13478,'119028','printshop-mobile','schema','4-2',0,''),(42470,13479,'119029','printshop-mobile','block_type','1',0,''),(42471,13479,'119029','printshop-mobile','padding-right','40',0,''),(42473,13480,'119030','printshop-mobile','block_type','1',0,''),(42474,13480,'119030','printshop-mobile','padding-top','30',0,''),(42475,13480,'119030','printshop-mobile','padding-left','30',0,''),(42476,13480,'119030','printshop-mobile','padding-right','30',0,''),(42477,13480,'119030','printshop-mobile','padding-bottom','23',0,''),(42478,13480,'119030','printshop-mobile','margin-bottom','20',0,''),(42479,13480,'119030','printshop-mobile','background-color','#ffffff',0,''),(42480,13480,'119030','printshop-mobile','style_class','hiding-box',0,''),(42481,13481,'119031','printshop-mobile','block_type','2',0,''),(42482,13481,'119031','printshop-mobile','schema','2-2',0,''),(42483,13482,'119032','printshop-mobile','padding-right','20',0,''),(42485,13482,'119032','printshop-mobile','padding-bottom','20',0,''),(42486,13483,'119033','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42487,13484,'119034','printshop-mobile','block_type','1',0,''),(42488,13484,'119034','printshop-mobile','padding-left','20',0,''),(42490,13485,'119035','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42491,13487,'119037','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(42492,13488,'119038','printshop-mobile','block_type','1',0,''),(42493,13488,'119038','printshop-mobile','background-color','#ffffff',0,''),(42494,13488,'119038','printshop-mobile','padding-top','30',0,''),(42495,13488,'119038','printshop-mobile','padding-left','30',0,''),(42496,13488,'119038','printshop-mobile','padding-right','30',0,''),(42497,13488,'119038','printshop-mobile','padding-bottom','30',0,''),(42498,13488,'119038','printshop-mobile','margin-bottom','20',0,''),(42499,13488,'119038','printshop-mobile','style_class','hiding-box',0,''),(42500,13489,'119039','printshop-mobile','padding-top','10',0,''),(42501,13489,'119039','printshop-mobile','padding-left','20',0,''),(42502,13489,'119039','printshop-mobile','padding-right','20',0,''),(42503,13489,'119039','printshop-mobile','margin-top','20',0,''),(42504,13489,'119039','printshop-mobile','background-color','#eeeeee',0,''),(42505,13489,'119039','printshop-mobile','padding-bottom','8',0,''),(42506,13490,'119040','printshop-mobile','margin-bottom','20',0,''),(42507,13491,'119041','printshop-mobile','block_type','1',0,''),(42508,13491,'119041','printshop-mobile','background-color','#ffffff',0,''),(42509,13491,'119041','printshop-mobile','padding-top','30',0,''),(42510,13491,'119041','printshop-mobile','padding-left','30',0,''),(42511,13491,'119041','printshop-mobile','padding-right','30',0,''),(42512,13491,'119041','printshop-mobile','padding-bottom','14',0,''),(42513,13491,'119041','printshop-mobile','margin-bottom','20',0,''),(42514,13491,'119041','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42515,13492,'119042','printshop-mobile','style_class','closeable-content',0,''),(42516,13492,'119042','printshop-mobile','padding-bottom','20',0,''),(42517,13493,'119043','printshop-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(42518,13493,'119043','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42519,13494,'119044','printshop-mobile','background-color','#ffffff',0,''),(42520,13494,'119044','printshop-mobile','padding-top','30',0,''),(42521,13494,'119044','printshop-mobile','padding-left','30',0,''),(42522,13494,'119044','printshop-mobile','padding-right','30',0,''),(42523,13494,'119044','printshop-mobile','padding-bottom','30',0,''),(42524,13494,'119044','printshop-mobile','margin-bottom','20',0,''),(42525,13495,'119045','printshop-mobile','block_type','1',0,''),(42526,13495,'119045','printshop-mobile','padding-top','20',0,''),(42527,13495,'119045','printshop-mobile','padding-left','20',0,''),(42528,13495,'119045','printshop-mobile','padding-right','20',0,''),(42529,13495,'119045','printshop-mobile','padding-bottom','20',0,''),(42530,13495,'119045','printshop-mobile','background-color','#ffffff',0,''),(42531,13495,'119045','printshop-mobile','style_class','order-summary',0,''),(42532,13496,'119046','printshop-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(42533,13496,'119046','printshop-mobile','text-align','center',0,''),(42534,13496,'119046','printshop-mobile','font-size','14',0,''),(42535,13496,'119046','printshop-mobile','color','#757575',0,''),(42536,13496,'119046','printshop-mobile','padding-top','10',0,''),(42537,13497,'119047','printshop-mobile','margin-bottom','10',0,''),(42538,13499,'119049','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(42539,13500,'119050','printshop-mobile','block_type','4',0,''),(42540,13500,'119050','printshop-mobile','schema','4-2',0,''),(42541,13501,'119051','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42542,13501,'119051','printshop-mobile','text-align','right',0,''),(42543,13501,'119051','printshop-mobile','padding-top','10',0,''),(42544,13501,'119051','printshop-mobile','font_size_measure','em',0,''),(42545,13501,'119051','printshop-mobile','font-size','1.2',0,''),(42546,13502,'119052','printshop-mobile','text-align','right',0,''),(42547,13503,'119053','printshop-mobile','block_type','2',0,''),(42548,13504,'119054','printshop-mobile','block_type','1',0,''),(42549,13504,'119054','printshop-mobile','padding-left','0',0,''),(42550,13504,'119054','printshop-mobile','padding-right','20',0,''),(42551,13506,'119056','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42552,13507,'119057','printshop-mobile','block_type','1',0,''),(42553,13507,'119057','printshop-mobile','padding-left','20',0,''),(42555,13509,'119059','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42556,13513,'119063','printshop-mobile','block_type','2',0,''),(42557,13514,'119064','printshop-mobile','block_type','1',0,''),(42558,13514,'119064','printshop-mobile','padding-left','0',0,''),(42559,13514,'119064','printshop-mobile','padding-right','20',0,''),(42560,13515,'119065','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42561,13517,'119067','printshop-mobile','block_type','1',0,''),(42562,13517,'119067','printshop-mobile','padding-left','20',0,''),(42564,13519,'119069','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42565,13523,'119073','printshop-mobile','block_type','4',0,''),(42566,13523,'119073','printshop-mobile','schema','4-2',0,''),(42567,13524,'119074','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42568,13524,'119074','printshop-mobile','text-align','right',0,''),(42569,13524,'119074','printshop-mobile','padding-top','10',0,''),(42570,13524,'119074','printshop-mobile','font_size_measure','em',0,''),(42571,13524,'119074','printshop-mobile','font-size','1.2',0,''),(42572,13525,'119075','printshop-mobile','text-align','right',0,''),(42573,13526,'119076','printshop-mobile','block_type','2',0,''),(42574,13527,'119077','printshop-mobile','block_type','1',0,''),(42575,13527,'119077','printshop-mobile','padding-left','0',0,''),(42576,13527,'119077','printshop-mobile','padding-right','20',0,''),(42577,13528,'119078','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42578,13530,'119080','printshop-mobile','block_type','1',0,''),(42579,13530,'119080','printshop-mobile','padding-left','20',0,''),(42581,13531,'119081','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42582,13536,'119086','printshop-mobile','block_type','4',0,''),(42583,13536,'119086','printshop-mobile','schema','4-2',0,''),(42584,13537,'119087','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42585,13537,'119087','printshop-mobile','text-align','right',0,''),(42586,13537,'119087','printshop-mobile','padding-top','10',0,''),(42587,13537,'119087','printshop-mobile','font_size_measure','em',0,''),(42588,13537,'119087','printshop-mobile','font-size','1.2',0,''),(42589,13538,'119088','printshop-mobile','text-align','right',0,''),(42590,13539,'119089','printshop-mobile','block_type','4',0,''),(42591,13539,'119089','printshop-mobile','schema','4-2',0,''),(42592,13540,'119090','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42593,13540,'119090','printshop-mobile','text-align','right',0,''),(42594,13540,'119090','printshop-mobile','padding-top','10',0,''),(42595,13540,'119090','printshop-mobile','font_size_measure','em',0,''),(42596,13540,'119090','printshop-mobile','font-size','1.2',0,''),(42597,13541,'119091','printshop-mobile','text-align','right',0,''),(42598,13542,'119092','printshop-mobile','block_type','2',0,''),(42599,13543,'119093','printshop-mobile','block_type','1',0,''),(42600,13543,'119093','printshop-mobile','padding-left','0',0,''),(42601,13543,'119093','printshop-mobile','padding-right','20',0,''),(42602,13545,'119095','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42603,13546,'119096','printshop-mobile','block_type','1',0,''),(42604,13546,'119096','printshop-mobile','padding-left','20',0,''),(42606,13548,'119098','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42607,13552,'119102','printshop-mobile','text','##PAYMENT_DETAILS##',0,''),(42608,13553,'119103','printshop-mobile','text','##PAYMENT_DETAILS##',0,''),(42609,13554,'119104','printshop-mobile','text','##PAYMENT_DETAILS##',0,''),(42610,13555,'119105','printshop-mobile','text','##PAYMENT_DETAILS##',0,''),(42611,13556,'119106','printshop-mobile','text','##PAYMENT_DETAILS##',0,''),(42612,13557,'119107','printshop-mobile','text','##PAYMENT_DETAILS##',0,''),(42613,13558,'119108','printshop-mobile','block_type','1',0,''),(42614,13558,'119108','printshop-mobile','background-color','#eeeeee',0,''),(42615,13558,'119108','printshop-mobile','padding-top','30',0,''),(42616,13558,'119108','printshop-mobile','padding-bottom','30',0,''),(42617,13559,'119109','printshop-mobile','block_type','4',0,''),(42618,13559,'119109','printshop-mobile','schema','4-2',0,''),(42619,13560,'119110','printshop-mobile','block_type','1',0,''),(42620,13560,'119110','printshop-mobile','padding-right','40',0,''),(42622,13561,'119111','printshop-mobile','block_type','1',0,''),(42623,13561,'119111','printshop-mobile','padding-top','30',0,''),(42624,13561,'119111','printshop-mobile','padding-left','30',0,''),(42625,13561,'119111','printshop-mobile','padding-right','30',0,''),(42626,13561,'119111','printshop-mobile','padding-bottom','23',0,''),(42627,13561,'119111','printshop-mobile','margin-bottom','20',0,''),(42628,13561,'119111','printshop-mobile','background-color','#ffffff',0,''),(42629,13561,'119111','printshop-mobile','style_class','hiding-box',0,''),(42630,13562,'119112','printshop-mobile','block_type','2',0,''),(42631,13562,'119112','printshop-mobile','schema','2-2',0,''),(42632,13563,'119113','printshop-mobile','padding-right','20',0,''),(42634,13563,'119113','printshop-mobile','padding-bottom','20',0,''),(42635,13564,'119114','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42636,13565,'119115','printshop-mobile','block_type','1',0,''),(42637,13565,'119115','printshop-mobile','padding-left','20',0,''),(42639,13566,'119116','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42640,13568,'119118','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(42641,13569,'119119','printshop-mobile','block_type','1',0,''),(42642,13569,'119119','printshop-mobile','background-color','#ffffff',0,''),(42643,13569,'119119','printshop-mobile','padding-top','30',0,''),(42644,13569,'119119','printshop-mobile','padding-left','30',0,''),(42645,13569,'119119','printshop-mobile','padding-right','30',0,''),(42646,13569,'119119','printshop-mobile','padding-bottom','14',0,''),(42647,13569,'119119','printshop-mobile','margin-bottom','20',0,''),(42648,13569,'119119','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42649,13570,'119120','printshop-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(42650,13570,'119120','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42651,13571,'119121','printshop-mobile','style_class','closeable-content',0,''),(42652,13571,'119121','printshop-mobile','padding-bottom','20',0,''),(42653,13572,'119122','printshop-mobile','background-color','#ffffff',0,''),(42654,13572,'119122','printshop-mobile','padding-top','30',0,''),(42655,13572,'119122','printshop-mobile','padding-left','30',0,''),(42656,13572,'119122','printshop-mobile','padding-right','30',0,''),(42657,13572,'119122','printshop-mobile','padding-bottom','30',0,''),(42658,13572,'119122','printshop-mobile','margin-bottom','20',0,''),(42659,13573,'119123','printshop-mobile','background-color','#ffffff',0,''),(42660,13573,'119123','printshop-mobile','block_type','1',0,''),(42661,13573,'119123','printshop-mobile','padding-top','30',0,''),(42662,13573,'119123','printshop-mobile','padding-left','30',0,''),(42663,13573,'119123','printshop-mobile','padding-right','30',0,''),(42664,13573,'119123','printshop-mobile','padding-bottom','30',0,''),(42665,13573,'119123','printshop-mobile','margin-bottom','20',0,''),(42666,13573,'119123','printshop-mobile','style_class','hiding-box',0,''),(42667,13574,'119124','printshop-mobile','block_type','2',0,''),(42668,13574,'119124','printshop-mobile','schema','2-2',0,''),(42669,13575,'119125','printshop-mobile','block_type','1',0,''),(42670,13575,'119125','printshop-mobile','padding-right','20',0,''),(42671,13575,'119125','printshop-mobile','padding-left','0',0,''),(42672,13575,'119125','printshop-mobile','margin-bottom','20',0,''),(42673,13576,'119126','printshop-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(42674,13579,'119129','printshop-mobile','block_type','1',0,''),(42675,13579,'119129','printshop-mobile','padding-left','20',0,''),(42677,13580,'119130','printshop-mobile','border-top-width','1',0,''),(42678,13580,'119130','printshop-mobile','border-top-color','#e0e0e0',0,''),(42679,13580,'119130','printshop-mobile','padding-top','13',0,''),(42680,13580,'119130','printshop-mobile','padding-bottom','10',0,''),(42681,13581,'119131','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42682,13583,'119133','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(42683,13584,'119134','printshop-mobile','background-color','#eeeeee',0,''),(42684,13584,'119134','printshop-mobile','padding-top','10',0,''),(42685,13584,'119134','printshop-mobile','padding-left','10',0,''),(42686,13584,'119134','printshop-mobile','padding-right','10',0,''),(42687,13584,'119134','printshop-mobile','padding-bottom','10',0,''),(42688,13584,'119134','printshop-mobile','margin-top','10',0,''),(42689,13585,'119135','printshop-mobile','block_type','1',0,''),(42690,13585,'119135','printshop-mobile','content','\\_',0,'3'),(42691,13585,'119135','printshop-mobile','border-top-width','1',0,'3'),(42692,13585,'119135','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(42693,13585,'119135','printshop-mobile','display','block',0,'3'),(42694,13585,'119135','printshop-mobile','position','absolute',0,'3'),(42695,13585,'119135','printshop-mobile','top','19',0,'3'),(42696,13585,'119135','printshop-mobile','left','0',0,'3'),(42697,13585,'119135','printshop-mobile','right','0',0,'3'),(42698,13585,'119135','printshop-mobile','margin-top','-2',0,'3'),(42699,13585,'119135','printshop-mobile','position','relative',0,''),(42700,13586,'119136','printshop-mobile','box_align','2',0,''),(42701,13586,'119136','printshop-mobile','margin-bottom','10',0,''),(42702,13586,'119136','printshop-mobile','background-color','#ffffff',0,''),(42703,13586,'119136','printshop-mobile','position','relative',0,''),(42704,13587,'119137','printshop-mobile','block_type','1',0,''),(42705,13587,'119137','printshop-mobile','background-color','#ffffff',0,''),(42706,13587,'119137','printshop-mobile','padding-top','30',0,''),(42707,13587,'119137','printshop-mobile','padding-left','30',0,''),(42708,13587,'119137','printshop-mobile','padding-right','30',0,''),(42709,13587,'119137','printshop-mobile','padding-bottom','30',0,''),(42710,13587,'119137','printshop-mobile','margin-bottom','20',0,''),(42711,13587,'119137','printshop-mobile','style_class','hiding-box',0,''),(42712,13588,'119138','printshop-mobile','margin-bottom','20',0,''),(42713,13589,'119139','printshop-mobile','padding-top','10',0,''),(42714,13589,'119139','printshop-mobile','padding-left','20',0,''),(42715,13589,'119139','printshop-mobile','padding-right','20',0,''),(42716,13589,'119139','printshop-mobile','margin-top','20',0,''),(42717,13589,'119139','printshop-mobile','background-color','#eeeeee',0,''),(42718,13589,'119139','printshop-mobile','padding-bottom','8',0,''),(42719,13590,'119140','printshop-mobile','block_type','1',0,''),(42720,13590,'119140','printshop-mobile','padding-top','20',0,''),(42721,13590,'119140','printshop-mobile','padding-left','20',0,''),(42722,13590,'119140','printshop-mobile','padding-right','20',0,''),(42723,13590,'119140','printshop-mobile','padding-bottom','20',0,''),(42724,13590,'119140','printshop-mobile','background-color','#ffffff',0,''),(42725,13590,'119140','printshop-mobile','style_class','order-summary',0,''),(42726,13592,'119142','printshop-mobile','margin-bottom','10',0,''),(42727,13593,'119143','printshop-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(42728,13593,'119143','printshop-mobile','text-align','center',0,''),(42729,13593,'119143','printshop-mobile','font-size','14',0,''),(42730,13593,'119143','printshop-mobile','color','#757575',0,''),(42731,13593,'119143','printshop-mobile','padding-top','10',0,''),(42732,13594,'119144','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(42733,13595,'119145','printshop-mobile','block_type','1',0,''),(42734,13595,'119145','printshop-mobile','padding-top','30',0,''),(42735,13595,'119145','printshop-mobile','padding-bottom','30',0,''),(42736,13595,'119145','printshop-mobile','background-color','#eeeeeh',0,''),(42737,13596,'119146','printshop-mobile','block_type','4',0,''),(42738,13596,'119146','printshop-mobile','schema','4-2',0,''),(42739,13597,'119147','printshop-mobile','block_type','1',0,''),(42740,13597,'119147','printshop-mobile','padding-right','40',0,''),(42742,13598,'119148','printshop-mobile','block_type','1',0,''),(42743,13598,'119148','printshop-mobile','padding-top','30',0,''),(42744,13598,'119148','printshop-mobile','padding-left','30',0,''),(42745,13598,'119148','printshop-mobile','padding-right','30',0,''),(42746,13598,'119148','printshop-mobile','padding-bottom','14',0,''),(42747,13598,'119148','printshop-mobile','margin-bottom','20',0,''),(42748,13598,'119148','printshop-mobile','background-color','#ffffff',0,''),(42749,13598,'119148','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42750,13599,'119149','printshop-mobile','block_type','2',0,''),(42751,13599,'119149','printshop-mobile','style_class','closeable-content',0,''),(42752,13599,'119149','printshop-mobile','schema','2-2',0,''),(42753,13600,'119150','printshop-mobile','padding-right','20',0,''),(42754,13600,'119150','printshop-mobile','padding-bottom','20',0,''),(42756,13601,'119151','printshop-mobile','padding-left','20',0,''),(42757,13601,'119151','printshop-mobile','padding-bottom','20',0,''),(42759,13602,'119152','printshop-mobile','padding-left','20',0,''),(42760,13602,'119152','printshop-mobile','padding-bottom','20',0,''),(42762,13603,'119153','printshop-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(42763,13603,'119153','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42764,13604,'119154','printshop-mobile','block_type','1',0,''),(42765,13604,'119154','printshop-mobile','padding-top','30',0,''),(42766,13604,'119154','printshop-mobile','padding-left','30',0,''),(42767,13604,'119154','printshop-mobile','padding-right','30',0,''),(42768,13604,'119154','printshop-mobile','padding-bottom','23',0,''),(42769,13604,'119154','printshop-mobile','margin-bottom','20',0,''),(42770,13604,'119154','printshop-mobile','background-color','#ffffff',0,''),(42771,13604,'119154','printshop-mobile','style_class','hiding-box',0,''),(42772,13605,'119155','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(42773,13606,'119156','printshop-mobile','block_type','2',0,''),(42774,13606,'119156','printshop-mobile','schema','2-2',0,''),(42775,13607,'119157','printshop-mobile','padding-right','20',0,''),(42777,13607,'119157','printshop-mobile','padding-bottom','20',0,''),(42778,13608,'119158','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42779,13609,'119159','printshop-mobile','block_type','1',0,''),(42780,13609,'119159','printshop-mobile','padding-left','20',0,''),(42782,13611,'119161','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42783,13612,'119162','printshop-mobile','block_type','1',0,''),(42784,13612,'119162','printshop-mobile','background-color','#ffffff',0,''),(42785,13612,'119162','printshop-mobile','padding-top','30',0,''),(42786,13612,'119162','printshop-mobile','padding-left','30',0,''),(42787,13612,'119162','printshop-mobile','padding-right','30',0,''),(42788,13612,'119162','printshop-mobile','padding-bottom','14',0,''),(42789,13612,'119162','printshop-mobile','margin-bottom','20',0,''),(42790,13612,'119162','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42791,13613,'119163','printshop-mobile','style_class','closeable-content',0,''),(42792,13613,'119163','printshop-mobile','padding-bottom','20',0,''),(42793,13614,'119164','printshop-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(42794,13614,'119164','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42795,13615,'119165','printshop-mobile','background-color','#ffffff',0,''),(42796,13615,'119165','printshop-mobile','block_type','1',0,''),(42797,13615,'119165','printshop-mobile','padding-top','30',0,''),(42798,13615,'119165','printshop-mobile','padding-left','30',0,''),(42799,13615,'119165','printshop-mobile','padding-right','30',0,''),(42800,13615,'119165','printshop-mobile','padding-bottom','30',0,''),(42801,13615,'119165','printshop-mobile','margin-bottom','20',0,''),(42802,13615,'119165','printshop-mobile','style_class','hiding-box',0,''),(42803,13616,'119166','printshop-mobile','block_type','1',0,''),(42804,13616,'119166','printshop-mobile','content','\\_',0,'3'),(42805,13616,'119166','printshop-mobile','border-top-width','1',0,'3'),(42806,13616,'119166','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(42807,13616,'119166','printshop-mobile','display','block',0,'3'),(42808,13616,'119166','printshop-mobile','position','absolute',0,'3'),(42809,13616,'119166','printshop-mobile','top','19',0,'3'),(42810,13616,'119166','printshop-mobile','left','0',0,'3'),(42811,13616,'119166','printshop-mobile','right','0',0,'3'),(42812,13616,'119166','printshop-mobile','margin-top','-2',0,'3'),(42813,13616,'119166','printshop-mobile','position','relative',0,''),(42814,13617,'119167','printshop-mobile','box_align','2',0,''),(42815,13617,'119167','printshop-mobile','margin-bottom','10',0,''),(42816,13617,'119167','printshop-mobile','background-color','#ffffff',0,''),(42817,13617,'119167','printshop-mobile','position','relative',0,''),(42818,13618,'119168','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(42819,13619,'119169','printshop-mobile','block_type','2',0,''),(42820,13619,'119169','printshop-mobile','schema','2-2',0,''),(42821,13620,'119170','printshop-mobile','block_type','1',0,''),(42822,13620,'119170','printshop-mobile','padding-right','20',0,''),(42823,13620,'119170','printshop-mobile','padding-left','0',0,''),(42824,13620,'119170','printshop-mobile','margin-bottom','20',0,''),(42825,13622,'119172','printshop-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(42826,13624,'119174','printshop-mobile','block_type','1',0,''),(42827,13624,'119174','printshop-mobile','padding-left','20',0,''),(42829,13625,'119175','printshop-mobile','border-top-width','1',0,''),(42830,13625,'119175','printshop-mobile','border-top-color','#e0e0e0',0,''),(42831,13625,'119175','printshop-mobile','padding-top','13',0,''),(42832,13625,'119175','printshop-mobile','padding-bottom','10',0,''),(42833,13626,'119176','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42834,13628,'119178','printshop-mobile','background-color','#eeeeee',0,''),(42835,13628,'119178','printshop-mobile','padding-top','10',0,''),(42836,13628,'119178','printshop-mobile','padding-left','10',0,''),(42837,13628,'119178','printshop-mobile','padding-right','10',0,''),(42838,13628,'119178','printshop-mobile','padding-bottom','10',0,''),(42839,13628,'119178','printshop-mobile','margin-top','10',0,''),(42840,13629,'119179','printshop-mobile','block_type','1',0,''),(42841,13629,'119179','printshop-mobile','background-color','#ffffff',0,''),(42842,13629,'119179','printshop-mobile','padding-top','30',0,''),(42843,13629,'119179','printshop-mobile','padding-left','30',0,''),(42844,13629,'119179','printshop-mobile','padding-right','30',0,''),(42845,13629,'119179','printshop-mobile','padding-bottom','30',0,''),(42846,13629,'119179','printshop-mobile','margin-bottom','20',0,''),(42847,13629,'119179','printshop-mobile','style_class','hiding-box',0,''),(42848,13630,'119180','printshop-mobile','padding-top','10',0,''),(42849,13630,'119180','printshop-mobile','padding-left','20',0,''),(42850,13630,'119180','printshop-mobile','padding-right','20',0,''),(42851,13630,'119180','printshop-mobile','margin-top','20',0,''),(42852,13630,'119180','printshop-mobile','background-color','#eeeeee',0,''),(42853,13630,'119180','printshop-mobile','padding-bottom','8',0,''),(42854,13631,'119181','printshop-mobile','margin-bottom','20',0,''),(42855,13632,'119182','printshop-mobile','background-color','#ffffff',0,''),(42856,13632,'119182','printshop-mobile','padding-top','30',0,''),(42857,13632,'119182','printshop-mobile','padding-left','30',0,''),(42858,13632,'119182','printshop-mobile','padding-right','30',0,''),(42859,13632,'119182','printshop-mobile','padding-bottom','30',0,''),(42860,13632,'119182','printshop-mobile','margin-bottom','20',0,''),(42861,13633,'119183','printshop-mobile','block_type','1',0,''),(42862,13633,'119183','printshop-mobile','padding-top','20',0,''),(42863,13633,'119183','printshop-mobile','padding-left','20',0,''),(42864,13633,'119183','printshop-mobile','padding-right','20',0,''),(42865,13633,'119183','printshop-mobile','padding-bottom','20',0,''),(42866,13633,'119183','printshop-mobile','background-color','#ffffff',0,''),(42867,13633,'119183','printshop-mobile','style_class','order-summary',0,''),(42868,13634,'119184','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(42869,13636,'119186','printshop-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(42870,13636,'119186','printshop-mobile','text-align','center',0,''),(42871,13636,'119186','printshop-mobile','font-size','14',0,''),(42872,13636,'119186','printshop-mobile','color','#757575',0,''),(42873,13636,'119186','printshop-mobile','padding-top','10',0,''),(42874,13637,'119187','printshop-mobile','margin-bottom','10',0,''),(42875,13640,'119190','printshop-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(42876,13643,'119193','printshop-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(42877,13644,'119194','printshop-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(42878,13647,'119197','printshop-mobile','style_class','order-summary',0,''),(42879,13647,'119197','printshop-mobile','box_align','3',0,''),(42880,13647,'119197','printshop-mobile','width','400',0,''),(42881,13648,'119198','printshop-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(42882,13650,'119200','printshop-mobile','block_type','1',0,''),(42883,13651,'119201','printshop-mobile','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(42884,13652,'119202','printshop-mobile','margin-bottom','30',0,''),(42885,13653,'119203','printshop-mobile','float','right',0,''),(42886,13653,'119203','printshop-mobile','position','relative',0,''),(42887,13653,'119203','printshop-mobile','z-index','1',0,''),(42888,13653,'119203','printshop-mobile','top','30',0,''),(42889,13653,'119203','printshop-mobile','margin-bottom','-20',0,''),(42890,13654,'119204','printshop-mobile','block_type','1',0,''),(42891,13655,'119205','printshop-mobile','listing_type','Compare Products',0,''),(42892,13656,'119206','printshop-mobile','block_type','1',0,''),(42893,13656,'119206','printshop-mobile','style_class','item-holder',0,''),(42894,13656,'119206','printshop-mobile','padding-top','10',0,''),(42895,13656,'119206','printshop-mobile','padding-left','20',0,''),(42896,13656,'119206','printshop-mobile','padding-right','20',0,''),(42897,13656,'119206','printshop-mobile','padding-bottom','10',0,''),(42898,13656,'119206','printshop-mobile','text-align','left',0,''),(42899,13659,'119209','printshop-mobile','margin-bottom','10',0,''),(42900,13660,'119210','printshop-mobile','block_type','5',0,''),(42901,13662,'119212','printshop-mobile','clear','both',0,''),(42902,13663,'119213','printshop-mobile','block_type','2',0,''),(42903,13664,'119214','printshop-mobile','margin-bottom','7',0,''),(42904,13665,'119215','printshop-mobile','text-align','right',0,''),(42905,13665,'119215','printshop-mobile','margin-bottom','10',0,''),(42906,13665,'119215','printshop-mobile','float','right',0,''),(42907,13666,'119216','printshop-mobile','block_type','1',0,''),(42908,13666,'119216','printshop-mobile','background-color','#eeeeee',0,''),(42909,13666,'119216','printshop-mobile','padding-bottom','30',0,''),(42910,13667,'119217','printshop-mobile','block_type','1',0,''),(42911,13667,'119217','printshop-mobile','schema','4-2',0,''),(42912,13667,'119217','printshop-mobile','schema','4-2',0,'702'),(42913,13669,'119219','printshop-mobile','block_type','1',0,''),(42914,13669,'119219','printshop-mobile','padding-right','40',0,''),(42916,13670,'119220','printshop-mobile','block_type','1',0,''),(42917,13670,'119220','printshop-mobile','margin-bottom','20',0,''),(42918,13670,'119220','printshop-mobile','schema','2-2',0,''),(42919,13670,'119220','printshop-mobile','background-color','#ffffff',0,''),(42920,13671,'119221','printshop-mobile','block_type','1',0,''),(42921,13671,'119221','printshop-mobile','border-right-width','20',0,''),(42922,13671,'119221','printshop-mobile','border-right-color','#e0e0e0',0,''),(42923,13671,'119221','printshop-mobile','margin-right','-10',0,''),(42924,13671,'119221','printshop-mobile','padding-right','30',0,''),(42925,13671,'119221','printshop-mobile','padding-top','20',0,''),(42926,13671,'119221','printshop-mobile','padding-left','30',0,''),(42927,13671,'119221','printshop-mobile','padding-bottom','20',0,''),(42930,13671,'119221','printshop-mobile','margin-bottom','20',0,''),(42933,13672,'119222','printshop-mobile','margin-bottom','20',0,''),(42934,13673,'119223','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(42935,13674,'119224','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(42936,13674,'119224','printshop-mobile','clear','none',0,''),(42937,13676,'119226','printshop-mobile','link','shipping_address',0,''),(42938,13676,'119226','printshop-mobile','float','right',0,''),(42939,13676,'119226','printshop-mobile','margin-top','-31',0,''),(42940,13677,'119227','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42941,13677,'119227','printshop-mobile','clear','none',0,''),(42942,13679,'119229','printshop-mobile','link','contact_information',0,''),(42943,13679,'119229','printshop-mobile','margin-top','-31',0,''),(42944,13679,'119229','printshop-mobile','float','right',0,''),(42945,13680,'119230','printshop-mobile','link','shipping_method',0,''),(42946,13680,'119230','printshop-mobile','float','right',0,''),(42947,13680,'119230','printshop-mobile','margin-top','-31',0,''),(42948,13681,'119231','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(42949,13681,'119231','printshop-mobile','padding-top','20',0,''),(42950,13683,'119233','printshop-mobile','block_type','1',0,''),(42951,13683,'119233','printshop-mobile','padding-left','30',0,''),(42952,13683,'119233','printshop-mobile','border-left-width','20',0,''),(42953,13683,'119233','printshop-mobile','border-left-color','#e0e0e0',0,''),(42954,13683,'119233','printshop-mobile','margin-left','-10',0,''),(42955,13683,'119233','printshop-mobile','padding-right','30',0,''),(42956,13683,'119233','printshop-mobile','padding-top','20',0,''),(42957,13683,'119233','printshop-mobile','padding-bottom','20',0,''),(42959,13684,'119234','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42960,13684,'119234','printshop-mobile','clear','none',0,''),(42961,13685,'119235','printshop-mobile','margin-bottom','20',0,''),(42962,13686,'119236','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42963,13686,'119236','printshop-mobile','clear','none',0,''),(42964,13688,'119238','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(42965,13689,'119239','printshop-mobile','link','billing_address',0,''),(42966,13689,'119239','printshop-mobile','float','right',0,''),(42967,13689,'119239','printshop-mobile','margin-top','-31',0,''),(42968,13690,'119240','printshop-mobile','link','payment_method',0,''),(42969,13690,'119240','printshop-mobile','float','right',0,''),(42970,13690,'119240','printshop-mobile','margin-top','-31',0,''),(42971,13691,'119241','printshop-mobile','block_type','1',0,''),(42972,13691,'119241','printshop-mobile','padding-right','30',0,''),(42973,13691,'119241','printshop-mobile','background-color','#ffffff',0,''),(42974,13691,'119241','printshop-mobile','padding-top','20',0,''),(42975,13691,'119241','printshop-mobile','padding-left','30',0,''),(42976,13691,'119241','printshop-mobile','padding-bottom','20',0,''),(42979,13692,'119242','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(42980,13693,'119243','printshop-mobile','link','products',0,''),(42981,13693,'119243','printshop-mobile','float','right',0,''),(42982,13693,'119243','printshop-mobile','margin-top','-37',0,''),(42983,13695,'119245','printshop-mobile','block_type','1',0,''),(42984,13695,'119245','printshop-mobile','background-color','#ffffff',0,''),(42985,13695,'119245','printshop-mobile','padding-top','20',0,''),(42986,13695,'119245','printshop-mobile','padding-bottom','20',0,''),(42987,13695,'119245','printshop-mobile','padding-left','30',0,''),(42988,13695,'119245','printshop-mobile','padding-right','30',0,''),(42989,13695,'119245','printshop-mobile','margin-bottom','20',0,''),(42990,13696,'119246','printshop-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(42991,13697,'119247','printshop-mobile','hide_parents','2',0,''),(42992,13698,'119248','printshop-mobile','float','right',0,''),(42993,13698,'119248','printshop-mobile','margin-top','-37',0,''),(42994,13698,'119248','printshop-mobile','link','comments',0,''),(42995,13699,'119249','printshop-mobile','block_type','1',0,''),(42996,13699,'119249','printshop-mobile','padding-top','20',0,''),(42997,13699,'119249','printshop-mobile','padding-left','20',0,''),(42998,13699,'119249','printshop-mobile','padding-right','20',0,''),(42999,13699,'119249','printshop-mobile','padding-bottom','20',0,''),(43000,13699,'119249','printshop-mobile','background-color','#ffffff',0,''),(43001,13699,'119249','printshop-mobile','style_class','order-summary2 hiding-box',0,''),(43002,13701,'119251','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(43003,13702,'119252','printshop-mobile','margin-bottom','20',0,''),(43004,13702,'119252','printshop-mobile','text-align','right',0,''),(43005,13703,'119253','printshop-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(43006,13704,'119254','printshop-mobile','block_type','1',0,''),(43007,13704,'119254','printshop-mobile','background-color','#eeeeee',0,''),(43008,13704,'119254','printshop-mobile','padding-bottom','30',0,''),(43009,13705,'119255','printshop-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(43010,13706,'119256','printshop-mobile','block_type','4',0,''),(43011,13706,'119256','printshop-mobile','schema','4-2',0,''),(43012,13707,'119257','printshop-mobile','block_type','1',0,''),(43013,13707,'119257','printshop-mobile','padding-right','40',0,''),(43015,13708,'119258','printshop-mobile','block_type','2',0,''),(43016,13708,'119258','printshop-mobile','margin-bottom','20',0,''),(43017,13708,'119258','printshop-mobile','schema','2-2',0,''),(43018,13708,'119258','printshop-mobile','background-color','#ffffff',0,''),(43019,13709,'119259','printshop-mobile','block_type','1',0,''),(43020,13709,'119259','printshop-mobile','border-right-width','20',0,''),(43021,13709,'119259','printshop-mobile','border-right-color','#e0e0e0',0,''),(43022,13709,'119259','printshop-mobile','margin-right','-10',0,''),(43023,13709,'119259','printshop-mobile','padding-right','30',0,''),(43024,13709,'119259','printshop-mobile','padding-top','20',0,''),(43025,13709,'119259','printshop-mobile','padding-left','30',0,''),(43026,13709,'119259','printshop-mobile','padding-bottom','20',0,''),(43029,13709,'119259','printshop-mobile','margin-bottom','20',0,''),(43032,13710,'119260','printshop-mobile','link','shipping_method',0,''),(43033,13710,'119260','printshop-mobile','float','right',0,''),(43034,13710,'119260','printshop-mobile','margin-top','-31',0,''),(43035,13711,'119261','printshop-mobile','margin-bottom','20',0,''),(43036,13712,'119262','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(43037,13712,'119262','printshop-mobile','clear','none',0,''),(43038,13714,'119264','printshop-mobile','link','shipping_address',0,''),(43039,13714,'119264','printshop-mobile','float','right',0,''),(43040,13714,'119264','printshop-mobile','margin-top','-31',0,''),(43041,13715,'119265','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(43042,13715,'119265','printshop-mobile','clear','none',0,''),(43043,13716,'119266','printshop-mobile','block_type','1',0,''),(43044,13716,'119266','printshop-mobile','padding-left','30',0,''),(43045,13716,'119266','printshop-mobile','border-left-width','20',0,''),(43046,13716,'119266','printshop-mobile','border-left-color','#e0e0e0',0,''),(43047,13716,'119266','printshop-mobile','margin-left','-10',0,''),(43048,13716,'119266','printshop-mobile','padding-right','30',0,''),(43049,13716,'119266','printshop-mobile','padding-top','20',0,''),(43050,13716,'119266','printshop-mobile','padding-bottom','20',0,''),(43052,13717,'119267','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(43053,13718,'119268','printshop-mobile','link','contact_information',0,''),(43054,13718,'119268','printshop-mobile','margin-top','-31',0,''),(43055,13718,'119268','printshop-mobile','float','right',0,''),(43056,13721,'119271','printshop-mobile','block_type','1',0,''),(43057,13721,'119271','printshop-mobile','background-color','#ffffff',0,''),(43058,13721,'119271','printshop-mobile','padding-top','20',0,''),(43059,13721,'119271','printshop-mobile','padding-bottom','20',0,''),(43060,13721,'119271','printshop-mobile','padding-left','30',0,''),(43061,13721,'119271','printshop-mobile','padding-right','30',0,''),(43062,13721,'119271','printshop-mobile','margin-bottom','20',0,''),(43063,13722,'119272','printshop-mobile','hide_parents','2',0,''),(43064,13723,'119273','printshop-mobile','float','right',0,''),(43065,13723,'119273','printshop-mobile','margin-top','-37',0,''),(43066,13723,'119273','printshop-mobile','link','comments',0,''),(43067,13724,'119274','printshop-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(43068,13725,'119275','printshop-mobile','block_type','1',0,''),(43069,13725,'119275','printshop-mobile','padding-right','30',0,''),(43070,13725,'119275','printshop-mobile','background-color','#ffffff',0,''),(43071,13725,'119275','printshop-mobile','padding-top','20',0,''),(43072,13725,'119275','printshop-mobile','padding-left','30',0,''),(43073,13725,'119275','printshop-mobile','padding-bottom','20',0,''),(43076,13727,'119277','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(43077,13728,'119278','printshop-mobile','link','products',0,''),(43078,13728,'119278','printshop-mobile','float','right',0,''),(43079,13728,'119278','printshop-mobile','margin-top','-37',0,''),(43080,13729,'119279','printshop-mobile','block_type','1',0,''),(43081,13729,'119279','printshop-mobile','padding-top','20',0,''),(43082,13729,'119279','printshop-mobile','padding-left','20',0,''),(43083,13729,'119279','printshop-mobile','padding-right','20',0,''),(43084,13729,'119279','printshop-mobile','padding-bottom','20',0,''),(43085,13729,'119279','printshop-mobile','background-color','#ffffff',0,''),(43086,13729,'119279','printshop-mobile','style_class','order-summary',0,''),(43087,13730,'119280','printshop-mobile','margin-bottom','20',0,''),(43088,13730,'119280','printshop-mobile','text-align','right',0,''),(43089,13731,'119281','printshop-mobile','block_type','1',0,''),(43090,13731,'119281','printshop-mobile','background-color','#eeeeee',0,''),(43091,13731,'119281','printshop-mobile','padding-bottom','30',0,''),(43092,13732,'119282','printshop-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(43093,13733,'119283','printshop-mobile','block_type','4',0,''),(43094,13734,'119284','printshop-mobile','block_type','1',0,''),(43095,13734,'119284','printshop-mobile','padding-right','40',0,''),(43096,13735,'119285','printshop-mobile','block_type','1',0,''),(43097,13735,'119285','printshop-mobile','padding-right','30',0,''),(43099,13735,'119285','printshop-mobile','background-color','#ffffff',0,''),(43100,13735,'119285','printshop-mobile','padding-top','20',0,''),(43101,13735,'119285','printshop-mobile','padding-left','30',0,''),(43102,13735,'119285','printshop-mobile','padding-bottom','20',0,''),(43103,13736,'119286','printshop-mobile','link','products',0,''),(43104,13736,'119286','printshop-mobile','float','right',0,''),(43105,13736,'119286','printshop-mobile','margin-top','-37',0,''),(43106,13737,'119287','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(43107,13739,'119289','printshop-mobile','block_type','1',0,''),(43108,13739,'119289','printshop-mobile','background-color','#ffffff',0,''),(43109,13739,'119289','printshop-mobile','padding-top','20',0,''),(43110,13739,'119289','printshop-mobile','padding-bottom','20',0,''),(43111,13739,'119289','printshop-mobile','padding-left','30',0,''),(43112,13739,'119289','printshop-mobile','padding-right','30',0,''),(43113,13739,'119289','printshop-mobile','margin-bottom','20',0,''),(43114,13740,'119290','printshop-mobile','float','right',0,''),(43115,13740,'119290','printshop-mobile','margin-top','-37',0,''),(43116,13740,'119290','printshop-mobile','link','comments',0,''),(43117,13741,'119291','printshop-mobile','hide_parents','2',0,''),(43118,13742,'119292','printshop-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(43119,13743,'119293','printshop-mobile','block_type','2',0,''),(43120,13743,'119293','printshop-mobile','margin-bottom','20',0,''),(43121,13743,'119293','printshop-mobile','schema','2-2',0,''),(43122,13743,'119293','printshop-mobile','background-color','#ffffff',0,''),(43123,13744,'119294','printshop-mobile','block_type','1',0,''),(43124,13744,'119294','printshop-mobile','padding-right','0',0,''),(43125,13744,'119294','printshop-mobile','border-right-width','20',0,''),(43126,13744,'119294','printshop-mobile','border-right-color','#e0e0e0',0,''),(43127,13744,'119294','printshop-mobile','margin-right','-10',0,''),(43129,13744,'119294','printshop-mobile','padding-top','20',0,''),(43130,13744,'119294','printshop-mobile','padding-left','30',0,''),(43131,13744,'119294','printshop-mobile','padding-bottom','20',0,''),(43132,13745,'119295','printshop-mobile','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(43133,13745,'119295','printshop-mobile','padding-top','20',0,''),(43134,13747,'119297','printshop-mobile','link','contact_information',0,''),(43135,13747,'119297','printshop-mobile','margin-top','-37',0,''),(43136,13747,'119297','printshop-mobile','float','right',0,''),(43137,13748,'119298','printshop-mobile','block_type','1',0,''),(43138,13748,'119298','printshop-mobile','padding-left','30',0,''),(43140,13748,'119298','printshop-mobile','border-left-width','20',0,''),(43141,13748,'119298','printshop-mobile','border-left-color','#e0e0e0',0,''),(43142,13748,'119298','printshop-mobile','margin-left','-10',0,''),(43143,13748,'119298','printshop-mobile','padding-right','30',0,''),(43144,13748,'119298','printshop-mobile','padding-top','20',0,''),(43145,13748,'119298','printshop-mobile','padding-bottom','20',0,''),(43146,13749,'119299','printshop-mobile','link','billing_address',0,''),(43147,13749,'119299','printshop-mobile','float','right',0,''),(43148,13749,'119299','printshop-mobile','margin-top','-31',0,''),(43149,13750,'119300','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(43150,13750,'119300','printshop-mobile','clear','none',0,''),(43151,13751,'119301','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(43152,13752,'119302','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(43153,13752,'119302','printshop-mobile','clear','none',0,''),(43154,13753,'119303','printshop-mobile','margin-bottom','20',0,''),(43155,13755,'119305','printshop-mobile','link','payment_method',0,''),(43156,13755,'119305','printshop-mobile','float','right',0,''),(43157,13755,'119305','printshop-mobile','margin-top','-31',0,''),(43158,13756,'119306','printshop-mobile','block_type','1',0,''),(43159,13756,'119306','printshop-mobile','padding-top','20',0,''),(43160,13756,'119306','printshop-mobile','padding-left','20',0,''),(43161,13756,'119306','printshop-mobile','padding-right','20',0,''),(43162,13756,'119306','printshop-mobile','padding-bottom','20',0,''),(43163,13756,'119306','printshop-mobile','background-color','#ffffff',0,''),(43164,13756,'119306','printshop-mobile','style_class','order-summary2 hiding-box',0,''),(43165,13757,'119307','printshop-mobile','margin-bottom','20',0,''),(43166,13757,'119307','printshop-mobile','text-align','right',0,''),(43167,13759,'119309','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(43168,13760,'119310','printshop-mobile','block_type','1',0,''),(43169,13760,'119310','printshop-mobile','background-color','#eeeeee',0,''),(43170,13760,'119310','printshop-mobile','padding-bottom','30',0,''),(43171,13761,'119311','printshop-mobile','block_type','4',0,''),(43172,13761,'119311','printshop-mobile','schema','4-2',0,''),(43173,13762,'119312','printshop-mobile','block_type','1',0,''),(43174,13762,'119312','printshop-mobile','padding-right','40',0,''),(43176,13763,'119313','printshop-mobile','block_type','1',0,''),(43177,13763,'119313','printshop-mobile','padding-right','30',0,''),(43178,13763,'119313','printshop-mobile','background-color','#ffffff',0,''),(43179,13763,'119313','printshop-mobile','padding-top','20',0,''),(43180,13763,'119313','printshop-mobile','padding-left','30',0,''),(43181,13763,'119313','printshop-mobile','padding-bottom','20',0,''),(43184,13764,'119314','printshop-mobile','margin-bottom','20',0,''),(43185,13765,'119315','printshop-mobile','link','products',0,''),(43186,13765,'119315','printshop-mobile','float','right',0,''),(43187,13765,'119315','printshop-mobile','margin-top','-37',0,''),(43188,13766,'119316','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(43189,13767,'119317','printshop-mobile','block_type','2',0,''),(43190,13767,'119317','printshop-mobile','margin-bottom','20',0,''),(43191,13767,'119317','printshop-mobile','schema','2-2',0,''),(43192,13767,'119317','printshop-mobile','background-color','#ffffff',0,''),(43193,13768,'119318','printshop-mobile','block_type','1',0,''),(43194,13768,'119318','printshop-mobile','border-right-width','20',0,''),(43195,13768,'119318','printshop-mobile','border-right-color','#e0e0e0',0,''),(43196,13768,'119318','printshop-mobile','margin-right','-10',0,''),(43197,13768,'119318','printshop-mobile','padding-right','30',0,''),(43198,13768,'119318','printshop-mobile','padding-top','20',0,''),(43199,13768,'119318','printshop-mobile','padding-left','30',0,''),(43200,13768,'119318','printshop-mobile','padding-bottom','20',0,''),(43203,13768,'119318','printshop-mobile','margin-bottom','20',0,''),(43206,13769,'119319','printshop-mobile','link','payment_method',0,''),(43207,13769,'119319','printshop-mobile','float','right',0,''),(43208,13769,'119319','printshop-mobile','margin-top','-31',0,''),(43209,13770,'119320','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(43210,13770,'119320','printshop-mobile','clear','none',0,''),(43211,13771,'119321','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(43212,13771,'119321','printshop-mobile','padding-top','20',0,''),(43213,13773,'119323','printshop-mobile','link','contact_information',0,''),(43214,13773,'119323','printshop-mobile','margin-top','-31',0,''),(43215,13773,'119323','printshop-mobile','float','right',0,''),(43216,13775,'119325','printshop-mobile','block_type','1',0,''),(43217,13775,'119325','printshop-mobile','padding-left','30',0,''),(43218,13775,'119325','printshop-mobile','border-left-width','20',0,''),(43219,13775,'119325','printshop-mobile','border-left-color','#e0e0e0',0,''),(43220,13775,'119325','printshop-mobile','margin-left','-10',0,''),(43221,13775,'119325','printshop-mobile','padding-right','30',0,''),(43222,13775,'119325','printshop-mobile','padding-top','20',0,''),(43223,13775,'119325','printshop-mobile','padding-bottom','20',0,''),(43225,13776,'119326','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(43226,13776,'119326','printshop-mobile','clear','none',0,''),(43227,13777,'119327','printshop-mobile','link','billing_address',0,''),(43228,13777,'119327','printshop-mobile','float','right',0,''),(43229,13777,'119327','printshop-mobile','margin-top','-31',0,''),(43230,13778,'119328','printshop-mobile','margin-bottom','20',0,''),(43231,13779,'119329','printshop-mobile','block_type','1',0,''),(43232,13779,'119329','printshop-mobile','background-color','#ffffff',0,''),(43233,13779,'119329','printshop-mobile','padding-top','20',0,''),(43234,13779,'119329','printshop-mobile','padding-bottom','20',0,''),(43235,13779,'119329','printshop-mobile','padding-left','30',0,''),(43236,13779,'119329','printshop-mobile','padding-right','30',0,''),(43237,13779,'119329','printshop-mobile','margin-bottom','20',0,''),(43238,13780,'119330','printshop-mobile','hide_parents','2',0,''),(43239,13781,'119331','printshop-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(43240,13782,'119332','printshop-mobile','float','right',0,''),(43241,13782,'119332','printshop-mobile','margin-top','-37',0,''),(43242,13782,'119332','printshop-mobile','link','comments',0,''),(43243,13783,'119333','printshop-mobile','block_type','1',0,''),(43244,13783,'119333','printshop-mobile','padding-top','20',0,''),(43245,13783,'119333','printshop-mobile','padding-left','20',0,''),(43246,13783,'119333','printshop-mobile','padding-right','20',0,''),(43247,13783,'119333','printshop-mobile','padding-bottom','20',0,''),(43248,13783,'119333','printshop-mobile','background-color','#ffffff',0,''),(43249,13783,'119333','printshop-mobile','style_class','order-summary',0,''),(43250,13784,'119334','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(43251,13786,'119336','printshop-mobile','margin-bottom','20',0,''),(43252,13786,'119336','printshop-mobile','text-align','right',0,''),(43253,13787,'119337','printshop-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(43254,13788,'119338','printshop-mobile','block_type','1',0,''),(43255,13788,'119338','printshop-mobile','background-color','#eeeeee',0,''),(43256,13788,'119338','printshop-mobile','padding-bottom','30',0,''),(43257,13789,'119339','printshop-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(43258,13790,'119340','printshop-mobile','block_type','4',0,''),(43259,13790,'119340','printshop-mobile','schema','4-2',0,''),(43260,13791,'119341','printshop-mobile','block_type','1',0,''),(43261,13791,'119341','printshop-mobile','padding-right','40',0,''),(43263,13792,'119342','printshop-mobile','block_type','1',0,''),(43264,13792,'119342','printshop-mobile','padding-right','30',0,''),(43265,13792,'119342','printshop-mobile','background-color','#ffffff',0,''),(43266,13792,'119342','printshop-mobile','padding-top','20',0,''),(43267,13792,'119342','printshop-mobile','padding-left','30',0,''),(43268,13792,'119342','printshop-mobile','padding-bottom','20',0,''),(43271,13793,'119343','printshop-mobile','link','products',0,''),(43272,13793,'119343','printshop-mobile','float','right',0,''),(43273,13793,'119343','printshop-mobile','margin-top','-37',0,''),(43274,13794,'119344','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(43275,13796,'119346','printshop-mobile','block_type','1',0,''),(43276,13796,'119346','printshop-mobile','background-color','#ffffff',0,''),(43277,13796,'119346','printshop-mobile','padding-top','20',0,''),(43278,13796,'119346','printshop-mobile','padding-bottom','20',0,''),(43279,13796,'119346','printshop-mobile','padding-left','30',0,''),(43280,13796,'119346','printshop-mobile','padding-right','30',0,''),(43281,13796,'119346','printshop-mobile','margin-bottom','20',0,''),(43282,13797,'119347','printshop-mobile','float','right',0,''),(43283,13797,'119347','printshop-mobile','margin-top','-37',0,''),(43284,13797,'119347','printshop-mobile','link','comments',0,''),(43285,13798,'119348','printshop-mobile','hide_parents','2',0,''),(43286,13799,'119349','printshop-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(43287,13800,'119350','printshop-mobile','block_type','2',0,''),(43288,13800,'119350','printshop-mobile','margin-bottom','20',0,''),(43289,13800,'119350','printshop-mobile','schema','2-2',0,''),(43290,13800,'119350','printshop-mobile','background-color','#ffffff',0,''),(43291,13801,'119351','printshop-mobile','block_type','1',0,''),(43292,13801,'119351','printshop-mobile','border-right-width','20',0,''),(43293,13801,'119351','printshop-mobile','border-right-color','#e0e0e0',0,''),(43294,13801,'119351','printshop-mobile','margin-right','-10',0,''),(43295,13801,'119351','printshop-mobile','padding-right','30',0,''),(43296,13801,'119351','printshop-mobile','padding-top','20',0,''),(43297,13801,'119351','printshop-mobile','padding-left','30',0,''),(43298,13801,'119351','printshop-mobile','padding-bottom','20',0,''),(43301,13801,'119351','printshop-mobile','margin-bottom','20',0,''),(43304,13802,'119352','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(43305,13802,'119352','printshop-mobile','clear','none',0,''),(43306,13803,'119353','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(43307,13803,'119353','printshop-mobile','padding-top','20',0,''),(43308,13804,'119354','printshop-mobile','link','shipping_method',0,''),(43309,13804,'119354','printshop-mobile','float','right',0,''),(43310,13804,'119354','printshop-mobile','margin-top','-31',0,''),(43311,13806,'119356','printshop-mobile','link','shipping_address',0,''),(43312,13806,'119356','printshop-mobile','float','right',0,''),(43313,13806,'119356','printshop-mobile','margin-top','-31',0,''),(43314,13808,'119358','printshop-mobile','margin-bottom','20',0,''),(43315,13810,'119360','printshop-mobile','link','contact_information',0,''),(43316,13810,'119360','printshop-mobile','margin-top','-31',0,''),(43317,13810,'119360','printshop-mobile','float','right',0,''),(43318,13811,'119361','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(43319,13811,'119361','printshop-mobile','clear','none',0,''),(43320,13812,'119362','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(43321,13813,'119363','printshop-mobile','block_type','1',0,''),(43322,13813,'119363','printshop-mobile','padding-left','30',0,''),(43323,13813,'119363','printshop-mobile','border-left-width','20',0,''),(43324,13813,'119363','printshop-mobile','border-left-color','#e0e0e0',0,''),(43325,13813,'119363','printshop-mobile','margin-left','-10',0,''),(43326,13813,'119363','printshop-mobile','padding-right','30',0,''),(43327,13813,'119363','printshop-mobile','padding-top','20',0,''),(43328,13813,'119363','printshop-mobile','padding-bottom','20',0,''),(43330,13814,'119364','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(43331,13815,'119365','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(43332,13815,'119365','printshop-mobile','clear','none',0,''),(43333,13817,'119367','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(43334,13817,'119367','printshop-mobile','clear','none',0,''),(43335,13818,'119368','printshop-mobile','margin-bottom','20',0,''),(43336,13819,'119369','printshop-mobile','link','payment_method',0,''),(43337,13819,'119369','printshop-mobile','float','right',0,''),(43338,13819,'119369','printshop-mobile','margin-top','-31',0,''),(43339,13820,'119370','printshop-mobile','link','billing_address',0,''),(43340,13820,'119370','printshop-mobile','float','right',0,''),(43341,13820,'119370','printshop-mobile','margin-top','-31',0,''),(43342,13821,'119371','printshop-mobile','block_type','1',0,''),(43343,13821,'119371','printshop-mobile','padding-top','20',0,''),(43344,13821,'119371','printshop-mobile','padding-left','20',0,''),(43345,13821,'119371','printshop-mobile','padding-right','20',0,''),(43346,13821,'119371','printshop-mobile','padding-bottom','20',0,''),(43347,13821,'119371','printshop-mobile','background-color','#ffffff',0,''),(43348,13821,'119371','printshop-mobile','style_class','order-summary',0,''),(43349,13822,'119372','printshop-mobile','margin-bottom','20',0,''),(43350,13822,'119372','printshop-mobile','text-align','right',0,''),(43351,13823,'119373','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(43352,13825,'119375','printshop-mobile','block_type','1',0,''),(43353,13825,'119375','printshop-mobile','background-color','#eeeeee',0,''),(43354,13825,'119375','printshop-mobile','padding-bottom','30',0,''),(43355,13826,'119376','printshop-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(43356,13827,'119377','printshop-mobile','block_type','4',0,''),(43357,13827,'119377','printshop-mobile','schema','4-2',0,''),(43358,13828,'119378','printshop-mobile','block_type','1',0,''),(43359,13828,'119378','printshop-mobile','padding-right','40',0,''),(43361,13829,'119379','printshop-mobile','block_type','1',0,''),(43362,13829,'119379','printshop-mobile','background-color','#ffffff',0,''),(43363,13829,'119379','printshop-mobile','padding-top','20',0,''),(43364,13829,'119379','printshop-mobile','padding-bottom','20',0,''),(43365,13829,'119379','printshop-mobile','padding-left','30',0,''),(43366,13829,'119379','printshop-mobile','padding-right','30',0,''),(43367,13829,'119379','printshop-mobile','margin-bottom','20',0,''),(43368,13830,'119380','printshop-mobile','hide_parents','2',0,''),(43369,13831,'119381','printshop-mobile','float','right',0,''),(43370,13831,'119381','printshop-mobile','margin-top','-37',0,''),(43371,13831,'119381','printshop-mobile','link','comments',0,''),(43372,13832,'119382','printshop-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(43373,13833,'119383','printshop-mobile','block_type','1',0,''),(43374,13833,'119383','printshop-mobile','padding-right','30',0,''),(43375,13833,'119383','printshop-mobile','background-color','#ffffff',0,''),(43376,13833,'119383','printshop-mobile','padding-top','20',0,''),(43377,13833,'119383','printshop-mobile','padding-left','30',0,''),(43378,13833,'119383','printshop-mobile','padding-bottom','20',0,''),(43381,13835,'119385','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(43382,13836,'119386','printshop-mobile','link','products',0,''),(43383,13836,'119386','printshop-mobile','float','right',0,''),(43384,13836,'119386','printshop-mobile','margin-top','-37',0,''),(43385,13837,'119387','printshop-mobile','block_type','2',0,''),(43386,13837,'119387','printshop-mobile','margin-bottom','20',0,''),(43387,13837,'119387','printshop-mobile','schema','2-2',0,''),(43388,13837,'119387','printshop-mobile','background-color','#ffffff',0,''),(43389,13838,'119388','printshop-mobile','block_type','1',0,''),(43390,13838,'119388','printshop-mobile','border-right-width','20',0,''),(43391,13838,'119388','printshop-mobile','border-right-color','#e0e0e0',0,''),(43392,13838,'119388','printshop-mobile','margin-right','-10',0,''),(43393,13838,'119388','printshop-mobile','padding-right','30',0,''),(43394,13838,'119388','printshop-mobile','padding-top','20',0,''),(43395,13838,'119388','printshop-mobile','padding-left','30',0,''),(43396,13838,'119388','printshop-mobile','padding-bottom','20',0,''),(43399,13838,'119388','printshop-mobile','margin-bottom','20',0,''),(43402,13839,'119389','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(43403,13839,'119389','printshop-mobile','padding-top','20',0,''),(43404,13841,'119391','printshop-mobile','link','shipping_method',0,''),(43405,13841,'119391','printshop-mobile','float','right',0,''),(43406,13841,'119391','printshop-mobile','margin-top','-31',0,''),(43407,13842,'119392','printshop-mobile','link','contact_information',0,''),(43408,13842,'119392','printshop-mobile','margin-top','-31',0,''),(43409,13842,'119392','printshop-mobile','float','right',0,''),(43410,13843,'119393','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(43411,13845,'119395','printshop-mobile','link','shipping_address',0,''),(43412,13845,'119395','printshop-mobile','float','right',0,''),(43413,13845,'119395','printshop-mobile','margin-top','-31',0,''),(43414,13846,'119396','printshop-mobile','margin-bottom','20',0,''),(43415,13847,'119397','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(43416,13847,'119397','printshop-mobile','clear','none',0,''),(43417,13848,'119398','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(43418,13848,'119398','printshop-mobile','clear','none',0,''),(43419,13850,'119400','printshop-mobile','block_type','1',0,''),(43420,13850,'119400','printshop-mobile','padding-left','30',0,''),(43421,13850,'119400','printshop-mobile','border-left-width','20',0,''),(43422,13850,'119400','printshop-mobile','border-left-color','#e0e0e0',0,''),(43423,13850,'119400','printshop-mobile','margin-left','-10',0,''),(43424,13850,'119400','printshop-mobile','padding-right','30',0,''),(43425,13850,'119400','printshop-mobile','padding-top','20',0,''),(43426,13850,'119400','printshop-mobile','padding-bottom','20',0,''),(43428,13851,'119401','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(43429,13851,'119401','printshop-mobile','clear','none',0,''),(43430,13852,'119402','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(43431,13853,'119403','printshop-mobile','link','payment_method',0,''),(43432,13853,'119403','printshop-mobile','float','right',0,''),(43433,13853,'119403','printshop-mobile','margin-top','-31',0,''),(43434,13854,'119404','printshop-mobile','margin-bottom','20',0,''),(43435,13855,'119405','printshop-mobile','link','billing_address',0,''),(43436,13855,'119405','printshop-mobile','float','right',0,''),(43437,13855,'119405','printshop-mobile','margin-top','-31',0,''),(43438,13856,'119406','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(43439,13856,'119406','printshop-mobile','clear','none',0,''),(43440,13858,'119408','printshop-mobile','block_type','1',0,''),(43441,13858,'119408','printshop-mobile','padding-top','20',0,''),(43442,13858,'119408','printshop-mobile','padding-left','20',0,''),(43443,13858,'119408','printshop-mobile','padding-right','20',0,''),(43444,13858,'119408','printshop-mobile','padding-bottom','20',0,''),(43445,13858,'119408','printshop-mobile','background-color','#ffffff',0,''),(43446,13858,'119408','printshop-mobile','style_class','order-summary',0,''),(43447,13860,'119410','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(43448,13861,'119411','printshop-mobile','margin-bottom','20',0,''),(43449,13861,'119411','printshop-mobile','text-align','right',0,''),(43450,13862,'119412','printshop-mobile','block_type','1',0,''),(43451,13863,'119413','printshop-mobile','block_type','2',0,''),(43452,13863,'119413','printshop-mobile','font-weight','400',0,''),(43453,13863,'119413','printshop-mobile','padding-bottom','20',0,''),(43454,13863,'119413','printshop-mobile','schema','2-2',0,''),(43455,13863,'119413','printshop-mobile','schema','2-2',0,'694'),(43456,13865,'119415','printshop-mobile','street_heading','90',0,''),(43457,13866,'119416','printshop-mobile','block_type','2',0,''),(43458,13866,'119416','printshop-mobile','font-weight','400',0,''),(43459,13866,'119416','printshop-mobile','padding-bottom','20',0,''),(43460,13866,'119416','printshop-mobile','schema','2-2',0,'694'),(43461,13867,'119417','printshop-mobile','show_captcha','on',0,''),(43462,13868,'119418','printshop-mobile','font-weight','400',0,''),(43463,13868,'119418','printshop-mobile','padding-left','40',0,''),(43464,13868,'119418','printshop-mobile','time_format','24',0,''),(43465,13868,'119418','printshop-mobile','show_icons','on',0,''),(43466,13868,'119418','printshop-mobile','padding-left','0',0,'694'),(43467,13870,'119420','printshop-mobile','block_type','1',0,''),(43468,13871,'119421','printshop-mobile','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(43469,13871,'119421','printshop-mobile','margin-bottom','40',0,''),(43470,13872,'119422','printshop-mobile','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(43471,13873,'119423','printshop-mobile','width','680',0,''),(43472,13873,'119423','printshop-mobile','font-weight','normal',0,''),(43473,13873,'119423','printshop-mobile','font-size','12',0,''),(43474,13873,'119423','printshop-mobile','padding-top','20',0,''),(43475,13873,'119423','printshop-mobile','padding-bottom','20',0,''),(43476,13873,'119423','printshop-mobile','color','#424242',0,''),(43477,13874,'119424','printshop-mobile','block_type','4',0,''),(43478,13874,'119424','printshop-mobile','font-weight','normal',0,''),(43479,13874,'119424','printshop-mobile','border-top-width','1',0,''),(43480,13874,'119424','printshop-mobile','border-top-color','#e0e0e0',0,''),(43481,13874,'119424','printshop-mobile','border-left-width','1',0,''),(43482,13874,'119424','printshop-mobile','border-left-color','#e0e0e0',0,''),(43483,13874,'119424','printshop-mobile','border-right-width','1',0,''),(43484,13874,'119424','printshop-mobile','border-right-color','#e0e0e0',0,''),(43485,13874,'119424','printshop-mobile','border-bottom-width','1',0,''),(43486,13874,'119424','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(43487,13875,'119425','printshop-mobile','block_type','2',0,''),(43488,13875,'119425','printshop-mobile','font-weight','normal',0,''),(43489,13875,'119425','printshop-mobile','border-top-width','1',0,''),(43490,13875,'119425','printshop-mobile','border-top-color','#e0e0e0',0,''),(43491,13875,'119425','printshop-mobile','border-right-width','1',0,''),(43492,13875,'119425','printshop-mobile','border-right-color','#e0e0e0',0,''),(43493,13876,'119426','printshop-mobile','block_type','1',0,''),(43494,13876,'119426','printshop-mobile','font-weight','normal',0,''),(43495,13876,'119426','printshop-mobile','padding-top','10',0,''),(43496,13876,'119426','printshop-mobile','padding-left','10',0,''),(43497,13876,'119426','printshop-mobile','padding-right','10',0,''),(43498,13876,'119426','printshop-mobile','padding-bottom','10',0,''),(43499,13876,'119426','printshop-mobile','border-right-width','1',0,''),(43500,13876,'119426','printshop-mobile','border-right-color','#e0e0e0',0,''),(43501,13877,'119427','printshop-mobile','text','<p>Shipping via</p>',1,''),(43502,13877,'119427','printshop-mobile','font-weight','bold',0,''),(43503,13877,'119427','printshop-mobile','font-size','14',0,''),(43504,13879,'119429','printshop-mobile','block_type','1',0,''),(43505,13879,'119429','printshop-mobile','font-weight','normal',0,''),(43506,13879,'119429','printshop-mobile','padding-top','10',0,''),(43507,13879,'119429','printshop-mobile','padding-left','10',0,''),(43508,13879,'119429','printshop-mobile','padding-right','10',0,''),(43509,13879,'119429','printshop-mobile','padding-bottom','10',0,''),(43510,13881,'119431','printshop-mobile','text','<p>Shipping service</p>',1,''),(43511,13881,'119431','printshop-mobile','font-weight','bold',0,''),(43512,13881,'119431','printshop-mobile','font-size','14',0,''),(43513,13882,'119432','printshop-mobile','block_type','2',0,''),(43514,13882,'119432','printshop-mobile','font-weight','normal',0,''),(43515,13882,'119432','printshop-mobile','border-right-width','1',0,''),(43516,13882,'119432','printshop-mobile','border-right-color','#e0e0e0',0,''),(43517,13883,'119433','printshop-mobile','block_type','1',0,''),(43518,13883,'119433','printshop-mobile','font-weight','400',0,''),(43519,13883,'119433','printshop-mobile','background-color','#eeeeee',0,''),(43520,13883,'119433','printshop-mobile','padding-top','10',0,''),(43521,13883,'119433','printshop-mobile','padding-left','10',0,''),(43522,13883,'119433','printshop-mobile','padding-right','10',0,''),(43523,13883,'119433','printshop-mobile','padding-bottom','30',0,''),(43524,13884,'119434','printshop-mobile','font-size','12',0,''),(43525,13885,'119435','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(43526,13885,'119435','printshop-mobile','font-size','14',0,''),(43527,13885,'119435','printshop-mobile','font-weight','bold',0,''),(43528,13886,'119436','printshop-mobile','block_type','1',0,''),(43529,13886,'119436','printshop-mobile','font-weight','normal',0,''),(43530,13886,'119436','printshop-mobile','padding-top','10',0,''),(43531,13886,'119436','printshop-mobile','padding-left','10',0,''),(43532,13886,'119436','printshop-mobile','padding-right','10',0,''),(43533,13886,'119436','printshop-mobile','padding-bottom','10',0,''),(43534,13887,'119437','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(43535,13887,'119437','printshop-mobile','font-weight','bold',0,''),(43536,13887,'119437','printshop-mobile','font-size','14',0,''),(43537,13887,'119437','printshop-mobile','padding-top','10',0,''),(43538,13888,'119438','printshop-mobile','font-weight','normal',0,''),(43539,13890,'119440','printshop-mobile','text','<p>PHONE NUMBER:</p>',1,''),(43540,13890,'119440','printshop-mobile','font-size','14',0,''),(43541,13890,'119440','printshop-mobile','font-weight','bold',0,''),(43542,13890,'119440','printshop-mobile','padding-top','10',0,''),(43543,13891,'119441','printshop-mobile','text','<p>CUSTOMER:</p>',1,''),(43544,13891,'119441','printshop-mobile','font-size','13',0,''),(43545,13891,'119441','printshop-mobile','font-weight','bold',0,''),(43546,13892,'119442','printshop-mobile','font-weight','normal',0,''),(43547,13893,'119443','printshop-mobile','font-weight','normal',0,''),(43548,13893,'119443','printshop-mobile','text-align','center',0,''),(43549,13893,'119443','printshop-mobile','padding-bottom','10',0,''),(43550,13894,'119444','printshop-mobile','text','<p>Payment date:</p>',1,''),(43551,13894,'119444','printshop-mobile','font-weight','bold',0,''),(43552,13894,'119444','printshop-mobile','text-align','center',0,''),(43553,13894,'119444','printshop-mobile','font-size','12',0,''),(43554,13895,'119445','printshop-mobile','font-size','14',0,''),(43555,13895,'119445','printshop-mobile','font-weight','bold',0,''),(43556,13895,'119445','printshop-mobile','text-align','center',0,''),(43557,13895,'119445','printshop-mobile','padding-bottom','10',0,''),(43558,13895,'119445','printshop-mobile','padding-top','10',0,''),(43559,13896,'119446','printshop-mobile','block_type','5',0,''),(43560,13896,'119446','printshop-mobile','font-weight','normal',0,''),(43561,13896,'119446','printshop-mobile','border-bottom-width','1',0,''),(43562,13896,'119446','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(43563,13896,'119446','printshop-mobile','border-top-width','1',0,''),(43564,13896,'119446','printshop-mobile','border-top-color','#e0e0e0',0,''),(43565,13896,'119446','printshop-mobile','border-left-color','#e0e0e0',0,''),(43566,13896,'119446','printshop-mobile','border-left-width','1',0,''),(43567,13897,'119447','printshop-mobile','block_type','1',0,''),(43568,13897,'119447','printshop-mobile','font-weight','normal',0,''),(43569,13897,'119447','printshop-mobile','padding-top','10',0,''),(43570,13897,'119447','printshop-mobile','padding-left','10',0,''),(43571,13897,'119447','printshop-mobile','padding-right','10',0,''),(43572,13898,'119448','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(43573,13898,'119448','printshop-mobile','font-size','14',0,''),(43574,13898,'119448','printshop-mobile','font-weight','bold',0,''),(43575,13898,'119448','printshop-mobile','padding-bottom','10',0,''),(43576,13899,'119449','printshop-mobile','font-weight','400',0,''),(43577,13899,'119449','printshop-mobile','line-height','120',0,''),(43578,13899,'119449','printshop-mobile','line_height_measure','%',0,''),(43579,13899,'119449','printshop-mobile','font-size','12',0,''),(43580,13900,'119450','printshop-mobile','block_type','1',0,''),(43581,13900,'119450','printshop-mobile','background-color','#eeeeee',0,''),(43582,13900,'119450','printshop-mobile','padding-top','20',0,''),(43583,13900,'119450','printshop-mobile','padding-left','10',0,''),(43584,13900,'119450','printshop-mobile','padding-right','10',0,''),(43585,13900,'119450','printshop-mobile','padding-bottom','20',0,''),(43586,13900,'119450','printshop-mobile','font-size','14',0,''),(43587,13901,'119451','printshop-mobile','block_type','2',0,''),(43588,13901,'119451','printshop-mobile','font-weight','normal',0,''),(43589,13901,'119451','printshop-mobile','padding-bottom','20',0,''),(43590,13902,'119452','printshop-mobile','font-weight','400',0,''),(43591,13902,'119452','printshop-mobile','padding-top','20',0,''),(43593,13903,'119453','printshop-mobile','block_type','1',0,''),(43594,13904,'119454','printshop-mobile','font-weight','normal',0,''),(43595,13904,'119454','printshop-mobile','text-align','right',0,''),(43596,13904,'119454','printshop-mobile','padding-bottom','10',0,''),(43597,13904,'119454','printshop-mobile','address_spacer',',',0,''),(43598,13904,'119454','printshop-mobile','font-size','12',0,''),(43599,13905,'119455','printshop-mobile','block_type','11',0,''),(43600,13905,'119455','printshop-mobile','font-weight','normal',0,''),(43601,13906,'119456','printshop-mobile','text','<p>Email:</p>',1,''),(43602,13906,'119456','printshop-mobile','font-weight','normal',0,''),(43603,13906,'119456','printshop-mobile','text-align','right',0,''),(43604,13907,'119457','printshop-mobile','font-weight','normal',0,''),(43605,13907,'119457','printshop-mobile','text-align','right',0,''),(43606,13908,'119458','printshop-mobile','block_type','11',0,''),(43607,13908,'119458','printshop-mobile','font-weight','normal',0,''),(43608,13909,'119459','printshop-mobile','text','<p>Phone:</p>',1,''),(43609,13909,'119459','printshop-mobile','font-weight','normal',0,''),(43610,13909,'119459','printshop-mobile','text-align','right',0,''),(43611,13910,'119460','printshop-mobile','font-weight','normal',0,''),(43612,13910,'119460','printshop-mobile','text-align','right',0,''),(43613,13911,'119461','printshop-mobile','block_type','11',0,''),(43614,13911,'119461','printshop-mobile','font-weight','normal',0,''),(43615,13912,'119462','printshop-mobile','text','<p>Web:</p>',1,''),(43616,13912,'119462','printshop-mobile','font-weight','normal',0,''),(43617,13912,'119462','printshop-mobile','text-align','right',0,''),(43618,13913,'119463','printshop-mobile','font-weight','normal',0,''),(43619,13913,'119463','printshop-mobile','text-align','right',0,''),(43620,13914,'119464','printshop-mobile','font-weight','400',0,''),(43621,13914,'119464','printshop-mobile','padding-top','20',0,''),(43622,13914,'119464','printshop-mobile','padding-bottom','0',0,''),(43623,13914,'119464','printshop-mobile','font-size','12',0,''),(43624,13915,'119465','printshop-mobile','block_type','3',0,''),(43625,13915,'119465','printshop-mobile','font-weight','normal',0,''),(43626,13915,'119465','printshop-mobile','padding-top','20',0,''),(43627,13916,'119466','printshop-mobile','font-size','12',0,''),(43628,13917,'119467','printshop-mobile','text','<p>If undelivered please return to:</p>',1,''),(43629,13917,'119467','printshop-mobile','font-size','12',0,''),(43630,13917,'119467','printshop-mobile','font-weight','bold',0,''),(43631,13918,'119468','printshop-mobile','text','<p>Thank you for your order</p>',1,''),(43632,13918,'119468','printshop-mobile','color','#1da1f2',0,''),(43633,13918,'119468','printshop-mobile','font-size','13',0,''),(43634,13918,'119468','printshop-mobile','font-weight','bold',0,''),(43635,13918,'119468','printshop-mobile','padding-top','5',0,''),(43636,13918,'119468','printshop-mobile','text-align','center',0,''),(43637,13919,'119469','printshop-mobile','font-weight','400',0,''),(43638,13919,'119469','printshop-mobile','text-align','center',0,''),(43639,13919,'119469','printshop-mobile','padding-top','0',0,''),(43641,13919,'119469','printshop-mobile','padding-left','20',0,''),(43642,13919,'119469','printshop-mobile','padding-right','20',0,''),(43643,13920,'119470','printshop-mobile','block_type','6',0,''),(43644,13920,'119470','printshop-mobile','font-weight','normal',0,''),(43645,13920,'119470','printshop-mobile','font-size','16',0,''),(43646,13921,'119471','printshop-mobile','text','<p>Phone:</p>',1,''),(43647,13921,'119471','printshop-mobile','font-weight','normal',0,''),(43648,13921,'119471','printshop-mobile','text-align','right',0,''),(43649,13921,'119471','printshop-mobile','font-size','12',0,''),(43650,13922,'119472','printshop-mobile','font-weight','normal',0,''),(43651,13922,'119472','printshop-mobile','text-align','right',0,''),(43652,13922,'119472','printshop-mobile','font-size','12',0,''),(43653,13923,'119473','printshop-mobile','block_type','6',0,''),(43654,13923,'119473','printshop-mobile','font-weight','normal',0,''),(43655,13923,'119473','printshop-mobile','font-size','16',0,''),(43656,13924,'119474','printshop-mobile','text','<p>Email:</p>',1,''),(43657,13924,'119474','printshop-mobile','font-weight','normal',0,''),(43658,13924,'119474','printshop-mobile','text-align','right',0,''),(43659,13924,'119474','printshop-mobile','font-size','12',0,''),(43660,13925,'119475','printshop-mobile','font-weight','normal',0,''),(43661,13925,'119475','printshop-mobile','text-align','right',0,''),(43662,13925,'119475','printshop-mobile','font-size','12',0,''),(43663,13926,'119476','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(43664,13926,'119476','printshop-mobile','font-size','12',0,''),(43665,13926,'119476','printshop-mobile','font-weight','bold',0,''),(43666,13926,'119476','printshop-mobile','text-align','right',0,''),(43667,13929,'119479','printshop-mobile','text-align','center',0,''),(43668,13929,'119479','printshop-mobile','padding-top','10',0,''),(43669,13935,'119485','printshop-mobile','heading_type','h1',0,''),(43670,13938,'119488','printshop-mobile','text-align','center',0,''),(43671,13938,'119488','printshop-mobile','padding-top','10',0,''),(43672,13943,'119493','printshop-mobile','font-weight','normal',0,''),(43673,13943,'119493','printshop-mobile','padding-top','20',0,''),(43674,13943,'119493','printshop-mobile','padding-left','10',0,''),(43675,13943,'119493','printshop-mobile','padding-right','10',0,''),(43676,13943,'119493','printshop-mobile','padding-bottom','20',0,''),(43677,13943,'119493','printshop-mobile','color','#444444',0,''),(43678,13943,'119493','printshop-mobile','font-size','14',0,''),(43679,13944,'119494','printshop-mobile','block_type','2',0,''),(43680,13944,'119494','printshop-mobile','font-weight','normal',0,''),(43681,13945,'119495','printshop-mobile','font-weight','normal',0,''),(43682,13945,'119495','printshop-mobile','padding-bottom','20',0,''),(43683,13946,'119496','printshop-mobile','color','#444444',0,''),(43684,13946,'119496','printshop-mobile','font-size','14',0,''),(43685,13946,'119496','printshop-mobile','padding-top','20',0,''),(43686,13946,'119496','printshop-mobile','padding-bottom','20',0,''),(43687,13946,'119496','printshop-mobile','border-top-width','1',0,''),(43688,13946,'119496','printshop-mobile','border-top-color','#cccccc',0,''),(43689,13947,'119497','printshop-mobile','block_type','1',0,''),(43690,13948,'119498','printshop-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',1,''),(43691,13948,'119498','printshop-mobile','font-weight','normal',0,''),(43692,13948,'119498','printshop-mobile','color','#444444',0,''),(43693,13948,'119498','printshop-mobile','font-size','14',0,''),(43694,13949,'119499','printshop-mobile','block_type','2',0,''),(43695,13949,'119499','printshop-mobile','font-weight','normal',0,''),(43696,13949,'119499','printshop-mobile','background-color','#092964',0,''),(43697,13949,'119499','printshop-mobile','padding-top','5',0,''),(43698,13949,'119499','printshop-mobile','padding-left','10',0,''),(43699,13949,'119499','printshop-mobile','padding-right','10',0,''),(43700,13949,'119499','printshop-mobile','padding-bottom','5',0,''),(43701,13950,'119500','printshop-mobile','color','#ffffff',0,''),(43702,13950,'119500','printshop-mobile','font-size','14',0,''),(43703,13950,'119500','printshop-mobile','font-weight','normal',0,''),(43704,13951,'119501','printshop-mobile','font-weight','normal',0,''),(43705,13951,'119501','printshop-mobile','text-align','right',0,''),(43706,13951,'119501','printshop-mobile','color','#ffffff',0,''),(43707,13951,'119501','printshop-mobile','font-size','12',0,''),(43708,13952,'119502','printshop-mobile','block_type','1',0,''),(43709,13953,'119503','printshop-mobile','block_type','1',0,''),(43710,13953,'119503','printshop-mobile','max-width','800',0,''),(43711,13953,'119503','printshop-mobile','margin','0 auto',0,''),(43712,13953,'119503','printshop-mobile','background-color','#ffffff',0,''),(43713,13954,'119504','printshop-mobile','font-weight','normal',0,''),(43714,13954,'119504','printshop-mobile','padding-top','20',0,''),(43715,13954,'119504','printshop-mobile','padding-left','10',0,''),(43716,13954,'119504','printshop-mobile','padding-right','10',0,''),(43717,13954,'119504','printshop-mobile','padding-bottom','20',0,''),(43718,13954,'119504','printshop-mobile','color','#424242',0,''),(43719,13954,'119504','printshop-mobile','font-size','14',0,''),(43720,13955,'119505','printshop-mobile','block_type','7',0,''),(43721,13955,'119505','printshop-mobile','font-weight','normal',0,''),(43722,13955,'119505','printshop-mobile','background-color','#183d78',0,''),(43723,13955,'119505','printshop-mobile','padding-top','5',0,''),(43724,13955,'119505','printshop-mobile','padding-left','10',0,''),(43725,13955,'119505','printshop-mobile','padding-right','10',0,''),(43726,13955,'119505','printshop-mobile','padding-bottom','5',0,''),(43727,13956,'119506','printshop-mobile','color','#ffffff',0,''),(43728,13956,'119506','printshop-mobile','font-size','15',0,''),(43729,13956,'119506','printshop-mobile','font-weight','700',0,''),(43730,13957,'119507','printshop-mobile','font-weight','normal',0,''),(43731,13957,'119507','printshop-mobile','text-align','right',0,''),(43732,13957,'119507','printshop-mobile','color','#757575',0,''),(43733,13957,'119507','printshop-mobile','font-size','12',0,''),(43734,13958,'119508','printshop-mobile','color','#424242',0,''),(43735,13958,'119508','printshop-mobile','font-size','12',0,''),(43736,13958,'119508','printshop-mobile','padding-top','20',0,''),(43737,13958,'119508','printshop-mobile','padding-bottom','20',0,''),(43738,13958,'119508','printshop-mobile','border-top-width','1',0,''),(43739,13958,'119508','printshop-mobile','border-top-color','#e0e0e0',0,''),(43740,13959,'119509','printshop-mobile','font-weight','normal',0,''),(43741,13959,'119509','printshop-mobile','padding-bottom','10',0,''),(43742,13959,'119509','printshop-mobile','background-color','#183d78',0,''),(43743,13959,'119509','printshop-mobile','logo','themes/printshop-mobile/img/logo-white-1.png',1,''),(43744,13959,'119509','printshop-mobile','padding-left','20',0,''),(43745,13959,'119509','printshop-mobile','padding-top','10',0,''),(43746,13960,'119510','printshop-mobile','block_type','1',0,''),(43747,13960,'119510','printshop-mobile','background-color','#eeeeee',0,''),(43748,13961,'119511','printshop-mobile','block_type','1',0,''),(43749,13961,'119511','printshop-mobile','max-width','800',0,''),(43750,13961,'119511','printshop-mobile','margin','0 auto',0,''),(43751,13962,'119512','printshop-mobile','font-weight','normal',0,''),(43752,13962,'119512','printshop-mobile','padding-bottom','10',0,''),(43753,13962,'119512','printshop-mobile','padding-top','10',0,''),(43754,13962,'119512','printshop-mobile','text-align','center',0,''),(43755,13962,'119512','printshop-mobile','logo_from','theme',0,''),(43756,13963,'119513','printshop-mobile','color','#757575',0,''),(43757,13963,'119513','printshop-mobile','font-size','12',0,''),(43758,13963,'119513','printshop-mobile','padding-top','20',0,''),(43759,13963,'119513','printshop-mobile','padding-bottom','20',0,''),(43760,13963,'119513','printshop-mobile','text-align','center',0,''),(43761,13964,'119514','printshop-mobile','block_type','1',0,''),(43762,13964,'119514','printshop-mobile','background-color','#ffffff',0,''),(43763,13964,'119514','printshop-mobile','padding-top','20',0,''),(43764,13964,'119514','printshop-mobile','padding-left','20',0,''),(43765,13964,'119514','printshop-mobile','padding-right','20',0,''),(43766,13964,'119514','printshop-mobile','padding-bottom','20',0,''),(43767,13965,'119515','printshop-mobile','block_type','7',0,''),(43768,13965,'119515','printshop-mobile','font-weight','normal',0,''),(43769,13965,'119515','printshop-mobile','padding-left','10',0,''),(43770,13965,'119515','printshop-mobile','padding-right','10',0,''),(43771,13965,'119515','printshop-mobile','padding-bottom','15',0,''),(43772,13965,'119515','printshop-mobile','border-bottom-width','1',0,''),(43773,13965,'119515','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(43774,13966,'119516','printshop-mobile','color','#424242',0,''),(43775,13966,'119516','printshop-mobile','font-size','14',0,''),(43776,13966,'119516','printshop-mobile','font-weight','700',0,''),(43777,13967,'119517','printshop-mobile','font-weight','normal',0,''),(43778,13967,'119517','printshop-mobile','text-align','right',0,''),(43779,13967,'119517','printshop-mobile','color','#757575',0,''),(43780,13967,'119517','printshop-mobile','font-size','11',0,''),(43781,13967,'119517','printshop-mobile','text-transform','uppercase',0,''),(43782,13968,'119518','printshop-mobile','font-weight','normal',0,''),(43783,13968,'119518','printshop-mobile','padding-top','20',0,''),(43784,13968,'119518','printshop-mobile','padding-bottom','20',0,''),(43785,13968,'119518','printshop-mobile','color','#424242',0,''),(43786,13968,'119518','printshop-mobile','font-size','14',0,''),(43787,13969,'119519','printshop-mobile','block_type','1',0,''),(43788,13969,'119519','printshop-mobile','background-color','#eeeeee',0,''),(43789,13969,'119519','printshop-mobile','padding-top','20',0,''),(43790,13969,'119519','printshop-mobile','padding-bottom','20',0,''),(43791,13970,'119520','printshop-mobile','block_type','1',0,''),(43792,13970,'119520','printshop-mobile','max-width','800',0,''),(43793,13970,'119520','printshop-mobile','margin','0 auto',0,''),(43794,13971,'119521','printshop-mobile','block_type','1',0,''),(43795,13971,'119521','printshop-mobile','background-color','#ffffff',0,''),(43796,13971,'119521','printshop-mobile','padding-top','20',0,''),(43797,13971,'119521','printshop-mobile','padding-left','20',0,''),(43798,13971,'119521','printshop-mobile','padding-right','20',0,''),(43799,13971,'119521','printshop-mobile','padding-bottom','20',0,''),(43800,13971,'119521','printshop-mobile','border-top-width','1',0,''),(43801,13971,'119521','printshop-mobile','border-left-width','1',0,''),(43802,13971,'119521','printshop-mobile','border-right-width','1',0,''),(43803,13971,'119521','printshop-mobile','border-bottom-width','1',0,''),(43804,13971,'119521','printshop-mobile','border-top-color','#e0e0e0',0,''),(43805,13971,'119521','printshop-mobile','border-left-color','#e0e0e0',0,''),(43806,13971,'119521','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(43807,13971,'119521','printshop-mobile','border-right-color','#e0e0e0',0,''),(43808,13972,'119522','printshop-mobile','font-weight','normal',0,''),(43809,13972,'119522','printshop-mobile','padding-top','20',0,''),(43810,13972,'119522','printshop-mobile','padding-bottom','20',0,''),(43811,13972,'119522','printshop-mobile','color','#424242',0,''),(43812,13972,'119522','printshop-mobile','font-size','14',0,''),(43813,13973,'119523','printshop-mobile','block_type','2',0,''),(43814,13974,'119524','printshop-mobile','font-weight','normal',0,''),(43815,13974,'119524','printshop-mobile','padding-bottom','10',0,''),(43816,13974,'119524','printshop-mobile','padding-top','10',0,''),(43817,13974,'119524','printshop-mobile','logo_from','theme',0,''),(43818,13975,'119525','printshop-mobile','color','#424242',0,''),(43819,13975,'119525','printshop-mobile','font-size','14',0,''),(43820,13975,'119525','printshop-mobile','font-weight','700',0,''),(43821,13975,'119525','printshop-mobile','text-align','right',0,''),(43822,13976,'119526','printshop-mobile','font-weight','normal',0,''),(43823,13976,'119526','printshop-mobile','text-align','right',0,''),(43824,13976,'119526','printshop-mobile','color','#757575',0,''),(43825,13976,'119526','printshop-mobile','font-size','11',0,''),(43826,13976,'119526','printshop-mobile','text-transform','uppercase',0,''),(43827,13977,'119527','printshop-mobile','color','#757575',0,''),(43828,13977,'119527','printshop-mobile','font-size','12',0,''),(43829,13977,'119527','printshop-mobile','padding-top','20',0,''),(43830,13977,'119527','printshop-mobile','padding-bottom','20',0,''),(43831,13977,'119527','printshop-mobile','text-align','left',0,''),(43832,13978,'119528','printshop-mobile','block_type','1',0,''),(43833,13978,'119528','printshop-mobile','font-weight','normal',0,''),(43834,13978,'119528','printshop-mobile','margin-top','40',0,''),(43835,13979,'119529','printshop-mobile','block_type','1',0,''),(43836,13980,'119530','printshop-mobile','text','Account',1,''),(43837,13980,'119530','printshop-mobile','style_class','footerTitle',0,''),(43838,13980,'119530','printshop-mobile','font-family','Varela Round',0,''),(43839,13980,'119530','printshop-mobile','font-size','18',0,''),(43840,13980,'119530','printshop-mobile','text-transform','uppercase',0,''),(43841,13981,'119531','printshop-mobile','class','menu-style-2',0,''),(43842,13981,'119531','printshop-mobile','padding-top','10',0,''),(43843,13981,'119531','printshop-mobile','padding-bottom','20',0,''),(43844,13982,'119532','printshop-mobile','border-top-width','1',0,''),(43845,13982,'119532','printshop-mobile','border-top-color','#e0e0e0',0,''),(43846,13982,'119532','printshop-mobile','padding-top','20',0,''),(43847,13983,'119533','printshop-mobile','block_type','1',0,''),(43848,13984,'119534','printshop-mobile','class','menu-style-2',0,''),(43849,13984,'119534','printshop-mobile','padding-top','10',0,''),(43850,13984,'119534','printshop-mobile','padding-bottom','20',0,''),(43851,13985,'119535','printshop-mobile','text','Account',1,''),(43852,13985,'119535','printshop-mobile','style_class','footerTitle',0,''),(43855,13985,'119535','printshop-mobile','font-family','Varela Round',0,''),(43856,13985,'119535','printshop-mobile','font-size','18',0,''),(43857,13985,'119535','printshop-mobile','text-transform','uppercase',0,''),(43858,13986,'119536','printshop-mobile','block_type','1',0,''),(43859,13987,'119537','printshop-mobile','text','Account',1,''),(43860,13987,'119537','printshop-mobile','style_class','footerTitle',0,''),(43863,13987,'119537','printshop-mobile','font-family','Varela Round',0,''),(43864,13987,'119537','printshop-mobile','text-transform','uppercase',0,''),(43865,13987,'119537','printshop-mobile','font-size','18',0,''),(43866,13988,'119538','printshop-mobile','class','menu-style-2',0,''),(43867,13988,'119538','printshop-mobile','padding-top','10',0,''),(43868,13988,'119538','printshop-mobile','padding-bottom','20',0,''),(43869,13989,'119539','printshop-mobile','block_type','1',0,''),(43870,13990,'119540','printshop-mobile','view_item','address',0,''),(43871,13990,'119540','printshop-mobile','address_spacer',',<span> </span>',0,''),(43872,13990,'119540','printshop-mobile','padding-top','10',0,''),(43873,13990,'119540','printshop-mobile','padding-bottom','20',0,''),(43874,13991,'119541','printshop-mobile','text','Account',1,''),(43875,13991,'119541','printshop-mobile','style_class','footerTitle',0,''),(43878,13991,'119541','printshop-mobile','font-family','Varela Round',0,''),(43879,13991,'119541','printshop-mobile','font-size','18',0,''),(43880,13991,'119541','printshop-mobile','text-transform','uppercase',0,''),(43881,13992,'119542','printshop-mobile','block_type','5',0,''),(43882,13993,'119543','printshop-mobile','text','##TEXT_LANGUAGE##',0,''),(43883,13995,'119545','printshop-mobile','block_type','5',0,''),(43884,13996,'119546','printshop-mobile','text','##TEXT_CURRENCY##',0,''),(43885,13998,'119548','printshop-mobile','block_type','1',0,''),(43886,13998,'119548','printshop-mobile','font-weight','normal',0,''),(43887,13999,'119549','printshop-mobile','block_type','2',0,''),(43888,13999,'119549','printshop-mobile','font-weight','normal',0,''),(43889,13999,'119549','printshop-mobile','padding-bottom','20',0,''),(43890,14000,'119550','printshop-mobile','block_type','1',0,''),(43891,14000,'119550','printshop-mobile','margin-right','20',0,''),(43892,14001,'119551','printshop-mobile','block_type','1',0,''),(43893,14001,'119551','printshop-mobile','font-weight','normal',0,''),(43894,14001,'119551','printshop-mobile','style_class','gift-card-view',0,''),(43895,14001,'119551','printshop-mobile','text-align','center',0,''),(43896,14001,'119551','printshop-mobile','padding-bottom','20',0,''),(43897,14001,'119551','printshop-mobile','background-color','#4546e2',0,''),(43898,14001,'119551','printshop-mobile','padding-left','20',0,''),(43899,14001,'119551','printshop-mobile','padding-right','20',0,''),(43900,14001,'119551','printshop-mobile','color','#f4f2f2',0,''),(43901,14002,'119552','printshop-mobile','block_type','1',0,''),(43902,14002,'119552','printshop-mobile','font-weight','normal',0,''),(43903,14002,'119552','printshop-mobile','padding-top','10',0,''),(43904,14003,'119553','printshop-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(43905,14003,'119553','printshop-mobile','font-weight','normal',0,''),(43906,14003,'119553','printshop-mobile','text-align','center',0,''),(43907,14003,'119553','printshop-mobile','font-size','12',0,''),(43908,14003,'119553','printshop-mobile','padding-top','10',0,''),(43909,14003,'119553','printshop-mobile','padding-bottom','5',0,''),(43910,14003,'119553','printshop-mobile','border-top-width','1',0,''),(43911,14003,'119553','printshop-mobile','border-top-color','#dfa82a',0,''),(43912,14004,'119554','printshop-mobile','font-size','12',0,''),(43913,14004,'119554','printshop-mobile','font-weight','bold',0,''),(43914,14004,'119554','printshop-mobile','text-align','center',0,''),(43915,14004,'119554','printshop-mobile','style_class','email',0,''),(43916,14005,'119555','printshop-mobile','font-size','12',0,''),(43917,14005,'119555','printshop-mobile','font-weight','bold',0,''),(43918,14005,'119555','printshop-mobile','text-align','center',0,''),(43919,14005,'119555','printshop-mobile','style_class','phone',0,''),(43920,14005,'119555','printshop-mobile','padding-bottom','5',0,''),(43921,14006,'119556','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(43922,14006,'119556','printshop-mobile','font-weight','normal',0,''),(43923,14006,'119556','printshop-mobile','text-align','center',0,''),(43924,14006,'119556','printshop-mobile','padding-top','20',0,''),(43925,14006,'119556','printshop-mobile','padding-bottom','10',0,''),(43926,14006,'119556','printshop-mobile','style_class','question-ico',0,''),(43927,14006,'119556','printshop-mobile','border-top-width','1',0,''),(43928,14006,'119556','printshop-mobile','border-top-color','#dfa82a',0,''),(43929,14006,'119556','printshop-mobile','font-size','18',0,''),(43930,14007,'119557','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(43931,14007,'119557','printshop-mobile','font-size','18',0,''),(43932,14007,'119557','printshop-mobile','font-weight','normal',0,''),(43933,14007,'119557','printshop-mobile','text-align','center',0,''),(43934,14007,'119557','printshop-mobile','padding-top','20',0,''),(43935,14007,'119557','printshop-mobile','padding-bottom','10',0,''),(43936,14007,'119557','printshop-mobile','border-top-width','1',0,''),(43937,14007,'119557','printshop-mobile','border-top-color','#dfa82a',0,''),(43938,14008,'119558','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(43939,14008,'119558','printshop-mobile','font-weight','normal',0,''),(43940,14008,'119558','printshop-mobile','text-align','center',0,''),(43941,14008,'119558','printshop-mobile','padding-bottom','10',0,''),(43942,14008,'119558','printshop-mobile','font-size','14',0,''),(43943,14009,'119559','printshop-mobile','text','<p>GIFT CARD</p>',1,''),(43944,14009,'119559','printshop-mobile','font-size','30',0,''),(43945,14009,'119559','printshop-mobile','font-weight','normal',0,''),(43946,14009,'119559','printshop-mobile','border-top-width','1',0,''),(43947,14009,'119559','printshop-mobile','border-top-color','#dfa82a',0,''),(43948,14009,'119559','printshop-mobile','style_class','gift-ico',0,''),(43949,14009,'119559','printshop-mobile','text-align','center',0,''),(43950,14009,'119559','printshop-mobile','padding-top','15',0,''),(43951,14010,'119560','printshop-mobile','block_type','4',0,''),(43952,14010,'119560','printshop-mobile','color','#ffffff',0,''),(43953,14010,'119560','printshop-mobile','font-size','30',0,''),(43954,14010,'119560','printshop-mobile','font-weight','normal',0,''),(43955,14010,'119560','printshop-mobile','background-color','#ee4225',0,''),(43956,14010,'119560','printshop-mobile','padding-top','5',0,''),(43957,14010,'119560','printshop-mobile','padding-left','10',0,''),(43958,14010,'119560','printshop-mobile','padding-right','10',0,''),(43959,14010,'119560','printshop-mobile','padding-bottom','5',0,''),(43960,14011,'119561','printshop-mobile','text','<p>Your code is:</p>',1,''),(43961,14011,'119561','printshop-mobile','font-weight','normal',0,''),(43962,14013,'119563','printshop-mobile','font-weight','normal',0,''),(43963,14013,'119563','printshop-mobile','text-align','center',0,''),(43964,14013,'119563','printshop-mobile','padding-bottom','20',0,''),(43965,14014,'119564','printshop-mobile','font-size','60',0,''),(43966,14014,'119564','printshop-mobile','font-weight','bold',0,''),(43967,14014,'119564','printshop-mobile','text-align','center',0,''),(43968,14014,'119564','printshop-mobile','line-height','100',0,''),(43969,14014,'119564','printshop-mobile','padding-bottom','20',0,''),(43970,14014,'119564','printshop-mobile','line_height_measure','px',0,''),(43971,14015,'119565','printshop-mobile','text','<p>HOLBI</p>',1,''),(43972,14015,'119565','printshop-mobile','font-family','Varela Round',0,''),(43973,14015,'119565','printshop-mobile','font-size','24',0,''),(43974,14015,'119565','printshop-mobile','font-weight','normal',0,''),(43975,14015,'119565','printshop-mobile','text-align','center',0,''),(43976,14015,'119565','printshop-mobile','padding-top','10',0,''),(43977,14015,'119565','printshop-mobile','padding-bottom','20',0,''),(43978,14017,'119567','printshop-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(43979,14017,'119567','printshop-mobile','font-weight','normal',0,''),(43980,14017,'119567','printshop-mobile','padding-bottom','20',0,''),(43981,14019,'119569','printshop-mobile','block_type','1',0,''),(43982,14019,'119569','printshop-mobile','font-weight','normal',0,''),(43983,14019,'119569','printshop-mobile','style_class','gift-card-view',0,''),(43984,14019,'119569','printshop-mobile','text-align','center',0,''),(43985,14019,'119569','printshop-mobile','padding-bottom','20',0,''),(43986,14019,'119569','printshop-mobile','background-color','#183d78',0,''),(43987,14019,'119569','printshop-mobile','padding-left','20',0,''),(43988,14019,'119569','printshop-mobile','padding-right','20',0,''),(43989,14019,'119569','printshop-mobile','color','#cccccc',0,''),(43990,14020,'119570','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(43991,14020,'119570','printshop-mobile','font-weight','normal',0,''),(43992,14020,'119570','printshop-mobile','text-align','center',0,''),(43993,14020,'119570','printshop-mobile','padding-bottom','10',0,''),(43994,14020,'119570','printshop-mobile','font-size','14',0,''),(43995,14021,'119571','printshop-mobile','text','<p>GIFT CARD</p>',1,''),(43996,14021,'119571','printshop-mobile','font-size','30',0,''),(43997,14021,'119571','printshop-mobile','font-weight','normal',0,''),(43998,14021,'119571','printshop-mobile','border-top-width','1',0,''),(43999,14021,'119571','printshop-mobile','border-top-color','#dfa82a',0,''),(44000,14021,'119571','printshop-mobile','style_class','gift-ico',0,''),(44001,14021,'119571','printshop-mobile','text-align','center',0,''),(44002,14021,'119571','printshop-mobile','padding-top','15',0,''),(44003,14022,'119572','printshop-mobile','logo','themes/printshop-mobile/img/logo-1.png',1,''),(44004,14023,'119573','printshop-mobile','logo','themes/printshop-mobile/img/bestseller-1.png',1,''),(44005,14024,'119574','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(44006,14024,'119574','printshop-mobile','font-size','18',0,''),(44007,14024,'119574','printshop-mobile','font-weight','normal',0,''),(44008,14024,'119574','printshop-mobile','text-align','center',0,''),(44009,14024,'119574','printshop-mobile','padding-top','20',0,''),(44010,14024,'119574','printshop-mobile','padding-bottom','10',0,''),(44011,14024,'119574','printshop-mobile','border-top-width','1',0,''),(44012,14024,'119574','printshop-mobile','border-top-color','#dfa82a',0,''),(44013,14025,'119575','printshop-mobile','font-size','60',0,''),(44014,14025,'119575','printshop-mobile','font-weight','bold',0,''),(44015,14025,'119575','printshop-mobile','text-align','center',0,''),(44016,14025,'119575','printshop-mobile','line-height','100',0,''),(44017,14025,'119575','printshop-mobile','padding-bottom','20',0,''),(44018,14025,'119575','printshop-mobile','line_height_measure','px',0,''),(44019,14026,'119576','printshop-mobile','font-weight','normal',0,''),(44020,14026,'119576','printshop-mobile','text-align','center',0,''),(44021,14026,'119576','printshop-mobile','padding-bottom','20',0,''),(44022,14027,'119577','printshop-mobile','block_type','4',0,''),(44023,14027,'119577','printshop-mobile','color','#ffffff',0,''),(44024,14027,'119577','printshop-mobile','font-size','30',0,''),(44025,14027,'119577','printshop-mobile','font-weight','normal',0,''),(44026,14027,'119577','printshop-mobile','background-color','#ee4225',0,''),(44027,14027,'119577','printshop-mobile','padding-top','5',0,''),(44028,14027,'119577','printshop-mobile','padding-left','10',0,''),(44029,14027,'119577','printshop-mobile','padding-right','10',0,''),(44030,14027,'119577','printshop-mobile','padding-bottom','5',0,''),(44031,14028,'119578','printshop-mobile','text','<p>Your code is:</p>',1,''),(44032,14028,'119578','printshop-mobile','font-weight','normal',0,''),(44033,14030,'119580','printshop-mobile','text','<p>HOLBI</p>',1,''),(44034,14030,'119580','printshop-mobile','font-family','Varela Round',0,''),(44035,14030,'119580','printshop-mobile','font-size','24',0,''),(44036,14030,'119580','printshop-mobile','font-weight','normal',0,''),(44037,14030,'119580','printshop-mobile','text-align','center',0,''),(44038,14030,'119580','printshop-mobile','padding-top','10',0,''),(44039,14030,'119580','printshop-mobile','padding-bottom','20',0,''),(44040,14031,'119581','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(44041,14031,'119581','printshop-mobile','font-weight','normal',0,''),(44042,14031,'119581','printshop-mobile','text-align','center',0,''),(44043,14031,'119581','printshop-mobile','padding-top','20',0,''),(44044,14031,'119581','printshop-mobile','padding-bottom','10',0,''),(44045,14031,'119581','printshop-mobile','style_class','question-ico',0,''),(44046,14031,'119581','printshop-mobile','border-top-width','1',0,''),(44047,14031,'119581','printshop-mobile','border-top-color','#dfa82a',0,''),(44048,14031,'119581','printshop-mobile','font-size','18',0,''),(44049,14032,'119582','printshop-mobile','block_type','1',0,''),(44050,14032,'119582','printshop-mobile','font-weight','normal',0,''),(44051,14032,'119582','printshop-mobile','padding-top','10',0,''),(44052,14033,'119583','printshop-mobile','font-size','12',0,''),(44053,14033,'119583','printshop-mobile','font-weight','bold',0,''),(44054,14033,'119583','printshop-mobile','text-align','center',0,''),(44055,14033,'119583','printshop-mobile','style_class','phone',0,''),(44056,14033,'119583','printshop-mobile','padding-bottom','5',0,''),(44057,14034,'119584','printshop-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(44058,14034,'119584','printshop-mobile','font-weight','normal',0,''),(44059,14034,'119584','printshop-mobile','text-align','center',0,''),(44060,14034,'119584','printshop-mobile','font-size','12',0,''),(44061,14034,'119584','printshop-mobile','padding-top','10',0,''),(44062,14034,'119584','printshop-mobile','padding-bottom','5',0,''),(44063,14034,'119584','printshop-mobile','border-top-width','1',0,''),(44064,14034,'119584','printshop-mobile','border-top-color','#dfa82a',0,''),(44065,14035,'119585','printshop-mobile','font-size','12',0,''),(44066,14035,'119585','printshop-mobile','font-weight','bold',0,''),(44067,14035,'119585','printshop-mobile','text-align','center',0,''),(44068,14035,'119585','printshop-mobile','style_class','email',0,''),(44069,14036,'119586','printshop-mobile','block_type','1',0,''),(44070,14036,'119586','printshop-mobile','font-weight','normal',0,''),(44071,14036,'119586','printshop-mobile','style_class','gift-card-view',0,''),(44072,14036,'119586','printshop-mobile','text-align','center',0,''),(44073,14036,'119586','printshop-mobile','padding-bottom','20',0,''),(44074,14036,'119586','printshop-mobile','background-color','#5289a4',0,''),(44075,14036,'119586','printshop-mobile','padding-left','20',0,''),(44076,14036,'119586','printshop-mobile','padding-right','20',0,''),(44077,14036,'119586','printshop-mobile','color','#cccccc',0,''),(44078,14037,'119587','printshop-mobile','text','<p>HOLBI</p>',1,''),(44079,14037,'119587','printshop-mobile','font-family','Varela Round',0,''),(44080,14037,'119587','printshop-mobile','font-size','24',0,''),(44081,14037,'119587','printshop-mobile','font-weight','normal',0,''),(44082,14037,'119587','printshop-mobile','text-align','center',0,''),(44083,14037,'119587','printshop-mobile','padding-top','10',0,''),(44084,14037,'119587','printshop-mobile','padding-bottom','20',0,''),(44085,14038,'119588','printshop-mobile','text','<p>GIFT CARD</p>',1,''),(44086,14038,'119588','printshop-mobile','font-size','30',0,''),(44087,14038,'119588','printshop-mobile','font-weight','normal',0,''),(44088,14038,'119588','printshop-mobile','border-top-width','1',0,''),(44089,14038,'119588','printshop-mobile','border-top-color','#dfa82a',0,''),(44090,14038,'119588','printshop-mobile','style_class','gift-ico',0,''),(44091,14038,'119588','printshop-mobile','text-align','center',0,''),(44092,14038,'119588','printshop-mobile','padding-top','15',0,''),(44093,14039,'119589','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(44094,14039,'119589','printshop-mobile','font-weight','normal',0,''),(44095,14039,'119589','printshop-mobile','text-align','center',0,''),(44096,14039,'119589','printshop-mobile','padding-top','20',0,''),(44097,14039,'119589','printshop-mobile','padding-bottom','10',0,''),(44098,14039,'119589','printshop-mobile','style_class','question-ico',0,''),(44099,14039,'119589','printshop-mobile','border-top-width','1',0,''),(44100,14039,'119589','printshop-mobile','border-top-color','#dfa82a',0,''),(44101,14039,'119589','printshop-mobile','font-size','18',0,''),(44102,14040,'119590','printshop-mobile','font-weight','normal',0,''),(44103,14040,'119590','printshop-mobile','text-align','center',0,''),(44104,14040,'119590','printshop-mobile','padding-bottom','20',0,''),(44105,14041,'119591','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(44106,14041,'119591','printshop-mobile','font-weight','normal',0,''),(44107,14041,'119591','printshop-mobile','text-align','center',0,''),(44108,14041,'119591','printshop-mobile','padding-bottom','10',0,''),(44109,14041,'119591','printshop-mobile','font-size','14',0,''),(44110,14042,'119592','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(44111,14042,'119592','printshop-mobile','font-size','18',0,''),(44112,14042,'119592','printshop-mobile','font-weight','normal',0,''),(44113,14042,'119592','printshop-mobile','text-align','center',0,''),(44114,14042,'119592','printshop-mobile','padding-top','20',0,''),(44115,14042,'119592','printshop-mobile','padding-bottom','10',0,''),(44116,14042,'119592','printshop-mobile','border-top-width','1',0,''),(44117,14042,'119592','printshop-mobile','border-top-color','#dfa82a',0,''),(44118,14043,'119593','printshop-mobile','block_type','1',0,''),(44119,14043,'119593','printshop-mobile','font-weight','normal',0,''),(44120,14043,'119593','printshop-mobile','padding-top','10',0,''),(44121,14044,'119594','printshop-mobile','font-size','12',0,''),(44122,14044,'119594','printshop-mobile','font-weight','bold',0,''),(44123,14044,'119594','printshop-mobile','text-align','center',0,''),(44124,14044,'119594','printshop-mobile','style_class','phone',0,''),(44125,14044,'119594','printshop-mobile','padding-bottom','5',0,''),(44126,14045,'119595','printshop-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(44127,14045,'119595','printshop-mobile','font-weight','normal',0,''),(44128,14045,'119595','printshop-mobile','text-align','center',0,''),(44129,14045,'119595','printshop-mobile','font-size','12',0,''),(44130,14045,'119595','printshop-mobile','padding-top','10',0,''),(44131,14045,'119595','printshop-mobile','padding-bottom','5',0,''),(44132,14045,'119595','printshop-mobile','border-top-width','1',0,''),(44133,14045,'119595','printshop-mobile','border-top-color','#dfa82a',0,''),(44134,14046,'119596','printshop-mobile','font-size','12',0,''),(44135,14046,'119596','printshop-mobile','font-weight','bold',0,''),(44136,14046,'119596','printshop-mobile','text-align','center',0,''),(44137,14046,'119596','printshop-mobile','style_class','email',0,''),(44138,14047,'119597','printshop-mobile','block_type','4',0,''),(44139,14047,'119597','printshop-mobile','color','#ffffff',0,''),(44140,14047,'119597','printshop-mobile','font-size','30',0,''),(44141,14047,'119597','printshop-mobile','font-weight','normal',0,''),(44142,14047,'119597','printshop-mobile','background-color','#ee4225',0,''),(44143,14047,'119597','printshop-mobile','padding-top','5',0,''),(44144,14047,'119597','printshop-mobile','padding-left','10',0,''),(44145,14047,'119597','printshop-mobile','padding-right','10',0,''),(44146,14047,'119597','printshop-mobile','padding-bottom','5',0,''),(44147,14048,'119598','printshop-mobile','text','<p>Your code is:</p>',1,''),(44148,14048,'119598','printshop-mobile','font-weight','normal',0,''),(44149,14050,'119600','printshop-mobile','font-size','60',0,''),(44150,14050,'119600','printshop-mobile','font-weight','bold',0,''),(44151,14050,'119600','printshop-mobile','text-align','center',0,''),(44152,14050,'119600','printshop-mobile','line-height','100',0,''),(44153,14050,'119600','printshop-mobile','padding-bottom','20',0,''),(44154,14050,'119600','printshop-mobile','line_height_measure','px',0,''),(44155,14051,'119601','printshop-mobile','block_type','1',0,''),(44156,14051,'119601','printshop-mobile','font-weight','normal',0,''),(44157,14051,'119601','printshop-mobile','style_class','gift-card-view',0,''),(44158,14051,'119601','printshop-mobile','text-align','center',0,''),(44159,14051,'119601','printshop-mobile','padding-bottom','20',0,''),(44160,14051,'119601','printshop-mobile','background-color','#5289a4',0,''),(44161,14051,'119601','printshop-mobile','padding-left','20',0,''),(44162,14051,'119601','printshop-mobile','padding-right','20',0,''),(44163,14051,'119601','printshop-mobile','color','#cccccc',0,''),(44164,14052,'119602','printshop-mobile','block_type','1',0,''),(44165,14052,'119602','printshop-mobile','font-weight','normal',0,''),(44166,14052,'119602','printshop-mobile','padding-top','10',0,''),(44167,14053,'119603','printshop-mobile','font-size','12',0,''),(44168,14053,'119603','printshop-mobile','font-weight','bold',0,''),(44169,14053,'119603','printshop-mobile','text-align','center',0,''),(44170,14053,'119603','printshop-mobile','style_class','email',0,''),(44171,14053,'119603','printshop-mobile','color','#ffffff',0,''),(44172,14054,'119604','printshop-mobile','font-size','12',0,''),(44173,14054,'119604','printshop-mobile','font-weight','bold',0,''),(44174,14054,'119604','printshop-mobile','text-align','center',0,''),(44175,14054,'119604','printshop-mobile','style_class','phone',0,''),(44176,14054,'119604','printshop-mobile','padding-bottom','5',0,''),(44177,14054,'119604','printshop-mobile','color','#ffffff',0,''),(44178,14055,'119605','printshop-mobile','text','If you require further assistance please contact us',0,''),(44179,14055,'119605','printshop-mobile','font-size','12',0,''),(44180,14055,'119605','printshop-mobile','color','#ffffff',0,''),(44181,14055,'119605','printshop-mobile','text-align','center',0,''),(44182,14055,'119605','printshop-mobile','padding-top','10',0,''),(44183,14056,'119606','printshop-mobile','block_type','4',0,''),(44184,14056,'119606','printshop-mobile','color','#ffffff',0,''),(44185,14056,'119606','printshop-mobile','font-size','30',0,''),(44186,14056,'119606','printshop-mobile','font-weight','normal',0,''),(44187,14056,'119606','printshop-mobile','background-color','#ee4225',0,''),(44188,14056,'119606','printshop-mobile','padding-top','5',0,''),(44189,14056,'119606','printshop-mobile','padding-left','10',0,''),(44190,14056,'119606','printshop-mobile','padding-right','10',0,''),(44191,14056,'119606','printshop-mobile','padding-bottom','5',0,''),(44192,14057,'119607','printshop-mobile','text','Your code is:',0,''),(44193,14057,'119607','printshop-mobile','font-size','30',0,''),(44194,14057,'119607','printshop-mobile','color','#ffffff',0,''),(44195,14058,'119608','printshop-mobile','color','#ffffff',0,''),(44196,14058,'119608','printshop-mobile','font-size','30',0,''),(44197,14059,'119609','printshop-mobile','block_type','1',0,''),(44198,14060,'119610','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(44199,14060,'119610','printshop-mobile','font-size','18',0,''),(44200,14060,'119610','printshop-mobile','font-weight','normal',0,''),(44201,14060,'119610','printshop-mobile','text-align','center',0,''),(44202,14060,'119610','printshop-mobile','padding-top','20',0,''),(44203,14060,'119610','printshop-mobile','padding-bottom','10',0,''),(44204,14060,'119610','printshop-mobile','border-top-width','1',0,''),(44205,14060,'119610','printshop-mobile','border-top-color','#dfa82a',0,''),(44206,14061,'119611','printshop-mobile','text','HOLBI',0,''),(44207,14061,'119611','printshop-mobile','color','#ffffff',0,''),(44208,14061,'119611','printshop-mobile','font-size','24',0,''),(44209,14061,'119611','printshop-mobile','padding-top','20',0,''),(44210,14061,'119611','printshop-mobile','text-align','center',0,''),(44211,14061,'119611','printshop-mobile','padding-bottom','20',0,''),(44212,14062,'119612','printshop-mobile','border-top-color','#dfa82a',0,''),(44213,14062,'119612','printshop-mobile','border-top-width','1',0,''),(44214,14062,'119612','printshop-mobile','padding-top','20',0,''),(44215,14062,'119612','printshop-mobile','font-size','30',0,''),(44216,14062,'119612','printshop-mobile','text-align','center',0,''),(44217,14062,'119612','printshop-mobile','color','#ffffff',0,''),(44218,14062,'119612','printshop-mobile','text','GIFT CARD',0,''),(44219,14063,'119613','printshop-mobile','text-align','center',0,''),(44220,14063,'119613','printshop-mobile','font-weight','bold',0,''),(44221,14063,'119613','printshop-mobile','font-size','60',0,''),(44222,14063,'119613','printshop-mobile','color','#ffffff',0,''),(44223,14064,'119614','printshop-mobile','font-size','20',0,''),(44224,14064,'119614','printshop-mobile','text-align','center',0,''),(44225,14064,'119614','printshop-mobile','color','#ffffff',0,''),(44226,14064,'119614','printshop-mobile','padding-top','20',0,''),(44227,14064,'119614','printshop-mobile','padding-bottom','20',0,''),(44228,14065,'119615','printshop-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(44229,14065,'119615','printshop-mobile','text-align','center',0,''),(44230,14065,'119615','printshop-mobile','color','#ffffff',0,''),(44231,14065,'119615','printshop-mobile','font-size','14',0,''),(44232,14065,'119615','printshop-mobile','padding-bottom','20',0,''),(44233,14066,'119616','printshop-mobile','text','WHAT TO DO NEXT:',0,''),(44234,14066,'119616','printshop-mobile','font-size','18',0,''),(44235,14066,'119616','printshop-mobile','text-align','center',0,''),(44236,14066,'119616','printshop-mobile','color','#ffffff',0,''),(44237,14066,'119616','printshop-mobile','padding-top','20',0,''),(44238,14066,'119616','printshop-mobile','padding-bottom','10',0,''),(44239,14066,'119616','printshop-mobile','border-top-width','1',0,''),(44240,14066,'119616','printshop-mobile','border-top-color','#dfa82a',0,''),(44241,14068,'119618','printshop-mobile','block_type','1',0,''),(44242,14068,'119618','printshop-mobile','font-weight','normal',0,''),(44243,14068,'119618','printshop-mobile','style_class','gift-card-view',0,''),(44244,14068,'119618','printshop-mobile','text-align','center',0,''),(44245,14068,'119618','printshop-mobile','padding-bottom','20',0,''),(44246,14068,'119618','printshop-mobile','background-color','#183d78',0,''),(44247,14068,'119618','printshop-mobile','padding-left','20',0,''),(44248,14068,'119618','printshop-mobile','padding-right','20',0,''),(44249,14068,'119618','printshop-mobile','color','#cccccc',0,''),(44250,14069,'119619','printshop-mobile','block_type','1',0,''),(44251,14069,'119619','printshop-mobile','font-weight','normal',0,''),(44252,14069,'119619','printshop-mobile','padding-top','10',0,''),(44253,14070,'119620','printshop-mobile','font-size','12',0,''),(44254,14070,'119620','printshop-mobile','font-weight','bold',0,''),(44255,14070,'119620','printshop-mobile','text-align','center',0,''),(44256,14070,'119620','printshop-mobile','style_class','email',0,''),(44257,14070,'119620','printshop-mobile','color','#ffffff',0,''),(44258,14071,'119621','printshop-mobile','font-size','12',0,''),(44259,14071,'119621','printshop-mobile','font-weight','bold',0,''),(44260,14071,'119621','printshop-mobile','text-align','center',0,''),(44261,14071,'119621','printshop-mobile','style_class','phone',0,''),(44262,14071,'119621','printshop-mobile','padding-bottom','5',0,''),(44263,14071,'119621','printshop-mobile','color','#ffffff',0,''),(44264,14072,'119622','printshop-mobile','text','If you require further assistance please contact us',0,''),(44265,14072,'119622','printshop-mobile','font-size','12',0,''),(44266,14072,'119622','printshop-mobile','color','#ffffff',0,''),(44267,14072,'119622','printshop-mobile','text-align','center',0,''),(44268,14072,'119622','printshop-mobile','padding-top','10',0,''),(44269,14073,'119623','printshop-mobile','block_type','4',0,''),(44270,14073,'119623','printshop-mobile','color','#ffffff',0,''),(44271,14073,'119623','printshop-mobile','font-size','30',0,''),(44272,14073,'119623','printshop-mobile','font-weight','normal',0,''),(44273,14073,'119623','printshop-mobile','background-color','#ee4225',0,''),(44274,14073,'119623','printshop-mobile','padding-top','5',0,''),(44275,14073,'119623','printshop-mobile','padding-left','10',0,''),(44276,14073,'119623','printshop-mobile','padding-right','10',0,''),(44277,14073,'119623','printshop-mobile','padding-bottom','5',0,''),(44278,14074,'119624','printshop-mobile','text','Your code is:',0,''),(44279,14074,'119624','printshop-mobile','font-size','30',0,''),(44280,14074,'119624','printshop-mobile','color','#ffffff',0,''),(44281,14075,'119625','printshop-mobile','color','#ffffff',0,''),(44282,14075,'119625','printshop-mobile','font-size','30',0,''),(44283,14076,'119626','printshop-mobile','block_type','1',0,''),(44284,14077,'119627','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(44285,14077,'119627','printshop-mobile','font-size','18',0,''),(44286,14077,'119627','printshop-mobile','font-weight','normal',0,''),(44287,14077,'119627','printshop-mobile','text-align','center',0,''),(44288,14077,'119627','printshop-mobile','padding-top','20',0,''),(44289,14077,'119627','printshop-mobile','padding-bottom','10',0,''),(44290,14077,'119627','printshop-mobile','border-top-width','1',0,''),(44291,14077,'119627','printshop-mobile','border-top-color','#dfa82a',0,''),(44292,14078,'119628','printshop-mobile','text','HOLBI',0,''),(44293,14078,'119628','printshop-mobile','color','#ffffff',0,''),(44294,14078,'119628','printshop-mobile','font-size','24',0,''),(44295,14078,'119628','printshop-mobile','padding-top','20',0,''),(44296,14078,'119628','printshop-mobile','text-align','center',0,''),(44297,14078,'119628','printshop-mobile','padding-bottom','20',0,''),(44298,14079,'119629','printshop-mobile','border-top-color','#dfa82a',0,''),(44299,14079,'119629','printshop-mobile','border-top-width','1',0,''),(44300,14079,'119629','printshop-mobile','padding-top','20',0,''),(44301,14079,'119629','printshop-mobile','font-size','30',0,''),(44302,14079,'119629','printshop-mobile','text-align','center',0,''),(44303,14079,'119629','printshop-mobile','color','#ffffff',0,''),(44304,14079,'119629','printshop-mobile','text','GIFT CARD',0,''),(44305,14080,'119630','printshop-mobile','text-align','center',0,''),(44306,14080,'119630','printshop-mobile','font-weight','bold',0,''),(44307,14080,'119630','printshop-mobile','font-size','60',0,''),(44308,14080,'119630','printshop-mobile','color','#ffffff',0,''),(44309,14081,'119631','printshop-mobile','font-size','20',0,''),(44310,14081,'119631','printshop-mobile','text-align','center',0,''),(44311,14081,'119631','printshop-mobile','color','#ffffff',0,''),(44312,14081,'119631','printshop-mobile','padding-top','20',0,''),(44313,14081,'119631','printshop-mobile','padding-bottom','20',0,''),(44314,14082,'119632','printshop-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(44315,14082,'119632','printshop-mobile','text-align','center',0,''),(44316,14082,'119632','printshop-mobile','color','#ffffff',0,''),(44317,14082,'119632','printshop-mobile','font-size','14',0,''),(44318,14082,'119632','printshop-mobile','padding-bottom','20',0,''),(44319,14083,'119633','printshop-mobile','text','WHAT TO DO NEXT:',0,''),(44320,14083,'119633','printshop-mobile','font-size','18',0,''),(44321,14083,'119633','printshop-mobile','text-align','center',0,''),(44322,14083,'119633','printshop-mobile','color','#ffffff',0,''),(44323,14083,'119633','printshop-mobile','padding-top','20',0,''),(44324,14083,'119633','printshop-mobile','padding-bottom','10',0,''),(44325,14083,'119633','printshop-mobile','border-top-width','1',0,''),(44326,14083,'119633','printshop-mobile','border-top-color','#dfa82a',0,''),(44327,14085,'119635','printshop-mobile','block_type','1',0,''),(44328,14087,'119637','printshop-mobile','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(44329,14087,'119637','printshop-mobile','text-align','center',0,''),(44330,14088,'119638','printshop-mobile','block_type','1',0,''),(44331,14088,'119638','printshop-mobile','font-weight','normal',0,''),(44332,14088,'119638','printshop-mobile','style_class','gift-card-view',0,''),(44333,14088,'119638','printshop-mobile','text-align','center',0,''),(44334,14088,'119638','printshop-mobile','padding-bottom','20',0,''),(44335,14088,'119638','printshop-mobile','background-color','#47a793',0,''),(44336,14088,'119638','printshop-mobile','padding-left','20',0,''),(44337,14088,'119638','printshop-mobile','padding-right','20',0,''),(44338,14088,'119638','printshop-mobile','color','#cccccc',0,''),(44339,14089,'119639','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(44340,14089,'119639','printshop-mobile','font-weight','normal',0,''),(44341,14089,'119639','printshop-mobile','text-align','center',0,''),(44342,14089,'119639','printshop-mobile','padding-bottom','10',0,''),(44343,14089,'119639','printshop-mobile','font-size','14',0,''),(44344,14090,'119640','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(44345,14090,'119640','printshop-mobile','font-size','18',0,''),(44346,14090,'119640','printshop-mobile','font-weight','normal',0,''),(44347,14090,'119640','printshop-mobile','text-align','center',0,''),(44348,14090,'119640','printshop-mobile','padding-top','20',0,''),(44349,14090,'119640','printshop-mobile','padding-bottom','10',0,''),(44350,14090,'119640','printshop-mobile','border-top-width','1',0,''),(44351,14090,'119640','printshop-mobile','border-top-color','#dfa82a',0,''),(44352,14091,'119641','printshop-mobile','font-size','60',0,''),(44353,14091,'119641','printshop-mobile','font-weight','bold',0,''),(44354,14091,'119641','printshop-mobile','text-align','center',0,''),(44355,14091,'119641','printshop-mobile','line-height','100',0,''),(44356,14091,'119641','printshop-mobile','padding-bottom','20',0,''),(44357,14091,'119641','printshop-mobile','line_height_measure','px',0,''),(44358,14092,'119642','printshop-mobile','text','<p>GIFT CARD</p>',1,''),(44359,14092,'119642','printshop-mobile','font-size','30',0,''),(44360,14092,'119642','printshop-mobile','font-weight','normal',0,''),(44361,14092,'119642','printshop-mobile','border-top-width','1',0,''),(44362,14092,'119642','printshop-mobile','border-top-color','#dfa82a',0,''),(44363,14092,'119642','printshop-mobile','style_class','gift-ico',0,''),(44364,14092,'119642','printshop-mobile','text-align','center',0,''),(44365,14092,'119642','printshop-mobile','padding-top','15',0,''),(44366,14093,'119643','printshop-mobile','font-weight','normal',0,''),(44367,14093,'119643','printshop-mobile','text-align','center',0,''),(44368,14093,'119643','printshop-mobile','padding-bottom','20',0,''),(44369,14094,'119644','printshop-mobile','text','<p>HOLBI</p>',1,''),(44370,14094,'119644','printshop-mobile','font-family','Varela Round',0,''),(44371,14094,'119644','printshop-mobile','font-size','24',0,''),(44372,14094,'119644','printshop-mobile','font-weight','normal',0,''),(44373,14094,'119644','printshop-mobile','text-align','center',0,''),(44374,14094,'119644','printshop-mobile','padding-top','10',0,''),(44375,14094,'119644','printshop-mobile','padding-bottom','20',0,''),(44376,14095,'119645','printshop-mobile','block_type','1',0,''),(44377,14095,'119645','printshop-mobile','font-weight','normal',0,''),(44378,14095,'119645','printshop-mobile','padding-top','10',0,''),(44379,14096,'119646','printshop-mobile','font-size','12',0,''),(44380,14096,'119646','printshop-mobile','font-weight','bold',0,''),(44381,14096,'119646','printshop-mobile','text-align','center',0,''),(44382,14096,'119646','printshop-mobile','style_class','email',0,''),(44383,14097,'119647','printshop-mobile','font-size','12',0,''),(44384,14097,'119647','printshop-mobile','font-weight','bold',0,''),(44385,14097,'119647','printshop-mobile','text-align','center',0,''),(44386,14097,'119647','printshop-mobile','style_class','phone',0,''),(44387,14097,'119647','printshop-mobile','padding-bottom','5',0,''),(44388,14098,'119648','printshop-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(44389,14098,'119648','printshop-mobile','font-weight','normal',0,''),(44390,14098,'119648','printshop-mobile','text-align','center',0,''),(44391,14098,'119648','printshop-mobile','font-size','12',0,''),(44392,14098,'119648','printshop-mobile','padding-top','10',0,''),(44393,14098,'119648','printshop-mobile','padding-bottom','5',0,''),(44394,14098,'119648','printshop-mobile','border-top-width','1',0,''),(44395,14098,'119648','printshop-mobile','border-top-color','#dfa82a',0,''),(44396,14099,'119649','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(44397,14099,'119649','printshop-mobile','font-weight','normal',0,''),(44398,14099,'119649','printshop-mobile','text-align','center',0,''),(44399,14099,'119649','printshop-mobile','padding-top','20',0,''),(44400,14099,'119649','printshop-mobile','padding-bottom','10',0,''),(44401,14099,'119649','printshop-mobile','style_class','question-ico',0,''),(44402,14099,'119649','printshop-mobile','border-top-width','1',0,''),(44403,14099,'119649','printshop-mobile','border-top-color','#dfa82a',0,''),(44404,14099,'119649','printshop-mobile','font-size','18',0,''),(44405,14100,'119650','printshop-mobile','block_type','4',0,''),(44406,14100,'119650','printshop-mobile','color','#ffffff',0,''),(44407,14100,'119650','printshop-mobile','font-size','30',0,''),(44408,14100,'119650','printshop-mobile','font-weight','normal',0,''),(44409,14100,'119650','printshop-mobile','background-color','#ee4225',0,''),(44410,14100,'119650','printshop-mobile','padding-top','5',0,''),(44411,14100,'119650','printshop-mobile','padding-left','10',0,''),(44412,14100,'119650','printshop-mobile','padding-right','10',0,''),(44413,14100,'119650','printshop-mobile','padding-bottom','5',0,''),(44414,14101,'119651','printshop-mobile','text','<p>Your code is:</p>',1,''),(44415,14101,'119651','printshop-mobile','font-weight','normal',0,''),(44416,14103,'119653','printshop-mobile','block_type','1',0,''),(44417,14103,'119653','printshop-mobile','font-weight','normal',0,''),(44418,14103,'119653','printshop-mobile','style_class','gift-card-view',0,''),(44419,14103,'119653','printshop-mobile','text-align','center',0,''),(44420,14103,'119653','printshop-mobile','padding-bottom','20',0,''),(44421,14103,'119653','printshop-mobile','background-color','#47a793',0,''),(44422,14103,'119653','printshop-mobile','padding-left','20',0,''),(44423,14103,'119653','printshop-mobile','padding-right','20',0,''),(44424,14103,'119653','printshop-mobile','color','#cccccc',0,''),(44425,14104,'119654','printshop-mobile','block_type','1',0,''),(44426,14104,'119654','printshop-mobile','font-weight','normal',0,''),(44427,14104,'119654','printshop-mobile','padding-top','10',0,''),(44428,14105,'119655','printshop-mobile','font-size','12',0,''),(44429,14105,'119655','printshop-mobile','font-weight','bold',0,''),(44430,14105,'119655','printshop-mobile','text-align','center',0,''),(44431,14105,'119655','printshop-mobile','style_class','email',0,''),(44432,14105,'119655','printshop-mobile','color','#ffffff',0,''),(44433,14106,'119656','printshop-mobile','font-size','12',0,''),(44434,14106,'119656','printshop-mobile','font-weight','bold',0,''),(44435,14106,'119656','printshop-mobile','text-align','center',0,''),(44436,14106,'119656','printshop-mobile','style_class','phone',0,''),(44437,14106,'119656','printshop-mobile','padding-bottom','5',0,''),(44438,14106,'119656','printshop-mobile','color','#ffffff',0,''),(44439,14107,'119657','printshop-mobile','text','If you require further assistance please contact us',0,''),(44440,14107,'119657','printshop-mobile','font-size','12',0,''),(44441,14107,'119657','printshop-mobile','color','#ffffff',0,''),(44442,14107,'119657','printshop-mobile','text-align','center',0,''),(44443,14107,'119657','printshop-mobile','padding-top','10',0,''),(44444,14108,'119658','printshop-mobile','block_type','4',0,''),(44445,14108,'119658','printshop-mobile','color','#ffffff',0,''),(44446,14108,'119658','printshop-mobile','font-size','30',0,''),(44447,14108,'119658','printshop-mobile','font-weight','normal',0,''),(44448,14108,'119658','printshop-mobile','background-color','#ee4225',0,''),(44449,14108,'119658','printshop-mobile','padding-top','5',0,''),(44450,14108,'119658','printshop-mobile','padding-left','10',0,''),(44451,14108,'119658','printshop-mobile','padding-right','10',0,''),(44452,14108,'119658','printshop-mobile','padding-bottom','5',0,''),(44453,14109,'119659','printshop-mobile','text','Your code is:',0,''),(44454,14109,'119659','printshop-mobile','font-size','30',0,''),(44455,14109,'119659','printshop-mobile','color','#ffffff',0,''),(44456,14110,'119660','printshop-mobile','color','#ffffff',0,''),(44457,14110,'119660','printshop-mobile','font-size','30',0,''),(44458,14111,'119661','printshop-mobile','block_type','1',0,''),(44459,14112,'119662','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(44460,14112,'119662','printshop-mobile','font-size','18',0,''),(44461,14112,'119662','printshop-mobile','font-weight','normal',0,''),(44462,14112,'119662','printshop-mobile','text-align','center',0,''),(44463,14112,'119662','printshop-mobile','padding-top','20',0,''),(44464,14112,'119662','printshop-mobile','padding-bottom','10',0,''),(44465,14112,'119662','printshop-mobile','border-top-width','1',0,''),(44466,14112,'119662','printshop-mobile','border-top-color','#dfa82a',0,''),(44467,14113,'119663','printshop-mobile','text','HOLBI',0,''),(44468,14113,'119663','printshop-mobile','color','#ffffff',0,''),(44469,14113,'119663','printshop-mobile','font-size','24',0,''),(44470,14113,'119663','printshop-mobile','padding-top','20',0,''),(44471,14113,'119663','printshop-mobile','text-align','center',0,''),(44472,14113,'119663','printshop-mobile','padding-bottom','20',0,''),(44473,14114,'119664','printshop-mobile','border-top-color','#dfa82a',0,''),(44474,14114,'119664','printshop-mobile','border-top-width','1',0,''),(44475,14114,'119664','printshop-mobile','padding-top','20',0,''),(44476,14114,'119664','printshop-mobile','font-size','30',0,''),(44477,14114,'119664','printshop-mobile','text-align','center',0,''),(44478,14114,'119664','printshop-mobile','color','#ffffff',0,''),(44479,14114,'119664','printshop-mobile','text','GIFT CARD',0,''),(44480,14115,'119665','printshop-mobile','text-align','center',0,''),(44481,14115,'119665','printshop-mobile','font-weight','bold',0,''),(44482,14115,'119665','printshop-mobile','font-size','60',0,''),(44483,14115,'119665','printshop-mobile','color','#ffffff',0,''),(44484,14116,'119666','printshop-mobile','font-size','20',0,''),(44485,14116,'119666','printshop-mobile','text-align','center',0,''),(44486,14116,'119666','printshop-mobile','color','#ffffff',0,''),(44487,14116,'119666','printshop-mobile','padding-top','20',0,''),(44488,14116,'119666','printshop-mobile','padding-bottom','20',0,''),(44489,14117,'119667','printshop-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(44490,14117,'119667','printshop-mobile','text-align','center',0,''),(44491,14117,'119667','printshop-mobile','color','#ffffff',0,''),(44492,14117,'119667','printshop-mobile','font-size','14',0,''),(44493,14117,'119667','printshop-mobile','padding-bottom','20',0,''),(44494,14118,'119668','printshop-mobile','text','WHAT TO DO NEXT:',0,''),(44495,14118,'119668','printshop-mobile','font-size','18',0,''),(44496,14118,'119668','printshop-mobile','text-align','center',0,''),(44497,14118,'119668','printshop-mobile','color','#ffffff',0,''),(44498,14118,'119668','printshop-mobile','padding-top','20',0,''),(44499,14118,'119668','printshop-mobile','padding-bottom','10',0,''),(44500,14118,'119668','printshop-mobile','border-top-width','1',0,''),(44501,14118,'119668','printshop-mobile','border-top-color','#dfa82a',0,''),(44502,14119,'119669','printshop-mobile','logo','themes/printshop-mobile/img/oscommerce_logo.png',1,''),(44503,14119,'119669','printshop-mobile','text-align','center',0,''),(44504,14119,'119669','printshop-mobile','padding-top','10',0,''),(44505,14119,'119669','printshop-mobile','padding-left','60',0,''),(44506,14119,'119669','printshop-mobile','padding-right','60',0,''),(44507,14119,'119669','printshop-mobile','padding-bottom','10',0,''),(44508,14120,'119670','printshop-mobile','text-align','center',0,''),(44509,14120,'119670','printshop-mobile','margin-bottom','20',0,''),(44510,14121,'119671','printshop-mobile','block_type','1',0,''),(44511,14121,'119671','printshop-mobile','background-color','#eeeeee',0,''),(44512,14121,'119671','printshop-mobile','border-bottom-width','1',0,''),(44513,14121,'119671','printshop-mobile','border-bottom-color','#dedede',0,''),(44514,14121,'119671','printshop-mobile','display_none','on',0,'694'),(44515,14122,'119672','printshop-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',1,''),(44516,14122,'119672','printshop-mobile','float','right',0,''),(44517,14122,'119672','printshop-mobile','max-width','450',0,''),(44518,14122,'119672','printshop-mobile','font-size','13',0,''),(44519,14122,'119672','printshop-mobile','padding-top','5',0,''),(44520,14122,'119672','printshop-mobile','padding-bottom','5',0,''),(44521,14122,'119672','printshop-mobile','width','350',0,'701'),(44522,14123,'119673','printshop-mobile','block_type','4',0,''),(44523,14123,'119673','printshop-mobile','display','inline-block',0,''),(44524,14123,'119673','printshop-mobile','width','650',0,''),(44525,14123,'119673','printshop-mobile','vertical-align','middle',0,''),(44526,14123,'119673','printshop-mobile','float','left',0,''),(44527,14123,'119673','printshop-mobile','clear','none',0,''),(44528,14123,'119673','printshop-mobile','text-align','left',0,''),(44529,14123,'119673','printshop-mobile','padding-top','10',0,''),(44530,14123,'119673','printshop-mobile','padding-bottom','10',0,''),(44531,14123,'119673','printshop-mobile','schema','4-2',0,'701'),(44532,14123,'119673','printshop-mobile','width','350',0,'701'),(44533,14123,'119673','printshop-mobile','padding-top','0',0,'701'),(44534,14124,'119674','printshop-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',1,''),(44535,14124,'119674','printshop-mobile','font-family','Hind',0,''),(44536,14124,'119674','printshop-mobile','font-size','22',0,''),(44537,14124,'119674','printshop-mobile','color','#00a858',0,''),(44538,14124,'119674','printshop-mobile','padding-top','7',0,''),(44539,14124,'119674','printshop-mobile','display','inline-block',0,''),(44540,14124,'119674','printshop-mobile','float','left',0,''),(44541,14124,'119674','printshop-mobile','clear','none',0,''),(44542,14124,'119674','printshop-mobile','font-size','20',0,'701'),(44543,14125,'119675','printshop-mobile','logo','themes/printshop-mobile/img/check-2.png',1,''),(44544,14125,'119675','printshop-mobile','display','inline-block',0,''),(44545,14125,'119675','printshop-mobile','vertical-align','top',0,''),(44546,14125,'119675','printshop-mobile','padding-top','10',0,''),(44547,14125,'119675','printshop-mobile','padding-right','10',0,''),(44548,14125,'119675','printshop-mobile','float','left',0,''),(44549,14125,'119675','printshop-mobile','clear','none',0,''),(44550,14126,'119676','printshop-mobile','block_type','2',0,''),(44551,14127,'119677','printshop-mobile','text','<a class=\"secure-1_\" href=\"//www.securitymetrics.com/site_certificate?id=1442870&tk=4964ae06eb42dd2462f57cde979b3228\" target=\"_blank\"><img src=\"images/security.jpg\" alt=\"SecurityMetrics Credit Card Safe\" /></a>',0,''),(44552,14127,'119677','printshop-mobile','text-align','center',0,''),(44553,14128,'119678','printshop-mobile','text','<a href=\"//www.securitymetrics.com/site_certificate?id=1442870&tk=4964ae06eb42dd2462f57cde979b3228\" target=\"_blank\"><img src=\"images/security2.jpg\" alt=\"SecurityMetrics Credit Card Safe\" /></a>',0,''),(44554,14128,'119678','printshop-mobile','text-align','center',0,''),(44555,14129,'119679','printshop-mobile','block_type','14',0,''),(44556,14129,'119679','printshop-mobile','font-weight','400',0,''),(44557,14129,'119679','printshop-mobile','background-color','#183d78',0,''),(44558,14130,'119680','printshop-mobile','class','menu-style-1',0,''),(44559,14130,'119680','printshop-mobile','box_align','4',0,''),(44560,14130,'119680','printshop-mobile','font-weight','400',0,''),(44561,14130,'119680','printshop-mobile','hide_menu','on',0,''),(44562,14130,'119680','printshop-mobile','color','#ffffff',0,''),(44563,14130,'119680','printshop-mobile','hide_menu','1',0,'695'),(44564,14134,'119684','printshop-mobile','block_type','1',0,''),(44565,14137,'119687','printshop-mobile','width','680',0,''),(44566,14137,'119687','printshop-mobile','font-weight','normal',0,''),(44567,14137,'119687','printshop-mobile','font-size','12',0,''),(44568,14137,'119687','printshop-mobile','padding-top','20',0,''),(44569,14137,'119687','printshop-mobile','padding-bottom','20',0,''),(44570,14137,'119687','printshop-mobile','color','#000000',0,''),(44571,14138,'119688','printshop-mobile','block_type','5',0,''),(44572,14138,'119688','printshop-mobile','font-weight','normal',0,''),(44573,14138,'119688','printshop-mobile','border-bottom-width','1',0,''),(44574,14138,'119688','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(44575,14138,'119688','printshop-mobile','border-top-width','1',0,''),(44576,14138,'119688','printshop-mobile','border-top-color','#e0e0e0',0,''),(44577,14138,'119688','printshop-mobile','border-left-color','#e0e0e0',0,''),(44578,14138,'119688','printshop-mobile','border-left-width','1',0,''),(44579,14139,'119689','printshop-mobile','block_type','1',0,''),(44580,14139,'119689','printshop-mobile','font-weight','normal',0,''),(44581,14139,'119689','printshop-mobile','padding-top','10',0,''),(44582,14139,'119689','printshop-mobile','padding-left','10',0,''),(44583,14139,'119689','printshop-mobile','padding-right','10',0,''),(44584,14140,'119690','printshop-mobile','font-weight','400',0,''),(44585,14140,'119690','printshop-mobile','line-height','120',0,''),(44586,14140,'119690','printshop-mobile','line_height_measure','%',0,''),(44587,14141,'119691','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(44588,14141,'119691','printshop-mobile','font-size','14',0,''),(44589,14141,'119691','printshop-mobile','font-weight','bold',0,''),(44590,14141,'119691','printshop-mobile','padding-bottom','10',0,''),(44591,14142,'119692','printshop-mobile','block_type','1',0,''),(44592,14142,'119692','printshop-mobile','background-color','#e0e0e0',0,''),(44593,14142,'119692','printshop-mobile','padding-top','40',0,''),(44594,14142,'119692','printshop-mobile','padding-left','10',0,''),(44595,14142,'119692','printshop-mobile','padding-right','10',0,''),(44596,14142,'119692','printshop-mobile','padding-bottom','40',0,''),(44597,14143,'119693','printshop-mobile','font-weight','normal',0,''),(44598,14143,'119693','printshop-mobile','line-height','200',0,''),(44599,14143,'119693','printshop-mobile','text-align','right',0,''),(44600,14143,'119693','printshop-mobile','font-size','14',0,''),(44601,14143,'119693','printshop-mobile','box_align','3',0,''),(44602,14144,'119694','printshop-mobile','font-weight','400',0,''),(44603,14144,'119694','printshop-mobile','padding-top','20',0,''),(44604,14144,'119694','printshop-mobile','padding-bottom','20',0,''),(44605,14144,'119694','printshop-mobile','font-size','12',0,''),(44606,14145,'119695','printshop-mobile','block_type','2',0,''),(44607,14145,'119695','printshop-mobile','font-weight','normal',0,''),(44608,14145,'119695','printshop-mobile','padding-bottom','20',0,''),(44609,14146,'119696','printshop-mobile','font-weight','400',0,''),(44610,14146,'119696','printshop-mobile','padding-top','20',0,''),(44612,14147,'119697','printshop-mobile','block_type','11',0,''),(44613,14147,'119697','printshop-mobile','font-weight','normal',0,''),(44614,14148,'119698','printshop-mobile','text','<p>Phone:</p>',1,''),(44615,14148,'119698','printshop-mobile','font-weight','normal',0,''),(44616,14148,'119698','printshop-mobile','text-align','right',0,''),(44617,14149,'119699','printshop-mobile','font-weight','normal',0,''),(44618,14149,'119699','printshop-mobile','text-align','right',0,''),(44619,14150,'119700','printshop-mobile','block_type','1',0,''),(44620,14151,'119701','printshop-mobile','font-weight','normal',0,''),(44621,14151,'119701','printshop-mobile','text-align','right',0,''),(44622,14151,'119701','printshop-mobile','padding-bottom','10',0,''),(44623,14151,'119701','printshop-mobile','address_spacer',',',0,''),(44624,14152,'119702','printshop-mobile','block_type','11',0,''),(44625,14152,'119702','printshop-mobile','font-weight','normal',0,''),(44626,14153,'119703','printshop-mobile','text','<p>Web:</p>',1,''),(44627,14153,'119703','printshop-mobile','font-weight','normal',0,''),(44628,14153,'119703','printshop-mobile','text-align','right',0,''),(44629,14154,'119704','printshop-mobile','font-weight','normal',0,''),(44630,14154,'119704','printshop-mobile','text-align','right',0,''),(44631,14155,'119705','printshop-mobile','block_type','11',0,''),(44632,14155,'119705','printshop-mobile','font-weight','normal',0,''),(44633,14156,'119706','printshop-mobile','text','<p>Email:</p>',1,''),(44634,14156,'119706','printshop-mobile','font-weight','normal',0,''),(44635,14156,'119706','printshop-mobile','text-align','right',0,''),(44636,14157,'119707','printshop-mobile','font-weight','normal',0,''),(44637,14157,'119707','printshop-mobile','text-align','right',0,''),(44638,14158,'119708','printshop-mobile','block_type','3',0,''),(44639,14158,'119708','printshop-mobile','font-weight','normal',0,''),(44640,14158,'119708','printshop-mobile','padding-top','20',0,''),(44641,14159,'119709','printshop-mobile','text','<p>If undelivered please return to:</p>',1,''),(44642,14159,'119709','printshop-mobile','font-size','15',0,''),(44643,14159,'119709','printshop-mobile','font-weight','bold',0,''),(44644,14160,'119710','printshop-mobile','font-size','14',0,''),(44645,14161,'119711','printshop-mobile','text','<p>Thank you for your order</p>',1,''),(44646,14161,'119711','printshop-mobile','color','#008fe9',0,''),(44647,14161,'119711','printshop-mobile','font-size','16',0,''),(44648,14161,'119711','printshop-mobile','font-weight','bold',0,''),(44649,14161,'119711','printshop-mobile','padding-top','5',0,''),(44650,14161,'119711','printshop-mobile','text-align','center',0,''),(44651,14162,'119712','printshop-mobile','font-weight','400',0,''),(44652,14162,'119712','printshop-mobile','text-align','center',0,''),(44653,14162,'119712','printshop-mobile','padding-top','0',0,''),(44655,14162,'119712','printshop-mobile','padding-left','20',0,''),(44656,14162,'119712','printshop-mobile','padding-right','20',0,''),(44657,14163,'119713','printshop-mobile','block_type','6',0,''),(44658,14163,'119713','printshop-mobile','font-weight','normal',0,''),(44659,14163,'119713','printshop-mobile','font-size','16',0,''),(44660,14164,'119714','printshop-mobile','text','<p>Email:</p>',1,''),(44661,14164,'119714','printshop-mobile','font-weight','normal',0,''),(44662,14164,'119714','printshop-mobile','text-align','right',0,''),(44663,14164,'119714','printshop-mobile','font-size','14',0,''),(44664,14165,'119715','printshop-mobile','font-weight','normal',0,''),(44665,14165,'119715','printshop-mobile','text-align','right',0,''),(44666,14165,'119715','printshop-mobile','font-size','14',0,''),(44667,14166,'119716','printshop-mobile','block_type','6',0,''),(44668,14166,'119716','printshop-mobile','font-weight','normal',0,''),(44669,14166,'119716','printshop-mobile','font-size','16',0,''),(44670,14167,'119717','printshop-mobile','text','<p>Phone:</p>',1,''),(44671,14167,'119717','printshop-mobile','font-weight','normal',0,''),(44672,14167,'119717','printshop-mobile','text-align','right',0,''),(44673,14167,'119717','printshop-mobile','font-size','14',0,''),(44674,14168,'119718','printshop-mobile','font-weight','normal',0,''),(44675,14168,'119718','printshop-mobile','text-align','right',0,''),(44676,14168,'119718','printshop-mobile','font-size','14',0,''),(44677,14169,'119719','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(44678,14169,'119719','printshop-mobile','font-size','14',0,''),(44679,14169,'119719','printshop-mobile','font-weight','bold',0,''),(44680,14169,'119719','printshop-mobile','text-align','right',0,''),(44681,14170,'119720','printshop-mobile','block_type','4',0,''),(44682,14170,'119720','printshop-mobile','font-weight','normal',0,''),(44683,14170,'119720','printshop-mobile','border-top-width','1',0,''),(44684,14170,'119720','printshop-mobile','border-top-color','#e0e0e0',0,''),(44685,14170,'119720','printshop-mobile','border-left-width','1',0,''),(44686,14170,'119720','printshop-mobile','border-left-color','#e0e0e0',0,''),(44687,14170,'119720','printshop-mobile','border-right-width','1',0,''),(44688,14170,'119720','printshop-mobile','border-right-color','#e0e0e0',0,''),(44689,14170,'119720','printshop-mobile','border-bottom-width','1',0,''),(44690,14170,'119720','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(44691,14171,'119721','printshop-mobile','block_type','2',0,''),(44692,14171,'119721','printshop-mobile','font-weight','normal',0,''),(44693,14171,'119721','printshop-mobile','border-top-width','1',0,''),(44694,14171,'119721','printshop-mobile','border-top-color','#e0e0e0',0,''),(44695,14171,'119721','printshop-mobile','border-right-width','1',0,''),(44696,14171,'119721','printshop-mobile','border-right-color','#e0e0e0',0,''),(44697,14172,'119722','printshop-mobile','block_type','1',0,''),(44698,14172,'119722','printshop-mobile','font-weight','normal',0,''),(44699,14172,'119722','printshop-mobile','padding-top','10',0,''),(44700,14172,'119722','printshop-mobile','padding-left','10',0,''),(44701,14172,'119722','printshop-mobile','padding-right','10',0,''),(44702,14172,'119722','printshop-mobile','padding-bottom','10',0,''),(44703,14172,'119722','printshop-mobile','border-right-width','1',0,''),(44704,14172,'119722','printshop-mobile','border-right-color','#e0e0e0',0,''),(44705,14173,'119723','printshop-mobile','text','<p>Shipping via</p>',1,''),(44706,14173,'119723','printshop-mobile','font-weight','bold',0,''),(44707,14175,'119725','printshop-mobile','block_type','1',0,''),(44708,14175,'119725','printshop-mobile','font-weight','normal',0,''),(44709,14175,'119725','printshop-mobile','padding-top','10',0,''),(44710,14175,'119725','printshop-mobile','padding-left','10',0,''),(44711,14175,'119725','printshop-mobile','padding-right','10',0,''),(44712,14175,'119725','printshop-mobile','padding-bottom','10',0,''),(44713,14177,'119727','printshop-mobile','text','<p>Shipping service</p>',1,''),(44714,14177,'119727','printshop-mobile','font-weight','bold',0,''),(44715,14178,'119728','printshop-mobile','block_type','2',0,''),(44716,14178,'119728','printshop-mobile','font-weight','normal',0,''),(44717,14178,'119728','printshop-mobile','border-right-width','1',0,''),(44718,14178,'119728','printshop-mobile','border-right-color','#e0e0e0',0,''),(44719,14179,'119729','printshop-mobile','block_type','1',0,''),(44720,14179,'119729','printshop-mobile','font-weight','400',0,''),(44721,14179,'119729','printshop-mobile','background-color','#e0e0e0',0,''),(44722,14179,'119729','printshop-mobile','padding-top','10',0,''),(44723,14179,'119729','printshop-mobile','padding-left','10',0,''),(44724,14179,'119729','printshop-mobile','padding-right','10',0,''),(44725,14179,'119729','printshop-mobile','padding-bottom','50',0,''),(44726,14180,'119730','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(44727,14180,'119730','printshop-mobile','font-size','16',0,''),(44728,14180,'119730','printshop-mobile','font-weight','bold',0,''),(44729,14182,'119732','printshop-mobile','block_type','1',0,''),(44730,14182,'119732','printshop-mobile','font-weight','normal',0,''),(44731,14182,'119732','printshop-mobile','padding-top','10',0,''),(44732,14182,'119732','printshop-mobile','padding-left','10',0,''),(44733,14182,'119732','printshop-mobile','padding-right','10',0,''),(44734,14182,'119732','printshop-mobile','padding-bottom','10',0,''),(44735,14183,'119733','printshop-mobile','font-weight','normal',0,''),(44736,14184,'119734','printshop-mobile','text','<p>CUSTOMER:</p>',1,''),(44737,14184,'119734','printshop-mobile','font-size','14',0,''),(44738,14184,'119734','printshop-mobile','font-weight','bold',0,''),(44739,14185,'119735','printshop-mobile','font-weight','normal',0,''),(44740,14186,'119736','printshop-mobile','text','<p>PHONE NUMBER:</p>',1,''),(44741,14186,'119736','printshop-mobile','font-size','14',0,''),(44742,14186,'119736','printshop-mobile','font-weight','bold',0,''),(44743,14186,'119736','printshop-mobile','padding-top','10',0,''),(44744,14187,'119737','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(44745,14187,'119737','printshop-mobile','font-weight','bold',0,''),(44746,14187,'119737','printshop-mobile','font-size','14',0,''),(44747,14187,'119737','printshop-mobile','padding-top','10',0,''),(44748,14189,'119739','printshop-mobile','font-weight','normal',0,''),(44749,14189,'119739','printshop-mobile','text-align','center',0,''),(44750,14189,'119739','printshop-mobile','padding-bottom','20',0,''),(44751,14190,'119740','printshop-mobile','font-weight','normal',0,''),(44752,14190,'119740','printshop-mobile','text-align','center',0,''),(44753,14190,'119740','printshop-mobile','padding-bottom','10',0,''),(44754,14191,'119741','printshop-mobile','font-size','16',0,''),(44755,14191,'119741','printshop-mobile','font-weight','bold',0,''),(44756,14191,'119741','printshop-mobile','text-align','center',0,''),(44757,14191,'119741','printshop-mobile','padding-bottom','10',0,''),(44758,14191,'119741','printshop-mobile','padding-top','10',0,''),(44759,14192,'119742','printshop-mobile','font-weight','normal',0,''),(44760,14192,'119742','printshop-mobile','text-align','center',0,''),(44761,14193,'119743','printshop-mobile','text','<p>Payment date:</p>',1,''),(44762,14193,'119743','printshop-mobile','font-weight','bold',0,''),(44763,14193,'119743','printshop-mobile','text-align','center',0,''),(44764,14194,'119744','printshop-mobile','text','<p>Payment Method:</p>',1,''),(44765,14194,'119744','printshop-mobile','font-weight','bold',0,''),(44766,14194,'119744','printshop-mobile','text-align','center',0,''),(44767,14195,'119745','printshop-mobile','block_type','1',0,''),(44768,14195,'119745','printshop-mobile','padding-top','20',0,''),(44769,14196,'119746','printshop-mobile','tab_1','RETURNING CUSTOMER',1,''),(44770,14196,'119746','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(44771,14199,'119749','printshop-mobile','block_type','1',0,''),(44772,14200,'119750','printshop-mobile','text','##TEXT_OR##',0,''),(44773,14200,'119750','printshop-mobile','font-size','18',0,''),(44774,14200,'119750','printshop-mobile','font-weight','700',0,''),(44775,14200,'119750','printshop-mobile','padding-top','15',0,''),(44776,14200,'119750','printshop-mobile','text-align','center',0,''),(44777,14200,'119750','printshop-mobile','content','\\_',0,'3'),(44778,14200,'119750','printshop-mobile','height','5',0,'3'),(44779,14200,'119750','printshop-mobile','width','70',0,'3'),(44780,14200,'119750','printshop-mobile','display','inline-block',0,'3'),(44781,14200,'119750','printshop-mobile','border-top-width','1',0,'3'),(44782,14200,'119750','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(44783,14200,'119750','printshop-mobile','margin-left','10',0,'3'),(44784,14200,'119750','printshop-mobile','margin-right','10',0,'3'),(44785,14200,'119750','printshop-mobile','content','\\_',0,'4'),(44786,14200,'119750','printshop-mobile','display','inline-block',0,'4'),(44787,14200,'119750','printshop-mobile','width','70',0,'4'),(44788,14200,'119750','printshop-mobile','height','5',0,'4'),(44789,14200,'119750','printshop-mobile','border-top-width','1',0,'4'),(44790,14200,'119750','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(44791,14200,'119750','printshop-mobile','margin-left','10',0,'4'),(44792,14200,'119750','printshop-mobile','margin-right','10',0,'4'),(44793,14200,'119750','printshop-mobile','position','relative',0,''),(44794,14200,'119750','printshop-mobile','top','-10',0,''),(44795,14201,'119751','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(44796,14201,'119751','printshop-mobile','font-size','26',0,''),(44797,14201,'119751','printshop-mobile','font-family','Varela Round',0,''),(44798,14201,'119751','printshop-mobile','padding-top','15',0,''),(44799,14201,'119751','printshop-mobile','padding-bottom','15',0,''),(44800,14201,'119751','printshop-mobile','text-align','center',0,''),(44801,14202,'119752','printshop-mobile','text-align','center',0,''),(44802,14202,'119752','printshop-mobile','hide_parents','2',0,''),(44803,14203,'119753','printshop-mobile','block_type','1',0,''),(44804,14203,'119753','printshop-mobile','padding-top','40',0,''),(44805,14203,'119753','printshop-mobile','background-color','#eeeeee',0,''),(44806,14203,'119753','printshop-mobile','padding-bottom','40',0,''),(44807,14204,'119754','printshop-mobile','block_type','1',0,''),(44808,14204,'119754','printshop-mobile','background-color','#ffffff',0,''),(44809,14204,'119754','printshop-mobile','max-width','830',0,''),(44810,14204,'119754','printshop-mobile','margin_left_measure','auto',0,''),(44811,14204,'119754','printshop-mobile','margin_right_measure','auto',0,''),(44812,14204,'119754','printshop-mobile','padding-top','40',0,''),(44813,14204,'119754','printshop-mobile','padding-bottom','40',0,''),(44814,14204,'119754','printshop-mobile','schema','2-3',0,''),(44815,14205,'119755','printshop-mobile','text','##NEW_CUSTOMER##',0,''),(44816,14205,'119755','printshop-mobile','font-size','18',0,''),(44817,14205,'119755','printshop-mobile','font-family','Varela Round',0,''),(44818,14205,'119755','printshop-mobile','text-align','center',0,''),(44819,14205,'119755','printshop-mobile','text-transform','uppercase',0,''),(44820,14205,'119755','printshop-mobile','margin-bottom','10',0,''),(44821,14206,'119756','printshop-mobile','text-align','center',0,''),(44822,14206,'119756','printshop-mobile','margin-bottom','40',0,''),(44823,14207,'119757','printshop-mobile','text-align','center',0,''),(44824,14208,'119758','printshop-mobile','text','##TEXT_OR##',0,''),(44825,14208,'119758','printshop-mobile','font-size','18',0,''),(44826,14208,'119758','printshop-mobile','font-weight','700',0,''),(44827,14208,'119758','printshop-mobile','text-align','center',0,''),(44828,14208,'119758','printshop-mobile','content','\\_',0,'3'),(44829,14208,'119758','printshop-mobile','height','5',0,'3'),(44830,14208,'119758','printshop-mobile','width','70',0,'3'),(44831,14208,'119758','printshop-mobile','display','inline-block',0,'3'),(44832,14208,'119758','printshop-mobile','border-top-width','1',0,'3'),(44833,14208,'119758','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(44834,14208,'119758','printshop-mobile','margin-left','10',0,'3'),(44835,14208,'119758','printshop-mobile','margin-right','10',0,'3'),(44836,14208,'119758','printshop-mobile','content','\\_',0,'4'),(44837,14208,'119758','printshop-mobile','display','inline-block',0,'4'),(44838,14208,'119758','printshop-mobile','width','70',0,'4'),(44839,14208,'119758','printshop-mobile','height','5',0,'4'),(44840,14208,'119758','printshop-mobile','border-top-width','1',0,'4'),(44841,14208,'119758','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(44842,14208,'119758','printshop-mobile','margin-left','10',0,'4'),(44843,14208,'119758','printshop-mobile','margin-right','10',0,'4'),(44844,14208,'119758','printshop-mobile','position','relative',0,''),(44845,14208,'119758','printshop-mobile','padding-top','10',0,''),(44846,14208,'119758','printshop-mobile','padding-bottom','10',0,''),(44847,14209,'119759','printshop-mobile','block_type','1',0,''),(44848,14210,'119760','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(44849,14210,'119760','printshop-mobile','font-size','18',0,''),(44850,14210,'119760','printshop-mobile','font-family','Varela Round',0,''),(44851,14210,'119760','printshop-mobile','padding-top','15',0,''),(44852,14210,'119760','printshop-mobile','padding-bottom','15',0,''),(44853,14210,'119760','printshop-mobile','text-align','center',0,''),(44854,14210,'119760','printshop-mobile','text-transform','uppercase',0,''),(44855,14211,'119761','printshop-mobile','text-align','center',0,''),(44856,14211,'119761','printshop-mobile','hide_parents','2',0,''),(44857,14212,'119762','printshop-mobile','max-width','230',0,''),(44858,14212,'119762','printshop-mobile','margin_left_measure','auto',0,''),(44859,14212,'119762','printshop-mobile','margin_right_measure','auto',0,''),(44860,14213,'119763','printshop-mobile','text','##RETURNING_CUSTOMER##',0,''),(44861,14213,'119763','printshop-mobile','font-size','18',0,''),(44862,14213,'119763','printshop-mobile','font-family','Varela Round',0,''),(44863,14213,'119763','printshop-mobile','text-transform','uppercase',0,''),(44864,14213,'119763','printshop-mobile','text-align','center',0,''),(44865,14214,'119764','printshop-mobile','block_type','1',0,''),(44866,14214,'119764','printshop-mobile','padding-top','20',0,''),(44867,14215,'119765','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(44868,14215,'119765','printshop-mobile','font-size','26',0,''),(44869,14215,'119765','printshop-mobile','font-family','Varela Round',0,''),(44870,14215,'119765','printshop-mobile','padding-top','15',0,''),(44871,14215,'119765','printshop-mobile','padding-bottom','15',0,''),(44872,14215,'119765','printshop-mobile','text-align','center',0,''),(44873,14216,'119766','printshop-mobile','text','##TEXT_OR##',0,''),(44874,14216,'119766','printshop-mobile','font-size','18',0,''),(44875,14216,'119766','printshop-mobile','font-weight','700',0,''),(44876,14216,'119766','printshop-mobile','padding-top','15',0,''),(44877,14216,'119766','printshop-mobile','text-align','center',0,''),(44878,14216,'119766','printshop-mobile','content','\\_',0,'3'),(44879,14216,'119766','printshop-mobile','height','5',0,'3'),(44880,14216,'119766','printshop-mobile','width','70',0,'3'),(44881,14216,'119766','printshop-mobile','display','inline-block',0,'3'),(44882,14216,'119766','printshop-mobile','border-top-width','1',0,'3'),(44883,14216,'119766','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(44884,14216,'119766','printshop-mobile','margin-left','10',0,'3'),(44885,14216,'119766','printshop-mobile','margin-right','10',0,'3'),(44886,14216,'119766','printshop-mobile','content','\\_',0,'4'),(44887,14216,'119766','printshop-mobile','display','inline-block',0,'4'),(44888,14216,'119766','printshop-mobile','width','70',0,'4'),(44889,14216,'119766','printshop-mobile','height','5',0,'4'),(44890,14216,'119766','printshop-mobile','border-top-width','1',0,'4'),(44891,14216,'119766','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(44892,14216,'119766','printshop-mobile','margin-left','10',0,'4'),(44893,14216,'119766','printshop-mobile','margin-right','10',0,'4'),(44894,14216,'119766','printshop-mobile','position','relative',0,''),(44895,14216,'119766','printshop-mobile','top','-10',0,''),(44896,14217,'119767','printshop-mobile','text-align','center',0,''),(44897,14218,'119768','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(44898,14218,'119768','printshop-mobile','tab_2','RETURNING CUSTOMER',1,''),(44899,14218,'119768','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(44900,14219,'119769','printshop-mobile','block_type','8',0,''),(44901,14220,'119770','printshop-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(44902,14221,'119771','printshop-mobile','block_type','1',0,''),(44903,14221,'119771','printshop-mobile','padding-left','20',0,''),(44904,14221,'119771','printshop-mobile','padding-right','20',0,''),(44905,14222,'119772','printshop-mobile','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(44906,14222,'119772','printshop-mobile','border-top-width','1',0,''),(44907,14222,'119772','printshop-mobile','border-top-color','#e0e0e0',0,''),(44908,14225,'119775','printshop-mobile','block_type','8',0,''),(44909,14226,'119776','printshop-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(44910,14227,'119777','printshop-mobile','block_type','1',0,''),(44911,14227,'119777','printshop-mobile','padding-left','20',0,''),(44912,14227,'119777','printshop-mobile','padding-right','20',0,''),(44913,14229,'119779','printshop-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(44914,14230,'119780','printshop-mobile','block_type','1',0,''),(44915,14230,'119780','printshop-mobile','padding-top','20',0,''),(44916,14231,'119781','printshop-mobile','text-align','center',0,''),(44917,14232,'119782','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(44918,14232,'119782','printshop-mobile','font-size','26',0,''),(44919,14232,'119782','printshop-mobile','font-family','Varela Round',0,''),(44920,14232,'119782','printshop-mobile','padding-top','15',0,''),(44921,14232,'119782','printshop-mobile','padding-bottom','15',0,''),(44922,14232,'119782','printshop-mobile','text-align','center',0,''),(44923,14233,'119783','printshop-mobile','text','##TEXT_OR##',0,''),(44924,14233,'119783','printshop-mobile','font-size','18',0,''),(44925,14233,'119783','printshop-mobile','font-weight','700',0,''),(44926,14233,'119783','printshop-mobile','padding-top','15',0,''),(44927,14233,'119783','printshop-mobile','text-align','center',0,''),(44928,14233,'119783','printshop-mobile','content','\\_',0,'3'),(44929,14233,'119783','printshop-mobile','height','5',0,'3'),(44930,14233,'119783','printshop-mobile','width','70',0,'3'),(44931,14233,'119783','printshop-mobile','display','inline-block',0,'3'),(44932,14233,'119783','printshop-mobile','border-top-width','1',0,'3'),(44933,14233,'119783','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(44934,14233,'119783','printshop-mobile','margin-left','10',0,'3'),(44935,14233,'119783','printshop-mobile','margin-right','10',0,'3'),(44936,14233,'119783','printshop-mobile','content','\\_',0,'4'),(44937,14233,'119783','printshop-mobile','display','inline-block',0,'4'),(44938,14233,'119783','printshop-mobile','width','70',0,'4'),(44939,14233,'119783','printshop-mobile','height','5',0,'4'),(44940,14233,'119783','printshop-mobile','border-top-width','1',0,'4'),(44941,14233,'119783','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(44942,14233,'119783','printshop-mobile','margin-left','10',0,'4'),(44943,14233,'119783','printshop-mobile','margin-right','10',0,'4'),(44944,14233,'119783','printshop-mobile','position','relative',0,''),(44945,14233,'119783','printshop-mobile','top','-10',0,''),(44946,14234,'119784','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(44947,14234,'119784','printshop-mobile','tab_2','RETURNING CUSTOMER',1,''),(44948,14234,'119784','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(44949,14235,'119785','printshop-mobile','block_type','8',0,''),(44950,14236,'119786','printshop-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(44951,14239,'119789','printshop-mobile','block_type','8',0,''),(44952,14240,'119790','printshop-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(44953,14242,'119792','printshop-mobile','block_type','1',0,''),(44954,14242,'119792','printshop-mobile','padding-left','20',0,''),(44955,14242,'119792','printshop-mobile','padding-right','20',0,''),(44956,14243,'119793','printshop-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(44957,14245,'119795','printshop-mobile','block_type','1',0,''),(44958,14245,'119795','printshop-mobile','padding-top','20',0,''),(44959,14246,'119796','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(44960,14246,'119796','printshop-mobile','font-size','26',0,''),(44961,14246,'119796','printshop-mobile','font-family','Varela Round',0,''),(44962,14246,'119796','printshop-mobile','padding-top','15',0,''),(44963,14246,'119796','printshop-mobile','padding-bottom','15',0,''),(44964,14246,'119796','printshop-mobile','text-align','center',0,''),(44965,14247,'119797','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(44966,14247,'119797','printshop-mobile','tab_2','RETURNING CUSTOMER',1,''),(44967,14247,'119797','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(44968,14248,'119798','printshop-mobile','block_type','8',0,''),(44969,14249,'119799','printshop-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(44970,14252,'119802','printshop-mobile','block_type','8',0,''),(44971,14253,'119803','printshop-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(44972,14254,'119804','printshop-mobile','block_type','1',0,''),(44973,14254,'119804','printshop-mobile','padding-left','20',0,''),(44974,14254,'119804','printshop-mobile','padding-right','20',0,''),(44975,14255,'119805','printshop-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(44976,14257,'119807','printshop-mobile','text-align','center',0,''),(44977,14258,'119808','printshop-mobile','text','##TEXT_OR##',0,''),(44978,14258,'119808','printshop-mobile','font-size','18',0,''),(44979,14258,'119808','printshop-mobile','font-weight','700',0,''),(44980,14258,'119808','printshop-mobile','padding-top','15',0,''),(44981,14258,'119808','printshop-mobile','text-align','center',0,''),(44982,14258,'119808','printshop-mobile','content','\\_',0,'3'),(44983,14258,'119808','printshop-mobile','height','5',0,'3'),(44984,14258,'119808','printshop-mobile','width','70',0,'3'),(44985,14258,'119808','printshop-mobile','display','inline-block',0,'3'),(44986,14258,'119808','printshop-mobile','border-top-width','1',0,'3'),(44987,14258,'119808','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(44988,14258,'119808','printshop-mobile','margin-left','10',0,'3'),(44989,14258,'119808','printshop-mobile','margin-right','10',0,'3'),(44990,14258,'119808','printshop-mobile','content','\\_',0,'4'),(44991,14258,'119808','printshop-mobile','display','inline-block',0,'4'),(44992,14258,'119808','printshop-mobile','width','70',0,'4'),(44993,14258,'119808','printshop-mobile','height','5',0,'4'),(44994,14258,'119808','printshop-mobile','border-top-width','1',0,'4'),(44995,14258,'119808','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(44996,14258,'119808','printshop-mobile','margin-left','10',0,'4'),(44997,14258,'119808','printshop-mobile','margin-right','10',0,'4'),(44998,14258,'119808','printshop-mobile','position','relative',0,''),(44999,14258,'119808','printshop-mobile','top','-10',0,''),(45000,14259,'119809','printshop-mobile','block_type','1',0,''),(45001,14259,'119809','printshop-mobile','padding-top','40',0,''),(45002,14259,'119809','printshop-mobile','background-color','#eeeeee',0,''),(45003,14259,'119809','printshop-mobile','padding-bottom','40',0,''),(45004,14260,'119810','printshop-mobile','block_type','2',0,''),(45005,14260,'119810','printshop-mobile','background-color','#ffffff',0,''),(45006,14260,'119810','printshop-mobile','max-width','830',0,''),(45007,14260,'119810','printshop-mobile','margin_left_measure','auto',0,''),(45008,14260,'119810','printshop-mobile','margin_right_measure','auto',0,''),(45009,14260,'119810','printshop-mobile','padding-top','40',0,''),(45010,14260,'119810','printshop-mobile','padding-bottom','40',0,''),(45011,14261,'119811','printshop-mobile','text-align','center',0,''),(45012,14261,'119811','printshop-mobile','margin-bottom','40',0,''),(45013,14262,'119812','printshop-mobile','text-align','center',0,''),(45014,14263,'119813','printshop-mobile','text','##NEW_CUSTOMER##',0,''),(45015,14263,'119813','printshop-mobile','font-size','18',0,''),(45016,14263,'119813','printshop-mobile','font-family','Varela Round',0,''),(45017,14263,'119813','printshop-mobile','text-align','center',0,''),(45018,14263,'119813','printshop-mobile','text-transform','uppercase',0,''),(45019,14263,'119813','printshop-mobile','margin-bottom','10',0,''),(45020,14264,'119814','printshop-mobile','text','##TEXT_OR##',0,''),(45021,14264,'119814','printshop-mobile','font-size','18',0,''),(45022,14264,'119814','printshop-mobile','font-weight','700',0,''),(45023,14264,'119814','printshop-mobile','text-align','center',0,''),(45024,14264,'119814','printshop-mobile','content','\\_',0,'3'),(45025,14264,'119814','printshop-mobile','height','5',0,'3'),(45026,14264,'119814','printshop-mobile','width','70',0,'3'),(45027,14264,'119814','printshop-mobile','display','inline-block',0,'3'),(45028,14264,'119814','printshop-mobile','border-top-width','1',0,'3'),(45029,14264,'119814','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(45030,14264,'119814','printshop-mobile','margin-left','10',0,'3'),(45031,14264,'119814','printshop-mobile','margin-right','10',0,'3'),(45032,14264,'119814','printshop-mobile','content','\\_',0,'4'),(45033,14264,'119814','printshop-mobile','display','inline-block',0,'4'),(45034,14264,'119814','printshop-mobile','width','70',0,'4'),(45035,14264,'119814','printshop-mobile','height','5',0,'4'),(45036,14264,'119814','printshop-mobile','border-top-width','1',0,'4'),(45037,14264,'119814','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(45038,14264,'119814','printshop-mobile','margin-left','10',0,'4'),(45039,14264,'119814','printshop-mobile','margin-right','10',0,'4'),(45040,14264,'119814','printshop-mobile','position','relative',0,''),(45041,14264,'119814','printshop-mobile','padding-top','10',0,''),(45042,14264,'119814','printshop-mobile','padding-bottom','10',0,''),(45043,14265,'119815','printshop-mobile','block_type','1',0,''),(45044,14266,'119816','printshop-mobile','text-align','center',0,''),(45045,14266,'119816','printshop-mobile','hide_parents','2',0,''),(45046,14267,'119817','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(45047,14267,'119817','printshop-mobile','font-size','18',0,''),(45048,14267,'119817','printshop-mobile','font-family','Varela Round',0,''),(45049,14267,'119817','printshop-mobile','padding-top','15',0,''),(45050,14267,'119817','printshop-mobile','padding-bottom','15',0,''),(45051,14267,'119817','printshop-mobile','text-align','center',0,''),(45052,14267,'119817','printshop-mobile','text-transform','uppercase',0,''),(45053,14268,'119818','printshop-mobile','max-width','230',0,''),(45054,14268,'119818','printshop-mobile','margin_left_measure','auto',0,''),(45055,14268,'119818','printshop-mobile','margin_right_measure','auto',0,''),(45056,14269,'119819','printshop-mobile','text','##RETURNING_CUSTOMER##',0,''),(45057,14269,'119819','printshop-mobile','font-size','18',0,''),(45058,14269,'119819','printshop-mobile','font-family','Varela Round',0,''),(45059,14269,'119819','printshop-mobile','text-transform','uppercase',0,''),(45060,14269,'119819','printshop-mobile','text-align','center',0,''),(45061,14270,'119820','printshop-mobile','block_type','1',0,''),(45062,14270,'119820','printshop-mobile','padding-top','40',0,''),(45063,14270,'119820','printshop-mobile','background-color','#eeeeee',0,''),(45064,14270,'119820','printshop-mobile','padding-bottom','40',0,''),(45065,14271,'119821','printshop-mobile','block_type','2',0,''),(45066,14271,'119821','printshop-mobile','background-color','#ffffff',0,''),(45067,14271,'119821','printshop-mobile','max-width','830',0,''),(45068,14271,'119821','printshop-mobile','margin_left_measure','auto',0,''),(45069,14271,'119821','printshop-mobile','margin_right_measure','auto',0,''),(45070,14271,'119821','printshop-mobile','padding-top','40',0,''),(45071,14271,'119821','printshop-mobile','padding-bottom','40',0,''),(45072,14272,'119822','printshop-mobile','block_type','1',0,''),(45073,14273,'119823','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(45074,14273,'119823','printshop-mobile','font-size','18',0,''),(45075,14273,'119823','printshop-mobile','font-family','Varela Round',0,''),(45076,14273,'119823','printshop-mobile','padding-top','15',0,''),(45077,14273,'119823','printshop-mobile','padding-bottom','15',0,''),(45078,14273,'119823','printshop-mobile','text-align','center',0,''),(45079,14273,'119823','printshop-mobile','text-transform','uppercase',0,''),(45080,14274,'119824','printshop-mobile','text-align','center',0,''),(45081,14274,'119824','printshop-mobile','hide_parents','2',0,''),(45082,14275,'119825','printshop-mobile','text','##TEXT_OR##',0,''),(45083,14275,'119825','printshop-mobile','font-size','18',0,''),(45084,14275,'119825','printshop-mobile','font-weight','700',0,''),(45085,14275,'119825','printshop-mobile','text-align','center',0,''),(45086,14275,'119825','printshop-mobile','content','\\_',0,'3'),(45087,14275,'119825','printshop-mobile','height','5',0,'3'),(45088,14275,'119825','printshop-mobile','width','70',0,'3'),(45089,14275,'119825','printshop-mobile','display','inline-block',0,'3'),(45090,14275,'119825','printshop-mobile','border-top-width','1',0,'3'),(45091,14275,'119825','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(45092,14275,'119825','printshop-mobile','margin-left','10',0,'3'),(45093,14275,'119825','printshop-mobile','margin-right','10',0,'3'),(45094,14275,'119825','printshop-mobile','content','\\_',0,'4'),(45095,14275,'119825','printshop-mobile','display','inline-block',0,'4'),(45096,14275,'119825','printshop-mobile','width','70',0,'4'),(45097,14275,'119825','printshop-mobile','height','5',0,'4'),(45098,14275,'119825','printshop-mobile','border-top-width','1',0,'4'),(45099,14275,'119825','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(45100,14275,'119825','printshop-mobile','margin-left','10',0,'4'),(45101,14275,'119825','printshop-mobile','margin-right','10',0,'4'),(45102,14275,'119825','printshop-mobile','position','relative',0,''),(45103,14275,'119825','printshop-mobile','padding-top','10',0,''),(45104,14275,'119825','printshop-mobile','padding-bottom','10',0,''),(45105,14276,'119826','printshop-mobile','text-align','center',0,''),(45106,14276,'119826','printshop-mobile','margin-bottom','40',0,''),(45107,14277,'119827','printshop-mobile','text','##NEW_CUSTOMER##',0,''),(45108,14277,'119827','printshop-mobile','font-size','18',0,''),(45109,14277,'119827','printshop-mobile','font-family','Varela Round',0,''),(45110,14277,'119827','printshop-mobile','text-align','center',0,''),(45111,14277,'119827','printshop-mobile','text-transform','uppercase',0,''),(45112,14277,'119827','printshop-mobile','margin-bottom','10',0,''),(45113,14278,'119828','printshop-mobile','text-align','center',0,''),(45114,14279,'119829','printshop-mobile','text','##RETURNING_CUSTOMER##',0,''),(45115,14279,'119829','printshop-mobile','font-size','18',0,''),(45116,14279,'119829','printshop-mobile','font-family','Varela Round',0,''),(45117,14279,'119829','printshop-mobile','text-transform','uppercase',0,''),(45118,14279,'119829','printshop-mobile','text-align','center',0,''),(45119,14280,'119830','printshop-mobile','max-width','230',0,''),(45120,14280,'119830','printshop-mobile','margin_left_measure','auto',0,''),(45121,14280,'119830','printshop-mobile','margin_right_measure','auto',0,''),(45122,14281,'119831','printshop-mobile','block_type','1',0,''),(45123,14282,'119832','printshop-mobile','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(45124,14282,'119832','printshop-mobile','margin-bottom','30',0,''),(45125,14283,'119833','printshop-mobile','block_type','1',0,''),(45126,14284,'119834','printshop-mobile','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(45127,14284,'119834','printshop-mobile','margin-bottom','30',0,''),(45128,14285,'119835','printshop-mobile','block_type','1',0,''),(45129,14285,'119835','printshop-mobile','font-weight','normal',0,''),(45130,14287,'119837','printshop-mobile','box_align','4',0,''),(45131,14287,'119837','printshop-mobile','margin-bottom','30',0,''),(45132,14288,'119838','printshop-mobile','tab_1','New products',1,''),(45133,14288,'119838','printshop-mobile','tab_2','Specials products',1,''),(45134,14288,'119838','printshop-mobile','font-weight','normal',0,''),(45135,14288,'119838','printshop-mobile','tab_3','Featured',1,''),(45136,14288,'119838','printshop-mobile','accordion','1',0,'693'),(45137,14289,'119839','printshop-mobile','font-weight','400',0,''),(45138,14289,'119839','printshop-mobile','listing_type','productListing',0,''),(45139,14289,'119839','printshop-mobile','show_compare','1',0,''),(45140,14289,'119839','printshop-mobile','show_model','1',0,''),(45141,14289,'119839','printshop-mobile','show_properties','1',0,''),(45142,14289,'119839','printshop-mobile','col_in_row','2',0,''),(45143,14289,'119839','printshop-mobile','show_name','0',0,''),(45144,14289,'119839','printshop-mobile','show_image','0',0,''),(45145,14289,'119839','printshop-mobile','show_stock','0',0,''),(45146,14289,'119839','printshop-mobile','show_description','0',0,''),(45147,14289,'119839','printshop-mobile','show_rating','0',0,''),(45148,14289,'119839','printshop-mobile','show_rating_counts','0',0,''),(45149,14289,'119839','printshop-mobile','show_price','0',0,''),(45150,14289,'119839','printshop-mobile','show_buy_button','0',0,''),(45151,14289,'119839','printshop-mobile','show_qty_input','0',0,''),(45152,14289,'119839','printshop-mobile','show_view_button','0',0,''),(45153,14289,'119839','printshop-mobile','show_wishlist_button','0',0,''),(45154,14289,'119839','printshop-mobile','col_in_row','2',0,'694'),(45155,14289,'119839','printshop-mobile','col_in_row','1',0,'718'),(45156,14289,'119839','printshop-mobile','view_as','carousel',0,''),(45157,14289,'119839','printshop-mobile','col_in_row','3',0,'702'),(45158,14290,'119840','printshop-mobile','font-weight','400',0,''),(45159,14290,'119840','printshop-mobile','show_compare','1',0,''),(45160,14290,'119840','printshop-mobile','listing_type','productListing',0,''),(45161,14290,'119840','printshop-mobile','show_model','1',0,''),(45162,14290,'119840','printshop-mobile','show_properties','1',0,''),(45163,14290,'119840','printshop-mobile','col_in_row','2',0,''),(45164,14290,'119840','printshop-mobile','show_name','0',0,''),(45165,14290,'119840','printshop-mobile','show_image','0',0,''),(45166,14290,'119840','printshop-mobile','show_stock','0',0,''),(45167,14290,'119840','printshop-mobile','show_description','0',0,''),(45168,14290,'119840','printshop-mobile','show_rating','0',0,''),(45169,14290,'119840','printshop-mobile','show_rating_counts','0',0,''),(45170,14290,'119840','printshop-mobile','show_price','0',0,''),(45171,14290,'119840','printshop-mobile','show_buy_button','0',0,''),(45172,14290,'119840','printshop-mobile','show_qty_input','0',0,''),(45173,14290,'119840','printshop-mobile','show_view_button','0',0,''),(45174,14290,'119840','printshop-mobile','show_wishlist_button','0',0,''),(45175,14290,'119840','printshop-mobile','col_in_row','2',0,'694'),(45176,14290,'119840','printshop-mobile','col_in_row','1',0,'718'),(45177,14290,'119840','printshop-mobile','view_as','carousel',0,''),(45178,14290,'119840','printshop-mobile','col_in_row','3',0,'702'),(45179,14290,'119840','printshop-mobile','product_names_teg','h2',0,''),(45180,14291,'119841','printshop-mobile','font-weight','400',0,''),(45181,14291,'119841','printshop-mobile','show_compare','1',0,''),(45182,14291,'119841','printshop-mobile','listing_type','productListing',0,''),(45183,14291,'119841','printshop-mobile','show_model','1',0,''),(45184,14291,'119841','printshop-mobile','show_properties','1',0,''),(45185,14291,'119841','printshop-mobile','col_in_row','2',0,''),(45186,14291,'119841','printshop-mobile','show_name','0',0,''),(45187,14291,'119841','printshop-mobile','show_image','0',0,''),(45188,14291,'119841','printshop-mobile','show_stock','0',0,''),(45189,14291,'119841','printshop-mobile','show_description','0',0,''),(45190,14291,'119841','printshop-mobile','show_rating','0',0,''),(45191,14291,'119841','printshop-mobile','show_rating_counts','0',0,''),(45192,14291,'119841','printshop-mobile','show_price','0',0,''),(45193,14291,'119841','printshop-mobile','show_buy_button','0',0,''),(45194,14291,'119841','printshop-mobile','show_qty_input','0',0,''),(45195,14291,'119841','printshop-mobile','show_view_button','0',0,''),(45196,14291,'119841','printshop-mobile','show_wishlist_button','0',0,''),(45197,14291,'119841','printshop-mobile','col_in_row','2',0,'694'),(45198,14291,'119841','printshop-mobile','col_in_row','1',0,'718'),(45199,14291,'119841','printshop-mobile','view_as','carousel',0,''),(45200,14291,'119841','printshop-mobile','col_in_row','3',0,'702'),(45201,14292,'119842','printshop-mobile','heading_type','h1',0,''),(45202,14293,'119843','printshop-mobile','block_type','1',0,''),(45203,14293,'119843','printshop-mobile','background-color','#eeeeee',0,''),(45204,14293,'119843','printshop-mobile','padding-top','20',0,''),(45205,14293,'119843','printshop-mobile','padding-bottom','20',0,''),(45206,14293,'119843','printshop-mobile','font-weight','400',0,''),(45207,14293,'119843','printshop-mobile','visibility_product','1',0,''),(45208,14293,'119843','printshop-mobile','visibility_catalog','1',0,''),(45209,14293,'119843','printshop-mobile','visibility_info','1',0,''),(45210,14293,'119843','printshop-mobile','visibility_cart','1',0,''),(45211,14293,'119843','printshop-mobile','visibility_checkout','1',0,''),(45212,14293,'119843','printshop-mobile','visibility_success','1',0,''),(45213,14293,'119843','printshop-mobile','visibility_account','1',0,''),(45214,14293,'119843','printshop-mobile','visibility_login','1',0,''),(45215,14293,'119843','printshop-mobile','visibility_other','1',0,''),(45216,14293,'119843','printshop-mobile','margin-bottom','20',0,''),(45217,14293,'119843','printshop-mobile','display_none','on',0,'694'),(45218,14294,'119844','printshop-mobile','block_type','2',0,''),(45219,14294,'119844','printshop-mobile','font-weight','normal',0,''),(45220,14295,'119845','printshop-mobile','font-weight','400',0,''),(45221,14295,'119845','printshop-mobile','visibility_product','1',0,''),(45222,14295,'119845','printshop-mobile','show_name','0',0,''),(45223,14295,'119845','printshop-mobile','show_image','1',0,''),(45224,14295,'119845','printshop-mobile','show_stock','1',0,''),(45225,14295,'119845','printshop-mobile','show_description','1',0,''),(45226,14295,'119845','printshop-mobile','show_model','1',0,''),(45227,14295,'119845','printshop-mobile','show_rating','1',0,''),(45228,14295,'119845','printshop-mobile','show_rating_counts','1',0,''),(45229,14295,'119845','printshop-mobile','show_price','1',0,''),(45230,14295,'119845','printshop-mobile','show_buy_button','1',0,''),(45231,14295,'119845','printshop-mobile','show_qty_input','1',0,''),(45232,14295,'119845','printshop-mobile','show_view_button','1',0,''),(45233,14295,'119845','printshop-mobile','show_wishlist_button','1',0,''),(45234,14295,'119845','printshop-mobile','show_compare','1',0,''),(45235,14295,'119845','printshop-mobile','listing_type','type-1',0,''),(45236,14295,'119845','printshop-mobile','show_properties','1',0,''),(45237,14296,'119846','printshop-mobile','font-weight','normal',0,''),(45238,14296,'119846','printshop-mobile','visibility_product','1',0,''),(45239,14297,'119847','printshop-mobile','block_type','1',0,''),(45240,14298,'119848','printshop-mobile','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(45241,14300,'119850','printshop-mobile','block_type','1',0,''),(45242,14300,'119850','printshop-mobile','padding-top','40',0,''),(45243,14300,'119850','printshop-mobile','padding-bottom','80',0,''),(45244,14301,'119851','printshop-mobile','block_type','6',0,''),(45245,14302,'119852','printshop-mobile','block_type','1',0,''),(45246,14302,'119852','printshop-mobile','padding-top','20',0,''),(45247,14302,'119852','printshop-mobile','padding-left','20',0,''),(45248,14302,'119852','printshop-mobile','padding-right','20',0,''),(45249,14302,'119852','printshop-mobile','padding-bottom','20',0,''),(45250,14302,'119852','printshop-mobile','border-top-width','1',0,''),(45251,14302,'119852','printshop-mobile','border-left-width','1',0,''),(45252,14302,'119852','printshop-mobile','border-right-width','1',0,''),(45253,14302,'119852','printshop-mobile','border-bottom-width','1',0,''),(45254,14302,'119852','printshop-mobile','border-top-color','#e0e0e0',0,''),(45255,14302,'119852','printshop-mobile','border-left-color','#e0e0e0',0,''),(45256,14302,'119852','printshop-mobile','border-right-color','#e0e0e0',0,''),(45257,14302,'119852','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(45258,14302,'119852','printshop-mobile','margin-right','20',0,''),(45259,14305,'119855','printshop-mobile','block_type','1',0,''),(45260,14305,'119855','printshop-mobile','padding-top','20',0,''),(45261,14306,'119856','printshop-mobile','block_type','6',0,''),(45262,14307,'119857','printshop-mobile','padding-right','20',0,''),(45263,14309,'119859','printshop-mobile','block_type','1',0,''),(45264,14309,'119859','printshop-mobile','padding-top','20',0,''),(45265,14310,'119860','printshop-mobile','block_type','6',0,''),(45266,14311,'119861','printshop-mobile','padding-right','20',0,''),(45267,14313,'119863','printshop-mobile','block_type','1',0,''),(45268,14314,'119864','printshop-mobile','block_type','6',0,''),(45269,14314,'119864','printshop-mobile','schema','6-3',0,''),(45270,14314,'119864','printshop-mobile','schema','6-3',0,'702'),(45271,14315,'119865','printshop-mobile','aria_name','account-menu',0,''),(45272,14317,'119867','printshop-mobile','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(45273,14318,'119868','printshop-mobile','text','CANCEL',0,''),(45274,14318,'119868','printshop-mobile','like_button','1',0,''),(45275,14318,'119868','printshop-mobile','padding-bottom','20',0,''),(45276,14319,'119869','printshop-mobile','block_type','1',0,''),(45277,14319,'119869','printshop-mobile','padding-top','20',0,''),(45278,14320,'119870','printshop-mobile','block_type','1',0,''),(45279,14321,'119871','printshop-mobile','tab_1','RETURNING CUSTOMER',1,''),(45280,14321,'119871','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(45281,14323,'119873','printshop-mobile','block_type','8',0,''),(45282,14324,'119874','printshop-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(45283,14325,'119875','printshop-mobile','block_type','1',0,''),(45284,14325,'119875','printshop-mobile','padding-left','20',0,''),(45285,14325,'119875','printshop-mobile','padding-right','20',0,''),(45286,14327,'119877','printshop-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(45287,14328,'119878','printshop-mobile','block_type','1',0,''),(45288,14329,'119879','printshop-mobile','margin-bottom','30',0,''),(45289,14330,'119880','printshop-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(45290,14331,'119881','printshop-mobile','margin_left_measure','auto',0,''),(45291,14331,'119881','printshop-mobile','margin_right_measure','auto',0,''),(45292,14331,'119881','printshop-mobile','max-width','560',0,''),(45293,14332,'119882','printshop-mobile','block_type','1',0,''),(45294,14334,'119884','printshop-mobile','block_type','6',0,''),(45295,14334,'119884','printshop-mobile','font-weight','400',0,''),(45296,14334,'119884','printshop-mobile','schema','6-2',0,''),(45298,14335,'119885','printshop-mobile','font-weight','400',0,''),(45299,14335,'119885','printshop-mobile','padding-right','40',0,''),(45302,14336,'119886','printshop-mobile','col_in_row','3',0,''),(45303,14336,'119886','printshop-mobile','products_align','left',0,''),(45304,14336,'119886','printshop-mobile','font-weight','400',0,''),(45305,14336,'119886','printshop-mobile','show_qty_input','0',0,''),(45306,14336,'119886','printshop-mobile','listing_type','productListing',0,''),(45307,14336,'119886','printshop-mobile','listing_type_rows','no',0,''),(45308,14336,'119886','printshop-mobile','show_buy_button_b2b','on',0,''),(45309,14336,'119886','printshop-mobile','show_wishlist_button_b2b','1',0,''),(45310,14336,'119886','printshop-mobile','show_compare_b2b','1',0,''),(45311,14336,'119886','printshop-mobile','show_stock','0',0,''),(45312,14336,'119886','printshop-mobile','show_description','0',0,''),(45313,14336,'119886','printshop-mobile','show_model','0',0,''),(45314,14336,'119886','printshop-mobile','show_properties','0',0,''),(45315,14336,'119886','printshop-mobile','show_rating','0',0,''),(45316,14336,'119886','printshop-mobile','show_rating_counts','0',0,''),(45317,14336,'119886','printshop-mobile','show_price','0',0,''),(45318,14336,'119886','printshop-mobile','show_buy_button','0',0,''),(45319,14336,'119886','printshop-mobile','show_view_button','0',0,''),(45320,14336,'119886','printshop-mobile','show_wishlist_button','0',0,''),(45321,14336,'119886','printshop-mobile','show_compare','0',0,''),(45322,14336,'119886','printshop-mobile','show_name_rows','0',0,''),(45323,14336,'119886','printshop-mobile','show_image_rows','0',0,''),(45324,14336,'119886','printshop-mobile','show_stock_rows','0',0,''),(45325,14336,'119886','printshop-mobile','show_description_rows','0',0,''),(45326,14336,'119886','printshop-mobile','show_model_rows','0',0,''),(45327,14336,'119886','printshop-mobile','show_properties_rows','0',0,''),(45328,14336,'119886','printshop-mobile','show_rating_rows','0',0,''),(45329,14336,'119886','printshop-mobile','show_rating_counts_rows','0',0,''),(45330,14336,'119886','printshop-mobile','show_price_rows','0',0,''),(45331,14336,'119886','printshop-mobile','show_buy_button_rows','0',0,''),(45332,14336,'119886','printshop-mobile','show_qty_input_rows','0',0,''),(45333,14336,'119886','printshop-mobile','show_view_button_rows','0',0,''),(45334,14336,'119886','printshop-mobile','show_wishlist_button_rows','0',0,''),(45335,14336,'119886','printshop-mobile','show_compare_rows','0',0,''),(45336,14336,'119886','printshop-mobile','show_name_b2b','0',0,''),(45337,14336,'119886','printshop-mobile','show_image_b2b','0',0,''),(45338,14336,'119886','printshop-mobile','show_stock_b2b','0',0,''),(45339,14336,'119886','printshop-mobile','show_description_b2b','0',0,''),(45340,14336,'119886','printshop-mobile','show_model_b2b','0',0,''),(45341,14336,'119886','printshop-mobile','show_properties_b2b','0',0,''),(45342,14336,'119886','printshop-mobile','show_rating_b2b','0',0,''),(45343,14336,'119886','printshop-mobile','show_rating_counts_b2b','0',0,''),(45344,14336,'119886','printshop-mobile','show_price_b2b','0',0,''),(45345,14336,'119886','printshop-mobile','show_qty_input_b2b','0',0,''),(45346,14336,'119886','printshop-mobile','show_view_button_b2b','0',0,''),(45347,14336,'119886','printshop-mobile','show_attributes_b2b','0',0,''),(45348,14336,'119886','printshop-mobile','items_on_page','9',0,''),(45351,14336,'119886','printshop-mobile','product_names_teg','h2',0,''),(45352,14338,'119888','printshop-mobile','block_type','5',0,''),(45353,14338,'119888','printshop-mobile','padding-top','10',0,''),(45354,14338,'119888','printshop-mobile','padding-bottom','10',0,''),(45355,14338,'119888','printshop-mobile','schema','5-2',0,''),(45356,14338,'119888','printshop-mobile','border-top-color','#e0e0e0',0,''),(45357,14338,'119888','printshop-mobile','border-top-width','1',0,''),(45358,14340,'119890','printshop-mobile','float','right',0,''),(45359,14341,'119891','printshop-mobile','listing_type','productListing',0,''),(45360,14343,'119893','printshop-mobile','block_type','1',0,''),(45361,14343,'119893','printshop-mobile','padding-top','10',0,''),(45362,14343,'119893','printshop-mobile','padding-bottom','10',0,''),(45363,14343,'119893','printshop-mobile','border-bottom-width','1',0,''),(45364,14343,'119893','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(45365,14343,'119893','printshop-mobile','margin-left','0',0,''),(45366,14343,'119893','printshop-mobile','margin-right','0',0,''),(45367,14344,'119894','printshop-mobile','float','right',0,''),(45368,14344,'119894','printshop-mobile','display','none',0,''),(45369,14345,'119895','printshop-mobile','float','left',0,''),(45370,14345,'119895','printshop-mobile','clear','none',0,''),(45371,14345,'119895','printshop-mobile','margin-left','20',0,''),(45372,14345,'119895','printshop-mobile','display','none',0,''),(45373,14346,'119896','printshop-mobile','margin-right','20',0,''),(45374,14346,'119896','printshop-mobile','float','right',0,''),(45375,14346,'119896','printshop-mobile','clear','none',0,''),(45376,14346,'119896','printshop-mobile','display','none',0,''),(45377,14347,'119897','printshop-mobile','float','left',0,''),(45378,14347,'119897','printshop-mobile','clear','none',0,''),(45379,14347,'119897','printshop-mobile','sort_pos_3','1',0,''),(45380,14347,'119897','printshop-mobile','sort_pos_4','2',0,''),(45381,14347,'119897','printshop-mobile','sort_pos_10','3',0,''),(45382,14347,'119897','printshop-mobile','sort_pos_9','4',0,''),(45383,14347,'119897','printshop-mobile','sort_pos_11','5',0,''),(45384,14347,'119897','printshop-mobile','sort_pos_12','6',0,''),(45385,14347,'119897','printshop-mobile','sort_pos_14','7',0,''),(45386,14347,'119897','printshop-mobile','sort_pos_13','8',0,''),(45387,14347,'119897','printshop-mobile','sort_pos_8','9',0,''),(45388,14347,'119897','printshop-mobile','sort_pos_7','10',0,''),(45389,14347,'119897','printshop-mobile','sort_pos_2','11',0,''),(45390,14347,'119897','printshop-mobile','sort_pos_1','12',0,''),(45391,14347,'119897','printshop-mobile','sort_pos_6','13',0,''),(45392,14347,'119897','printshop-mobile','sort_pos_5','14',0,''),(45393,14347,'119897','printshop-mobile','sort_pos_0','15',0,''),(45394,14347,'119897','printshop-mobile','sort_hide_10','1',0,''),(45395,14347,'119897','printshop-mobile','sort_hide_9','1',0,''),(45396,14347,'119897','printshop-mobile','hide_icons','1',0,''),(45397,14347,'119897','printshop-mobile','sort_hide_16','1',0,''),(45398,14347,'119897','printshop-mobile','sort_hide_15','1',0,''),(45399,14347,'119897','printshop-mobile','sort_hide_3','0',0,''),(45400,14347,'119897','printshop-mobile','sort_hide_4','0',0,''),(45401,14347,'119897','printshop-mobile','sort_hide_11','1',0,''),(45402,14347,'119897','printshop-mobile','sort_hide_12','1',0,''),(45403,14347,'119897','printshop-mobile','sort_hide_14','1',0,''),(45404,14347,'119897','printshop-mobile','sort_hide_13','1',0,''),(45405,14347,'119897','printshop-mobile','sort_hide_8','0',0,''),(45406,14347,'119897','printshop-mobile','sort_hide_7','0',0,''),(45407,14347,'119897','printshop-mobile','sort_hide_2','1',0,''),(45408,14347,'119897','printshop-mobile','sort_hide_1','1',0,''),(45409,14347,'119897','printshop-mobile','sort_hide_6','1',0,''),(45410,14347,'119897','printshop-mobile','sort_hide_5','1',0,''),(45411,14347,'119897','printshop-mobile','sort_hide_0','1',0,''),(45412,14348,'119898','printshop-mobile','block_type','1',0,''),(45413,14349,'119899','printshop-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(45414,14350,'119900','printshop-mobile','margin-bottom','30',0,''),(45415,14351,'119901','printshop-mobile','block_type','1',0,''),(45416,14352,'119902','printshop-mobile','block_type','1',0,''),(45417,14353,'119903','printshop-mobile','margin-bottom','20',0,''),(45418,14354,'119904','printshop-mobile','block_type','1',0,''),(45419,14354,'119904','printshop-mobile','padding-top','10',0,''),(45420,14354,'119904','printshop-mobile','padding-bottom','10',0,''),(45421,14354,'119904','printshop-mobile','border-bottom-width','1',0,''),(45422,14354,'119904','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(45423,14354,'119904','printshop-mobile','margin-left','0',0,''),(45424,14354,'119904','printshop-mobile','margin-right','0',0,''),(45425,14355,'119905','printshop-mobile','float','left',0,''),(45426,14355,'119905','printshop-mobile','clear','none',0,''),(45427,14355,'119905','printshop-mobile','sort_pos_3','2',0,''),(45428,14355,'119905','printshop-mobile','sort_pos_4','1',0,''),(45429,14355,'119905','printshop-mobile','sort_pos_10','5',0,''),(45430,14355,'119905','printshop-mobile','sort_pos_9','6',0,''),(45431,14355,'119905','printshop-mobile','sort_pos_11','7',0,''),(45432,14355,'119905','printshop-mobile','sort_pos_12','8',0,''),(45433,14355,'119905','printshop-mobile','sort_pos_14','9',0,''),(45434,14355,'119905','printshop-mobile','sort_pos_13','10',0,''),(45435,14355,'119905','printshop-mobile','sort_pos_8','11',0,''),(45436,14355,'119905','printshop-mobile','sort_pos_7','12',0,''),(45437,14355,'119905','printshop-mobile','sort_pos_2','13',0,''),(45438,14355,'119905','printshop-mobile','sort_pos_1','14',0,''),(45439,14355,'119905','printshop-mobile','sort_pos_6','15',0,''),(45440,14355,'119905','printshop-mobile','sort_pos_5','16',0,''),(45441,14355,'119905','printshop-mobile','sort_pos_0','17',0,''),(45442,14355,'119905','printshop-mobile','sort_hide_10','1',0,''),(45443,14355,'119905','printshop-mobile','sort_hide_9','1',0,''),(45444,14355,'119905','printshop-mobile','sort_pos_15','4',0,''),(45445,14355,'119905','printshop-mobile','sort_pos_16','3',0,''),(45446,14355,'119905','printshop-mobile','sort_hide_4','0',0,''),(45447,14355,'119905','printshop-mobile','sort_hide_3','0',0,''),(45448,14355,'119905','printshop-mobile','sort_hide_16','1',0,''),(45449,14355,'119905','printshop-mobile','sort_hide_15','1',0,''),(45450,14355,'119905','printshop-mobile','sort_hide_11','1',0,''),(45451,14355,'119905','printshop-mobile','sort_hide_12','1',0,''),(45452,14355,'119905','printshop-mobile','sort_hide_14','1',0,''),(45453,14355,'119905','printshop-mobile','sort_hide_13','1',0,''),(45454,14355,'119905','printshop-mobile','sort_hide_8','0',0,''),(45455,14355,'119905','printshop-mobile','sort_hide_7','0',0,''),(45456,14355,'119905','printshop-mobile','sort_hide_2','1',0,''),(45457,14355,'119905','printshop-mobile','sort_hide_1','1',0,''),(45458,14355,'119905','printshop-mobile','sort_hide_6','1',0,''),(45459,14355,'119905','printshop-mobile','sort_hide_5','1',0,''),(45460,14355,'119905','printshop-mobile','sort_hide_0','1',0,''),(45461,14355,'119905','printshop-mobile','hide_icons','1',0,''),(45462,14356,'119906','printshop-mobile','float','left',0,''),(45463,14356,'119906','printshop-mobile','clear','none',0,''),(45464,14356,'119906','printshop-mobile','margin-left','20',0,''),(45465,14356,'119906','printshop-mobile','display','none',0,''),(45466,14357,'119907','printshop-mobile','clear','none',0,''),(45467,14357,'119907','printshop-mobile','float','left',0,''),(45468,14357,'119907','printshop-mobile','padding-top','3',0,''),(45469,14357,'119907','printshop-mobile','margin-left','20',0,''),(45470,14358,'119908','printshop-mobile','margin-right','20',0,''),(45471,14358,'119908','printshop-mobile','float','right',0,''),(45472,14358,'119908','printshop-mobile','clear','none',0,''),(45473,14358,'119908','printshop-mobile','display','none',0,''),(45474,14359,'119909','printshop-mobile','float','right',0,''),(45475,14359,'119909','printshop-mobile','display','none',0,''),(45476,14360,'119910','printshop-mobile','block_type','5',0,''),(45477,14360,'119910','printshop-mobile','padding-top','10',0,''),(45478,14360,'119910','printshop-mobile','padding-bottom','10',0,''),(45479,14360,'119910','printshop-mobile','schema','5-2',0,''),(45480,14360,'119910','printshop-mobile','border-top-color','#e0e0e0',0,''),(45481,14360,'119910','printshop-mobile','border-top-width','1',0,''),(45482,14361,'119911','printshop-mobile','padding-top','3',0,''),(45483,14362,'119912','printshop-mobile','float','right',0,''),(45484,14362,'119912','printshop-mobile','height','31',0,''),(45485,14365,'119915','printshop-mobile','col_in_row','4',0,''),(45486,14365,'119915','printshop-mobile','products_align','left',0,''),(45487,14365,'119915','printshop-mobile','font-weight','400',0,''),(45488,14365,'119915','printshop-mobile','listing_type','productListing',0,''),(45489,14365,'119915','printshop-mobile','listing_type_rows','Rows',0,''),(45490,14365,'119915','printshop-mobile','show_buy_button_b2b','on',0,''),(45491,14365,'119915','printshop-mobile','show_wishlist_button_b2b','1',0,''),(45492,14365,'119915','printshop-mobile','show_compare_b2b','1',0,''),(45493,14365,'119915','printshop-mobile','listing_type_b2b','b2b',0,''),(45494,14365,'119915','printshop-mobile','show_image','0',0,''),(45495,14365,'119915','printshop-mobile','show_stock','0',0,''),(45496,14365,'119915','printshop-mobile','show_description','0',0,''),(45497,14365,'119915','printshop-mobile','show_model','0',0,''),(45498,14365,'119915','printshop-mobile','show_properties','0',0,''),(45499,14365,'119915','printshop-mobile','show_rating','0',0,''),(45500,14365,'119915','printshop-mobile','show_rating_counts','0',0,''),(45501,14365,'119915','printshop-mobile','show_price','0',0,''),(45502,14365,'119915','printshop-mobile','show_buy_button','0',0,''),(45503,14365,'119915','printshop-mobile','show_view_button','0',0,''),(45504,14365,'119915','printshop-mobile','show_wishlist_button','0',0,''),(45505,14365,'119915','printshop-mobile','show_compare','0',0,''),(45506,14365,'119915','printshop-mobile','show_name_rows','0',0,''),(45507,14365,'119915','printshop-mobile','show_image_rows','0',0,''),(45508,14365,'119915','printshop-mobile','show_stock_rows','0',0,''),(45509,14365,'119915','printshop-mobile','show_description_rows','0',0,''),(45510,14365,'119915','printshop-mobile','show_model_rows','0',0,''),(45511,14365,'119915','printshop-mobile','show_properties_rows','0',0,''),(45512,14365,'119915','printshop-mobile','show_rating_rows','0',0,''),(45513,14365,'119915','printshop-mobile','show_rating_counts_rows','0',0,''),(45514,14365,'119915','printshop-mobile','show_price_rows','0',0,''),(45515,14365,'119915','printshop-mobile','show_buy_button_rows','0',0,''),(45516,14365,'119915','printshop-mobile','show_qty_input_rows','0',0,''),(45517,14365,'119915','printshop-mobile','show_view_button_rows','0',0,''),(45518,14365,'119915','printshop-mobile','show_wishlist_button_rows','0',0,''),(45519,14365,'119915','printshop-mobile','show_compare_rows','0',0,''),(45520,14365,'119915','printshop-mobile','show_name_b2b','0',0,''),(45521,14365,'119915','printshop-mobile','show_image_b2b','0',0,''),(45522,14365,'119915','printshop-mobile','show_stock_b2b','0',0,''),(45523,14365,'119915','printshop-mobile','show_description_b2b','0',0,''),(45524,14365,'119915','printshop-mobile','show_model_b2b','0',0,''),(45525,14365,'119915','printshop-mobile','show_properties_b2b','0',0,''),(45526,14365,'119915','printshop-mobile','show_rating_b2b','0',0,''),(45527,14365,'119915','printshop-mobile','show_rating_counts_b2b','0',0,''),(45528,14365,'119915','printshop-mobile','show_price_b2b','0',0,''),(45529,14365,'119915','printshop-mobile','show_qty_input_b2b','0',0,''),(45530,14365,'119915','printshop-mobile','show_view_button_b2b','0',0,''),(45531,14365,'119915','printshop-mobile','show_attributes_b2b','0',0,''),(45532,14365,'119915','printshop-mobile','items_on_page','12',0,''),(45535,14365,'119915','printshop-mobile','product_names_teg','h2',0,''),(45536,14366,'119916','printshop-mobile','block_type','1',0,''),(45537,14367,'119917','printshop-mobile','block_type','6',0,''),(45538,14367,'119917','printshop-mobile','schema','6-3',0,''),(45539,14367,'119917','printshop-mobile','schema','6-3',0,'702'),(45540,14368,'119918','printshop-mobile','aria_name','account-menu',0,''),(45541,14369,'119919','printshop-mobile','link','Order History Info',0,''),(45542,14369,'119919','printshop-mobile','text','TEXT_VIEW',0,''),(45543,14369,'119919','printshop-mobile','show_pagenation','1',0,''),(45544,14369,'119919','printshop-mobile','link_pay','Order pay',0,''),(45545,14369,'119919','printshop-mobile','margin-bottom','20',0,''),(45546,14370,'119920','printshop-mobile','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(45547,14371,'119921','printshop-mobile','block_type','1',0,''),(45548,14372,'119922','printshop-mobile','block_type','6',0,''),(45549,14372,'119922','printshop-mobile','schema','6-3',0,'702'),(45550,14373,'119923','printshop-mobile','aria_name','account-menu',0,''),(45551,14374,'119924','printshop-mobile','float','left',0,''),(45552,14375,'119925','printshop-mobile','block_type','3',0,''),(45553,14375,'119925','printshop-mobile','clear','both',0,''),(45554,14375,'119925','printshop-mobile','padding-top','20',0,''),(45555,14375,'119925','printshop-mobile','schema','3-4',0,'702'),(45556,14376,'119926','printshop-mobile','block_type','1',0,''),(45557,14376,'119926','printshop-mobile','padding-right','20',0,''),(45558,14376,'119926','printshop-mobile','margin-bottom','20',0,''),(45559,14377,'119927','printshop-mobile','link','Tracking numbers',0,''),(45560,14377,'119927','printshop-mobile','text','MORE_TRACKING_NUMBER',0,''),(45561,14377,'119927','printshop-mobile','popup','1',0,''),(45562,14377,'119927','printshop-mobile','order_id','1',0,''),(45563,14377,'119927','printshop-mobile','popup_class','tracking-numbers-popup',0,''),(45564,14377,'119927','printshop-mobile','font-weight','700',0,''),(45565,14377,'119927','printshop-mobile','font-size','18',0,''),(45566,14378,'119928','printshop-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(45567,14379,'119929','printshop-mobile','short_view','1',0,''),(45568,14379,'119929','printshop-mobile','hide_parents','2',0,''),(45569,14380,'119930','printshop-mobile','block_type','1',0,''),(45570,14380,'119930','printshop-mobile','margin-bottom','20',0,''),(45571,14380,'119930','printshop-mobile','padding-right','20',0,''),(45572,14381,'119931','printshop-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(45573,14382,'119932','printshop-mobile','padding-left','30',0,''),(45574,14382,'119932','printshop-mobile','orders_data','telephone',0,''),(45575,14382,'119932','printshop-mobile','hide_parents','2',0,''),(45576,14383,'119933','printshop-mobile','block_type','1',0,''),(45577,14383,'119933','printshop-mobile','padding-right','20',0,''),(45578,14383,'119933','printshop-mobile','padding-bottom','20',0,''),(45579,14384,'119934','printshop-mobile','orders_data','name',0,''),(45580,14384,'119934','printshop-mobile','padding-left','30',0,''),(45581,14385,'119935','printshop-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(45582,14386,'119936','printshop-mobile','block_type','1',0,''),(45583,14386,'119936','printshop-mobile','padding-right','20',0,''),(45584,14386,'119936','printshop-mobile','padding-bottom','20',0,''),(45585,14387,'119937','printshop-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(45586,14388,'119938','printshop-mobile','orders_data','delivery_address',0,''),(45587,14388,'119938','printshop-mobile','padding-left','30',0,''),(45588,14389,'119939','printshop-mobile','block_type','1',0,''),(45589,14389,'119939','printshop-mobile','padding-right','20',0,''),(45590,14390,'119940','printshop-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(45591,14391,'119941','printshop-mobile','orders_data','shipping_method',0,''),(45592,14391,'119941','printshop-mobile','padding-left','30',0,''),(45593,14392,'119942','printshop-mobile','block_type','1',0,''),(45594,14392,'119942','printshop-mobile','padding-bottom','20',0,''),(45595,14393,'119943','printshop-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(45596,14394,'119944','printshop-mobile','orders_data','billing_address',0,''),(45597,14394,'119944','printshop-mobile','padding-left','30',0,''),(45598,14395,'119945','printshop-mobile','block_type','1',0,''),(45599,14396,'119946','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(45600,14397,'119947','printshop-mobile','orders_data','payment_method',0,''),(45601,14397,'119947','printshop-mobile','padding-left','30',0,''),(45602,14398,'119948','printshop-mobile','float','right',0,''),(45603,14400,'119950','printshop-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(45604,14403,'119953','printshop-mobile','float','right',0,''),(45605,14403,'119953','printshop-mobile','clear','none',0,''),(45606,14403,'119953','printshop-mobile','margin-left','20',0,''),(45607,14404,'119954','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(45608,14406,'119956','printshop-mobile','float','right',0,''),(45609,14406,'119956','printshop-mobile','clear','none',0,''),(45610,14406,'119956','printshop-mobile','like_button','2',0,''),(45611,14406,'119956','printshop-mobile','link','Order pay',0,''),(45612,14407,'119957','printshop-mobile','float','right',0,''),(45613,14407,'119957','printshop-mobile','clear','none',0,''),(45614,14407,'119957','printshop-mobile','margin-left','20',0,''),(45615,14408,'119958','printshop-mobile','block_type','2',0,''),(45616,14408,'119958','printshop-mobile','padding-top','20',0,''),(45617,14408,'119958','printshop-mobile','margin-bottom','20',0,''),(45618,14409,'119959','printshop-mobile','like_button','1',0,''),(45619,14409,'119959','printshop-mobile','text','IMAGE_BUTTON_BACK',0,''),(45620,14409,'119959','printshop-mobile','link','Order History',0,''),(45621,14410,'119960','printshop-mobile','text-align','right',0,''),(45622,14411,'119961','printshop-mobile','block_type','1',0,''),(45623,14412,'119962','printshop-mobile','block_type','6',0,''),(45624,14412,'119962','printshop-mobile','schema','6-3',0,''),(45625,14412,'119962','printshop-mobile','schema','6-3',0,'702'),(45626,14413,'119963','printshop-mobile','aria_name','account-menu',0,''),(45627,14416,'119966','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(45628,14417,'119967','printshop-mobile','margin-bottom','20',0,''),(45629,14418,'119968','printshop-mobile','block_type','3',0,''),(45630,14418,'119968','printshop-mobile','schema','3-4',0,'702'),(45631,14419,'119969','printshop-mobile','block_type','1',0,''),(45632,14420,'119970','printshop-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(45633,14421,'119971','printshop-mobile','padding-left','30',0,''),(45634,14422,'119972','printshop-mobile','block_type','1',0,''),(45635,14422,'119972','printshop-mobile','padding-right','20',0,''),(45636,14422,'119972','printshop-mobile','padding-bottom','20',0,''),(45637,14423,'119973','printshop-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(45638,14424,'119974','printshop-mobile','orders_data','name',0,''),(45639,14424,'119974','printshop-mobile','padding-left','30',0,''),(45640,14425,'119975','printshop-mobile','block_type','1',0,''),(45641,14425,'119975','printshop-mobile','padding-right','20',0,''),(45642,14426,'119976','printshop-mobile','orders_data','shipping_method',0,''),(45643,14426,'119976','printshop-mobile','padding-left','30',0,''),(45644,14427,'119977','printshop-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(45645,14428,'119978','printshop-mobile','block_type','1',0,''),(45646,14428,'119978','printshop-mobile','padding-right','20',0,''),(45647,14428,'119978','printshop-mobile','padding-bottom','20',0,''),(45648,14429,'119979','printshop-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(45649,14430,'119980','printshop-mobile','orders_data','delivery_address',0,''),(45650,14430,'119980','printshop-mobile','padding-left','30',0,''),(45651,14431,'119981','printshop-mobile','block_type','1',0,''),(45652,14432,'119982','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(45653,14433,'119983','printshop-mobile','orders_data','payment_method',0,''),(45654,14433,'119983','printshop-mobile','padding-left','30',0,''),(45655,14434,'119984','printshop-mobile','block_type','1',0,''),(45656,14434,'119984','printshop-mobile','padding-bottom','20',0,''),(45657,14435,'119985','printshop-mobile','orders_data','billing_address',0,''),(45658,14435,'119985','printshop-mobile','padding-left','30',0,''),(45659,14436,'119986','printshop-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(45660,14438,'119988','printshop-mobile','width','680',0,''),(45661,14438,'119988','printshop-mobile','font-weight','400',0,''),(45662,14438,'119988','printshop-mobile','font-size','12',0,''),(45663,14438,'119988','printshop-mobile','padding-top','20',0,''),(45664,14438,'119988','printshop-mobile','padding-bottom','20',0,''),(45665,14439,'119989','printshop-mobile','font-weight','normal',0,''),(45666,14439,'119989','printshop-mobile','padding-top','20',0,''),(45667,14439,'119989','printshop-mobile','font-size','12',0,''),(45668,14440,'119990','printshop-mobile','block_type','4',0,''),(45669,14440,'119990','printshop-mobile','font-weight','400',0,''),(45670,14440,'119990','printshop-mobile','border-top-width','1',0,''),(45671,14440,'119990','printshop-mobile','border-top-color','#e0e0e0',0,''),(45672,14440,'119990','printshop-mobile','border-left-width','1',0,''),(45673,14440,'119990','printshop-mobile','border-left-color','#e0e0e0',0,''),(45674,14440,'119990','printshop-mobile','border-right-width','1',0,''),(45675,14440,'119990','printshop-mobile','border-right-color','#e0e0e0',0,''),(45676,14440,'119990','printshop-mobile','border-bottom-width','1',0,''),(45677,14440,'119990','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(45678,14441,'119991','printshop-mobile','block_type','2',0,''),(45679,14441,'119991','printshop-mobile','font-weight','normal',0,''),(45680,14441,'119991','printshop-mobile','border-right-width','1',0,''),(45681,14441,'119991','printshop-mobile','border-right-color','#e0e0e0',0,''),(45682,14442,'119992','printshop-mobile','block_type','1',0,''),(45683,14442,'119992','printshop-mobile','font-weight','normal',0,''),(45684,14442,'119992','printshop-mobile','border-right-width','1',0,''),(45685,14442,'119992','printshop-mobile','border-right-color','#e0e0e0',0,''),(45686,14442,'119992','printshop-mobile','background-color','#e0e0e0',0,''),(45687,14442,'119992','printshop-mobile','padding-top','10',0,''),(45688,14442,'119992','printshop-mobile','padding-left','10',0,''),(45689,14442,'119992','printshop-mobile','padding-right','10',0,''),(45690,14442,'119992','printshop-mobile','padding-bottom','10',0,''),(45691,14443,'119993','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(45692,14443,'119993','printshop-mobile','font-size','16',0,''),(45693,14443,'119993','printshop-mobile','font-weight','bold',0,''),(45694,14443,'119993','printshop-mobile','padding-bottom','10',0,''),(45695,14444,'119994','printshop-mobile','font-size','16',0,''),(45696,14444,'119994','printshop-mobile','font-weight','normal',0,''),(45697,14445,'119995','printshop-mobile','block_type','1',0,''),(45698,14445,'119995','printshop-mobile','font-weight','normal',0,''),(45699,14445,'119995','printshop-mobile','padding-top','10',0,''),(45700,14445,'119995','printshop-mobile','padding-left','10',0,''),(45701,14445,'119995','printshop-mobile','padding-right','10',0,''),(45702,14445,'119995','printshop-mobile','padding-bottom','10',0,''),(45703,14449,'119999','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(45704,14449,'119999','printshop-mobile','font-size','14',0,''),(45705,14449,'119999','printshop-mobile','font-weight','bold',0,''),(45706,14449,'119999','printshop-mobile','padding-top','10',0,''),(45707,14450,'120000','printshop-mobile','text','<p>CUSTOMER:</p>',1,''),(45708,14450,'120000','printshop-mobile','font-size','14',0,''),(45709,14450,'120000','printshop-mobile','font-weight','bold',0,''),(45710,14451,'120001','printshop-mobile','text','<p>PHONE NUMBER:</p>',1,''),(45711,14451,'120001','printshop-mobile','font-size','14',0,''),(45712,14451,'120001','printshop-mobile','font-weight','bold',0,''),(45713,14451,'120001','printshop-mobile','padding-top','10',0,''),(45714,14452,'120002','printshop-mobile','block_type','2',0,''),(45715,14452,'120002','printshop-mobile','font-weight','normal',0,''),(45716,14452,'120002','printshop-mobile','border-right-width','1',0,''),(45717,14452,'120002','printshop-mobile','border-right-color','#e0e0e0',0,''),(45718,14452,'120002','printshop-mobile','border-top-width','1',0,''),(45719,14452,'120002','printshop-mobile','border-top-color','#e0e0e0',0,''),(45720,14453,'120003','printshop-mobile','block_type','1',0,''),(45721,14453,'120003','printshop-mobile','font-weight','normal',0,''),(45722,14453,'120003','printshop-mobile','padding-top','10',0,''),(45723,14453,'120003','printshop-mobile','padding-left','10',0,''),(45724,14453,'120003','printshop-mobile','padding-right','10',0,''),(45725,14453,'120003','printshop-mobile','padding-bottom','10',0,''),(45726,14453,'120003','printshop-mobile','border-right-width','1',0,''),(45727,14453,'120003','printshop-mobile','border-right-color','#e0e0e0',0,''),(45728,14455,'120005','printshop-mobile','text','<p>Shipping via</p>',1,''),(45729,14455,'120005','printshop-mobile','font-weight','bold',0,''),(45730,14456,'120006','printshop-mobile','block_type','1',0,''),(45731,14456,'120006','printshop-mobile','font-weight','normal',0,''),(45732,14456,'120006','printshop-mobile','padding-top','10',0,''),(45733,14456,'120006','printshop-mobile','padding-left','10',0,''),(45734,14456,'120006','printshop-mobile','padding-right','10',0,''),(45735,14456,'120006','printshop-mobile','padding-bottom','10',0,''),(45736,14457,'120007','printshop-mobile','text','<p>Shipping service</p>',1,''),(45737,14457,'120007','printshop-mobile','font-weight','bold',0,''),(45738,14459,'120009','printshop-mobile','font-weight','normal',0,''),(45739,14459,'120009','printshop-mobile','text-align','center',0,''),(45740,14459,'120009','printshop-mobile','padding-top','40',0,''),(45741,14460,'120010','printshop-mobile','block_type','1',0,''),(45742,14460,'120010','printshop-mobile','font-weight','normal',0,''),(45743,14460,'120010','printshop-mobile','padding-top','10',0,''),(45744,14460,'120010','printshop-mobile','padding-bottom','10',0,''),(45745,14461,'120011','printshop-mobile','text','<p>If undelivered please return to:</p>',1,''),(45746,14461,'120011','printshop-mobile','font-weight','bold',0,''),(45747,14463,'120013','printshop-mobile','block_type','2',0,''),(45748,14463,'120013','printshop-mobile','font-weight','normal',0,''),(45749,14463,'120013','printshop-mobile','padding-bottom','20',0,''),(45750,14464,'120014','printshop-mobile','font-weight','400',0,''),(45751,14464,'120014','printshop-mobile','text-align','center',0,''),(45752,14464,'120014','printshop-mobile','padding-top','10',0,''),(45754,14465,'120015','printshop-mobile','block_type','1',0,''),(45755,14466,'120016','printshop-mobile','font-weight','400',0,''),(45756,14466,'120016','printshop-mobile','text-align','right',0,''),(45757,14466,'120016','printshop-mobile','padding-bottom','10',0,''),(45758,14466,'120016','printshop-mobile','address_spacer',',',0,''),(45759,14467,'120017','printshop-mobile','block_type','11',0,''),(45760,14467,'120017','printshop-mobile','font-weight','normal',0,''),(45761,14468,'120018','printshop-mobile','text','<p>Phone:</p>',1,''),(45762,14468,'120018','printshop-mobile','font-weight','normal',0,''),(45763,14468,'120018','printshop-mobile','text-align','right',0,''),(45764,14469,'120019','printshop-mobile','font-weight','normal',0,''),(45765,14469,'120019','printshop-mobile','text-align','right',0,''),(45766,14470,'120020','printshop-mobile','block_type','11',0,''),(45767,14470,'120020','printshop-mobile','font-weight','400',0,''),(45768,14471,'120021','printshop-mobile','text','<p>Web:</p>',1,''),(45769,14471,'120021','printshop-mobile','font-weight','400',0,''),(45770,14471,'120021','printshop-mobile','text-align','right',0,''),(45771,14472,'120022','printshop-mobile','font-weight','normal',0,''),(45772,14472,'120022','printshop-mobile','text-align','right',0,''),(45773,14473,'120023','printshop-mobile','block_type','11',0,''),(45774,14473,'120023','printshop-mobile','font-weight','normal',0,''),(45775,14474,'120024','printshop-mobile','text','<p>Email:</p>',1,''),(45776,14474,'120024','printshop-mobile','font-weight','normal',0,''),(45777,14474,'120024','printshop-mobile','text-align','right',0,''),(45778,14475,'120025','printshop-mobile','font-weight','normal',0,''),(45779,14475,'120025','printshop-mobile','text-align','right',0,''),(45780,14476,'120026','printshop-mobile','block_type','1',0,''),(45781,14477,'120027','printshop-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(45782,14478,'120028','printshop-mobile','block_type','8',0,''),(45783,14479,'120029','printshop-mobile','margin-bottom','20',0,''),(45784,14480,'120030','printshop-mobile','text','##TEXT_MAIN##',0,''),(45785,14480,'120030','printshop-mobile','margin-bottom','20',0,''),(45786,14480,'120030','printshop-mobile','text-align','center',0,''),(45787,14482,'120032','printshop-mobile','block_type','2',0,''),(45788,14483,'120033','printshop-mobile','block_type','1',0,''),(45789,14483,'120033','printshop-mobile','style_class','product',0,''),(45790,14483,'120033','printshop-mobile','padding-right','10',0,''),(45791,14483,'120033','printshop-mobile','padding-bottom','20',0,''),(45792,14484,'120034','printshop-mobile','block_type','2',0,''),(45793,14485,'120035','printshop-mobile','product_element','image',0,''),(45794,14485,'120035','printshop-mobile','padding-right','10',0,''),(45795,14486,'120036','printshop-mobile','product_element','products_price_old',0,''),(45796,14486,'120036','printshop-mobile','font-family','Varela Round',0,''),(45797,14486,'120036','printshop-mobile','font-size','14',0,''),(45798,14486,'120036','printshop-mobile','text-decoration','line-through',0,''),(45799,14487,'120037','printshop-mobile','product_element','products_price',0,''),(45800,14487,'120037','printshop-mobile','font-family','Varela Round',0,''),(45801,14487,'120037','printshop-mobile','font-size','20',0,''),(45802,14487,'120037','printshop-mobile','padding-top','20',0,''),(45803,14488,'120038','printshop-mobile','block_type','1',0,''),(45804,14489,'120039','printshop-mobile','product_element','products_name',0,''),(45805,14489,'120039','printshop-mobile','font-family','Varela Round',0,''),(45806,14489,'120039','printshop-mobile','padding-bottom','10',0,''),(45807,14489,'120039','printshop-mobile','font-size','16',0,''),(45808,14490,'120040','printshop-mobile','block_type','1',0,''),(45809,14490,'120040','printshop-mobile','style_class','product',0,''),(45810,14490,'120040','printshop-mobile','padding-left','10',0,''),(45811,14490,'120040','printshop-mobile','padding-bottom','20',0,''),(45812,14491,'120041','printshop-mobile','block_type','1',0,''),(45813,14492,'120042','printshop-mobile','product_element','products_name',0,''),(45814,14492,'120042','printshop-mobile','font-family','Varela Round',0,''),(45815,14492,'120042','printshop-mobile','font-size','16',0,''),(45816,14492,'120042','printshop-mobile','padding-bottom','10',0,''),(45817,14493,'120043','printshop-mobile','block_type','2',0,''),(45818,14494,'120044','printshop-mobile','product_element','image',0,''),(45819,14494,'120044','printshop-mobile','padding-right','10',0,''),(45820,14495,'120045','printshop-mobile','font-size','14',0,''),(45821,14495,'120045','printshop-mobile','font-family','Varela Round',0,''),(45822,14495,'120045','printshop-mobile','text-decoration','line-through',0,''),(45823,14495,'120045','printshop-mobile','product_element','products_price_old',0,''),(45824,14496,'120046','printshop-mobile','product_element','products_price',0,''),(45825,14496,'120046','printshop-mobile','font-family','Varela Round',0,''),(45826,14496,'120046','printshop-mobile','font-size','20',0,''),(45827,14496,'120046','printshop-mobile','padding-top','20',0,''),(45828,14497,'120047','printshop-mobile','font-size','30',0,''),(45829,14497,'120047','printshop-mobile','font-family','Varela Round',0,''),(45830,14497,'120047','printshop-mobile','text-align','center',0,''),(45831,14497,'120047','printshop-mobile','padding-bottom','50',0,''),(45832,14498,'120048','printshop-mobile','padding-bottom','20',0,''),(45833,14498,'120048','printshop-mobile','text-align','center',0,''),(45834,14499,'120049','printshop-mobile','width','680',0,''),(45835,14500,'120050','printshop-mobile','padding-top','200',0,''),(45836,14500,'120050','printshop-mobile','padding-left','200',0,''),(45838,14501,'120051','printshop-mobile','text','osCommerce 4',1,''),(45839,14501,'120051','printshop-mobile','font-family','Varela Round',0,''),(45840,14501,'120051','printshop-mobile','font-size','40',0,''),(45841,14501,'120051','printshop-mobile','padding-top','50',0,''),(45842,14501,'120051','printshop-mobile','text-align','center',0,''),(45843,14502,'120052','printshop-mobile','block_type','2',0,''),(45844,14502,'120052','printshop-mobile','border-top-width','1',0,''),(45845,14502,'120052','printshop-mobile','border-top-color','#eeeeee',0,''),(45846,14503,'120053','printshop-mobile','text-align','right',0,''),(45847,14503,'120053','printshop-mobile','padding-top','15',0,''),(45848,14503,'120053','printshop-mobile','padding-bottom','15',0,''),(45849,14503,'120053','printshop-mobile','font-size','14',0,''),(45850,14504,'120054','printshop-mobile','font-family','Varela Round',0,''),(45851,14504,'120054','printshop-mobile','text-align','center',0,''),(45852,14504,'120054','printshop-mobile','font-size','20',0,''),(45853,14504,'120054','printshop-mobile','color','#183d78',0,''),(45854,14504,'120054','printshop-mobile','border-bottom-width','1',0,''),(45855,14504,'120054','printshop-mobile','border-bottom-color','#dedede',0,''),(45856,14504,'120054','printshop-mobile','padding-top','10',0,''),(45857,14504,'120054','printshop-mobile','padding-bottom','10',0,''),(45858,14505,'120055','printshop-mobile','block_type','1',0,''),(45859,14506,'120056','printshop-mobile','block_type','6',0,''),(45860,14506,'120056','printshop-mobile','schema','6-3',0,''),(45861,14506,'120056','printshop-mobile','schema','6-3',0,'702'),(45862,14507,'120057','printshop-mobile','aria_name','account-menu',0,''),(45863,14508,'120058','printshop-mobile','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(45864,14509,'120059','printshop-mobile','max_items','10',0,''),(45865,14510,'120060','printshop-mobile','block_type','1',0,''),(45866,14510,'120060','printshop-mobile','padding-top','20',0,''),(45867,14510,'120060','printshop-mobile','padding-left','20',0,''),(45868,14510,'120060','printshop-mobile','padding-right','20',0,''),(45869,14510,'120060','printshop-mobile','padding-bottom','20',0,''),(45870,14511,'120061','printshop-mobile','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(45871,14513,'120063','printshop-mobile','block_type','1',0,''),(45872,14514,'120064','printshop-mobile','margin_left_measure','auto',0,''),(45873,14514,'120064','printshop-mobile','margin_right_measure','auto',0,''),(45874,14514,'120064','printshop-mobile','max-width','560',0,''),(45875,14515,'120065','printshop-mobile','margin-bottom','30',0,''),(45876,14516,'120066','printshop-mobile','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(45877,14517,'120067','printshop-mobile','block_type','1',0,''),(45878,14518,'120068','printshop-mobile','block_type','2',0,''),(45879,14518,'120068','printshop-mobile','border-top-width','1',0,''),(45880,14518,'120068','printshop-mobile','border-top-color','#e0e0e0',0,''),(45881,14518,'120068','printshop-mobile','padding-top','15',0,''),(45882,14518,'120068','printshop-mobile','padding-bottom','15',0,''),(45883,14520,'120070','printshop-mobile','font-size','30',0,''),(45884,14520,'120070','printshop-mobile','font-weight','400',0,''),(45885,14520,'120070','printshop-mobile','line-height','35',0,''),(45886,14520,'120070','printshop-mobile','font-family','Varela Round',0,''),(45887,14520,'120070','printshop-mobile','line_height_measure','px',0,''),(45888,14521,'120071','printshop-mobile','font-weight','400',0,''),(45889,14522,'120072','printshop-mobile','font-weight','normal',0,''),(45890,14522,'120072','printshop-mobile','padding-bottom','20',0,''),(45891,14523,'120073','printshop-mobile','padding-right','0',0,''),(45892,14523,'120073','printshop-mobile','align_position','horizontal',0,''),(45893,14525,'120075','printshop-mobile','text-align','right',0,''),(45894,14525,'120075','printshop-mobile','width','100',0,'693'),(45895,14525,'120075','printshop-mobile','width_measure','%',0,'693'),(45896,14525,'120075','printshop-mobile','float','none',0,'693'),(45897,14525,'120075','printshop-mobile','margin-bottom','20',0,''),(45898,14526,'120076','printshop-mobile','font-weight','400',0,''),(45899,14526,'120076','printshop-mobile','box_align','4',0,''),(45900,14526,'120076','printshop-mobile','align_position','horizontal',0,''),(45901,14526,'120076','printshop-mobile','margin-bottom','30',0,''),(45902,14527,'120077','printshop-mobile','font-weight','400',0,''),(45903,14528,'120078','printshop-mobile','block_type','1',0,''),(45904,14528,'120078','printshop-mobile','style_class','personal-buttons',0,''),(45905,14528,'120078','printshop-mobile','margin-bottom','20',0,''),(45906,14528,'120078','printshop-mobile','border-bottom-width','1',0,''),(45907,14528,'120078','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(45908,14528,'120078','printshop-mobile','padding-left','30',0,''),(45909,14533,'120083','printshop-mobile','font-weight','normal',0,''),(45910,14533,'120083','printshop-mobile','padding-bottom','20',0,''),(45911,14533,'120083','printshop-mobile','show_qty_input','1',0,''),(45912,14533,'120083','printshop-mobile','show_compare','1',0,''),(45913,14533,'120083','printshop-mobile','col_in_row','1',0,''),(45914,14533,'120083','printshop-mobile','view_as','carousel',0,''),(45915,14533,'120083','printshop-mobile','listing_type','productListing',0,''),(45916,14534,'120084','printshop-mobile','font-weight','400',0,''),(45917,14534,'120084','printshop-mobile','padding-bottom','20',0,''),(45918,14534,'120084','printshop-mobile','show_qty_input','1',0,''),(45919,14534,'120084','printshop-mobile','show_compare','1',0,''),(45920,14534,'120084','printshop-mobile','listing_type','type-1',0,''),(45921,14534,'120084','printshop-mobile','view_as','carousel',0,''),(45922,14534,'120084','printshop-mobile','show_name','0',0,''),(45923,14534,'120084','printshop-mobile','show_image','0',0,''),(45924,14534,'120084','printshop-mobile','show_stock','0',0,''),(45925,14534,'120084','printshop-mobile','show_description','0',0,''),(45926,14534,'120084','printshop-mobile','show_model','0',0,''),(45927,14534,'120084','printshop-mobile','show_properties','0',0,''),(45928,14534,'120084','printshop-mobile','show_rating','0',0,''),(45929,14534,'120084','printshop-mobile','show_rating_counts','0',0,''),(45930,14534,'120084','printshop-mobile','show_price','0',0,''),(45931,14534,'120084','printshop-mobile','show_buy_button','0',0,''),(45932,14534,'120084','printshop-mobile','show_view_button','0',0,''),(45933,14534,'120084','printshop-mobile','show_wishlist_button','0',0,''),(45934,14534,'120084','printshop-mobile','display','none',0,'694'),(45935,14534,'120084','printshop-mobile','product_names_teg','h2',0,''),(45936,14535,'120085','printshop-mobile','font-weight','normal',0,''),(45937,14535,'120085','printshop-mobile','padding-bottom','20',0,''),(45938,14536,'120086','printshop-mobile','tab_1','Description',1,''),(45939,14536,'120086','printshop-mobile','tab_2','Reviews',1,''),(45940,14536,'120086','printshop-mobile','font-weight','400',0,''),(45941,14536,'120086','printshop-mobile','margin-top','20',0,''),(45942,14539,'120089','printshop-mobile','padding-bottom','10',0,''),(45943,14539,'120089','printshop-mobile','padding-top','5',0,''),(45944,14540,'120090','printshop-mobile','font-weight','normal',0,''),(45945,14540,'120090','printshop-mobile','padding-top','20',0,''),(45946,14540,'120090','printshop-mobile','padding-bottom','20',0,''),(45947,14540,'120090','printshop-mobile','border-top-width','1',0,''),(45948,14540,'120090','printshop-mobile','border-top-color','#cccccc',0,''),(45949,14542,'120092','printshop-mobile','font-weight','400',0,''),(45950,14542,'120092','printshop-mobile','padding-bottom','20',0,''),(45951,14542,'120092','printshop-mobile','show_qty_input','1',0,''),(45952,14542,'120092','printshop-mobile','show_compare','1',0,''),(45953,14542,'120092','printshop-mobile','show_name','0',0,''),(45954,14542,'120092','printshop-mobile','show_image','0',0,''),(45955,14542,'120092','printshop-mobile','show_stock','0',0,''),(45956,14542,'120092','printshop-mobile','show_description','0',0,''),(45957,14542,'120092','printshop-mobile','show_model','0',0,''),(45958,14542,'120092','printshop-mobile','show_properties','0',0,''),(45959,14542,'120092','printshop-mobile','show_rating','0',0,''),(45960,14542,'120092','printshop-mobile','show_rating_counts','0',0,''),(45961,14542,'120092','printshop-mobile','show_price','0',0,''),(45962,14542,'120092','printshop-mobile','show_buy_button','0',0,''),(45963,14542,'120092','printshop-mobile','show_view_button','0',0,''),(45964,14542,'120092','printshop-mobile','show_wishlist_button','0',0,''),(45965,14542,'120092','printshop-mobile','listing_type','productListing',0,''),(45966,14542,'120092','printshop-mobile','col_in_row','1',0,''),(45967,14542,'120092','printshop-mobile','view_as','carousel',0,''),(45968,14553,'120103','printshop-mobile','block_type','1',0,''),(45969,14553,'120103','printshop-mobile','style_class','item-holder',0,''),(45970,14553,'120103','printshop-mobile','padding-top','25',0,''),(45971,14553,'120103','printshop-mobile','padding-left','25',0,''),(45972,14553,'120103','printshop-mobile','padding-right','25',0,''),(45973,14553,'120103','printshop-mobile','padding-bottom','25',0,''),(45974,14553,'120103','printshop-mobile','text-align','left',0,''),(45975,14556,'120106','printshop-mobile','description_characters','90',0,''),(45976,14557,'120107','printshop-mobile','text-align','right',0,''),(45977,14557,'120107','printshop-mobile','margin-bottom','10',0,''),(45978,14558,'120108','printshop-mobile','text-align','right',0,''),(45979,14558,'120108','printshop-mobile','clear','none',0,''),(45980,14558,'120108','printshop-mobile','float','left',0,''),(45981,14560,'120110','printshop-mobile','block_type','2',0,''),(45982,14561,'120111','printshop-mobile','margin-bottom','7',0,''),(45983,14562,'120112','printshop-mobile','margin-bottom','10',0,''),(45984,14562,'120112','printshop-mobile','text-align','right',0,''),(45985,14562,'120112','printshop-mobile','float','right',0,''),(45986,14563,'120113','printshop-mobile','clear','both',0,''),(45987,14564,'120114','printshop-mobile','float','left',0,''),(45988,14564,'120114','printshop-mobile','margin-right','20',0,''),(45989,14564,'120114','printshop-mobile','margin-bottom','5',0,''),(45990,14565,'120115','printshop-mobile','block_type','1',0,''),(45991,14566,'120116','printshop-mobile','font-weight','400',0,''),(45992,14566,'120116','printshop-mobile','padding-right','40',0,''),(45993,14566,'120116','printshop-mobile','padding-right','0',0,'718'),(45994,14566,'120116','printshop-mobile','padding-right','0',0,'720'),(45995,14566,'120116','printshop-mobile','margin-bottom','20',0,''),(45996,14567,'120117','printshop-mobile','text-align','center',0,''),(45997,14567,'120117','printshop-mobile','margin-bottom','20',0,''),(45998,14569,'120119','printshop-mobile','margin-bottom','20',0,''),(45999,14569,'120119','printshop-mobile','text-align','center',0,''),(46000,14570,'120120','printshop-mobile','block_type','2',0,''),(46001,14570,'120120','printshop-mobile','margin-bottom','20',0,''),(46002,14571,'120121','printshop-mobile','sort_pos_3','1',0,''),(46003,14571,'120121','printshop-mobile','sort_pos_4','2',0,''),(46004,14571,'120121','printshop-mobile','sort_pos_10','5',0,''),(46005,14571,'120121','printshop-mobile','sort_pos_9','6',0,''),(46006,14571,'120121','printshop-mobile','sort_pos_11','7',0,''),(46007,14571,'120121','printshop-mobile','sort_pos_12','8',0,''),(46008,14571,'120121','printshop-mobile','sort_pos_14','9',0,''),(46009,14571,'120121','printshop-mobile','sort_pos_13','10',0,''),(46010,14571,'120121','printshop-mobile','sort_pos_8','11',0,''),(46011,14571,'120121','printshop-mobile','sort_pos_7','12',0,''),(46012,14571,'120121','printshop-mobile','sort_pos_2','13',0,''),(46013,14571,'120121','printshop-mobile','sort_pos_1','14',0,''),(46014,14571,'120121','printshop-mobile','sort_pos_6','15',0,''),(46015,14571,'120121','printshop-mobile','sort_pos_5','16',0,''),(46016,14571,'120121','printshop-mobile','sort_pos_0','17',0,''),(46017,14571,'120121','printshop-mobile','sort_hide_10','1',0,''),(46018,14571,'120121','printshop-mobile','sort_hide_9','1',0,''),(46019,14571,'120121','printshop-mobile','sort_pos_15','4',0,''),(46020,14571,'120121','printshop-mobile','sort_pos_16','3',0,''),(46021,14571,'120121','printshop-mobile','sort_hide_3','0',0,''),(46022,14571,'120121','printshop-mobile','sort_hide_4','0',0,''),(46023,14571,'120121','printshop-mobile','sort_hide_16','1',0,''),(46024,14571,'120121','printshop-mobile','sort_hide_15','1',0,''),(46025,14571,'120121','printshop-mobile','sort_hide_11','0',0,''),(46026,14571,'120121','printshop-mobile','sort_hide_12','0',0,''),(46027,14571,'120121','printshop-mobile','sort_hide_14','0',0,''),(46028,14571,'120121','printshop-mobile','sort_hide_13','0',0,''),(46029,14571,'120121','printshop-mobile','sort_hide_8','0',0,''),(46030,14571,'120121','printshop-mobile','sort_hide_7','0',0,''),(46031,14571,'120121','printshop-mobile','sort_hide_2','0',0,''),(46032,14571,'120121','printshop-mobile','sort_hide_1','0',0,''),(46033,14571,'120121','printshop-mobile','sort_hide_6','0',0,''),(46034,14571,'120121','printshop-mobile','sort_hide_5','0',0,''),(46035,14571,'120121','printshop-mobile','sort_hide_0','0',0,''),(46036,14572,'120122','printshop-mobile','text-align','right',0,''),(46037,14572,'120122','printshop-mobile','padding-top','10',0,''),(46038,14573,'120123','printshop-mobile','col_in_row','2',0,''),(46039,14573,'120123','printshop-mobile','products_align','left',0,''),(46040,14573,'120123','printshop-mobile','font-weight','400',0,''),(46041,14573,'120123','printshop-mobile','show_qty_input','1',0,''),(46042,14573,'120123','printshop-mobile','listing_type','productListing',0,''),(46043,14573,'120123','printshop-mobile','listing_type_rows','type-1_2',0,''),(46044,14573,'120123','printshop-mobile','show_buy_button_b2b','on',0,''),(46045,14573,'120123','printshop-mobile','show_wishlist_button_b2b','1',0,''),(46046,14573,'120123','printshop-mobile','show_compare_b2b','1',0,''),(46047,14573,'120123','printshop-mobile','listing_type_b2b','type-1_3',0,''),(46048,14573,'120123','printshop-mobile','show_name','0',0,''),(46049,14573,'120123','printshop-mobile','show_image','0',0,''),(46050,14573,'120123','printshop-mobile','show_stock','0',0,''),(46051,14573,'120123','printshop-mobile','show_description','1',0,''),(46052,14573,'120123','printshop-mobile','show_model','1',0,''),(46053,14573,'120123','printshop-mobile','show_properties','1',0,''),(46054,14573,'120123','printshop-mobile','show_rating_counts','1',0,''),(46055,14573,'120123','printshop-mobile','show_price','0',0,''),(46056,14573,'120123','printshop-mobile','show_buy_button','1',0,''),(46057,14573,'120123','printshop-mobile','show_view_button','1',0,''),(46058,14573,'120123','printshop-mobile','show_wishlist_button','1',0,''),(46059,14573,'120123','printshop-mobile','show_compare','1',0,''),(46060,14573,'120123','printshop-mobile','show_name_rows','0',0,''),(46061,14573,'120123','printshop-mobile','show_image_rows','0',0,''),(46062,14573,'120123','printshop-mobile','show_stock_rows','0',0,''),(46063,14573,'120123','printshop-mobile','show_description_rows','0',0,''),(46064,14573,'120123','printshop-mobile','show_model_rows','0',0,''),(46065,14573,'120123','printshop-mobile','show_properties_rows','0',0,''),(46066,14573,'120123','printshop-mobile','show_rating_rows','0',0,''),(46067,14573,'120123','printshop-mobile','show_rating_counts_rows','0',0,''),(46068,14573,'120123','printshop-mobile','show_price_rows','0',0,''),(46069,14573,'120123','printshop-mobile','show_buy_button_rows','0',0,''),(46070,14573,'120123','printshop-mobile','show_qty_input_rows','0',0,''),(46071,14573,'120123','printshop-mobile','show_view_button_rows','0',0,''),(46072,14573,'120123','printshop-mobile','show_wishlist_button_rows','0',0,''),(46073,14573,'120123','printshop-mobile','show_compare_rows','0',0,''),(46074,14573,'120123','printshop-mobile','show_name_b2b','0',0,''),(46075,14573,'120123','printshop-mobile','show_image_b2b','0',0,''),(46076,14573,'120123','printshop-mobile','show_stock_b2b','0',0,''),(46077,14573,'120123','printshop-mobile','show_description_b2b','0',0,''),(46078,14573,'120123','printshop-mobile','show_model_b2b','0',0,''),(46079,14573,'120123','printshop-mobile','show_properties_b2b','0',0,''),(46080,14573,'120123','printshop-mobile','show_rating_b2b','0',0,''),(46081,14573,'120123','printshop-mobile','show_rating_counts_b2b','0',0,''),(46082,14573,'120123','printshop-mobile','show_price_b2b','0',0,''),(46083,14573,'120123','printshop-mobile','show_qty_input_b2b','0',0,''),(46084,14573,'120123','printshop-mobile','show_view_button_b2b','0',0,''),(46085,14573,'120123','printshop-mobile','show_attributes_b2b','0',0,''),(46086,14573,'120123','printshop-mobile','items_on_page','10',0,''),(46087,14573,'120123','printshop-mobile','product_names_teg','h2',0,''),(46088,14575,'120125','printshop-mobile','block_type','1',0,''),(46089,14577,'120127','printshop-mobile','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(46090,14578,'120128','printshop-mobile','width','680',0,''),(46091,14578,'120128','printshop-mobile','font-weight','normal',0,''),(46092,14578,'120128','printshop-mobile','font-size','12',0,''),(46093,14578,'120128','printshop-mobile','padding-top','20',0,''),(46094,14578,'120128','printshop-mobile','padding-bottom','20',0,''),(46095,14578,'120128','printshop-mobile','color','#424242',0,''),(46096,14579,'120129','printshop-mobile','block_type','5',0,''),(46097,14579,'120129','printshop-mobile','font-weight','normal',0,''),(46098,14579,'120129','printshop-mobile','border-bottom-width','1',0,''),(46099,14579,'120129','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(46100,14579,'120129','printshop-mobile','border-top-width','1',0,''),(46101,14579,'120129','printshop-mobile','border-top-color','#e0e0e0',0,''),(46102,14579,'120129','printshop-mobile','border-left-color','#e0e0e0',0,''),(46103,14579,'120129','printshop-mobile','border-left-width','1',0,''),(46104,14580,'120130','printshop-mobile','block_type','1',0,''),(46105,14580,'120130','printshop-mobile','font-weight','normal',0,''),(46106,14580,'120130','printshop-mobile','padding-top','10',0,''),(46107,14580,'120130','printshop-mobile','padding-left','10',0,''),(46108,14580,'120130','printshop-mobile','padding-right','10',0,''),(46109,14581,'120131','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(46110,14581,'120131','printshop-mobile','font-size','14',0,''),(46111,14581,'120131','printshop-mobile','font-weight','bold',0,''),(46112,14581,'120131','printshop-mobile','padding-bottom','10',0,''),(46113,14582,'120132','printshop-mobile','font-weight','400',0,''),(46114,14582,'120132','printshop-mobile','line-height','120',0,''),(46115,14582,'120132','printshop-mobile','line_height_measure','%',0,''),(46116,14582,'120132','printshop-mobile','font-size','12',0,''),(46117,14583,'120133','printshop-mobile','block_type','4',0,''),(46118,14583,'120133','printshop-mobile','font-weight','normal',0,''),(46119,14583,'120133','printshop-mobile','border-top-width','1',0,''),(46120,14583,'120133','printshop-mobile','border-top-color','#e0e0e0',0,''),(46121,14583,'120133','printshop-mobile','border-left-width','1',0,''),(46122,14583,'120133','printshop-mobile','border-left-color','#e0e0e0',0,''),(46123,14583,'120133','printshop-mobile','border-right-width','1',0,''),(46124,14583,'120133','printshop-mobile','border-right-color','#e0e0e0',0,''),(46125,14583,'120133','printshop-mobile','border-bottom-width','1',0,''),(46126,14583,'120133','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(46127,14584,'120134','printshop-mobile','block_type','2',0,''),(46128,14584,'120134','printshop-mobile','font-weight','normal',0,''),(46129,14584,'120134','printshop-mobile','border-right-width','1',0,''),(46130,14584,'120134','printshop-mobile','border-right-color','#e0e0e0',0,''),(46131,14585,'120135','printshop-mobile','block_type','1',0,''),(46132,14585,'120135','printshop-mobile','font-weight','400',0,''),(46133,14585,'120135','printshop-mobile','background-color','#eeeeee',0,''),(46134,14585,'120135','printshop-mobile','padding-top','10',0,''),(46135,14585,'120135','printshop-mobile','padding-left','10',0,''),(46136,14585,'120135','printshop-mobile','padding-right','10',0,''),(46137,14585,'120135','printshop-mobile','padding-bottom','30',0,''),(46138,14586,'120136','printshop-mobile','text','<p>ADDRESS:</p>\n',1,''),(46139,14586,'120136','printshop-mobile','font-size','14',0,''),(46140,14586,'120136','printshop-mobile','font-weight','bold',0,''),(46141,14587,'120137','printshop-mobile','font-size','12',0,''),(46142,14588,'120138','printshop-mobile','block_type','1',0,''),(46143,14588,'120138','printshop-mobile','font-weight','normal',0,''),(46144,14588,'120138','printshop-mobile','padding-top','10',0,''),(46145,14588,'120138','printshop-mobile','padding-left','10',0,''),(46146,14588,'120138','printshop-mobile','padding-right','10',0,''),(46147,14588,'120138','printshop-mobile','padding-bottom','10',0,''),(46148,14589,'120139','printshop-mobile','text','<p>CUSTOMER:</p>',1,''),(46149,14589,'120139','printshop-mobile','font-size','13',0,''),(46150,14589,'120139','printshop-mobile','font-weight','bold',0,''),(46151,14590,'120140','printshop-mobile','text','<p>PHONE NUMBER:</p>',1,''),(46152,14590,'120140','printshop-mobile','font-size','14',0,''),(46153,14590,'120140','printshop-mobile','font-weight','bold',0,''),(46154,14590,'120140','printshop-mobile','padding-top','10',0,''),(46155,14591,'120141','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(46156,14591,'120141','printshop-mobile','font-weight','bold',0,''),(46157,14591,'120141','printshop-mobile','font-size','14',0,''),(46158,14591,'120141','printshop-mobile','padding-top','10',0,''),(46159,14592,'120142','printshop-mobile','font-weight','normal',0,''),(46160,14593,'120143','printshop-mobile','font-weight','normal',0,''),(46161,14595,'120145','printshop-mobile','text','<p>Order date:</p>\n',1,''),(46162,14595,'120145','printshop-mobile','font-weight','bold',0,''),(46163,14595,'120145','printshop-mobile','text-align','center',0,''),(46164,14595,'120145','printshop-mobile','font-size','12',0,''),(46165,14596,'120146','printshop-mobile','font-weight','normal',0,''),(46166,14596,'120146','printshop-mobile','text-align','center',0,''),(46167,14596,'120146','printshop-mobile','padding-bottom','10',0,''),(46168,14597,'120147','printshop-mobile','font-size','14',0,''),(46169,14597,'120147','printshop-mobile','font-weight','bold',0,''),(46170,14597,'120147','printshop-mobile','text-align','center',0,''),(46171,14597,'120147','printshop-mobile','padding-bottom','10',0,''),(46172,14597,'120147','printshop-mobile','padding-top','10',0,''),(46173,14598,'120148','printshop-mobile','block_type','2',0,''),(46174,14598,'120148','printshop-mobile','font-weight','normal',0,''),(46175,14598,'120148','printshop-mobile','padding-bottom','20',0,''),(46176,14599,'120149','printshop-mobile','font-weight','400',0,''),(46177,14599,'120149','printshop-mobile','padding-top','20',0,''),(46179,14600,'120150','printshop-mobile','block_type','1',0,''),(46180,14601,'120151','printshop-mobile','font-weight','normal',0,''),(46181,14601,'120151','printshop-mobile','text-align','right',0,''),(46182,14601,'120151','printshop-mobile','padding-bottom','10',0,''),(46183,14601,'120151','printshop-mobile','address_spacer',',',0,''),(46184,14601,'120151','printshop-mobile','font-size','12',0,''),(46185,14602,'120152','printshop-mobile','block_type','11',0,''),(46186,14602,'120152','printshop-mobile','font-weight','normal',0,''),(46187,14603,'120153','printshop-mobile','text','<p>Email:</p>',1,''),(46188,14603,'120153','printshop-mobile','font-weight','normal',0,''),(46189,14603,'120153','printshop-mobile','text-align','right',0,''),(46190,14604,'120154','printshop-mobile','font-weight','normal',0,''),(46191,14604,'120154','printshop-mobile','text-align','right',0,''),(46192,14605,'120155','printshop-mobile','block_type','11',0,''),(46193,14605,'120155','printshop-mobile','font-weight','normal',0,''),(46194,14606,'120156','printshop-mobile','text','<p>Web:</p>',1,''),(46195,14606,'120156','printshop-mobile','font-weight','normal',0,''),(46196,14606,'120156','printshop-mobile','text-align','right',0,''),(46197,14607,'120157','printshop-mobile','font-weight','normal',0,''),(46198,14607,'120157','printshop-mobile','text-align','right',0,''),(46199,14608,'120158','printshop-mobile','block_type','11',0,''),(46200,14608,'120158','printshop-mobile','font-weight','normal',0,''),(46201,14609,'120159','printshop-mobile','text','<p>Phone:</p>',1,''),(46202,14609,'120159','printshop-mobile','font-weight','normal',0,''),(46203,14609,'120159','printshop-mobile','text-align','right',0,''),(46204,14610,'120160','printshop-mobile','font-weight','normal',0,''),(46205,14610,'120160','printshop-mobile','text-align','right',0,''),(46206,14611,'120161','printshop-mobile','block_type','3',0,''),(46207,14611,'120161','printshop-mobile','font-weight','normal',0,''),(46208,14611,'120161','printshop-mobile','padding-top','20',0,''),(46209,14612,'120162','printshop-mobile','font-size','12',0,''),(46210,14613,'120163','printshop-mobile','text','<p>If undelivered please return to:</p>',1,''),(46211,14613,'120163','printshop-mobile','font-size','12',0,''),(46212,14613,'120163','printshop-mobile','font-weight','bold',0,''),(46213,14614,'120164','printshop-mobile','text','<p>Thank you for your order</p>',1,''),(46214,14614,'120164','printshop-mobile','color','#1da1f2',0,''),(46215,14614,'120164','printshop-mobile','font-size','13',0,''),(46216,14614,'120164','printshop-mobile','font-weight','bold',0,''),(46217,14614,'120164','printshop-mobile','padding-top','5',0,''),(46218,14614,'120164','printshop-mobile','text-align','center',0,''),(46219,14615,'120165','printshop-mobile','font-weight','400',0,''),(46220,14615,'120165','printshop-mobile','text-align','center',0,''),(46221,14615,'120165','printshop-mobile','padding-top','0',0,''),(46223,14615,'120165','printshop-mobile','padding-left','20',0,''),(46224,14615,'120165','printshop-mobile','padding-right','20',0,''),(46225,14616,'120166','printshop-mobile','block_type','6',0,''),(46226,14616,'120166','printshop-mobile','font-weight','normal',0,''),(46227,14616,'120166','printshop-mobile','font-size','16',0,''),(46228,14617,'120167','printshop-mobile','text','<p>Phone:</p>',1,''),(46229,14617,'120167','printshop-mobile','font-weight','normal',0,''),(46230,14617,'120167','printshop-mobile','text-align','right',0,''),(46231,14617,'120167','printshop-mobile','font-size','12',0,''),(46232,14618,'120168','printshop-mobile','font-weight','normal',0,''),(46233,14618,'120168','printshop-mobile','text-align','right',0,''),(46234,14618,'120168','printshop-mobile','font-size','12',0,''),(46235,14619,'120169','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(46236,14619,'120169','printshop-mobile','font-size','12',0,''),(46237,14619,'120169','printshop-mobile','font-weight','bold',0,''),(46238,14619,'120169','printshop-mobile','text-align','right',0,''),(46239,14620,'120170','printshop-mobile','block_type','6',0,''),(46240,14620,'120170','printshop-mobile','font-weight','normal',0,''),(46241,14620,'120170','printshop-mobile','font-size','16',0,''),(46242,14621,'120171','printshop-mobile','text','<p>Email:</p>',1,''),(46243,14621,'120171','printshop-mobile','font-weight','normal',0,''),(46244,14621,'120171','printshop-mobile','text-align','right',0,''),(46245,14621,'120171','printshop-mobile','font-size','12',0,''),(46246,14622,'120172','printshop-mobile','font-weight','normal',0,''),(46247,14622,'120172','printshop-mobile','text-align','right',0,''),(46248,14622,'120172','printshop-mobile','font-size','12',0,''),(46249,14623,'120173','printshop-mobile','font-weight','400',0,''),(46250,14623,'120173','printshop-mobile','padding-top','20',0,''),(46251,14623,'120173','printshop-mobile','padding-bottom','0',0,''),(46252,14623,'120173','printshop-mobile','font-size','12',0,''),(46253,14624,'120174','printshop-mobile','block_type','1',0,''),(46254,14625,'120175','printshop-mobile','block_type','6',0,''),(46255,14625,'120175','printshop-mobile','schema','6-3',0,'702'),(46256,14626,'120176','printshop-mobile','aria_name','account-menu',0,''),(46257,14627,'120177','printshop-mobile','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(46258,14628,'120178','printshop-mobile','link','Quotation Info',0,''),(46259,14628,'120178','printshop-mobile','margin-bottom','20',0,''),(46260,14629,'120179','printshop-mobile','block_type','1',0,''),(46261,14630,'120180','printshop-mobile','block_type','6',0,''),(46262,14630,'120180','printshop-mobile','schema','6-3',0,''),(46263,14630,'120180','printshop-mobile','schema','6-3',0,'702'),(46264,14631,'120181','printshop-mobile','aria_name','account-menu',0,''),(46265,14634,'120184','printshop-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(46266,14635,'120185','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(46267,14637,'120187','printshop-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(46268,14638,'120188','printshop-mobile','block_type','2',0,''),(46269,14638,'120188','printshop-mobile','padding-top','20',0,''),(46270,14638,'120188','printshop-mobile','margin-bottom','20',0,''),(46271,14639,'120189','printshop-mobile','like_button','1',0,''),(46272,14639,'120189','printshop-mobile','text','IMAGE_BUTTON_BACK',0,''),(46273,14639,'120189','printshop-mobile','link','Quotations',0,''),(46274,14640,'120190','printshop-mobile','block_type','3',0,''),(46275,14640,'120190','printshop-mobile','schema','3-4',0,'702'),(46276,14641,'120191','printshop-mobile','block_type','1',0,''),(46277,14641,'120191','printshop-mobile','padding-right','20',0,''),(46278,14641,'120191','printshop-mobile','padding-bottom','20',0,''),(46279,14642,'120192','printshop-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(46280,14643,'120193','printshop-mobile','orders_data','telephone',0,''),(46281,14644,'120194','printshop-mobile','block_type','1',0,''),(46282,14644,'120194','printshop-mobile','padding-right','20',0,''),(46283,14644,'120194','printshop-mobile','padding-bottom','20',0,''),(46284,14645,'120195','printshop-mobile','orders_data','name',0,''),(46285,14646,'120196','printshop-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(46286,14647,'120197','printshop-mobile','block_type','1',0,''),(46287,14647,'120197','printshop-mobile','padding-right','20',0,''),(46288,14648,'120198','printshop-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(46289,14649,'120199','printshop-mobile','orders_data','shipping_method',0,''),(46290,14650,'120200','printshop-mobile','block_type','1',0,''),(46291,14650,'120200','printshop-mobile','padding-right','20',0,''),(46292,14650,'120200','printshop-mobile','padding-bottom','20',0,''),(46293,14651,'120201','printshop-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(46294,14652,'120202','printshop-mobile','orders_data','delivery_address',0,''),(46295,14653,'120203','printshop-mobile','block_type','1',0,''),(46296,14653,'120203','printshop-mobile','padding-bottom','20',0,''),(46297,14654,'120204','printshop-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(46298,14655,'120205','printshop-mobile','orders_data','billing_address',0,''),(46299,14656,'120206','printshop-mobile','block_type','1',0,''),(46300,14657,'120207','printshop-mobile','orders_data','payment_method',0,''),(46301,14658,'120208','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(46302,14661,'120211','printshop-mobile','text','<h1>Quotations</h1>',1,''),(46303,14662,'120212','printshop-mobile','block_type','1',0,''),(46304,14663,'120213','printshop-mobile','block_type','6',0,''),(46305,14663,'120213','printshop-mobile','schema','6-3',0,''),(46306,14663,'120213','printshop-mobile','schema','6-3',0,'702'),(46307,14664,'120214','printshop-mobile','aria_name','account-menu',0,''),(46308,14665,'120215','printshop-mobile','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(46309,14666,'120216','printshop-mobile','margin-bottom','20',0,''),(46310,14667,'120217','printshop-mobile','block_type','1',0,''),(46311,14668,'120218','printshop-mobile','pagination','bottom',0,''),(46312,14670,'120220','printshop-mobile','width','800',0,''),(46313,14671,'120221','printshop-mobile','block_type','1',0,''),(46314,14671,'120221','printshop-mobile','border-top-width','1',0,''),(46315,14671,'120221','printshop-mobile','border-left-width','1',0,''),(46316,14671,'120221','printshop-mobile','border-right-width','1',0,''),(46317,14671,'120221','printshop-mobile','border-bottom-width','1',0,''),(46318,14671,'120221','printshop-mobile','border-top-color','#000000',0,''),(46319,14671,'120221','printshop-mobile','border-left-color','#000000',0,''),(46320,14671,'120221','printshop-mobile','border-right-color','#000000',0,''),(46321,14671,'120221','printshop-mobile','border-bottom-color','#000000',0,''),(46322,14672,'120222','printshop-mobile','block_type','11',0,''),(46323,14673,'120223','printshop-mobile','block_type','1',0,''),(46324,14673,'120223','printshop-mobile','padding-top','10',0,''),(46325,14673,'120223','printshop-mobile','padding-right','10',0,''),(46326,14673,'120223','printshop-mobile','padding-bottom','10',0,''),(46327,14673,'120223','printshop-mobile','border-right-width','1',0,''),(46328,14673,'120223','printshop-mobile','border-right-color','#000000',0,''),(46329,14674,'120224','printshop-mobile','block_type','1',0,''),(46330,14674,'120224','printshop-mobile','padding-left','10',0,''),(46331,14674,'120224','printshop-mobile','padding-right','10',0,''),(46332,14674,'120224','printshop-mobile','padding-bottom','10',0,''),(46333,14675,'120225','printshop-mobile','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(46334,14675,'120225','printshop-mobile','font-size','11',0,''),(46335,14675,'120225','printshop-mobile','font-style','italic',0,''),(46336,14676,'120226','printshop-mobile','block_type','9',0,''),(46337,14677,'120227','printshop-mobile','text','2.',0,''),(46338,14677,'120227','printshop-mobile','font-size','12',0,''),(46339,14677,'120227','printshop-mobile','text-align','right',0,''),(46340,14677,'120227','printshop-mobile','padding-right','5',0,''),(46341,14678,'120228','printshop-mobile','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(46342,14678,'120228','printshop-mobile','font-size','12',0,''),(46343,14678,'120228','printshop-mobile','padding-bottom','10',0,''),(46344,14679,'120229','printshop-mobile','block_type','1',0,''),(46345,14680,'120230','printshop-mobile','text','Shipping Instructions:',0,''),(46346,14680,'120230','printshop-mobile','font-weight','bold',0,''),(46347,14680,'120230','printshop-mobile','font-size','14',0,''),(46348,14680,'120230','printshop-mobile','padding-bottom','5',0,''),(46349,14680,'120230','printshop-mobile','padding-left','10',0,''),(46350,14681,'120231','printshop-mobile','block_type','9',0,''),(46351,14682,'120232','printshop-mobile','text','1.',0,''),(46352,14682,'120232','printshop-mobile','font-size','12',0,''),(46353,14682,'120232','printshop-mobile','text-align','right',0,''),(46354,14682,'120232','printshop-mobile','padding-right','5',0,''),(46355,14683,'120233','printshop-mobile','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(46356,14683,'120233','printshop-mobile','font-size','12',0,''),(46357,14683,'120233','printshop-mobile','padding-bottom','10',0,''),(46358,14684,'120234','printshop-mobile','block_type','9',0,''),(46359,14685,'120235','printshop-mobile','text','3.',0,''),(46360,14685,'120235','printshop-mobile','font-size','12',0,''),(46361,14685,'120235','printshop-mobile','text-align','right',0,''),(46362,14685,'120235','printshop-mobile','padding-right','5',0,''),(46363,14686,'120236','printshop-mobile','text','Ship only the items that are authorized.',0,''),(46364,14686,'120236','printshop-mobile','font-size','12',0,''),(46365,14686,'120236','printshop-mobile','padding-bottom','10',0,''),(46366,14687,'120237','printshop-mobile','block_type','9',0,''),(46367,14688,'120238','printshop-mobile','text','4.',0,''),(46368,14688,'120238','printshop-mobile','font-size','12',0,''),(46369,14688,'120238','printshop-mobile','text-align','right',0,''),(46370,14688,'120238','printshop-mobile','padding-right','5',0,''),(46371,14689,'120239','printshop-mobile','text','Ship returned items to:',0,''),(46372,14689,'120239','printshop-mobile','font-size','12',0,''),(46373,14689,'120239','printshop-mobile','padding-bottom','5',0,''),(46374,14690,'120240','printshop-mobile','font-size','11',0,''),(46375,14690,'120240','printshop-mobile','font-style','italic',0,''),(46376,14690,'120240','printshop-mobile','padding-bottom','5',0,''),(46377,14691,'120241','printshop-mobile','block_type','3',0,''),(46378,14691,'120241','printshop-mobile','padding-right','10',0,''),(46379,14692,'120242','printshop-mobile','text','Customer Signature:',0,''),(46380,14692,'120242','printshop-mobile','font-weight','bold',0,''),(46381,14692,'120242','printshop-mobile','font-size','11',0,''),(46382,14692,'120242','printshop-mobile','padding-top','5',0,''),(46383,14692,'120242','printshop-mobile','padding-left','10',0,''),(46384,14693,'120243','printshop-mobile','text','&nbsp;',0,''),(46385,14693,'120243','printshop-mobile','border-bottom-width','1',0,''),(46386,14693,'120243','printshop-mobile','border-bottom-color','#000000',0,''),(46387,14694,'120244','printshop-mobile','block_type','5',0,''),(46388,14695,'120245','printshop-mobile','text','Date:',0,''),(46389,14695,'120245','printshop-mobile','padding-top','5',0,''),(46390,14695,'120245','printshop-mobile','font-size','11',0,''),(46391,14695,'120245','printshop-mobile','font-weight','bold',0,''),(46392,14695,'120245','printshop-mobile','padding-left','5',0,''),(46393,14696,'120246','printshop-mobile','text','&nbsp;',0,''),(46394,14696,'120246','printshop-mobile','border-bottom-width','1',0,''),(46395,14696,'120246','printshop-mobile','border-bottom-color','#000000',0,''),(46396,14697,'120247','printshop-mobile','block_type','3',0,''),(46397,14697,'120247','printshop-mobile','padding-top','10',0,''),(46398,14697,'120247','printshop-mobile','padding-bottom','10',0,''),(46399,14697,'120247','printshop-mobile','padding-right','10',0,''),(46400,14698,'120248','printshop-mobile','font-size','11',0,''),(46401,14698,'120248','printshop-mobile','font-weight','bold',0,''),(46402,14698,'120248','printshop-mobile','text','Return Approval:',0,''),(46403,14698,'120248','printshop-mobile','padding-top','5',0,''),(46404,14698,'120248','printshop-mobile','padding-left','10',0,''),(46405,14699,'120249','printshop-mobile','border-bottom-width','1',0,''),(46406,14699,'120249','printshop-mobile','border-bottom-color','#000000',0,''),(46407,14699,'120249','printshop-mobile','text','&nbsp;',0,''),(46408,14700,'120250','printshop-mobile','block_type','5',0,''),(46409,14701,'120251','printshop-mobile','text','Date:',0,''),(46410,14701,'120251','printshop-mobile','padding-top','5',0,''),(46411,14701,'120251','printshop-mobile','font-size','11',0,''),(46412,14701,'120251','printshop-mobile','font-weight','bold',0,''),(46413,14701,'120251','printshop-mobile','padding-left','5',0,''),(46414,14702,'120252','printshop-mobile','text','&nbsp;',0,''),(46415,14702,'120252','printshop-mobile','border-bottom-width','1',0,''),(46416,14702,'120252','printshop-mobile','border-bottom-color','#000000',0,''),(46417,14703,'120253','printshop-mobile','block_type','1',0,''),(46418,14703,'120253','printshop-mobile','padding-left','10',0,''),(46419,14703,'120253','printshop-mobile','padding-right','10',0,''),(46420,14703,'120253','printshop-mobile','padding-bottom','10',0,''),(46421,14704,'120254','printshop-mobile','text','Use this space for additional Comments:',0,''),(46422,14704,'120254','printshop-mobile','font-size','11',0,''),(46423,14704,'120254','printshop-mobile','font-style','italic',0,''),(46424,14705,'120255','printshop-mobile','text','&nbsp;',0,''),(46425,14705,'120255','printshop-mobile','border-bottom-width','1',0,''),(46426,14705,'120255','printshop-mobile','border-bottom-color','#000000',0,''),(46427,14706,'120256','printshop-mobile','text','&nbsp;',0,''),(46428,14706,'120256','printshop-mobile','border-bottom-width','1',0,''),(46429,14706,'120256','printshop-mobile','border-bottom-color','#000000',0,''),(46430,14706,'120256','printshop-mobile','padding-top','5',0,''),(46431,14707,'120257','printshop-mobile','text','&nbsp;',0,''),(46432,14707,'120257','printshop-mobile','border-bottom-width','1',0,''),(46433,14707,'120257','printshop-mobile','border-bottom-color','#000000',0,''),(46434,14707,'120257','printshop-mobile','padding-top','5',0,''),(46435,14708,'120258','printshop-mobile','text','&nbsp;',0,''),(46436,14708,'120258','printshop-mobile','border-bottom-width','1',0,''),(46437,14708,'120258','printshop-mobile','border-bottom-color','#000000',0,''),(46438,14708,'120258','printshop-mobile','padding-top','5',0,''),(46439,14709,'120259','printshop-mobile','block_type','1',0,''),(46440,14709,'120259','printshop-mobile','padding-top','10',0,''),(46441,14709,'120259','printshop-mobile','padding-left','40',0,''),(46442,14709,'120259','printshop-mobile','padding-right','40',0,''),(46443,14709,'120259','printshop-mobile','padding-bottom','10',0,''),(46444,14710,'120260','printshop-mobile','block_type','1',0,''),(46445,14710,'120260','printshop-mobile','padding-top','10',0,''),(46446,14710,'120260','printshop-mobile','padding-left','10',0,''),(46447,14710,'120260','printshop-mobile','padding-right','10',0,''),(46448,14710,'120260','printshop-mobile','padding-bottom','10',0,''),(46449,14710,'120260','printshop-mobile','border-top-width','1',0,''),(46450,14710,'120260','printshop-mobile','border-left-width','1',0,''),(46451,14710,'120260','printshop-mobile','border-right-width','1',0,''),(46452,14710,'120260','printshop-mobile','border-bottom-width','1',0,''),(46453,14710,'120260','printshop-mobile','border-top-color','#000000',0,''),(46454,14710,'120260','printshop-mobile','border-left-color','#000000',0,''),(46455,14710,'120260','printshop-mobile','border-right-color','#000000',0,''),(46456,14710,'120260','printshop-mobile','border-bottom-color','#000000',0,''),(46457,14711,'120261','printshop-mobile','block_type','3',0,''),(46458,14712,'120262','printshop-mobile','data','rrDelivery_name',0,''),(46459,14712,'120262','printshop-mobile','font-size','9',0,''),(46460,14713,'120263','printshop-mobile','block_type','2',0,''),(46461,14714,'120264','printshop-mobile','text','RMA#:',0,''),(46462,14714,'120264','printshop-mobile','font-size','10',0,''),(46463,14715,'120265','printshop-mobile','data','rrNumber',0,''),(46464,14715,'120265','printshop-mobile','font-size','9',0,''),(46465,14716,'120266','printshop-mobile','block_type','5',0,''),(46466,14717,'120267','printshop-mobile','font-size','9',0,''),(46467,14718,'120268','printshop-mobile','block_type','1',0,''),(46468,14720,'120270','printshop-mobile','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(46469,14720,'120270','printshop-mobile','font-size','12',0,''),(46470,14720,'120270','printshop-mobile','font-style','italic',0,''),(46471,14720,'120270','printshop-mobile','padding-bottom','20',0,''),(46472,14721,'120271','printshop-mobile','block_type','11',0,''),(46473,14721,'120271','printshop-mobile','border-top-width','1',0,''),(46474,14721,'120271','printshop-mobile','border-left-width','1',0,''),(46475,14721,'120271','printshop-mobile','border-right-width','1',0,''),(46476,14721,'120271','printshop-mobile','border-bottom-width','1',0,''),(46477,14721,'120271','printshop-mobile','border-top-color','#000000',0,''),(46478,14721,'120271','printshop-mobile','border-left-color','#000000',0,''),(46479,14721,'120271','printshop-mobile','border-right-color','#000000',0,''),(46480,14721,'120271','printshop-mobile','border-bottom-color','#000000',0,''),(46481,14722,'120272','printshop-mobile','block_type','1',0,''),(46482,14722,'120272','printshop-mobile','border-right-width','1',0,''),(46483,14722,'120272','printshop-mobile','border-right-color','#000000',0,''),(46484,14722,'120272','printshop-mobile','padding-top','10',0,''),(46485,14722,'120272','printshop-mobile','padding-right','10',0,''),(46486,14722,'120272','printshop-mobile','padding-bottom','10',0,''),(46487,14723,'120273','printshop-mobile','block_type','1',0,''),(46488,14723,'120273','printshop-mobile','padding-left','15',0,''),(46489,14724,'120274','printshop-mobile','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(46490,14724,'120274','printshop-mobile','font-size','11',0,''),(46491,14724,'120274','printshop-mobile','font-style','italic',0,''),(46492,14724,'120274','printshop-mobile','padding-bottom','5',0,''),(46493,14725,'120275','printshop-mobile','text','Replacement Policy:',0,''),(46494,14725,'120275','printshop-mobile','font-size','14',0,''),(46495,14725,'120275','printshop-mobile','padding-bottom','5',0,''),(46496,14725,'120275','printshop-mobile','font-weight','bold',0,''),(46497,14726,'120276','printshop-mobile','block_type','9',0,''),(46498,14727,'120277','printshop-mobile','text','2.',0,''),(46499,14727,'120277','printshop-mobile','font-size','12',0,''),(46500,14727,'120277','printshop-mobile','text-align','right',0,''),(46501,14727,'120277','printshop-mobile','margin-right','5',0,''),(46502,14728,'120278','printshop-mobile','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(46503,14728,'120278','printshop-mobile','font-size','12',0,''),(46504,14728,'120278','printshop-mobile','padding-bottom','5',0,''),(46505,14729,'120279','printshop-mobile','block_type','9',0,''),(46506,14730,'120280','printshop-mobile','text','1.',0,''),(46507,14730,'120280','printshop-mobile','font-size','12',0,''),(46508,14730,'120280','printshop-mobile','text-align','right',0,''),(46509,14730,'120280','printshop-mobile','padding-right','5',0,''),(46510,14731,'120281','printshop-mobile','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(46511,14731,'120281','printshop-mobile','font-size','12',0,''),(46512,14731,'120281','printshop-mobile','padding-bottom','5',0,''),(46513,14732,'120282','printshop-mobile','block_type','9',0,''),(46514,14733,'120283','printshop-mobile','text','3.',0,''),(46515,14733,'120283','printshop-mobile','font-size','12',0,''),(46516,14733,'120283','printshop-mobile','text-align','right',0,''),(46517,14733,'120283','printshop-mobile','margin-right','5',0,''),(46518,14734,'120284','printshop-mobile','text','Return the authorized item(s) per shipping instructions.',0,''),(46519,14734,'120284','printshop-mobile','font-size','12',0,''),(46520,14734,'120284','printshop-mobile','padding-bottom','5',0,''),(46521,14735,'120285','printshop-mobile','block_type','9',0,''),(46522,14736,'120286','printshop-mobile','text','4.',0,''),(46523,14736,'120286','printshop-mobile','font-size','12',0,''),(46524,14736,'120286','printshop-mobile','text-align','right',0,''),(46525,14736,'120286','printshop-mobile','margin-right','5',0,''),(46526,14737,'120287','printshop-mobile','text','Our Replacement Department will process your request.',0,''),(46527,14737,'120287','printshop-mobile','font-size','12',0,''),(46528,14737,'120287','printshop-mobile','padding-bottom','5',0,''),(46529,14738,'120288','printshop-mobile','block_type','2',0,''),(46530,14738,'120288','printshop-mobile','padding-left','10',0,''),(46531,14738,'120288','printshop-mobile','padding-top','20',0,''),(46532,14738,'120288','printshop-mobile','padding-right','10',0,''),(46533,14739,'120289','printshop-mobile','block_type','5',0,''),(46534,14740,'120290','printshop-mobile','text','RMA No:',0,''),(46535,14740,'120290','printshop-mobile','font-size','12',0,''),(46536,14740,'120290','printshop-mobile','font-weight','bold',0,''),(46537,14741,'120291','printshop-mobile','data','rrNumber',0,''),(46538,14741,'120291','printshop-mobile','font-size','12',0,''),(46539,14741,'120291','printshop-mobile','font-weight','bold',0,''),(46540,14742,'120292','printshop-mobile','block_type','2',0,''),(46541,14743,'120293','printshop-mobile','text','Date Issued:',0,''),(46542,14743,'120293','printshop-mobile','font-size','12',0,''),(46543,14743,'120293','printshop-mobile','font-weight','bold',0,''),(46544,14744,'120294','printshop-mobile','data','rrDateCreate',0,''),(46545,14744,'120294','printshop-mobile','font-size','12',0,''),(46546,14744,'120294','printshop-mobile','font-weight','bold',0,''),(46547,14745,'120295','printshop-mobile','block_type','1',0,''),(46548,14745,'120295','printshop-mobile','padding-top','10',0,''),(46549,14745,'120295','printshop-mobile','padding-left','10',0,''),(46550,14745,'120295','printshop-mobile','padding-right','10',0,''),(46551,14745,'120295','printshop-mobile','padding-bottom','10',0,''),(46552,14746,'120296','printshop-mobile','block_type','2',0,''),(46553,14747,'120297','printshop-mobile','block_type','11',0,''),(46554,14748,'120298','printshop-mobile','text','Company:',0,''),(46555,14748,'120298','printshop-mobile','font-size','12',0,''),(46556,14749,'120299','printshop-mobile','data','rrDelivery_company',0,''),(46557,14749,'120299','printshop-mobile','font-size','12',0,''),(46558,14750,'120300','printshop-mobile','block_type','2',0,''),(46559,14751,'120301','printshop-mobile','text','Contact Name:',0,''),(46560,14751,'120301','printshop-mobile','font-size','12',0,''),(46561,14752,'120302','printshop-mobile','data','rrDelivery_name',0,''),(46562,14752,'120302','printshop-mobile','font-size','12',0,''),(46563,14753,'120303','printshop-mobile','block_type','9',0,''),(46564,14753,'120303','printshop-mobile','padding-top','5',0,''),(46565,14754,'120304','printshop-mobile','text','Address:',0,''),(46566,14754,'120304','printshop-mobile','font-size','12',0,''),(46567,14755,'120305','printshop-mobile','data','rrDelivery_street_address',0,''),(46568,14755,'120305','printshop-mobile','font-size','12',0,''),(46569,14756,'120306','printshop-mobile','block_type','2',0,''),(46570,14756,'120306','printshop-mobile','padding-top','5',0,''),(46571,14757,'120307','printshop-mobile','block_type','11',0,''),(46572,14758,'120308','printshop-mobile','text','City:',0,''),(46573,14758,'120308','printshop-mobile','font-size','12',0,''),(46574,14759,'120309','printshop-mobile','data','rrDelivery_city',0,''),(46575,14759,'120309','printshop-mobile','font-size','12',0,''),(46576,14760,'120310','printshop-mobile','block_type','11',0,''),(46577,14761,'120311','printshop-mobile','text','State:',0,''),(46578,14761,'120311','printshop-mobile','font-size','12',0,''),(46579,14762,'120312','printshop-mobile','data','rrDelivery_state',0,''),(46580,14762,'120312','printshop-mobile','font-size','12',0,''),(46581,14763,'120313','printshop-mobile','block_type','2',0,''),(46582,14763,'120313','printshop-mobile','padding-top','5',0,''),(46583,14764,'120314','printshop-mobile','block_type','11',0,''),(46584,14765,'120315','printshop-mobile','text','Country:',0,''),(46585,14765,'120315','printshop-mobile','font-size','12',0,''),(46586,14766,'120316','printshop-mobile','data','rrDelivery_country',0,''),(46587,14766,'120316','printshop-mobile','font-size','12',0,''),(46588,14767,'120317','printshop-mobile','block_type','11',0,''),(46589,14768,'120318','printshop-mobile','text','Postcode:',0,''),(46590,14768,'120318','printshop-mobile','font-size','12',0,''),(46591,14769,'120319','printshop-mobile','data','rrDelivery_postcode',0,''),(46592,14769,'120319','printshop-mobile','font-size','12',0,''),(46593,14770,'120320','printshop-mobile','block_type','2',0,''),(46594,14770,'120320','printshop-mobile','padding-top','5',0,''),(46595,14771,'120321','printshop-mobile','block_type','11',0,''),(46596,14772,'120322','printshop-mobile','text','Email:',0,''),(46597,14772,'120322','printshop-mobile','font-size','12',0,''),(46598,14773,'120323','printshop-mobile','data','rrDelivery_email_address',0,''),(46599,14773,'120323','printshop-mobile','font-size','12',0,''),(46600,14774,'120324','printshop-mobile','block_type','11',0,''),(46601,14775,'120325','printshop-mobile','text','Phone:',0,''),(46602,14775,'120325','printshop-mobile','font-size','12',0,''),(46603,14776,'120326','printshop-mobile','data','rrDelivery_telephone',0,''),(46604,14776,'120326','printshop-mobile','font-size','12',0,''),(46605,14777,'120327','printshop-mobile','block_type','1',0,''),(46606,14777,'120327','printshop-mobile','border-bottom-width','1',0,''),(46607,14777,'120327','printshop-mobile','border-bottom-color','#000000',0,''),(46608,14778,'120328','printshop-mobile','text-align','center',0,''),(46609,14778,'120328','printshop-mobile','logo','themes/printshop-mobile/img/Furntech-1.jpg',1,''),(46610,14778,'120328','printshop-mobile','padding-top','10',0,''),(46611,14778,'120328','printshop-mobile','padding-bottom','10',0,''),(46612,14779,'120329','printshop-mobile','text','Return Material Authorization (RMA) Form',0,''),(46613,14779,'120329','printshop-mobile','text-align','center',0,''),(46614,14779,'120329','printshop-mobile','font-size','12',0,''),(46615,14779,'120329','printshop-mobile','font-weight','bold',0,''),(46616,14779,'120329','printshop-mobile','font-family','Arial',0,''),(46617,14780,'120330','printshop-mobile','block_type','1',0,''),(46618,14780,'120330','printshop-mobile','style_class','item-holder',0,''),(46619,14780,'120330','printshop-mobile','padding-top','25',0,''),(46620,14780,'120330','printshop-mobile','padding-bottom','25',0,''),(46621,14780,'120330','printshop-mobile','text-align','left',0,''),(46622,14780,'120330','printshop-mobile','border-top-width','1',0,''),(46623,14780,'120330','printshop-mobile','border-top-color','#e0e0e0',0,''),(46624,14781,'120331','printshop-mobile','block_type','7',0,''),(46625,14781,'120331','printshop-mobile','schema','7-2',0,''),(46626,14782,'120332','printshop-mobile','block_type','5',0,''),(46627,14782,'120332','printshop-mobile','schema','5-2',0,''),(46628,14783,'120333','printshop-mobile','block_type','1',0,''),(46629,14784,'120334','printshop-mobile','text-align','right',0,''),(46630,14784,'120334','printshop-mobile','margin-top','4',0,''),(46631,14784,'120334','printshop-mobile','margin-bottom','7',0,''),(46632,14784,'120334','printshop-mobile','float','left',0,''),(46633,14785,'120335','printshop-mobile','padding-top','6',0,''),(46634,14785,'120335','printshop-mobile','padding-left','5',0,''),(46635,14785,'120335','printshop-mobile','float','left',0,''),(46636,14785,'120335','printshop-mobile','clear','none',0,''),(46637,14786,'120336','printshop-mobile','clear','none',0,''),(46638,14786,'120336','printshop-mobile','padding-right','20',0,''),(46639,14787,'120337','printshop-mobile','padding-right','20',0,''),(46640,14787,'120337','printshop-mobile','max-width','300',0,''),(46641,14787,'120337','printshop-mobile','margin_left_measure','auto',0,''),(46642,14787,'120337','printshop-mobile','margin_right_measure','auto',0,''),(46643,14788,'120338','printshop-mobile','clear','none',0,''),(46644,14789,'120339','printshop-mobile','padding-right','20',0,''),(46645,14790,'120340','printshop-mobile','description_characters','200',0,''),(46646,14790,'120340','printshop-mobile','clear','none',0,''),(46647,14790,'120340','printshop-mobile','padding-right','20',0,''),(46648,14791,'120341','printshop-mobile','margin-bottom','20',0,''),(46649,14792,'120342','printshop-mobile','block_type','1',0,''),(46650,14792,'120342','printshop-mobile','padding-left','40',0,''),(46651,14792,'120342','printshop-mobile','style_class','right-aria',0,''),(46653,14793,'120343','printshop-mobile','text-align','right',0,''),(46654,14793,'120343','printshop-mobile','margin-bottom','10',0,''),(46655,14794,'120344','printshop-mobile','margin-bottom','10',0,''),(46656,14794,'120344','printshop-mobile','text-align','right',0,''),(46657,14796,'120346','printshop-mobile','margin-bottom','15',0,''),(46658,14796,'120346','printshop-mobile','text-align','right',0,''),(46659,14797,'120347','printshop-mobile','margin-bottom','10',0,''),(46660,14798,'120348','printshop-mobile','text-align','right',0,''),(46661,14798,'120348','printshop-mobile','margin-bottom','15',0,''),(46662,14799,'120349','printshop-mobile','block_type','1',0,''),(46663,14800,'120350','printshop-mobile','padding-bottom','20',0,''),(46664,14801,'120351','printshop-mobile','text-align','right',0,''),(46665,14801,'120351','printshop-mobile','margin-bottom','40',0,''),(46666,14802,'120352','printshop-mobile','text','<h1>Samples</h1>',1,''),(46667,14803,'120353','printshop-mobile','block_type','1',0,''),(46668,14804,'120354','printshop-mobile','block_type','6',0,''),(46669,14804,'120354','printshop-mobile','schema','6-3',0,''),(46670,14804,'120354','printshop-mobile','schema','6-3',0,'702'),(46671,14805,'120355','printshop-mobile','aria_name','account-menu',0,''),(46672,14806,'120356','printshop-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(46673,14807,'120357','printshop-mobile','show_pagenation','1',0,''),(46674,14807,'120357','printshop-mobile','link','Sample Info',0,''),(46675,14807,'120357','printshop-mobile','margin-bottom','20',0,''),(46676,14808,'120358','printshop-mobile','block_type','1',0,''),(46677,14809,'120359','printshop-mobile','block_type','6',0,''),(46678,14810,'120360','printshop-mobile','aria_name','account-menu',0,''),(46679,14811,'120361','printshop-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(46680,14812,'120362','printshop-mobile','block_type','3',0,''),(46681,14813,'120363','printshop-mobile','block_type','1',0,''),(46682,14813,'120363','printshop-mobile','padding-right','20',0,''),(46683,14813,'120363','printshop-mobile','padding-bottom','20',0,''),(46684,14814,'120364','printshop-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(46685,14815,'120365','printshop-mobile','orders_data','telephone',0,''),(46686,14816,'120366','printshop-mobile','block_type','1',0,''),(46687,14816,'120366','printshop-mobile','padding-right','20',0,''),(46688,14816,'120366','printshop-mobile','padding-bottom','20',0,''),(46689,14817,'120367','printshop-mobile','orders_data','name',0,''),(46690,14818,'120368','printshop-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(46691,14819,'120369','printshop-mobile','block_type','1',0,''),(46692,14819,'120369','printshop-mobile','padding-right','20',0,''),(46693,14819,'120369','printshop-mobile','padding-bottom','20',0,''),(46694,14820,'120370','printshop-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(46695,14821,'120371','printshop-mobile','orders_data','delivery_address',0,''),(46696,14822,'120372','printshop-mobile','block_type','1',0,''),(46697,14822,'120372','printshop-mobile','padding-right','20',0,''),(46698,14823,'120373','printshop-mobile','orders_data','shipping_method',0,''),(46699,14824,'120374','printshop-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(46700,14825,'120375','printshop-mobile','block_type','1',0,''),(46701,14825,'120375','printshop-mobile','padding-bottom','20',0,''),(46702,14826,'120376','printshop-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(46703,14827,'120377','printshop-mobile','orders_data','billing_address',0,''),(46704,14828,'120378','printshop-mobile','block_type','1',0,''),(46705,14829,'120379','printshop-mobile','orders_data','payment_method',0,''),(46706,14830,'120380','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(46707,14831,'120381','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(46708,14834,'120384','printshop-mobile','block_type','2',0,''),(46709,14834,'120384','printshop-mobile','padding-top','20',0,''),(46710,14834,'120384','printshop-mobile','margin-bottom','20',0,''),(46711,14835,'120385','printshop-mobile','like_button','1',0,''),(46712,14835,'120385','printshop-mobile','text','IMAGE_BUTTON_BACK',0,''),(46713,14835,'120385','printshop-mobile','link','Samples',0,''),(46714,14837,'120387','printshop-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(46715,14838,'120388','printshop-mobile','block_type','1',0,''),(46716,14839,'120389','printshop-mobile','block_type','6',0,''),(46717,14839,'120389','printshop-mobile','schema','6-3',0,''),(46718,14839,'120389','printshop-mobile','schema','6-3',0,'702'),(46719,14840,'120390','printshop-mobile','aria_name','account-menu',0,''),(46720,14841,'120391','printshop-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(46721,14842,'120392','printshop-mobile','link','Order History Info',0,''),(46722,14842,'120392','printshop-mobile','text','TEXT_VIEW',0,''),(46723,14842,'120392','printshop-mobile','max_orders','3',0,''),(46724,14842,'120392','printshop-mobile','link_pay','Order pay',0,''),(46725,14842,'120392','printshop-mobile','margin-bottom','30',0,''),(46726,14842,'120392','printshop-mobile','text_pay','ORDER_PAY',0,''),(46727,14843,'120393','printshop-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(46728,14844,'120394','printshop-mobile','block_type','15',0,''),(46729,14844,'120394','printshop-mobile','margin-bottom','30',0,''),(46730,14844,'120394','printshop-mobile','padding-top','20',0,''),(46731,14844,'120394','printshop-mobile','padding-left','20',0,''),(46732,14844,'120394','printshop-mobile','padding-right','20',0,''),(46733,14844,'120394','printshop-mobile','padding-bottom','20',0,''),(46734,14844,'120394','printshop-mobile','border-top-width','1',0,''),(46735,14844,'120394','printshop-mobile','border-top-color','#e0e0e0',0,''),(46736,14844,'120394','printshop-mobile','border-left-width','1',0,''),(46737,14844,'120394','printshop-mobile','border-right-width','1',0,''),(46738,14844,'120394','printshop-mobile','border-bottom-width','1',0,''),(46739,14844,'120394','printshop-mobile','border-left-color','#e0e0e0',0,''),(46740,14844,'120394','printshop-mobile','border-right-color','#e0e0e0',0,''),(46741,14844,'120394','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(46742,14844,'120394','printshop-mobile','schema','15-2',0,'702'),(46743,14845,'120395','printshop-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(46744,14845,'120395','printshop-mobile','font-family','trueloaded',0,'3'),(46745,14845,'120395','printshop-mobile','content','\\e920',0,'3'),(46746,14845,'120395','printshop-mobile','color','#ee4225',0,'3'),(46747,14845,'120395','printshop-mobile','font-size','30',0,'3'),(46748,14845,'120395','printshop-mobile','text-align','center',0,'3'),(46749,14845,'120395','printshop-mobile','margin-bottom','10',0,'3'),(46750,14845,'120395','printshop-mobile','text-align','center',0,''),(46751,14845,'120395','printshop-mobile','font-size','16',0,''),(46752,14845,'120395','printshop-mobile','text-transform','uppercase',0,''),(46753,14845,'120395','printshop-mobile','line-height','1',0,'3'),(46755,14846,'120396','printshop-mobile','font-family','Varela Round',0,''),(46756,14846,'120396','printshop-mobile','color','#ee4225',0,''),(46757,14846,'120396','printshop-mobile','font-size','14',0,''),(46758,14846,'120396','printshop-mobile','text-align','center',0,''),(46759,14847,'120397','printshop-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(46760,14847,'120397','printshop-mobile','font-family','trueloaded',0,'3'),(46761,14847,'120397','printshop-mobile','content','\\e928',0,'3'),(46762,14847,'120397','printshop-mobile','color','#ee4225',0,'3'),(46763,14847,'120397','printshop-mobile','font-size','30',0,'3'),(46764,14847,'120397','printshop-mobile','text-align','center',0,'3'),(46765,14847,'120397','printshop-mobile','text-align','center',0,''),(46766,14847,'120397','printshop-mobile','font-size','16',0,''),(46767,14847,'120397','printshop-mobile','text-transform','uppercase',0,''),(46768,14847,'120397','printshop-mobile','line-height','1',0,'3'),(46770,14848,'120398','printshop-mobile','link','download_orders',0,''),(46771,14848,'120398','printshop-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(46772,14848,'120398','printshop-mobile','hide_link','orders',0,''),(46773,14848,'120398','printshop-mobile','text-align','center',0,''),(46774,14848,'120398','printshop-mobile','popup','2',0,''),(46775,14848,'120398','printshop-mobile','font-size','14',0,''),(46776,14849,'120399','printshop-mobile','font-family','Varela Round',0,''),(46777,14849,'120399','printshop-mobile','color','#ee4225',0,''),(46778,14849,'120399','printshop-mobile','font-size','14',0,''),(46779,14849,'120399','printshop-mobile','text-align','center',0,''),(46780,14850,'120400','printshop-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(46781,14850,'120400','printshop-mobile','font-family','trueloaded',0,'3'),(46782,14850,'120400','printshop-mobile','content','\\e922',0,'3'),(46783,14850,'120400','printshop-mobile','color','#ee4225',0,'3'),(46784,14850,'120400','printshop-mobile','font-size','30',0,'3'),(46785,14850,'120400','printshop-mobile','line-height','1',0,'3'),(46786,14850,'120400','printshop-mobile','font-size','16',0,''),(46787,14850,'120400','printshop-mobile','text-align','center',0,''),(46788,14850,'120400','printshop-mobile','text-transform','uppercase',0,''),(46790,14851,'120401','printshop-mobile','font-family','Varela Round',0,''),(46791,14851,'120401','printshop-mobile','color','#ee4225',0,''),(46792,14851,'120401','printshop-mobile','line-height','1',0,''),(46793,14851,'120401','printshop-mobile','text-align','center',0,''),(46794,14851,'120401','printshop-mobile','font-size','14',0,''),(46795,14852,'120402','printshop-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(46796,14852,'120402','printshop-mobile','content','\\e994',0,'3'),(46797,14852,'120402','printshop-mobile','font-family','trueloaded',0,'3'),(46798,14852,'120402','printshop-mobile','color','#ee4225',0,'3'),(46799,14852,'120402','printshop-mobile','font-size','30',0,'3'),(46800,14852,'120402','printshop-mobile','line-height','1',0,'3'),(46801,14852,'120402','printshop-mobile','font-size','16',0,''),(46802,14852,'120402','printshop-mobile','text-align','center',0,''),(46803,14852,'120402','printshop-mobile','text-transform','uppercase',0,''),(46805,14853,'120403','printshop-mobile','link','Gift Certificate',0,''),(46806,14853,'120403','printshop-mobile','text','GIFT_CERTIFICATE',0,''),(46807,14853,'120403','printshop-mobile','popup','1',0,''),(46808,14853,'120403','printshop-mobile','text-align','center',0,''),(46809,14853,'120403','printshop-mobile','font-size','14',0,''),(46810,14854,'120404','printshop-mobile','font-family','Varela Round',0,''),(46811,14854,'120404','printshop-mobile','color','#ee4225',0,''),(46812,14854,'120404','printshop-mobile','font-size','14',0,''),(46813,14854,'120404','printshop-mobile','text-align','center',0,''),(46814,14855,'120405','printshop-mobile','text','TEXT_VIEW_HISTORY',0,''),(46815,14855,'120405','printshop-mobile','popup','1',0,''),(46816,14855,'120405','printshop-mobile','text-align','center',0,''),(46817,14855,'120405','printshop-mobile','link','Points Earnt History',0,''),(46818,14855,'120405','printshop-mobile','font-size','14',0,''),(46819,14856,'120406','printshop-mobile','font-family','Varela Round',0,''),(46820,14856,'120406','printshop-mobile','color','#ee4225',0,''),(46821,14856,'120406','printshop-mobile','font-size','14',0,''),(46822,14856,'120406','printshop-mobile','text-align','center',0,''),(46823,14857,'120407','printshop-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(46824,14857,'120407','printshop-mobile','content','\\e990',0,'3'),(46825,14857,'120407','printshop-mobile','font-family','trueloaded',0,'3'),(46826,14857,'120407','printshop-mobile','font-size','30',0,'3'),(46827,14857,'120407','printshop-mobile','text-align','center',0,'3'),(46828,14857,'120407','printshop-mobile','line-height','1',0,'3'),(46829,14857,'120407','printshop-mobile','color','#ee4225',0,'3'),(46830,14857,'120407','printshop-mobile','font-size','16',0,''),(46831,14857,'120407','printshop-mobile','text-align','center',0,''),(46832,14857,'120407','printshop-mobile','text-transform','uppercase',0,''),(46834,14858,'120408','printshop-mobile','block_type','1',0,''),(46835,14859,'120409','printshop-mobile','hide_parents','2',0,''),(46836,14860,'120410','printshop-mobile','text','<div class=\"heading-3\">##TEXT_GIFT_CARDS##</div>',0,''),(46837,14862,'120412','printshop-mobile','block_type','1',0,''),(46838,14863,'120413','printshop-mobile','block_type','6',0,''),(46839,14864,'120414','printshop-mobile','class','menu-simple',0,''),(46840,14866,'120416','printshop-mobile','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(46841,14868,'120418','printshop-mobile','text','<div class=\"heading-4\">Categories</div>',0,''),(46842,14869,'120419','printshop-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(46843,14870,'120420','printshop-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(46844,14872,'120422','printshop-mobile','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(46845,14873,'120423','printshop-mobile','block_type','1',0,''),(46846,14874,'120424','printshop-mobile','style_class','middle-form',0,''),(46847,14874,'120424','printshop-mobile','margin-bottom','30',0,''),(46848,14875,'120425','printshop-mobile','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(46849,14876,'120426','printshop-mobile','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(46850,14876,'120426','printshop-mobile','style_class','middle-form',0,''),(46851,14877,'120427','printshop-mobile','style_class','middle-form',0,''),(46852,14878,'120428','printshop-mobile','block_type','1',0,''),(46853,14879,'120429','printshop-mobile','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(46854,14879,'120429','printshop-mobile','padding-top','100',0,''),(46855,14879,'120429','printshop-mobile','margin-bottom','100',0,''),(46856,14879,'120429','printshop-mobile','text-align','center',0,''),(46857,14879,'120429','printshop-mobile','font-size','20',0,''),(46858,14880,'120430','printshop-mobile','block_type','1',0,''),(46859,14881,'120431','printshop-mobile','block_type','6',0,''),(46860,14881,'120431','printshop-mobile','schema','6-3',0,''),(46861,14881,'120431','printshop-mobile','schema','6-3',0,'702'),(46862,14882,'120432','printshop-mobile','aria_name','account-menu',0,''),(46863,14883,'120433','printshop-mobile','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(46864,14884,'120434','printshop-mobile','text','##SUBSCRIPTION_TEXT##',0,''),(46865,14886,'120436','printshop-mobile','block_type','1',0,''),(46866,14887,'120437','printshop-mobile','block_type','1',0,''),(46867,14887,'120437','printshop-mobile','font-weight','normal',0,''),(46868,14888,'120438','printshop-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',1,''),(46869,14888,'120438','printshop-mobile','font-weight','400',0,''),(46870,14889,'120439','printshop-mobile','block_type','3',0,''),(46871,14889,'120439','printshop-mobile','font-weight','400',0,''),(46872,14889,'120439','printshop-mobile','schema','3-4',0,'694'),(46873,14890,'120440','printshop-mobile','text','&nbsp;',0,''),(46874,14890,'120440','printshop-mobile','font-weight','normal',0,''),(46875,14891,'120441','printshop-mobile','font-weight','normal',0,''),(46876,14891,'120441','printshop-mobile','box_align','2',0,''),(46877,14891,'120441','printshop-mobile','padding-top','40',0,''),(46878,14892,'120442','printshop-mobile','font-weight','400',0,''),(46879,14892,'120442','printshop-mobile','text-align','right',0,''),(46880,14892,'120442','printshop-mobile','padding-top','40',0,''),(46881,14892,'120442','printshop-mobile','padding-bottom','100',0,''),(46882,14892,'120442','printshop-mobile','text-align','center',0,'694'),(46883,14892,'120442','printshop-mobile','float','none',0,'694'),(46884,14893,'120443','printshop-mobile','block_type','1',0,''),(46885,14894,'120444','printshop-mobile','block_type','1',0,''),(46886,14894,'120444','printshop-mobile','font-weight','normal',0,''),(46887,14895,'120445','printshop-mobile','block_type','1',0,''),(46888,14895,'120445','printshop-mobile','text-align','center',0,''),(46889,14895,'120445','printshop-mobile','padding-top','30',0,''),(46890,14895,'120445','printshop-mobile','margin-bottom','200',0,''),(46891,14896,'120446','printshop-mobile','display','inline-block',0,''),(46892,14897,'120447','printshop-mobile','display','inline-block',0,''),(46893,14897,'120447','printshop-mobile','clear','none',0,''),(46894,14897,'120447','printshop-mobile','margin-left','20',0,''),(46895,14898,'120448','printshop-mobile','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(46897,14902,'120452','printshop-mobile','width','680',0,''),(46898,14902,'120452','printshop-mobile','font-weight','normal',0,''),(46899,14902,'120452','printshop-mobile','font-size','12',0,''),(46900,14902,'120452','printshop-mobile','padding-top','20',0,''),(46901,14902,'120452','printshop-mobile','padding-bottom','20',0,''),(46902,14902,'120452','printshop-mobile','color','#424242',0,''),(46903,14903,'120453','printshop-mobile','block_type','2',0,''),(46904,14903,'120453','printshop-mobile','font-weight','normal',0,''),(46905,14903,'120453','printshop-mobile','padding-bottom','20',0,''),(46906,14904,'120454','printshop-mobile','block_type','1',0,''),(46907,14905,'120455','printshop-mobile','font-weight','normal',0,''),(46908,14905,'120455','printshop-mobile','text-align','right',0,''),(46909,14905,'120455','printshop-mobile','padding-bottom','10',0,''),(46910,14905,'120455','printshop-mobile','address_spacer',',',0,''),(46911,14905,'120455','printshop-mobile','font-size','12',0,''),(46912,14906,'120456','printshop-mobile','block_type','11',0,''),(46913,14906,'120456','printshop-mobile','font-weight','normal',0,''),(46914,14907,'120457','printshop-mobile','text','<p>Phone:</p>',1,''),(46915,14907,'120457','printshop-mobile','font-weight','normal',0,''),(46916,14907,'120457','printshop-mobile','text-align','right',0,''),(46917,14908,'120458','printshop-mobile','font-weight','normal',0,''),(46918,14908,'120458','printshop-mobile','text-align','right',0,''),(46919,14909,'120459','printshop-mobile','block_type','11',0,''),(46920,14909,'120459','printshop-mobile','font-weight','normal',0,''),(46921,14910,'120460','printshop-mobile','text','<p>Web:</p>',1,''),(46922,14910,'120460','printshop-mobile','font-weight','normal',0,''),(46923,14910,'120460','printshop-mobile','text-align','right',0,''),(46924,14911,'120461','printshop-mobile','font-weight','normal',0,''),(46925,14911,'120461','printshop-mobile','text-align','right',0,''),(46926,14912,'120462','printshop-mobile','block_type','11',0,''),(46927,14912,'120462','printshop-mobile','font-weight','normal',0,''),(46928,14913,'120463','printshop-mobile','text','<p>Email:</p>',1,''),(46929,14913,'120463','printshop-mobile','font-weight','normal',0,''),(46930,14913,'120463','printshop-mobile','text-align','right',0,''),(46931,14914,'120464','printshop-mobile','font-weight','normal',0,''),(46932,14914,'120464','printshop-mobile','text-align','right',0,''),(46933,14915,'120465','printshop-mobile','block_type','4',0,''),(46934,14915,'120465','printshop-mobile','font-weight','normal',0,''),(46935,14915,'120465','printshop-mobile','border-top-width','1',0,''),(46936,14915,'120465','printshop-mobile','border-top-color','#e0e0e0',0,''),(46937,14915,'120465','printshop-mobile','border-left-width','1',0,''),(46938,14915,'120465','printshop-mobile','border-left-color','#e0e0e0',0,''),(46939,14915,'120465','printshop-mobile','border-right-width','1',0,''),(46940,14915,'120465','printshop-mobile','border-right-color','#e0e0e0',0,''),(46941,14915,'120465','printshop-mobile','border-bottom-width','1',0,''),(46942,14915,'120465','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(46943,14916,'120466','printshop-mobile','block_type','2',0,''),(46944,14916,'120466','printshop-mobile','font-weight','normal',0,''),(46945,14916,'120466','printshop-mobile','border-right-width','1',0,''),(46946,14916,'120466','printshop-mobile','border-right-color','#e0e0e0',0,''),(46947,14917,'120467','printshop-mobile','block_type','1',0,''),(46948,14917,'120467','printshop-mobile','font-weight','400',0,''),(46949,14917,'120467','printshop-mobile','background-color','#eeeeee',0,''),(46950,14917,'120467','printshop-mobile','padding-top','10',0,''),(46951,14917,'120467','printshop-mobile','padding-left','10',0,''),(46952,14917,'120467','printshop-mobile','padding-right','10',0,''),(46953,14917,'120467','printshop-mobile','padding-bottom','30',0,''),(46954,14918,'120468','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(46955,14918,'120468','printshop-mobile','font-size','14',0,''),(46956,14918,'120468','printshop-mobile','font-weight','bold',0,''),(46957,14919,'120469','printshop-mobile','font-size','12',0,''),(46958,14920,'120470','printshop-mobile','block_type','1',0,''),(46959,14920,'120470','printshop-mobile','font-weight','normal',0,''),(46960,14920,'120470','printshop-mobile','padding-top','10',0,''),(46961,14920,'120470','printshop-mobile','padding-left','10',0,''),(46962,14920,'120470','printshop-mobile','padding-right','10',0,''),(46963,14920,'120470','printshop-mobile','padding-bottom','10',0,''),(46964,14921,'120471','printshop-mobile','text','<p>PHONE NUMBER:</p>',1,''),(46965,14921,'120471','printshop-mobile','font-size','14',0,''),(46966,14921,'120471','printshop-mobile','font-weight','bold',0,''),(46967,14921,'120471','printshop-mobile','padding-top','10',0,''),(46968,14922,'120472','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(46969,14922,'120472','printshop-mobile','font-weight','bold',0,''),(46970,14922,'120472','printshop-mobile','font-size','14',0,''),(46971,14922,'120472','printshop-mobile','padding-top','10',0,''),(46972,14923,'120473','printshop-mobile','text','<p>CUSTOMER:</p>',1,''),(46973,14923,'120473','printshop-mobile','font-size','13',0,''),(46974,14923,'120473','printshop-mobile','font-weight','bold',0,''),(46975,14924,'120474','printshop-mobile','font-weight','normal',0,''),(46976,14925,'120475','printshop-mobile','font-weight','normal',0,''),(46977,14927,'120477','printshop-mobile','block_type','2',0,''),(46978,14927,'120477','printshop-mobile','font-weight','normal',0,''),(46979,14927,'120477','printshop-mobile','border-top-width','1',0,''),(46980,14927,'120477','printshop-mobile','border-top-color','#e0e0e0',0,''),(46981,14927,'120477','printshop-mobile','border-right-width','1',0,''),(46982,14927,'120477','printshop-mobile','border-right-color','#e0e0e0',0,''),(46983,14928,'120478','printshop-mobile','block_type','1',0,''),(46984,14928,'120478','printshop-mobile','font-weight','normal',0,''),(46985,14928,'120478','printshop-mobile','padding-top','10',0,''),(46986,14928,'120478','printshop-mobile','padding-left','10',0,''),(46987,14928,'120478','printshop-mobile','padding-right','10',0,''),(46988,14928,'120478','printshop-mobile','padding-bottom','10',0,''),(46989,14928,'120478','printshop-mobile','border-right-width','1',0,''),(46990,14928,'120478','printshop-mobile','border-right-color','#e0e0e0',0,''),(46991,14929,'120479','printshop-mobile','text','<p>Shipping via</p>',1,''),(46992,14929,'120479','printshop-mobile','font-weight','bold',0,''),(46993,14929,'120479','printshop-mobile','font-size','14',0,''),(46994,14931,'120481','printshop-mobile','block_type','1',0,''),(46995,14931,'120481','printshop-mobile','font-weight','normal',0,''),(46996,14931,'120481','printshop-mobile','padding-top','10',0,''),(46997,14931,'120481','printshop-mobile','padding-left','10',0,''),(46998,14931,'120481','printshop-mobile','padding-right','10',0,''),(46999,14931,'120481','printshop-mobile','padding-bottom','10',0,''),(47000,14933,'120483','printshop-mobile','text','<p>Shipping service</p>',1,''),(47001,14933,'120483','printshop-mobile','font-weight','bold',0,''),(47002,14933,'120483','printshop-mobile','font-size','14',0,''),(47003,14934,'120484','printshop-mobile','text','<p>Payment date:</p>',1,''),(47004,14934,'120484','printshop-mobile','font-weight','bold',0,''),(47005,14934,'120484','printshop-mobile','text-align','center',0,''),(47006,14934,'120484','printshop-mobile','font-size','12',0,''),(47007,14935,'120485','printshop-mobile','font-weight','normal',0,''),(47008,14935,'120485','printshop-mobile','text-align','center',0,''),(47009,14936,'120486','printshop-mobile','text','<p>Payment Method:</p>',1,''),(47010,14936,'120486','printshop-mobile','font-weight','bold',0,''),(47011,14936,'120486','printshop-mobile','text-align','center',0,''),(47012,14937,'120487','printshop-mobile','font-size','14',0,''),(47013,14937,'120487','printshop-mobile','font-weight','bold',0,''),(47014,14937,'120487','printshop-mobile','text-align','center',0,''),(47015,14937,'120487','printshop-mobile','padding-bottom','10',0,''),(47016,14937,'120487','printshop-mobile','padding-top','10',0,''),(47017,14938,'120488','printshop-mobile','font-weight','normal',0,''),(47018,14938,'120488','printshop-mobile','text-align','center',0,''),(47019,14938,'120488','printshop-mobile','padding-bottom','10',0,''),(47020,14939,'120489','printshop-mobile','font-weight','normal',0,''),(47021,14939,'120489','printshop-mobile','text-align','center',0,''),(47022,14939,'120489','printshop-mobile','padding-bottom','20',0,''),(47023,14940,'120490','printshop-mobile','block_type','3',0,''),(47024,14940,'120490','printshop-mobile','font-weight','normal',0,''),(47025,14940,'120490','printshop-mobile','padding-top','20',0,''),(47026,14941,'120491','printshop-mobile','text','<p>If undelivered please return to:</p>',1,''),(47027,14941,'120491','printshop-mobile','font-size','12',0,''),(47028,14941,'120491','printshop-mobile','font-weight','bold',0,''),(47029,14942,'120492','printshop-mobile','font-size','12',0,''),(47030,14943,'120493','printshop-mobile','font-weight','400',0,''),(47031,14943,'120493','printshop-mobile','text-align','center',0,''),(47032,14943,'120493','printshop-mobile','padding-top','0',0,''),(47034,14943,'120493','printshop-mobile','padding-left','20',0,''),(47035,14943,'120493','printshop-mobile','padding-right','20',0,''),(47036,14944,'120494','printshop-mobile','text','<p>Thank you for your order</p>',1,''),(47037,14944,'120494','printshop-mobile','color','#1da1f2',0,''),(47038,14944,'120494','printshop-mobile','font-size','13',0,''),(47039,14944,'120494','printshop-mobile','font-weight','bold',0,''),(47040,14944,'120494','printshop-mobile','padding-top','5',0,''),(47041,14944,'120494','printshop-mobile','text-align','center',0,''),(47042,14945,'120495','printshop-mobile','block_type','6',0,''),(47043,14945,'120495','printshop-mobile','font-weight','normal',0,''),(47044,14945,'120495','printshop-mobile','font-size','16',0,''),(47045,14946,'120496','printshop-mobile','text','<p>Phone:</p>',1,''),(47046,14946,'120496','printshop-mobile','font-weight','normal',0,''),(47047,14946,'120496','printshop-mobile','text-align','right',0,''),(47048,14946,'120496','printshop-mobile','font-size','12',0,''),(47049,14947,'120497','printshop-mobile','font-weight','normal',0,''),(47050,14947,'120497','printshop-mobile','text-align','right',0,''),(47051,14947,'120497','printshop-mobile','font-size','12',0,''),(47052,14948,'120498','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(47053,14948,'120498','printshop-mobile','font-size','12',0,''),(47054,14948,'120498','printshop-mobile','font-weight','bold',0,''),(47055,14948,'120498','printshop-mobile','text-align','right',0,''),(47056,14949,'120499','printshop-mobile','block_type','6',0,''),(47057,14949,'120499','printshop-mobile','font-weight','normal',0,''),(47058,14949,'120499','printshop-mobile','font-size','16',0,''),(47059,14950,'120500','printshop-mobile','text','<p>Email:</p>',1,''),(47060,14950,'120500','printshop-mobile','font-weight','normal',0,''),(47061,14950,'120500','printshop-mobile','text-align','right',0,''),(47062,14950,'120500','printshop-mobile','font-size','12',0,''),(47063,14951,'120501','printshop-mobile','font-weight','normal',0,''),(47064,14951,'120501','printshop-mobile','text-align','right',0,''),(47065,14951,'120501','printshop-mobile','font-size','12',0,''),(47066,14952,'120502','printshop-mobile','font-weight','400',0,''),(47067,14952,'120502','printshop-mobile','padding-top','20',0,''),(47068,14952,'120502','printshop-mobile','padding-bottom','0',0,''),(47069,14952,'120502','printshop-mobile','font-size','12',0,''),(47070,14953,'120503','printshop-mobile','block_type','5',0,''),(47071,14953,'120503','printshop-mobile','font-weight','normal',0,''),(47072,14953,'120503','printshop-mobile','border-bottom-width','1',0,''),(47073,14953,'120503','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(47074,14953,'120503','printshop-mobile','border-top-width','1',0,''),(47075,14953,'120503','printshop-mobile','border-top-color','#e0e0e0',0,''),(47076,14953,'120503','printshop-mobile','border-left-color','#e0e0e0',0,''),(47077,14953,'120503','printshop-mobile','border-left-width','1',0,''),(47078,14954,'120504','printshop-mobile','block_type','1',0,''),(47079,14954,'120504','printshop-mobile','font-weight','normal',0,''),(47080,14954,'120504','printshop-mobile','padding-top','10',0,''),(47081,14954,'120504','printshop-mobile','padding-left','10',0,''),(47082,14954,'120504','printshop-mobile','padding-right','10',0,''),(47083,14955,'120505','printshop-mobile','font-weight','400',0,''),(47084,14955,'120505','printshop-mobile','line-height','120',0,''),(47085,14955,'120505','printshop-mobile','line_height_measure','%',0,''),(47086,14955,'120505','printshop-mobile','font-size','12',0,''),(47087,14956,'120506','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(47088,14956,'120506','printshop-mobile','font-size','14',0,''),(47089,14956,'120506','printshop-mobile','font-weight','bold',0,''),(47090,14956,'120506','printshop-mobile','padding-bottom','10',0,''),(47091,14957,'120507','printshop-mobile','block_type','1',0,''),(47092,14957,'120507','printshop-mobile','background-color','#eeeeee',0,''),(47093,14957,'120507','printshop-mobile','padding-top','20',0,''),(47094,14957,'120507','printshop-mobile','padding-left','10',0,''),(47095,14957,'120507','printshop-mobile','padding-right','10',0,''),(47096,14957,'120507','printshop-mobile','padding-bottom','20',0,''),(47097,14957,'120507','printshop-mobile','font-size','14',0,''),(47098,14958,'120508','printshop-mobile','font-weight','normal',0,''),(47099,14958,'120508','printshop-mobile','text-align','right',0,''),(47100,14958,'120508','printshop-mobile','font-size','14',0,''),(47101,14958,'120508','printshop-mobile','box_align','3',0,''),(47102,14959,'120509','printshop-mobile','block_type','1',0,''),(47103,14959,'120509','printshop-mobile','padding-top','35',0,''),(47104,14959,'120509','printshop-mobile','padding-bottom','35',0,''),(47105,14960,'120510','printshop-mobile','block_type','7',0,''),(47106,14960,'120510','printshop-mobile','schema','7-2',0,''),(47107,14961,'120511','printshop-mobile','block_type','1',0,''),(47108,14961,'120511','printshop-mobile','style_class','blog_list_content',0,''),(47109,14963,'120513','printshop-mobile','text-align','center',0,''),(47110,14964,'120514','printshop-mobile','aria_name','blogsidebar',0,''),(47111,14964,'120514','printshop-mobile','style_class','blogsidebar',0,''),(47112,14965,'120515','printshop-mobile','block_type','1',0,''),(47113,14965,'120515','printshop-mobile','padding-top','35',0,''),(47114,14965,'120515','printshop-mobile','padding-bottom','35',0,''),(47115,14966,'120516','printshop-mobile','block_type','7',0,''),(47116,14966,'120516','printshop-mobile','schema','7-1',0,''),(47118,14967,'120517','printshop-mobile','block_type','1',0,''),(47119,14967,'120517','printshop-mobile','style_class','blog_list_content',0,''),(47120,14968,'120518','printshop-mobile','items_on_page','12',0,''),(47121,14968,'120518','printshop-mobile','items_cut_off','200',0,''),(47122,14969,'120519','printshop-mobile','text-align','center',0,''),(47123,14969,'120519','printshop-mobile','hide_parents','1',0,''),(47124,14970,'120520','printshop-mobile','aria_name','blogsidebar',0,''),(47125,14970,'120520','printshop-mobile','padding-left','35',0,''),(47126,14970,'120520','printshop-mobile','style_class','blogsidebar',0,''),(47128,14971,'120521','printshop-mobile','banners_group','blog',0,''),(47129,14971,'120521','printshop-mobile','margin-bottom','40',0,''),(47130,14972,'120522','printshop-mobile','block_type','1',0,''),(47131,14972,'120522','printshop-mobile','padding-top','35',0,''),(47132,14972,'120522','printshop-mobile','padding-bottom','35',0,''),(47133,14973,'120523','printshop-mobile','block_type','7',0,''),(47134,14973,'120523','printshop-mobile','schema','7-2',0,''),(47135,14975,'120525','printshop-mobile','block_type','1',0,''),(47136,14976,'120526','printshop-mobile','text','<div class=\"heading-3\">##TEXT_BLOG_RELATED_PRODUCTS##</div>',0,''),(47137,14977,'120527','printshop-mobile','count_products','8',0,''),(47138,14977,'120527','printshop-mobile','col_in_row','4',0,''),(47139,14977,'120527','printshop-mobile','view_as','carousel',0,''),(47140,14977,'120527','printshop-mobile','show_stock','1',0,''),(47141,14977,'120527','printshop-mobile','show_description','1',0,''),(47142,14977,'120527','printshop-mobile','show_properties','1',0,''),(47143,14977,'120527','printshop-mobile','show_rating','1',0,''),(47144,14977,'120527','printshop-mobile','show_rating_counts','1',0,''),(47145,14977,'120527','printshop-mobile','show_qty_input','1',0,''),(47146,14977,'120527','printshop-mobile','show_wishlist_button','1',0,''),(47147,14977,'120527','printshop-mobile','show_compare','1',0,''),(47151,14977,'120527','printshop-mobile','listing_type','productListing',0,''),(47152,14977,'120527','printshop-mobile','hide_parents','2',0,''),(47153,14978,'120528','printshop-mobile','block_type','1',0,''),(47154,14978,'120528','printshop-mobile','style_class','blog-white-bg',0,''),(47155,14978,'120528','printshop-mobile','padding-bottom','20',0,''),(47156,14982,'120532','printshop-mobile','block_type','1',0,''),(47157,14982,'120532','printshop-mobile','padding-top','20',0,''),(47158,14982,'120532','printshop-mobile','margin-top','20',0,''),(47159,14982,'120532','printshop-mobile','border-top-width','1',0,''),(47160,14982,'120532','printshop-mobile','border-top-color','#EDE5D5',0,''),(47161,14982,'120532','printshop-mobile','clear','both',0,''),(47162,14983,'120533','printshop-mobile','box_align','4',0,''),(47163,14983,'120533','printshop-mobile','text-align','center',0,''),(47164,14984,'120534','printshop-mobile','text-align','center',0,''),(47165,14985,'120535','printshop-mobile','aria_name','blogsidebar',0,''),(47166,14985,'120535','printshop-mobile','style_class','blogsidebar',0,''),(47167,14986,'120536','printshop-mobile','block_type','1',0,''),(47168,14986,'120536','printshop-mobile','padding-top','35',0,''),(47169,14986,'120536','printshop-mobile','padding-bottom','35',0,''),(47170,14987,'120537','printshop-mobile','block_type','7',0,''),(47171,14987,'120537','printshop-mobile','schema','7-2',0,''),(47172,14988,'120538','printshop-mobile','block_type','1',0,''),(47173,14988,'120538','printshop-mobile','style_class','blog_list_content',0,''),(47174,14990,'120540','printshop-mobile','text-align','center',0,''),(47175,14990,'120540','printshop-mobile','hide_parents','1',0,''),(47176,14991,'120541','printshop-mobile','aria_name','blogsidebar',0,''),(47177,14991,'120541','printshop-mobile','style_class','blogsidebar',0,''),(47178,14992,'120542','printshop-mobile','block_type','1',0,''),(47179,14994,'120544','printshop-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(47180,14995,'120545','printshop-mobile','block_type','1',0,''),(47181,14996,'120546','printshop-mobile','block_type','2',0,''),(47182,14996,'120546','printshop-mobile','margin-bottom','20',0,''),(47183,14997,'120547','printshop-mobile','block_type','1',0,''),(47184,14997,'120547','printshop-mobile','padding-right','20',0,''),(47185,14998,'120548','printshop-mobile','field','50',0,''),(47186,14999,'120549','printshop-mobile','field','49',0,''),(47187,15000,'120550','printshop-mobile','block_type','2',0,''),(47188,15002,'120552','printshop-mobile','float','right',0,''),(47189,15002,'120552','printshop-mobile','clear','none',0,''),(47190,15003,'120553','printshop-mobile','float','right',0,''),(47191,15003,'120553','printshop-mobile','margin-left','20',0,''),(47192,15004,'120554','printshop-mobile','block_type','2',0,''),(47193,15004,'120554','printshop-mobile','margin-bottom','20',0,''),(47194,15005,'120555','printshop-mobile','block_type','1',0,''),(47195,15005,'120555','printshop-mobile','padding-right','20',0,''),(47196,15006,'120556','printshop-mobile','field','66',0,''),(47197,15007,'120557','printshop-mobile','block_type','1',0,''),(47198,15007,'120557','printshop-mobile','padding-left','20',0,''),(47199,15008,'120558','printshop-mobile','field','67',0,''),(47200,15009,'120559','printshop-mobile','text','<div class=\"heading-2\">##TRADE_REFERENCES##</div>',0,''),(47201,15009,'120559','printshop-mobile','text-align','center',0,''),(47202,15010,'120560','printshop-mobile','text','<div class=\"heading-2\">##BANK_ACCOUNT_DETAILS##</div>',0,''),(47203,15010,'120560','printshop-mobile','text-align','center',0,''),(47204,15011,'120561','printshop-mobile','text','<div class=\"heading-2\">##TEXT_DECLARATION##</div>',0,''),(47205,15011,'120561','printshop-mobile','text-align','center',0,''),(47206,15012,'120562','printshop-mobile','block_type','2',0,''),(47207,15012,'120562','printshop-mobile','margin-bottom','20',0,''),(47208,15013,'120563','printshop-mobile','block_type','1',0,''),(47209,15013,'120563','printshop-mobile','padding-right','20',0,''),(47210,15014,'120564','printshop-mobile','field','62',0,''),(47211,15015,'120565','printshop-mobile','field','60',0,''),(47212,15016,'120566','printshop-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 1</div>',0,''),(47213,15017,'120567','printshop-mobile','field','61',0,''),(47214,15018,'120568','printshop-mobile','block_type','1',0,''),(47215,15018,'120568','printshop-mobile','padding-left','20',0,''),(47216,15019,'120569','printshop-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 2</div>',0,''),(47217,15020,'120570','printshop-mobile','field','64',0,''),(47218,15021,'120571','printshop-mobile','field','63',0,''),(47219,15022,'120572','printshop-mobile','field','65',0,''),(47220,15023,'120573','printshop-mobile','block_type','2',0,''),(47221,15023,'120573','printshop-mobile','margin-bottom','20',0,''),(47222,15024,'120574','printshop-mobile','block_type','1',0,''),(47223,15024,'120574','printshop-mobile','padding-right','20',0,''),(47224,15025,'120575','printshop-mobile','field','52',0,''),(47225,15026,'120576','printshop-mobile','field','51',0,''),(47226,15027,'120577','printshop-mobile','block_type','2',0,''),(47227,15028,'120578','printshop-mobile','block_type','1',0,''),(47228,15028,'120578','printshop-mobile','padding-right','20',0,''),(47229,15029,'120579','printshop-mobile','group','15',0,''),(47230,15030,'120580','printshop-mobile','text','<div class=\"heading-3\">##CATEGORY_COMPANY##</div>',0,''),(47231,15032,'120582','printshop-mobile','block_type','2',0,''),(47232,15033,'120583','printshop-mobile','field','68',0,''),(47233,15033,'120583','printshop-mobile','padding-right','10',0,''),(47234,15034,'120584','printshop-mobile','block_type','2',0,''),(47235,15034,'120584','printshop-mobile','border-bottom-width','1',0,''),(47236,15034,'120584','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(47237,15034,'120584','printshop-mobile','padding-bottom','10',0,''),(47238,15034,'120584','printshop-mobile','margin-bottom','20',0,''),(47239,15035,'120585','printshop-mobile','block_type','1',0,''),(47240,15035,'120585','printshop-mobile','padding-right','10',0,''),(47241,15036,'120586','printshop-mobile','field','69',0,''),(47242,15037,'120587','printshop-mobile','field','75',0,''),(47243,15038,'120588','printshop-mobile','field','71',0,''),(47244,15039,'120589','printshop-mobile','field','73',0,''),(47245,15040,'120590','printshop-mobile','block_type','1',0,''),(47246,15040,'120590','printshop-mobile','padding-left','10',0,''),(47247,15041,'120591','printshop-mobile','field','76',0,''),(47248,15042,'120592','printshop-mobile','field','74',0,''),(47249,15043,'120593','printshop-mobile','field','72',0,''),(47250,15044,'120594','printshop-mobile','field','70',0,''),(47251,15045,'120595','printshop-mobile','block_type','1',0,''),(47252,15045,'120595','printshop-mobile','padding-left','20',0,''),(47253,15046,'120596','printshop-mobile','group','16',0,''),(47254,15047,'120597','printshop-mobile','block_type','2',0,''),(47255,15048,'120598','printshop-mobile','block_type','1',0,''),(47256,15048,'120598','printshop-mobile','padding-right','10',0,''),(47257,15049,'120599','printshop-mobile','field','77',0,''),(47258,15050,'120600','printshop-mobile','field','79',0,''),(47259,15051,'120601','printshop-mobile','block_type','1',0,''),(47260,15051,'120601','printshop-mobile','padding-left','10',0,''),(47261,15052,'120602','printshop-mobile','field','78',0,''),(47262,15053,'120603','printshop-mobile','block_type','2',0,''),(47263,15054,'120604','printshop-mobile','block_type','1',0,''),(47264,15054,'120604','printshop-mobile','padding-right','10',0,''),(47265,15055,'120605','printshop-mobile','field','82',0,''),(47266,15056,'120606','printshop-mobile','field','80',0,''),(47267,15057,'120607','printshop-mobile','field','84',0,''),(47268,15058,'120608','printshop-mobile','block_type','1',0,''),(47269,15058,'120608','printshop-mobile','padding-left','10',0,''),(47270,15059,'120609','printshop-mobile','field','83',0,''),(47271,15060,'120610','printshop-mobile','field','81',0,''),(47272,15061,'120611','printshop-mobile','field','85',0,''),(47273,15062,'120612','printshop-mobile','text','<div class=\"heading-3\">##OWNERS_DETAILS##</div>',0,''),(47274,15063,'120613','printshop-mobile','block_type','2',0,''),(47275,15063,'120613','printshop-mobile','margin-bottom','20',0,''),(47276,15064,'120614','printshop-mobile','block_type','1',0,''),(47277,15064,'120614','printshop-mobile','padding-right','20',0,''),(47278,15065,'120615','printshop-mobile','field','53',0,''),(47279,15066,'120616','printshop-mobile','field','54',0,''),(47280,15067,'120617','printshop-mobile','block_type','1',0,''),(47281,15067,'120617','printshop-mobile','padding-left','20',0,''),(47282,15068,'120618','printshop-mobile','field','55',0,''),(47283,15069,'120619','printshop-mobile','text','<div class=\"heading-2\">##TEXT_CUSTOMER_DETAILS##</div>',0,''),(47284,15069,'120619','printshop-mobile','text-align','center',0,''),(47285,15070,'120620','printshop-mobile','block_type','2',0,''),(47286,15070,'120620','printshop-mobile','margin-bottom','20',0,''),(47287,15071,'120621','printshop-mobile','block_type','1',0,''),(47288,15071,'120621','printshop-mobile','padding-right','20',0,''),(47289,15072,'120622','printshop-mobile','field','56',0,''),(47290,15073,'120623','printshop-mobile','field','57',0,''),(47291,15074,'120624','printshop-mobile','block_type','1',0,''),(47292,15074,'120624','printshop-mobile','padding-left','20',0,''),(47293,15075,'120625','printshop-mobile','field','58',0,''),(47294,15076,'120626','printshop-mobile','field','59',0,''),(47295,15077,'120627','printshop-mobile','text','<h1>##TRADE_FORM##</h1>',0,''),(47296,15078,'120628','printshop-mobile','text','<div class=\"heading-2\">##DISCOUNT##</div>',0,''),(47297,15078,'120628','printshop-mobile','text-align','center',0,''),(47298,15079,'120629','printshop-mobile','block_type','1',0,''),(47299,15080,'120630','printshop-mobile','block_type','6',0,''),(47300,15081,'120631','printshop-mobile','text','Telephone No.',0,''),(47301,15081,'120631','printshop-mobile','text-align','right',0,''),(47302,15082,'120632','printshop-mobile','field','79',0,''),(47303,15082,'120632','printshop-mobile','border-bottom-width','1',0,''),(47304,15082,'120632','printshop-mobile','border-bottom-color','#000000',0,''),(47305,15082,'120632','printshop-mobile','padding-left','10',0,''),(47306,15083,'120633','printshop-mobile','block_type','6',0,''),(47307,15084,'120634','printshop-mobile','text','Address',0,''),(47308,15084,'120634','printshop-mobile','text-align','right',0,''),(47309,15085,'120635','printshop-mobile','fields','company_street_address, company_suburb, company_city',0,''),(47310,15085,'120635','printshop-mobile','padding-left','10',0,''),(47311,15085,'120635','printshop-mobile','border-bottom-width','1',0,''),(47312,15085,'120635','printshop-mobile','border-bottom-color','#000000',0,''),(47313,15086,'120636','printshop-mobile','block_type','6',0,''),(47314,15087,'120637','printshop-mobile','text','Postcode',0,''),(47315,15087,'120637','printshop-mobile','text-align','right',0,''),(47316,15088,'120638','printshop-mobile','field','80',0,''),(47317,15088,'120638','printshop-mobile','border-bottom-width','1',0,''),(47318,15088,'120638','printshop-mobile','border-bottom-color','#000000',0,''),(47319,15088,'120638','printshop-mobile','padding-left','10',0,''),(47320,15089,'120639','printshop-mobile','block_type','6',0,''),(47321,15090,'120640','printshop-mobile','text','Address',0,''),(47322,15090,'120640','printshop-mobile','text-align','right',0,''),(47323,15091,'120641','printshop-mobile','fields','oner_street_address, owner_suburb, owner_city',0,''),(47324,15091,'120641','printshop-mobile','padding-left','10',0,''),(47325,15091,'120641','printshop-mobile','border-bottom-width','1',0,''),(47326,15091,'120641','printshop-mobile','border-bottom-color','#000000',0,''),(47327,15092,'120642','printshop-mobile','block_type','6',0,''),(47328,15092,'120642','printshop-mobile','margin-top','20',0,''),(47329,15093,'120643','printshop-mobile','text','Owner’s Name',0,''),(47330,15093,'120643','printshop-mobile','text-align','right',0,''),(47331,15094,'120644','printshop-mobile','fields','owner_firstname owner_lastname',0,''),(47332,15094,'120644','printshop-mobile','padding-left','10',0,''),(47333,15094,'120644','printshop-mobile','border-bottom-width','1',0,''),(47334,15094,'120644','printshop-mobile','border-bottom-color','#000000',0,''),(47335,15095,'120645','printshop-mobile','block_type','6',0,''),(47336,15096,'120646','printshop-mobile','text','Email',0,''),(47337,15096,'120646','printshop-mobile','text-align','right',0,''),(47338,15097,'120647','printshop-mobile','field','70',0,''),(47339,15097,'120647','printshop-mobile','border-bottom-width','1',0,''),(47340,15097,'120647','printshop-mobile','border-bottom-color','#000000',0,''),(47341,15097,'120647','printshop-mobile','padding-left','10',0,''),(47342,15098,'120648','printshop-mobile','block_type','6',0,''),(47343,15098,'120648','printshop-mobile','padding-bottom','20',0,''),(47344,15099,'120649','printshop-mobile','text','Telephone No.',0,''),(47345,15099,'120649','printshop-mobile','text-align','right',0,''),(47346,15100,'120650','printshop-mobile','block_type','11',0,''),(47347,15101,'120651','printshop-mobile','field','69',0,''),(47348,15101,'120651','printshop-mobile','border-bottom-width','1',0,''),(47349,15101,'120651','printshop-mobile','border-bottom-color','#000000',0,''),(47350,15101,'120651','printshop-mobile','padding-left','10',0,''),(47351,15102,'120652','printshop-mobile','block_type','5',0,''),(47352,15103,'120653','printshop-mobile','text','Fax No.',0,''),(47353,15103,'120653','printshop-mobile','text-align','right',0,''),(47354,15104,'120654','printshop-mobile','field','51',0,''),(47355,15104,'120654','printshop-mobile','padding-left','10',0,''),(47356,15104,'120654','printshop-mobile','border-bottom-width','1',0,''),(47357,15104,'120654','printshop-mobile','border-bottom-color','#000000',0,''),(47358,15105,'120655','printshop-mobile','block_type','1',0,''),(47359,15106,'120656','printshop-mobile','background-color','#000000',0,''),(47360,15106,'120656','printshop-mobile','color','#ffffff',0,''),(47361,15106,'120656','printshop-mobile','font-size','20',0,''),(47362,15106,'120656','printshop-mobile','text','Customer Details',0,''),(47363,15106,'120656','printshop-mobile','padding-left','10',0,''),(47364,15106,'120656','printshop-mobile','padding-right','10',0,''),(47365,15107,'120657','printshop-mobile','block_type','2',0,''),(47366,15107,'120657','printshop-mobile','color','#ffffff',0,''),(47367,15107,'120657','printshop-mobile','background-color','#000000',0,''),(47368,15108,'120658','printshop-mobile','view_item','name',0,''),(47369,15108,'120658','printshop-mobile','color','#ffffff',0,''),(47370,15108,'120658','printshop-mobile','font-size','40',0,''),(47371,15109,'120659','printshop-mobile','text','New Account Form',0,''),(47372,15109,'120659','printshop-mobile','font-size','20',0,''),(47373,15109,'120659','printshop-mobile','color','#ffffff',0,''),(47374,15109,'120659','printshop-mobile','padding-top','20',0,''),(47375,15110,'120660','printshop-mobile','block_type','2',0,''),(47376,15111,'120661','printshop-mobile','block_type','2',0,''),(47377,15111,'120661','printshop-mobile','padding-top','5',0,''),(47378,15112,'120662','printshop-mobile','block_type','10',0,''),(47379,15113,'120663','printshop-mobile','text','Limited Company',0,''),(47380,15113,'120663','printshop-mobile','font-size','16',0,''),(47381,15114,'120664','printshop-mobile','field','49',0,''),(47382,15114,'120664','printshop-mobile','padding-left','5',0,''),(47383,15115,'120665','printshop-mobile','block_type','10',0,''),(47384,15116,'120666','printshop-mobile','text','Sole Trader',0,''),(47385,15116,'120666','printshop-mobile','text-align','center',0,''),(47386,15117,'120667','printshop-mobile','field','50',0,''),(47387,15117,'120667','printshop-mobile','padding-left','5',0,''),(47388,15118,'120668','printshop-mobile','block_type','5',0,''),(47389,15119,'120669','printshop-mobile','view_item','data_format',0,''),(47390,15119,'120669','printshop-mobile','data_format_content','##STREET_ADDRESS##, ##SUBURB##,\n##CITY##, ##POSTCODE##\nTel: ##TELEPHONE##\nEmail: ##EMAIL_ADDRESS##\n',0,''),(47391,15119,'120669','printshop-mobile','font-size','14',0,''),(47392,15120,'120670','printshop-mobile','block_type','6',0,''),(47393,15121,'120671','printshop-mobile','text','Postcode',0,''),(47394,15121,'120671','printshop-mobile','text-align','right',0,''),(47395,15122,'120672','printshop-mobile','field','71',0,''),(47396,15122,'120672','printshop-mobile','border-bottom-width','1',0,''),(47397,15122,'120672','printshop-mobile','border-bottom-color','#000000',0,''),(47398,15122,'120672','printshop-mobile','padding-left','10',0,''),(47399,15123,'120673','printshop-mobile','block_type','6',0,''),(47400,15124,'120674','printshop-mobile','text','Business Name',0,''),(47401,15124,'120674','printshop-mobile','text-align','right',0,''),(47402,15125,'120675','printshop-mobile','field','68',0,''),(47403,15125,'120675','printshop-mobile','border-bottom-width','1',0,''),(47404,15125,'120675','printshop-mobile','border-bottom-color','#000000',0,''),(47405,15125,'120675','printshop-mobile','padding-left','10',0,''),(47406,15126,'120676','printshop-mobile','block_type','6',0,''),(47407,15126,'120676','printshop-mobile','padding-bottom','20',0,''),(47408,15127,'120677','printshop-mobile','text','Nature of Business',0,''),(47409,15127,'120677','printshop-mobile','text-align','right',0,''),(47410,15128,'120678','printshop-mobile','field','52',0,''),(47411,15128,'120678','printshop-mobile','border-bottom-width','1',0,''),(47412,15128,'120678','printshop-mobile','border-bottom-color','#000000',0,''),(47413,15128,'120678','printshop-mobile','padding-left','10',0,''),(47414,15129,'120679','printshop-mobile','block_type','6',0,''),(47415,15130,'120680','printshop-mobile','text','Bank Name',0,''),(47416,15130,'120680','printshop-mobile','text-align','right',0,''),(47417,15130,'120680','printshop-mobile','font-size','16',0,''),(47418,15131,'120681','printshop-mobile','field','53',0,''),(47419,15131,'120681','printshop-mobile','border-bottom-width','1',0,''),(47420,15131,'120681','printshop-mobile','border-bottom-color','#000000',0,''),(47421,15131,'120681','printshop-mobile','padding-left','10',0,''),(47422,15132,'120682','printshop-mobile','block_type','1',0,''),(47423,15132,'120682','printshop-mobile','padding-top','20',0,''),(47424,15132,'120682','printshop-mobile','padding-bottom','10',0,''),(47425,15133,'120683','printshop-mobile','background-color','#000000',0,''),(47426,15133,'120683','printshop-mobile','color','#ffffff',0,''),(47427,15133,'120683','printshop-mobile','font-size','20',0,''),(47428,15133,'120683','printshop-mobile','text','Discount (%)',0,''),(47429,15133,'120683','printshop-mobile','padding-left','10',0,''),(47430,15133,'120683','printshop-mobile','padding-right','10',0,''),(47431,15134,'120684','printshop-mobile','block_type','1',0,''),(47432,15134,'120684','printshop-mobile','padding-bottom','10',0,''),(47433,15135,'120685','printshop-mobile','background-color','#000000',0,''),(47434,15135,'120685','printshop-mobile','color','#ffffff',0,''),(47435,15135,'120685','printshop-mobile','font-size','20',0,''),(47436,15135,'120685','printshop-mobile','text','Bank Account Details',0,''),(47437,15135,'120685','printshop-mobile','padding-left','10',0,''),(47438,15135,'120685','printshop-mobile','padding-right','10',0,''),(47439,15136,'120686','printshop-mobile','block_type','6',0,''),(47440,15136,'120686','printshop-mobile','padding-bottom','20',0,''),(47441,15137,'120687','printshop-mobile','text','Account No',0,''),(47442,15137,'120687','printshop-mobile','text-align','right',0,''),(47443,15138,'120688','printshop-mobile','field','54',0,''),(47444,15138,'120688','printshop-mobile','border-bottom-width','1',0,''),(47445,15138,'120688','printshop-mobile','border-bottom-color','#000000',0,''),(47446,15138,'120688','printshop-mobile','padding-left','10',0,''),(47447,15139,'120689','printshop-mobile','block_type','6',0,''),(47448,15140,'120690','printshop-mobile','text','Address',0,''),(47449,15140,'120690','printshop-mobile','text-align','right',0,''),(47450,15141,'120691','printshop-mobile','field','55',0,''),(47451,15141,'120691','printshop-mobile','border-bottom-width','1',0,''),(47452,15141,'120691','printshop-mobile','border-bottom-color','#000000',0,''),(47453,15141,'120691','printshop-mobile','padding-left','10',0,''),(47454,15142,'120692','printshop-mobile','block_type','14',0,''),(47455,15142,'120692','printshop-mobile','padding-bottom','20',0,''),(47456,15143,'120693','printshop-mobile','text','33.33% Sale or Return',0,''),(47457,15143,'120693','printshop-mobile','text-align','right',0,''),(47458,15143,'120693','printshop-mobile','font-size','16',0,''),(47459,15144,'120694','printshop-mobile','block_type','13',0,''),(47460,15145,'120695','printshop-mobile','field','56',0,''),(47461,15145,'120695','printshop-mobile','padding-left','10',0,''),(47462,15146,'120696','printshop-mobile','text','35% Firm',0,''),(47463,15146,'120696','printshop-mobile','text-align','right',0,''),(47464,15147,'120697','printshop-mobile','field','58',0,''),(47465,15147,'120697','printshop-mobile','padding-left','10',0,''),(47466,15148,'120698','printshop-mobile','block_type','10',0,''),(47467,15149,'120699','printshop-mobile','block_type','6',0,''),(47468,15150,'120700','printshop-mobile','text','Address',0,''),(47469,15150,'120700','printshop-mobile','text-align','right',0,''),(47470,15151,'120701','printshop-mobile','field','61',0,''),(47471,15151,'120701','printshop-mobile','border-bottom-width','1',0,''),(47472,15151,'120701','printshop-mobile','border-bottom-color','#000000',0,''),(47473,15151,'120701','printshop-mobile','padding-left','10',0,''),(47474,15152,'120702','printshop-mobile','block_type','1',0,''),(47475,15152,'120702','printshop-mobile','padding-bottom','10',0,''),(47476,15153,'120703','printshop-mobile','background-color','#000000',0,''),(47477,15153,'120703','printshop-mobile','color','#ffffff',0,''),(47478,15153,'120703','printshop-mobile','font-size','20',0,''),(47479,15153,'120703','printshop-mobile','text','Trade References',0,''),(47480,15153,'120703','printshop-mobile','padding-left','10',0,''),(47481,15153,'120703','printshop-mobile','padding-right','10',0,''),(47482,15154,'120704','printshop-mobile','block_type','1',0,''),(47483,15155,'120705','printshop-mobile','text','I would like to open a trade account with Vladislav B. Malyshev and agree to abide by their General Terms & Conditions –\na signed copy of which is returned to them with this form in the supplied SAE. I have retained a copy for my reference. I\nam authorised to sign on behalf of the company I represent.',0,''),(47484,15155,'120705','printshop-mobile','font-size','15',0,''),(47485,15155,'120705','printshop-mobile','padding-left','10',0,''),(47486,15155,'120705','printshop-mobile','padding-right','10',0,''),(47487,15156,'120706','printshop-mobile','block_type','6',0,''),(47488,15156,'120706','printshop-mobile','padding-bottom','20',0,''),(47489,15157,'120707','printshop-mobile','text','Telephone No.',0,''),(47490,15157,'120707','printshop-mobile','text-align','right',0,''),(47491,15158,'120708','printshop-mobile','field','62',0,''),(47492,15158,'120708','printshop-mobile','border-bottom-width','1',0,''),(47493,15158,'120708','printshop-mobile','border-bottom-color','#000000',0,''),(47494,15158,'120708','printshop-mobile','padding-left','10',0,''),(47495,15159,'120709','printshop-mobile','block_type','1',0,''),(47496,15159,'120709','printshop-mobile','padding-bottom','10',0,''),(47497,15160,'120710','printshop-mobile','background-color','#000000',0,''),(47498,15160,'120710','printshop-mobile','color','#ffffff',0,''),(47499,15160,'120710','printshop-mobile','font-size','20',0,''),(47500,15160,'120710','printshop-mobile','text','Customer Details',0,''),(47501,15160,'120710','printshop-mobile','padding-left','10',0,''),(47502,15160,'120710','printshop-mobile','padding-right','10',0,''),(47503,15161,'120711','printshop-mobile','block_type','6',0,''),(47504,15162,'120712','printshop-mobile','text','Name',0,''),(47505,15162,'120712','printshop-mobile','text-align','right',0,''),(47506,15162,'120712','printshop-mobile','font-size','16',0,''),(47507,15163,'120713','printshop-mobile','field','60',0,''),(47508,15163,'120713','printshop-mobile','border-bottom-width','1',0,''),(47509,15163,'120713','printshop-mobile','border-bottom-color','#000000',0,''),(47510,15163,'120713','printshop-mobile','padding-left','10',0,''),(47511,15164,'120714','printshop-mobile','block_type','14',0,''),(47512,15165,'120715','printshop-mobile','text','Signed',0,''),(47513,15165,'120715','printshop-mobile','text-align','right',0,''),(47514,15166,'120716','printshop-mobile','text','&nbsp;',0,''),(47515,15166,'120716','printshop-mobile','border-bottom-width','1',0,''),(47516,15166,'120716','printshop-mobile','border-bottom-color','#000000',0,''),(47517,15167,'120717','printshop-mobile','text','Date',0,''),(47518,15167,'120717','printshop-mobile','text-align','right',0,''),(47519,15168,'120718','printshop-mobile','text','&nbsp;',0,''),(47520,15168,'120718','printshop-mobile','border-bottom-width','1',0,''),(47521,15168,'120718','printshop-mobile','border-bottom-color','#000000',0,''),(47522,15169,'120719','printshop-mobile','block_type','14',0,''),(47523,15170,'120720','printshop-mobile','text','Name in Full',0,''),(47524,15170,'120720','printshop-mobile','text-align','right',0,''),(47525,15171,'120721','printshop-mobile','field','66',0,''),(47526,15171,'120721','printshop-mobile','padding-left','10',0,''),(47527,15171,'120721','printshop-mobile','border-bottom-width','1',0,''),(47528,15171,'120721','printshop-mobile','border-bottom-color','#000000',0,''),(47529,15172,'120722','printshop-mobile','text','Position',0,''),(47530,15172,'120722','printshop-mobile','text-align','right',0,''),(47531,15173,'120723','printshop-mobile','field','67',0,''),(47532,15173,'120723','printshop-mobile','border-bottom-width','1',0,''),(47533,15173,'120723','printshop-mobile','border-bottom-color','#000000',0,''),(47534,15173,'120723','printshop-mobile','padding-left','10',0,''),(47535,15174,'120724','printshop-mobile','block_type','1',0,''),(47536,15175,'120725','printshop-mobile','text','Scottish books of exceptional value',0,''),(47537,15175,'120725','printshop-mobile','font-size','20',0,''),(47538,15175,'120725','printshop-mobile','text-align','center',0,''),(47539,15175,'120725','printshop-mobile','padding-top','20',0,''),(47540,15176,'120726','printshop-mobile','block_type','1',0,''),(47541,15177,'120727','printshop-mobile','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(47542,15177,'120727','printshop-mobile','padding-top','100',0,''),(47543,15177,'120727','printshop-mobile','margin-bottom','100',0,''),(47544,15177,'120727','printshop-mobile','text-align','center',0,''),(47545,15177,'120727','printshop-mobile','font-size','20',0,''),(47546,15178,'120728','printshop-mobile','block_type','1',0,''),(47547,15178,'120728','printshop-mobile','background-color','#eeeeee',0,''),(47548,15178,'120728','printshop-mobile','padding-bottom','30',0,''),(47549,15179,'120729','printshop-mobile','block_type','4',0,''),(47550,15179,'120729','printshop-mobile','schema','4-2',0,''),(47551,15180,'120730','printshop-mobile','block_type','1',0,''),(47552,15180,'120730','printshop-mobile','padding-right','40',0,''),(47554,15181,'120731','printshop-mobile','block_type','2',0,''),(47555,15181,'120731','printshop-mobile','margin-bottom','20',0,''),(47556,15181,'120731','printshop-mobile','schema','2-2',0,''),(47557,15181,'120731','printshop-mobile','background-color','#ffffff',0,''),(47558,15182,'120732','printshop-mobile','block_type','1',0,''),(47559,15182,'120732','printshop-mobile','border-right-width','20',0,''),(47560,15182,'120732','printshop-mobile','border-right-color','#e0e0e0',0,''),(47561,15182,'120732','printshop-mobile','margin-right','-10',0,''),(47562,15182,'120732','printshop-mobile','padding-right','30',0,''),(47563,15182,'120732','printshop-mobile','padding-top','20',0,''),(47564,15182,'120732','printshop-mobile','padding-left','30',0,''),(47565,15182,'120732','printshop-mobile','padding-bottom','20',0,''),(47568,15182,'120732','printshop-mobile','margin-bottom','20',0,''),(47571,15183,'120733','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(47572,15183,'120733','printshop-mobile','clear','none',0,''),(47573,15184,'120734','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(47574,15184,'120734','printshop-mobile','clear','none',0,''),(47575,15185,'120735','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(47576,15187,'120737','printshop-mobile','margin-bottom','20',0,''),(47577,15191,'120741','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(47578,15191,'120741','printshop-mobile','padding-top','20',0,''),(47579,15192,'120742','printshop-mobile','block_type','1',0,''),(47580,15192,'120742','printshop-mobile','padding-left','30',0,''),(47581,15192,'120742','printshop-mobile','border-left-width','20',0,''),(47582,15192,'120742','printshop-mobile','border-left-color','#e0e0e0',0,''),(47583,15192,'120742','printshop-mobile','margin-left','-10',0,''),(47584,15192,'120742','printshop-mobile','padding-right','30',0,''),(47585,15192,'120742','printshop-mobile','padding-top','20',0,''),(47586,15192,'120742','printshop-mobile','padding-bottom','20',0,''),(47588,15193,'120743','printshop-mobile','margin-bottom','20',0,''),(47589,15195,'120745','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(47590,15196,'120746','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(47591,15196,'120746','printshop-mobile','clear','none',0,''),(47592,15197,'120747','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(47593,15197,'120747','printshop-mobile','clear','none',0,''),(47594,15198,'120748','printshop-mobile','block_type','1',0,''),(47595,15198,'120748','printshop-mobile','padding-right','30',0,''),(47596,15198,'120748','printshop-mobile','background-color','#ffffff',0,''),(47597,15198,'120748','printshop-mobile','padding-top','20',0,''),(47598,15198,'120748','printshop-mobile','padding-left','30',0,''),(47599,15198,'120748','printshop-mobile','padding-bottom','20',0,''),(47602,15200,'120750','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(47603,15201,'120751','printshop-mobile','block_type','1',0,''),(47604,15201,'120751','printshop-mobile','padding-top','20',0,''),(47605,15201,'120751','printshop-mobile','padding-left','20',0,''),(47606,15201,'120751','printshop-mobile','padding-right','20',0,''),(47607,15201,'120751','printshop-mobile','padding-bottom','20',0,''),(47608,15201,'120751','printshop-mobile','background-color','#ffffff',0,''),(47609,15201,'120751','printshop-mobile','style_class','order-summary',0,''),(47610,15202,'120752','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(47611,15206,'120756','printshop-mobile','block_type','1',0,''),(47612,15206,'120756','printshop-mobile','background-color','#eeeeee',0,''),(47613,15206,'120756','printshop-mobile','padding-bottom','30',0,''),(47614,15207,'120757','printshop-mobile','block_type','4',0,''),(47615,15207,'120757','printshop-mobile','schema','4-2',0,''),(47616,15208,'120758','printshop-mobile','block_type','1',0,''),(47617,15208,'120758','printshop-mobile','padding-right','40',0,''),(47619,15209,'120759','printshop-mobile','block_type','1',0,''),(47620,15209,'120759','printshop-mobile','padding-right','30',0,''),(47621,15209,'120759','printshop-mobile','background-color','#ffffff',0,''),(47622,15209,'120759','printshop-mobile','padding-top','20',0,''),(47623,15209,'120759','printshop-mobile','padding-left','30',0,''),(47624,15209,'120759','printshop-mobile','padding-bottom','20',0,''),(47627,15210,'120760','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(47628,15212,'120762','printshop-mobile','block_type','2',0,''),(47629,15212,'120762','printshop-mobile','margin-bottom','20',0,''),(47630,15212,'120762','printshop-mobile','schema','2-2',0,''),(47631,15212,'120762','printshop-mobile','background-color','#ffffff',0,''),(47632,15213,'120763','printshop-mobile','block_type','1',0,''),(47633,15213,'120763','printshop-mobile','border-right-width','20',0,''),(47634,15213,'120763','printshop-mobile','border-right-color','#e0e0e0',0,''),(47635,15213,'120763','printshop-mobile','margin-right','-10',0,''),(47636,15213,'120763','printshop-mobile','padding-right','30',0,''),(47637,15213,'120763','printshop-mobile','padding-top','20',0,''),(47638,15213,'120763','printshop-mobile','padding-left','30',0,''),(47639,15213,'120763','printshop-mobile','padding-bottom','20',0,''),(47642,15213,'120763','printshop-mobile','margin-bottom','20',0,''),(47645,15216,'120766','printshop-mobile','margin-bottom','20',0,''),(47646,15217,'120767','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(47647,15217,'120767','printshop-mobile','padding-top','20',0,''),(47648,15219,'120769','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(47649,15219,'120769','printshop-mobile','clear','none',0,''),(47650,15221,'120771','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(47651,15221,'120771','printshop-mobile','clear','none',0,''),(47652,15222,'120772','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(47653,15223,'120773','printshop-mobile','block_type','1',0,''),(47654,15223,'120773','printshop-mobile','padding-left','30',0,''),(47655,15223,'120773','printshop-mobile','border-left-width','20',0,''),(47656,15223,'120773','printshop-mobile','border-left-color','#e0e0e0',0,''),(47657,15223,'120773','printshop-mobile','margin-left','-10',0,''),(47658,15223,'120773','printshop-mobile','padding-right','30',0,''),(47659,15223,'120773','printshop-mobile','padding-top','20',0,''),(47660,15223,'120773','printshop-mobile','padding-bottom','20',0,''),(47662,15224,'120774','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(47663,15224,'120774','printshop-mobile','clear','none',0,''),(47664,15225,'120775','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(47665,15226,'120776','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(47666,15226,'120776','printshop-mobile','clear','none',0,''),(47667,15227,'120777','printshop-mobile','margin-bottom','20',0,''),(47668,15229,'120779','printshop-mobile','block_type','1',0,''),(47669,15229,'120779','printshop-mobile','padding-top','20',0,''),(47670,15229,'120779','printshop-mobile','padding-left','20',0,''),(47671,15229,'120779','printshop-mobile','padding-right','20',0,''),(47672,15229,'120779','printshop-mobile','padding-bottom','20',0,''),(47673,15229,'120779','printshop-mobile','background-color','#ffffff',0,''),(47674,15229,'120779','printshop-mobile','style_class','order-summary',0,''),(47675,15231,'120781','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(47676,15234,'120784','printshop-mobile','block_type','1',0,''),(47677,15234,'120784','printshop-mobile','background_image','themes/printshop-mobile/img/wedding-registry-page-1-1.jpg',0,''),(47678,15234,'120784','printshop-mobile','background-position','top center',0,''),(47679,15234,'120784','printshop-mobile','background-repeat','no-repeat',0,''),(47680,15234,'120784','printshop-mobile','background-size','cover',0,''),(47681,15234,'120784','printshop-mobile','padding-top','50',0,''),(47682,15234,'120784','printshop-mobile','padding-bottom','50',0,''),(47683,15234,'120784','printshop-mobile','margin-bottom','30',0,''),(47684,15235,'120785','printshop-mobile','background-color','#ffffff',0,''),(47685,15235,'120785','printshop-mobile','block_type','1',0,''),(47686,15235,'120785','printshop-mobile','max-width','700',0,''),(47687,15235,'120785','printshop-mobile','margin_left_measure','auto',0,''),(47688,15235,'120785','printshop-mobile','margin_right_measure','auto',0,''),(47689,15236,'120786','printshop-mobile','text-align','center',0,''),(47690,15236,'120786','printshop-mobile','margin-bottom','30',0,''),(47691,15237,'120787','printshop-mobile','padding-bottom','30',0,''),(47692,15237,'120787','printshop-mobile','text-align','center',0,''),(47693,15238,'120788','printshop-mobile','heading_type','h1',0,''),(47694,15239,'120789','printshop-mobile','block_type','13',0,''),(47695,15239,'120789','printshop-mobile','margin-bottom','20',0,''),(47696,15239,'120789','printshop-mobile','schema','13-2',0,''),(47697,15240,'120790','printshop-mobile','position','relative',0,''),(47698,15240,'120790','printshop-mobile','margin-top','-100',0,''),(47700,15241,'120791','printshop-mobile','font-family','Varela Round',0,''),(47701,15241,'120791','printshop-mobile','font-size','30',0,''),(47702,15241,'120791','printshop-mobile','text-transform','uppercase',0,''),(47703,15241,'120791','printshop-mobile','text-align','center',0,''),(47705,15242,'120792','printshop-mobile','block_type','1',0,''),(47706,15242,'120792','printshop-mobile','float','left',0,''),(47708,15243,'120793','printshop-mobile','display','inline-block',0,''),(47709,15243,'120793','printshop-mobile','font-weight','700',0,''),(47710,15244,'120794','printshop-mobile','clear','none',0,''),(47711,15244,'120794','printshop-mobile','padding-left','20',0,''),(47712,15244,'120794','printshop-mobile','font-weight','700',0,''),(47713,15244,'120794','printshop-mobile','display','inline-block',0,''),(47714,15245,'120795','printshop-mobile','font-weight','700',0,''),(47715,15245,'120795','printshop-mobile','clear','none',0,''),(47716,15245,'120795','printshop-mobile','padding-left','20',0,''),(47717,15245,'120795','printshop-mobile','display','inline-block',0,''),(47718,15246,'120796','printshop-mobile','font-family','Varela Round',0,''),(47719,15246,'120796','printshop-mobile','font-size','18',0,''),(47720,15246,'120796','printshop-mobile','margin-bottom','10',0,''),(47721,15246,'120796','printshop-mobile','text-align','center',0,''),(47722,15247,'120797','printshop-mobile','font-weight','700',0,''),(47723,15247,'120797','printshop-mobile','text-align','right',0,''),(47724,15247,'120797','printshop-mobile','max-width','110',0,''),(47725,15247,'120797','printshop-mobile','float','right',0,''),(47726,15248,'120798','printshop-mobile','margin-bottom','10',0,''),(47727,15249,'120799','printshop-mobile','like_button','1',0,''),(47728,15249,'120799','printshop-mobile','text-align','center',0,''),(47729,15249,'120799','printshop-mobile','margin-bottom','20',0,''),(47730,15249,'120799','printshop-mobile','margin-top','20',0,''),(47731,15249,'120799','printshop-mobile','padding-top','30',0,''),(47732,15249,'120799','printshop-mobile','border-top-width','1',0,''),(47733,15249,'120799','printshop-mobile','border-top-color','#e0e0e0',0,''),(47741,15254,'120804','printshop-mobile','block_type','1',0,''),(47742,15254,'120804','printshop-mobile','padding-top','20',0,''),(47743,15254,'120804','printshop-mobile','padding-bottom','20',0,''),(47744,15256,'120806','printshop-mobile','padding-top','10',0,''),(47745,15256,'120806','printshop-mobile','padding-bottom','10',0,''),(47746,15256,'120806','printshop-mobile','border-top-width','1',0,''),(47747,15256,'120806','printshop-mobile','border-top-color','#e0e0e0',0,''),(47748,15256,'120806','printshop-mobile','text-align','right',0,''),(47749,15257,'120807','printshop-mobile','block_type','1',0,''),(47750,15257,'120807','printshop-mobile','border-top-width','1',0,''),(47751,15257,'120807','printshop-mobile','border-left-width','1',0,''),(47752,15257,'120807','printshop-mobile','border-right-width','1',0,''),(47753,15257,'120807','printshop-mobile','border-bottom-width','1',0,''),(47754,15257,'120807','printshop-mobile','border-top-color','#e0e0e0',0,''),(47755,15257,'120807','printshop-mobile','border-left-color','#e0e0e0',0,''),(47756,15257,'120807','printshop-mobile','border-right-color','#e0e0e0',0,''),(47757,15257,'120807','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(47758,15257,'120807','printshop-mobile','padding-top','15',0,''),(47759,15257,'120807','printshop-mobile','padding-left','15',0,''),(47760,15257,'120807','printshop-mobile','padding-right','15',0,''),(47761,15257,'120807','printshop-mobile','padding-bottom','15',0,''),(47762,15257,'120807','printshop-mobile','margin-bottom','50',0,''),(47763,15258,'120808','printshop-mobile','block_type','1',0,''),(47764,15258,'120808','printshop-mobile','padding-top','20',0,''),(47765,15258,'120808','printshop-mobile','padding-left','20',0,''),(47766,15258,'120808','printshop-mobile','padding-right','20',0,''),(47767,15258,'120808','printshop-mobile','background-color','#ffffff',0,''),(47768,15260,'120810','printshop-mobile','text','<h1>##FIND_REGISTRY##</h1>',0,''),(47769,15261,'120811','printshop-mobile','block_type','1',0,''),(47770,15262,'120812','printshop-mobile','block_type','8',0,''),(47771,15262,'120812','printshop-mobile','schema','8-6',0,''),(47772,15263,'120813','printshop-mobile','text','<div class=\"heading-3\">##INVITE_GUESTS##</div>',0,''),(47773,15264,'120814','printshop-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_PERSONALIZED_URL##</div>',0,''),(47774,15265,'120815','printshop-mobile','margin-bottom','30',0,''),(47775,15268,'120818','printshop-mobile','margin-top','-100',0,''),(47776,15269,'120819','printshop-mobile','text','<h1>##SHARE_YOUR_WEDDING_REGISTRY##</h1>',0,''),(47777,15269,'120819','printshop-mobile','margin-top','-80',0,''),(47779,15270,'120820','printshop-mobile','text','<h1>##CREATE_WR_SUCCESS_MESSAGE##</h1>',0,''),(47780,15272,'120822','printshop-mobile','block_type','2',0,''),(47781,15272,'120822','printshop-mobile','schema','2-2',0,''),(47782,15273,'120823','printshop-mobile','block_type','1',0,''),(47783,15273,'120823','printshop-mobile','padding-right','15',0,''),(47785,15274,'120824','printshop-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_REGISTRY##</div>',0,''),(47786,15275,'120825','printshop-mobile','text','<div class=\"heading-3\">##TEXT_WEDDING_DETAILS##</div>',0,''),(47787,15276,'120826','printshop-mobile','margin-bottom','20',0,''),(47788,15277,'120827','printshop-mobile','margin-bottom','20',0,''),(47789,15278,'120828','printshop-mobile','text','<div class=\"heading-3\">##TEXT_NAMES##</div>',0,''),(47790,15279,'120829','printshop-mobile','padding-bottom','20',0,''),(47791,15280,'120830','printshop-mobile','block_type','1',0,''),(47792,15280,'120830','printshop-mobile','padding-left','15',0,''),(47794,15281,'120831','printshop-mobile','margin-bottom','20',0,''),(47795,15282,'120832','printshop-mobile','text','<div class=\"heading-3\">##TEXT_SHIPPING_DETAILS##</div>',0,''),(47796,15283,'120833','printshop-mobile','text','<div class=\"heading-3\">##UPLOAD_PHOTO##</div>',0,''),(47797,15284,'120834','printshop-mobile','margin-bottom','20',0,''),(47798,15284,'120834','printshop-mobile','padding-left','1',0,''),(47799,15285,'120835','printshop-mobile','text','<div class=\"heading-3\">##TEXT_ADDITIONAL_INFORMATION##</div>',0,''),(47800,15286,'120836','printshop-mobile','margin-bottom','20',0,''),(47801,15287,'120837','printshop-mobile','text','<h1>##WEDDING_REGISTRY_FORM_HEADING##</h1>',0,''),(47802,15288,'120838','printshop-mobile','block_type','2',0,''),(47803,15288,'120838','printshop-mobile','margin-bottom','20',0,''),(47804,15290,'120840','printshop-mobile','text-align','right',0,''),(47805,15292,'120842','printshop-mobile','block_type','13',0,''),(47806,15292,'120842','printshop-mobile','margin-bottom','20',0,''),(47807,15293,'120843','printshop-mobile','position','relative',0,''),(47808,15293,'120843','printshop-mobile','margin-top','-100',0,''),(47809,15294,'120844','printshop-mobile','font-family','Varela Round',0,''),(47810,15294,'120844','printshop-mobile','font-size','18',0,''),(47811,15294,'120844','printshop-mobile','margin-bottom','10',0,''),(47812,15295,'120845','printshop-mobile','font-family','Varela Round',0,''),(47813,15295,'120845','printshop-mobile','font-size','30',0,''),(47814,15295,'120845','printshop-mobile','text-transform','uppercase',0,''),(47815,15296,'120846','printshop-mobile','font-weight','700',0,''),(47816,15296,'120846','printshop-mobile','text-align','right',0,''),(47817,15298,'120848','printshop-mobile','block_type','1',0,''),(47818,15299,'120849','printshop-mobile','block_type','6',0,''),(47819,15299,'120849','printshop-mobile','schema','6-3',0,''),(47820,15300,'120850','printshop-mobile','aria_name','account-menu',0,''),(47821,15301,'120851','printshop-mobile','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(47822,15302,'120852','printshop-mobile','margin-bottom','20',0,''),(47823,15303,'120853','printshop-mobile','block_type','1',0,''),(47824,15303,'120853','printshop-mobile','padding-top','20',0,''),(47825,15303,'120853','printshop-mobile','padding-bottom','20',0,''),(47826,15305,'120855','printshop-mobile','padding-top','20',0,''),(47827,15305,'120855','printshop-mobile','padding-bottom','20',0,''),(55610,17790,'118459','deals-mobile','text','##TEXT_PAGE_NOT_FOUND##',0,''),(55611,17790,'118459','deals-mobile','text-align','center',0,''),(55612,17790,'118459','deals-mobile','padding-top','100',0,''),(55613,17790,'118459','deals-mobile','padding-bottom','100',0,''),(55614,17791,'118460','deals-mobile','block_type','1',0,''),(55733,17807,'118476','deals-mobile','block_type','1',0,''),(55852,17823,'118492','deals-mobile','block_type','1',0,''),(55971,17839,'118508','deals-mobile','block_type','1',0,''),(56090,17855,'118524','deals-mobile','block_type','1',0,''),(56209,17871,'118540','deals-mobile','block_type','1',0,''),(56328,17887,'118556','deals-mobile','block_type','1',0,''),(56329,17888,'118557','deals-mobile','block_type','6',0,''),(56330,17888,'118557','deals-mobile','schema','6-3',0,''),(56331,17888,'118557','deals-mobile','schema','6-3',0,'872'),(56332,17889,'118558','deals-mobile','aria_name','account-menu',0,''),(56333,17890,'118559','deals-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(56334,17891,'118560','deals-mobile','link','Order History Info',0,''),(56335,17891,'118560','deals-mobile','text','TEXT_VIEW',0,''),(56336,17891,'118560','deals-mobile','max_orders','3',0,''),(56337,17891,'118560','deals-mobile','link_pay','Order pay',0,''),(56338,17891,'118560','deals-mobile','margin-bottom','30',0,''),(56339,17891,'118560','deals-mobile','text_pay','ORDER_PAY',0,''),(56340,17892,'118561','deals-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(56341,17893,'118562','deals-mobile','block_type','15',0,''),(56342,17893,'118562','deals-mobile','margin-bottom','30',0,''),(56343,17893,'118562','deals-mobile','padding-top','20',0,''),(56344,17893,'118562','deals-mobile','padding-left','20',0,''),(56345,17893,'118562','deals-mobile','padding-right','20',0,''),(56346,17893,'118562','deals-mobile','padding-bottom','20',0,''),(56347,17893,'118562','deals-mobile','border-top-width','1',0,''),(56348,17893,'118562','deals-mobile','border-top-color','#e0e0e0',0,''),(56349,17893,'118562','deals-mobile','border-left-width','1',0,''),(56350,17893,'118562','deals-mobile','border-right-width','1',0,''),(56351,17893,'118562','deals-mobile','border-bottom-width','1',0,''),(56352,17893,'118562','deals-mobile','border-left-color','#e0e0e0',0,''),(56353,17893,'118562','deals-mobile','border-right-color','#e0e0e0',0,''),(56354,17893,'118562','deals-mobile','border-bottom-color','#e0e0e0',0,''),(56355,17893,'118562','deals-mobile','schema','15-2',0,'872'),(56356,17894,'118563','deals-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(56357,17894,'118563','deals-mobile','font-family','trueloaded',0,'3'),(56358,17894,'118563','deals-mobile','content','\\e920',0,'3'),(56359,17894,'118563','deals-mobile','color','#ee4225',0,'3'),(56360,17894,'118563','deals-mobile','font-size','30',0,'3'),(56361,17894,'118563','deals-mobile','text-align','center',0,'3'),(56362,17894,'118563','deals-mobile','margin-bottom','10',0,'3'),(56363,17894,'118563','deals-mobile','text-align','center',0,''),(56364,17894,'118563','deals-mobile','font-size','16',0,''),(56365,17894,'118563','deals-mobile','text-transform','uppercase',0,''),(56366,17894,'118563','deals-mobile','line-height','1',0,'3'),(56368,17895,'118564','deals-mobile','font-family','Varela Round',0,''),(56369,17895,'118564','deals-mobile','color','#ee4225',0,''),(56370,17895,'118564','deals-mobile','font-size','14',0,''),(56371,17895,'118564','deals-mobile','text-align','center',0,''),(56372,17896,'118565','deals-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(56373,17896,'118565','deals-mobile','font-family','trueloaded',0,'3'),(56374,17896,'118565','deals-mobile','content','\\e928',0,'3'),(56375,17896,'118565','deals-mobile','color','#ee4225',0,'3'),(56376,17896,'118565','deals-mobile','font-size','30',0,'3'),(56377,17896,'118565','deals-mobile','text-align','center',0,'3'),(56378,17896,'118565','deals-mobile','text-align','center',0,''),(56379,17896,'118565','deals-mobile','font-size','16',0,''),(56380,17896,'118565','deals-mobile','text-transform','uppercase',0,''),(56381,17896,'118565','deals-mobile','line-height','1',0,'3'),(56383,17897,'118566','deals-mobile','link','download_orders',0,''),(56384,17897,'118566','deals-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(56385,17897,'118566','deals-mobile','hide_link','orders',0,''),(56386,17897,'118566','deals-mobile','text-align','center',0,''),(56387,17897,'118566','deals-mobile','popup','2',0,''),(56388,17897,'118566','deals-mobile','font-size','14',0,''),(56389,17898,'118567','deals-mobile','font-family','Varela Round',0,''),(56390,17898,'118567','deals-mobile','color','#ee4225',0,''),(56391,17898,'118567','deals-mobile','font-size','14',0,''),(56392,17898,'118567','deals-mobile','text-align','center',0,''),(56393,17899,'118568','deals-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(56394,17899,'118568','deals-mobile','font-family','trueloaded',0,'3'),(56395,17899,'118568','deals-mobile','content','\\e922',0,'3'),(56396,17899,'118568','deals-mobile','color','#ee4225',0,'3'),(56397,17899,'118568','deals-mobile','font-size','30',0,'3'),(56398,17899,'118568','deals-mobile','line-height','1',0,'3'),(56399,17899,'118568','deals-mobile','font-size','16',0,''),(56400,17899,'118568','deals-mobile','text-align','center',0,''),(56401,17899,'118568','deals-mobile','text-transform','uppercase',0,''),(56403,17900,'118569','deals-mobile','font-family','Varela Round',0,''),(56404,17900,'118569','deals-mobile','color','#ee4225',0,''),(56405,17900,'118569','deals-mobile','line-height','1',0,''),(56406,17900,'118569','deals-mobile','text-align','center',0,''),(56407,17900,'118569','deals-mobile','font-size','14',0,''),(56408,17901,'118570','deals-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(56409,17901,'118570','deals-mobile','content','\\e994',0,'3'),(56410,17901,'118570','deals-mobile','font-family','trueloaded',0,'3'),(56411,17901,'118570','deals-mobile','color','#ee4225',0,'3'),(56412,17901,'118570','deals-mobile','font-size','30',0,'3'),(56413,17901,'118570','deals-mobile','line-height','1',0,'3'),(56414,17901,'118570','deals-mobile','font-size','16',0,''),(56415,17901,'118570','deals-mobile','text-align','center',0,''),(56416,17901,'118570','deals-mobile','text-transform','uppercase',0,''),(56418,17902,'118571','deals-mobile','link','Gift Certificate',0,''),(56419,17902,'118571','deals-mobile','text','GIFT_CERTIFICATE',0,''),(56420,17902,'118571','deals-mobile','popup','1',0,''),(56421,17902,'118571','deals-mobile','text-align','center',0,''),(56422,17902,'118571','deals-mobile','font-size','14',0,''),(56423,17903,'118572','deals-mobile','font-family','Varela Round',0,''),(56424,17903,'118572','deals-mobile','color','#ee4225',0,''),(56425,17903,'118572','deals-mobile','font-size','14',0,''),(56426,17903,'118572','deals-mobile','text-align','center',0,''),(56427,17904,'118573','deals-mobile','text','TEXT_VIEW_HISTORY',0,''),(56428,17904,'118573','deals-mobile','popup','1',0,''),(56429,17904,'118573','deals-mobile','text-align','center',0,''),(56430,17904,'118573','deals-mobile','link','Points Earnt History',0,''),(56431,17904,'118573','deals-mobile','font-size','14',0,''),(56432,17905,'118574','deals-mobile','font-family','Varela Round',0,''),(56433,17905,'118574','deals-mobile','color','#ee4225',0,''),(56434,17905,'118574','deals-mobile','font-size','14',0,''),(56435,17905,'118574','deals-mobile','text-align','center',0,''),(56436,17906,'118575','deals-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(56437,17906,'118575','deals-mobile','content','\\e990',0,'3'),(56438,17906,'118575','deals-mobile','font-family','trueloaded',0,'3'),(56439,17906,'118575','deals-mobile','font-size','30',0,'3'),(56440,17906,'118575','deals-mobile','text-align','center',0,'3'),(56441,17906,'118575','deals-mobile','line-height','1',0,'3'),(56442,17906,'118575','deals-mobile','color','#ee4225',0,'3'),(56443,17906,'118575','deals-mobile','font-size','16',0,''),(56444,17906,'118575','deals-mobile','text-align','center',0,''),(56445,17906,'118575','deals-mobile','text-transform','uppercase',0,''),(56447,17907,'118576','deals-mobile','block_type','1',0,''),(56448,17908,'118577','deals-mobile','hide_parents','2',0,''),(56449,17909,'118578','deals-mobile','text','<div class=\"heading-3\">##TEXT_GIFT_CARDS##</div>',0,''),(56450,17911,'118580','deals-mobile','block_type','1',0,''),(56451,17911,'118580','deals-mobile','padding-top','70',0,''),(56452,17911,'118580','deals-mobile','padding-right','30',0,''),(56453,17911,'118580','deals-mobile','padding-bottom','30',0,''),(56455,17911,'118580','deals-mobile','padding-left','0',0,''),(56458,17912,'118581','deals-mobile','block_type','1',0,''),(56459,17912,'118581','deals-mobile','padding-right','20',0,''),(56460,17912,'118581','deals-mobile','style_class','account-menu',0,''),(56461,17912,'118581','deals-mobile','padding-top','20',0,''),(56462,17912,'118581','deals-mobile','margin-bottom','20',0,''),(56463,17912,'118581','deals-mobile','background-color','#eeeeee',0,''),(56464,17912,'118581','deals-mobile','padding-left','20',0,''),(56465,17912,'118581','deals-mobile','padding-bottom','20',0,''),(56466,17913,'118582','deals-mobile','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(56467,17913,'118582','deals-mobile','style_class','heading-settings',0,''),(56468,17914,'118583','deals-mobile','link','delete',0,''),(56469,17914,'118583','deals-mobile','text','DELETE_ACCOUNT',0,''),(56470,17915,'118584','deals-mobile','text','TEXT_DASHBOARD',0,''),(56471,17915,'118584','deals-mobile','font-family','Varela Round',0,''),(56472,17915,'118584','deals-mobile','font-size','18',0,''),(56473,17915,'118584','deals-mobile','text-transform','uppercase',0,''),(56474,17916,'118585','deals-mobile','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(56475,17916,'118585','deals-mobile','style_class','heading-saved-lists',0,''),(56476,17917,'118586','deals-mobile','link','logoff',0,''),(56477,17918,'118587','deals-mobile','link','Personal Catalog',0,''),(56478,17918,'118587','deals-mobile','text','TEXT_PERSONAL_CATALOG',0,''),(56479,17918,'118587','deals-mobile','hide_link','personal_catalog',0,''),(56480,17919,'118588','deals-mobile','link','Address Book',0,''),(56481,17919,'118588','deals-mobile','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(56482,17920,'118589','deals-mobile','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(56483,17920,'118589','deals-mobile','style_class','heading-ordered-items',0,''),(56484,17921,'118590','deals-mobile','link','Samples',0,''),(56485,17921,'118590','deals-mobile','text','TEXT_HEADING_SAMPLE_CART',0,''),(56486,17921,'118590','deals-mobile','hide_link','samples',0,''),(56487,17922,'118591','deals-mobile','link','Order History',0,''),(56488,17922,'118591','deals-mobile','text','HEADING_ORDER_HISTORY',0,''),(56489,17922,'118591','deals-mobile','active_link','Order History Info,Order pay',0,''),(56490,17923,'118592','deals-mobile','link','My password',0,''),(56491,17923,'118592','deals-mobile','text','TEXT_MY_PASSWORD',0,''),(56492,17924,'118593','deals-mobile','link','Review',0,''),(56493,17924,'118593','deals-mobile','text','REVIEWS',0,''),(56494,17925,'118594','deals-mobile','link','Account edit',0,''),(56495,17925,'118594','deals-mobile','text','ACCOUNT_EDIT',0,''),(56496,17926,'118595','deals-mobile','link','Quotations',0,''),(56497,17926,'118595','deals-mobile','hide_link','quotations',0,''),(56498,17926,'118595','deals-mobile','text','TEXT_HEADING_QUOTE_CART',0,''),(56499,17927,'118596','deals-mobile','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(56500,17927,'118596','deals-mobile','style_class','heading-settings',0,''),(56501,17928,'118597','deals-mobile','link','trade_form',0,''),(56502,17928,'118597','deals-mobile','text','TRADE_FORM',0,''),(56503,17929,'118598','deals-mobile','block_type','1',0,''),(56504,17930,'118599','deals-mobile','block_type','6',0,''),(56505,17930,'118599','deals-mobile','schema','6-3',0,''),(56506,17930,'118599','deals-mobile','schema','6-3',0,'872'),(56507,17931,'118600','deals-mobile','aria_name','account-menu',0,''),(56508,17933,'118602','deals-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(56509,17934,'118603','deals-mobile','text','CANCEL',0,''),(56510,17934,'118603','deals-mobile','like_button','1',0,''),(56511,17934,'118603','deals-mobile','padding-bottom','20',0,''),(56512,17935,'118604','deals-mobile','block_type','1',0,''),(56513,17936,'118605','deals-mobile','block_type','6',0,''),(56514,17936,'118605','deals-mobile','schema','6-3',0,''),(56515,17936,'118605','deals-mobile','schema','6-3',0,'872'),(56516,17937,'118606','deals-mobile','aria_name','account-menu',0,''),(56517,17938,'118607','deals-mobile','padding-top','15',0,''),(56518,17938,'118607','deals-mobile','padding-bottom','15',0,''),(56519,17938,'118607','deals-mobile','link','Address Book Process',0,''),(56520,17938,'118607','deals-mobile','text','EDIT',0,''),(56521,17938,'118607','deals-mobile','link_add','Address Book Process',0,''),(56522,17938,'118607','deals-mobile','like_button_add','2',0,''),(56523,17938,'118607','deals-mobile','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(56524,17939,'118608','deals-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1><div class=\"info-popup bottom-left\">\n<div><ul><li>##PRIMARY_ADDRESS##<br>##PRIMARY_ADDRESS_DESCRIPTION##<br></li><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(56525,17939,'118608','deals-mobile','text-align','center',0,''),(56526,17940,'118609','deals-mobile','block_type','1',0,''),(56527,17941,'118610','deals-mobile','block_type','6',0,''),(56528,17941,'118610','deals-mobile','schema','6-3',0,''),(56529,17941,'118610','deals-mobile','schema','6-3',0,'872'),(56530,17942,'118611','deals-mobile','aria_name','account-menu',0,''),(56531,17944,'118613','deals-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(56532,17945,'118614','deals-mobile','text','CANCEL',0,''),(56533,17945,'118614','deals-mobile','like_button','1',0,''),(56534,17945,'118614','deals-mobile','padding-bottom','20',0,''),(56535,17945,'118614','deals-mobile','link','Address Book',0,''),(56536,17946,'118615','deals-mobile','block_type','1',0,''),(56537,17946,'118615','deals-mobile','style_class','item-holder',0,''),(56538,17946,'118615','deals-mobile','padding-top','25',0,''),(56539,17946,'118615','deals-mobile','padding-bottom','25',0,''),(56540,17946,'118615','deals-mobile','text-align','left',0,''),(56541,17946,'118615','deals-mobile','border-top-color','#e0e0e0',0,''),(56542,17946,'118615','deals-mobile','border-top-width','1',0,''),(56543,17947,'118616','deals-mobile','block_type','6',0,''),(56544,17948,'118617','deals-mobile','padding-right','20',0,''),(56545,17949,'118618','deals-mobile','clear','none',0,''),(56546,17951,'118620','deals-mobile','block_type','4',0,''),(56547,17952,'118621','deals-mobile','block_type','2',0,''),(56548,17953,'118622','deals-mobile','margin-bottom','7',0,''),(56549,17954,'118623','deals-mobile','clear','none',0,''),(56550,17955,'118624','deals-mobile','margin-bottom','20',0,''),(56551,17955,'118624','deals-mobile','text-align','right',0,''),(56552,17956,'118625','deals-mobile','description_characters','200',0,''),(56553,17956,'118625','deals-mobile','clear','none',0,''),(56554,17956,'118625','deals-mobile','padding-right','20',0,''),(56555,17957,'118626','deals-mobile','block_type','2',0,''),(56556,17958,'118627','deals-mobile','clear','none',0,''),(56557,17960,'118629','deals-mobile','padding-right','20',0,''),(56558,17961,'118630','deals-mobile','block_type','1',0,''),(56559,17961,'118630','deals-mobile','style_class','item-holder',0,''),(56560,17961,'118630','deals-mobile','padding-top','25',0,''),(56561,17961,'118630','deals-mobile','padding-left','25',0,''),(56562,17961,'118630','deals-mobile','padding-right','25',0,''),(56563,17961,'118630','deals-mobile','padding-bottom','25',0,''),(56564,17961,'118630','deals-mobile','text-align','left',0,''),(56565,17963,'118632','deals-mobile','margin-bottom','7',0,''),(56566,17964,'118633','deals-mobile','clear','both',0,''),(56567,17967,'118636','deals-mobile','block_type','1',0,''),(56568,17967,'118636','deals-mobile','style_class','item-holder',0,''),(56569,17967,'118636','deals-mobile','padding-top','25',0,''),(56570,17967,'118636','deals-mobile','padding-left','25',0,''),(56571,17967,'118636','deals-mobile','padding-right','25',0,''),(56572,17967,'118636','deals-mobile','padding-bottom','25',0,''),(56573,17967,'118636','deals-mobile','text-align','left',0,''),(56574,17968,'118637','deals-mobile','block_type','5',0,''),(56575,17971,'118640','deals-mobile','margin-bottom','7',0,''),(56576,17972,'118641','deals-mobile','clear','both',0,''),(56577,17973,'118642','deals-mobile','block_type','1',0,''),(56578,17974,'118643','deals-mobile','block_type','6',0,''),(56579,17974,'118643','deals-mobile','font-weight','400',0,''),(56580,17974,'118643','deals-mobile','schema','6-2',0,''),(56582,17975,'118644','deals-mobile','font-weight','400',0,''),(56583,17975,'118644','deals-mobile','padding-right','40',0,''),(56586,17976,'118645','deals-mobile','block_type','5',0,''),(56587,17976,'118645','deals-mobile','padding-top','10',0,''),(56588,17976,'118645','deals-mobile','padding-bottom','10',0,''),(56589,17976,'118645','deals-mobile','schema','5-2',0,''),(56590,17976,'118645','deals-mobile','border-top-color','#e0e0e0',0,''),(56591,17976,'118645','deals-mobile','border-top-width','1',0,''),(56592,17978,'118647','deals-mobile','float','right',0,''),(56593,17980,'118649','deals-mobile','col_in_row','3',0,''),(56594,17980,'118649','deals-mobile','products_align','left',0,''),(56595,17980,'118649','deals-mobile','font-weight','400',0,''),(56596,17980,'118649','deals-mobile','show_qty_input','0',0,''),(56597,17980,'118649','deals-mobile','listing_type','productListing',0,''),(56598,17980,'118649','deals-mobile','listing_type_rows','no',0,''),(56599,17980,'118649','deals-mobile','show_buy_button_b2b','on',0,''),(56600,17980,'118649','deals-mobile','show_wishlist_button_b2b','1',0,''),(56601,17980,'118649','deals-mobile','show_compare_b2b','1',0,''),(56602,17980,'118649','deals-mobile','show_stock','0',0,''),(56603,17980,'118649','deals-mobile','show_description','0',0,''),(56604,17980,'118649','deals-mobile','show_model','0',0,''),(56605,17980,'118649','deals-mobile','show_properties','0',0,''),(56606,17980,'118649','deals-mobile','show_rating','0',0,''),(56607,17980,'118649','deals-mobile','show_rating_counts','0',0,''),(56608,17980,'118649','deals-mobile','show_price','0',0,''),(56609,17980,'118649','deals-mobile','show_buy_button','0',0,''),(56610,17980,'118649','deals-mobile','show_view_button','0',0,''),(56611,17980,'118649','deals-mobile','show_wishlist_button','0',0,''),(56612,17980,'118649','deals-mobile','show_compare','0',0,''),(56613,17980,'118649','deals-mobile','show_name_rows','0',0,''),(56614,17980,'118649','deals-mobile','show_image_rows','0',0,''),(56615,17980,'118649','deals-mobile','show_stock_rows','0',0,''),(56616,17980,'118649','deals-mobile','show_description_rows','0',0,''),(56617,17980,'118649','deals-mobile','show_model_rows','0',0,''),(56618,17980,'118649','deals-mobile','show_properties_rows','0',0,''),(56619,17980,'118649','deals-mobile','show_rating_rows','0',0,''),(56620,17980,'118649','deals-mobile','show_rating_counts_rows','0',0,''),(56621,17980,'118649','deals-mobile','show_price_rows','0',0,''),(56622,17980,'118649','deals-mobile','show_buy_button_rows','0',0,''),(56623,17980,'118649','deals-mobile','show_qty_input_rows','0',0,''),(56624,17980,'118649','deals-mobile','show_view_button_rows','0',0,''),(56625,17980,'118649','deals-mobile','show_wishlist_button_rows','0',0,''),(56626,17980,'118649','deals-mobile','show_compare_rows','0',0,''),(56627,17980,'118649','deals-mobile','show_name_b2b','0',0,''),(56628,17980,'118649','deals-mobile','show_image_b2b','0',0,''),(56629,17980,'118649','deals-mobile','show_stock_b2b','0',0,''),(56630,17980,'118649','deals-mobile','show_description_b2b','0',0,''),(56631,17980,'118649','deals-mobile','show_model_b2b','0',0,''),(56632,17980,'118649','deals-mobile','show_properties_b2b','0',0,''),(56633,17980,'118649','deals-mobile','show_rating_b2b','0',0,''),(56634,17980,'118649','deals-mobile','show_rating_counts_b2b','0',0,''),(56635,17980,'118649','deals-mobile','show_price_b2b','0',0,''),(56636,17980,'118649','deals-mobile','show_qty_input_b2b','0',0,''),(56637,17980,'118649','deals-mobile','show_view_button_b2b','0',0,''),(56638,17980,'118649','deals-mobile','show_attributes_b2b','0',0,''),(56639,17980,'118649','deals-mobile','items_on_page','9',0,''),(56642,17980,'118649','deals-mobile','product_names_teg','h2',0,''),(56643,17981,'118650','deals-mobile','listing_type','productListing',0,''),(56644,17982,'118651','deals-mobile','block_type','1',0,''),(56645,17982,'118651','deals-mobile','padding-top','10',0,''),(56646,17982,'118651','deals-mobile','padding-bottom','10',0,''),(56647,17982,'118651','deals-mobile','border-bottom-width','1',0,''),(56648,17982,'118651','deals-mobile','border-bottom-color','#e0e0e0',0,''),(56649,17982,'118651','deals-mobile','margin-left','0',0,''),(56650,17982,'118651','deals-mobile','margin-right','0',0,''),(56651,17983,'118652','deals-mobile','float','right',0,''),(56652,17983,'118652','deals-mobile','display','none',0,''),(56653,17984,'118653','deals-mobile','margin-right','20',0,''),(56654,17984,'118653','deals-mobile','float','right',0,''),(56655,17984,'118653','deals-mobile','clear','none',0,''),(56656,17984,'118653','deals-mobile','display','none',0,''),(56657,17985,'118654','deals-mobile','float','left',0,''),(56658,17985,'118654','deals-mobile','clear','none',0,''),(56659,17985,'118654','deals-mobile','margin-left','20',0,''),(56660,17985,'118654','deals-mobile','display','none',0,''),(56661,17986,'118655','deals-mobile','float','left',0,''),(56662,17986,'118655','deals-mobile','clear','none',0,''),(56663,17986,'118655','deals-mobile','sort_pos_3','1',0,''),(56664,17986,'118655','deals-mobile','sort_pos_4','2',0,''),(56665,17986,'118655','deals-mobile','sort_pos_10','3',0,''),(56666,17986,'118655','deals-mobile','sort_pos_9','4',0,''),(56667,17986,'118655','deals-mobile','sort_pos_11','5',0,''),(56668,17986,'118655','deals-mobile','sort_pos_12','6',0,''),(56669,17986,'118655','deals-mobile','sort_pos_14','7',0,''),(56670,17986,'118655','deals-mobile','sort_pos_13','8',0,''),(56671,17986,'118655','deals-mobile','sort_pos_8','9',0,''),(56672,17986,'118655','deals-mobile','sort_pos_7','10',0,''),(56673,17986,'118655','deals-mobile','sort_pos_2','11',0,''),(56674,17986,'118655','deals-mobile','sort_pos_1','12',0,''),(56675,17986,'118655','deals-mobile','sort_pos_6','13',0,''),(56676,17986,'118655','deals-mobile','sort_pos_5','14',0,''),(56677,17986,'118655','deals-mobile','sort_pos_0','15',0,''),(56678,17986,'118655','deals-mobile','sort_hide_10','1',0,''),(56679,17986,'118655','deals-mobile','sort_hide_9','1',0,''),(56680,17986,'118655','deals-mobile','hide_icons','1',0,''),(56681,17986,'118655','deals-mobile','sort_hide_16','1',0,''),(56682,17986,'118655','deals-mobile','sort_hide_15','1',0,''),(56683,17986,'118655','deals-mobile','sort_hide_3','0',0,''),(56684,17986,'118655','deals-mobile','sort_hide_4','0',0,''),(56685,17986,'118655','deals-mobile','sort_hide_11','1',0,''),(56686,17986,'118655','deals-mobile','sort_hide_12','1',0,''),(56687,17986,'118655','deals-mobile','sort_hide_14','1',0,''),(56688,17986,'118655','deals-mobile','sort_hide_13','1',0,''),(56689,17986,'118655','deals-mobile','sort_hide_8','0',0,''),(56690,17986,'118655','deals-mobile','sort_hide_7','0',0,''),(56691,17986,'118655','deals-mobile','sort_hide_2','1',0,''),(56692,17986,'118655','deals-mobile','sort_hide_1','1',0,''),(56693,17986,'118655','deals-mobile','sort_hide_6','1',0,''),(56694,17986,'118655','deals-mobile','sort_hide_5','1',0,''),(56695,17986,'118655','deals-mobile','sort_hide_0','1',0,''),(56696,17989,'118658','deals-mobile','block_type','1',0,''),(56697,17990,'118659','deals-mobile','block_type','7',0,''),(56698,17990,'118659','deals-mobile','schema','7-2',0,'890'),(56699,17991,'118660','deals-mobile','padding-top','20',0,''),(56700,17991,'118660','deals-mobile','padding-right','20',0,''),(56701,17992,'118661','deals-mobile','blog_sidebar','1',0,''),(56702,17992,'118661','deals-mobile','padding-top','20',0,''),(56703,17992,'118661','deals-mobile','padding-left','20',0,''),(56704,17993,'118662','deals-mobile','block_type','1',0,''),(56705,17994,'118663','deals-mobile','item_tag','h2',0,''),(56706,17994,'118663','deals-mobile','hTagsInline','inline',0,''),(56707,17998,'118667','deals-mobile','block_type','1',0,''),(56708,17998,'118667','deals-mobile','schema','4-1',0,''),(56710,17998,'118667','deals-mobile','schema','4-1',0,'872'),(56711,17999,'118668','deals-mobile','block_type','1',0,''),(56712,17999,'118668','deals-mobile','background-color','#ffffff',0,''),(56713,17999,'118668','deals-mobile','padding-top','20',0,''),(56714,17999,'118668','deals-mobile','padding-bottom','20',0,''),(56715,17999,'118668','deals-mobile','margin-bottom','30',0,''),(56716,18000,'118669','deals-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(56717,18000,'118669','deals-mobile','style_class','bell-ico',0,''),(56718,18001,'118670','deals-mobile','col_in_row','3',0,''),(56719,18001,'118670','deals-mobile','show_description','1',0,''),(56720,18001,'118670','deals-mobile','show_model','1',0,''),(56721,18001,'118670','deals-mobile','show_properties','1',0,''),(56722,18001,'118670','deals-mobile','show_rating','1',0,''),(56723,18001,'118670','deals-mobile','show_rating_counts','1',0,''),(56724,18001,'118670','deals-mobile','show_qty_input','1',0,''),(56725,18001,'118670','deals-mobile','show_view_button','1',0,''),(56726,18001,'118670','deals-mobile','show_wishlist_button','1',0,''),(56727,18001,'118670','deals-mobile','show_compare','1',0,''),(56728,18001,'118670','deals-mobile','view_as','carousel',0,''),(56729,18001,'118670','deals-mobile','hide_parents','2',0,''),(56730,18002,'118671','deals-mobile','block_type','1',0,''),(56731,18002,'118671','deals-mobile','background-color','#ffffff',0,''),(56732,18002,'118671','deals-mobile','margin-bottom','30',0,''),(56733,18003,'118672','deals-mobile','padding-top','20',0,''),(56734,18003,'118672','deals-mobile','padding-bottom','20',0,''),(56735,18004,'118673','deals-mobile','block_type','2',0,''),(56736,18004,'118673','deals-mobile','padding-bottom','20',0,''),(56737,18004,'118673','deals-mobile','padding-top','20',0,''),(56738,18004,'118673','deals-mobile','border-bottom-color','#e0e0e0',0,''),(56739,18004,'118673','deals-mobile','border-bottom-width','1',0,''),(56740,18004,'118673','deals-mobile','schema','2-2',0,''),(56741,18005,'118674','deals-mobile','padding-top','22',0,''),(56742,18006,'118675','deals-mobile','float','right',0,''),(56743,18006,'118675','deals-mobile','padding-top','26',0,''),(56744,18007,'118676','deals-mobile','float','left',0,''),(56745,18008,'118677','deals-mobile','block_type','1',0,''),(56746,18008,'118677','deals-mobile','padding-top','20',0,''),(56747,18008,'118677','deals-mobile','padding-bottom','20',0,''),(56748,18008,'118677','deals-mobile','background-color','#ffffff',0,''),(56749,18008,'118677','deals-mobile','margin-bottom','30',0,''),(56750,18009,'118678','deals-mobile','hide_parents','2',0,''),(56751,18010,'118679','deals-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(56752,18011,'118680','deals-mobile','block_type','1',0,''),(56753,18011,'118680','deals-mobile','background-color','#ffffff',0,''),(56754,18011,'118680','deals-mobile','padding-top','20',0,''),(56755,18011,'118680','deals-mobile','padding-bottom','20',0,''),(56756,18011,'118680','deals-mobile','margin-bottom','30',0,''),(56757,18011,'118680','deals-mobile','style_class','closeable-box',0,''),(56758,18012,'118681','deals-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(56759,18012,'118681','deals-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(56760,18013,'118682','deals-mobile','block_type','1',0,''),(56761,18013,'118682','deals-mobile','font-weight','400',0,''),(56762,18013,'118682','deals-mobile','schema','2-2',0,''),(56763,18013,'118682','deals-mobile','style_class','closeable-content',0,''),(56764,18013,'118682','deals-mobile','padding-top','10',0,''),(56765,18014,'118683','deals-mobile','font-weight','400',0,''),(56766,18014,'118683','deals-mobile','padding-top','12',0,''),(56767,18014,'118683','deals-mobile','padding-left','0',0,''),(56768,18017,'118686','deals-mobile','block_type','1',0,''),(56769,18017,'118686','deals-mobile','background-color','#ffffff',0,''),(56770,18017,'118686','deals-mobile','padding-top','20',0,''),(56771,18017,'118686','deals-mobile','padding-left','25',0,''),(56772,18017,'118686','deals-mobile','padding-right','25',0,''),(56773,18017,'118686','deals-mobile','padding-bottom','20',0,''),(56774,18017,'118686','deals-mobile','margin-bottom','30',0,''),(56775,18017,'118686','deals-mobile','style_class','closeable-box',0,''),(56776,18017,'118686','deals-mobile','display','none',0,''),(56778,18018,'118687','deals-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(56779,18018,'118687','deals-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(56780,18019,'118688','deals-mobile','font-weight','normal',0,''),(56781,18019,'118688','deals-mobile','style_class','closeable-content',0,''),(56782,18019,'118688','deals-mobile','padding-top','10',0,''),(56783,18019,'118688','deals-mobile','hide_parents','2',0,''),(56784,18020,'118689','deals-mobile','style_class','order-summary',0,''),(56785,18020,'118689','deals-mobile','block_type','1',0,''),(56786,18020,'118689','deals-mobile','margin-left','30',0,''),(56788,18020,'118689','deals-mobile','margin-bottom','30',0,''),(56789,18021,'118690','deals-mobile','block_type','1',0,''),(56790,18021,'118690','deals-mobile','padding-bottom','20',0,''),(56791,18022,'118691','deals-mobile','font-weight','400',0,''),(56792,18022,'118691','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',1,''),(56793,18022,'118691','deals-mobile','padding-top','20',0,''),(56794,18022,'118691','deals-mobile','padding-bottom','10',0,''),(56795,18023,'118692','deals-mobile','font-weight','400',0,''),(56796,18023,'118692','deals-mobile','box_align','4',0,''),(56797,18023,'118692','deals-mobile','text-align','center',0,''),(56798,18023,'118692','deals-mobile','float','none',0,''),(56799,18023,'118692','deals-mobile','width','100',0,''),(56800,18023,'118692','deals-mobile','width_measure','%',0,''),(56801,18025,'118694','deals-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(56802,18026,'118695','deals-mobile','block_type','1',0,''),(56803,18026,'118695','deals-mobile','font-weight','normal',0,''),(56804,18026,'118695','deals-mobile','padding-top','20',0,''),(56805,18026,'118695','deals-mobile','background-color','#eeeeee',0,''),(56806,18028,'118697','deals-mobile','block_type','4',0,''),(56807,18028,'118697','deals-mobile','schema','4-1',0,''),(56809,18029,'118698','deals-mobile','block_type','1',0,''),(56810,18029,'118698','deals-mobile','background-color','#ffffff',0,''),(56811,18029,'118698','deals-mobile','padding-top','20',0,''),(56812,18029,'118698','deals-mobile','padding-bottom','20',0,''),(56813,18029,'118698','deals-mobile','padding-left','25',0,''),(56814,18029,'118698','deals-mobile','padding-right','25',0,''),(56815,18029,'118698','deals-mobile','margin-bottom','30',0,''),(56816,18030,'118699','deals-mobile','col_in_row','3',0,''),(56817,18030,'118699','deals-mobile','show_description','1',0,''),(56818,18030,'118699','deals-mobile','show_model','1',0,''),(56819,18030,'118699','deals-mobile','show_properties','1',0,''),(56820,18030,'118699','deals-mobile','show_rating','1',0,''),(56821,18030,'118699','deals-mobile','show_rating_counts','1',0,''),(56822,18030,'118699','deals-mobile','show_qty_input','1',0,''),(56823,18030,'118699','deals-mobile','show_view_button','1',0,''),(56824,18030,'118699','deals-mobile','show_wishlist_button','1',0,''),(56825,18030,'118699','deals-mobile','show_compare','1',0,''),(56826,18030,'118699','deals-mobile','view_as','carousel',0,''),(56827,18030,'118699','deals-mobile','hide_parents','2',0,''),(56828,18031,'118700','deals-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(56829,18031,'118700','deals-mobile','style_class','bell-ico',0,''),(56830,18032,'118701','deals-mobile','block_type','1',0,''),(56831,18032,'118701','deals-mobile','background-color','#ffffff',0,''),(56832,18032,'118701','deals-mobile','margin-bottom','30',0,''),(56833,18033,'118702','deals-mobile','padding-top','20',0,''),(56834,18033,'118702','deals-mobile','padding-left','25',0,''),(56835,18033,'118702','deals-mobile','padding-right','25',0,''),(56836,18033,'118702','deals-mobile','padding-bottom','20',0,''),(56837,18034,'118703','deals-mobile','block_type','2',0,''),(56838,18034,'118703','deals-mobile','padding-bottom','20',0,''),(56839,18034,'118703','deals-mobile','padding-top','20',0,''),(56840,18034,'118703','deals-mobile','padding-left','25',0,''),(56841,18034,'118703','deals-mobile','padding-right','25',0,''),(56842,18034,'118703','deals-mobile','border-bottom-color','#e0e0e0',0,''),(56843,18034,'118703','deals-mobile','border-bottom-width','1',0,''),(56844,18034,'118703','deals-mobile','schema','2-2',0,''),(56845,18035,'118704','deals-mobile','float','left',0,''),(56846,18036,'118705','deals-mobile','text-align','right',0,''),(56847,18036,'118705','deals-mobile','clear','none',0,''),(56848,18036,'118705','deals-mobile','float','right',0,''),(56849,18036,'118705','deals-mobile','padding-top','22',0,''),(56850,18037,'118706','deals-mobile','float','right',0,''),(56851,18037,'118706','deals-mobile','padding-top','26',0,''),(56852,18038,'118707','deals-mobile','block_type','1',0,''),(56853,18038,'118707','deals-mobile','padding-top','20',0,''),(56854,18038,'118707','deals-mobile','padding-bottom','20',0,''),(56855,18038,'118707','deals-mobile','padding-left','25',0,''),(56856,18038,'118707','deals-mobile','padding-right','25',0,''),(56857,18038,'118707','deals-mobile','background-color','#ffffff',0,''),(56858,18038,'118707','deals-mobile','margin-bottom','30',0,''),(56859,18039,'118708','deals-mobile','hide_parents','2',0,''),(56860,18040,'118709','deals-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(56861,18041,'118710','deals-mobile','block_type','1',0,''),(56862,18041,'118710','deals-mobile','background-color','#ffffff',0,''),(56863,18041,'118710','deals-mobile','padding-top','20',0,''),(56864,18041,'118710','deals-mobile','padding-bottom','20',0,''),(56865,18041,'118710','deals-mobile','padding-left','25',0,''),(56866,18041,'118710','deals-mobile','padding-right','25',0,''),(56867,18041,'118710','deals-mobile','margin-bottom','30',0,''),(56868,18041,'118710','deals-mobile','style_class','closeable-box',0,''),(56869,18042,'118711','deals-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(56870,18042,'118711','deals-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(56871,18043,'118712','deals-mobile','block_type','3',0,''),(56872,18043,'118712','deals-mobile','font-weight','400',0,''),(56873,18043,'118712','deals-mobile','schema','2-2',0,''),(56874,18043,'118712','deals-mobile','style_class','closeable-content',0,''),(56875,18043,'118712','deals-mobile','padding-top','10',0,''),(56876,18044,'118713','deals-mobile','font-weight','400',0,''),(56877,18044,'118713','deals-mobile','padding-top','12',0,''),(56878,18044,'118713','deals-mobile','padding-left','0',0,''),(56879,18047,'118716','deals-mobile','block_type','1',0,''),(56880,18047,'118716','deals-mobile','background-color','#ffffff',0,''),(56881,18047,'118716','deals-mobile','padding-top','20',0,''),(56882,18047,'118716','deals-mobile','padding-left','25',0,''),(56883,18047,'118716','deals-mobile','padding-right','25',0,''),(56884,18047,'118716','deals-mobile','padding-bottom','20',0,''),(56885,18047,'118716','deals-mobile','margin-bottom','30',0,''),(56886,18047,'118716','deals-mobile','style_class','closeable-box',0,''),(56887,18047,'118716','deals-mobile','display','none',0,''),(56889,18048,'118717','deals-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(56890,18048,'118717','deals-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(56891,18049,'118718','deals-mobile','font-weight','normal',0,''),(56892,18049,'118718','deals-mobile','style_class','closeable-content',0,''),(56893,18049,'118718','deals-mobile','padding-top','10',0,''),(56894,18049,'118718','deals-mobile','hide_parents','2',0,''),(56895,18050,'118719','deals-mobile','style_class','order-summary',0,''),(56896,18050,'118719','deals-mobile','block_type','1',0,''),(56897,18050,'118719','deals-mobile','margin-left','30',0,''),(56899,18050,'118719','deals-mobile','margin-bottom','30',0,''),(56900,18051,'118720','deals-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(56901,18052,'118721','deals-mobile','block_type','1',0,''),(56902,18052,'118721','deals-mobile','padding-left','20',0,''),(56903,18052,'118721','deals-mobile','padding-right','20',0,''),(56904,18052,'118721','deals-mobile','padding-bottom','20',0,''),(56905,18053,'118722','deals-mobile','font-weight','400',0,''),(56906,18053,'118722','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',1,''),(56907,18053,'118722','deals-mobile','padding-top','20',0,''),(56908,18053,'118722','deals-mobile','padding-bottom','10',0,''),(56909,18054,'118723','deals-mobile','font-weight','400',0,''),(56910,18054,'118723','deals-mobile','box_align','4',0,''),(56911,18054,'118723','deals-mobile','text-align','center',0,''),(56912,18054,'118723','deals-mobile','float','none',0,''),(56913,18054,'118723','deals-mobile','width','100',0,''),(56914,18054,'118723','deals-mobile','width_measure','%',0,''),(56915,18056,'118725','deals-mobile','block_type','1',0,''),(56916,18059,'118728','deals-mobile','block_type','1',0,''),(56917,18060,'118729','deals-mobile','col_in_row','2',0,''),(56918,18060,'118729','deals-mobile','products_align','left',0,''),(56919,18060,'118729','deals-mobile','font-weight','400',0,''),(56920,18060,'118729','deals-mobile','show_qty_input','1',0,''),(56921,18060,'118729','deals-mobile','listing_type','productListing',0,''),(56922,18060,'118729','deals-mobile','listing_type_rows','type-1_2',0,''),(56923,18060,'118729','deals-mobile','show_buy_button_b2b','on',0,''),(56924,18060,'118729','deals-mobile','show_wishlist_button_b2b','1',0,''),(56925,18060,'118729','deals-mobile','show_compare_b2b','1',0,''),(56926,18060,'118729','deals-mobile','listing_type_b2b','type-1_3',0,''),(56927,18060,'118729','deals-mobile','show_name','0',0,''),(56928,18060,'118729','deals-mobile','show_image','0',0,''),(56929,18060,'118729','deals-mobile','show_stock','0',0,''),(56930,18060,'118729','deals-mobile','show_description','1',0,''),(56931,18060,'118729','deals-mobile','show_model','1',0,''),(56932,18060,'118729','deals-mobile','show_properties','1',0,''),(56933,18060,'118729','deals-mobile','show_rating_counts','1',0,''),(56934,18060,'118729','deals-mobile','show_price','0',0,''),(56935,18060,'118729','deals-mobile','show_buy_button','1',0,''),(56936,18060,'118729','deals-mobile','show_view_button','1',0,''),(56937,18060,'118729','deals-mobile','show_wishlist_button','1',0,''),(56938,18060,'118729','deals-mobile','show_compare','1',0,''),(56939,18060,'118729','deals-mobile','show_name_rows','0',0,''),(56940,18060,'118729','deals-mobile','show_image_rows','0',0,''),(56941,18060,'118729','deals-mobile','show_stock_rows','0',0,''),(56942,18060,'118729','deals-mobile','show_description_rows','0',0,''),(56943,18060,'118729','deals-mobile','show_model_rows','0',0,''),(56944,18060,'118729','deals-mobile','show_properties_rows','0',0,''),(56945,18060,'118729','deals-mobile','show_rating_rows','0',0,''),(56946,18060,'118729','deals-mobile','show_rating_counts_rows','0',0,''),(56947,18060,'118729','deals-mobile','show_price_rows','0',0,''),(56948,18060,'118729','deals-mobile','show_buy_button_rows','0',0,''),(56949,18060,'118729','deals-mobile','show_qty_input_rows','0',0,''),(56950,18060,'118729','deals-mobile','show_view_button_rows','0',0,''),(56951,18060,'118729','deals-mobile','show_wishlist_button_rows','0',0,''),(56952,18060,'118729','deals-mobile','show_compare_rows','0',0,''),(56953,18060,'118729','deals-mobile','show_name_b2b','0',0,''),(56954,18060,'118729','deals-mobile','show_image_b2b','0',0,''),(56955,18060,'118729','deals-mobile','show_stock_b2b','0',0,''),(56956,18060,'118729','deals-mobile','show_description_b2b','0',0,''),(56957,18060,'118729','deals-mobile','show_model_b2b','0',0,''),(56958,18060,'118729','deals-mobile','show_properties_b2b','0',0,''),(56959,18060,'118729','deals-mobile','show_rating_b2b','0',0,''),(56960,18060,'118729','deals-mobile','show_rating_counts_b2b','0',0,''),(56961,18060,'118729','deals-mobile','show_price_b2b','0',0,''),(56962,18060,'118729','deals-mobile','show_qty_input_b2b','0',0,''),(56963,18060,'118729','deals-mobile','show_view_button_b2b','0',0,''),(56964,18060,'118729','deals-mobile','show_attributes_b2b','0',0,''),(56965,18060,'118729','deals-mobile','items_on_page','10',0,''),(56966,18060,'118729','deals-mobile','product_names_teg','h2',0,''),(56967,18061,'118730','deals-mobile','block_type','2',0,''),(56968,18061,'118730','deals-mobile','margin-bottom','20',0,''),(56969,18062,'118731','deals-mobile','sort_pos_3','1',0,''),(56970,18062,'118731','deals-mobile','sort_pos_4','2',0,''),(56971,18062,'118731','deals-mobile','sort_pos_10','5',0,''),(56972,18062,'118731','deals-mobile','sort_pos_9','6',0,''),(56973,18062,'118731','deals-mobile','sort_pos_11','7',0,''),(56974,18062,'118731','deals-mobile','sort_pos_12','8',0,''),(56975,18062,'118731','deals-mobile','sort_pos_14','9',0,''),(56976,18062,'118731','deals-mobile','sort_pos_13','10',0,''),(56977,18062,'118731','deals-mobile','sort_pos_8','11',0,''),(56978,18062,'118731','deals-mobile','sort_pos_7','12',0,''),(56979,18062,'118731','deals-mobile','sort_pos_2','13',0,''),(56980,18062,'118731','deals-mobile','sort_pos_1','14',0,''),(56981,18062,'118731','deals-mobile','sort_pos_6','15',0,''),(56982,18062,'118731','deals-mobile','sort_pos_5','16',0,''),(56983,18062,'118731','deals-mobile','sort_pos_0','17',0,''),(56984,18062,'118731','deals-mobile','sort_hide_10','1',0,''),(56985,18062,'118731','deals-mobile','sort_hide_9','1',0,''),(56986,18062,'118731','deals-mobile','sort_pos_15','4',0,''),(56987,18062,'118731','deals-mobile','sort_pos_16','3',0,''),(56988,18062,'118731','deals-mobile','sort_hide_3','0',0,''),(56989,18062,'118731','deals-mobile','sort_hide_4','0',0,''),(56990,18062,'118731','deals-mobile','sort_hide_16','1',0,''),(56991,18062,'118731','deals-mobile','sort_hide_15','1',0,''),(56992,18062,'118731','deals-mobile','sort_hide_11','0',0,''),(56993,18062,'118731','deals-mobile','sort_hide_12','0',0,''),(56994,18062,'118731','deals-mobile','sort_hide_14','0',0,''),(56995,18062,'118731','deals-mobile','sort_hide_13','0',0,''),(56996,18062,'118731','deals-mobile','sort_hide_8','0',0,''),(56997,18062,'118731','deals-mobile','sort_hide_7','0',0,''),(56998,18062,'118731','deals-mobile','sort_hide_2','0',0,''),(56999,18062,'118731','deals-mobile','sort_hide_1','0',0,''),(57000,18062,'118731','deals-mobile','sort_hide_6','0',0,''),(57001,18062,'118731','deals-mobile','sort_hide_5','0',0,''),(57002,18062,'118731','deals-mobile','sort_hide_0','0',0,''),(57003,18063,'118732','deals-mobile','text-align','right',0,''),(57004,18063,'118732','deals-mobile','padding-top','10',0,''),(57005,18064,'118733','deals-mobile','text-align','center',0,''),(57006,18064,'118733','deals-mobile','margin-bottom','20',0,''),(57007,18070,'118739','deals-mobile','block_type','1',0,''),(57008,18072,'118741','deals-mobile','block_type','6',0,''),(57009,18072,'118741','deals-mobile','font-weight','400',0,''),(57010,18072,'118741','deals-mobile','schema','6-2',0,''),(57012,18073,'118742','deals-mobile','font-weight','400',0,''),(57013,18073,'118742','deals-mobile','padding-right','40',0,''),(57016,18075,'118744','deals-mobile','col_in_row','3',0,''),(57017,18075,'118744','deals-mobile','products_align','left',0,''),(57018,18075,'118744','deals-mobile','font-weight','400',0,''),(57019,18075,'118744','deals-mobile','show_qty_input','0',0,''),(57020,18075,'118744','deals-mobile','listing_type','productListing',0,''),(57021,18075,'118744','deals-mobile','listing_type_rows','no',0,''),(57022,18075,'118744','deals-mobile','show_buy_button_b2b','on',0,''),(57023,18075,'118744','deals-mobile','show_wishlist_button_b2b','1',0,''),(57024,18075,'118744','deals-mobile','show_compare_b2b','1',0,''),(57025,18075,'118744','deals-mobile','show_stock','0',0,''),(57026,18075,'118744','deals-mobile','show_description','0',0,''),(57027,18075,'118744','deals-mobile','show_model','0',0,''),(57028,18075,'118744','deals-mobile','show_properties','0',0,''),(57029,18075,'118744','deals-mobile','show_rating','0',0,''),(57030,18075,'118744','deals-mobile','show_rating_counts','0',0,''),(57031,18075,'118744','deals-mobile','show_price','0',0,''),(57032,18075,'118744','deals-mobile','show_buy_button','0',0,''),(57033,18075,'118744','deals-mobile','show_view_button','0',0,''),(57034,18075,'118744','deals-mobile','show_wishlist_button','0',0,''),(57035,18075,'118744','deals-mobile','show_compare','0',0,''),(57036,18075,'118744','deals-mobile','show_name_rows','0',0,''),(57037,18075,'118744','deals-mobile','show_image_rows','0',0,''),(57038,18075,'118744','deals-mobile','show_stock_rows','0',0,''),(57039,18075,'118744','deals-mobile','show_description_rows','0',0,''),(57040,18075,'118744','deals-mobile','show_model_rows','0',0,''),(57041,18075,'118744','deals-mobile','show_properties_rows','0',0,''),(57042,18075,'118744','deals-mobile','show_rating_rows','0',0,''),(57043,18075,'118744','deals-mobile','show_rating_counts_rows','0',0,''),(57044,18075,'118744','deals-mobile','show_price_rows','0',0,''),(57045,18075,'118744','deals-mobile','show_buy_button_rows','0',0,''),(57046,18075,'118744','deals-mobile','show_qty_input_rows','0',0,''),(57047,18075,'118744','deals-mobile','show_view_button_rows','0',0,''),(57048,18075,'118744','deals-mobile','show_wishlist_button_rows','0',0,''),(57049,18075,'118744','deals-mobile','show_compare_rows','0',0,''),(57050,18075,'118744','deals-mobile','show_name_b2b','0',0,''),(57051,18075,'118744','deals-mobile','show_image_b2b','0',0,''),(57052,18075,'118744','deals-mobile','show_stock_b2b','0',0,''),(57053,18075,'118744','deals-mobile','show_description_b2b','0',0,''),(57054,18075,'118744','deals-mobile','show_model_b2b','0',0,''),(57055,18075,'118744','deals-mobile','show_properties_b2b','0',0,''),(57056,18075,'118744','deals-mobile','show_rating_b2b','0',0,''),(57057,18075,'118744','deals-mobile','show_rating_counts_b2b','0',0,''),(57058,18075,'118744','deals-mobile','show_price_b2b','0',0,''),(57059,18075,'118744','deals-mobile','show_qty_input_b2b','0',0,''),(57060,18075,'118744','deals-mobile','show_view_button_b2b','0',0,''),(57061,18075,'118744','deals-mobile','show_attributes_b2b','0',0,''),(57062,18075,'118744','deals-mobile','items_on_page','9',0,''),(57065,18075,'118744','deals-mobile','product_names_teg','h2',0,''),(57066,18076,'118745','deals-mobile','block_type','1',0,''),(57067,18076,'118745','deals-mobile','padding-top','10',0,''),(57068,18076,'118745','deals-mobile','padding-bottom','10',0,''),(57069,18076,'118745','deals-mobile','border-bottom-width','1',0,''),(57070,18076,'118745','deals-mobile','border-bottom-color','#e0e0e0',0,''),(57071,18076,'118745','deals-mobile','margin-left','0',0,''),(57072,18076,'118745','deals-mobile','margin-right','0',0,''),(57073,18077,'118746','deals-mobile','float','left',0,''),(57074,18077,'118746','deals-mobile','clear','none',0,''),(57075,18077,'118746','deals-mobile','sort_pos_3','1',0,''),(57076,18077,'118746','deals-mobile','sort_pos_4','2',0,''),(57077,18077,'118746','deals-mobile','sort_pos_10','3',0,''),(57078,18077,'118746','deals-mobile','sort_pos_9','4',0,''),(57079,18077,'118746','deals-mobile','sort_pos_11','5',0,''),(57080,18077,'118746','deals-mobile','sort_pos_12','6',0,''),(57081,18077,'118746','deals-mobile','sort_pos_14','7',0,''),(57082,18077,'118746','deals-mobile','sort_pos_13','8',0,''),(57083,18077,'118746','deals-mobile','sort_pos_8','9',0,''),(57084,18077,'118746','deals-mobile','sort_pos_7','10',0,''),(57085,18077,'118746','deals-mobile','sort_pos_2','11',0,''),(57086,18077,'118746','deals-mobile','sort_pos_1','12',0,''),(57087,18077,'118746','deals-mobile','sort_pos_6','13',0,''),(57088,18077,'118746','deals-mobile','sort_pos_5','14',0,''),(57089,18077,'118746','deals-mobile','sort_pos_0','15',0,''),(57090,18077,'118746','deals-mobile','sort_hide_10','1',0,''),(57091,18077,'118746','deals-mobile','sort_hide_9','1',0,''),(57092,18077,'118746','deals-mobile','hide_icons','1',0,''),(57093,18077,'118746','deals-mobile','sort_hide_16','1',0,''),(57094,18077,'118746','deals-mobile','sort_hide_15','1',0,''),(57095,18077,'118746','deals-mobile','sort_hide_3','0',0,''),(57096,18077,'118746','deals-mobile','sort_hide_4','0',0,''),(57097,18077,'118746','deals-mobile','sort_hide_11','1',0,''),(57098,18077,'118746','deals-mobile','sort_hide_12','1',0,''),(57099,18077,'118746','deals-mobile','sort_hide_14','1',0,''),(57100,18077,'118746','deals-mobile','sort_hide_13','1',0,''),(57101,18077,'118746','deals-mobile','sort_hide_8','0',0,''),(57102,18077,'118746','deals-mobile','sort_hide_7','0',0,''),(57103,18077,'118746','deals-mobile','sort_hide_2','1',0,''),(57104,18077,'118746','deals-mobile','sort_hide_1','1',0,''),(57105,18077,'118746','deals-mobile','sort_hide_6','1',0,''),(57106,18077,'118746','deals-mobile','sort_hide_5','1',0,''),(57107,18077,'118746','deals-mobile','sort_hide_0','1',0,''),(57108,18078,'118747','deals-mobile','float','left',0,''),(57109,18078,'118747','deals-mobile','clear','none',0,''),(57110,18078,'118747','deals-mobile','margin-left','20',0,''),(57111,18078,'118747','deals-mobile','display','none',0,''),(57112,18079,'118748','deals-mobile','margin-right','20',0,''),(57113,18079,'118748','deals-mobile','float','right',0,''),(57114,18079,'118748','deals-mobile','clear','none',0,''),(57115,18079,'118748','deals-mobile','display','none',0,''),(57116,18080,'118749','deals-mobile','float','right',0,''),(57117,18080,'118749','deals-mobile','display','none',0,''),(57118,18081,'118750','deals-mobile','listing_type','productListing',0,''),(57119,18083,'118752','deals-mobile','block_type','5',0,''),(57120,18083,'118752','deals-mobile','padding-top','10',0,''),(57121,18083,'118752','deals-mobile','padding-bottom','10',0,''),(57122,18083,'118752','deals-mobile','schema','5-2',0,''),(57123,18083,'118752','deals-mobile','border-top-color','#e0e0e0',0,''),(57124,18083,'118752','deals-mobile','border-top-width','1',0,''),(57125,18085,'118754','deals-mobile','float','right',0,''),(57126,18086,'118755','deals-mobile','block_type','1',0,''),(57127,18088,'118757','deals-mobile','block_type','5',0,''),(57128,18088,'118757','deals-mobile','padding-top','10',0,''),(57129,18088,'118757','deals-mobile','padding-bottom','10',0,''),(57130,18088,'118757','deals-mobile','schema','5-2',0,''),(57131,18088,'118757','deals-mobile','border-top-color','#e0e0e0',0,''),(57132,18088,'118757','deals-mobile','border-top-width','1',0,''),(57133,18090,'118759','deals-mobile','float','right',0,''),(57134,18091,'118760','deals-mobile','col_in_row','4',0,''),(57135,18091,'118760','deals-mobile','products_align','left',0,''),(57136,18091,'118760','deals-mobile','font-weight','400',0,''),(57137,18091,'118760','deals-mobile','show_qty_input','0',0,''),(57138,18091,'118760','deals-mobile','listing_type','productListing',0,''),(57139,18091,'118760','deals-mobile','listing_type_rows','Rows',0,''),(57140,18091,'118760','deals-mobile','show_buy_button_b2b','on',0,''),(57141,18091,'118760','deals-mobile','show_wishlist_button_b2b','1',0,''),(57142,18091,'118760','deals-mobile','show_compare_b2b','1',0,''),(57143,18091,'118760','deals-mobile','listing_type_b2b','b2b',0,''),(57144,18091,'118760','deals-mobile','show_image','0',0,''),(57145,18091,'118760','deals-mobile','show_stock','0',0,''),(57146,18091,'118760','deals-mobile','show_description','0',0,''),(57147,18091,'118760','deals-mobile','show_model','0',0,''),(57148,18091,'118760','deals-mobile','show_properties','0',0,''),(57149,18091,'118760','deals-mobile','show_rating','0',0,''),(57150,18091,'118760','deals-mobile','show_rating_counts','0',0,''),(57151,18091,'118760','deals-mobile','show_price','0',0,''),(57152,18091,'118760','deals-mobile','show_buy_button','0',0,''),(57153,18091,'118760','deals-mobile','show_view_button','0',0,''),(57154,18091,'118760','deals-mobile','show_wishlist_button','0',0,''),(57155,18091,'118760','deals-mobile','show_compare','0',0,''),(57156,18091,'118760','deals-mobile','show_name_rows','0',0,''),(57157,18091,'118760','deals-mobile','show_image_rows','0',0,''),(57158,18091,'118760','deals-mobile','show_stock_rows','0',0,''),(57159,18091,'118760','deals-mobile','show_description_rows','0',0,''),(57160,18091,'118760','deals-mobile','show_model_rows','0',0,''),(57161,18091,'118760','deals-mobile','show_properties_rows','0',0,''),(57162,18091,'118760','deals-mobile','show_rating_rows','0',0,''),(57163,18091,'118760','deals-mobile','show_rating_counts_rows','0',0,''),(57164,18091,'118760','deals-mobile','show_price_rows','0',0,''),(57165,18091,'118760','deals-mobile','show_buy_button_rows','0',0,''),(57166,18091,'118760','deals-mobile','show_qty_input_rows','0',0,''),(57167,18091,'118760','deals-mobile','show_view_button_rows','0',0,''),(57168,18091,'118760','deals-mobile','show_wishlist_button_rows','0',0,''),(57169,18091,'118760','deals-mobile','show_compare_rows','0',0,''),(57170,18091,'118760','deals-mobile','show_name_b2b','0',0,''),(57171,18091,'118760','deals-mobile','show_image_b2b','0',0,''),(57172,18091,'118760','deals-mobile','show_stock_b2b','0',0,''),(57173,18091,'118760','deals-mobile','show_description_b2b','0',0,''),(57174,18091,'118760','deals-mobile','show_model_b2b','0',0,''),(57175,18091,'118760','deals-mobile','show_properties_b2b','0',0,''),(57176,18091,'118760','deals-mobile','show_rating_b2b','0',0,''),(57177,18091,'118760','deals-mobile','show_rating_counts_b2b','0',0,''),(57178,18091,'118760','deals-mobile','show_price_b2b','0',0,''),(57179,18091,'118760','deals-mobile','show_qty_input_b2b','0',0,''),(57180,18091,'118760','deals-mobile','show_view_button_b2b','0',0,''),(57181,18091,'118760','deals-mobile','show_attributes_b2b','0',0,''),(57182,18091,'118760','deals-mobile','items_on_page','12',0,''),(57185,18091,'118760','deals-mobile','product_names_teg','h2',0,''),(57187,18093,'118762','deals-mobile','block_type','1',0,''),(57188,18093,'118762','deals-mobile','padding-top','10',0,''),(57189,18093,'118762','deals-mobile','padding-bottom','10',0,''),(57190,18093,'118762','deals-mobile','border-bottom-width','1',0,''),(57191,18093,'118762','deals-mobile','border-bottom-color','#e0e0e0',0,''),(57192,18093,'118762','deals-mobile','margin-left','0',0,''),(57193,18093,'118762','deals-mobile','margin-right','0',0,''),(57194,18094,'118763','deals-mobile','float','right',0,''),(57195,18094,'118763','deals-mobile','display','none',0,''),(57196,18095,'118764','deals-mobile','margin-right','20',0,''),(57197,18095,'118764','deals-mobile','float','right',0,''),(57198,18095,'118764','deals-mobile','clear','none',0,''),(57199,18095,'118764','deals-mobile','display','none',0,''),(57200,18096,'118765','deals-mobile','clear','none',0,''),(57201,18096,'118765','deals-mobile','float','left',0,''),(57202,18096,'118765','deals-mobile','padding-top','3',0,''),(57203,18096,'118765','deals-mobile','padding-left','20',0,''),(57204,18097,'118766','deals-mobile','float','left',0,''),(57205,18097,'118766','deals-mobile','clear','none',0,''),(57206,18097,'118766','deals-mobile','margin-left','20',0,''),(57207,18097,'118766','deals-mobile','display','none',0,''),(57208,18098,'118767','deals-mobile','float','left',0,''),(57209,18098,'118767','deals-mobile','clear','none',0,''),(57210,18098,'118767','deals-mobile','sort_pos_3','1',0,''),(57211,18098,'118767','deals-mobile','sort_pos_4','2',0,''),(57212,18098,'118767','deals-mobile','sort_pos_10','3',0,''),(57213,18098,'118767','deals-mobile','sort_pos_9','4',0,''),(57214,18098,'118767','deals-mobile','sort_pos_11','5',0,''),(57215,18098,'118767','deals-mobile','sort_pos_12','6',0,''),(57216,18098,'118767','deals-mobile','sort_pos_14','7',0,''),(57217,18098,'118767','deals-mobile','sort_pos_13','8',0,''),(57218,18098,'118767','deals-mobile','sort_pos_8','9',0,''),(57219,18098,'118767','deals-mobile','sort_pos_7','10',0,''),(57220,18098,'118767','deals-mobile','sort_pos_2','11',0,''),(57221,18098,'118767','deals-mobile','sort_pos_1','12',0,''),(57222,18098,'118767','deals-mobile','sort_pos_6','13',0,''),(57223,18098,'118767','deals-mobile','sort_pos_5','14',0,''),(57224,18098,'118767','deals-mobile','sort_pos_0','15',0,''),(57225,18098,'118767','deals-mobile','sort_hide_10','1',0,''),(57226,18098,'118767','deals-mobile','sort_hide_9','1',0,''),(57227,18098,'118767','deals-mobile','hide_icons','1',0,''),(57228,18098,'118767','deals-mobile','sort_hide_16','1',0,''),(57229,18098,'118767','deals-mobile','sort_hide_15','1',0,''),(57230,18098,'118767','deals-mobile','sort_hide_3','0',0,''),(57231,18098,'118767','deals-mobile','sort_hide_4','0',0,''),(57232,18098,'118767','deals-mobile','sort_hide_11','1',0,''),(57233,18098,'118767','deals-mobile','sort_hide_12','1',0,''),(57234,18098,'118767','deals-mobile','sort_hide_14','1',0,''),(57235,18098,'118767','deals-mobile','sort_hide_13','1',0,''),(57236,18098,'118767','deals-mobile','sort_hide_8','0',0,''),(57237,18098,'118767','deals-mobile','sort_hide_7','0',0,''),(57238,18098,'118767','deals-mobile','sort_hide_2','1',0,''),(57239,18098,'118767','deals-mobile','sort_hide_1','1',0,''),(57240,18098,'118767','deals-mobile','sort_hide_6','1',0,''),(57241,18098,'118767','deals-mobile','sort_hide_5','1',0,''),(57242,18098,'118767','deals-mobile','sort_hide_0','1',0,''),(57243,18101,'118770','deals-mobile','block_type','1',0,''),(57244,18101,'118770','deals-mobile','background-color','#eeeeee',0,''),(57245,18101,'118770','deals-mobile','padding-top','30',0,''),(57246,18101,'118770','deals-mobile','padding-bottom','30',0,''),(57247,18102,'118771','deals-mobile','block_type','1',0,''),(57248,18102,'118771','deals-mobile','schema','4-2',0,''),(57249,18102,'118771','deals-mobile','schema','4-1',0,'872'),(57250,18103,'118772','deals-mobile','block_type','1',0,''),(57251,18103,'118772','deals-mobile','padding-right','40',0,''),(57253,18104,'118773','deals-mobile','block_type','1',0,''),(57254,18104,'118773','deals-mobile','padding-top','30',0,''),(57255,18104,'118773','deals-mobile','padding-left','30',0,''),(57256,18104,'118773','deals-mobile','padding-right','30',0,''),(57257,18104,'118773','deals-mobile','padding-bottom','23',0,''),(57258,18104,'118773','deals-mobile','margin-bottom','20',0,''),(57259,18104,'118773','deals-mobile','background-color','#ffffff',0,''),(57260,18104,'118773','deals-mobile','style_class','hiding-box',0,''),(57261,18105,'118774','deals-mobile','block_type','2',0,''),(57262,18105,'118774','deals-mobile','schema','2-2',0,''),(57263,18105,'118774','deals-mobile','schema','2-2',0,'872'),(57264,18106,'118775','deals-mobile','padding-right','20',0,''),(57266,18106,'118775','deals-mobile','padding-bottom','20',0,''),(57267,18106,'118775','deals-mobile','address_in','popup',0,''),(57268,18107,'118776','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57269,18108,'118777','deals-mobile','block_type','1',0,''),(57270,18108,'118777','deals-mobile','padding-left','20',0,''),(57272,18109,'118778','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57273,18111,'118780','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(57274,18112,'118781','deals-mobile','block_type','1',0,''),(57275,18112,'118781','deals-mobile','background-color','#ffffff',0,''),(57276,18112,'118781','deals-mobile','padding-top','30',0,''),(57277,18112,'118781','deals-mobile','padding-left','30',0,''),(57278,18112,'118781','deals-mobile','padding-right','30',0,''),(57279,18112,'118781','deals-mobile','padding-bottom','30',0,''),(57280,18112,'118781','deals-mobile','margin-bottom','20',0,''),(57281,18112,'118781','deals-mobile','style_class','hiding-box',0,''),(57282,18113,'118782','deals-mobile','padding-top','10',0,''),(57283,18113,'118782','deals-mobile','padding-left','20',0,''),(57284,18113,'118782','deals-mobile','padding-right','20',0,''),(57285,18113,'118782','deals-mobile','margin-top','20',0,''),(57286,18113,'118782','deals-mobile','background-color','#eeeeee',0,''),(57287,18113,'118782','deals-mobile','padding-bottom','8',0,''),(57288,18114,'118783','deals-mobile','margin-bottom','20',0,''),(57289,18115,'118784','deals-mobile','background-color','#ffffff',0,''),(57290,18115,'118784','deals-mobile','block_type','1',0,''),(57291,18115,'118784','deals-mobile','padding-top','30',0,''),(57292,18115,'118784','deals-mobile','padding-left','30',0,''),(57293,18115,'118784','deals-mobile','padding-right','30',0,''),(57294,18115,'118784','deals-mobile','padding-bottom','30',0,''),(57295,18115,'118784','deals-mobile','margin-bottom','20',0,''),(57296,18115,'118784','deals-mobile','style_class','hiding-box',0,''),(57297,18116,'118785','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(57298,18117,'118786','deals-mobile','block_type','1',0,''),(57299,18117,'118786','deals-mobile','schema','2-2',0,''),(57300,18117,'118786','deals-mobile','schema','2-1',0,'872'),(57301,18118,'118787','deals-mobile','block_type','1',0,''),(57302,18118,'118787','deals-mobile','padding-left','0',0,''),(57303,18118,'118787','deals-mobile','margin-bottom','20',0,''),(57304,18121,'118790','deals-mobile','address_in','popup',0,''),(57305,18122,'118791','deals-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(57306,18123,'118792','deals-mobile','block_type','1',0,''),(57307,18123,'118792','deals-mobile','padding-left','20',0,''),(57309,18124,'118793','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(57310,18125,'118794','deals-mobile','border-top-width','1',0,''),(57311,18125,'118794','deals-mobile','border-top-color','#e0e0e0',0,''),(57312,18125,'118794','deals-mobile','padding-top','13',0,''),(57313,18125,'118794','deals-mobile','padding-bottom','10',0,''),(57314,18127,'118796','deals-mobile','background-color','#eeeeee',0,''),(57315,18127,'118796','deals-mobile','padding-top','10',0,''),(57316,18127,'118796','deals-mobile','padding-left','10',0,''),(57317,18127,'118796','deals-mobile','padding-right','10',0,''),(57318,18127,'118796','deals-mobile','padding-bottom','10',0,''),(57319,18127,'118796','deals-mobile','margin-top','10',0,''),(57320,18128,'118797','deals-mobile','block_type','1',0,''),(57321,18128,'118797','deals-mobile','content','\\_',0,'3'),(57322,18128,'118797','deals-mobile','border-top-width','1',0,'3'),(57323,18128,'118797','deals-mobile','border-top-color','#e0e0e0',0,'3'),(57324,18128,'118797','deals-mobile','display','block',0,'3'),(57325,18128,'118797','deals-mobile','position','absolute',0,'3'),(57326,18128,'118797','deals-mobile','top','19',0,'3'),(57327,18128,'118797','deals-mobile','left','0',0,'3'),(57328,18128,'118797','deals-mobile','right','0',0,'3'),(57329,18128,'118797','deals-mobile','margin-top','-2',0,'3'),(57330,18128,'118797','deals-mobile','position','relative',0,''),(57331,18129,'118798','deals-mobile','box_align','2',0,''),(57332,18129,'118798','deals-mobile','margin-bottom','10',0,''),(57333,18129,'118798','deals-mobile','background-color','#ffffff',0,''),(57334,18129,'118798','deals-mobile','position','relative',0,''),(57335,18130,'118799','deals-mobile','block_type','1',0,''),(57336,18130,'118799','deals-mobile','padding-top','30',0,''),(57337,18130,'118799','deals-mobile','padding-left','30',0,''),(57338,18130,'118799','deals-mobile','padding-right','30',0,''),(57339,18130,'118799','deals-mobile','padding-bottom','14',0,''),(57340,18130,'118799','deals-mobile','margin-bottom','20',0,''),(57341,18130,'118799','deals-mobile','background-color','#ffffff',0,''),(57342,18130,'118799','deals-mobile','style_class','hiding-box closeable-box',0,''),(57343,18131,'118800','deals-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(57344,18131,'118800','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57345,18132,'118801','deals-mobile','block_type','2',0,''),(57346,18132,'118801','deals-mobile','style_class','closeable-content',0,''),(57347,18132,'118801','deals-mobile','schema','2-2',0,''),(57348,18132,'118801','deals-mobile','schema','2-2',0,'872'),(57349,18133,'118802','deals-mobile','padding-right','20',0,''),(57350,18133,'118802','deals-mobile','padding-bottom','20',0,''),(57352,18134,'118803','deals-mobile','padding-left','20',0,''),(57353,18134,'118803','deals-mobile','padding-bottom','20',0,''),(57355,18135,'118804','deals-mobile','padding-left','20',0,''),(57356,18135,'118804','deals-mobile','padding-bottom','20',0,''),(57358,18136,'118805','deals-mobile','block_type','1',0,''),(57359,18136,'118805','deals-mobile','background-color','#ffffff',0,''),(57360,18136,'118805','deals-mobile','padding-top','30',0,''),(57361,18136,'118805','deals-mobile','padding-left','30',0,''),(57362,18136,'118805','deals-mobile','padding-right','30',0,''),(57363,18136,'118805','deals-mobile','padding-bottom','14',0,''),(57364,18136,'118805','deals-mobile','margin-bottom','20',0,''),(57365,18136,'118805','deals-mobile','style_class','hiding-box closeable-box',0,''),(57366,18137,'118806','deals-mobile','style_class','closeable-content',0,''),(57367,18137,'118806','deals-mobile','padding-bottom','20',0,''),(57368,18138,'118807','deals-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(57369,18138,'118807','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57370,18139,'118808','deals-mobile','block_type','1',0,''),(57371,18139,'118808','deals-mobile','padding-top','20',0,''),(57372,18139,'118808','deals-mobile','padding-left','20',0,''),(57373,18139,'118808','deals-mobile','padding-right','20',0,''),(57374,18139,'118808','deals-mobile','padding-bottom','20',0,''),(57375,18139,'118808','deals-mobile','background-color','#ffffff',0,''),(57376,18139,'118808','deals-mobile','style_class','order-summary',0,''),(57377,18140,'118809','deals-mobile','margin-bottom','10',0,''),(57378,18142,'118811','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(57379,18143,'118812','deals-mobile','hide_page','1',0,''),(57380,18143,'118812','deals-mobile','hide_continue_button','1',0,''),(57381,18144,'118813','deals-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(57382,18144,'118813','deals-mobile','text-align','center',0,''),(57383,18144,'118813','deals-mobile','font-size','14',0,''),(57384,18144,'118813','deals-mobile','color','#757575',0,''),(57385,18144,'118813','deals-mobile','padding-top','10',0,''),(57386,18145,'118814','deals-mobile','block_type','1',0,''),(57387,18146,'118815','deals-mobile','margin-bottom','20',0,''),(57388,18146,'118815','deals-mobile','text-align','right',0,''),(57389,18148,'118817','deals-mobile','block_type','2',0,''),(57390,18148,'118817','deals-mobile','margin-bottom','20',0,''),(57391,18148,'118817','deals-mobile','schema','2-2',0,''),(57392,18149,'118818','deals-mobile','block_type','1',0,''),(57393,18149,'118818','deals-mobile','padding-right','20',0,''),(57395,18150,'118819','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(57396,18150,'118819','deals-mobile','clear','none',0,''),(57397,18152,'118821','deals-mobile','block_type','1',0,''),(57398,18152,'118821','deals-mobile','padding-left','20',0,''),(57400,18153,'118822','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57401,18153,'118822','deals-mobile','clear','none',0,''),(57402,18155,'118824','deals-mobile','text-align','right',0,''),(57403,18155,'118824','deals-mobile','margin-bottom','20',0,''),(57404,18156,'118825','deals-mobile','block_type','2',0,''),(57405,18156,'118825','deals-mobile','margin-bottom','20',0,''),(57406,18156,'118825','deals-mobile','schema','2-2',0,''),(57407,18157,'118826','deals-mobile','block_type','1',0,''),(57408,18157,'118826','deals-mobile','padding-right','20',0,''),(57410,18158,'118827','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(57411,18158,'118827','deals-mobile','clear','none',0,''),(57412,18160,'118829','deals-mobile','padding-left','20',0,''),(57413,18160,'118829','deals-mobile','block_type','1',0,''),(57415,18162,'118831','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57416,18162,'118831','deals-mobile','clear','none',0,''),(57417,18163,'118832','deals-mobile','link','products',0,''),(57418,18163,'118832','deals-mobile','margin-top','-33',0,''),(57419,18163,'118832','deals-mobile','float','right',0,''),(57420,18165,'118834','deals-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(57421,18166,'118835','deals-mobile','block_type','1',0,''),(57422,18167,'118836','deals-mobile','margin-bottom','20',0,''),(57423,18168,'118837','deals-mobile','text-align','right',0,''),(57424,18168,'118837','deals-mobile','margin-bottom','20',0,''),(57425,18169,'118838','deals-mobile','block_type','2',0,''),(57426,18169,'118838','deals-mobile','margin-bottom','20',0,''),(57427,18169,'118838','deals-mobile','schema','2-2',0,''),(57428,18170,'118839','deals-mobile','block_type','1',0,''),(57429,18170,'118839','deals-mobile','padding-right','20',0,''),(57431,18171,'118840','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57432,18171,'118840','deals-mobile','clear','none',0,''),(57433,18173,'118842','deals-mobile','block_type','1',0,''),(57434,18173,'118842','deals-mobile','padding-left','20',0,''),(57436,18174,'118843','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57437,18174,'118843','deals-mobile','clear','none',0,''),(57438,18176,'118845','deals-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(57439,18177,'118846','deals-mobile','margin-bottom','20',0,''),(57440,18178,'118847','deals-mobile','margin-bottom','20',0,''),(57441,18178,'118847','deals-mobile','text-align','right',0,''),(57442,18179,'118848','deals-mobile','block_type','1',0,''),(57443,18180,'118849','deals-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(57444,18181,'118850','deals-mobile','margin-bottom','20',0,''),(57445,18181,'118850','deals-mobile','text-align','right',0,''),(57446,18184,'118853','deals-mobile','text-align','right',0,''),(57447,18184,'118853','deals-mobile','margin-bottom','20',0,''),(57448,18185,'118854','deals-mobile','block_type','2',0,''),(57449,18185,'118854','deals-mobile','margin-bottom','20',0,''),(57450,18185,'118854','deals-mobile','schema','2-2',0,''),(57451,18186,'118855','deals-mobile','block_type','1',0,''),(57452,18186,'118855','deals-mobile','padding-right','20',0,''),(57454,18188,'118857','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57455,18188,'118857','deals-mobile','clear','none',0,''),(57456,18189,'118858','deals-mobile','block_type','1',0,''),(57457,18189,'118858','deals-mobile','padding-left','20',0,''),(57459,18190,'118859','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57460,18190,'118859','deals-mobile','clear','none',0,''),(57461,18192,'118861','deals-mobile','block_type','1',0,''),(57462,18193,'118862','deals-mobile','block_type','2',0,''),(57463,18193,'118862','deals-mobile','margin-bottom','20',0,''),(57464,18193,'118862','deals-mobile','schema','2-2',0,''),(57465,18194,'118863','deals-mobile','block_type','1',0,''),(57466,18194,'118863','deals-mobile','padding-right','20',0,''),(57468,18196,'118865','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(57469,18196,'118865','deals-mobile','clear','none',0,''),(57470,18197,'118866','deals-mobile','padding-left','20',0,''),(57471,18197,'118866','deals-mobile','block_type','1',0,''),(57473,18198,'118867','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57474,18198,'118867','deals-mobile','clear','none',0,''),(57475,18200,'118869','deals-mobile','text-align','right',0,''),(57476,18200,'118869','deals-mobile','margin-bottom','20',0,''),(57477,18201,'118870','deals-mobile','margin-bottom','20',0,''),(57478,18201,'118870','deals-mobile','text-align','right',0,''),(57479,18202,'118871','deals-mobile','link','products',0,''),(57480,18202,'118871','deals-mobile','margin-top','-33',0,''),(57481,18202,'118871','deals-mobile','float','right',0,''),(57482,18203,'118872','deals-mobile','margin-bottom','20',0,''),(57483,18204,'118873','deals-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(57484,18205,'118874','deals-mobile','margin-bottom','20',0,''),(57485,18206,'118875','deals-mobile','block_type','2',0,''),(57486,18206,'118875','deals-mobile','margin-bottom','20',0,''),(57487,18206,'118875','deals-mobile','schema','2-2',0,''),(57488,18207,'118876','deals-mobile','block_type','1',0,''),(57489,18207,'118876','deals-mobile','padding-right','20',0,''),(57491,18209,'118878','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(57492,18209,'118878','deals-mobile','clear','none',0,''),(57493,18210,'118879','deals-mobile','block_type','1',0,''),(57494,18210,'118879','deals-mobile','padding-left','20',0,''),(57496,18211,'118880','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57497,18211,'118880','deals-mobile','clear','none',0,''),(57498,18213,'118882','deals-mobile','text','##TEXT_CONFIRMATION##',0,''),(57499,18214,'118883','deals-mobile','text','##TEXT_CONFIRMATION##',0,''),(57500,18215,'118884','deals-mobile','text','##TEXT_CONFIRMATION##',0,''),(57501,18216,'118885','deals-mobile','text','##TEXT_CONFIRMATION##',0,''),(57502,18217,'118886','deals-mobile','text','##TEXT_CONFIRMATION##',0,''),(57503,18218,'118887','deals-mobile','text','##TEXT_CONFIRMATION##',0,''),(57504,18219,'118888','deals-mobile','block_type','2',0,''),(57505,18220,'118889','deals-mobile','block_type','1',0,''),(57506,18220,'118889','deals-mobile','padding-right','20',0,''),(57508,18222,'118891','deals-mobile','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(57509,18223,'118892','deals-mobile','block_type','1',0,''),(57510,18223,'118892','deals-mobile','padding-right','0',0,''),(57511,18223,'118892','deals-mobile','padding-left','20',0,''),(57512,18225,'118894','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(57513,18228,'118897','deals-mobile','block_type','2',0,''),(57514,18229,'118898','deals-mobile','block_type','1',0,''),(57515,18229,'118898','deals-mobile','padding-right','20',0,''),(57516,18230,'118899','deals-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(57517,18232,'118901','deals-mobile','block_type','1',0,''),(57518,18232,'118901','deals-mobile','padding-left','20',0,''),(57520,18233,'118902','deals-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(57521,18235,'118904','deals-mobile','block_type','4',0,''),(57522,18235,'118904','deals-mobile','schema','4-2',0,''),(57523,18236,'118905','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57524,18236,'118905','deals-mobile','text-align','right',0,''),(57525,18236,'118905','deals-mobile','padding-top','10',0,''),(57526,18236,'118905','deals-mobile','font_size_measure','em',0,''),(57527,18236,'118905','deals-mobile','font-size','1.2',0,''),(57528,18237,'118906','deals-mobile','text-align','right',0,''),(57529,18238,'118907','deals-mobile','block_type','2',0,''),(57530,18239,'118908','deals-mobile','block_type','1',0,''),(57531,18239,'118908','deals-mobile','padding-right','20',0,''),(57533,18241,'118910','deals-mobile','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(57534,18242,'118911','deals-mobile','block_type','1',0,''),(57535,18242,'118911','deals-mobile','padding-right','0',0,''),(57536,18242,'118911','deals-mobile','padding-left','20',0,''),(57537,18243,'118912','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(57538,18247,'118916','deals-mobile','block_type','4',0,''),(57539,18247,'118916','deals-mobile','schema','4-2',0,''),(57540,18248,'118917','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57541,18248,'118917','deals-mobile','text-align','right',0,''),(57542,18248,'118917','deals-mobile','padding-top','10',0,''),(57543,18248,'118917','deals-mobile','font_size_measure','em',0,''),(57544,18248,'118917','deals-mobile','font-size','1.2',0,''),(57545,18249,'118918','deals-mobile','text-align','right',0,''),(57546,18250,'118919','deals-mobile','block_type','2',0,''),(57547,18251,'118920','deals-mobile','block_type','1',0,''),(57548,18251,'118920','deals-mobile','padding-right','20',0,''),(57549,18253,'118922','deals-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(57550,18254,'118923','deals-mobile','block_type','1',0,''),(57551,18254,'118923','deals-mobile','padding-left','20',0,''),(57553,18256,'118925','deals-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(57554,18257,'118926','deals-mobile','block_type','4',0,''),(57555,18257,'118926','deals-mobile','schema','4-2',0,''),(57556,18258,'118927','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57557,18258,'118927','deals-mobile','text-align','right',0,''),(57558,18258,'118927','deals-mobile','padding-top','10',0,''),(57559,18258,'118927','deals-mobile','font_size_measure','em',0,''),(57560,18258,'118927','deals-mobile','font-size','1.2',0,''),(57561,18259,'118928','deals-mobile','text-align','right',0,''),(57562,18260,'118929','deals-mobile','block_type','2',0,''),(57563,18261,'118930','deals-mobile','block_type','1',0,''),(57564,18261,'118930','deals-mobile','padding-right','20',0,''),(57565,18263,'118932','deals-mobile','block_type','1',0,''),(57566,18263,'118932','deals-mobile','padding-left','20',0,''),(57568,18265,'118934','deals-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(57569,18266,'118935','deals-mobile','block_type','2',0,''),(57570,18267,'118936','deals-mobile','block_type','1',0,''),(57571,18267,'118936','deals-mobile','padding-right','20',0,''),(57572,18269,'118938','deals-mobile','block_type','1',0,''),(57573,18269,'118938','deals-mobile','padding-left','20',0,''),(57575,18270,'118939','deals-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(57576,18272,'118941','deals-mobile','block_type','4',0,''),(57577,18272,'118941','deals-mobile','schema','4-2',0,''),(57578,18273,'118942','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57579,18273,'118942','deals-mobile','text-align','right',0,''),(57580,18273,'118942','deals-mobile','padding-top','10',0,''),(57581,18273,'118942','deals-mobile','font_size_measure','em',0,''),(57582,18273,'118942','deals-mobile','font-size','1.2',0,''),(57583,18274,'118943','deals-mobile','text-align','right',0,''),(57584,18275,'118944','deals-mobile','text','##DELIVERY_DETAILS##',0,''),(57585,18276,'118945','deals-mobile','text','##DELIVERY_DETAILS##',0,''),(57586,18277,'118946','deals-mobile','text','##CONTACT_INFORMATION##',0,''),(57587,18278,'118947','deals-mobile','text','##CONTACT_INFORMATION##',0,''),(57588,18279,'118948','deals-mobile','text','##DELIVERY_DETAILS##',0,''),(57589,18280,'118949','deals-mobile','text','##DELIVERY_DETAILS##',0,''),(57590,18281,'118950','deals-mobile','block_type','1',0,''),(57591,18281,'118950','deals-mobile','background-color','#eeeeee',0,''),(57592,18281,'118950','deals-mobile','padding-top','30',0,''),(57593,18281,'118950','deals-mobile','padding-bottom','30',0,''),(57594,18282,'118951','deals-mobile','block_type','4',0,''),(57595,18282,'118951','deals-mobile','schema','4-2',0,''),(57596,18283,'118952','deals-mobile','block_type','1',0,''),(57597,18283,'118952','deals-mobile','padding-right','40',0,''),(57599,18284,'118953','deals-mobile','background-color','#ffffff',0,''),(57600,18284,'118953','deals-mobile','block_type','1',0,''),(57601,18284,'118953','deals-mobile','padding-top','30',0,''),(57602,18284,'118953','deals-mobile','padding-left','30',0,''),(57603,18284,'118953','deals-mobile','padding-right','30',0,''),(57604,18284,'118953','deals-mobile','padding-bottom','30',0,''),(57605,18284,'118953','deals-mobile','margin-bottom','20',0,''),(57606,18284,'118953','deals-mobile','style_class','hiding-box',0,''),(57607,18285,'118954','deals-mobile','background-color','#eeeeee',0,''),(57608,18285,'118954','deals-mobile','padding-top','10',0,''),(57609,18285,'118954','deals-mobile','padding-left','10',0,''),(57610,18285,'118954','deals-mobile','padding-right','10',0,''),(57611,18285,'118954','deals-mobile','padding-bottom','10',0,''),(57612,18285,'118954','deals-mobile','margin-top','10',0,''),(57613,18286,'118955','deals-mobile','block_type','2',0,''),(57614,18286,'118955','deals-mobile','schema','2-2',0,''),(57615,18287,'118956','deals-mobile','block_type','1',0,''),(57616,18287,'118956','deals-mobile','padding-right','20',0,''),(57617,18287,'118956','deals-mobile','padding-left','0',0,''),(57618,18287,'118956','deals-mobile','margin-bottom','20',0,''),(57619,18289,'118958','deals-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(57620,18291,'118960','deals-mobile','block_type','1',0,''),(57621,18291,'118960','deals-mobile','padding-left','20',0,''),(57623,18292,'118961','deals-mobile','border-top-width','1',0,''),(57624,18292,'118961','deals-mobile','border-top-color','#e0e0e0',0,''),(57625,18292,'118961','deals-mobile','padding-top','13',0,''),(57626,18292,'118961','deals-mobile','padding-bottom','10',0,''),(57627,18293,'118962','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(57628,18294,'118963','deals-mobile','block_type','1',0,''),(57629,18294,'118963','deals-mobile','content','\\_',0,'3'),(57630,18294,'118963','deals-mobile','border-top-width','1',0,'3'),(57631,18294,'118963','deals-mobile','border-top-color','#e0e0e0',0,'3'),(57632,18294,'118963','deals-mobile','display','block',0,'3'),(57633,18294,'118963','deals-mobile','position','absolute',0,'3'),(57634,18294,'118963','deals-mobile','top','19',0,'3'),(57635,18294,'118963','deals-mobile','left','0',0,'3'),(57636,18294,'118963','deals-mobile','right','0',0,'3'),(57637,18294,'118963','deals-mobile','margin-top','-2',0,'3'),(57638,18294,'118963','deals-mobile','position','relative',0,''),(57639,18295,'118964','deals-mobile','box_align','2',0,''),(57640,18295,'118964','deals-mobile','margin-bottom','10',0,''),(57641,18295,'118964','deals-mobile','background-color','#ffffff',0,''),(57642,18295,'118964','deals-mobile','position','relative',0,''),(57643,18296,'118965','deals-mobile','block_type','1',0,''),(57644,18296,'118965','deals-mobile','background-color','#ffffff',0,''),(57645,18296,'118965','deals-mobile','padding-top','30',0,''),(57646,18296,'118965','deals-mobile','padding-left','30',0,''),(57647,18296,'118965','deals-mobile','padding-right','30',0,''),(57648,18296,'118965','deals-mobile','padding-bottom','14',0,''),(57649,18296,'118965','deals-mobile','margin-bottom','20',0,''),(57650,18296,'118965','deals-mobile','style_class','hiding-box closeable-box',0,''),(57651,18297,'118966','deals-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(57652,18297,'118966','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57653,18298,'118967','deals-mobile','style_class','closeable-content',0,''),(57654,18298,'118967','deals-mobile','padding-bottom','20',0,''),(57655,18299,'118968','deals-mobile','background-color','#ffffff',0,''),(57656,18299,'118968','deals-mobile','padding-top','30',0,''),(57657,18299,'118968','deals-mobile','padding-left','30',0,''),(57658,18299,'118968','deals-mobile','padding-right','30',0,''),(57659,18299,'118968','deals-mobile','padding-bottom','30',0,''),(57660,18299,'118968','deals-mobile','margin-bottom','20',0,''),(57661,18300,'118969','deals-mobile','block_type','1',0,''),(57662,18300,'118969','deals-mobile','background-color','#ffffff',0,''),(57663,18300,'118969','deals-mobile','padding-top','30',0,''),(57664,18300,'118969','deals-mobile','padding-left','30',0,''),(57665,18300,'118969','deals-mobile','padding-right','30',0,''),(57666,18300,'118969','deals-mobile','padding-bottom','30',0,''),(57667,18300,'118969','deals-mobile','margin-bottom','20',0,''),(57668,18300,'118969','deals-mobile','style_class','hiding-box',0,''),(57669,18301,'118970','deals-mobile','padding-top','10',0,''),(57670,18301,'118970','deals-mobile','padding-left','20',0,''),(57671,18301,'118970','deals-mobile','padding-right','20',0,''),(57672,18301,'118970','deals-mobile','margin-top','20',0,''),(57673,18301,'118970','deals-mobile','background-color','#eeeeee',0,''),(57674,18301,'118970','deals-mobile','padding-bottom','8',0,''),(57675,18302,'118971','deals-mobile','margin-bottom','20',0,''),(57676,18303,'118972','deals-mobile','block_type','1',0,''),(57677,18303,'118972','deals-mobile','padding-top','20',0,''),(57678,18303,'118972','deals-mobile','padding-left','20',0,''),(57679,18303,'118972','deals-mobile','padding-right','20',0,''),(57680,18303,'118972','deals-mobile','padding-bottom','20',0,''),(57681,18303,'118972','deals-mobile','background-color','#ffffff',0,''),(57682,18303,'118972','deals-mobile','style_class','order-summary',0,''),(57683,18305,'118974','deals-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(57684,18305,'118974','deals-mobile','text-align','center',0,''),(57685,18305,'118974','deals-mobile','font-size','14',0,''),(57686,18305,'118974','deals-mobile','color','#757575',0,''),(57687,18305,'118974','deals-mobile','padding-top','10',0,''),(57688,18306,'118975','deals-mobile','block_type','1',0,''),(57689,18306,'118975','deals-mobile','background-color','#eeeeee',0,''),(57690,18306,'118975','deals-mobile','padding-top','30',0,''),(57691,18306,'118975','deals-mobile','padding-bottom','30',0,''),(57692,18307,'118976','deals-mobile','block_type','4',0,''),(57693,18308,'118977','deals-mobile','block_type','1',0,''),(57694,18308,'118977','deals-mobile','padding-right','40',0,''),(57695,18309,'118978','deals-mobile','block_type','1',0,''),(57696,18309,'118978','deals-mobile','background-color','#ffffff',0,''),(57697,18309,'118978','deals-mobile','padding-top','30',0,''),(57698,18309,'118978','deals-mobile','padding-left','30',0,''),(57699,18309,'118978','deals-mobile','padding-right','30',0,''),(57700,18309,'118978','deals-mobile','padding-bottom','14',0,''),(57701,18309,'118978','deals-mobile','margin-bottom','20',0,''),(57702,18309,'118978','deals-mobile','style_class','hiding-box closeable-box',0,''),(57703,18310,'118979','deals-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(57704,18310,'118979','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57705,18311,'118980','deals-mobile','style_class','closeable-content',0,''),(57706,18311,'118980','deals-mobile','padding-bottom','20',0,''),(57707,18312,'118981','deals-mobile','block_type','1',0,''),(57708,18312,'118981','deals-mobile','padding-top','30',0,''),(57709,18312,'118981','deals-mobile','padding-left','30',0,''),(57710,18312,'118981','deals-mobile','padding-right','30',0,''),(57711,18312,'118981','deals-mobile','padding-bottom','14',0,''),(57712,18312,'118981','deals-mobile','margin-bottom','20',0,''),(57713,18312,'118981','deals-mobile','background-color','#ffffff',0,''),(57714,18312,'118981','deals-mobile','style_class','hiding-box closeable-box',0,''),(57715,18313,'118982','deals-mobile','block_type','2',0,''),(57716,18313,'118982','deals-mobile','style_class','closeable-content',0,''),(57717,18314,'118983','deals-mobile','padding-right','20',0,''),(57718,18314,'118983','deals-mobile','padding-bottom','20',0,''),(57719,18315,'118984','deals-mobile','padding-left','20',0,''),(57720,18315,'118984','deals-mobile','padding-bottom','20',0,''),(57721,18316,'118985','deals-mobile','padding-left','20',0,''),(57722,18316,'118985','deals-mobile','padding-bottom','20',0,''),(57723,18317,'118986','deals-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(57724,18317,'118986','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57725,18318,'118987','deals-mobile','block_type','1',0,''),(57726,18318,'118987','deals-mobile','padding-top','30',0,''),(57727,18318,'118987','deals-mobile','padding-left','30',0,''),(57728,18318,'118987','deals-mobile','padding-right','30',0,''),(57729,18318,'118987','deals-mobile','padding-bottom','23',0,''),(57730,18318,'118987','deals-mobile','margin-bottom','20',0,''),(57731,18318,'118987','deals-mobile','background-color','#ffffff',0,''),(57732,18318,'118987','deals-mobile','style_class','hiding-box',0,''),(57733,18319,'118988','deals-mobile','block_type','2',0,''),(57734,18320,'118989','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57735,18321,'118990','deals-mobile','padding-right','20',0,''),(57736,18322,'118991','deals-mobile','block_type','1',0,''),(57737,18322,'118991','deals-mobile','padding-left','20',0,''),(57738,18323,'118992','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57739,18325,'118994','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(57740,18326,'118995','deals-mobile','block_type','1',0,''),(57741,18326,'118995','deals-mobile','background-color','#ffffff',0,''),(57742,18326,'118995','deals-mobile','padding-top','30',0,''),(57743,18326,'118995','deals-mobile','padding-left','30',0,''),(57744,18326,'118995','deals-mobile','padding-right','30',0,''),(57745,18326,'118995','deals-mobile','padding-bottom','30',0,''),(57746,18326,'118995','deals-mobile','margin-bottom','20',0,''),(57747,18326,'118995','deals-mobile','style_class','hiding-box',0,''),(57748,18327,'118996','deals-mobile','margin-bottom','20',0,''),(57749,18328,'118997','deals-mobile','padding-top','10',0,''),(57750,18328,'118997','deals-mobile','padding-left','20',0,''),(57751,18328,'118997','deals-mobile','padding-right','20',0,''),(57752,18328,'118997','deals-mobile','margin-top','20',0,''),(57753,18328,'118997','deals-mobile','background-color','#eeeeee',0,''),(57754,18328,'118997','deals-mobile','padding-bottom','8',0,''),(57755,18329,'118998','deals-mobile','block_type','1',0,''),(57756,18329,'118998','deals-mobile','padding-top','20',0,''),(57757,18329,'118998','deals-mobile','padding-left','20',0,''),(57758,18329,'118998','deals-mobile','padding-right','20',0,''),(57759,18329,'118998','deals-mobile','padding-bottom','20',0,''),(57760,18329,'118998','deals-mobile','background-color','#ffffff',0,''),(57761,18329,'118998','deals-mobile','style_class','order-summary hiding-box',0,''),(57762,18330,'118999','deals-mobile','hide_page','1',0,''),(57763,18330,'118999','deals-mobile','hide_continue_button','1',0,''),(57764,18332,'119001','deals-mobile','margin-bottom','10',0,''),(57765,18333,'119002','deals-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(57766,18333,'119002','deals-mobile','text-align','center',0,''),(57767,18333,'119002','deals-mobile','font-size','14',0,''),(57768,18333,'119002','deals-mobile','color','#757575',0,''),(57769,18333,'119002','deals-mobile','padding-top','10',0,''),(57770,18334,'119003','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(57771,18335,'119004','deals-mobile','block_type','1',0,''),(57772,18336,'119005','deals-mobile','margin-bottom','20',0,''),(57773,18337,'119006','deals-mobile','block_type','2',0,''),(57774,18337,'119006','deals-mobile','schema','2-2',0,''),(57775,18338,'119007','deals-mobile','block_type','1',0,''),(57776,18338,'119007','deals-mobile','padding-right','20',0,''),(57778,18340,'119009','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57779,18341,'119010','deals-mobile','block_type','1',0,''),(57780,18341,'119010','deals-mobile','padding-left','20',0,''),(57782,18343,'119012','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57783,18347,'119016','deals-mobile','block_type','2',0,''),(57784,18347,'119016','deals-mobile','schema','2-2',0,''),(57785,18348,'119017','deals-mobile','block_type','1',0,''),(57786,18348,'119017','deals-mobile','padding-right','20',0,''),(57788,18349,'119018','deals-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(57789,18351,'119020','deals-mobile','block_type','1',0,''),(57790,18351,'119020','deals-mobile','padding-left','20',0,''),(57792,18352,'119021','deals-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(57793,18354,'119023','deals-mobile','block_type','4',0,''),(57794,18354,'119023','deals-mobile','schema','4-2',0,''),(57795,18355,'119024','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57796,18355,'119024','deals-mobile','text-align','right',0,''),(57797,18355,'119024','deals-mobile','padding-top','10',0,''),(57798,18355,'119024','deals-mobile','font_size_measure','em',0,''),(57799,18355,'119024','deals-mobile','font-size','1.2',0,''),(57800,18356,'119025','deals-mobile','text-align','right',0,''),(57801,18358,'119027','deals-mobile','block_type','1',0,''),(57802,18358,'119027','deals-mobile','background-color','#eeeeee',0,''),(57803,18358,'119027','deals-mobile','padding-top','30',0,''),(57804,18358,'119027','deals-mobile','padding-bottom','30',0,''),(57805,18359,'119028','deals-mobile','block_type','4',0,''),(57806,18359,'119028','deals-mobile','schema','4-2',0,''),(57807,18360,'119029','deals-mobile','block_type','1',0,''),(57808,18360,'119029','deals-mobile','padding-right','40',0,''),(57810,18361,'119030','deals-mobile','block_type','1',0,''),(57811,18361,'119030','deals-mobile','padding-top','30',0,''),(57812,18361,'119030','deals-mobile','padding-left','30',0,''),(57813,18361,'119030','deals-mobile','padding-right','30',0,''),(57814,18361,'119030','deals-mobile','padding-bottom','23',0,''),(57815,18361,'119030','deals-mobile','margin-bottom','20',0,''),(57816,18361,'119030','deals-mobile','background-color','#ffffff',0,''),(57817,18361,'119030','deals-mobile','style_class','hiding-box',0,''),(57818,18362,'119031','deals-mobile','block_type','2',0,''),(57819,18362,'119031','deals-mobile','schema','2-2',0,''),(57820,18363,'119032','deals-mobile','padding-right','20',0,''),(57822,18363,'119032','deals-mobile','padding-bottom','20',0,''),(57823,18364,'119033','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57824,18365,'119034','deals-mobile','block_type','1',0,''),(57825,18365,'119034','deals-mobile','padding-left','20',0,''),(57827,18366,'119035','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57828,18368,'119037','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(57829,18369,'119038','deals-mobile','block_type','1',0,''),(57830,18369,'119038','deals-mobile','background-color','#ffffff',0,''),(57831,18369,'119038','deals-mobile','padding-top','30',0,''),(57832,18369,'119038','deals-mobile','padding-left','30',0,''),(57833,18369,'119038','deals-mobile','padding-right','30',0,''),(57834,18369,'119038','deals-mobile','padding-bottom','30',0,''),(57835,18369,'119038','deals-mobile','margin-bottom','20',0,''),(57836,18369,'119038','deals-mobile','style_class','hiding-box',0,''),(57837,18370,'119039','deals-mobile','padding-top','10',0,''),(57838,18370,'119039','deals-mobile','padding-left','20',0,''),(57839,18370,'119039','deals-mobile','padding-right','20',0,''),(57840,18370,'119039','deals-mobile','margin-top','20',0,''),(57841,18370,'119039','deals-mobile','background-color','#eeeeee',0,''),(57842,18370,'119039','deals-mobile','padding-bottom','8',0,''),(57843,18371,'119040','deals-mobile','margin-bottom','20',0,''),(57844,18372,'119041','deals-mobile','block_type','1',0,''),(57845,18372,'119041','deals-mobile','background-color','#ffffff',0,''),(57846,18372,'119041','deals-mobile','padding-top','30',0,''),(57847,18372,'119041','deals-mobile','padding-left','30',0,''),(57848,18372,'119041','deals-mobile','padding-right','30',0,''),(57849,18372,'119041','deals-mobile','padding-bottom','14',0,''),(57850,18372,'119041','deals-mobile','margin-bottom','20',0,''),(57851,18372,'119041','deals-mobile','style_class','hiding-box closeable-box',0,''),(57852,18373,'119042','deals-mobile','style_class','closeable-content',0,''),(57853,18373,'119042','deals-mobile','padding-bottom','20',0,''),(57854,18374,'119043','deals-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(57855,18374,'119043','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57856,18375,'119044','deals-mobile','background-color','#ffffff',0,''),(57857,18375,'119044','deals-mobile','padding-top','30',0,''),(57858,18375,'119044','deals-mobile','padding-left','30',0,''),(57859,18375,'119044','deals-mobile','padding-right','30',0,''),(57860,18375,'119044','deals-mobile','padding-bottom','30',0,''),(57861,18375,'119044','deals-mobile','margin-bottom','20',0,''),(57862,18376,'119045','deals-mobile','block_type','1',0,''),(57863,18376,'119045','deals-mobile','padding-top','20',0,''),(57864,18376,'119045','deals-mobile','padding-left','20',0,''),(57865,18376,'119045','deals-mobile','padding-right','20',0,''),(57866,18376,'119045','deals-mobile','padding-bottom','20',0,''),(57867,18376,'119045','deals-mobile','background-color','#ffffff',0,''),(57868,18376,'119045','deals-mobile','style_class','order-summary',0,''),(57869,18377,'119046','deals-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(57870,18377,'119046','deals-mobile','text-align','center',0,''),(57871,18377,'119046','deals-mobile','font-size','14',0,''),(57872,18377,'119046','deals-mobile','color','#757575',0,''),(57873,18377,'119046','deals-mobile','padding-top','10',0,''),(57874,18378,'119047','deals-mobile','margin-bottom','10',0,''),(57875,18380,'119049','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(57876,18381,'119050','deals-mobile','block_type','4',0,''),(57877,18381,'119050','deals-mobile','schema','4-2',0,''),(57878,18382,'119051','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57879,18382,'119051','deals-mobile','text-align','right',0,''),(57880,18382,'119051','deals-mobile','padding-top','10',0,''),(57881,18382,'119051','deals-mobile','font_size_measure','em',0,''),(57882,18382,'119051','deals-mobile','font-size','1.2',0,''),(57883,18383,'119052','deals-mobile','text-align','right',0,''),(57884,18384,'119053','deals-mobile','block_type','2',0,''),(57885,18385,'119054','deals-mobile','block_type','1',0,''),(57886,18385,'119054','deals-mobile','padding-left','0',0,''),(57887,18385,'119054','deals-mobile','padding-right','20',0,''),(57888,18387,'119056','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57889,18388,'119057','deals-mobile','block_type','1',0,''),(57890,18388,'119057','deals-mobile','padding-left','20',0,''),(57892,18390,'119059','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57893,18394,'119063','deals-mobile','block_type','2',0,''),(57894,18395,'119064','deals-mobile','block_type','1',0,''),(57895,18395,'119064','deals-mobile','padding-left','0',0,''),(57896,18395,'119064','deals-mobile','padding-right','20',0,''),(57897,18396,'119065','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57898,18398,'119067','deals-mobile','block_type','1',0,''),(57899,18398,'119067','deals-mobile','padding-left','20',0,''),(57901,18400,'119069','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57902,18404,'119073','deals-mobile','block_type','4',0,''),(57903,18404,'119073','deals-mobile','schema','4-2',0,''),(57904,18405,'119074','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57905,18405,'119074','deals-mobile','text-align','right',0,''),(57906,18405,'119074','deals-mobile','padding-top','10',0,''),(57907,18405,'119074','deals-mobile','font_size_measure','em',0,''),(57908,18405,'119074','deals-mobile','font-size','1.2',0,''),(57909,18406,'119075','deals-mobile','text-align','right',0,''),(57910,18407,'119076','deals-mobile','block_type','2',0,''),(57911,18408,'119077','deals-mobile','block_type','1',0,''),(57912,18408,'119077','deals-mobile','padding-left','0',0,''),(57913,18408,'119077','deals-mobile','padding-right','20',0,''),(57914,18409,'119078','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57915,18411,'119080','deals-mobile','block_type','1',0,''),(57916,18411,'119080','deals-mobile','padding-left','20',0,''),(57918,18412,'119081','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57919,18417,'119086','deals-mobile','block_type','4',0,''),(57920,18417,'119086','deals-mobile','schema','4-2',0,''),(57921,18418,'119087','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57922,18418,'119087','deals-mobile','text-align','right',0,''),(57923,18418,'119087','deals-mobile','padding-top','10',0,''),(57924,18418,'119087','deals-mobile','font_size_measure','em',0,''),(57925,18418,'119087','deals-mobile','font-size','1.2',0,''),(57926,18419,'119088','deals-mobile','text-align','right',0,''),(57927,18420,'119089','deals-mobile','block_type','4',0,''),(57928,18420,'119089','deals-mobile','schema','4-2',0,''),(57929,18421,'119090','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57930,18421,'119090','deals-mobile','text-align','right',0,''),(57931,18421,'119090','deals-mobile','padding-top','10',0,''),(57932,18421,'119090','deals-mobile','font_size_measure','em',0,''),(57933,18421,'119090','deals-mobile','font-size','1.2',0,''),(57934,18422,'119091','deals-mobile','text-align','right',0,''),(57935,18423,'119092','deals-mobile','block_type','2',0,''),(57936,18424,'119093','deals-mobile','block_type','1',0,''),(57937,18424,'119093','deals-mobile','padding-left','0',0,''),(57938,18424,'119093','deals-mobile','padding-right','20',0,''),(57939,18426,'119095','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57940,18427,'119096','deals-mobile','block_type','1',0,''),(57941,18427,'119096','deals-mobile','padding-left','20',0,''),(57943,18429,'119098','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57944,18433,'119102','deals-mobile','text','##PAYMENT_DETAILS##',0,''),(57945,18434,'119103','deals-mobile','text','##PAYMENT_DETAILS##',0,''),(57946,18435,'119104','deals-mobile','text','##PAYMENT_DETAILS##',0,''),(57947,18436,'119105','deals-mobile','text','##PAYMENT_DETAILS##',0,''),(57948,18437,'119106','deals-mobile','text','##PAYMENT_DETAILS##',0,''),(57949,18438,'119107','deals-mobile','text','##PAYMENT_DETAILS##',0,''),(57950,18439,'119108','deals-mobile','block_type','1',0,''),(57951,18439,'119108','deals-mobile','background-color','#eeeeee',0,''),(57952,18439,'119108','deals-mobile','padding-top','30',0,''),(57953,18439,'119108','deals-mobile','padding-bottom','30',0,''),(57954,18440,'119109','deals-mobile','block_type','4',0,''),(57955,18440,'119109','deals-mobile','schema','4-2',0,''),(57956,18441,'119110','deals-mobile','block_type','1',0,''),(57957,18441,'119110','deals-mobile','padding-right','40',0,''),(57959,18442,'119111','deals-mobile','block_type','1',0,''),(57960,18442,'119111','deals-mobile','padding-top','30',0,''),(57961,18442,'119111','deals-mobile','padding-left','30',0,''),(57962,18442,'119111','deals-mobile','padding-right','30',0,''),(57963,18442,'119111','deals-mobile','padding-bottom','23',0,''),(57964,18442,'119111','deals-mobile','margin-bottom','20',0,''),(57965,18442,'119111','deals-mobile','background-color','#ffffff',0,''),(57966,18442,'119111','deals-mobile','style_class','hiding-box',0,''),(57967,18443,'119112','deals-mobile','block_type','2',0,''),(57968,18443,'119112','deals-mobile','schema','2-2',0,''),(57969,18444,'119113','deals-mobile','padding-right','20',0,''),(57971,18444,'119113','deals-mobile','padding-bottom','20',0,''),(57972,18445,'119114','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57973,18446,'119115','deals-mobile','block_type','1',0,''),(57974,18446,'119115','deals-mobile','padding-left','20',0,''),(57976,18447,'119116','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57977,18449,'119118','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(57978,18450,'119119','deals-mobile','block_type','1',0,''),(57979,18450,'119119','deals-mobile','background-color','#ffffff',0,''),(57980,18450,'119119','deals-mobile','padding-top','30',0,''),(57981,18450,'119119','deals-mobile','padding-left','30',0,''),(57982,18450,'119119','deals-mobile','padding-right','30',0,''),(57983,18450,'119119','deals-mobile','padding-bottom','14',0,''),(57984,18450,'119119','deals-mobile','margin-bottom','20',0,''),(57985,18450,'119119','deals-mobile','style_class','hiding-box closeable-box',0,''),(57986,18451,'119120','deals-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(57987,18451,'119120','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57988,18452,'119121','deals-mobile','style_class','closeable-content',0,''),(57989,18452,'119121','deals-mobile','padding-bottom','20',0,''),(57990,18453,'119122','deals-mobile','background-color','#ffffff',0,''),(57991,18453,'119122','deals-mobile','padding-top','30',0,''),(57992,18453,'119122','deals-mobile','padding-left','30',0,''),(57993,18453,'119122','deals-mobile','padding-right','30',0,''),(57994,18453,'119122','deals-mobile','padding-bottom','30',0,''),(57995,18453,'119122','deals-mobile','margin-bottom','20',0,''),(57996,18454,'119123','deals-mobile','background-color','#ffffff',0,''),(57997,18454,'119123','deals-mobile','block_type','1',0,''),(57998,18454,'119123','deals-mobile','padding-top','30',0,''),(57999,18454,'119123','deals-mobile','padding-left','30',0,''),(58000,18454,'119123','deals-mobile','padding-right','30',0,''),(58001,18454,'119123','deals-mobile','padding-bottom','30',0,''),(58002,18454,'119123','deals-mobile','margin-bottom','20',0,''),(58003,18454,'119123','deals-mobile','style_class','hiding-box',0,''),(58004,18455,'119124','deals-mobile','block_type','2',0,''),(58005,18455,'119124','deals-mobile','schema','2-2',0,''),(58006,18456,'119125','deals-mobile','block_type','1',0,''),(58007,18456,'119125','deals-mobile','padding-right','20',0,''),(58008,18456,'119125','deals-mobile','padding-left','0',0,''),(58009,18456,'119125','deals-mobile','margin-bottom','20',0,''),(58010,18457,'119126','deals-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(58011,18460,'119129','deals-mobile','block_type','1',0,''),(58012,18460,'119129','deals-mobile','padding-left','20',0,''),(58014,18461,'119130','deals-mobile','border-top-width','1',0,''),(58015,18461,'119130','deals-mobile','border-top-color','#e0e0e0',0,''),(58016,18461,'119130','deals-mobile','padding-top','13',0,''),(58017,18461,'119130','deals-mobile','padding-bottom','10',0,''),(58018,18462,'119131','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(58019,18464,'119133','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(58020,18465,'119134','deals-mobile','background-color','#eeeeee',0,''),(58021,18465,'119134','deals-mobile','padding-top','10',0,''),(58022,18465,'119134','deals-mobile','padding-left','10',0,''),(58023,18465,'119134','deals-mobile','padding-right','10',0,''),(58024,18465,'119134','deals-mobile','padding-bottom','10',0,''),(58025,18465,'119134','deals-mobile','margin-top','10',0,''),(58026,18466,'119135','deals-mobile','block_type','1',0,''),(58027,18466,'119135','deals-mobile','content','\\_',0,'3'),(58028,18466,'119135','deals-mobile','border-top-width','1',0,'3'),(58029,18466,'119135','deals-mobile','border-top-color','#e0e0e0',0,'3'),(58030,18466,'119135','deals-mobile','display','block',0,'3'),(58031,18466,'119135','deals-mobile','position','absolute',0,'3'),(58032,18466,'119135','deals-mobile','top','19',0,'3'),(58033,18466,'119135','deals-mobile','left','0',0,'3'),(58034,18466,'119135','deals-mobile','right','0',0,'3'),(58035,18466,'119135','deals-mobile','margin-top','-2',0,'3'),(58036,18466,'119135','deals-mobile','position','relative',0,''),(58037,18467,'119136','deals-mobile','box_align','2',0,''),(58038,18467,'119136','deals-mobile','margin-bottom','10',0,''),(58039,18467,'119136','deals-mobile','background-color','#ffffff',0,''),(58040,18467,'119136','deals-mobile','position','relative',0,''),(58041,18468,'119137','deals-mobile','block_type','1',0,''),(58042,18468,'119137','deals-mobile','background-color','#ffffff',0,''),(58043,18468,'119137','deals-mobile','padding-top','30',0,''),(58044,18468,'119137','deals-mobile','padding-left','30',0,''),(58045,18468,'119137','deals-mobile','padding-right','30',0,''),(58046,18468,'119137','deals-mobile','padding-bottom','30',0,''),(58047,18468,'119137','deals-mobile','margin-bottom','20',0,''),(58048,18468,'119137','deals-mobile','style_class','hiding-box',0,''),(58049,18469,'119138','deals-mobile','margin-bottom','20',0,''),(58050,18470,'119139','deals-mobile','padding-top','10',0,''),(58051,18470,'119139','deals-mobile','padding-left','20',0,''),(58052,18470,'119139','deals-mobile','padding-right','20',0,''),(58053,18470,'119139','deals-mobile','margin-top','20',0,''),(58054,18470,'119139','deals-mobile','background-color','#eeeeee',0,''),(58055,18470,'119139','deals-mobile','padding-bottom','8',0,''),(58056,18471,'119140','deals-mobile','block_type','1',0,''),(58057,18471,'119140','deals-mobile','padding-top','20',0,''),(58058,18471,'119140','deals-mobile','padding-left','20',0,''),(58059,18471,'119140','deals-mobile','padding-right','20',0,''),(58060,18471,'119140','deals-mobile','padding-bottom','20',0,''),(58061,18471,'119140','deals-mobile','background-color','#ffffff',0,''),(58062,18471,'119140','deals-mobile','style_class','order-summary',0,''),(58063,18473,'119142','deals-mobile','margin-bottom','10',0,''),(58064,18474,'119143','deals-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(58065,18474,'119143','deals-mobile','text-align','center',0,''),(58066,18474,'119143','deals-mobile','font-size','14',0,''),(58067,18474,'119143','deals-mobile','color','#757575',0,''),(58068,18474,'119143','deals-mobile','padding-top','10',0,''),(58069,18475,'119144','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58070,18476,'119145','deals-mobile','block_type','1',0,''),(58071,18476,'119145','deals-mobile','padding-top','30',0,''),(58072,18476,'119145','deals-mobile','padding-bottom','30',0,''),(58073,18476,'119145','deals-mobile','background-color','#eeeeeh',0,''),(58074,18477,'119146','deals-mobile','block_type','4',0,''),(58075,18477,'119146','deals-mobile','schema','4-2',0,''),(58076,18478,'119147','deals-mobile','block_type','1',0,''),(58077,18478,'119147','deals-mobile','padding-right','40',0,''),(58079,18479,'119148','deals-mobile','block_type','1',0,''),(58080,18479,'119148','deals-mobile','padding-top','30',0,''),(58081,18479,'119148','deals-mobile','padding-left','30',0,''),(58082,18479,'119148','deals-mobile','padding-right','30',0,''),(58083,18479,'119148','deals-mobile','padding-bottom','14',0,''),(58084,18479,'119148','deals-mobile','margin-bottom','20',0,''),(58085,18479,'119148','deals-mobile','background-color','#ffffff',0,''),(58086,18479,'119148','deals-mobile','style_class','hiding-box closeable-box',0,''),(58087,18480,'119149','deals-mobile','block_type','2',0,''),(58088,18480,'119149','deals-mobile','style_class','closeable-content',0,''),(58089,18480,'119149','deals-mobile','schema','2-2',0,''),(58090,18481,'119150','deals-mobile','padding-right','20',0,''),(58091,18481,'119150','deals-mobile','padding-bottom','20',0,''),(58093,18482,'119151','deals-mobile','padding-left','20',0,''),(58094,18482,'119151','deals-mobile','padding-bottom','20',0,''),(58096,18483,'119152','deals-mobile','padding-left','20',0,''),(58097,18483,'119152','deals-mobile','padding-bottom','20',0,''),(58099,18484,'119153','deals-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(58100,18484,'119153','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(58101,18485,'119154','deals-mobile','block_type','1',0,''),(58102,18485,'119154','deals-mobile','padding-top','30',0,''),(58103,18485,'119154','deals-mobile','padding-left','30',0,''),(58104,18485,'119154','deals-mobile','padding-right','30',0,''),(58105,18485,'119154','deals-mobile','padding-bottom','23',0,''),(58106,18485,'119154','deals-mobile','margin-bottom','20',0,''),(58107,18485,'119154','deals-mobile','background-color','#ffffff',0,''),(58108,18485,'119154','deals-mobile','style_class','hiding-box',0,''),(58109,18486,'119155','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(58110,18487,'119156','deals-mobile','block_type','2',0,''),(58111,18487,'119156','deals-mobile','schema','2-2',0,''),(58112,18488,'119157','deals-mobile','padding-right','20',0,''),(58114,18488,'119157','deals-mobile','padding-bottom','20',0,''),(58115,18489,'119158','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(58116,18490,'119159','deals-mobile','block_type','1',0,''),(58117,18490,'119159','deals-mobile','padding-left','20',0,''),(58119,18492,'119161','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(58120,18493,'119162','deals-mobile','block_type','1',0,''),(58121,18493,'119162','deals-mobile','background-color','#ffffff',0,''),(58122,18493,'119162','deals-mobile','padding-top','30',0,''),(58123,18493,'119162','deals-mobile','padding-left','30',0,''),(58124,18493,'119162','deals-mobile','padding-right','30',0,''),(58125,18493,'119162','deals-mobile','padding-bottom','14',0,''),(58126,18493,'119162','deals-mobile','margin-bottom','20',0,''),(58127,18493,'119162','deals-mobile','style_class','hiding-box closeable-box',0,''),(58128,18494,'119163','deals-mobile','style_class','closeable-content',0,''),(58129,18494,'119163','deals-mobile','padding-bottom','20',0,''),(58130,18495,'119164','deals-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(58131,18495,'119164','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(58132,18496,'119165','deals-mobile','background-color','#ffffff',0,''),(58133,18496,'119165','deals-mobile','block_type','1',0,''),(58134,18496,'119165','deals-mobile','padding-top','30',0,''),(58135,18496,'119165','deals-mobile','padding-left','30',0,''),(58136,18496,'119165','deals-mobile','padding-right','30',0,''),(58137,18496,'119165','deals-mobile','padding-bottom','30',0,''),(58138,18496,'119165','deals-mobile','margin-bottom','20',0,''),(58139,18496,'119165','deals-mobile','style_class','hiding-box',0,''),(58140,18497,'119166','deals-mobile','block_type','1',0,''),(58141,18497,'119166','deals-mobile','content','\\_',0,'3'),(58142,18497,'119166','deals-mobile','border-top-width','1',0,'3'),(58143,18497,'119166','deals-mobile','border-top-color','#e0e0e0',0,'3'),(58144,18497,'119166','deals-mobile','display','block',0,'3'),(58145,18497,'119166','deals-mobile','position','absolute',0,'3'),(58146,18497,'119166','deals-mobile','top','19',0,'3'),(58147,18497,'119166','deals-mobile','left','0',0,'3'),(58148,18497,'119166','deals-mobile','right','0',0,'3'),(58149,18497,'119166','deals-mobile','margin-top','-2',0,'3'),(58150,18497,'119166','deals-mobile','position','relative',0,''),(58151,18498,'119167','deals-mobile','box_align','2',0,''),(58152,18498,'119167','deals-mobile','margin-bottom','10',0,''),(58153,18498,'119167','deals-mobile','background-color','#ffffff',0,''),(58154,18498,'119167','deals-mobile','position','relative',0,''),(58155,18499,'119168','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(58156,18500,'119169','deals-mobile','block_type','2',0,''),(58157,18500,'119169','deals-mobile','schema','2-2',0,''),(58158,18501,'119170','deals-mobile','block_type','1',0,''),(58159,18501,'119170','deals-mobile','padding-right','20',0,''),(58160,18501,'119170','deals-mobile','padding-left','0',0,''),(58161,18501,'119170','deals-mobile','margin-bottom','20',0,''),(58162,18503,'119172','deals-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(58163,18505,'119174','deals-mobile','block_type','1',0,''),(58164,18505,'119174','deals-mobile','padding-left','20',0,''),(58166,18506,'119175','deals-mobile','border-top-width','1',0,''),(58167,18506,'119175','deals-mobile','border-top-color','#e0e0e0',0,''),(58168,18506,'119175','deals-mobile','padding-top','13',0,''),(58169,18506,'119175','deals-mobile','padding-bottom','10',0,''),(58170,18507,'119176','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(58171,18509,'119178','deals-mobile','background-color','#eeeeee',0,''),(58172,18509,'119178','deals-mobile','padding-top','10',0,''),(58173,18509,'119178','deals-mobile','padding-left','10',0,''),(58174,18509,'119178','deals-mobile','padding-right','10',0,''),(58175,18509,'119178','deals-mobile','padding-bottom','10',0,''),(58176,18509,'119178','deals-mobile','margin-top','10',0,''),(58177,18510,'119179','deals-mobile','block_type','1',0,''),(58178,18510,'119179','deals-mobile','background-color','#ffffff',0,''),(58179,18510,'119179','deals-mobile','padding-top','30',0,''),(58180,18510,'119179','deals-mobile','padding-left','30',0,''),(58181,18510,'119179','deals-mobile','padding-right','30',0,''),(58182,18510,'119179','deals-mobile','padding-bottom','30',0,''),(58183,18510,'119179','deals-mobile','margin-bottom','20',0,''),(58184,18510,'119179','deals-mobile','style_class','hiding-box',0,''),(58185,18511,'119180','deals-mobile','padding-top','10',0,''),(58186,18511,'119180','deals-mobile','padding-left','20',0,''),(58187,18511,'119180','deals-mobile','padding-right','20',0,''),(58188,18511,'119180','deals-mobile','margin-top','20',0,''),(58189,18511,'119180','deals-mobile','background-color','#eeeeee',0,''),(58190,18511,'119180','deals-mobile','padding-bottom','8',0,''),(58191,18512,'119181','deals-mobile','margin-bottom','20',0,''),(58192,18513,'119182','deals-mobile','background-color','#ffffff',0,''),(58193,18513,'119182','deals-mobile','padding-top','30',0,''),(58194,18513,'119182','deals-mobile','padding-left','30',0,''),(58195,18513,'119182','deals-mobile','padding-right','30',0,''),(58196,18513,'119182','deals-mobile','padding-bottom','30',0,''),(58197,18513,'119182','deals-mobile','margin-bottom','20',0,''),(58198,18514,'119183','deals-mobile','block_type','1',0,''),(58199,18514,'119183','deals-mobile','padding-top','20',0,''),(58200,18514,'119183','deals-mobile','padding-left','20',0,''),(58201,18514,'119183','deals-mobile','padding-right','20',0,''),(58202,18514,'119183','deals-mobile','padding-bottom','20',0,''),(58203,18514,'119183','deals-mobile','background-color','#ffffff',0,''),(58204,18514,'119183','deals-mobile','style_class','order-summary',0,''),(58205,18515,'119184','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58206,18517,'119186','deals-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(58207,18517,'119186','deals-mobile','text-align','center',0,''),(58208,18517,'119186','deals-mobile','font-size','14',0,''),(58209,18517,'119186','deals-mobile','color','#757575',0,''),(58210,18517,'119186','deals-mobile','padding-top','10',0,''),(58211,18518,'119187','deals-mobile','margin-bottom','10',0,''),(58212,18521,'119190','deals-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(58213,18524,'119193','deals-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(58214,18525,'119194','deals-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(58215,18528,'119197','deals-mobile','style_class','order-summary',0,''),(58216,18528,'119197','deals-mobile','box_align','3',0,''),(58217,18528,'119197','deals-mobile','width','400',0,''),(58218,18529,'119198','deals-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(58219,18531,'119200','deals-mobile','block_type','1',0,''),(58220,18532,'119201','deals-mobile','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(58221,18533,'119202','deals-mobile','margin-bottom','30',0,''),(58222,18534,'119203','deals-mobile','float','right',0,''),(58223,18534,'119203','deals-mobile','position','relative',0,''),(58224,18534,'119203','deals-mobile','z-index','1',0,''),(58225,18534,'119203','deals-mobile','top','30',0,''),(58226,18534,'119203','deals-mobile','margin-bottom','-20',0,''),(58227,18535,'119204','deals-mobile','block_type','1',0,''),(58228,18536,'119205','deals-mobile','listing_type','Compare Products',0,''),(58229,18537,'119206','deals-mobile','block_type','1',0,''),(58230,18537,'119206','deals-mobile','style_class','item-holder',0,''),(58231,18537,'119206','deals-mobile','padding-top','10',0,''),(58232,18537,'119206','deals-mobile','padding-left','20',0,''),(58233,18537,'119206','deals-mobile','padding-right','20',0,''),(58234,18537,'119206','deals-mobile','padding-bottom','10',0,''),(58235,18537,'119206','deals-mobile','text-align','left',0,''),(58236,18540,'119209','deals-mobile','margin-bottom','10',0,''),(58237,18541,'119210','deals-mobile','block_type','5',0,''),(58238,18543,'119212','deals-mobile','clear','both',0,''),(58239,18544,'119213','deals-mobile','block_type','2',0,''),(58240,18545,'119214','deals-mobile','margin-bottom','7',0,''),(58241,18546,'119215','deals-mobile','text-align','right',0,''),(58242,18546,'119215','deals-mobile','margin-bottom','10',0,''),(58243,18546,'119215','deals-mobile','float','right',0,''),(58244,18547,'119216','deals-mobile','block_type','1',0,''),(58245,18547,'119216','deals-mobile','background-color','#eeeeee',0,''),(58246,18547,'119216','deals-mobile','padding-bottom','30',0,''),(58247,18548,'119217','deals-mobile','block_type','1',0,''),(58248,18548,'119217','deals-mobile','schema','4-2',0,''),(58249,18548,'119217','deals-mobile','schema','4-2',0,'872'),(58250,18550,'119219','deals-mobile','block_type','1',0,''),(58251,18550,'119219','deals-mobile','padding-right','40',0,''),(58253,18551,'119220','deals-mobile','block_type','1',0,''),(58254,18551,'119220','deals-mobile','margin-bottom','20',0,''),(58255,18551,'119220','deals-mobile','schema','2-2',0,''),(58256,18551,'119220','deals-mobile','background-color','#ffffff',0,''),(58257,18552,'119221','deals-mobile','block_type','1',0,''),(58258,18552,'119221','deals-mobile','border-right-width','20',0,''),(58259,18552,'119221','deals-mobile','border-right-color','#e0e0e0',0,''),(58260,18552,'119221','deals-mobile','margin-right','-10',0,''),(58261,18552,'119221','deals-mobile','padding-right','30',0,''),(58262,18552,'119221','deals-mobile','padding-top','20',0,''),(58263,18552,'119221','deals-mobile','padding-left','30',0,''),(58264,18552,'119221','deals-mobile','padding-bottom','20',0,''),(58267,18552,'119221','deals-mobile','margin-bottom','20',0,''),(58270,18553,'119222','deals-mobile','margin-bottom','20',0,''),(58271,18554,'119223','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(58272,18555,'119224','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(58273,18555,'119224','deals-mobile','clear','none',0,''),(58274,18557,'119226','deals-mobile','link','shipping_address',0,''),(58275,18557,'119226','deals-mobile','float','right',0,''),(58276,18557,'119226','deals-mobile','margin-top','-31',0,''),(58277,18558,'119227','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(58278,18558,'119227','deals-mobile','clear','none',0,''),(58279,18560,'119229','deals-mobile','link','contact_information',0,''),(58280,18560,'119229','deals-mobile','margin-top','-31',0,''),(58281,18560,'119229','deals-mobile','float','right',0,''),(58282,18561,'119230','deals-mobile','link','shipping_method',0,''),(58283,18561,'119230','deals-mobile','float','right',0,''),(58284,18561,'119230','deals-mobile','margin-top','-31',0,''),(58285,18562,'119231','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(58286,18562,'119231','deals-mobile','padding-top','20',0,''),(58287,18564,'119233','deals-mobile','block_type','1',0,''),(58288,18564,'119233','deals-mobile','padding-left','30',0,''),(58289,18564,'119233','deals-mobile','border-left-width','20',0,''),(58290,18564,'119233','deals-mobile','border-left-color','#e0e0e0',0,''),(58291,18564,'119233','deals-mobile','margin-left','-10',0,''),(58292,18564,'119233','deals-mobile','padding-right','30',0,''),(58293,18564,'119233','deals-mobile','padding-top','20',0,''),(58294,18564,'119233','deals-mobile','padding-bottom','20',0,''),(58296,18565,'119234','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(58297,18565,'119234','deals-mobile','clear','none',0,''),(58298,18566,'119235','deals-mobile','margin-bottom','20',0,''),(58299,18567,'119236','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(58300,18567,'119236','deals-mobile','clear','none',0,''),(58301,18569,'119238','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(58302,18570,'119239','deals-mobile','link','billing_address',0,''),(58303,18570,'119239','deals-mobile','float','right',0,''),(58304,18570,'119239','deals-mobile','margin-top','-31',0,''),(58305,18571,'119240','deals-mobile','link','payment_method',0,''),(58306,18571,'119240','deals-mobile','float','right',0,''),(58307,18571,'119240','deals-mobile','margin-top','-31',0,''),(58308,18572,'119241','deals-mobile','block_type','1',0,''),(58309,18572,'119241','deals-mobile','padding-right','30',0,''),(58310,18572,'119241','deals-mobile','background-color','#ffffff',0,''),(58311,18572,'119241','deals-mobile','padding-top','20',0,''),(58312,18572,'119241','deals-mobile','padding-left','30',0,''),(58313,18572,'119241','deals-mobile','padding-bottom','20',0,''),(58316,18573,'119242','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(58317,18574,'119243','deals-mobile','link','products',0,''),(58318,18574,'119243','deals-mobile','float','right',0,''),(58319,18574,'119243','deals-mobile','margin-top','-37',0,''),(58320,18576,'119245','deals-mobile','block_type','1',0,''),(58321,18576,'119245','deals-mobile','background-color','#ffffff',0,'');
INSERT INTO `design_boxes_settings` VALUES (58322,18576,'119245','deals-mobile','padding-top','20',0,''),(58323,18576,'119245','deals-mobile','padding-bottom','20',0,''),(58324,18576,'119245','deals-mobile','padding-left','30',0,''),(58325,18576,'119245','deals-mobile','padding-right','30',0,''),(58326,18576,'119245','deals-mobile','margin-bottom','20',0,''),(58327,18577,'119246','deals-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(58328,18578,'119247','deals-mobile','hide_parents','2',0,''),(58329,18579,'119248','deals-mobile','float','right',0,''),(58330,18579,'119248','deals-mobile','margin-top','-37',0,''),(58331,18579,'119248','deals-mobile','link','comments',0,''),(58332,18580,'119249','deals-mobile','block_type','1',0,''),(58333,18580,'119249','deals-mobile','padding-top','20',0,''),(58334,18580,'119249','deals-mobile','padding-left','20',0,''),(58335,18580,'119249','deals-mobile','padding-right','20',0,''),(58336,18580,'119249','deals-mobile','padding-bottom','20',0,''),(58337,18580,'119249','deals-mobile','background-color','#ffffff',0,''),(58338,18580,'119249','deals-mobile','style_class','order-summary2 hiding-box',0,''),(58339,18582,'119251','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58340,18583,'119252','deals-mobile','margin-bottom','20',0,''),(58341,18583,'119252','deals-mobile','text-align','right',0,''),(58342,18584,'119253','deals-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(58343,18585,'119254','deals-mobile','block_type','1',0,''),(58344,18585,'119254','deals-mobile','background-color','#eeeeee',0,''),(58345,18585,'119254','deals-mobile','padding-bottom','30',0,''),(58346,18586,'119255','deals-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(58347,18587,'119256','deals-mobile','block_type','4',0,''),(58348,18587,'119256','deals-mobile','schema','4-2',0,''),(58349,18588,'119257','deals-mobile','block_type','1',0,''),(58350,18588,'119257','deals-mobile','padding-right','40',0,''),(58352,18589,'119258','deals-mobile','block_type','2',0,''),(58353,18589,'119258','deals-mobile','margin-bottom','20',0,''),(58354,18589,'119258','deals-mobile','schema','2-2',0,''),(58355,18589,'119258','deals-mobile','background-color','#ffffff',0,''),(58356,18590,'119259','deals-mobile','block_type','1',0,''),(58357,18590,'119259','deals-mobile','border-right-width','20',0,''),(58358,18590,'119259','deals-mobile','border-right-color','#e0e0e0',0,''),(58359,18590,'119259','deals-mobile','margin-right','-10',0,''),(58360,18590,'119259','deals-mobile','padding-right','30',0,''),(58361,18590,'119259','deals-mobile','padding-top','20',0,''),(58362,18590,'119259','deals-mobile','padding-left','30',0,''),(58363,18590,'119259','deals-mobile','padding-bottom','20',0,''),(58366,18590,'119259','deals-mobile','margin-bottom','20',0,''),(58369,18591,'119260','deals-mobile','link','shipping_method',0,''),(58370,18591,'119260','deals-mobile','float','right',0,''),(58371,18591,'119260','deals-mobile','margin-top','-31',0,''),(58372,18592,'119261','deals-mobile','margin-bottom','20',0,''),(58373,18593,'119262','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(58374,18593,'119262','deals-mobile','clear','none',0,''),(58375,18595,'119264','deals-mobile','link','shipping_address',0,''),(58376,18595,'119264','deals-mobile','float','right',0,''),(58377,18595,'119264','deals-mobile','margin-top','-31',0,''),(58378,18596,'119265','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(58379,18596,'119265','deals-mobile','clear','none',0,''),(58380,18597,'119266','deals-mobile','block_type','1',0,''),(58381,18597,'119266','deals-mobile','padding-left','30',0,''),(58382,18597,'119266','deals-mobile','border-left-width','20',0,''),(58383,18597,'119266','deals-mobile','border-left-color','#e0e0e0',0,''),(58384,18597,'119266','deals-mobile','margin-left','-10',0,''),(58385,18597,'119266','deals-mobile','padding-right','30',0,''),(58386,18597,'119266','deals-mobile','padding-top','20',0,''),(58387,18597,'119266','deals-mobile','padding-bottom','20',0,''),(58389,18598,'119267','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(58390,18599,'119268','deals-mobile','link','contact_information',0,''),(58391,18599,'119268','deals-mobile','margin-top','-31',0,''),(58392,18599,'119268','deals-mobile','float','right',0,''),(58393,18602,'119271','deals-mobile','block_type','1',0,''),(58394,18602,'119271','deals-mobile','background-color','#ffffff',0,''),(58395,18602,'119271','deals-mobile','padding-top','20',0,''),(58396,18602,'119271','deals-mobile','padding-bottom','20',0,''),(58397,18602,'119271','deals-mobile','padding-left','30',0,''),(58398,18602,'119271','deals-mobile','padding-right','30',0,''),(58399,18602,'119271','deals-mobile','margin-bottom','20',0,''),(58400,18603,'119272','deals-mobile','hide_parents','2',0,''),(58401,18604,'119273','deals-mobile','float','right',0,''),(58402,18604,'119273','deals-mobile','margin-top','-37',0,''),(58403,18604,'119273','deals-mobile','link','comments',0,''),(58404,18605,'119274','deals-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(58405,18606,'119275','deals-mobile','block_type','1',0,''),(58406,18606,'119275','deals-mobile','padding-right','30',0,''),(58407,18606,'119275','deals-mobile','background-color','#ffffff',0,''),(58408,18606,'119275','deals-mobile','padding-top','20',0,''),(58409,18606,'119275','deals-mobile','padding-left','30',0,''),(58410,18606,'119275','deals-mobile','padding-bottom','20',0,''),(58413,18608,'119277','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(58414,18609,'119278','deals-mobile','link','products',0,''),(58415,18609,'119278','deals-mobile','float','right',0,''),(58416,18609,'119278','deals-mobile','margin-top','-37',0,''),(58417,18610,'119279','deals-mobile','block_type','1',0,''),(58418,18610,'119279','deals-mobile','padding-top','20',0,''),(58419,18610,'119279','deals-mobile','padding-left','20',0,''),(58420,18610,'119279','deals-mobile','padding-right','20',0,''),(58421,18610,'119279','deals-mobile','padding-bottom','20',0,''),(58422,18610,'119279','deals-mobile','background-color','#ffffff',0,''),(58423,18610,'119279','deals-mobile','style_class','order-summary',0,''),(58424,18611,'119280','deals-mobile','margin-bottom','20',0,''),(58425,18611,'119280','deals-mobile','text-align','right',0,''),(58426,18612,'119281','deals-mobile','block_type','1',0,''),(58427,18612,'119281','deals-mobile','background-color','#eeeeee',0,''),(58428,18612,'119281','deals-mobile','padding-bottom','30',0,''),(58429,18613,'119282','deals-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(58430,18614,'119283','deals-mobile','block_type','4',0,''),(58431,18615,'119284','deals-mobile','block_type','1',0,''),(58432,18615,'119284','deals-mobile','padding-right','40',0,''),(58433,18616,'119285','deals-mobile','block_type','1',0,''),(58434,18616,'119285','deals-mobile','padding-right','30',0,''),(58436,18616,'119285','deals-mobile','background-color','#ffffff',0,''),(58437,18616,'119285','deals-mobile','padding-top','20',0,''),(58438,18616,'119285','deals-mobile','padding-left','30',0,''),(58439,18616,'119285','deals-mobile','padding-bottom','20',0,''),(58440,18617,'119286','deals-mobile','link','products',0,''),(58441,18617,'119286','deals-mobile','float','right',0,''),(58442,18617,'119286','deals-mobile','margin-top','-37',0,''),(58443,18618,'119287','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(58444,18620,'119289','deals-mobile','block_type','1',0,''),(58445,18620,'119289','deals-mobile','background-color','#ffffff',0,''),(58446,18620,'119289','deals-mobile','padding-top','20',0,''),(58447,18620,'119289','deals-mobile','padding-bottom','20',0,''),(58448,18620,'119289','deals-mobile','padding-left','30',0,''),(58449,18620,'119289','deals-mobile','padding-right','30',0,''),(58450,18620,'119289','deals-mobile','margin-bottom','20',0,''),(58451,18621,'119290','deals-mobile','float','right',0,''),(58452,18621,'119290','deals-mobile','margin-top','-37',0,''),(58453,18621,'119290','deals-mobile','link','comments',0,''),(58454,18622,'119291','deals-mobile','hide_parents','2',0,''),(58455,18623,'119292','deals-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(58456,18624,'119293','deals-mobile','block_type','2',0,''),(58457,18624,'119293','deals-mobile','margin-bottom','20',0,''),(58458,18624,'119293','deals-mobile','schema','2-2',0,''),(58459,18624,'119293','deals-mobile','background-color','#ffffff',0,''),(58460,18625,'119294','deals-mobile','block_type','1',0,''),(58461,18625,'119294','deals-mobile','padding-right','0',0,''),(58462,18625,'119294','deals-mobile','border-right-width','20',0,''),(58463,18625,'119294','deals-mobile','border-right-color','#e0e0e0',0,''),(58464,18625,'119294','deals-mobile','margin-right','-10',0,''),(58466,18625,'119294','deals-mobile','padding-top','20',0,''),(58467,18625,'119294','deals-mobile','padding-left','30',0,''),(58468,18625,'119294','deals-mobile','padding-bottom','20',0,''),(58469,18626,'119295','deals-mobile','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(58470,18626,'119295','deals-mobile','padding-top','20',0,''),(58471,18628,'119297','deals-mobile','link','contact_information',0,''),(58472,18628,'119297','deals-mobile','margin-top','-37',0,''),(58473,18628,'119297','deals-mobile','float','right',0,''),(58474,18629,'119298','deals-mobile','block_type','1',0,''),(58475,18629,'119298','deals-mobile','padding-left','30',0,''),(58477,18629,'119298','deals-mobile','border-left-width','20',0,''),(58478,18629,'119298','deals-mobile','border-left-color','#e0e0e0',0,''),(58479,18629,'119298','deals-mobile','margin-left','-10',0,''),(58480,18629,'119298','deals-mobile','padding-right','30',0,''),(58481,18629,'119298','deals-mobile','padding-top','20',0,''),(58482,18629,'119298','deals-mobile','padding-bottom','20',0,''),(58483,18630,'119299','deals-mobile','link','billing_address',0,''),(58484,18630,'119299','deals-mobile','float','right',0,''),(58485,18630,'119299','deals-mobile','margin-top','-31',0,''),(58486,18631,'119300','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(58487,18631,'119300','deals-mobile','clear','none',0,''),(58488,18632,'119301','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(58489,18633,'119302','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(58490,18633,'119302','deals-mobile','clear','none',0,''),(58491,18634,'119303','deals-mobile','margin-bottom','20',0,''),(58492,18636,'119305','deals-mobile','link','payment_method',0,''),(58493,18636,'119305','deals-mobile','float','right',0,''),(58494,18636,'119305','deals-mobile','margin-top','-31',0,''),(58495,18637,'119306','deals-mobile','block_type','1',0,''),(58496,18637,'119306','deals-mobile','padding-top','20',0,''),(58497,18637,'119306','deals-mobile','padding-left','20',0,''),(58498,18637,'119306','deals-mobile','padding-right','20',0,''),(58499,18637,'119306','deals-mobile','padding-bottom','20',0,''),(58500,18637,'119306','deals-mobile','background-color','#ffffff',0,''),(58501,18637,'119306','deals-mobile','style_class','order-summary2 hiding-box',0,''),(58502,18638,'119307','deals-mobile','margin-bottom','20',0,''),(58503,18638,'119307','deals-mobile','text-align','right',0,''),(58504,18640,'119309','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58505,18641,'119310','deals-mobile','block_type','1',0,''),(58506,18641,'119310','deals-mobile','background-color','#eeeeee',0,''),(58507,18641,'119310','deals-mobile','padding-bottom','30',0,''),(58508,18642,'119311','deals-mobile','block_type','4',0,''),(58509,18642,'119311','deals-mobile','schema','4-2',0,''),(58510,18643,'119312','deals-mobile','block_type','1',0,''),(58511,18643,'119312','deals-mobile','padding-right','40',0,''),(58513,18644,'119313','deals-mobile','block_type','1',0,''),(58514,18644,'119313','deals-mobile','padding-right','30',0,''),(58515,18644,'119313','deals-mobile','background-color','#ffffff',0,''),(58516,18644,'119313','deals-mobile','padding-top','20',0,''),(58517,18644,'119313','deals-mobile','padding-left','30',0,''),(58518,18644,'119313','deals-mobile','padding-bottom','20',0,''),(58521,18645,'119314','deals-mobile','margin-bottom','20',0,''),(58522,18646,'119315','deals-mobile','link','products',0,''),(58523,18646,'119315','deals-mobile','float','right',0,''),(58524,18646,'119315','deals-mobile','margin-top','-37',0,''),(58525,18647,'119316','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(58526,18648,'119317','deals-mobile','block_type','2',0,''),(58527,18648,'119317','deals-mobile','margin-bottom','20',0,''),(58528,18648,'119317','deals-mobile','schema','2-2',0,''),(58529,18648,'119317','deals-mobile','background-color','#ffffff',0,''),(58530,18649,'119318','deals-mobile','block_type','1',0,''),(58531,18649,'119318','deals-mobile','border-right-width','20',0,''),(58532,18649,'119318','deals-mobile','border-right-color','#e0e0e0',0,''),(58533,18649,'119318','deals-mobile','margin-right','-10',0,''),(58534,18649,'119318','deals-mobile','padding-right','30',0,''),(58535,18649,'119318','deals-mobile','padding-top','20',0,''),(58536,18649,'119318','deals-mobile','padding-left','30',0,''),(58537,18649,'119318','deals-mobile','padding-bottom','20',0,''),(58540,18649,'119318','deals-mobile','margin-bottom','20',0,''),(58543,18650,'119319','deals-mobile','link','payment_method',0,''),(58544,18650,'119319','deals-mobile','float','right',0,''),(58545,18650,'119319','deals-mobile','margin-top','-31',0,''),(58546,18651,'119320','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(58547,18651,'119320','deals-mobile','clear','none',0,''),(58548,18652,'119321','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(58549,18652,'119321','deals-mobile','padding-top','20',0,''),(58550,18654,'119323','deals-mobile','link','contact_information',0,''),(58551,18654,'119323','deals-mobile','margin-top','-31',0,''),(58552,18654,'119323','deals-mobile','float','right',0,''),(58553,18656,'119325','deals-mobile','block_type','1',0,''),(58554,18656,'119325','deals-mobile','padding-left','30',0,''),(58555,18656,'119325','deals-mobile','border-left-width','20',0,''),(58556,18656,'119325','deals-mobile','border-left-color','#e0e0e0',0,''),(58557,18656,'119325','deals-mobile','margin-left','-10',0,''),(58558,18656,'119325','deals-mobile','padding-right','30',0,''),(58559,18656,'119325','deals-mobile','padding-top','20',0,''),(58560,18656,'119325','deals-mobile','padding-bottom','20',0,''),(58562,18657,'119326','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(58563,18657,'119326','deals-mobile','clear','none',0,''),(58564,18658,'119327','deals-mobile','link','billing_address',0,''),(58565,18658,'119327','deals-mobile','float','right',0,''),(58566,18658,'119327','deals-mobile','margin-top','-31',0,''),(58567,18659,'119328','deals-mobile','margin-bottom','20',0,''),(58568,18660,'119329','deals-mobile','block_type','1',0,''),(58569,18660,'119329','deals-mobile','background-color','#ffffff',0,''),(58570,18660,'119329','deals-mobile','padding-top','20',0,''),(58571,18660,'119329','deals-mobile','padding-bottom','20',0,''),(58572,18660,'119329','deals-mobile','padding-left','30',0,''),(58573,18660,'119329','deals-mobile','padding-right','30',0,''),(58574,18660,'119329','deals-mobile','margin-bottom','20',0,''),(58575,18661,'119330','deals-mobile','hide_parents','2',0,''),(58576,18662,'119331','deals-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(58577,18663,'119332','deals-mobile','float','right',0,''),(58578,18663,'119332','deals-mobile','margin-top','-37',0,''),(58579,18663,'119332','deals-mobile','link','comments',0,''),(58580,18664,'119333','deals-mobile','block_type','1',0,''),(58581,18664,'119333','deals-mobile','padding-top','20',0,''),(58582,18664,'119333','deals-mobile','padding-left','20',0,''),(58583,18664,'119333','deals-mobile','padding-right','20',0,''),(58584,18664,'119333','deals-mobile','padding-bottom','20',0,''),(58585,18664,'119333','deals-mobile','background-color','#ffffff',0,''),(58586,18664,'119333','deals-mobile','style_class','order-summary',0,''),(58587,18665,'119334','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58588,18667,'119336','deals-mobile','margin-bottom','20',0,''),(58589,18667,'119336','deals-mobile','text-align','right',0,''),(58590,18668,'119337','deals-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(58591,18669,'119338','deals-mobile','block_type','1',0,''),(58592,18669,'119338','deals-mobile','background-color','#eeeeee',0,''),(58593,18669,'119338','deals-mobile','padding-bottom','30',0,''),(58594,18670,'119339','deals-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(58595,18671,'119340','deals-mobile','block_type','4',0,''),(58596,18671,'119340','deals-mobile','schema','4-2',0,''),(58597,18672,'119341','deals-mobile','block_type','1',0,''),(58598,18672,'119341','deals-mobile','padding-right','40',0,''),(58600,18673,'119342','deals-mobile','block_type','1',0,''),(58601,18673,'119342','deals-mobile','padding-right','30',0,''),(58602,18673,'119342','deals-mobile','background-color','#ffffff',0,''),(58603,18673,'119342','deals-mobile','padding-top','20',0,''),(58604,18673,'119342','deals-mobile','padding-left','30',0,''),(58605,18673,'119342','deals-mobile','padding-bottom','20',0,''),(58608,18674,'119343','deals-mobile','link','products',0,''),(58609,18674,'119343','deals-mobile','float','right',0,''),(58610,18674,'119343','deals-mobile','margin-top','-37',0,''),(58611,18675,'119344','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(58612,18677,'119346','deals-mobile','block_type','1',0,''),(58613,18677,'119346','deals-mobile','background-color','#ffffff',0,''),(58614,18677,'119346','deals-mobile','padding-top','20',0,''),(58615,18677,'119346','deals-mobile','padding-bottom','20',0,''),(58616,18677,'119346','deals-mobile','padding-left','30',0,''),(58617,18677,'119346','deals-mobile','padding-right','30',0,''),(58618,18677,'119346','deals-mobile','margin-bottom','20',0,''),(58619,18678,'119347','deals-mobile','float','right',0,''),(58620,18678,'119347','deals-mobile','margin-top','-37',0,''),(58621,18678,'119347','deals-mobile','link','comments',0,''),(58622,18679,'119348','deals-mobile','hide_parents','2',0,''),(58623,18680,'119349','deals-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(58624,18681,'119350','deals-mobile','block_type','2',0,''),(58625,18681,'119350','deals-mobile','margin-bottom','20',0,''),(58626,18681,'119350','deals-mobile','schema','2-2',0,''),(58627,18681,'119350','deals-mobile','background-color','#ffffff',0,''),(58628,18682,'119351','deals-mobile','block_type','1',0,''),(58629,18682,'119351','deals-mobile','border-right-width','20',0,''),(58630,18682,'119351','deals-mobile','border-right-color','#e0e0e0',0,''),(58631,18682,'119351','deals-mobile','margin-right','-10',0,''),(58632,18682,'119351','deals-mobile','padding-right','30',0,''),(58633,18682,'119351','deals-mobile','padding-top','20',0,''),(58634,18682,'119351','deals-mobile','padding-left','30',0,''),(58635,18682,'119351','deals-mobile','padding-bottom','20',0,''),(58638,18682,'119351','deals-mobile','margin-bottom','20',0,''),(58641,18683,'119352','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(58642,18683,'119352','deals-mobile','clear','none',0,''),(58643,18684,'119353','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(58644,18684,'119353','deals-mobile','padding-top','20',0,''),(58645,18685,'119354','deals-mobile','link','shipping_method',0,''),(58646,18685,'119354','deals-mobile','float','right',0,''),(58647,18685,'119354','deals-mobile','margin-top','-31',0,''),(58648,18687,'119356','deals-mobile','link','shipping_address',0,''),(58649,18687,'119356','deals-mobile','float','right',0,''),(58650,18687,'119356','deals-mobile','margin-top','-31',0,''),(58651,18689,'119358','deals-mobile','margin-bottom','20',0,''),(58652,18691,'119360','deals-mobile','link','contact_information',0,''),(58653,18691,'119360','deals-mobile','margin-top','-31',0,''),(58654,18691,'119360','deals-mobile','float','right',0,''),(58655,18692,'119361','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(58656,18692,'119361','deals-mobile','clear','none',0,''),(58657,18693,'119362','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(58658,18694,'119363','deals-mobile','block_type','1',0,''),(58659,18694,'119363','deals-mobile','padding-left','30',0,''),(58660,18694,'119363','deals-mobile','border-left-width','20',0,''),(58661,18694,'119363','deals-mobile','border-left-color','#e0e0e0',0,''),(58662,18694,'119363','deals-mobile','margin-left','-10',0,''),(58663,18694,'119363','deals-mobile','padding-right','30',0,''),(58664,18694,'119363','deals-mobile','padding-top','20',0,''),(58665,18694,'119363','deals-mobile','padding-bottom','20',0,''),(58667,18695,'119364','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(58668,18696,'119365','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(58669,18696,'119365','deals-mobile','clear','none',0,''),(58670,18698,'119367','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(58671,18698,'119367','deals-mobile','clear','none',0,''),(58672,18699,'119368','deals-mobile','margin-bottom','20',0,''),(58673,18700,'119369','deals-mobile','link','payment_method',0,''),(58674,18700,'119369','deals-mobile','float','right',0,''),(58675,18700,'119369','deals-mobile','margin-top','-31',0,''),(58676,18701,'119370','deals-mobile','link','billing_address',0,''),(58677,18701,'119370','deals-mobile','float','right',0,''),(58678,18701,'119370','deals-mobile','margin-top','-31',0,''),(58679,18702,'119371','deals-mobile','block_type','1',0,''),(58680,18702,'119371','deals-mobile','padding-top','20',0,''),(58681,18702,'119371','deals-mobile','padding-left','20',0,''),(58682,18702,'119371','deals-mobile','padding-right','20',0,''),(58683,18702,'119371','deals-mobile','padding-bottom','20',0,''),(58684,18702,'119371','deals-mobile','background-color','#ffffff',0,''),(58685,18702,'119371','deals-mobile','style_class','order-summary',0,''),(58686,18703,'119372','deals-mobile','margin-bottom','20',0,''),(58687,18703,'119372','deals-mobile','text-align','right',0,''),(58688,18704,'119373','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58689,18706,'119375','deals-mobile','block_type','1',0,''),(58690,18706,'119375','deals-mobile','background-color','#eeeeee',0,''),(58691,18706,'119375','deals-mobile','padding-bottom','30',0,''),(58692,18707,'119376','deals-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(58693,18708,'119377','deals-mobile','block_type','4',0,''),(58694,18708,'119377','deals-mobile','schema','4-2',0,''),(58695,18709,'119378','deals-mobile','block_type','1',0,''),(58696,18709,'119378','deals-mobile','padding-right','40',0,''),(58698,18710,'119379','deals-mobile','block_type','1',0,''),(58699,18710,'119379','deals-mobile','background-color','#ffffff',0,''),(58700,18710,'119379','deals-mobile','padding-top','20',0,''),(58701,18710,'119379','deals-mobile','padding-bottom','20',0,''),(58702,18710,'119379','deals-mobile','padding-left','30',0,''),(58703,18710,'119379','deals-mobile','padding-right','30',0,''),(58704,18710,'119379','deals-mobile','margin-bottom','20',0,''),(58705,18711,'119380','deals-mobile','hide_parents','2',0,''),(58706,18712,'119381','deals-mobile','float','right',0,''),(58707,18712,'119381','deals-mobile','margin-top','-37',0,''),(58708,18712,'119381','deals-mobile','link','comments',0,''),(58709,18713,'119382','deals-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(58710,18714,'119383','deals-mobile','block_type','1',0,''),(58711,18714,'119383','deals-mobile','padding-right','30',0,''),(58712,18714,'119383','deals-mobile','background-color','#ffffff',0,''),(58713,18714,'119383','deals-mobile','padding-top','20',0,''),(58714,18714,'119383','deals-mobile','padding-left','30',0,''),(58715,18714,'119383','deals-mobile','padding-bottom','20',0,''),(58718,18716,'119385','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(58719,18717,'119386','deals-mobile','link','products',0,''),(58720,18717,'119386','deals-mobile','float','right',0,''),(58721,18717,'119386','deals-mobile','margin-top','-37',0,''),(58722,18718,'119387','deals-mobile','block_type','2',0,''),(58723,18718,'119387','deals-mobile','margin-bottom','20',0,''),(58724,18718,'119387','deals-mobile','schema','2-2',0,''),(58725,18718,'119387','deals-mobile','background-color','#ffffff',0,''),(58726,18719,'119388','deals-mobile','block_type','1',0,''),(58727,18719,'119388','deals-mobile','border-right-width','20',0,''),(58728,18719,'119388','deals-mobile','border-right-color','#e0e0e0',0,''),(58729,18719,'119388','deals-mobile','margin-right','-10',0,''),(58730,18719,'119388','deals-mobile','padding-right','30',0,''),(58731,18719,'119388','deals-mobile','padding-top','20',0,''),(58732,18719,'119388','deals-mobile','padding-left','30',0,''),(58733,18719,'119388','deals-mobile','padding-bottom','20',0,''),(58736,18719,'119388','deals-mobile','margin-bottom','20',0,''),(58739,18720,'119389','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(58740,18720,'119389','deals-mobile','padding-top','20',0,''),(58741,18722,'119391','deals-mobile','link','shipping_method',0,''),(58742,18722,'119391','deals-mobile','float','right',0,''),(58743,18722,'119391','deals-mobile','margin-top','-31',0,''),(58744,18723,'119392','deals-mobile','link','contact_information',0,''),(58745,18723,'119392','deals-mobile','margin-top','-31',0,''),(58746,18723,'119392','deals-mobile','float','right',0,''),(58747,18724,'119393','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(58748,18726,'119395','deals-mobile','link','shipping_address',0,''),(58749,18726,'119395','deals-mobile','float','right',0,''),(58750,18726,'119395','deals-mobile','margin-top','-31',0,''),(58751,18727,'119396','deals-mobile','margin-bottom','20',0,''),(58752,18728,'119397','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(58753,18728,'119397','deals-mobile','clear','none',0,''),(58754,18729,'119398','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(58755,18729,'119398','deals-mobile','clear','none',0,''),(58756,18731,'119400','deals-mobile','block_type','1',0,''),(58757,18731,'119400','deals-mobile','padding-left','30',0,''),(58758,18731,'119400','deals-mobile','border-left-width','20',0,''),(58759,18731,'119400','deals-mobile','border-left-color','#e0e0e0',0,''),(58760,18731,'119400','deals-mobile','margin-left','-10',0,''),(58761,18731,'119400','deals-mobile','padding-right','30',0,''),(58762,18731,'119400','deals-mobile','padding-top','20',0,''),(58763,18731,'119400','deals-mobile','padding-bottom','20',0,''),(58765,18732,'119401','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(58766,18732,'119401','deals-mobile','clear','none',0,''),(58767,18733,'119402','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(58768,18734,'119403','deals-mobile','link','payment_method',0,''),(58769,18734,'119403','deals-mobile','float','right',0,''),(58770,18734,'119403','deals-mobile','margin-top','-31',0,''),(58771,18735,'119404','deals-mobile','margin-bottom','20',0,''),(58772,18736,'119405','deals-mobile','link','billing_address',0,''),(58773,18736,'119405','deals-mobile','float','right',0,''),(58774,18736,'119405','deals-mobile','margin-top','-31',0,''),(58775,18737,'119406','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(58776,18737,'119406','deals-mobile','clear','none',0,''),(58777,18739,'119408','deals-mobile','block_type','1',0,''),(58778,18739,'119408','deals-mobile','padding-top','20',0,''),(58779,18739,'119408','deals-mobile','padding-left','20',0,''),(58780,18739,'119408','deals-mobile','padding-right','20',0,''),(58781,18739,'119408','deals-mobile','padding-bottom','20',0,''),(58782,18739,'119408','deals-mobile','background-color','#ffffff',0,''),(58783,18739,'119408','deals-mobile','style_class','order-summary',0,''),(58784,18741,'119410','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58785,18742,'119411','deals-mobile','margin-bottom','20',0,''),(58786,18742,'119411','deals-mobile','text-align','right',0,''),(58787,18743,'119412','deals-mobile','block_type','1',0,''),(58788,18744,'119413','deals-mobile','block_type','2',0,''),(58789,18744,'119413','deals-mobile','font-weight','400',0,''),(58790,18744,'119413','deals-mobile','padding-bottom','20',0,''),(58791,18744,'119413','deals-mobile','schema','2-2',0,''),(58792,18744,'119413','deals-mobile','schema','2-2',0,'864'),(58793,18746,'119415','deals-mobile','street_heading','90',0,''),(58794,18747,'119416','deals-mobile','block_type','2',0,''),(58795,18747,'119416','deals-mobile','font-weight','400',0,''),(58796,18747,'119416','deals-mobile','padding-bottom','20',0,''),(58797,18747,'119416','deals-mobile','schema','2-2',0,'864'),(58798,18748,'119417','deals-mobile','show_captcha','on',0,''),(58799,18749,'119418','deals-mobile','font-weight','400',0,''),(58800,18749,'119418','deals-mobile','padding-left','40',0,''),(58801,18749,'119418','deals-mobile','time_format','24',0,''),(58802,18749,'119418','deals-mobile','show_icons','on',0,''),(58803,18749,'119418','deals-mobile','padding-left','0',0,'864'),(58804,18751,'119420','deals-mobile','block_type','1',0,''),(58805,18752,'119421','deals-mobile','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(58806,18752,'119421','deals-mobile','margin-bottom','40',0,''),(58807,18753,'119422','deals-mobile','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(58808,18754,'119423','deals-mobile','width','680',0,''),(58809,18754,'119423','deals-mobile','font-weight','normal',0,''),(58810,18754,'119423','deals-mobile','font-size','12',0,''),(58811,18754,'119423','deals-mobile','padding-top','20',0,''),(58812,18754,'119423','deals-mobile','padding-bottom','20',0,''),(58813,18754,'119423','deals-mobile','color','#424242',0,''),(58814,18755,'119424','deals-mobile','block_type','4',0,''),(58815,18755,'119424','deals-mobile','font-weight','normal',0,''),(58816,18755,'119424','deals-mobile','border-top-width','1',0,''),(58817,18755,'119424','deals-mobile','border-top-color','#e0e0e0',0,''),(58818,18755,'119424','deals-mobile','border-left-width','1',0,''),(58819,18755,'119424','deals-mobile','border-left-color','#e0e0e0',0,''),(58820,18755,'119424','deals-mobile','border-right-width','1',0,''),(58821,18755,'119424','deals-mobile','border-right-color','#e0e0e0',0,''),(58822,18755,'119424','deals-mobile','border-bottom-width','1',0,''),(58823,18755,'119424','deals-mobile','border-bottom-color','#e0e0e0',0,''),(58824,18756,'119425','deals-mobile','block_type','2',0,''),(58825,18756,'119425','deals-mobile','font-weight','normal',0,''),(58826,18756,'119425','deals-mobile','border-top-width','1',0,''),(58827,18756,'119425','deals-mobile','border-top-color','#e0e0e0',0,''),(58828,18756,'119425','deals-mobile','border-right-width','1',0,''),(58829,18756,'119425','deals-mobile','border-right-color','#e0e0e0',0,''),(58830,18757,'119426','deals-mobile','block_type','1',0,''),(58831,18757,'119426','deals-mobile','font-weight','normal',0,''),(58832,18757,'119426','deals-mobile','padding-top','10',0,''),(58833,18757,'119426','deals-mobile','padding-left','10',0,''),(58834,18757,'119426','deals-mobile','padding-right','10',0,''),(58835,18757,'119426','deals-mobile','padding-bottom','10',0,''),(58836,18757,'119426','deals-mobile','border-right-width','1',0,''),(58837,18757,'119426','deals-mobile','border-right-color','#e0e0e0',0,''),(58838,18758,'119427','deals-mobile','text','<p>Shipping via</p>',1,''),(58839,18758,'119427','deals-mobile','font-weight','bold',0,''),(58840,18758,'119427','deals-mobile','font-size','14',0,''),(58841,18760,'119429','deals-mobile','block_type','1',0,''),(58842,18760,'119429','deals-mobile','font-weight','normal',0,''),(58843,18760,'119429','deals-mobile','padding-top','10',0,''),(58844,18760,'119429','deals-mobile','padding-left','10',0,''),(58845,18760,'119429','deals-mobile','padding-right','10',0,''),(58846,18760,'119429','deals-mobile','padding-bottom','10',0,''),(58847,18762,'119431','deals-mobile','text','<p>Shipping service</p>',1,''),(58848,18762,'119431','deals-mobile','font-weight','bold',0,''),(58849,18762,'119431','deals-mobile','font-size','14',0,''),(58850,18763,'119432','deals-mobile','block_type','2',0,''),(58851,18763,'119432','deals-mobile','font-weight','normal',0,''),(58852,18763,'119432','deals-mobile','border-right-width','1',0,''),(58853,18763,'119432','deals-mobile','border-right-color','#e0e0e0',0,''),(58854,18764,'119433','deals-mobile','block_type','1',0,''),(58855,18764,'119433','deals-mobile','font-weight','400',0,''),(58856,18764,'119433','deals-mobile','background-color','#eeeeee',0,''),(58857,18764,'119433','deals-mobile','padding-top','10',0,''),(58858,18764,'119433','deals-mobile','padding-left','10',0,''),(58859,18764,'119433','deals-mobile','padding-right','10',0,''),(58860,18764,'119433','deals-mobile','padding-bottom','30',0,''),(58861,18765,'119434','deals-mobile','font-size','12',0,''),(58862,18766,'119435','deals-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(58863,18766,'119435','deals-mobile','font-size','14',0,''),(58864,18766,'119435','deals-mobile','font-weight','bold',0,''),(58865,18767,'119436','deals-mobile','block_type','1',0,''),(58866,18767,'119436','deals-mobile','font-weight','normal',0,''),(58867,18767,'119436','deals-mobile','padding-top','10',0,''),(58868,18767,'119436','deals-mobile','padding-left','10',0,''),(58869,18767,'119436','deals-mobile','padding-right','10',0,''),(58870,18767,'119436','deals-mobile','padding-bottom','10',0,''),(58871,18768,'119437','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(58872,18768,'119437','deals-mobile','font-weight','bold',0,''),(58873,18768,'119437','deals-mobile','font-size','14',0,''),(58874,18768,'119437','deals-mobile','padding-top','10',0,''),(58875,18769,'119438','deals-mobile','font-weight','normal',0,''),(58876,18771,'119440','deals-mobile','text','<p>PHONE NUMBER:</p>',1,''),(58877,18771,'119440','deals-mobile','font-size','14',0,''),(58878,18771,'119440','deals-mobile','font-weight','bold',0,''),(58879,18771,'119440','deals-mobile','padding-top','10',0,''),(58880,18772,'119441','deals-mobile','text','<p>CUSTOMER:</p>',1,''),(58881,18772,'119441','deals-mobile','font-size','13',0,''),(58882,18772,'119441','deals-mobile','font-weight','bold',0,''),(58883,18773,'119442','deals-mobile','font-weight','normal',0,''),(58884,18774,'119443','deals-mobile','font-weight','normal',0,''),(58885,18774,'119443','deals-mobile','text-align','center',0,''),(58886,18774,'119443','deals-mobile','padding-bottom','10',0,''),(58887,18775,'119444','deals-mobile','text','<p>Payment date:</p>',1,''),(58888,18775,'119444','deals-mobile','font-weight','bold',0,''),(58889,18775,'119444','deals-mobile','text-align','center',0,''),(58890,18775,'119444','deals-mobile','font-size','12',0,''),(58891,18776,'119445','deals-mobile','font-size','14',0,''),(58892,18776,'119445','deals-mobile','font-weight','bold',0,''),(58893,18776,'119445','deals-mobile','text-align','center',0,''),(58894,18776,'119445','deals-mobile','padding-bottom','10',0,''),(58895,18776,'119445','deals-mobile','padding-top','10',0,''),(58896,18777,'119446','deals-mobile','block_type','5',0,''),(58897,18777,'119446','deals-mobile','font-weight','normal',0,''),(58898,18777,'119446','deals-mobile','border-bottom-width','1',0,''),(58899,18777,'119446','deals-mobile','border-bottom-color','#e0e0e0',0,''),(58900,18777,'119446','deals-mobile','border-top-width','1',0,''),(58901,18777,'119446','deals-mobile','border-top-color','#e0e0e0',0,''),(58902,18777,'119446','deals-mobile','border-left-color','#e0e0e0',0,''),(58903,18777,'119446','deals-mobile','border-left-width','1',0,''),(58904,18778,'119447','deals-mobile','block_type','1',0,''),(58905,18778,'119447','deals-mobile','font-weight','normal',0,''),(58906,18778,'119447','deals-mobile','padding-top','10',0,''),(58907,18778,'119447','deals-mobile','padding-left','10',0,''),(58908,18778,'119447','deals-mobile','padding-right','10',0,''),(58909,18779,'119448','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(58910,18779,'119448','deals-mobile','font-size','14',0,''),(58911,18779,'119448','deals-mobile','font-weight','bold',0,''),(58912,18779,'119448','deals-mobile','padding-bottom','10',0,''),(58913,18780,'119449','deals-mobile','font-weight','400',0,''),(58914,18780,'119449','deals-mobile','line-height','120',0,''),(58915,18780,'119449','deals-mobile','line_height_measure','%',0,''),(58916,18780,'119449','deals-mobile','font-size','12',0,''),(58917,18781,'119450','deals-mobile','block_type','1',0,''),(58918,18781,'119450','deals-mobile','background-color','#eeeeee',0,''),(58919,18781,'119450','deals-mobile','padding-top','20',0,''),(58920,18781,'119450','deals-mobile','padding-left','10',0,''),(58921,18781,'119450','deals-mobile','padding-right','10',0,''),(58922,18781,'119450','deals-mobile','padding-bottom','20',0,''),(58923,18781,'119450','deals-mobile','font-size','14',0,''),(58924,18782,'119451','deals-mobile','block_type','2',0,''),(58925,18782,'119451','deals-mobile','font-weight','normal',0,''),(58926,18782,'119451','deals-mobile','padding-bottom','20',0,''),(58927,18783,'119452','deals-mobile','font-weight','400',0,''),(58928,18783,'119452','deals-mobile','padding-top','20',0,''),(58930,18784,'119453','deals-mobile','block_type','1',0,''),(58931,18785,'119454','deals-mobile','font-weight','normal',0,''),(58932,18785,'119454','deals-mobile','text-align','right',0,''),(58933,18785,'119454','deals-mobile','padding-bottom','10',0,''),(58934,18785,'119454','deals-mobile','address_spacer',',',0,''),(58935,18785,'119454','deals-mobile','font-size','12',0,''),(58936,18786,'119455','deals-mobile','block_type','11',0,''),(58937,18786,'119455','deals-mobile','font-weight','normal',0,''),(58938,18787,'119456','deals-mobile','text','<p>Email:</p>',1,''),(58939,18787,'119456','deals-mobile','font-weight','normal',0,''),(58940,18787,'119456','deals-mobile','text-align','right',0,''),(58941,18788,'119457','deals-mobile','font-weight','normal',0,''),(58942,18788,'119457','deals-mobile','text-align','right',0,''),(58943,18789,'119458','deals-mobile','block_type','11',0,''),(58944,18789,'119458','deals-mobile','font-weight','normal',0,''),(58945,18790,'119459','deals-mobile','text','<p>Phone:</p>',1,''),(58946,18790,'119459','deals-mobile','font-weight','normal',0,''),(58947,18790,'119459','deals-mobile','text-align','right',0,''),(58948,18791,'119460','deals-mobile','font-weight','normal',0,''),(58949,18791,'119460','deals-mobile','text-align','right',0,''),(58950,18792,'119461','deals-mobile','block_type','11',0,''),(58951,18792,'119461','deals-mobile','font-weight','normal',0,''),(58952,18793,'119462','deals-mobile','text','<p>Web:</p>',1,''),(58953,18793,'119462','deals-mobile','font-weight','normal',0,''),(58954,18793,'119462','deals-mobile','text-align','right',0,''),(58955,18794,'119463','deals-mobile','font-weight','normal',0,''),(58956,18794,'119463','deals-mobile','text-align','right',0,''),(58957,18795,'119464','deals-mobile','font-weight','400',0,''),(58958,18795,'119464','deals-mobile','padding-top','20',0,''),(58959,18795,'119464','deals-mobile','padding-bottom','0',0,''),(58960,18795,'119464','deals-mobile','font-size','12',0,''),(58961,18796,'119465','deals-mobile','block_type','3',0,''),(58962,18796,'119465','deals-mobile','font-weight','normal',0,''),(58963,18796,'119465','deals-mobile','padding-top','20',0,''),(58964,18797,'119466','deals-mobile','font-size','12',0,''),(58965,18798,'119467','deals-mobile','text','<p>If undelivered please return to:</p>',1,''),(58966,18798,'119467','deals-mobile','font-size','12',0,''),(58967,18798,'119467','deals-mobile','font-weight','bold',0,''),(58968,18799,'119468','deals-mobile','text','<p>Thank you for your order</p>',1,''),(58969,18799,'119468','deals-mobile','color','#1da1f2',0,''),(58970,18799,'119468','deals-mobile','font-size','13',0,''),(58971,18799,'119468','deals-mobile','font-weight','bold',0,''),(58972,18799,'119468','deals-mobile','padding-top','5',0,''),(58973,18799,'119468','deals-mobile','text-align','center',0,''),(58974,18800,'119469','deals-mobile','font-weight','400',0,''),(58975,18800,'119469','deals-mobile','text-align','center',0,''),(58976,18800,'119469','deals-mobile','padding-top','0',0,''),(58978,18800,'119469','deals-mobile','padding-left','20',0,''),(58979,18800,'119469','deals-mobile','padding-right','20',0,''),(58980,18801,'119470','deals-mobile','block_type','6',0,''),(58981,18801,'119470','deals-mobile','font-weight','normal',0,''),(58982,18801,'119470','deals-mobile','font-size','16',0,''),(58983,18802,'119471','deals-mobile','text','<p>Phone:</p>',1,''),(58984,18802,'119471','deals-mobile','font-weight','normal',0,''),(58985,18802,'119471','deals-mobile','text-align','right',0,''),(58986,18802,'119471','deals-mobile','font-size','12',0,''),(58987,18803,'119472','deals-mobile','font-weight','normal',0,''),(58988,18803,'119472','deals-mobile','text-align','right',0,''),(58989,18803,'119472','deals-mobile','font-size','12',0,''),(58990,18804,'119473','deals-mobile','block_type','6',0,''),(58991,18804,'119473','deals-mobile','font-weight','normal',0,''),(58992,18804,'119473','deals-mobile','font-size','16',0,''),(58993,18805,'119474','deals-mobile','text','<p>Email:</p>',1,''),(58994,18805,'119474','deals-mobile','font-weight','normal',0,''),(58995,18805,'119474','deals-mobile','text-align','right',0,''),(58996,18805,'119474','deals-mobile','font-size','12',0,''),(58997,18806,'119475','deals-mobile','font-weight','normal',0,''),(58998,18806,'119475','deals-mobile','text-align','right',0,''),(58999,18806,'119475','deals-mobile','font-size','12',0,''),(59000,18807,'119476','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(59001,18807,'119476','deals-mobile','font-size','12',0,''),(59002,18807,'119476','deals-mobile','font-weight','bold',0,''),(59003,18807,'119476','deals-mobile','text-align','right',0,''),(59004,18810,'119479','deals-mobile','text-align','center',0,''),(59005,18810,'119479','deals-mobile','padding-top','10',0,''),(59006,18816,'119485','deals-mobile','heading_type','h1',0,''),(59007,18819,'119488','deals-mobile','text-align','center',0,''),(59008,18819,'119488','deals-mobile','padding-top','10',0,''),(59009,18824,'119493','deals-mobile','font-weight','normal',0,''),(59010,18824,'119493','deals-mobile','padding-top','20',0,''),(59011,18824,'119493','deals-mobile','padding-left','10',0,''),(59012,18824,'119493','deals-mobile','padding-right','10',0,''),(59013,18824,'119493','deals-mobile','padding-bottom','20',0,''),(59014,18824,'119493','deals-mobile','color','#444444',0,''),(59015,18824,'119493','deals-mobile','font-size','14',0,''),(59016,18825,'119494','deals-mobile','block_type','2',0,''),(59017,18825,'119494','deals-mobile','font-weight','normal',0,''),(59018,18826,'119495','deals-mobile','font-weight','normal',0,''),(59019,18826,'119495','deals-mobile','padding-bottom','20',0,''),(59020,18827,'119496','deals-mobile','color','#444444',0,''),(59021,18827,'119496','deals-mobile','font-size','14',0,''),(59022,18827,'119496','deals-mobile','padding-top','20',0,''),(59023,18827,'119496','deals-mobile','padding-bottom','20',0,''),(59024,18827,'119496','deals-mobile','border-top-width','1',0,''),(59025,18827,'119496','deals-mobile','border-top-color','#cccccc',0,''),(59026,18828,'119497','deals-mobile','block_type','1',0,''),(59027,18829,'119498','deals-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',1,''),(59028,18829,'119498','deals-mobile','font-weight','normal',0,''),(59029,18829,'119498','deals-mobile','color','#444444',0,''),(59030,18829,'119498','deals-mobile','font-size','14',0,''),(59031,18830,'119499','deals-mobile','block_type','2',0,''),(59032,18830,'119499','deals-mobile','font-weight','normal',0,''),(59033,18830,'119499','deals-mobile','background-color','#092964',0,''),(59034,18830,'119499','deals-mobile','padding-top','5',0,''),(59035,18830,'119499','deals-mobile','padding-left','10',0,''),(59036,18830,'119499','deals-mobile','padding-right','10',0,''),(59037,18830,'119499','deals-mobile','padding-bottom','5',0,''),(59038,18831,'119500','deals-mobile','color','#ffffff',0,''),(59039,18831,'119500','deals-mobile','font-size','14',0,''),(59040,18831,'119500','deals-mobile','font-weight','normal',0,''),(59041,18832,'119501','deals-mobile','font-weight','normal',0,''),(59042,18832,'119501','deals-mobile','text-align','right',0,''),(59043,18832,'119501','deals-mobile','color','#ffffff',0,''),(59044,18832,'119501','deals-mobile','font-size','12',0,''),(59045,18833,'119502','deals-mobile','block_type','1',0,''),(59046,18834,'119503','deals-mobile','block_type','1',0,''),(59047,18834,'119503','deals-mobile','max-width','800',0,''),(59048,18834,'119503','deals-mobile','margin','0 auto',0,''),(59049,18834,'119503','deals-mobile','background-color','#ffffff',0,''),(59050,18835,'119504','deals-mobile','font-weight','normal',0,''),(59051,18835,'119504','deals-mobile','padding-top','20',0,''),(59052,18835,'119504','deals-mobile','padding-left','10',0,''),(59053,18835,'119504','deals-mobile','padding-right','10',0,''),(59054,18835,'119504','deals-mobile','padding-bottom','20',0,''),(59055,18835,'119504','deals-mobile','color','#424242',0,''),(59056,18835,'119504','deals-mobile','font-size','14',0,''),(59057,18836,'119505','deals-mobile','block_type','7',0,''),(59058,18836,'119505','deals-mobile','font-weight','normal',0,''),(59059,18836,'119505','deals-mobile','background-color','#183d78',0,''),(59060,18836,'119505','deals-mobile','padding-top','5',0,''),(59061,18836,'119505','deals-mobile','padding-left','10',0,''),(59062,18836,'119505','deals-mobile','padding-right','10',0,''),(59063,18836,'119505','deals-mobile','padding-bottom','5',0,''),(59064,18837,'119506','deals-mobile','color','#ffffff',0,''),(59065,18837,'119506','deals-mobile','font-size','15',0,''),(59066,18837,'119506','deals-mobile','font-weight','700',0,''),(59067,18838,'119507','deals-mobile','font-weight','normal',0,''),(59068,18838,'119507','deals-mobile','text-align','right',0,''),(59069,18838,'119507','deals-mobile','color','#757575',0,''),(59070,18838,'119507','deals-mobile','font-size','12',0,''),(59071,18839,'119508','deals-mobile','color','#424242',0,''),(59072,18839,'119508','deals-mobile','font-size','12',0,''),(59073,18839,'119508','deals-mobile','padding-top','20',0,''),(59074,18839,'119508','deals-mobile','padding-bottom','20',0,''),(59075,18839,'119508','deals-mobile','border-top-width','1',0,''),(59076,18839,'119508','deals-mobile','border-top-color','#e0e0e0',0,''),(59077,18840,'119509','deals-mobile','font-weight','normal',0,''),(59078,18840,'119509','deals-mobile','padding-bottom','10',0,''),(59079,18840,'119509','deals-mobile','background-color','#183d78',0,''),(59080,18840,'119509','deals-mobile','logo','themes/deals-mobile/img/logo-white-1.png',1,''),(59081,18840,'119509','deals-mobile','padding-left','20',0,''),(59082,18840,'119509','deals-mobile','padding-top','10',0,''),(59083,18841,'119510','deals-mobile','block_type','1',0,''),(59084,18841,'119510','deals-mobile','background-color','#eeeeee',0,''),(59085,18842,'119511','deals-mobile','block_type','1',0,''),(59086,18842,'119511','deals-mobile','max-width','800',0,''),(59087,18842,'119511','deals-mobile','margin','0 auto',0,''),(59088,18843,'119512','deals-mobile','font-weight','normal',0,''),(59089,18843,'119512','deals-mobile','padding-bottom','10',0,''),(59090,18843,'119512','deals-mobile','padding-top','10',0,''),(59091,18843,'119512','deals-mobile','text-align','center',0,''),(59092,18843,'119512','deals-mobile','logo_from','theme',0,''),(59093,18844,'119513','deals-mobile','color','#757575',0,''),(59094,18844,'119513','deals-mobile','font-size','12',0,''),(59095,18844,'119513','deals-mobile','padding-top','20',0,''),(59096,18844,'119513','deals-mobile','padding-bottom','20',0,''),(59097,18844,'119513','deals-mobile','text-align','center',0,''),(59098,18845,'119514','deals-mobile','block_type','1',0,''),(59099,18845,'119514','deals-mobile','background-color','#ffffff',0,''),(59100,18845,'119514','deals-mobile','padding-top','20',0,''),(59101,18845,'119514','deals-mobile','padding-left','20',0,''),(59102,18845,'119514','deals-mobile','padding-right','20',0,''),(59103,18845,'119514','deals-mobile','padding-bottom','20',0,''),(59104,18846,'119515','deals-mobile','block_type','7',0,''),(59105,18846,'119515','deals-mobile','font-weight','normal',0,''),(59106,18846,'119515','deals-mobile','padding-left','10',0,''),(59107,18846,'119515','deals-mobile','padding-right','10',0,''),(59108,18846,'119515','deals-mobile','padding-bottom','15',0,''),(59109,18846,'119515','deals-mobile','border-bottom-width','1',0,''),(59110,18846,'119515','deals-mobile','border-bottom-color','#e0e0e0',0,''),(59111,18847,'119516','deals-mobile','color','#424242',0,''),(59112,18847,'119516','deals-mobile','font-size','14',0,''),(59113,18847,'119516','deals-mobile','font-weight','700',0,''),(59114,18848,'119517','deals-mobile','font-weight','normal',0,''),(59115,18848,'119517','deals-mobile','text-align','right',0,''),(59116,18848,'119517','deals-mobile','color','#757575',0,''),(59117,18848,'119517','deals-mobile','font-size','11',0,''),(59118,18848,'119517','deals-mobile','text-transform','uppercase',0,''),(59119,18849,'119518','deals-mobile','font-weight','normal',0,''),(59120,18849,'119518','deals-mobile','padding-top','20',0,''),(59121,18849,'119518','deals-mobile','padding-bottom','20',0,''),(59122,18849,'119518','deals-mobile','color','#424242',0,''),(59123,18849,'119518','deals-mobile','font-size','14',0,''),(59124,18850,'119519','deals-mobile','block_type','1',0,''),(59125,18850,'119519','deals-mobile','background-color','#eeeeee',0,''),(59126,18850,'119519','deals-mobile','padding-top','20',0,''),(59127,18850,'119519','deals-mobile','padding-bottom','20',0,''),(59128,18851,'119520','deals-mobile','block_type','1',0,''),(59129,18851,'119520','deals-mobile','max-width','800',0,''),(59130,18851,'119520','deals-mobile','margin','0 auto',0,''),(59131,18852,'119521','deals-mobile','block_type','1',0,''),(59132,18852,'119521','deals-mobile','background-color','#ffffff',0,''),(59133,18852,'119521','deals-mobile','padding-top','20',0,''),(59134,18852,'119521','deals-mobile','padding-left','20',0,''),(59135,18852,'119521','deals-mobile','padding-right','20',0,''),(59136,18852,'119521','deals-mobile','padding-bottom','20',0,''),(59137,18852,'119521','deals-mobile','border-top-width','1',0,''),(59138,18852,'119521','deals-mobile','border-left-width','1',0,''),(59139,18852,'119521','deals-mobile','border-right-width','1',0,''),(59140,18852,'119521','deals-mobile','border-bottom-width','1',0,''),(59141,18852,'119521','deals-mobile','border-top-color','#e0e0e0',0,''),(59142,18852,'119521','deals-mobile','border-left-color','#e0e0e0',0,''),(59143,18852,'119521','deals-mobile','border-bottom-color','#e0e0e0',0,''),(59144,18852,'119521','deals-mobile','border-right-color','#e0e0e0',0,''),(59145,18853,'119522','deals-mobile','font-weight','normal',0,''),(59146,18853,'119522','deals-mobile','padding-top','20',0,''),(59147,18853,'119522','deals-mobile','padding-bottom','20',0,''),(59148,18853,'119522','deals-mobile','color','#424242',0,''),(59149,18853,'119522','deals-mobile','font-size','14',0,''),(59150,18854,'119523','deals-mobile','block_type','2',0,''),(59151,18855,'119524','deals-mobile','font-weight','normal',0,''),(59152,18855,'119524','deals-mobile','padding-bottom','10',0,''),(59153,18855,'119524','deals-mobile','padding-top','10',0,''),(59154,18855,'119524','deals-mobile','logo_from','theme',0,''),(59155,18856,'119525','deals-mobile','color','#424242',0,''),(59156,18856,'119525','deals-mobile','font-size','14',0,''),(59157,18856,'119525','deals-mobile','font-weight','700',0,''),(59158,18856,'119525','deals-mobile','text-align','right',0,''),(59159,18857,'119526','deals-mobile','font-weight','normal',0,''),(59160,18857,'119526','deals-mobile','text-align','right',0,''),(59161,18857,'119526','deals-mobile','color','#757575',0,''),(59162,18857,'119526','deals-mobile','font-size','11',0,''),(59163,18857,'119526','deals-mobile','text-transform','uppercase',0,''),(59164,18858,'119527','deals-mobile','color','#757575',0,''),(59165,18858,'119527','deals-mobile','font-size','12',0,''),(59166,18858,'119527','deals-mobile','padding-top','20',0,''),(59167,18858,'119527','deals-mobile','padding-bottom','20',0,''),(59168,18858,'119527','deals-mobile','text-align','left',0,''),(59169,18859,'119528','deals-mobile','block_type','1',0,''),(59170,18859,'119528','deals-mobile','font-weight','normal',0,''),(59171,18859,'119528','deals-mobile','margin-top','40',0,''),(59172,18860,'119529','deals-mobile','block_type','1',0,''),(59173,18861,'119530','deals-mobile','text','Account',1,''),(59174,18861,'119530','deals-mobile','style_class','footerTitle',0,''),(59175,18861,'119530','deals-mobile','font-family','Varela Round',0,''),(59176,18861,'119530','deals-mobile','font-size','18',0,''),(59177,18861,'119530','deals-mobile','text-transform','uppercase',0,''),(59178,18862,'119531','deals-mobile','class','menu-style-2',0,''),(59179,18862,'119531','deals-mobile','padding-top','10',0,''),(59180,18862,'119531','deals-mobile','padding-bottom','20',0,''),(59181,18863,'119532','deals-mobile','border-top-width','1',0,''),(59182,18863,'119532','deals-mobile','border-top-color','#e0e0e0',0,''),(59183,18863,'119532','deals-mobile','padding-top','20',0,''),(59184,18864,'119533','deals-mobile','block_type','1',0,''),(59185,18865,'119534','deals-mobile','class','menu-style-2',0,''),(59186,18865,'119534','deals-mobile','padding-top','10',0,''),(59187,18865,'119534','deals-mobile','padding-bottom','20',0,''),(59188,18866,'119535','deals-mobile','text','Account',1,''),(59189,18866,'119535','deals-mobile','style_class','footerTitle',0,''),(59192,18866,'119535','deals-mobile','font-family','Varela Round',0,''),(59193,18866,'119535','deals-mobile','font-size','18',0,''),(59194,18866,'119535','deals-mobile','text-transform','uppercase',0,''),(59195,18867,'119536','deals-mobile','block_type','1',0,''),(59196,18868,'119537','deals-mobile','text','Account',1,''),(59197,18868,'119537','deals-mobile','style_class','footerTitle',0,''),(59200,18868,'119537','deals-mobile','font-family','Varela Round',0,''),(59201,18868,'119537','deals-mobile','text-transform','uppercase',0,''),(59202,18868,'119537','deals-mobile','font-size','18',0,''),(59203,18869,'119538','deals-mobile','class','menu-style-2',0,''),(59204,18869,'119538','deals-mobile','padding-top','10',0,''),(59205,18869,'119538','deals-mobile','padding-bottom','20',0,''),(59206,18870,'119539','deals-mobile','block_type','1',0,''),(59207,18871,'119540','deals-mobile','view_item','address',0,''),(59208,18871,'119540','deals-mobile','address_spacer',',<span> </span>',0,''),(59209,18871,'119540','deals-mobile','padding-top','10',0,''),(59210,18871,'119540','deals-mobile','padding-bottom','20',0,''),(59211,18872,'119541','deals-mobile','text','Account',1,''),(59212,18872,'119541','deals-mobile','style_class','footerTitle',0,''),(59215,18872,'119541','deals-mobile','font-family','Varela Round',0,''),(59216,18872,'119541','deals-mobile','font-size','18',0,''),(59217,18872,'119541','deals-mobile','text-transform','uppercase',0,''),(59218,18873,'119542','deals-mobile','block_type','5',0,''),(59219,18874,'119543','deals-mobile','text','##TEXT_LANGUAGE##',0,''),(59220,18876,'119545','deals-mobile','block_type','5',0,''),(59221,18877,'119546','deals-mobile','text','##TEXT_CURRENCY##',0,''),(59222,18879,'119548','deals-mobile','block_type','1',0,''),(59223,18879,'119548','deals-mobile','font-weight','normal',0,''),(59224,18880,'119549','deals-mobile','block_type','2',0,''),(59225,18880,'119549','deals-mobile','font-weight','normal',0,''),(59226,18880,'119549','deals-mobile','padding-bottom','20',0,''),(59227,18881,'119550','deals-mobile','block_type','1',0,''),(59228,18881,'119550','deals-mobile','margin-right','20',0,''),(59229,18882,'119551','deals-mobile','block_type','1',0,''),(59230,18882,'119551','deals-mobile','font-weight','normal',0,''),(59231,18882,'119551','deals-mobile','style_class','gift-card-view',0,''),(59232,18882,'119551','deals-mobile','text-align','center',0,''),(59233,18882,'119551','deals-mobile','padding-bottom','20',0,''),(59234,18882,'119551','deals-mobile','background-color','#4546e2',0,''),(59235,18882,'119551','deals-mobile','padding-left','20',0,''),(59236,18882,'119551','deals-mobile','padding-right','20',0,''),(59237,18882,'119551','deals-mobile','color','#f4f2f2',0,''),(59238,18883,'119552','deals-mobile','block_type','1',0,''),(59239,18883,'119552','deals-mobile','font-weight','normal',0,''),(59240,18883,'119552','deals-mobile','padding-top','10',0,''),(59241,18884,'119553','deals-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(59242,18884,'119553','deals-mobile','font-weight','normal',0,''),(59243,18884,'119553','deals-mobile','text-align','center',0,''),(59244,18884,'119553','deals-mobile','font-size','12',0,''),(59245,18884,'119553','deals-mobile','padding-top','10',0,''),(59246,18884,'119553','deals-mobile','padding-bottom','5',0,''),(59247,18884,'119553','deals-mobile','border-top-width','1',0,''),(59248,18884,'119553','deals-mobile','border-top-color','#dfa82a',0,''),(59249,18885,'119554','deals-mobile','font-size','12',0,''),(59250,18885,'119554','deals-mobile','font-weight','bold',0,''),(59251,18885,'119554','deals-mobile','text-align','center',0,''),(59252,18885,'119554','deals-mobile','style_class','email',0,''),(59253,18886,'119555','deals-mobile','font-size','12',0,''),(59254,18886,'119555','deals-mobile','font-weight','bold',0,''),(59255,18886,'119555','deals-mobile','text-align','center',0,''),(59256,18886,'119555','deals-mobile','style_class','phone',0,''),(59257,18886,'119555','deals-mobile','padding-bottom','5',0,''),(59258,18887,'119556','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(59259,18887,'119556','deals-mobile','font-weight','normal',0,''),(59260,18887,'119556','deals-mobile','text-align','center',0,''),(59261,18887,'119556','deals-mobile','padding-top','20',0,''),(59262,18887,'119556','deals-mobile','padding-bottom','10',0,''),(59263,18887,'119556','deals-mobile','style_class','question-ico',0,''),(59264,18887,'119556','deals-mobile','border-top-width','1',0,''),(59265,18887,'119556','deals-mobile','border-top-color','#dfa82a',0,''),(59266,18887,'119556','deals-mobile','font-size','18',0,''),(59267,18888,'119557','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59268,18888,'119557','deals-mobile','font-size','18',0,''),(59269,18888,'119557','deals-mobile','font-weight','normal',0,''),(59270,18888,'119557','deals-mobile','text-align','center',0,''),(59271,18888,'119557','deals-mobile','padding-top','20',0,''),(59272,18888,'119557','deals-mobile','padding-bottom','10',0,''),(59273,18888,'119557','deals-mobile','border-top-width','1',0,''),(59274,18888,'119557','deals-mobile','border-top-color','#dfa82a',0,''),(59275,18889,'119558','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(59276,18889,'119558','deals-mobile','font-weight','normal',0,''),(59277,18889,'119558','deals-mobile','text-align','center',0,''),(59278,18889,'119558','deals-mobile','padding-bottom','10',0,''),(59279,18889,'119558','deals-mobile','font-size','14',0,''),(59280,18890,'119559','deals-mobile','text','<p>GIFT CARD</p>',1,''),(59281,18890,'119559','deals-mobile','font-size','30',0,''),(59282,18890,'119559','deals-mobile','font-weight','normal',0,''),(59283,18890,'119559','deals-mobile','border-top-width','1',0,''),(59284,18890,'119559','deals-mobile','border-top-color','#dfa82a',0,''),(59285,18890,'119559','deals-mobile','style_class','gift-ico',0,''),(59286,18890,'119559','deals-mobile','text-align','center',0,''),(59287,18890,'119559','deals-mobile','padding-top','15',0,''),(59288,18891,'119560','deals-mobile','block_type','4',0,''),(59289,18891,'119560','deals-mobile','color','#ffffff',0,''),(59290,18891,'119560','deals-mobile','font-size','30',0,''),(59291,18891,'119560','deals-mobile','font-weight','normal',0,''),(59292,18891,'119560','deals-mobile','background-color','#ee4225',0,''),(59293,18891,'119560','deals-mobile','padding-top','5',0,''),(59294,18891,'119560','deals-mobile','padding-left','10',0,''),(59295,18891,'119560','deals-mobile','padding-right','10',0,''),(59296,18891,'119560','deals-mobile','padding-bottom','5',0,''),(59297,18892,'119561','deals-mobile','text','<p>Your code is:</p>',1,''),(59298,18892,'119561','deals-mobile','font-weight','normal',0,''),(59299,18894,'119563','deals-mobile','font-weight','normal',0,''),(59300,18894,'119563','deals-mobile','text-align','center',0,''),(59301,18894,'119563','deals-mobile','padding-bottom','20',0,''),(59302,18895,'119564','deals-mobile','font-size','60',0,''),(59303,18895,'119564','deals-mobile','font-weight','bold',0,''),(59304,18895,'119564','deals-mobile','text-align','center',0,''),(59305,18895,'119564','deals-mobile','line-height','100',0,''),(59306,18895,'119564','deals-mobile','padding-bottom','20',0,''),(59307,18895,'119564','deals-mobile','line_height_measure','px',0,''),(59308,18896,'119565','deals-mobile','text','<p>HOLBI</p>',1,''),(59309,18896,'119565','deals-mobile','font-family','Varela Round',0,''),(59310,18896,'119565','deals-mobile','font-size','24',0,''),(59311,18896,'119565','deals-mobile','font-weight','normal',0,''),(59312,18896,'119565','deals-mobile','text-align','center',0,''),(59313,18896,'119565','deals-mobile','padding-top','10',0,''),(59314,18896,'119565','deals-mobile','padding-bottom','20',0,''),(59315,18898,'119567','deals-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(59316,18898,'119567','deals-mobile','font-weight','normal',0,''),(59317,18898,'119567','deals-mobile','padding-bottom','20',0,''),(59318,18900,'119569','deals-mobile','block_type','1',0,''),(59319,18900,'119569','deals-mobile','font-weight','normal',0,''),(59320,18900,'119569','deals-mobile','style_class','gift-card-view',0,''),(59321,18900,'119569','deals-mobile','text-align','center',0,''),(59322,18900,'119569','deals-mobile','padding-bottom','20',0,''),(59323,18900,'119569','deals-mobile','background-color','#183d78',0,''),(59324,18900,'119569','deals-mobile','padding-left','20',0,''),(59325,18900,'119569','deals-mobile','padding-right','20',0,''),(59326,18900,'119569','deals-mobile','color','#cccccc',0,''),(59327,18901,'119570','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(59328,18901,'119570','deals-mobile','font-weight','normal',0,''),(59329,18901,'119570','deals-mobile','text-align','center',0,''),(59330,18901,'119570','deals-mobile','padding-bottom','10',0,''),(59331,18901,'119570','deals-mobile','font-size','14',0,''),(59332,18902,'119571','deals-mobile','text','<p>GIFT CARD</p>',1,''),(59333,18902,'119571','deals-mobile','font-size','30',0,''),(59334,18902,'119571','deals-mobile','font-weight','normal',0,''),(59335,18902,'119571','deals-mobile','border-top-width','1',0,''),(59336,18902,'119571','deals-mobile','border-top-color','#dfa82a',0,''),(59337,18902,'119571','deals-mobile','style_class','gift-ico',0,''),(59338,18902,'119571','deals-mobile','text-align','center',0,''),(59339,18902,'119571','deals-mobile','padding-top','15',0,''),(59340,18903,'119572','deals-mobile','logo','themes/deals-mobile/img/logo-1.png',1,''),(59341,18904,'119573','deals-mobile','logo','themes/deals-mobile/img/bestseller-1.png',1,''),(59342,18905,'119574','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59343,18905,'119574','deals-mobile','font-size','18',0,''),(59344,18905,'119574','deals-mobile','font-weight','normal',0,''),(59345,18905,'119574','deals-mobile','text-align','center',0,''),(59346,18905,'119574','deals-mobile','padding-top','20',0,''),(59347,18905,'119574','deals-mobile','padding-bottom','10',0,''),(59348,18905,'119574','deals-mobile','border-top-width','1',0,''),(59349,18905,'119574','deals-mobile','border-top-color','#dfa82a',0,''),(59350,18906,'119575','deals-mobile','font-size','60',0,''),(59351,18906,'119575','deals-mobile','font-weight','bold',0,''),(59352,18906,'119575','deals-mobile','text-align','center',0,''),(59353,18906,'119575','deals-mobile','line-height','100',0,''),(59354,18906,'119575','deals-mobile','padding-bottom','20',0,''),(59355,18906,'119575','deals-mobile','line_height_measure','px',0,''),(59356,18907,'119576','deals-mobile','font-weight','normal',0,''),(59357,18907,'119576','deals-mobile','text-align','center',0,''),(59358,18907,'119576','deals-mobile','padding-bottom','20',0,''),(59359,18908,'119577','deals-mobile','block_type','4',0,''),(59360,18908,'119577','deals-mobile','color','#ffffff',0,''),(59361,18908,'119577','deals-mobile','font-size','30',0,''),(59362,18908,'119577','deals-mobile','font-weight','normal',0,''),(59363,18908,'119577','deals-mobile','background-color','#ee4225',0,''),(59364,18908,'119577','deals-mobile','padding-top','5',0,''),(59365,18908,'119577','deals-mobile','padding-left','10',0,''),(59366,18908,'119577','deals-mobile','padding-right','10',0,''),(59367,18908,'119577','deals-mobile','padding-bottom','5',0,''),(59368,18909,'119578','deals-mobile','text','<p>Your code is:</p>',1,''),(59369,18909,'119578','deals-mobile','font-weight','normal',0,''),(59370,18911,'119580','deals-mobile','text','<p>HOLBI</p>',1,''),(59371,18911,'119580','deals-mobile','font-family','Varela Round',0,''),(59372,18911,'119580','deals-mobile','font-size','24',0,''),(59373,18911,'119580','deals-mobile','font-weight','normal',0,''),(59374,18911,'119580','deals-mobile','text-align','center',0,''),(59375,18911,'119580','deals-mobile','padding-top','10',0,''),(59376,18911,'119580','deals-mobile','padding-bottom','20',0,''),(59377,18912,'119581','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(59378,18912,'119581','deals-mobile','font-weight','normal',0,''),(59379,18912,'119581','deals-mobile','text-align','center',0,''),(59380,18912,'119581','deals-mobile','padding-top','20',0,''),(59381,18912,'119581','deals-mobile','padding-bottom','10',0,''),(59382,18912,'119581','deals-mobile','style_class','question-ico',0,''),(59383,18912,'119581','deals-mobile','border-top-width','1',0,''),(59384,18912,'119581','deals-mobile','border-top-color','#dfa82a',0,''),(59385,18912,'119581','deals-mobile','font-size','18',0,''),(59386,18913,'119582','deals-mobile','block_type','1',0,''),(59387,18913,'119582','deals-mobile','font-weight','normal',0,''),(59388,18913,'119582','deals-mobile','padding-top','10',0,''),(59389,18914,'119583','deals-mobile','font-size','12',0,''),(59390,18914,'119583','deals-mobile','font-weight','bold',0,''),(59391,18914,'119583','deals-mobile','text-align','center',0,''),(59392,18914,'119583','deals-mobile','style_class','phone',0,''),(59393,18914,'119583','deals-mobile','padding-bottom','5',0,''),(59394,18915,'119584','deals-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(59395,18915,'119584','deals-mobile','font-weight','normal',0,''),(59396,18915,'119584','deals-mobile','text-align','center',0,''),(59397,18915,'119584','deals-mobile','font-size','12',0,''),(59398,18915,'119584','deals-mobile','padding-top','10',0,''),(59399,18915,'119584','deals-mobile','padding-bottom','5',0,''),(59400,18915,'119584','deals-mobile','border-top-width','1',0,''),(59401,18915,'119584','deals-mobile','border-top-color','#dfa82a',0,''),(59402,18916,'119585','deals-mobile','font-size','12',0,''),(59403,18916,'119585','deals-mobile','font-weight','bold',0,''),(59404,18916,'119585','deals-mobile','text-align','center',0,''),(59405,18916,'119585','deals-mobile','style_class','email',0,''),(59406,18917,'119586','deals-mobile','block_type','1',0,''),(59407,18917,'119586','deals-mobile','font-weight','normal',0,''),(59408,18917,'119586','deals-mobile','style_class','gift-card-view',0,''),(59409,18917,'119586','deals-mobile','text-align','center',0,''),(59410,18917,'119586','deals-mobile','padding-bottom','20',0,''),(59411,18917,'119586','deals-mobile','background-color','#5289a4',0,''),(59412,18917,'119586','deals-mobile','padding-left','20',0,''),(59413,18917,'119586','deals-mobile','padding-right','20',0,''),(59414,18917,'119586','deals-mobile','color','#cccccc',0,''),(59415,18918,'119587','deals-mobile','text','<p>HOLBI</p>',1,''),(59416,18918,'119587','deals-mobile','font-family','Varela Round',0,''),(59417,18918,'119587','deals-mobile','font-size','24',0,''),(59418,18918,'119587','deals-mobile','font-weight','normal',0,''),(59419,18918,'119587','deals-mobile','text-align','center',0,''),(59420,18918,'119587','deals-mobile','padding-top','10',0,''),(59421,18918,'119587','deals-mobile','padding-bottom','20',0,''),(59422,18919,'119588','deals-mobile','text','<p>GIFT CARD</p>',1,''),(59423,18919,'119588','deals-mobile','font-size','30',0,''),(59424,18919,'119588','deals-mobile','font-weight','normal',0,''),(59425,18919,'119588','deals-mobile','border-top-width','1',0,''),(59426,18919,'119588','deals-mobile','border-top-color','#dfa82a',0,''),(59427,18919,'119588','deals-mobile','style_class','gift-ico',0,''),(59428,18919,'119588','deals-mobile','text-align','center',0,''),(59429,18919,'119588','deals-mobile','padding-top','15',0,''),(59430,18920,'119589','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(59431,18920,'119589','deals-mobile','font-weight','normal',0,''),(59432,18920,'119589','deals-mobile','text-align','center',0,''),(59433,18920,'119589','deals-mobile','padding-top','20',0,''),(59434,18920,'119589','deals-mobile','padding-bottom','10',0,''),(59435,18920,'119589','deals-mobile','style_class','question-ico',0,''),(59436,18920,'119589','deals-mobile','border-top-width','1',0,''),(59437,18920,'119589','deals-mobile','border-top-color','#dfa82a',0,''),(59438,18920,'119589','deals-mobile','font-size','18',0,''),(59439,18921,'119590','deals-mobile','font-weight','normal',0,''),(59440,18921,'119590','deals-mobile','text-align','center',0,''),(59441,18921,'119590','deals-mobile','padding-bottom','20',0,''),(59442,18922,'119591','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(59443,18922,'119591','deals-mobile','font-weight','normal',0,''),(59444,18922,'119591','deals-mobile','text-align','center',0,''),(59445,18922,'119591','deals-mobile','padding-bottom','10',0,''),(59446,18922,'119591','deals-mobile','font-size','14',0,''),(59447,18923,'119592','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59448,18923,'119592','deals-mobile','font-size','18',0,''),(59449,18923,'119592','deals-mobile','font-weight','normal',0,''),(59450,18923,'119592','deals-mobile','text-align','center',0,''),(59451,18923,'119592','deals-mobile','padding-top','20',0,''),(59452,18923,'119592','deals-mobile','padding-bottom','10',0,''),(59453,18923,'119592','deals-mobile','border-top-width','1',0,''),(59454,18923,'119592','deals-mobile','border-top-color','#dfa82a',0,''),(59455,18924,'119593','deals-mobile','block_type','1',0,''),(59456,18924,'119593','deals-mobile','font-weight','normal',0,''),(59457,18924,'119593','deals-mobile','padding-top','10',0,''),(59458,18925,'119594','deals-mobile','font-size','12',0,''),(59459,18925,'119594','deals-mobile','font-weight','bold',0,''),(59460,18925,'119594','deals-mobile','text-align','center',0,''),(59461,18925,'119594','deals-mobile','style_class','phone',0,''),(59462,18925,'119594','deals-mobile','padding-bottom','5',0,''),(59463,18926,'119595','deals-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(59464,18926,'119595','deals-mobile','font-weight','normal',0,''),(59465,18926,'119595','deals-mobile','text-align','center',0,''),(59466,18926,'119595','deals-mobile','font-size','12',0,''),(59467,18926,'119595','deals-mobile','padding-top','10',0,''),(59468,18926,'119595','deals-mobile','padding-bottom','5',0,''),(59469,18926,'119595','deals-mobile','border-top-width','1',0,''),(59470,18926,'119595','deals-mobile','border-top-color','#dfa82a',0,''),(59471,18927,'119596','deals-mobile','font-size','12',0,''),(59472,18927,'119596','deals-mobile','font-weight','bold',0,''),(59473,18927,'119596','deals-mobile','text-align','center',0,''),(59474,18927,'119596','deals-mobile','style_class','email',0,''),(59475,18928,'119597','deals-mobile','block_type','4',0,''),(59476,18928,'119597','deals-mobile','color','#ffffff',0,''),(59477,18928,'119597','deals-mobile','font-size','30',0,''),(59478,18928,'119597','deals-mobile','font-weight','normal',0,''),(59479,18928,'119597','deals-mobile','background-color','#ee4225',0,''),(59480,18928,'119597','deals-mobile','padding-top','5',0,''),(59481,18928,'119597','deals-mobile','padding-left','10',0,''),(59482,18928,'119597','deals-mobile','padding-right','10',0,''),(59483,18928,'119597','deals-mobile','padding-bottom','5',0,''),(59484,18929,'119598','deals-mobile','text','<p>Your code is:</p>',1,''),(59485,18929,'119598','deals-mobile','font-weight','normal',0,''),(59486,18931,'119600','deals-mobile','font-size','60',0,''),(59487,18931,'119600','deals-mobile','font-weight','bold',0,''),(59488,18931,'119600','deals-mobile','text-align','center',0,''),(59489,18931,'119600','deals-mobile','line-height','100',0,''),(59490,18931,'119600','deals-mobile','padding-bottom','20',0,''),(59491,18931,'119600','deals-mobile','line_height_measure','px',0,''),(59492,18932,'119601','deals-mobile','block_type','1',0,''),(59493,18932,'119601','deals-mobile','font-weight','normal',0,''),(59494,18932,'119601','deals-mobile','style_class','gift-card-view',0,''),(59495,18932,'119601','deals-mobile','text-align','center',0,''),(59496,18932,'119601','deals-mobile','padding-bottom','20',0,''),(59497,18932,'119601','deals-mobile','background-color','#5289a4',0,''),(59498,18932,'119601','deals-mobile','padding-left','20',0,''),(59499,18932,'119601','deals-mobile','padding-right','20',0,''),(59500,18932,'119601','deals-mobile','color','#cccccc',0,''),(59501,18933,'119602','deals-mobile','block_type','1',0,''),(59502,18933,'119602','deals-mobile','font-weight','normal',0,''),(59503,18933,'119602','deals-mobile','padding-top','10',0,''),(59504,18934,'119603','deals-mobile','font-size','12',0,''),(59505,18934,'119603','deals-mobile','font-weight','bold',0,''),(59506,18934,'119603','deals-mobile','text-align','center',0,''),(59507,18934,'119603','deals-mobile','style_class','email',0,''),(59508,18934,'119603','deals-mobile','color','#ffffff',0,''),(59509,18935,'119604','deals-mobile','font-size','12',0,''),(59510,18935,'119604','deals-mobile','font-weight','bold',0,''),(59511,18935,'119604','deals-mobile','text-align','center',0,''),(59512,18935,'119604','deals-mobile','style_class','phone',0,''),(59513,18935,'119604','deals-mobile','padding-bottom','5',0,''),(59514,18935,'119604','deals-mobile','color','#ffffff',0,''),(59515,18936,'119605','deals-mobile','text','If you require further assistance please contact us',0,''),(59516,18936,'119605','deals-mobile','font-size','12',0,''),(59517,18936,'119605','deals-mobile','color','#ffffff',0,''),(59518,18936,'119605','deals-mobile','text-align','center',0,''),(59519,18936,'119605','deals-mobile','padding-top','10',0,''),(59520,18937,'119606','deals-mobile','block_type','4',0,''),(59521,18937,'119606','deals-mobile','color','#ffffff',0,''),(59522,18937,'119606','deals-mobile','font-size','30',0,''),(59523,18937,'119606','deals-mobile','font-weight','normal',0,''),(59524,18937,'119606','deals-mobile','background-color','#ee4225',0,''),(59525,18937,'119606','deals-mobile','padding-top','5',0,''),(59526,18937,'119606','deals-mobile','padding-left','10',0,''),(59527,18937,'119606','deals-mobile','padding-right','10',0,''),(59528,18937,'119606','deals-mobile','padding-bottom','5',0,''),(59529,18938,'119607','deals-mobile','text','Your code is:',0,''),(59530,18938,'119607','deals-mobile','font-size','30',0,''),(59531,18938,'119607','deals-mobile','color','#ffffff',0,''),(59532,18939,'119608','deals-mobile','color','#ffffff',0,''),(59533,18939,'119608','deals-mobile','font-size','30',0,''),(59534,18940,'119609','deals-mobile','block_type','1',0,''),(59535,18941,'119610','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59536,18941,'119610','deals-mobile','font-size','18',0,''),(59537,18941,'119610','deals-mobile','font-weight','normal',0,''),(59538,18941,'119610','deals-mobile','text-align','center',0,''),(59539,18941,'119610','deals-mobile','padding-top','20',0,''),(59540,18941,'119610','deals-mobile','padding-bottom','10',0,''),(59541,18941,'119610','deals-mobile','border-top-width','1',0,''),(59542,18941,'119610','deals-mobile','border-top-color','#dfa82a',0,''),(59543,18942,'119611','deals-mobile','text','HOLBI',0,''),(59544,18942,'119611','deals-mobile','color','#ffffff',0,''),(59545,18942,'119611','deals-mobile','font-size','24',0,''),(59546,18942,'119611','deals-mobile','padding-top','20',0,''),(59547,18942,'119611','deals-mobile','text-align','center',0,''),(59548,18942,'119611','deals-mobile','padding-bottom','20',0,''),(59549,18943,'119612','deals-mobile','border-top-color','#dfa82a',0,''),(59550,18943,'119612','deals-mobile','border-top-width','1',0,''),(59551,18943,'119612','deals-mobile','padding-top','20',0,''),(59552,18943,'119612','deals-mobile','font-size','30',0,''),(59553,18943,'119612','deals-mobile','text-align','center',0,''),(59554,18943,'119612','deals-mobile','color','#ffffff',0,''),(59555,18943,'119612','deals-mobile','text','GIFT CARD',0,''),(59556,18944,'119613','deals-mobile','text-align','center',0,''),(59557,18944,'119613','deals-mobile','font-weight','bold',0,''),(59558,18944,'119613','deals-mobile','font-size','60',0,''),(59559,18944,'119613','deals-mobile','color','#ffffff',0,''),(59560,18945,'119614','deals-mobile','font-size','20',0,''),(59561,18945,'119614','deals-mobile','text-align','center',0,''),(59562,18945,'119614','deals-mobile','color','#ffffff',0,''),(59563,18945,'119614','deals-mobile','padding-top','20',0,''),(59564,18945,'119614','deals-mobile','padding-bottom','20',0,''),(59565,18946,'119615','deals-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(59566,18946,'119615','deals-mobile','text-align','center',0,''),(59567,18946,'119615','deals-mobile','color','#ffffff',0,''),(59568,18946,'119615','deals-mobile','font-size','14',0,''),(59569,18946,'119615','deals-mobile','padding-bottom','20',0,''),(59570,18947,'119616','deals-mobile','text','WHAT TO DO NEXT:',0,''),(59571,18947,'119616','deals-mobile','font-size','18',0,''),(59572,18947,'119616','deals-mobile','text-align','center',0,''),(59573,18947,'119616','deals-mobile','color','#ffffff',0,''),(59574,18947,'119616','deals-mobile','padding-top','20',0,''),(59575,18947,'119616','deals-mobile','padding-bottom','10',0,''),(59576,18947,'119616','deals-mobile','border-top-width','1',0,''),(59577,18947,'119616','deals-mobile','border-top-color','#dfa82a',0,''),(59578,18949,'119618','deals-mobile','block_type','1',0,''),(59579,18949,'119618','deals-mobile','font-weight','normal',0,''),(59580,18949,'119618','deals-mobile','style_class','gift-card-view',0,''),(59581,18949,'119618','deals-mobile','text-align','center',0,''),(59582,18949,'119618','deals-mobile','padding-bottom','20',0,''),(59583,18949,'119618','deals-mobile','background-color','#183d78',0,''),(59584,18949,'119618','deals-mobile','padding-left','20',0,''),(59585,18949,'119618','deals-mobile','padding-right','20',0,''),(59586,18949,'119618','deals-mobile','color','#cccccc',0,''),(59587,18950,'119619','deals-mobile','block_type','1',0,''),(59588,18950,'119619','deals-mobile','font-weight','normal',0,''),(59589,18950,'119619','deals-mobile','padding-top','10',0,''),(59590,18951,'119620','deals-mobile','font-size','12',0,''),(59591,18951,'119620','deals-mobile','font-weight','bold',0,''),(59592,18951,'119620','deals-mobile','text-align','center',0,''),(59593,18951,'119620','deals-mobile','style_class','email',0,''),(59594,18951,'119620','deals-mobile','color','#ffffff',0,''),(59595,18952,'119621','deals-mobile','font-size','12',0,''),(59596,18952,'119621','deals-mobile','font-weight','bold',0,''),(59597,18952,'119621','deals-mobile','text-align','center',0,''),(59598,18952,'119621','deals-mobile','style_class','phone',0,''),(59599,18952,'119621','deals-mobile','padding-bottom','5',0,''),(59600,18952,'119621','deals-mobile','color','#ffffff',0,''),(59601,18953,'119622','deals-mobile','text','If you require further assistance please contact us',0,''),(59602,18953,'119622','deals-mobile','font-size','12',0,''),(59603,18953,'119622','deals-mobile','color','#ffffff',0,''),(59604,18953,'119622','deals-mobile','text-align','center',0,''),(59605,18953,'119622','deals-mobile','padding-top','10',0,''),(59606,18954,'119623','deals-mobile','block_type','4',0,''),(59607,18954,'119623','deals-mobile','color','#ffffff',0,''),(59608,18954,'119623','deals-mobile','font-size','30',0,''),(59609,18954,'119623','deals-mobile','font-weight','normal',0,''),(59610,18954,'119623','deals-mobile','background-color','#ee4225',0,''),(59611,18954,'119623','deals-mobile','padding-top','5',0,''),(59612,18954,'119623','deals-mobile','padding-left','10',0,''),(59613,18954,'119623','deals-mobile','padding-right','10',0,''),(59614,18954,'119623','deals-mobile','padding-bottom','5',0,''),(59615,18955,'119624','deals-mobile','text','Your code is:',0,''),(59616,18955,'119624','deals-mobile','font-size','30',0,''),(59617,18955,'119624','deals-mobile','color','#ffffff',0,''),(59618,18956,'119625','deals-mobile','color','#ffffff',0,''),(59619,18956,'119625','deals-mobile','font-size','30',0,''),(59620,18957,'119626','deals-mobile','block_type','1',0,''),(59621,18958,'119627','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59622,18958,'119627','deals-mobile','font-size','18',0,''),(59623,18958,'119627','deals-mobile','font-weight','normal',0,''),(59624,18958,'119627','deals-mobile','text-align','center',0,''),(59625,18958,'119627','deals-mobile','padding-top','20',0,''),(59626,18958,'119627','deals-mobile','padding-bottom','10',0,''),(59627,18958,'119627','deals-mobile','border-top-width','1',0,''),(59628,18958,'119627','deals-mobile','border-top-color','#dfa82a',0,''),(59629,18959,'119628','deals-mobile','text','HOLBI',0,''),(59630,18959,'119628','deals-mobile','color','#ffffff',0,''),(59631,18959,'119628','deals-mobile','font-size','24',0,''),(59632,18959,'119628','deals-mobile','padding-top','20',0,''),(59633,18959,'119628','deals-mobile','text-align','center',0,''),(59634,18959,'119628','deals-mobile','padding-bottom','20',0,''),(59635,18960,'119629','deals-mobile','border-top-color','#dfa82a',0,''),(59636,18960,'119629','deals-mobile','border-top-width','1',0,''),(59637,18960,'119629','deals-mobile','padding-top','20',0,''),(59638,18960,'119629','deals-mobile','font-size','30',0,''),(59639,18960,'119629','deals-mobile','text-align','center',0,''),(59640,18960,'119629','deals-mobile','color','#ffffff',0,''),(59641,18960,'119629','deals-mobile','text','GIFT CARD',0,''),(59642,18961,'119630','deals-mobile','text-align','center',0,''),(59643,18961,'119630','deals-mobile','font-weight','bold',0,''),(59644,18961,'119630','deals-mobile','font-size','60',0,''),(59645,18961,'119630','deals-mobile','color','#ffffff',0,''),(59646,18962,'119631','deals-mobile','font-size','20',0,''),(59647,18962,'119631','deals-mobile','text-align','center',0,''),(59648,18962,'119631','deals-mobile','color','#ffffff',0,''),(59649,18962,'119631','deals-mobile','padding-top','20',0,''),(59650,18962,'119631','deals-mobile','padding-bottom','20',0,''),(59651,18963,'119632','deals-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(59652,18963,'119632','deals-mobile','text-align','center',0,''),(59653,18963,'119632','deals-mobile','color','#ffffff',0,''),(59654,18963,'119632','deals-mobile','font-size','14',0,''),(59655,18963,'119632','deals-mobile','padding-bottom','20',0,''),(59656,18964,'119633','deals-mobile','text','WHAT TO DO NEXT:',0,''),(59657,18964,'119633','deals-mobile','font-size','18',0,''),(59658,18964,'119633','deals-mobile','text-align','center',0,''),(59659,18964,'119633','deals-mobile','color','#ffffff',0,''),(59660,18964,'119633','deals-mobile','padding-top','20',0,''),(59661,18964,'119633','deals-mobile','padding-bottom','10',0,''),(59662,18964,'119633','deals-mobile','border-top-width','1',0,''),(59663,18964,'119633','deals-mobile','border-top-color','#dfa82a',0,''),(59664,18966,'119635','deals-mobile','block_type','1',0,''),(59665,18968,'119637','deals-mobile','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(59666,18968,'119637','deals-mobile','text-align','center',0,''),(59667,18969,'119638','deals-mobile','block_type','1',0,''),(59668,18969,'119638','deals-mobile','font-weight','normal',0,''),(59669,18969,'119638','deals-mobile','style_class','gift-card-view',0,''),(59670,18969,'119638','deals-mobile','text-align','center',0,''),(59671,18969,'119638','deals-mobile','padding-bottom','20',0,''),(59672,18969,'119638','deals-mobile','background-color','#47a793',0,''),(59673,18969,'119638','deals-mobile','padding-left','20',0,''),(59674,18969,'119638','deals-mobile','padding-right','20',0,''),(59675,18969,'119638','deals-mobile','color','#cccccc',0,''),(59676,18970,'119639','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(59677,18970,'119639','deals-mobile','font-weight','normal',0,''),(59678,18970,'119639','deals-mobile','text-align','center',0,''),(59679,18970,'119639','deals-mobile','padding-bottom','10',0,''),(59680,18970,'119639','deals-mobile','font-size','14',0,''),(59681,18971,'119640','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59682,18971,'119640','deals-mobile','font-size','18',0,''),(59683,18971,'119640','deals-mobile','font-weight','normal',0,''),(59684,18971,'119640','deals-mobile','text-align','center',0,''),(59685,18971,'119640','deals-mobile','padding-top','20',0,''),(59686,18971,'119640','deals-mobile','padding-bottom','10',0,''),(59687,18971,'119640','deals-mobile','border-top-width','1',0,''),(59688,18971,'119640','deals-mobile','border-top-color','#dfa82a',0,''),(59689,18972,'119641','deals-mobile','font-size','60',0,''),(59690,18972,'119641','deals-mobile','font-weight','bold',0,''),(59691,18972,'119641','deals-mobile','text-align','center',0,''),(59692,18972,'119641','deals-mobile','line-height','100',0,''),(59693,18972,'119641','deals-mobile','padding-bottom','20',0,''),(59694,18972,'119641','deals-mobile','line_height_measure','px',0,''),(59695,18973,'119642','deals-mobile','text','<p>GIFT CARD</p>',1,''),(59696,18973,'119642','deals-mobile','font-size','30',0,''),(59697,18973,'119642','deals-mobile','font-weight','normal',0,''),(59698,18973,'119642','deals-mobile','border-top-width','1',0,''),(59699,18973,'119642','deals-mobile','border-top-color','#dfa82a',0,''),(59700,18973,'119642','deals-mobile','style_class','gift-ico',0,''),(59701,18973,'119642','deals-mobile','text-align','center',0,''),(59702,18973,'119642','deals-mobile','padding-top','15',0,''),(59703,18974,'119643','deals-mobile','font-weight','normal',0,''),(59704,18974,'119643','deals-mobile','text-align','center',0,''),(59705,18974,'119643','deals-mobile','padding-bottom','20',0,''),(59706,18975,'119644','deals-mobile','text','<p>HOLBI</p>',1,''),(59707,18975,'119644','deals-mobile','font-family','Varela Round',0,''),(59708,18975,'119644','deals-mobile','font-size','24',0,''),(59709,18975,'119644','deals-mobile','font-weight','normal',0,''),(59710,18975,'119644','deals-mobile','text-align','center',0,''),(59711,18975,'119644','deals-mobile','padding-top','10',0,''),(59712,18975,'119644','deals-mobile','padding-bottom','20',0,''),(59713,18976,'119645','deals-mobile','block_type','1',0,''),(59714,18976,'119645','deals-mobile','font-weight','normal',0,''),(59715,18976,'119645','deals-mobile','padding-top','10',0,''),(59716,18977,'119646','deals-mobile','font-size','12',0,''),(59717,18977,'119646','deals-mobile','font-weight','bold',0,''),(59718,18977,'119646','deals-mobile','text-align','center',0,''),(59719,18977,'119646','deals-mobile','style_class','email',0,''),(59720,18978,'119647','deals-mobile','font-size','12',0,''),(59721,18978,'119647','deals-mobile','font-weight','bold',0,''),(59722,18978,'119647','deals-mobile','text-align','center',0,''),(59723,18978,'119647','deals-mobile','style_class','phone',0,''),(59724,18978,'119647','deals-mobile','padding-bottom','5',0,''),(59725,18979,'119648','deals-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(59726,18979,'119648','deals-mobile','font-weight','normal',0,''),(59727,18979,'119648','deals-mobile','text-align','center',0,''),(59728,18979,'119648','deals-mobile','font-size','12',0,''),(59729,18979,'119648','deals-mobile','padding-top','10',0,''),(59730,18979,'119648','deals-mobile','padding-bottom','5',0,''),(59731,18979,'119648','deals-mobile','border-top-width','1',0,''),(59732,18979,'119648','deals-mobile','border-top-color','#dfa82a',0,''),(59733,18980,'119649','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(59734,18980,'119649','deals-mobile','font-weight','normal',0,''),(59735,18980,'119649','deals-mobile','text-align','center',0,''),(59736,18980,'119649','deals-mobile','padding-top','20',0,''),(59737,18980,'119649','deals-mobile','padding-bottom','10',0,''),(59738,18980,'119649','deals-mobile','style_class','question-ico',0,''),(59739,18980,'119649','deals-mobile','border-top-width','1',0,''),(59740,18980,'119649','deals-mobile','border-top-color','#dfa82a',0,''),(59741,18980,'119649','deals-mobile','font-size','18',0,''),(59742,18981,'119650','deals-mobile','block_type','4',0,''),(59743,18981,'119650','deals-mobile','color','#ffffff',0,''),(59744,18981,'119650','deals-mobile','font-size','30',0,''),(59745,18981,'119650','deals-mobile','font-weight','normal',0,''),(59746,18981,'119650','deals-mobile','background-color','#ee4225',0,''),(59747,18981,'119650','deals-mobile','padding-top','5',0,''),(59748,18981,'119650','deals-mobile','padding-left','10',0,''),(59749,18981,'119650','deals-mobile','padding-right','10',0,''),(59750,18981,'119650','deals-mobile','padding-bottom','5',0,''),(59751,18982,'119651','deals-mobile','text','<p>Your code is:</p>',1,''),(59752,18982,'119651','deals-mobile','font-weight','normal',0,''),(59753,18984,'119653','deals-mobile','block_type','1',0,''),(59754,18984,'119653','deals-mobile','font-weight','normal',0,''),(59755,18984,'119653','deals-mobile','style_class','gift-card-view',0,''),(59756,18984,'119653','deals-mobile','text-align','center',0,''),(59757,18984,'119653','deals-mobile','padding-bottom','20',0,''),(59758,18984,'119653','deals-mobile','background-color','#47a793',0,''),(59759,18984,'119653','deals-mobile','padding-left','20',0,''),(59760,18984,'119653','deals-mobile','padding-right','20',0,''),(59761,18984,'119653','deals-mobile','color','#cccccc',0,''),(59762,18985,'119654','deals-mobile','block_type','1',0,''),(59763,18985,'119654','deals-mobile','font-weight','normal',0,''),(59764,18985,'119654','deals-mobile','padding-top','10',0,''),(59765,18986,'119655','deals-mobile','font-size','12',0,''),(59766,18986,'119655','deals-mobile','font-weight','bold',0,''),(59767,18986,'119655','deals-mobile','text-align','center',0,''),(59768,18986,'119655','deals-mobile','style_class','email',0,''),(59769,18986,'119655','deals-mobile','color','#ffffff',0,''),(59770,18987,'119656','deals-mobile','font-size','12',0,''),(59771,18987,'119656','deals-mobile','font-weight','bold',0,''),(59772,18987,'119656','deals-mobile','text-align','center',0,''),(59773,18987,'119656','deals-mobile','style_class','phone',0,''),(59774,18987,'119656','deals-mobile','padding-bottom','5',0,''),(59775,18987,'119656','deals-mobile','color','#ffffff',0,''),(59776,18988,'119657','deals-mobile','text','If you require further assistance please contact us',0,''),(59777,18988,'119657','deals-mobile','font-size','12',0,''),(59778,18988,'119657','deals-mobile','color','#ffffff',0,''),(59779,18988,'119657','deals-mobile','text-align','center',0,''),(59780,18988,'119657','deals-mobile','padding-top','10',0,''),(59781,18989,'119658','deals-mobile','block_type','4',0,''),(59782,18989,'119658','deals-mobile','color','#ffffff',0,''),(59783,18989,'119658','deals-mobile','font-size','30',0,''),(59784,18989,'119658','deals-mobile','font-weight','normal',0,''),(59785,18989,'119658','deals-mobile','background-color','#ee4225',0,''),(59786,18989,'119658','deals-mobile','padding-top','5',0,''),(59787,18989,'119658','deals-mobile','padding-left','10',0,''),(59788,18989,'119658','deals-mobile','padding-right','10',0,''),(59789,18989,'119658','deals-mobile','padding-bottom','5',0,''),(59790,18990,'119659','deals-mobile','text','Your code is:',0,''),(59791,18990,'119659','deals-mobile','font-size','30',0,''),(59792,18990,'119659','deals-mobile','color','#ffffff',0,''),(59793,18991,'119660','deals-mobile','color','#ffffff',0,''),(59794,18991,'119660','deals-mobile','font-size','30',0,''),(59795,18992,'119661','deals-mobile','block_type','1',0,''),(59796,18993,'119662','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59797,18993,'119662','deals-mobile','font-size','18',0,''),(59798,18993,'119662','deals-mobile','font-weight','normal',0,''),(59799,18993,'119662','deals-mobile','text-align','center',0,''),(59800,18993,'119662','deals-mobile','padding-top','20',0,''),(59801,18993,'119662','deals-mobile','padding-bottom','10',0,''),(59802,18993,'119662','deals-mobile','border-top-width','1',0,''),(59803,18993,'119662','deals-mobile','border-top-color','#dfa82a',0,''),(59804,18994,'119663','deals-mobile','text','HOLBI',0,''),(59805,18994,'119663','deals-mobile','color','#ffffff',0,''),(59806,18994,'119663','deals-mobile','font-size','24',0,''),(59807,18994,'119663','deals-mobile','padding-top','20',0,''),(59808,18994,'119663','deals-mobile','text-align','center',0,''),(59809,18994,'119663','deals-mobile','padding-bottom','20',0,''),(59810,18995,'119664','deals-mobile','border-top-color','#dfa82a',0,''),(59811,18995,'119664','deals-mobile','border-top-width','1',0,''),(59812,18995,'119664','deals-mobile','padding-top','20',0,''),(59813,18995,'119664','deals-mobile','font-size','30',0,''),(59814,18995,'119664','deals-mobile','text-align','center',0,''),(59815,18995,'119664','deals-mobile','color','#ffffff',0,''),(59816,18995,'119664','deals-mobile','text','GIFT CARD',0,''),(59817,18996,'119665','deals-mobile','text-align','center',0,''),(59818,18996,'119665','deals-mobile','font-weight','bold',0,''),(59819,18996,'119665','deals-mobile','font-size','60',0,''),(59820,18996,'119665','deals-mobile','color','#ffffff',0,''),(59821,18997,'119666','deals-mobile','font-size','20',0,''),(59822,18997,'119666','deals-mobile','text-align','center',0,''),(59823,18997,'119666','deals-mobile','color','#ffffff',0,''),(59824,18997,'119666','deals-mobile','padding-top','20',0,''),(59825,18997,'119666','deals-mobile','padding-bottom','20',0,''),(59826,18998,'119667','deals-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(59827,18998,'119667','deals-mobile','text-align','center',0,''),(59828,18998,'119667','deals-mobile','color','#ffffff',0,''),(59829,18998,'119667','deals-mobile','font-size','14',0,''),(59830,18998,'119667','deals-mobile','padding-bottom','20',0,''),(59831,18999,'119668','deals-mobile','text','WHAT TO DO NEXT:',0,''),(59832,18999,'119668','deals-mobile','font-size','18',0,''),(59833,18999,'119668','deals-mobile','text-align','center',0,''),(59834,18999,'119668','deals-mobile','color','#ffffff',0,''),(59835,18999,'119668','deals-mobile','padding-top','20',0,''),(59836,18999,'119668','deals-mobile','padding-bottom','10',0,''),(59837,18999,'119668','deals-mobile','border-top-width','1',0,''),(59838,18999,'119668','deals-mobile','border-top-color','#dfa82a',0,''),(59839,19000,'119669','deals-mobile','logo','themes/deals-mobile/img/oscommerce_logo.png',1,''),(59840,19000,'119669','deals-mobile','text-align','center',0,''),(59841,19000,'119669','deals-mobile','padding-top','10',0,''),(59842,19000,'119669','deals-mobile','padding-left','60',0,''),(59843,19000,'119669','deals-mobile','padding-right','60',0,''),(59844,19000,'119669','deals-mobile','padding-bottom','10',0,''),(59845,19001,'119670','deals-mobile','text-align','center',0,''),(59846,19001,'119670','deals-mobile','margin-bottom','20',0,''),(59847,19002,'119671','deals-mobile','block_type','1',0,''),(59848,19002,'119671','deals-mobile','background-color','#eeeeee',0,''),(59849,19002,'119671','deals-mobile','border-bottom-width','1',0,''),(59850,19002,'119671','deals-mobile','border-bottom-color','#dedede',0,''),(59851,19002,'119671','deals-mobile','display_none','on',0,'864'),(59852,19003,'119672','deals-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',1,''),(59853,19003,'119672','deals-mobile','float','right',0,''),(59854,19003,'119672','deals-mobile','max-width','450',0,''),(59855,19003,'119672','deals-mobile','font-size','13',0,''),(59856,19003,'119672','deals-mobile','padding-top','5',0,''),(59857,19003,'119672','deals-mobile','padding-bottom','5',0,''),(59858,19003,'119672','deals-mobile','width','350',0,'871'),(59859,19004,'119673','deals-mobile','block_type','4',0,''),(59860,19004,'119673','deals-mobile','display','inline-block',0,''),(59861,19004,'119673','deals-mobile','width','650',0,''),(59862,19004,'119673','deals-mobile','vertical-align','middle',0,''),(59863,19004,'119673','deals-mobile','float','left',0,''),(59864,19004,'119673','deals-mobile','clear','none',0,''),(59865,19004,'119673','deals-mobile','text-align','left',0,''),(59866,19004,'119673','deals-mobile','padding-top','10',0,''),(59867,19004,'119673','deals-mobile','padding-bottom','10',0,''),(59868,19004,'119673','deals-mobile','schema','4-2',0,'871'),(59869,19004,'119673','deals-mobile','width','350',0,'871'),(59870,19004,'119673','deals-mobile','padding-top','0',0,'871'),(59871,19005,'119674','deals-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',1,''),(59872,19005,'119674','deals-mobile','font-family','Hind',0,''),(59873,19005,'119674','deals-mobile','font-size','22',0,''),(59874,19005,'119674','deals-mobile','color','#00a858',0,''),(59875,19005,'119674','deals-mobile','padding-top','7',0,''),(59876,19005,'119674','deals-mobile','display','inline-block',0,''),(59877,19005,'119674','deals-mobile','float','left',0,''),(59878,19005,'119674','deals-mobile','clear','none',0,''),(59879,19005,'119674','deals-mobile','font-size','20',0,'871'),(59880,19006,'119675','deals-mobile','logo','themes/deals-mobile/img/check-2.png',1,''),(59881,19006,'119675','deals-mobile','display','inline-block',0,''),(59882,19006,'119675','deals-mobile','vertical-align','top',0,''),(59883,19006,'119675','deals-mobile','padding-top','10',0,''),(59884,19006,'119675','deals-mobile','padding-right','10',0,''),(59885,19006,'119675','deals-mobile','float','left',0,''),(59886,19006,'119675','deals-mobile','clear','none',0,''),(59887,19007,'119676','deals-mobile','block_type','2',0,''),(59888,19008,'119677','deals-mobile','text','<a class=\"secure-1_\" href=\"//www.securitymetrics.com/site_certificate?id=1442870&tk=4964ae06eb42dd2462f57cde979b3228\" target=\"_blank\"><img src=\"images/security.jpg\" alt=\"SecurityMetrics Credit Card Safe\" /></a>',0,''),(59889,19008,'119677','deals-mobile','text-align','center',0,''),(59890,19009,'119678','deals-mobile','text','<a href=\"//www.securitymetrics.com/site_certificate?id=1442870&tk=4964ae06eb42dd2462f57cde979b3228\" target=\"_blank\"><img src=\"images/security2.jpg\" alt=\"SecurityMetrics Credit Card Safe\" /></a>',0,''),(59891,19009,'119678','deals-mobile','text-align','center',0,''),(59892,19010,'119679','deals-mobile','block_type','14',0,''),(59893,19010,'119679','deals-mobile','font-weight','400',0,''),(59894,19010,'119679','deals-mobile','background-color','#183d78',0,''),(59895,19011,'119680','deals-mobile','class','menu-style-1',0,''),(59896,19011,'119680','deals-mobile','box_align','4',0,''),(59897,19011,'119680','deals-mobile','font-weight','400',0,''),(59898,19011,'119680','deals-mobile','hide_menu','on',0,''),(59899,19011,'119680','deals-mobile','color','#ffffff',0,''),(59900,19011,'119680','deals-mobile','hide_menu','1',0,'865'),(59901,19015,'119684','deals-mobile','block_type','1',0,''),(59902,19018,'119687','deals-mobile','width','680',0,''),(59903,19018,'119687','deals-mobile','font-weight','normal',0,''),(59904,19018,'119687','deals-mobile','font-size','12',0,''),(59905,19018,'119687','deals-mobile','padding-top','20',0,''),(59906,19018,'119687','deals-mobile','padding-bottom','20',0,''),(59907,19018,'119687','deals-mobile','color','#000000',0,''),(59908,19019,'119688','deals-mobile','block_type','5',0,''),(59909,19019,'119688','deals-mobile','font-weight','normal',0,''),(59910,19019,'119688','deals-mobile','border-bottom-width','1',0,''),(59911,19019,'119688','deals-mobile','border-bottom-color','#e0e0e0',0,''),(59912,19019,'119688','deals-mobile','border-top-width','1',0,''),(59913,19019,'119688','deals-mobile','border-top-color','#e0e0e0',0,''),(59914,19019,'119688','deals-mobile','border-left-color','#e0e0e0',0,''),(59915,19019,'119688','deals-mobile','border-left-width','1',0,''),(59916,19020,'119689','deals-mobile','block_type','1',0,''),(59917,19020,'119689','deals-mobile','font-weight','normal',0,''),(59918,19020,'119689','deals-mobile','padding-top','10',0,''),(59919,19020,'119689','deals-mobile','padding-left','10',0,''),(59920,19020,'119689','deals-mobile','padding-right','10',0,''),(59921,19021,'119690','deals-mobile','font-weight','400',0,''),(59922,19021,'119690','deals-mobile','line-height','120',0,''),(59923,19021,'119690','deals-mobile','line_height_measure','%',0,''),(59924,19022,'119691','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(59925,19022,'119691','deals-mobile','font-size','14',0,''),(59926,19022,'119691','deals-mobile','font-weight','bold',0,''),(59927,19022,'119691','deals-mobile','padding-bottom','10',0,''),(59928,19023,'119692','deals-mobile','block_type','1',0,''),(59929,19023,'119692','deals-mobile','background-color','#e0e0e0',0,''),(59930,19023,'119692','deals-mobile','padding-top','40',0,''),(59931,19023,'119692','deals-mobile','padding-left','10',0,''),(59932,19023,'119692','deals-mobile','padding-right','10',0,''),(59933,19023,'119692','deals-mobile','padding-bottom','40',0,''),(59934,19024,'119693','deals-mobile','font-weight','normal',0,''),(59935,19024,'119693','deals-mobile','line-height','200',0,''),(59936,19024,'119693','deals-mobile','text-align','right',0,''),(59937,19024,'119693','deals-mobile','font-size','14',0,''),(59938,19024,'119693','deals-mobile','box_align','3',0,''),(59939,19025,'119694','deals-mobile','font-weight','400',0,''),(59940,19025,'119694','deals-mobile','padding-top','20',0,''),(59941,19025,'119694','deals-mobile','padding-bottom','20',0,''),(59942,19025,'119694','deals-mobile','font-size','12',0,''),(59943,19026,'119695','deals-mobile','block_type','2',0,''),(59944,19026,'119695','deals-mobile','font-weight','normal',0,''),(59945,19026,'119695','deals-mobile','padding-bottom','20',0,''),(59946,19027,'119696','deals-mobile','font-weight','400',0,''),(59947,19027,'119696','deals-mobile','padding-top','20',0,''),(59949,19028,'119697','deals-mobile','block_type','11',0,''),(59950,19028,'119697','deals-mobile','font-weight','normal',0,''),(59951,19029,'119698','deals-mobile','text','<p>Phone:</p>',1,''),(59952,19029,'119698','deals-mobile','font-weight','normal',0,''),(59953,19029,'119698','deals-mobile','text-align','right',0,''),(59954,19030,'119699','deals-mobile','font-weight','normal',0,''),(59955,19030,'119699','deals-mobile','text-align','right',0,''),(59956,19031,'119700','deals-mobile','block_type','1',0,''),(59957,19032,'119701','deals-mobile','font-weight','normal',0,''),(59958,19032,'119701','deals-mobile','text-align','right',0,''),(59959,19032,'119701','deals-mobile','padding-bottom','10',0,''),(59960,19032,'119701','deals-mobile','address_spacer',',',0,''),(59961,19033,'119702','deals-mobile','block_type','11',0,''),(59962,19033,'119702','deals-mobile','font-weight','normal',0,''),(59963,19034,'119703','deals-mobile','text','<p>Web:</p>',1,''),(59964,19034,'119703','deals-mobile','font-weight','normal',0,''),(59965,19034,'119703','deals-mobile','text-align','right',0,''),(59966,19035,'119704','deals-mobile','font-weight','normal',0,''),(59967,19035,'119704','deals-mobile','text-align','right',0,''),(59968,19036,'119705','deals-mobile','block_type','11',0,''),(59969,19036,'119705','deals-mobile','font-weight','normal',0,''),(59970,19037,'119706','deals-mobile','text','<p>Email:</p>',1,''),(59971,19037,'119706','deals-mobile','font-weight','normal',0,''),(59972,19037,'119706','deals-mobile','text-align','right',0,''),(59973,19038,'119707','deals-mobile','font-weight','normal',0,''),(59974,19038,'119707','deals-mobile','text-align','right',0,''),(59975,19039,'119708','deals-mobile','block_type','3',0,''),(59976,19039,'119708','deals-mobile','font-weight','normal',0,''),(59977,19039,'119708','deals-mobile','padding-top','20',0,''),(59978,19040,'119709','deals-mobile','text','<p>If undelivered please return to:</p>',1,''),(59979,19040,'119709','deals-mobile','font-size','15',0,''),(59980,19040,'119709','deals-mobile','font-weight','bold',0,''),(59981,19041,'119710','deals-mobile','font-size','14',0,''),(59982,19042,'119711','deals-mobile','text','<p>Thank you for your order</p>',1,''),(59983,19042,'119711','deals-mobile','color','#008fe9',0,''),(59984,19042,'119711','deals-mobile','font-size','16',0,''),(59985,19042,'119711','deals-mobile','font-weight','bold',0,''),(59986,19042,'119711','deals-mobile','padding-top','5',0,''),(59987,19042,'119711','deals-mobile','text-align','center',0,''),(59988,19043,'119712','deals-mobile','font-weight','400',0,''),(59989,19043,'119712','deals-mobile','text-align','center',0,''),(59990,19043,'119712','deals-mobile','padding-top','0',0,''),(59992,19043,'119712','deals-mobile','padding-left','20',0,''),(59993,19043,'119712','deals-mobile','padding-right','20',0,''),(59994,19044,'119713','deals-mobile','block_type','6',0,''),(59995,19044,'119713','deals-mobile','font-weight','normal',0,''),(59996,19044,'119713','deals-mobile','font-size','16',0,''),(59997,19045,'119714','deals-mobile','text','<p>Email:</p>',1,''),(59998,19045,'119714','deals-mobile','font-weight','normal',0,''),(59999,19045,'119714','deals-mobile','text-align','right',0,''),(60000,19045,'119714','deals-mobile','font-size','14',0,''),(60001,19046,'119715','deals-mobile','font-weight','normal',0,''),(60002,19046,'119715','deals-mobile','text-align','right',0,''),(60003,19046,'119715','deals-mobile','font-size','14',0,''),(60004,19047,'119716','deals-mobile','block_type','6',0,''),(60005,19047,'119716','deals-mobile','font-weight','normal',0,''),(60006,19047,'119716','deals-mobile','font-size','16',0,''),(60007,19048,'119717','deals-mobile','text','<p>Phone:</p>',1,''),(60008,19048,'119717','deals-mobile','font-weight','normal',0,''),(60009,19048,'119717','deals-mobile','text-align','right',0,''),(60010,19048,'119717','deals-mobile','font-size','14',0,''),(60011,19049,'119718','deals-mobile','font-weight','normal',0,''),(60012,19049,'119718','deals-mobile','text-align','right',0,''),(60013,19049,'119718','deals-mobile','font-size','14',0,''),(60014,19050,'119719','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(60015,19050,'119719','deals-mobile','font-size','14',0,''),(60016,19050,'119719','deals-mobile','font-weight','bold',0,''),(60017,19050,'119719','deals-mobile','text-align','right',0,''),(60018,19051,'119720','deals-mobile','block_type','4',0,''),(60019,19051,'119720','deals-mobile','font-weight','normal',0,''),(60020,19051,'119720','deals-mobile','border-top-width','1',0,''),(60021,19051,'119720','deals-mobile','border-top-color','#e0e0e0',0,''),(60022,19051,'119720','deals-mobile','border-left-width','1',0,''),(60023,19051,'119720','deals-mobile','border-left-color','#e0e0e0',0,''),(60024,19051,'119720','deals-mobile','border-right-width','1',0,''),(60025,19051,'119720','deals-mobile','border-right-color','#e0e0e0',0,''),(60026,19051,'119720','deals-mobile','border-bottom-width','1',0,''),(60027,19051,'119720','deals-mobile','border-bottom-color','#e0e0e0',0,''),(60028,19052,'119721','deals-mobile','block_type','2',0,''),(60029,19052,'119721','deals-mobile','font-weight','normal',0,''),(60030,19052,'119721','deals-mobile','border-top-width','1',0,''),(60031,19052,'119721','deals-mobile','border-top-color','#e0e0e0',0,''),(60032,19052,'119721','deals-mobile','border-right-width','1',0,''),(60033,19052,'119721','deals-mobile','border-right-color','#e0e0e0',0,''),(60034,19053,'119722','deals-mobile','block_type','1',0,''),(60035,19053,'119722','deals-mobile','font-weight','normal',0,''),(60036,19053,'119722','deals-mobile','padding-top','10',0,''),(60037,19053,'119722','deals-mobile','padding-left','10',0,''),(60038,19053,'119722','deals-mobile','padding-right','10',0,''),(60039,19053,'119722','deals-mobile','padding-bottom','10',0,''),(60040,19053,'119722','deals-mobile','border-right-width','1',0,''),(60041,19053,'119722','deals-mobile','border-right-color','#e0e0e0',0,''),(60042,19054,'119723','deals-mobile','text','<p>Shipping via</p>',1,''),(60043,19054,'119723','deals-mobile','font-weight','bold',0,''),(60044,19056,'119725','deals-mobile','block_type','1',0,''),(60045,19056,'119725','deals-mobile','font-weight','normal',0,''),(60046,19056,'119725','deals-mobile','padding-top','10',0,''),(60047,19056,'119725','deals-mobile','padding-left','10',0,''),(60048,19056,'119725','deals-mobile','padding-right','10',0,''),(60049,19056,'119725','deals-mobile','padding-bottom','10',0,''),(60050,19058,'119727','deals-mobile','text','<p>Shipping service</p>',1,''),(60051,19058,'119727','deals-mobile','font-weight','bold',0,''),(60052,19059,'119728','deals-mobile','block_type','2',0,''),(60053,19059,'119728','deals-mobile','font-weight','normal',0,''),(60054,19059,'119728','deals-mobile','border-right-width','1',0,''),(60055,19059,'119728','deals-mobile','border-right-color','#e0e0e0',0,''),(60056,19060,'119729','deals-mobile','block_type','1',0,''),(60057,19060,'119729','deals-mobile','font-weight','400',0,''),(60058,19060,'119729','deals-mobile','background-color','#e0e0e0',0,''),(60059,19060,'119729','deals-mobile','padding-top','10',0,''),(60060,19060,'119729','deals-mobile','padding-left','10',0,''),(60061,19060,'119729','deals-mobile','padding-right','10',0,''),(60062,19060,'119729','deals-mobile','padding-bottom','50',0,''),(60063,19061,'119730','deals-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(60064,19061,'119730','deals-mobile','font-size','16',0,''),(60065,19061,'119730','deals-mobile','font-weight','bold',0,''),(60066,19063,'119732','deals-mobile','block_type','1',0,''),(60067,19063,'119732','deals-mobile','font-weight','normal',0,''),(60068,19063,'119732','deals-mobile','padding-top','10',0,''),(60069,19063,'119732','deals-mobile','padding-left','10',0,''),(60070,19063,'119732','deals-mobile','padding-right','10',0,''),(60071,19063,'119732','deals-mobile','padding-bottom','10',0,''),(60072,19064,'119733','deals-mobile','font-weight','normal',0,''),(60073,19065,'119734','deals-mobile','text','<p>CUSTOMER:</p>',1,''),(60074,19065,'119734','deals-mobile','font-size','14',0,''),(60075,19065,'119734','deals-mobile','font-weight','bold',0,''),(60076,19066,'119735','deals-mobile','font-weight','normal',0,''),(60077,19067,'119736','deals-mobile','text','<p>PHONE NUMBER:</p>',1,''),(60078,19067,'119736','deals-mobile','font-size','14',0,''),(60079,19067,'119736','deals-mobile','font-weight','bold',0,''),(60080,19067,'119736','deals-mobile','padding-top','10',0,''),(60081,19068,'119737','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(60082,19068,'119737','deals-mobile','font-weight','bold',0,''),(60083,19068,'119737','deals-mobile','font-size','14',0,''),(60084,19068,'119737','deals-mobile','padding-top','10',0,''),(60085,19070,'119739','deals-mobile','font-weight','normal',0,''),(60086,19070,'119739','deals-mobile','text-align','center',0,''),(60087,19070,'119739','deals-mobile','padding-bottom','20',0,''),(60088,19071,'119740','deals-mobile','font-weight','normal',0,''),(60089,19071,'119740','deals-mobile','text-align','center',0,''),(60090,19071,'119740','deals-mobile','padding-bottom','10',0,''),(60091,19072,'119741','deals-mobile','font-size','16',0,''),(60092,19072,'119741','deals-mobile','font-weight','bold',0,''),(60093,19072,'119741','deals-mobile','text-align','center',0,''),(60094,19072,'119741','deals-mobile','padding-bottom','10',0,''),(60095,19072,'119741','deals-mobile','padding-top','10',0,''),(60096,19073,'119742','deals-mobile','font-weight','normal',0,''),(60097,19073,'119742','deals-mobile','text-align','center',0,''),(60098,19074,'119743','deals-mobile','text','<p>Payment date:</p>',1,''),(60099,19074,'119743','deals-mobile','font-weight','bold',0,''),(60100,19074,'119743','deals-mobile','text-align','center',0,''),(60101,19075,'119744','deals-mobile','text','<p>Payment Method:</p>',1,''),(60102,19075,'119744','deals-mobile','font-weight','bold',0,''),(60103,19075,'119744','deals-mobile','text-align','center',0,''),(60104,19076,'119745','deals-mobile','block_type','1',0,''),(60105,19076,'119745','deals-mobile','padding-top','20',0,''),(60106,19077,'119746','deals-mobile','tab_1','RETURNING CUSTOMER',1,''),(60107,19077,'119746','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(60108,19080,'119749','deals-mobile','block_type','1',0,''),(60109,19081,'119750','deals-mobile','text','##TEXT_OR##',0,''),(60110,19081,'119750','deals-mobile','font-size','18',0,''),(60111,19081,'119750','deals-mobile','font-weight','700',0,''),(60112,19081,'119750','deals-mobile','padding-top','15',0,''),(60113,19081,'119750','deals-mobile','text-align','center',0,''),(60114,19081,'119750','deals-mobile','content','\\_',0,'3'),(60115,19081,'119750','deals-mobile','height','5',0,'3'),(60116,19081,'119750','deals-mobile','width','70',0,'3'),(60117,19081,'119750','deals-mobile','display','inline-block',0,'3'),(60118,19081,'119750','deals-mobile','border-top-width','1',0,'3'),(60119,19081,'119750','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60120,19081,'119750','deals-mobile','margin-left','10',0,'3'),(60121,19081,'119750','deals-mobile','margin-right','10',0,'3'),(60122,19081,'119750','deals-mobile','content','\\_',0,'4'),(60123,19081,'119750','deals-mobile','display','inline-block',0,'4'),(60124,19081,'119750','deals-mobile','width','70',0,'4'),(60125,19081,'119750','deals-mobile','height','5',0,'4'),(60126,19081,'119750','deals-mobile','border-top-width','1',0,'4'),(60127,19081,'119750','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60128,19081,'119750','deals-mobile','margin-left','10',0,'4'),(60129,19081,'119750','deals-mobile','margin-right','10',0,'4'),(60130,19081,'119750','deals-mobile','position','relative',0,''),(60131,19081,'119750','deals-mobile','top','-10',0,''),(60132,19082,'119751','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60133,19082,'119751','deals-mobile','font-size','26',0,''),(60134,19082,'119751','deals-mobile','font-family','Varela Round',0,''),(60135,19082,'119751','deals-mobile','padding-top','15',0,''),(60136,19082,'119751','deals-mobile','padding-bottom','15',0,''),(60137,19082,'119751','deals-mobile','text-align','center',0,''),(60138,19083,'119752','deals-mobile','text-align','center',0,''),(60139,19083,'119752','deals-mobile','hide_parents','2',0,''),(60140,19084,'119753','deals-mobile','block_type','1',0,''),(60141,19084,'119753','deals-mobile','padding-top','40',0,''),(60142,19084,'119753','deals-mobile','background-color','#eeeeee',0,''),(60143,19084,'119753','deals-mobile','padding-bottom','40',0,''),(60144,19085,'119754','deals-mobile','block_type','1',0,''),(60145,19085,'119754','deals-mobile','background-color','#ffffff',0,''),(60146,19085,'119754','deals-mobile','max-width','830',0,''),(60147,19085,'119754','deals-mobile','margin_left_measure','auto',0,''),(60148,19085,'119754','deals-mobile','margin_right_measure','auto',0,''),(60149,19085,'119754','deals-mobile','padding-top','40',0,''),(60150,19085,'119754','deals-mobile','padding-bottom','40',0,''),(60151,19085,'119754','deals-mobile','schema','2-3',0,''),(60152,19086,'119755','deals-mobile','text','##NEW_CUSTOMER##',0,''),(60153,19086,'119755','deals-mobile','font-size','18',0,''),(60154,19086,'119755','deals-mobile','font-family','Varela Round',0,''),(60155,19086,'119755','deals-mobile','text-align','center',0,''),(60156,19086,'119755','deals-mobile','text-transform','uppercase',0,''),(60157,19086,'119755','deals-mobile','margin-bottom','10',0,''),(60158,19087,'119756','deals-mobile','text-align','center',0,''),(60159,19087,'119756','deals-mobile','margin-bottom','40',0,''),(60160,19088,'119757','deals-mobile','text-align','center',0,''),(60161,19089,'119758','deals-mobile','text','##TEXT_OR##',0,''),(60162,19089,'119758','deals-mobile','font-size','18',0,''),(60163,19089,'119758','deals-mobile','font-weight','700',0,''),(60164,19089,'119758','deals-mobile','text-align','center',0,''),(60165,19089,'119758','deals-mobile','content','\\_',0,'3'),(60166,19089,'119758','deals-mobile','height','5',0,'3'),(60167,19089,'119758','deals-mobile','width','70',0,'3'),(60168,19089,'119758','deals-mobile','display','inline-block',0,'3'),(60169,19089,'119758','deals-mobile','border-top-width','1',0,'3'),(60170,19089,'119758','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60171,19089,'119758','deals-mobile','margin-left','10',0,'3'),(60172,19089,'119758','deals-mobile','margin-right','10',0,'3'),(60173,19089,'119758','deals-mobile','content','\\_',0,'4'),(60174,19089,'119758','deals-mobile','display','inline-block',0,'4'),(60175,19089,'119758','deals-mobile','width','70',0,'4'),(60176,19089,'119758','deals-mobile','height','5',0,'4'),(60177,19089,'119758','deals-mobile','border-top-width','1',0,'4'),(60178,19089,'119758','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60179,19089,'119758','deals-mobile','margin-left','10',0,'4'),(60180,19089,'119758','deals-mobile','margin-right','10',0,'4'),(60181,19089,'119758','deals-mobile','position','relative',0,''),(60182,19089,'119758','deals-mobile','padding-top','10',0,''),(60183,19089,'119758','deals-mobile','padding-bottom','10',0,''),(60184,19090,'119759','deals-mobile','block_type','1',0,''),(60185,19091,'119760','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60186,19091,'119760','deals-mobile','font-size','18',0,''),(60187,19091,'119760','deals-mobile','font-family','Varela Round',0,''),(60188,19091,'119760','deals-mobile','padding-top','15',0,''),(60189,19091,'119760','deals-mobile','padding-bottom','15',0,''),(60190,19091,'119760','deals-mobile','text-align','center',0,''),(60191,19091,'119760','deals-mobile','text-transform','uppercase',0,''),(60192,19092,'119761','deals-mobile','text-align','center',0,''),(60193,19092,'119761','deals-mobile','hide_parents','2',0,''),(60194,19093,'119762','deals-mobile','max-width','230',0,''),(60195,19093,'119762','deals-mobile','margin_left_measure','auto',0,''),(60196,19093,'119762','deals-mobile','margin_right_measure','auto',0,''),(60197,19094,'119763','deals-mobile','text','##RETURNING_CUSTOMER##',0,''),(60198,19094,'119763','deals-mobile','font-size','18',0,''),(60199,19094,'119763','deals-mobile','font-family','Varela Round',0,''),(60200,19094,'119763','deals-mobile','text-transform','uppercase',0,''),(60201,19094,'119763','deals-mobile','text-align','center',0,''),(60202,19095,'119764','deals-mobile','block_type','1',0,''),(60203,19095,'119764','deals-mobile','padding-top','20',0,''),(60204,19096,'119765','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60205,19096,'119765','deals-mobile','font-size','26',0,''),(60206,19096,'119765','deals-mobile','font-family','Varela Round',0,''),(60207,19096,'119765','deals-mobile','padding-top','15',0,''),(60208,19096,'119765','deals-mobile','padding-bottom','15',0,''),(60209,19096,'119765','deals-mobile','text-align','center',0,''),(60210,19097,'119766','deals-mobile','text','##TEXT_OR##',0,''),(60211,19097,'119766','deals-mobile','font-size','18',0,''),(60212,19097,'119766','deals-mobile','font-weight','700',0,''),(60213,19097,'119766','deals-mobile','padding-top','15',0,''),(60214,19097,'119766','deals-mobile','text-align','center',0,''),(60215,19097,'119766','deals-mobile','content','\\_',0,'3'),(60216,19097,'119766','deals-mobile','height','5',0,'3'),(60217,19097,'119766','deals-mobile','width','70',0,'3'),(60218,19097,'119766','deals-mobile','display','inline-block',0,'3'),(60219,19097,'119766','deals-mobile','border-top-width','1',0,'3'),(60220,19097,'119766','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60221,19097,'119766','deals-mobile','margin-left','10',0,'3'),(60222,19097,'119766','deals-mobile','margin-right','10',0,'3'),(60223,19097,'119766','deals-mobile','content','\\_',0,'4'),(60224,19097,'119766','deals-mobile','display','inline-block',0,'4'),(60225,19097,'119766','deals-mobile','width','70',0,'4'),(60226,19097,'119766','deals-mobile','height','5',0,'4'),(60227,19097,'119766','deals-mobile','border-top-width','1',0,'4'),(60228,19097,'119766','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60229,19097,'119766','deals-mobile','margin-left','10',0,'4'),(60230,19097,'119766','deals-mobile','margin-right','10',0,'4'),(60231,19097,'119766','deals-mobile','position','relative',0,''),(60232,19097,'119766','deals-mobile','top','-10',0,''),(60233,19098,'119767','deals-mobile','text-align','center',0,''),(60234,19099,'119768','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(60235,19099,'119768','deals-mobile','tab_2','RETURNING CUSTOMER',1,''),(60236,19099,'119768','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(60237,19100,'119769','deals-mobile','block_type','8',0,''),(60238,19101,'119770','deals-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(60239,19102,'119771','deals-mobile','block_type','1',0,''),(60240,19102,'119771','deals-mobile','padding-left','20',0,''),(60241,19102,'119771','deals-mobile','padding-right','20',0,''),(60242,19103,'119772','deals-mobile','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(60243,19103,'119772','deals-mobile','border-top-width','1',0,''),(60244,19103,'119772','deals-mobile','border-top-color','#e0e0e0',0,''),(60245,19106,'119775','deals-mobile','block_type','8',0,''),(60246,19107,'119776','deals-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(60247,19108,'119777','deals-mobile','block_type','1',0,''),(60248,19108,'119777','deals-mobile','padding-left','20',0,''),(60249,19108,'119777','deals-mobile','padding-right','20',0,''),(60250,19110,'119779','deals-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(60251,19111,'119780','deals-mobile','block_type','1',0,''),(60252,19111,'119780','deals-mobile','padding-top','20',0,''),(60253,19112,'119781','deals-mobile','text-align','center',0,''),(60254,19113,'119782','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60255,19113,'119782','deals-mobile','font-size','26',0,''),(60256,19113,'119782','deals-mobile','font-family','Varela Round',0,''),(60257,19113,'119782','deals-mobile','padding-top','15',0,''),(60258,19113,'119782','deals-mobile','padding-bottom','15',0,''),(60259,19113,'119782','deals-mobile','text-align','center',0,''),(60260,19114,'119783','deals-mobile','text','##TEXT_OR##',0,''),(60261,19114,'119783','deals-mobile','font-size','18',0,''),(60262,19114,'119783','deals-mobile','font-weight','700',0,''),(60263,19114,'119783','deals-mobile','padding-top','15',0,''),(60264,19114,'119783','deals-mobile','text-align','center',0,''),(60265,19114,'119783','deals-mobile','content','\\_',0,'3'),(60266,19114,'119783','deals-mobile','height','5',0,'3'),(60267,19114,'119783','deals-mobile','width','70',0,'3'),(60268,19114,'119783','deals-mobile','display','inline-block',0,'3'),(60269,19114,'119783','deals-mobile','border-top-width','1',0,'3'),(60270,19114,'119783','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60271,19114,'119783','deals-mobile','margin-left','10',0,'3'),(60272,19114,'119783','deals-mobile','margin-right','10',0,'3'),(60273,19114,'119783','deals-mobile','content','\\_',0,'4'),(60274,19114,'119783','deals-mobile','display','inline-block',0,'4'),(60275,19114,'119783','deals-mobile','width','70',0,'4'),(60276,19114,'119783','deals-mobile','height','5',0,'4'),(60277,19114,'119783','deals-mobile','border-top-width','1',0,'4'),(60278,19114,'119783','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60279,19114,'119783','deals-mobile','margin-left','10',0,'4'),(60280,19114,'119783','deals-mobile','margin-right','10',0,'4'),(60281,19114,'119783','deals-mobile','position','relative',0,''),(60282,19114,'119783','deals-mobile','top','-10',0,''),(60283,19115,'119784','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(60284,19115,'119784','deals-mobile','tab_2','RETURNING CUSTOMER',1,''),(60285,19115,'119784','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(60286,19116,'119785','deals-mobile','block_type','8',0,''),(60287,19117,'119786','deals-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(60288,19120,'119789','deals-mobile','block_type','8',0,''),(60289,19121,'119790','deals-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(60290,19123,'119792','deals-mobile','block_type','1',0,''),(60291,19123,'119792','deals-mobile','padding-left','20',0,''),(60292,19123,'119792','deals-mobile','padding-right','20',0,''),(60293,19124,'119793','deals-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(60294,19126,'119795','deals-mobile','block_type','1',0,''),(60295,19126,'119795','deals-mobile','padding-top','20',0,''),(60296,19127,'119796','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60297,19127,'119796','deals-mobile','font-size','26',0,''),(60298,19127,'119796','deals-mobile','font-family','Varela Round',0,''),(60299,19127,'119796','deals-mobile','padding-top','15',0,''),(60300,19127,'119796','deals-mobile','padding-bottom','15',0,''),(60301,19127,'119796','deals-mobile','text-align','center',0,''),(60302,19128,'119797','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(60303,19128,'119797','deals-mobile','tab_2','RETURNING CUSTOMER',1,''),(60304,19128,'119797','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(60305,19129,'119798','deals-mobile','block_type','8',0,''),(60306,19130,'119799','deals-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(60307,19133,'119802','deals-mobile','block_type','8',0,''),(60308,19134,'119803','deals-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(60309,19135,'119804','deals-mobile','block_type','1',0,''),(60310,19135,'119804','deals-mobile','padding-left','20',0,''),(60311,19135,'119804','deals-mobile','padding-right','20',0,''),(60312,19136,'119805','deals-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(60313,19138,'119807','deals-mobile','text-align','center',0,''),(60314,19139,'119808','deals-mobile','text','##TEXT_OR##',0,''),(60315,19139,'119808','deals-mobile','font-size','18',0,''),(60316,19139,'119808','deals-mobile','font-weight','700',0,''),(60317,19139,'119808','deals-mobile','padding-top','15',0,''),(60318,19139,'119808','deals-mobile','text-align','center',0,''),(60319,19139,'119808','deals-mobile','content','\\_',0,'3'),(60320,19139,'119808','deals-mobile','height','5',0,'3'),(60321,19139,'119808','deals-mobile','width','70',0,'3'),(60322,19139,'119808','deals-mobile','display','inline-block',0,'3'),(60323,19139,'119808','deals-mobile','border-top-width','1',0,'3'),(60324,19139,'119808','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60325,19139,'119808','deals-mobile','margin-left','10',0,'3'),(60326,19139,'119808','deals-mobile','margin-right','10',0,'3'),(60327,19139,'119808','deals-mobile','content','\\_',0,'4'),(60328,19139,'119808','deals-mobile','display','inline-block',0,'4'),(60329,19139,'119808','deals-mobile','width','70',0,'4'),(60330,19139,'119808','deals-mobile','height','5',0,'4'),(60331,19139,'119808','deals-mobile','border-top-width','1',0,'4'),(60332,19139,'119808','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60333,19139,'119808','deals-mobile','margin-left','10',0,'4'),(60334,19139,'119808','deals-mobile','margin-right','10',0,'4'),(60335,19139,'119808','deals-mobile','position','relative',0,''),(60336,19139,'119808','deals-mobile','top','-10',0,''),(60337,19140,'119809','deals-mobile','block_type','1',0,''),(60338,19140,'119809','deals-mobile','padding-top','40',0,''),(60339,19140,'119809','deals-mobile','background-color','#eeeeee',0,''),(60340,19140,'119809','deals-mobile','padding-bottom','40',0,''),(60341,19141,'119810','deals-mobile','block_type','2',0,''),(60342,19141,'119810','deals-mobile','background-color','#ffffff',0,''),(60343,19141,'119810','deals-mobile','max-width','830',0,''),(60344,19141,'119810','deals-mobile','margin_left_measure','auto',0,''),(60345,19141,'119810','deals-mobile','margin_right_measure','auto',0,''),(60346,19141,'119810','deals-mobile','padding-top','40',0,''),(60347,19141,'119810','deals-mobile','padding-bottom','40',0,''),(60348,19142,'119811','deals-mobile','text-align','center',0,''),(60349,19142,'119811','deals-mobile','margin-bottom','40',0,''),(60350,19143,'119812','deals-mobile','text-align','center',0,''),(60351,19144,'119813','deals-mobile','text','##NEW_CUSTOMER##',0,''),(60352,19144,'119813','deals-mobile','font-size','18',0,''),(60353,19144,'119813','deals-mobile','font-family','Varela Round',0,''),(60354,19144,'119813','deals-mobile','text-align','center',0,''),(60355,19144,'119813','deals-mobile','text-transform','uppercase',0,''),(60356,19144,'119813','deals-mobile','margin-bottom','10',0,''),(60357,19145,'119814','deals-mobile','text','##TEXT_OR##',0,''),(60358,19145,'119814','deals-mobile','font-size','18',0,''),(60359,19145,'119814','deals-mobile','font-weight','700',0,''),(60360,19145,'119814','deals-mobile','text-align','center',0,''),(60361,19145,'119814','deals-mobile','content','\\_',0,'3'),(60362,19145,'119814','deals-mobile','height','5',0,'3'),(60363,19145,'119814','deals-mobile','width','70',0,'3'),(60364,19145,'119814','deals-mobile','display','inline-block',0,'3'),(60365,19145,'119814','deals-mobile','border-top-width','1',0,'3'),(60366,19145,'119814','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60367,19145,'119814','deals-mobile','margin-left','10',0,'3'),(60368,19145,'119814','deals-mobile','margin-right','10',0,'3'),(60369,19145,'119814','deals-mobile','content','\\_',0,'4'),(60370,19145,'119814','deals-mobile','display','inline-block',0,'4'),(60371,19145,'119814','deals-mobile','width','70',0,'4'),(60372,19145,'119814','deals-mobile','height','5',0,'4'),(60373,19145,'119814','deals-mobile','border-top-width','1',0,'4'),(60374,19145,'119814','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60375,19145,'119814','deals-mobile','margin-left','10',0,'4'),(60376,19145,'119814','deals-mobile','margin-right','10',0,'4'),(60377,19145,'119814','deals-mobile','position','relative',0,''),(60378,19145,'119814','deals-mobile','padding-top','10',0,''),(60379,19145,'119814','deals-mobile','padding-bottom','10',0,''),(60380,19146,'119815','deals-mobile','block_type','1',0,''),(60381,19147,'119816','deals-mobile','text-align','center',0,''),(60382,19147,'119816','deals-mobile','hide_parents','2',0,''),(60383,19148,'119817','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60384,19148,'119817','deals-mobile','font-size','18',0,''),(60385,19148,'119817','deals-mobile','font-family','Varela Round',0,''),(60386,19148,'119817','deals-mobile','padding-top','15',0,''),(60387,19148,'119817','deals-mobile','padding-bottom','15',0,''),(60388,19148,'119817','deals-mobile','text-align','center',0,''),(60389,19148,'119817','deals-mobile','text-transform','uppercase',0,''),(60390,19149,'119818','deals-mobile','max-width','230',0,''),(60391,19149,'119818','deals-mobile','margin_left_measure','auto',0,''),(60392,19149,'119818','deals-mobile','margin_right_measure','auto',0,''),(60393,19150,'119819','deals-mobile','text','##RETURNING_CUSTOMER##',0,''),(60394,19150,'119819','deals-mobile','font-size','18',0,''),(60395,19150,'119819','deals-mobile','font-family','Varela Round',0,''),(60396,19150,'119819','deals-mobile','text-transform','uppercase',0,''),(60397,19150,'119819','deals-mobile','text-align','center',0,''),(60398,19151,'119820','deals-mobile','block_type','1',0,''),(60399,19151,'119820','deals-mobile','padding-top','40',0,''),(60400,19151,'119820','deals-mobile','background-color','#eeeeee',0,''),(60401,19151,'119820','deals-mobile','padding-bottom','40',0,''),(60402,19152,'119821','deals-mobile','block_type','2',0,''),(60403,19152,'119821','deals-mobile','background-color','#ffffff',0,''),(60404,19152,'119821','deals-mobile','max-width','830',0,''),(60405,19152,'119821','deals-mobile','margin_left_measure','auto',0,''),(60406,19152,'119821','deals-mobile','margin_right_measure','auto',0,''),(60407,19152,'119821','deals-mobile','padding-top','40',0,''),(60408,19152,'119821','deals-mobile','padding-bottom','40',0,''),(60409,19153,'119822','deals-mobile','block_type','1',0,''),(60410,19154,'119823','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60411,19154,'119823','deals-mobile','font-size','18',0,''),(60412,19154,'119823','deals-mobile','font-family','Varela Round',0,''),(60413,19154,'119823','deals-mobile','padding-top','15',0,''),(60414,19154,'119823','deals-mobile','padding-bottom','15',0,''),(60415,19154,'119823','deals-mobile','text-align','center',0,''),(60416,19154,'119823','deals-mobile','text-transform','uppercase',0,''),(60417,19155,'119824','deals-mobile','text-align','center',0,''),(60418,19155,'119824','deals-mobile','hide_parents','2',0,''),(60419,19156,'119825','deals-mobile','text','##TEXT_OR##',0,''),(60420,19156,'119825','deals-mobile','font-size','18',0,''),(60421,19156,'119825','deals-mobile','font-weight','700',0,''),(60422,19156,'119825','deals-mobile','text-align','center',0,''),(60423,19156,'119825','deals-mobile','content','\\_',0,'3'),(60424,19156,'119825','deals-mobile','height','5',0,'3'),(60425,19156,'119825','deals-mobile','width','70',0,'3'),(60426,19156,'119825','deals-mobile','display','inline-block',0,'3'),(60427,19156,'119825','deals-mobile','border-top-width','1',0,'3'),(60428,19156,'119825','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60429,19156,'119825','deals-mobile','margin-left','10',0,'3'),(60430,19156,'119825','deals-mobile','margin-right','10',0,'3'),(60431,19156,'119825','deals-mobile','content','\\_',0,'4'),(60432,19156,'119825','deals-mobile','display','inline-block',0,'4'),(60433,19156,'119825','deals-mobile','width','70',0,'4'),(60434,19156,'119825','deals-mobile','height','5',0,'4'),(60435,19156,'119825','deals-mobile','border-top-width','1',0,'4'),(60436,19156,'119825','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60437,19156,'119825','deals-mobile','margin-left','10',0,'4'),(60438,19156,'119825','deals-mobile','margin-right','10',0,'4'),(60439,19156,'119825','deals-mobile','position','relative',0,''),(60440,19156,'119825','deals-mobile','padding-top','10',0,''),(60441,19156,'119825','deals-mobile','padding-bottom','10',0,''),(60442,19157,'119826','deals-mobile','text-align','center',0,''),(60443,19157,'119826','deals-mobile','margin-bottom','40',0,''),(60444,19158,'119827','deals-mobile','text','##NEW_CUSTOMER##',0,''),(60445,19158,'119827','deals-mobile','font-size','18',0,''),(60446,19158,'119827','deals-mobile','font-family','Varela Round',0,''),(60447,19158,'119827','deals-mobile','text-align','center',0,''),(60448,19158,'119827','deals-mobile','text-transform','uppercase',0,''),(60449,19158,'119827','deals-mobile','margin-bottom','10',0,''),(60450,19159,'119828','deals-mobile','text-align','center',0,''),(60451,19160,'119829','deals-mobile','text','##RETURNING_CUSTOMER##',0,''),(60452,19160,'119829','deals-mobile','font-size','18',0,''),(60453,19160,'119829','deals-mobile','font-family','Varela Round',0,''),(60454,19160,'119829','deals-mobile','text-transform','uppercase',0,''),(60455,19160,'119829','deals-mobile','text-align','center',0,''),(60456,19161,'119830','deals-mobile','max-width','230',0,''),(60457,19161,'119830','deals-mobile','margin_left_measure','auto',0,''),(60458,19161,'119830','deals-mobile','margin_right_measure','auto',0,''),(60459,19162,'119831','deals-mobile','block_type','1',0,''),(60460,19163,'119832','deals-mobile','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(60461,19163,'119832','deals-mobile','margin-bottom','30',0,''),(60462,19164,'119833','deals-mobile','block_type','1',0,''),(60463,19165,'119834','deals-mobile','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(60464,19165,'119834','deals-mobile','margin-bottom','30',0,''),(60465,19166,'119835','deals-mobile','block_type','1',0,''),(60466,19166,'119835','deals-mobile','font-weight','normal',0,''),(60467,19168,'119837','deals-mobile','box_align','4',0,''),(60468,19168,'119837','deals-mobile','margin-bottom','30',0,''),(60469,19169,'119838','deals-mobile','tab_1','New products',1,''),(60470,19169,'119838','deals-mobile','tab_2','Specials products',1,''),(60471,19169,'119838','deals-mobile','font-weight','normal',0,''),(60472,19169,'119838','deals-mobile','tab_3','Featured',1,''),(60473,19169,'119838','deals-mobile','accordion','1',0,'863'),(60474,19170,'119839','deals-mobile','font-weight','400',0,''),(60475,19170,'119839','deals-mobile','listing_type','productListing',0,''),(60476,19170,'119839','deals-mobile','show_compare','1',0,''),(60477,19170,'119839','deals-mobile','show_model','1',0,''),(60478,19170,'119839','deals-mobile','show_properties','1',0,''),(60479,19170,'119839','deals-mobile','col_in_row','2',0,''),(60480,19170,'119839','deals-mobile','show_name','0',0,''),(60481,19170,'119839','deals-mobile','show_image','0',0,''),(60482,19170,'119839','deals-mobile','show_stock','0',0,''),(60483,19170,'119839','deals-mobile','show_description','0',0,''),(60484,19170,'119839','deals-mobile','show_rating','0',0,''),(60485,19170,'119839','deals-mobile','show_rating_counts','0',0,''),(60486,19170,'119839','deals-mobile','show_price','0',0,''),(60487,19170,'119839','deals-mobile','show_buy_button','0',0,''),(60488,19170,'119839','deals-mobile','show_qty_input','0',0,''),(60489,19170,'119839','deals-mobile','show_view_button','0',0,''),(60490,19170,'119839','deals-mobile','show_wishlist_button','0',0,''),(60491,19170,'119839','deals-mobile','col_in_row','2',0,'864'),(60492,19170,'119839','deals-mobile','col_in_row','1',0,'888'),(60493,19170,'119839','deals-mobile','view_as','carousel',0,''),(60494,19170,'119839','deals-mobile','col_in_row','3',0,'872'),(60495,19171,'119840','deals-mobile','font-weight','400',0,''),(60496,19171,'119840','deals-mobile','show_compare','1',0,''),(60497,19171,'119840','deals-mobile','listing_type','productListing',0,''),(60498,19171,'119840','deals-mobile','show_model','1',0,''),(60499,19171,'119840','deals-mobile','show_properties','1',0,''),(60500,19171,'119840','deals-mobile','col_in_row','2',0,''),(60501,19171,'119840','deals-mobile','show_name','0',0,''),(60502,19171,'119840','deals-mobile','show_image','0',0,''),(60503,19171,'119840','deals-mobile','show_stock','0',0,''),(60504,19171,'119840','deals-mobile','show_description','0',0,''),(60505,19171,'119840','deals-mobile','show_rating','0',0,''),(60506,19171,'119840','deals-mobile','show_rating_counts','0',0,''),(60507,19171,'119840','deals-mobile','show_price','0',0,''),(60508,19171,'119840','deals-mobile','show_buy_button','0',0,''),(60509,19171,'119840','deals-mobile','show_qty_input','0',0,''),(60510,19171,'119840','deals-mobile','show_view_button','0',0,''),(60511,19171,'119840','deals-mobile','show_wishlist_button','0',0,''),(60512,19171,'119840','deals-mobile','col_in_row','2',0,'864'),(60513,19171,'119840','deals-mobile','col_in_row','1',0,'888'),(60514,19171,'119840','deals-mobile','view_as','carousel',0,''),(60515,19171,'119840','deals-mobile','col_in_row','3',0,'872'),(60516,19171,'119840','deals-mobile','product_names_teg','h2',0,''),(60517,19172,'119841','deals-mobile','font-weight','400',0,''),(60518,19172,'119841','deals-mobile','show_compare','1',0,''),(60519,19172,'119841','deals-mobile','listing_type','productListing',0,''),(60520,19172,'119841','deals-mobile','show_model','1',0,''),(60521,19172,'119841','deals-mobile','show_properties','1',0,''),(60522,19172,'119841','deals-mobile','col_in_row','2',0,''),(60523,19172,'119841','deals-mobile','show_name','0',0,''),(60524,19172,'119841','deals-mobile','show_image','0',0,''),(60525,19172,'119841','deals-mobile','show_stock','0',0,''),(60526,19172,'119841','deals-mobile','show_description','0',0,''),(60527,19172,'119841','deals-mobile','show_rating','0',0,''),(60528,19172,'119841','deals-mobile','show_rating_counts','0',0,''),(60529,19172,'119841','deals-mobile','show_price','0',0,''),(60530,19172,'119841','deals-mobile','show_buy_button','0',0,''),(60531,19172,'119841','deals-mobile','show_qty_input','0',0,''),(60532,19172,'119841','deals-mobile','show_view_button','0',0,''),(60533,19172,'119841','deals-mobile','show_wishlist_button','0',0,''),(60534,19172,'119841','deals-mobile','col_in_row','2',0,'864'),(60535,19172,'119841','deals-mobile','col_in_row','1',0,'888'),(60536,19172,'119841','deals-mobile','view_as','carousel',0,''),(60537,19172,'119841','deals-mobile','col_in_row','3',0,'872'),(60538,19173,'119842','deals-mobile','heading_type','h1',0,''),(60539,19174,'119843','deals-mobile','block_type','1',0,''),(60540,19174,'119843','deals-mobile','background-color','#eeeeee',0,''),(60541,19174,'119843','deals-mobile','padding-top','20',0,''),(60542,19174,'119843','deals-mobile','padding-bottom','20',0,''),(60543,19174,'119843','deals-mobile','font-weight','400',0,''),(60544,19174,'119843','deals-mobile','visibility_product','1',0,''),(60545,19174,'119843','deals-mobile','visibility_catalog','1',0,''),(60546,19174,'119843','deals-mobile','visibility_info','1',0,''),(60547,19174,'119843','deals-mobile','visibility_cart','1',0,''),(60548,19174,'119843','deals-mobile','visibility_checkout','1',0,''),(60549,19174,'119843','deals-mobile','visibility_success','1',0,''),(60550,19174,'119843','deals-mobile','visibility_account','1',0,''),(60551,19174,'119843','deals-mobile','visibility_login','1',0,''),(60552,19174,'119843','deals-mobile','visibility_other','1',0,''),(60553,19174,'119843','deals-mobile','margin-bottom','20',0,''),(60554,19174,'119843','deals-mobile','display_none','on',0,'864'),(60555,19175,'119844','deals-mobile','block_type','2',0,''),(60556,19175,'119844','deals-mobile','font-weight','normal',0,''),(60557,19176,'119845','deals-mobile','font-weight','400',0,''),(60558,19176,'119845','deals-mobile','visibility_product','1',0,''),(60559,19176,'119845','deals-mobile','show_name','0',0,''),(60560,19176,'119845','deals-mobile','show_image','1',0,''),(60561,19176,'119845','deals-mobile','show_stock','1',0,''),(60562,19176,'119845','deals-mobile','show_description','1',0,''),(60563,19176,'119845','deals-mobile','show_model','1',0,''),(60564,19176,'119845','deals-mobile','show_rating','1',0,''),(60565,19176,'119845','deals-mobile','show_rating_counts','1',0,''),(60566,19176,'119845','deals-mobile','show_price','1',0,''),(60567,19176,'119845','deals-mobile','show_buy_button','1',0,''),(60568,19176,'119845','deals-mobile','show_qty_input','1',0,''),(60569,19176,'119845','deals-mobile','show_view_button','1',0,''),(60570,19176,'119845','deals-mobile','show_wishlist_button','1',0,''),(60571,19176,'119845','deals-mobile','show_compare','1',0,''),(60572,19176,'119845','deals-mobile','listing_type','type-1',0,''),(60573,19176,'119845','deals-mobile','show_properties','1',0,''),(60574,19177,'119846','deals-mobile','font-weight','normal',0,''),(60575,19177,'119846','deals-mobile','visibility_product','1',0,''),(60576,19178,'119847','deals-mobile','block_type','1',0,''),(60577,19179,'119848','deals-mobile','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(60578,19181,'119850','deals-mobile','block_type','1',0,''),(60579,19181,'119850','deals-mobile','padding-top','40',0,''),(60580,19181,'119850','deals-mobile','padding-bottom','80',0,''),(60581,19182,'119851','deals-mobile','block_type','6',0,''),(60582,19183,'119852','deals-mobile','block_type','1',0,''),(60583,19183,'119852','deals-mobile','padding-top','20',0,''),(60584,19183,'119852','deals-mobile','padding-left','20',0,''),(60585,19183,'119852','deals-mobile','padding-right','20',0,''),(60586,19183,'119852','deals-mobile','padding-bottom','20',0,''),(60587,19183,'119852','deals-mobile','border-top-width','1',0,''),(60588,19183,'119852','deals-mobile','border-left-width','1',0,''),(60589,19183,'119852','deals-mobile','border-right-width','1',0,''),(60590,19183,'119852','deals-mobile','border-bottom-width','1',0,''),(60591,19183,'119852','deals-mobile','border-top-color','#e0e0e0',0,''),(60592,19183,'119852','deals-mobile','border-left-color','#e0e0e0',0,''),(60593,19183,'119852','deals-mobile','border-right-color','#e0e0e0',0,''),(60594,19183,'119852','deals-mobile','border-bottom-color','#e0e0e0',0,''),(60595,19183,'119852','deals-mobile','margin-right','20',0,''),(60596,19186,'119855','deals-mobile','block_type','1',0,''),(60597,19186,'119855','deals-mobile','padding-top','20',0,''),(60598,19187,'119856','deals-mobile','block_type','6',0,''),(60599,19188,'119857','deals-mobile','padding-right','20',0,''),(60600,19190,'119859','deals-mobile','block_type','1',0,''),(60601,19190,'119859','deals-mobile','padding-top','20',0,''),(60602,19191,'119860','deals-mobile','block_type','6',0,''),(60603,19192,'119861','deals-mobile','padding-right','20',0,''),(60604,19194,'119863','deals-mobile','block_type','1',0,''),(60605,19195,'119864','deals-mobile','block_type','6',0,''),(60606,19195,'119864','deals-mobile','schema','6-3',0,''),(60607,19195,'119864','deals-mobile','schema','6-3',0,'872'),(60608,19196,'119865','deals-mobile','aria_name','account-menu',0,''),(60609,19198,'119867','deals-mobile','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(60610,19199,'119868','deals-mobile','text','CANCEL',0,''),(60611,19199,'119868','deals-mobile','like_button','1',0,''),(60612,19199,'119868','deals-mobile','padding-bottom','20',0,''),(60613,19200,'119869','deals-mobile','block_type','1',0,''),(60614,19200,'119869','deals-mobile','padding-top','20',0,''),(60615,19201,'119870','deals-mobile','block_type','1',0,''),(60616,19202,'119871','deals-mobile','tab_1','RETURNING CUSTOMER',1,''),(60617,19202,'119871','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(60618,19204,'119873','deals-mobile','block_type','8',0,''),(60619,19205,'119874','deals-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(60620,19206,'119875','deals-mobile','block_type','1',0,''),(60621,19206,'119875','deals-mobile','padding-left','20',0,''),(60622,19206,'119875','deals-mobile','padding-right','20',0,''),(60623,19208,'119877','deals-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(60624,19209,'119878','deals-mobile','block_type','1',0,''),(60625,19210,'119879','deals-mobile','margin-bottom','30',0,''),(60626,19211,'119880','deals-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(60627,19212,'119881','deals-mobile','margin_left_measure','auto',0,''),(60628,19212,'119881','deals-mobile','margin_right_measure','auto',0,''),(60629,19212,'119881','deals-mobile','max-width','560',0,''),(60630,19213,'119882','deals-mobile','block_type','1',0,''),(60631,19215,'119884','deals-mobile','block_type','6',0,''),(60632,19215,'119884','deals-mobile','font-weight','400',0,''),(60633,19215,'119884','deals-mobile','schema','6-2',0,''),(60635,19216,'119885','deals-mobile','font-weight','400',0,''),(60636,19216,'119885','deals-mobile','padding-right','40',0,''),(60639,19217,'119886','deals-mobile','col_in_row','3',0,''),(60640,19217,'119886','deals-mobile','products_align','left',0,''),(60641,19217,'119886','deals-mobile','font-weight','400',0,''),(60642,19217,'119886','deals-mobile','show_qty_input','0',0,''),(60643,19217,'119886','deals-mobile','listing_type','productListing',0,''),(60644,19217,'119886','deals-mobile','listing_type_rows','no',0,''),(60645,19217,'119886','deals-mobile','show_buy_button_b2b','on',0,''),(60646,19217,'119886','deals-mobile','show_wishlist_button_b2b','1',0,''),(60647,19217,'119886','deals-mobile','show_compare_b2b','1',0,''),(60648,19217,'119886','deals-mobile','show_stock','0',0,''),(60649,19217,'119886','deals-mobile','show_description','0',0,''),(60650,19217,'119886','deals-mobile','show_model','0',0,''),(60651,19217,'119886','deals-mobile','show_properties','0',0,''),(60652,19217,'119886','deals-mobile','show_rating','0',0,''),(60653,19217,'119886','deals-mobile','show_rating_counts','0',0,''),(60654,19217,'119886','deals-mobile','show_price','0',0,''),(60655,19217,'119886','deals-mobile','show_buy_button','0',0,''),(60656,19217,'119886','deals-mobile','show_view_button','0',0,''),(60657,19217,'119886','deals-mobile','show_wishlist_button','0',0,''),(60658,19217,'119886','deals-mobile','show_compare','0',0,''),(60659,19217,'119886','deals-mobile','show_name_rows','0',0,''),(60660,19217,'119886','deals-mobile','show_image_rows','0',0,''),(60661,19217,'119886','deals-mobile','show_stock_rows','0',0,''),(60662,19217,'119886','deals-mobile','show_description_rows','0',0,''),(60663,19217,'119886','deals-mobile','show_model_rows','0',0,''),(60664,19217,'119886','deals-mobile','show_properties_rows','0',0,''),(60665,19217,'119886','deals-mobile','show_rating_rows','0',0,''),(60666,19217,'119886','deals-mobile','show_rating_counts_rows','0',0,''),(60667,19217,'119886','deals-mobile','show_price_rows','0',0,''),(60668,19217,'119886','deals-mobile','show_buy_button_rows','0',0,''),(60669,19217,'119886','deals-mobile','show_qty_input_rows','0',0,''),(60670,19217,'119886','deals-mobile','show_view_button_rows','0',0,''),(60671,19217,'119886','deals-mobile','show_wishlist_button_rows','0',0,''),(60672,19217,'119886','deals-mobile','show_compare_rows','0',0,''),(60673,19217,'119886','deals-mobile','show_name_b2b','0',0,''),(60674,19217,'119886','deals-mobile','show_image_b2b','0',0,''),(60675,19217,'119886','deals-mobile','show_stock_b2b','0',0,''),(60676,19217,'119886','deals-mobile','show_description_b2b','0',0,''),(60677,19217,'119886','deals-mobile','show_model_b2b','0',0,''),(60678,19217,'119886','deals-mobile','show_properties_b2b','0',0,''),(60679,19217,'119886','deals-mobile','show_rating_b2b','0',0,''),(60680,19217,'119886','deals-mobile','show_rating_counts_b2b','0',0,''),(60681,19217,'119886','deals-mobile','show_price_b2b','0',0,''),(60682,19217,'119886','deals-mobile','show_qty_input_b2b','0',0,''),(60683,19217,'119886','deals-mobile','show_view_button_b2b','0',0,''),(60684,19217,'119886','deals-mobile','show_attributes_b2b','0',0,''),(60685,19217,'119886','deals-mobile','items_on_page','9',0,''),(60688,19217,'119886','deals-mobile','product_names_teg','h2',0,''),(60689,19219,'119888','deals-mobile','block_type','5',0,''),(60690,19219,'119888','deals-mobile','padding-top','10',0,''),(60691,19219,'119888','deals-mobile','padding-bottom','10',0,''),(60692,19219,'119888','deals-mobile','schema','5-2',0,''),(60693,19219,'119888','deals-mobile','border-top-color','#e0e0e0',0,''),(60694,19219,'119888','deals-mobile','border-top-width','1',0,''),(60695,19221,'119890','deals-mobile','float','right',0,''),(60696,19222,'119891','deals-mobile','listing_type','productListing',0,''),(60697,19224,'119893','deals-mobile','block_type','1',0,''),(60698,19224,'119893','deals-mobile','padding-top','10',0,''),(60699,19224,'119893','deals-mobile','padding-bottom','10',0,''),(60700,19224,'119893','deals-mobile','border-bottom-width','1',0,''),(60701,19224,'119893','deals-mobile','border-bottom-color','#e0e0e0',0,''),(60702,19224,'119893','deals-mobile','margin-left','0',0,''),(60703,19224,'119893','deals-mobile','margin-right','0',0,''),(60704,19225,'119894','deals-mobile','float','right',0,''),(60705,19225,'119894','deals-mobile','display','none',0,''),(60706,19226,'119895','deals-mobile','float','left',0,''),(60707,19226,'119895','deals-mobile','clear','none',0,''),(60708,19226,'119895','deals-mobile','margin-left','20',0,''),(60709,19226,'119895','deals-mobile','display','none',0,''),(60710,19227,'119896','deals-mobile','margin-right','20',0,''),(60711,19227,'119896','deals-mobile','float','right',0,''),(60712,19227,'119896','deals-mobile','clear','none',0,''),(60713,19227,'119896','deals-mobile','display','none',0,''),(60714,19228,'119897','deals-mobile','float','left',0,''),(60715,19228,'119897','deals-mobile','clear','none',0,''),(60716,19228,'119897','deals-mobile','sort_pos_3','1',0,''),(60717,19228,'119897','deals-mobile','sort_pos_4','2',0,''),(60718,19228,'119897','deals-mobile','sort_pos_10','3',0,''),(60719,19228,'119897','deals-mobile','sort_pos_9','4',0,''),(60720,19228,'119897','deals-mobile','sort_pos_11','5',0,''),(60721,19228,'119897','deals-mobile','sort_pos_12','6',0,''),(60722,19228,'119897','deals-mobile','sort_pos_14','7',0,''),(60723,19228,'119897','deals-mobile','sort_pos_13','8',0,''),(60724,19228,'119897','deals-mobile','sort_pos_8','9',0,''),(60725,19228,'119897','deals-mobile','sort_pos_7','10',0,''),(60726,19228,'119897','deals-mobile','sort_pos_2','11',0,''),(60727,19228,'119897','deals-mobile','sort_pos_1','12',0,''),(60728,19228,'119897','deals-mobile','sort_pos_6','13',0,''),(60729,19228,'119897','deals-mobile','sort_pos_5','14',0,''),(60730,19228,'119897','deals-mobile','sort_pos_0','15',0,''),(60731,19228,'119897','deals-mobile','sort_hide_10','1',0,''),(60732,19228,'119897','deals-mobile','sort_hide_9','1',0,''),(60733,19228,'119897','deals-mobile','hide_icons','1',0,''),(60734,19228,'119897','deals-mobile','sort_hide_16','1',0,''),(60735,19228,'119897','deals-mobile','sort_hide_15','1',0,''),(60736,19228,'119897','deals-mobile','sort_hide_3','0',0,''),(60737,19228,'119897','deals-mobile','sort_hide_4','0',0,''),(60738,19228,'119897','deals-mobile','sort_hide_11','1',0,''),(60739,19228,'119897','deals-mobile','sort_hide_12','1',0,''),(60740,19228,'119897','deals-mobile','sort_hide_14','1',0,''),(60741,19228,'119897','deals-mobile','sort_hide_13','1',0,''),(60742,19228,'119897','deals-mobile','sort_hide_8','0',0,''),(60743,19228,'119897','deals-mobile','sort_hide_7','0',0,''),(60744,19228,'119897','deals-mobile','sort_hide_2','1',0,''),(60745,19228,'119897','deals-mobile','sort_hide_1','1',0,''),(60746,19228,'119897','deals-mobile','sort_hide_6','1',0,''),(60747,19228,'119897','deals-mobile','sort_hide_5','1',0,''),(60748,19228,'119897','deals-mobile','sort_hide_0','1',0,''),(60749,19229,'119898','deals-mobile','block_type','1',0,''),(60750,19230,'119899','deals-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(60751,19231,'119900','deals-mobile','margin-bottom','30',0,''),(60752,19232,'119901','deals-mobile','block_type','1',0,''),(60753,19233,'119902','deals-mobile','block_type','1',0,''),(60754,19234,'119903','deals-mobile','margin-bottom','20',0,''),(60755,19235,'119904','deals-mobile','block_type','1',0,''),(60756,19235,'119904','deals-mobile','padding-top','10',0,''),(60757,19235,'119904','deals-mobile','padding-bottom','10',0,''),(60758,19235,'119904','deals-mobile','border-bottom-width','1',0,''),(60759,19235,'119904','deals-mobile','border-bottom-color','#e0e0e0',0,''),(60760,19235,'119904','deals-mobile','margin-left','0',0,''),(60761,19235,'119904','deals-mobile','margin-right','0',0,''),(60762,19236,'119905','deals-mobile','float','left',0,''),(60763,19236,'119905','deals-mobile','clear','none',0,''),(60764,19236,'119905','deals-mobile','sort_pos_3','2',0,''),(60765,19236,'119905','deals-mobile','sort_pos_4','1',0,''),(60766,19236,'119905','deals-mobile','sort_pos_10','5',0,''),(60767,19236,'119905','deals-mobile','sort_pos_9','6',0,''),(60768,19236,'119905','deals-mobile','sort_pos_11','7',0,''),(60769,19236,'119905','deals-mobile','sort_pos_12','8',0,''),(60770,19236,'119905','deals-mobile','sort_pos_14','9',0,''),(60771,19236,'119905','deals-mobile','sort_pos_13','10',0,''),(60772,19236,'119905','deals-mobile','sort_pos_8','11',0,''),(60773,19236,'119905','deals-mobile','sort_pos_7','12',0,''),(60774,19236,'119905','deals-mobile','sort_pos_2','13',0,''),(60775,19236,'119905','deals-mobile','sort_pos_1','14',0,''),(60776,19236,'119905','deals-mobile','sort_pos_6','15',0,''),(60777,19236,'119905','deals-mobile','sort_pos_5','16',0,''),(60778,19236,'119905','deals-mobile','sort_pos_0','17',0,''),(60779,19236,'119905','deals-mobile','sort_hide_10','1',0,''),(60780,19236,'119905','deals-mobile','sort_hide_9','1',0,''),(60781,19236,'119905','deals-mobile','sort_pos_15','4',0,''),(60782,19236,'119905','deals-mobile','sort_pos_16','3',0,''),(60783,19236,'119905','deals-mobile','sort_hide_4','0',0,''),(60784,19236,'119905','deals-mobile','sort_hide_3','0',0,''),(60785,19236,'119905','deals-mobile','sort_hide_16','1',0,''),(60786,19236,'119905','deals-mobile','sort_hide_15','1',0,''),(60787,19236,'119905','deals-mobile','sort_hide_11','1',0,''),(60788,19236,'119905','deals-mobile','sort_hide_12','1',0,''),(60789,19236,'119905','deals-mobile','sort_hide_14','1',0,''),(60790,19236,'119905','deals-mobile','sort_hide_13','1',0,''),(60791,19236,'119905','deals-mobile','sort_hide_8','0',0,''),(60792,19236,'119905','deals-mobile','sort_hide_7','0',0,''),(60793,19236,'119905','deals-mobile','sort_hide_2','1',0,''),(60794,19236,'119905','deals-mobile','sort_hide_1','1',0,''),(60795,19236,'119905','deals-mobile','sort_hide_6','1',0,''),(60796,19236,'119905','deals-mobile','sort_hide_5','1',0,''),(60797,19236,'119905','deals-mobile','sort_hide_0','1',0,''),(60798,19236,'119905','deals-mobile','hide_icons','1',0,''),(60799,19237,'119906','deals-mobile','float','left',0,''),(60800,19237,'119906','deals-mobile','clear','none',0,''),(60801,19237,'119906','deals-mobile','margin-left','20',0,''),(60802,19237,'119906','deals-mobile','display','none',0,''),(60803,19238,'119907','deals-mobile','clear','none',0,''),(60804,19238,'119907','deals-mobile','float','left',0,''),(60805,19238,'119907','deals-mobile','padding-top','3',0,''),(60806,19238,'119907','deals-mobile','margin-left','20',0,''),(60807,19239,'119908','deals-mobile','margin-right','20',0,''),(60808,19239,'119908','deals-mobile','float','right',0,''),(60809,19239,'119908','deals-mobile','clear','none',0,''),(60810,19239,'119908','deals-mobile','display','none',0,''),(60811,19240,'119909','deals-mobile','float','right',0,''),(60812,19240,'119909','deals-mobile','display','none',0,''),(60813,19241,'119910','deals-mobile','block_type','5',0,''),(60814,19241,'119910','deals-mobile','padding-top','10',0,''),(60815,19241,'119910','deals-mobile','padding-bottom','10',0,''),(60816,19241,'119910','deals-mobile','schema','5-2',0,''),(60817,19241,'119910','deals-mobile','border-top-color','#e0e0e0',0,''),(60818,19241,'119910','deals-mobile','border-top-width','1',0,''),(60819,19242,'119911','deals-mobile','padding-top','3',0,''),(60820,19243,'119912','deals-mobile','float','right',0,''),(60821,19243,'119912','deals-mobile','height','31',0,''),(60822,19246,'119915','deals-mobile','col_in_row','4',0,''),(60823,19246,'119915','deals-mobile','products_align','left',0,''),(60824,19246,'119915','deals-mobile','font-weight','400',0,''),(60825,19246,'119915','deals-mobile','listing_type','productListing',0,''),(60826,19246,'119915','deals-mobile','listing_type_rows','Rows',0,''),(60827,19246,'119915','deals-mobile','show_buy_button_b2b','on',0,''),(60828,19246,'119915','deals-mobile','show_wishlist_button_b2b','1',0,''),(60829,19246,'119915','deals-mobile','show_compare_b2b','1',0,''),(60830,19246,'119915','deals-mobile','listing_type_b2b','b2b',0,''),(60831,19246,'119915','deals-mobile','show_image','0',0,''),(60832,19246,'119915','deals-mobile','show_stock','0',0,''),(60833,19246,'119915','deals-mobile','show_description','0',0,''),(60834,19246,'119915','deals-mobile','show_model','0',0,''),(60835,19246,'119915','deals-mobile','show_properties','0',0,''),(60836,19246,'119915','deals-mobile','show_rating','0',0,''),(60837,19246,'119915','deals-mobile','show_rating_counts','0',0,''),(60838,19246,'119915','deals-mobile','show_price','0',0,''),(60839,19246,'119915','deals-mobile','show_buy_button','0',0,''),(60840,19246,'119915','deals-mobile','show_view_button','0',0,''),(60841,19246,'119915','deals-mobile','show_wishlist_button','0',0,''),(60842,19246,'119915','deals-mobile','show_compare','0',0,''),(60843,19246,'119915','deals-mobile','show_name_rows','0',0,''),(60844,19246,'119915','deals-mobile','show_image_rows','0',0,''),(60845,19246,'119915','deals-mobile','show_stock_rows','0',0,''),(60846,19246,'119915','deals-mobile','show_description_rows','0',0,''),(60847,19246,'119915','deals-mobile','show_model_rows','0',0,''),(60848,19246,'119915','deals-mobile','show_properties_rows','0',0,''),(60849,19246,'119915','deals-mobile','show_rating_rows','0',0,''),(60850,19246,'119915','deals-mobile','show_rating_counts_rows','0',0,''),(60851,19246,'119915','deals-mobile','show_price_rows','0',0,''),(60852,19246,'119915','deals-mobile','show_buy_button_rows','0',0,''),(60853,19246,'119915','deals-mobile','show_qty_input_rows','0',0,''),(60854,19246,'119915','deals-mobile','show_view_button_rows','0',0,''),(60855,19246,'119915','deals-mobile','show_wishlist_button_rows','0',0,''),(60856,19246,'119915','deals-mobile','show_compare_rows','0',0,''),(60857,19246,'119915','deals-mobile','show_name_b2b','0',0,''),(60858,19246,'119915','deals-mobile','show_image_b2b','0',0,''),(60859,19246,'119915','deals-mobile','show_stock_b2b','0',0,''),(60860,19246,'119915','deals-mobile','show_description_b2b','0',0,''),(60861,19246,'119915','deals-mobile','show_model_b2b','0',0,''),(60862,19246,'119915','deals-mobile','show_properties_b2b','0',0,''),(60863,19246,'119915','deals-mobile','show_rating_b2b','0',0,''),(60864,19246,'119915','deals-mobile','show_rating_counts_b2b','0',0,''),(60865,19246,'119915','deals-mobile','show_price_b2b','0',0,''),(60866,19246,'119915','deals-mobile','show_qty_input_b2b','0',0,''),(60867,19246,'119915','deals-mobile','show_view_button_b2b','0',0,''),(60868,19246,'119915','deals-mobile','show_attributes_b2b','0',0,''),(60869,19246,'119915','deals-mobile','items_on_page','12',0,''),(60872,19246,'119915','deals-mobile','product_names_teg','h2',0,''),(60873,19247,'119916','deals-mobile','block_type','1',0,''),(60874,19248,'119917','deals-mobile','block_type','6',0,''),(60875,19248,'119917','deals-mobile','schema','6-3',0,''),(60876,19248,'119917','deals-mobile','schema','6-3',0,'872'),(60877,19249,'119918','deals-mobile','aria_name','account-menu',0,''),(60878,19250,'119919','deals-mobile','link','Order History Info',0,''),(60879,19250,'119919','deals-mobile','text','TEXT_VIEW',0,''),(60880,19250,'119919','deals-mobile','show_pagenation','1',0,''),(60881,19250,'119919','deals-mobile','link_pay','Order pay',0,''),(60882,19250,'119919','deals-mobile','margin-bottom','20',0,''),(60883,19251,'119920','deals-mobile','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(60884,19252,'119921','deals-mobile','block_type','1',0,''),(60885,19253,'119922','deals-mobile','block_type','6',0,''),(60886,19253,'119922','deals-mobile','schema','6-3',0,'872'),(60887,19254,'119923','deals-mobile','aria_name','account-menu',0,''),(60888,19255,'119924','deals-mobile','float','left',0,''),(60889,19256,'119925','deals-mobile','block_type','3',0,''),(60890,19256,'119925','deals-mobile','clear','both',0,''),(60891,19256,'119925','deals-mobile','padding-top','20',0,''),(60892,19256,'119925','deals-mobile','schema','3-4',0,'872'),(60893,19257,'119926','deals-mobile','block_type','1',0,''),(60894,19257,'119926','deals-mobile','padding-right','20',0,''),(60895,19257,'119926','deals-mobile','margin-bottom','20',0,''),(60896,19258,'119927','deals-mobile','link','Tracking numbers',0,''),(60897,19258,'119927','deals-mobile','text','MORE_TRACKING_NUMBER',0,''),(60898,19258,'119927','deals-mobile','popup','1',0,''),(60899,19258,'119927','deals-mobile','order_id','1',0,''),(60900,19258,'119927','deals-mobile','popup_class','tracking-numbers-popup',0,''),(60901,19258,'119927','deals-mobile','font-weight','700',0,''),(60902,19258,'119927','deals-mobile','font-size','18',0,''),(60903,19259,'119928','deals-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(60904,19260,'119929','deals-mobile','short_view','1',0,''),(60905,19260,'119929','deals-mobile','hide_parents','2',0,''),(60906,19261,'119930','deals-mobile','block_type','1',0,''),(60907,19261,'119930','deals-mobile','margin-bottom','20',0,''),(60908,19261,'119930','deals-mobile','padding-right','20',0,''),(60909,19262,'119931','deals-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(60910,19263,'119932','deals-mobile','padding-left','30',0,''),(60911,19263,'119932','deals-mobile','orders_data','telephone',0,''),(60912,19263,'119932','deals-mobile','hide_parents','2',0,''),(60913,19264,'119933','deals-mobile','block_type','1',0,''),(60914,19264,'119933','deals-mobile','padding-right','20',0,''),(60915,19264,'119933','deals-mobile','padding-bottom','20',0,''),(60916,19265,'119934','deals-mobile','orders_data','name',0,''),(60917,19265,'119934','deals-mobile','padding-left','30',0,''),(60918,19266,'119935','deals-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(60919,19267,'119936','deals-mobile','block_type','1',0,''),(60920,19267,'119936','deals-mobile','padding-right','20',0,''),(60921,19267,'119936','deals-mobile','padding-bottom','20',0,''),(60922,19268,'119937','deals-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(60923,19269,'119938','deals-mobile','orders_data','delivery_address',0,''),(60924,19269,'119938','deals-mobile','padding-left','30',0,''),(60925,19270,'119939','deals-mobile','block_type','1',0,''),(60926,19270,'119939','deals-mobile','padding-right','20',0,''),(60927,19271,'119940','deals-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(60928,19272,'119941','deals-mobile','orders_data','shipping_method',0,''),(60929,19272,'119941','deals-mobile','padding-left','30',0,''),(60930,19273,'119942','deals-mobile','block_type','1',0,''),(60931,19273,'119942','deals-mobile','padding-bottom','20',0,''),(60932,19274,'119943','deals-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(60933,19275,'119944','deals-mobile','orders_data','billing_address',0,''),(60934,19275,'119944','deals-mobile','padding-left','30',0,''),(60935,19276,'119945','deals-mobile','block_type','1',0,''),(60936,19277,'119946','deals-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(60937,19278,'119947','deals-mobile','orders_data','payment_method',0,''),(60938,19278,'119947','deals-mobile','padding-left','30',0,''),(60939,19279,'119948','deals-mobile','float','right',0,''),(60940,19281,'119950','deals-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(60941,19284,'119953','deals-mobile','float','right',0,''),(60942,19284,'119953','deals-mobile','clear','none',0,''),(60943,19284,'119953','deals-mobile','margin-left','20',0,''),(60944,19285,'119954','deals-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(60945,19287,'119956','deals-mobile','float','right',0,''),(60946,19287,'119956','deals-mobile','clear','none',0,''),(60947,19287,'119956','deals-mobile','like_button','2',0,''),(60948,19287,'119956','deals-mobile','link','Order pay',0,''),(60949,19288,'119957','deals-mobile','float','right',0,''),(60950,19288,'119957','deals-mobile','clear','none',0,''),(60951,19288,'119957','deals-mobile','margin-left','20',0,''),(60952,19289,'119958','deals-mobile','block_type','2',0,''),(60953,19289,'119958','deals-mobile','padding-top','20',0,''),(60954,19289,'119958','deals-mobile','margin-bottom','20',0,''),(60955,19290,'119959','deals-mobile','like_button','1',0,''),(60956,19290,'119959','deals-mobile','text','IMAGE_BUTTON_BACK',0,''),(60957,19290,'119959','deals-mobile','link','Order History',0,''),(60958,19291,'119960','deals-mobile','text-align','right',0,''),(60959,19292,'119961','deals-mobile','block_type','1',0,''),(60960,19293,'119962','deals-mobile','block_type','6',0,''),(60961,19293,'119962','deals-mobile','schema','6-3',0,''),(60962,19293,'119962','deals-mobile','schema','6-3',0,'872'),(60963,19294,'119963','deals-mobile','aria_name','account-menu',0,''),(60964,19297,'119966','deals-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(60965,19298,'119967','deals-mobile','margin-bottom','20',0,''),(60966,19299,'119968','deals-mobile','block_type','3',0,''),(60967,19299,'119968','deals-mobile','schema','3-4',0,'872'),(60968,19300,'119969','deals-mobile','block_type','1',0,''),(60969,19301,'119970','deals-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(60970,19302,'119971','deals-mobile','padding-left','30',0,''),(60971,19303,'119972','deals-mobile','block_type','1',0,''),(60972,19303,'119972','deals-mobile','padding-right','20',0,''),(60973,19303,'119972','deals-mobile','padding-bottom','20',0,''),(60974,19304,'119973','deals-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(60975,19305,'119974','deals-mobile','orders_data','name',0,''),(60976,19305,'119974','deals-mobile','padding-left','30',0,''),(60977,19306,'119975','deals-mobile','block_type','1',0,''),(60978,19306,'119975','deals-mobile','padding-right','20',0,''),(60979,19307,'119976','deals-mobile','orders_data','shipping_method',0,''),(60980,19307,'119976','deals-mobile','padding-left','30',0,''),(60981,19308,'119977','deals-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(60982,19309,'119978','deals-mobile','block_type','1',0,''),(60983,19309,'119978','deals-mobile','padding-right','20',0,''),(60984,19309,'119978','deals-mobile','padding-bottom','20',0,''),(60985,19310,'119979','deals-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(60986,19311,'119980','deals-mobile','orders_data','delivery_address',0,''),(60987,19311,'119980','deals-mobile','padding-left','30',0,''),(60988,19312,'119981','deals-mobile','block_type','1',0,''),(60989,19313,'119982','deals-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(60990,19314,'119983','deals-mobile','orders_data','payment_method',0,''),(60991,19314,'119983','deals-mobile','padding-left','30',0,''),(60992,19315,'119984','deals-mobile','block_type','1',0,''),(60993,19315,'119984','deals-mobile','padding-bottom','20',0,''),(60994,19316,'119985','deals-mobile','orders_data','billing_address',0,''),(60995,19316,'119985','deals-mobile','padding-left','30',0,''),(60996,19317,'119986','deals-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(60997,19319,'119988','deals-mobile','width','680',0,''),(60998,19319,'119988','deals-mobile','font-weight','400',0,''),(60999,19319,'119988','deals-mobile','font-size','12',0,''),(61000,19319,'119988','deals-mobile','padding-top','20',0,''),(61001,19319,'119988','deals-mobile','padding-bottom','20',0,''),(61002,19320,'119989','deals-mobile','font-weight','normal',0,''),(61003,19320,'119989','deals-mobile','padding-top','20',0,''),(61004,19320,'119989','deals-mobile','font-size','12',0,''),(61005,19321,'119990','deals-mobile','block_type','4',0,''),(61006,19321,'119990','deals-mobile','font-weight','400',0,''),(61007,19321,'119990','deals-mobile','border-top-width','1',0,''),(61008,19321,'119990','deals-mobile','border-top-color','#e0e0e0',0,''),(61009,19321,'119990','deals-mobile','border-left-width','1',0,''),(61010,19321,'119990','deals-mobile','border-left-color','#e0e0e0',0,''),(61011,19321,'119990','deals-mobile','border-right-width','1',0,''),(61012,19321,'119990','deals-mobile','border-right-color','#e0e0e0',0,''),(61013,19321,'119990','deals-mobile','border-bottom-width','1',0,''),(61014,19321,'119990','deals-mobile','border-bottom-color','#e0e0e0',0,''),(61015,19322,'119991','deals-mobile','block_type','2',0,''),(61016,19322,'119991','deals-mobile','font-weight','normal',0,''),(61017,19322,'119991','deals-mobile','border-right-width','1',0,''),(61018,19322,'119991','deals-mobile','border-right-color','#e0e0e0',0,''),(61019,19323,'119992','deals-mobile','block_type','1',0,''),(61020,19323,'119992','deals-mobile','font-weight','normal',0,''),(61021,19323,'119992','deals-mobile','border-right-width','1',0,''),(61022,19323,'119992','deals-mobile','border-right-color','#e0e0e0',0,''),(61023,19323,'119992','deals-mobile','background-color','#e0e0e0',0,''),(61024,19323,'119992','deals-mobile','padding-top','10',0,''),(61025,19323,'119992','deals-mobile','padding-left','10',0,''),(61026,19323,'119992','deals-mobile','padding-right','10',0,''),(61027,19323,'119992','deals-mobile','padding-bottom','10',0,''),(61028,19324,'119993','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(61029,19324,'119993','deals-mobile','font-size','16',0,''),(61030,19324,'119993','deals-mobile','font-weight','bold',0,''),(61031,19324,'119993','deals-mobile','padding-bottom','10',0,''),(61032,19325,'119994','deals-mobile','font-size','16',0,''),(61033,19325,'119994','deals-mobile','font-weight','normal',0,''),(61034,19326,'119995','deals-mobile','block_type','1',0,''),(61035,19326,'119995','deals-mobile','font-weight','normal',0,''),(61036,19326,'119995','deals-mobile','padding-top','10',0,''),(61037,19326,'119995','deals-mobile','padding-left','10',0,''),(61038,19326,'119995','deals-mobile','padding-right','10',0,''),(61039,19326,'119995','deals-mobile','padding-bottom','10',0,''),(61040,19330,'119999','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(61041,19330,'119999','deals-mobile','font-size','14',0,''),(61042,19330,'119999','deals-mobile','font-weight','bold',0,''),(61043,19330,'119999','deals-mobile','padding-top','10',0,''),(61044,19331,'120000','deals-mobile','text','<p>CUSTOMER:</p>',1,''),(61045,19331,'120000','deals-mobile','font-size','14',0,''),(61046,19331,'120000','deals-mobile','font-weight','bold',0,''),(61047,19332,'120001','deals-mobile','text','<p>PHONE NUMBER:</p>',1,''),(61048,19332,'120001','deals-mobile','font-size','14',0,''),(61049,19332,'120001','deals-mobile','font-weight','bold',0,''),(61050,19332,'120001','deals-mobile','padding-top','10',0,''),(61051,19333,'120002','deals-mobile','block_type','2',0,''),(61052,19333,'120002','deals-mobile','font-weight','normal',0,''),(61053,19333,'120002','deals-mobile','border-right-width','1',0,''),(61054,19333,'120002','deals-mobile','border-right-color','#e0e0e0',0,''),(61055,19333,'120002','deals-mobile','border-top-width','1',0,''),(61056,19333,'120002','deals-mobile','border-top-color','#e0e0e0',0,''),(61057,19334,'120003','deals-mobile','block_type','1',0,''),(61058,19334,'120003','deals-mobile','font-weight','normal',0,''),(61059,19334,'120003','deals-mobile','padding-top','10',0,''),(61060,19334,'120003','deals-mobile','padding-left','10',0,''),(61061,19334,'120003','deals-mobile','padding-right','10',0,''),(61062,19334,'120003','deals-mobile','padding-bottom','10',0,''),(61063,19334,'120003','deals-mobile','border-right-width','1',0,''),(61064,19334,'120003','deals-mobile','border-right-color','#e0e0e0',0,''),(61065,19336,'120005','deals-mobile','text','<p>Shipping via</p>',1,''),(61066,19336,'120005','deals-mobile','font-weight','bold',0,''),(61067,19337,'120006','deals-mobile','block_type','1',0,''),(61068,19337,'120006','deals-mobile','font-weight','normal',0,''),(61069,19337,'120006','deals-mobile','padding-top','10',0,''),(61070,19337,'120006','deals-mobile','padding-left','10',0,''),(61071,19337,'120006','deals-mobile','padding-right','10',0,''),(61072,19337,'120006','deals-mobile','padding-bottom','10',0,''),(61073,19338,'120007','deals-mobile','text','<p>Shipping service</p>',1,''),(61074,19338,'120007','deals-mobile','font-weight','bold',0,''),(61075,19340,'120009','deals-mobile','font-weight','normal',0,''),(61076,19340,'120009','deals-mobile','text-align','center',0,''),(61077,19340,'120009','deals-mobile','padding-top','40',0,''),(61078,19341,'120010','deals-mobile','block_type','1',0,''),(61079,19341,'120010','deals-mobile','font-weight','normal',0,''),(61080,19341,'120010','deals-mobile','padding-top','10',0,''),(61081,19341,'120010','deals-mobile','padding-bottom','10',0,''),(61082,19342,'120011','deals-mobile','text','<p>If undelivered please return to:</p>',1,''),(61083,19342,'120011','deals-mobile','font-weight','bold',0,''),(61084,19344,'120013','deals-mobile','block_type','2',0,''),(61085,19344,'120013','deals-mobile','font-weight','normal',0,''),(61086,19344,'120013','deals-mobile','padding-bottom','20',0,''),(61087,19345,'120014','deals-mobile','font-weight','400',0,''),(61088,19345,'120014','deals-mobile','text-align','center',0,''),(61089,19345,'120014','deals-mobile','padding-top','10',0,''),(61091,19346,'120015','deals-mobile','block_type','1',0,''),(61092,19347,'120016','deals-mobile','font-weight','400',0,''),(61093,19347,'120016','deals-mobile','text-align','right',0,''),(61094,19347,'120016','deals-mobile','padding-bottom','10',0,''),(61095,19347,'120016','deals-mobile','address_spacer',',',0,''),(61096,19348,'120017','deals-mobile','block_type','11',0,''),(61097,19348,'120017','deals-mobile','font-weight','normal',0,''),(61098,19349,'120018','deals-mobile','text','<p>Phone:</p>',1,''),(61099,19349,'120018','deals-mobile','font-weight','normal',0,''),(61100,19349,'120018','deals-mobile','text-align','right',0,''),(61101,19350,'120019','deals-mobile','font-weight','normal',0,''),(61102,19350,'120019','deals-mobile','text-align','right',0,''),(61103,19351,'120020','deals-mobile','block_type','11',0,''),(61104,19351,'120020','deals-mobile','font-weight','400',0,''),(61105,19352,'120021','deals-mobile','text','<p>Web:</p>',1,''),(61106,19352,'120021','deals-mobile','font-weight','400',0,''),(61107,19352,'120021','deals-mobile','text-align','right',0,''),(61108,19353,'120022','deals-mobile','font-weight','normal',0,''),(61109,19353,'120022','deals-mobile','text-align','right',0,''),(61110,19354,'120023','deals-mobile','block_type','11',0,''),(61111,19354,'120023','deals-mobile','font-weight','normal',0,''),(61112,19355,'120024','deals-mobile','text','<p>Email:</p>',1,''),(61113,19355,'120024','deals-mobile','font-weight','normal',0,''),(61114,19355,'120024','deals-mobile','text-align','right',0,''),(61115,19356,'120025','deals-mobile','font-weight','normal',0,''),(61116,19356,'120025','deals-mobile','text-align','right',0,''),(61117,19357,'120026','deals-mobile','block_type','1',0,''),(61118,19358,'120027','deals-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(61119,19359,'120028','deals-mobile','block_type','8',0,''),(61120,19360,'120029','deals-mobile','margin-bottom','20',0,''),(61121,19361,'120030','deals-mobile','text','##TEXT_MAIN##',0,''),(61122,19361,'120030','deals-mobile','margin-bottom','20',0,''),(61123,19361,'120030','deals-mobile','text-align','center',0,''),(61124,19363,'120032','deals-mobile','block_type','2',0,''),(61125,19364,'120033','deals-mobile','block_type','1',0,''),(61126,19364,'120033','deals-mobile','style_class','product',0,''),(61127,19364,'120033','deals-mobile','padding-right','10',0,''),(61128,19364,'120033','deals-mobile','padding-bottom','20',0,''),(61129,19365,'120034','deals-mobile','block_type','2',0,''),(61130,19366,'120035','deals-mobile','product_element','image',0,''),(61131,19366,'120035','deals-mobile','padding-right','10',0,''),(61132,19367,'120036','deals-mobile','product_element','products_price_old',0,''),(61133,19367,'120036','deals-mobile','font-family','Varela Round',0,''),(61134,19367,'120036','deals-mobile','font-size','14',0,''),(61135,19367,'120036','deals-mobile','text-decoration','line-through',0,''),(61136,19368,'120037','deals-mobile','product_element','products_price',0,''),(61137,19368,'120037','deals-mobile','font-family','Varela Round',0,''),(61138,19368,'120037','deals-mobile','font-size','20',0,''),(61139,19368,'120037','deals-mobile','padding-top','20',0,''),(61140,19369,'120038','deals-mobile','block_type','1',0,''),(61141,19370,'120039','deals-mobile','product_element','products_name',0,''),(61142,19370,'120039','deals-mobile','font-family','Varela Round',0,''),(61143,19370,'120039','deals-mobile','padding-bottom','10',0,''),(61144,19370,'120039','deals-mobile','font-size','16',0,''),(61145,19371,'120040','deals-mobile','block_type','1',0,''),(61146,19371,'120040','deals-mobile','style_class','product',0,''),(61147,19371,'120040','deals-mobile','padding-left','10',0,''),(61148,19371,'120040','deals-mobile','padding-bottom','20',0,''),(61149,19372,'120041','deals-mobile','block_type','1',0,''),(61150,19373,'120042','deals-mobile','product_element','products_name',0,''),(61151,19373,'120042','deals-mobile','font-family','Varela Round',0,''),(61152,19373,'120042','deals-mobile','font-size','16',0,''),(61153,19373,'120042','deals-mobile','padding-bottom','10',0,''),(61154,19374,'120043','deals-mobile','block_type','2',0,''),(61155,19375,'120044','deals-mobile','product_element','image',0,''),(61156,19375,'120044','deals-mobile','padding-right','10',0,''),(61157,19376,'120045','deals-mobile','font-size','14',0,''),(61158,19376,'120045','deals-mobile','font-family','Varela Round',0,''),(61159,19376,'120045','deals-mobile','text-decoration','line-through',0,''),(61160,19376,'120045','deals-mobile','product_element','products_price_old',0,''),(61161,19377,'120046','deals-mobile','product_element','products_price',0,''),(61162,19377,'120046','deals-mobile','font-family','Varela Round',0,''),(61163,19377,'120046','deals-mobile','font-size','20',0,''),(61164,19377,'120046','deals-mobile','padding-top','20',0,''),(61165,19378,'120047','deals-mobile','font-size','30',0,''),(61166,19378,'120047','deals-mobile','font-family','Varela Round',0,''),(61167,19378,'120047','deals-mobile','text-align','center',0,''),(61168,19378,'120047','deals-mobile','padding-bottom','50',0,''),(61169,19379,'120048','deals-mobile','padding-bottom','20',0,''),(61170,19379,'120048','deals-mobile','text-align','center',0,''),(61171,19380,'120049','deals-mobile','width','680',0,''),(61172,19381,'120050','deals-mobile','padding-top','200',0,''),(61173,19381,'120050','deals-mobile','padding-left','200',0,''),(61175,19382,'120051','deals-mobile','text','osCommerce 4',1,''),(61176,19382,'120051','deals-mobile','font-family','Varela Round',0,''),(61177,19382,'120051','deals-mobile','font-size','40',0,''),(61178,19382,'120051','deals-mobile','padding-top','50',0,''),(61179,19382,'120051','deals-mobile','text-align','center',0,''),(61180,19383,'120052','deals-mobile','block_type','2',0,''),(61181,19383,'120052','deals-mobile','border-top-width','1',0,''),(61182,19383,'120052','deals-mobile','border-top-color','#eeeeee',0,''),(61183,19384,'120053','deals-mobile','text-align','right',0,''),(61184,19384,'120053','deals-mobile','padding-top','15',0,''),(61185,19384,'120053','deals-mobile','padding-bottom','15',0,''),(61186,19384,'120053','deals-mobile','font-size','14',0,''),(61187,19385,'120054','deals-mobile','font-family','Varela Round',0,''),(61188,19385,'120054','deals-mobile','text-align','center',0,''),(61189,19385,'120054','deals-mobile','font-size','20',0,''),(61190,19385,'120054','deals-mobile','color','#183d78',0,''),(61191,19385,'120054','deals-mobile','border-bottom-width','1',0,''),(61192,19385,'120054','deals-mobile','border-bottom-color','#dedede',0,''),(61193,19385,'120054','deals-mobile','padding-top','10',0,''),(61194,19385,'120054','deals-mobile','padding-bottom','10',0,''),(61195,19386,'120055','deals-mobile','block_type','1',0,''),(61196,19387,'120056','deals-mobile','block_type','6',0,''),(61197,19387,'120056','deals-mobile','schema','6-3',0,''),(61198,19387,'120056','deals-mobile','schema','6-3',0,'872'),(61199,19388,'120057','deals-mobile','aria_name','account-menu',0,''),(61200,19389,'120058','deals-mobile','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(61201,19390,'120059','deals-mobile','max_items','10',0,''),(61202,19391,'120060','deals-mobile','block_type','1',0,''),(61203,19391,'120060','deals-mobile','padding-top','20',0,''),(61204,19391,'120060','deals-mobile','padding-left','20',0,''),(61205,19391,'120060','deals-mobile','padding-right','20',0,''),(61206,19391,'120060','deals-mobile','padding-bottom','20',0,''),(61207,19392,'120061','deals-mobile','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(61208,19394,'120063','deals-mobile','block_type','1',0,''),(61209,19395,'120064','deals-mobile','margin_left_measure','auto',0,''),(61210,19395,'120064','deals-mobile','margin_right_measure','auto',0,''),(61211,19395,'120064','deals-mobile','max-width','560',0,''),(61212,19396,'120065','deals-mobile','margin-bottom','30',0,''),(61213,19397,'120066','deals-mobile','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(61214,19398,'120067','deals-mobile','block_type','1',0,''),(61215,19399,'120068','deals-mobile','block_type','2',0,''),(61216,19399,'120068','deals-mobile','border-top-width','1',0,''),(61217,19399,'120068','deals-mobile','border-top-color','#e0e0e0',0,''),(61218,19399,'120068','deals-mobile','padding-top','15',0,''),(61219,19399,'120068','deals-mobile','padding-bottom','15',0,''),(61220,19401,'120070','deals-mobile','font-size','30',0,''),(61221,19401,'120070','deals-mobile','font-weight','400',0,''),(61222,19401,'120070','deals-mobile','line-height','35',0,''),(61223,19401,'120070','deals-mobile','font-family','Varela Round',0,''),(61224,19401,'120070','deals-mobile','line_height_measure','px',0,''),(61225,19402,'120071','deals-mobile','font-weight','400',0,''),(61226,19403,'120072','deals-mobile','font-weight','normal',0,''),(61227,19403,'120072','deals-mobile','padding-bottom','20',0,''),(61228,19404,'120073','deals-mobile','padding-right','0',0,''),(61229,19404,'120073','deals-mobile','align_position','horizontal',0,''),(61230,19406,'120075','deals-mobile','text-align','right',0,''),(61231,19406,'120075','deals-mobile','width','100',0,'863'),(61232,19406,'120075','deals-mobile','width_measure','%',0,'863'),(61233,19406,'120075','deals-mobile','float','none',0,'863'),(61234,19406,'120075','deals-mobile','margin-bottom','20',0,''),(61235,19407,'120076','deals-mobile','font-weight','400',0,''),(61236,19407,'120076','deals-mobile','box_align','4',0,''),(61237,19407,'120076','deals-mobile','align_position','horizontal',0,''),(61238,19407,'120076','deals-mobile','margin-bottom','30',0,''),(61239,19408,'120077','deals-mobile','font-weight','400',0,''),(61240,19409,'120078','deals-mobile','block_type','1',0,''),(61241,19409,'120078','deals-mobile','style_class','personal-buttons',0,''),(61242,19409,'120078','deals-mobile','margin-bottom','20',0,''),(61243,19409,'120078','deals-mobile','border-bottom-width','1',0,''),(61244,19409,'120078','deals-mobile','border-bottom-color','#e0e0e0',0,''),(61245,19409,'120078','deals-mobile','padding-left','30',0,''),(61246,19414,'120083','deals-mobile','font-weight','normal',0,''),(61247,19414,'120083','deals-mobile','padding-bottom','20',0,''),(61248,19414,'120083','deals-mobile','show_qty_input','1',0,''),(61249,19414,'120083','deals-mobile','show_compare','1',0,''),(61250,19414,'120083','deals-mobile','col_in_row','1',0,''),(61251,19414,'120083','deals-mobile','view_as','carousel',0,''),(61252,19414,'120083','deals-mobile','listing_type','productListing',0,''),(61253,19415,'120084','deals-mobile','font-weight','400',0,''),(61254,19415,'120084','deals-mobile','padding-bottom','20',0,''),(61255,19415,'120084','deals-mobile','show_qty_input','1',0,''),(61256,19415,'120084','deals-mobile','show_compare','1',0,''),(61257,19415,'120084','deals-mobile','listing_type','type-1',0,''),(61258,19415,'120084','deals-mobile','view_as','carousel',0,''),(61259,19415,'120084','deals-mobile','show_name','0',0,''),(61260,19415,'120084','deals-mobile','show_image','0',0,''),(61261,19415,'120084','deals-mobile','show_stock','0',0,''),(61262,19415,'120084','deals-mobile','show_description','0',0,''),(61263,19415,'120084','deals-mobile','show_model','0',0,''),(61264,19415,'120084','deals-mobile','show_properties','0',0,''),(61265,19415,'120084','deals-mobile','show_rating','0',0,''),(61266,19415,'120084','deals-mobile','show_rating_counts','0',0,''),(61267,19415,'120084','deals-mobile','show_price','0',0,''),(61268,19415,'120084','deals-mobile','show_buy_button','0',0,''),(61269,19415,'120084','deals-mobile','show_view_button','0',0,''),(61270,19415,'120084','deals-mobile','show_wishlist_button','0',0,''),(61271,19415,'120084','deals-mobile','display','none',0,'864'),(61272,19415,'120084','deals-mobile','product_names_teg','h2',0,''),(61273,19416,'120085','deals-mobile','font-weight','normal',0,''),(61274,19416,'120085','deals-mobile','padding-bottom','20',0,''),(61275,19417,'120086','deals-mobile','tab_1','Description',1,''),(61276,19417,'120086','deals-mobile','tab_2','Reviews',1,''),(61277,19417,'120086','deals-mobile','font-weight','400',0,''),(61278,19417,'120086','deals-mobile','margin-top','20',0,''),(61279,19420,'120089','deals-mobile','padding-bottom','10',0,''),(61280,19420,'120089','deals-mobile','padding-top','5',0,''),(61281,19421,'120090','deals-mobile','font-weight','normal',0,''),(61282,19421,'120090','deals-mobile','padding-top','20',0,''),(61283,19421,'120090','deals-mobile','padding-bottom','20',0,''),(61284,19421,'120090','deals-mobile','border-top-width','1',0,''),(61285,19421,'120090','deals-mobile','border-top-color','#cccccc',0,''),(61286,19423,'120092','deals-mobile','font-weight','400',0,''),(61287,19423,'120092','deals-mobile','padding-bottom','20',0,''),(61288,19423,'120092','deals-mobile','show_qty_input','1',0,''),(61289,19423,'120092','deals-mobile','show_compare','1',0,''),(61290,19423,'120092','deals-mobile','show_name','0',0,''),(61291,19423,'120092','deals-mobile','show_image','0',0,''),(61292,19423,'120092','deals-mobile','show_stock','0',0,''),(61293,19423,'120092','deals-mobile','show_description','0',0,''),(61294,19423,'120092','deals-mobile','show_model','0',0,''),(61295,19423,'120092','deals-mobile','show_properties','0',0,''),(61296,19423,'120092','deals-mobile','show_rating','0',0,''),(61297,19423,'120092','deals-mobile','show_rating_counts','0',0,''),(61298,19423,'120092','deals-mobile','show_price','0',0,''),(61299,19423,'120092','deals-mobile','show_buy_button','0',0,''),(61300,19423,'120092','deals-mobile','show_view_button','0',0,''),(61301,19423,'120092','deals-mobile','show_wishlist_button','0',0,''),(61302,19423,'120092','deals-mobile','listing_type','productListing',0,''),(61303,19423,'120092','deals-mobile','col_in_row','1',0,''),(61304,19423,'120092','deals-mobile','view_as','carousel',0,''),(61305,19434,'120103','deals-mobile','block_type','1',0,''),(61306,19434,'120103','deals-mobile','style_class','item-holder',0,''),(61307,19434,'120103','deals-mobile','padding-top','25',0,''),(61308,19434,'120103','deals-mobile','padding-left','25',0,''),(61309,19434,'120103','deals-mobile','padding-right','25',0,''),(61310,19434,'120103','deals-mobile','padding-bottom','25',0,''),(61311,19434,'120103','deals-mobile','text-align','left',0,''),(61312,19437,'120106','deals-mobile','description_characters','90',0,''),(61313,19438,'120107','deals-mobile','text-align','right',0,''),(61314,19438,'120107','deals-mobile','margin-bottom','10',0,''),(61315,19439,'120108','deals-mobile','text-align','right',0,''),(61316,19439,'120108','deals-mobile','clear','none',0,''),(61317,19439,'120108','deals-mobile','float','left',0,''),(61318,19441,'120110','deals-mobile','block_type','2',0,''),(61319,19442,'120111','deals-mobile','margin-bottom','7',0,''),(61320,19443,'120112','deals-mobile','margin-bottom','10',0,''),(61321,19443,'120112','deals-mobile','text-align','right',0,''),(61322,19443,'120112','deals-mobile','float','right',0,''),(61323,19444,'120113','deals-mobile','clear','both',0,''),(61324,19445,'120114','deals-mobile','float','left',0,''),(61325,19445,'120114','deals-mobile','margin-right','20',0,''),(61326,19445,'120114','deals-mobile','margin-bottom','5',0,''),(61327,19446,'120115','deals-mobile','block_type','1',0,''),(61328,19447,'120116','deals-mobile','font-weight','400',0,''),(61329,19447,'120116','deals-mobile','padding-right','40',0,''),(61330,19447,'120116','deals-mobile','padding-right','0',0,'888'),(61331,19447,'120116','deals-mobile','padding-right','0',0,'890'),(61332,19447,'120116','deals-mobile','margin-bottom','20',0,''),(61333,19448,'120117','deals-mobile','text-align','center',0,''),(61334,19448,'120117','deals-mobile','margin-bottom','20',0,''),(61335,19450,'120119','deals-mobile','margin-bottom','20',0,''),(61336,19450,'120119','deals-mobile','text-align','center',0,''),(61337,19451,'120120','deals-mobile','block_type','2',0,''),(61338,19451,'120120','deals-mobile','margin-bottom','20',0,''),(61339,19452,'120121','deals-mobile','sort_pos_3','1',0,''),(61340,19452,'120121','deals-mobile','sort_pos_4','2',0,''),(61341,19452,'120121','deals-mobile','sort_pos_10','5',0,''),(61342,19452,'120121','deals-mobile','sort_pos_9','6',0,''),(61343,19452,'120121','deals-mobile','sort_pos_11','7',0,''),(61344,19452,'120121','deals-mobile','sort_pos_12','8',0,''),(61345,19452,'120121','deals-mobile','sort_pos_14','9',0,''),(61346,19452,'120121','deals-mobile','sort_pos_13','10',0,''),(61347,19452,'120121','deals-mobile','sort_pos_8','11',0,''),(61348,19452,'120121','deals-mobile','sort_pos_7','12',0,''),(61349,19452,'120121','deals-mobile','sort_pos_2','13',0,''),(61350,19452,'120121','deals-mobile','sort_pos_1','14',0,''),(61351,19452,'120121','deals-mobile','sort_pos_6','15',0,''),(61352,19452,'120121','deals-mobile','sort_pos_5','16',0,''),(61353,19452,'120121','deals-mobile','sort_pos_0','17',0,''),(61354,19452,'120121','deals-mobile','sort_hide_10','1',0,''),(61355,19452,'120121','deals-mobile','sort_hide_9','1',0,''),(61356,19452,'120121','deals-mobile','sort_pos_15','4',0,''),(61357,19452,'120121','deals-mobile','sort_pos_16','3',0,''),(61358,19452,'120121','deals-mobile','sort_hide_3','0',0,''),(61359,19452,'120121','deals-mobile','sort_hide_4','0',0,''),(61360,19452,'120121','deals-mobile','sort_hide_16','1',0,''),(61361,19452,'120121','deals-mobile','sort_hide_15','1',0,''),(61362,19452,'120121','deals-mobile','sort_hide_11','0',0,''),(61363,19452,'120121','deals-mobile','sort_hide_12','0',0,''),(61364,19452,'120121','deals-mobile','sort_hide_14','0',0,''),(61365,19452,'120121','deals-mobile','sort_hide_13','0',0,''),(61366,19452,'120121','deals-mobile','sort_hide_8','0',0,''),(61367,19452,'120121','deals-mobile','sort_hide_7','0',0,''),(61368,19452,'120121','deals-mobile','sort_hide_2','0',0,''),(61369,19452,'120121','deals-mobile','sort_hide_1','0',0,''),(61370,19452,'120121','deals-mobile','sort_hide_6','0',0,''),(61371,19452,'120121','deals-mobile','sort_hide_5','0',0,''),(61372,19452,'120121','deals-mobile','sort_hide_0','0',0,''),(61373,19453,'120122','deals-mobile','text-align','right',0,''),(61374,19453,'120122','deals-mobile','padding-top','10',0,''),(61375,19454,'120123','deals-mobile','col_in_row','2',0,''),(61376,19454,'120123','deals-mobile','products_align','left',0,''),(61377,19454,'120123','deals-mobile','font-weight','400',0,''),(61378,19454,'120123','deals-mobile','show_qty_input','1',0,''),(61379,19454,'120123','deals-mobile','listing_type','productListing',0,''),(61380,19454,'120123','deals-mobile','listing_type_rows','type-1_2',0,''),(61381,19454,'120123','deals-mobile','show_buy_button_b2b','on',0,''),(61382,19454,'120123','deals-mobile','show_wishlist_button_b2b','1',0,''),(61383,19454,'120123','deals-mobile','show_compare_b2b','1',0,''),(61384,19454,'120123','deals-mobile','listing_type_b2b','type-1_3',0,''),(61385,19454,'120123','deals-mobile','show_name','0',0,''),(61386,19454,'120123','deals-mobile','show_image','0',0,''),(61387,19454,'120123','deals-mobile','show_stock','0',0,''),(61388,19454,'120123','deals-mobile','show_description','1',0,''),(61389,19454,'120123','deals-mobile','show_model','1',0,''),(61390,19454,'120123','deals-mobile','show_properties','1',0,''),(61391,19454,'120123','deals-mobile','show_rating_counts','1',0,''),(61392,19454,'120123','deals-mobile','show_price','0',0,''),(61393,19454,'120123','deals-mobile','show_buy_button','1',0,''),(61394,19454,'120123','deals-mobile','show_view_button','1',0,''),(61395,19454,'120123','deals-mobile','show_wishlist_button','1',0,''),(61396,19454,'120123','deals-mobile','show_compare','1',0,''),(61397,19454,'120123','deals-mobile','show_name_rows','0',0,''),(61398,19454,'120123','deals-mobile','show_image_rows','0',0,''),(61399,19454,'120123','deals-mobile','show_stock_rows','0',0,''),(61400,19454,'120123','deals-mobile','show_description_rows','0',0,''),(61401,19454,'120123','deals-mobile','show_model_rows','0',0,''),(61402,19454,'120123','deals-mobile','show_properties_rows','0',0,''),(61403,19454,'120123','deals-mobile','show_rating_rows','0',0,''),(61404,19454,'120123','deals-mobile','show_rating_counts_rows','0',0,''),(61405,19454,'120123','deals-mobile','show_price_rows','0',0,''),(61406,19454,'120123','deals-mobile','show_buy_button_rows','0',0,''),(61407,19454,'120123','deals-mobile','show_qty_input_rows','0',0,''),(61408,19454,'120123','deals-mobile','show_view_button_rows','0',0,''),(61409,19454,'120123','deals-mobile','show_wishlist_button_rows','0',0,''),(61410,19454,'120123','deals-mobile','show_compare_rows','0',0,''),(61411,19454,'120123','deals-mobile','show_name_b2b','0',0,''),(61412,19454,'120123','deals-mobile','show_image_b2b','0',0,''),(61413,19454,'120123','deals-mobile','show_stock_b2b','0',0,''),(61414,19454,'120123','deals-mobile','show_description_b2b','0',0,''),(61415,19454,'120123','deals-mobile','show_model_b2b','0',0,''),(61416,19454,'120123','deals-mobile','show_properties_b2b','0',0,''),(61417,19454,'120123','deals-mobile','show_rating_b2b','0',0,''),(61418,19454,'120123','deals-mobile','show_rating_counts_b2b','0',0,''),(61419,19454,'120123','deals-mobile','show_price_b2b','0',0,''),(61420,19454,'120123','deals-mobile','show_qty_input_b2b','0',0,''),(61421,19454,'120123','deals-mobile','show_view_button_b2b','0',0,''),(61422,19454,'120123','deals-mobile','show_attributes_b2b','0',0,''),(61423,19454,'120123','deals-mobile','items_on_page','10',0,''),(61424,19454,'120123','deals-mobile','product_names_teg','h2',0,''),(61425,19456,'120125','deals-mobile','block_type','1',0,''),(61426,19458,'120127','deals-mobile','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(61427,19459,'120128','deals-mobile','width','680',0,''),(61428,19459,'120128','deals-mobile','font-weight','normal',0,''),(61429,19459,'120128','deals-mobile','font-size','12',0,''),(61430,19459,'120128','deals-mobile','padding-top','20',0,''),(61431,19459,'120128','deals-mobile','padding-bottom','20',0,''),(61432,19459,'120128','deals-mobile','color','#424242',0,''),(61433,19460,'120129','deals-mobile','block_type','5',0,''),(61434,19460,'120129','deals-mobile','font-weight','normal',0,''),(61435,19460,'120129','deals-mobile','border-bottom-width','1',0,''),(61436,19460,'120129','deals-mobile','border-bottom-color','#e0e0e0',0,''),(61437,19460,'120129','deals-mobile','border-top-width','1',0,''),(61438,19460,'120129','deals-mobile','border-top-color','#e0e0e0',0,''),(61439,19460,'120129','deals-mobile','border-left-color','#e0e0e0',0,''),(61440,19460,'120129','deals-mobile','border-left-width','1',0,''),(61441,19461,'120130','deals-mobile','block_type','1',0,''),(61442,19461,'120130','deals-mobile','font-weight','normal',0,''),(61443,19461,'120130','deals-mobile','padding-top','10',0,''),(61444,19461,'120130','deals-mobile','padding-left','10',0,''),(61445,19461,'120130','deals-mobile','padding-right','10',0,''),(61446,19462,'120131','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(61447,19462,'120131','deals-mobile','font-size','14',0,''),(61448,19462,'120131','deals-mobile','font-weight','bold',0,''),(61449,19462,'120131','deals-mobile','padding-bottom','10',0,''),(61450,19463,'120132','deals-mobile','font-weight','400',0,''),(61451,19463,'120132','deals-mobile','line-height','120',0,''),(61452,19463,'120132','deals-mobile','line_height_measure','%',0,''),(61453,19463,'120132','deals-mobile','font-size','12',0,''),(61454,19464,'120133','deals-mobile','block_type','4',0,''),(61455,19464,'120133','deals-mobile','font-weight','normal',0,''),(61456,19464,'120133','deals-mobile','border-top-width','1',0,''),(61457,19464,'120133','deals-mobile','border-top-color','#e0e0e0',0,''),(61458,19464,'120133','deals-mobile','border-left-width','1',0,''),(61459,19464,'120133','deals-mobile','border-left-color','#e0e0e0',0,''),(61460,19464,'120133','deals-mobile','border-right-width','1',0,''),(61461,19464,'120133','deals-mobile','border-right-color','#e0e0e0',0,''),(61462,19464,'120133','deals-mobile','border-bottom-width','1',0,''),(61463,19464,'120133','deals-mobile','border-bottom-color','#e0e0e0',0,''),(61464,19465,'120134','deals-mobile','block_type','2',0,''),(61465,19465,'120134','deals-mobile','font-weight','normal',0,''),(61466,19465,'120134','deals-mobile','border-right-width','1',0,''),(61467,19465,'120134','deals-mobile','border-right-color','#e0e0e0',0,''),(61468,19466,'120135','deals-mobile','block_type','1',0,''),(61469,19466,'120135','deals-mobile','font-weight','400',0,''),(61470,19466,'120135','deals-mobile','background-color','#eeeeee',0,''),(61471,19466,'120135','deals-mobile','padding-top','10',0,''),(61472,19466,'120135','deals-mobile','padding-left','10',0,''),(61473,19466,'120135','deals-mobile','padding-right','10',0,''),(61474,19466,'120135','deals-mobile','padding-bottom','30',0,''),(61475,19467,'120136','deals-mobile','text','<p>ADDRESS:</p>\n',1,''),(61476,19467,'120136','deals-mobile','font-size','14',0,''),(61477,19467,'120136','deals-mobile','font-weight','bold',0,''),(61478,19468,'120137','deals-mobile','font-size','12',0,''),(61479,19469,'120138','deals-mobile','block_type','1',0,''),(61480,19469,'120138','deals-mobile','font-weight','normal',0,''),(61481,19469,'120138','deals-mobile','padding-top','10',0,''),(61482,19469,'120138','deals-mobile','padding-left','10',0,''),(61483,19469,'120138','deals-mobile','padding-right','10',0,''),(61484,19469,'120138','deals-mobile','padding-bottom','10',0,''),(61485,19470,'120139','deals-mobile','text','<p>CUSTOMER:</p>',1,''),(61486,19470,'120139','deals-mobile','font-size','13',0,''),(61487,19470,'120139','deals-mobile','font-weight','bold',0,''),(61488,19471,'120140','deals-mobile','text','<p>PHONE NUMBER:</p>',1,''),(61489,19471,'120140','deals-mobile','font-size','14',0,''),(61490,19471,'120140','deals-mobile','font-weight','bold',0,''),(61491,19471,'120140','deals-mobile','padding-top','10',0,''),(61492,19472,'120141','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(61493,19472,'120141','deals-mobile','font-weight','bold',0,''),(61494,19472,'120141','deals-mobile','font-size','14',0,''),(61495,19472,'120141','deals-mobile','padding-top','10',0,''),(61496,19473,'120142','deals-mobile','font-weight','normal',0,''),(61497,19474,'120143','deals-mobile','font-weight','normal',0,''),(61498,19476,'120145','deals-mobile','text','<p>Order date:</p>\n',1,''),(61499,19476,'120145','deals-mobile','font-weight','bold',0,''),(61500,19476,'120145','deals-mobile','text-align','center',0,''),(61501,19476,'120145','deals-mobile','font-size','12',0,''),(61502,19477,'120146','deals-mobile','font-weight','normal',0,''),(61503,19477,'120146','deals-mobile','text-align','center',0,''),(61504,19477,'120146','deals-mobile','padding-bottom','10',0,''),(61505,19478,'120147','deals-mobile','font-size','14',0,''),(61506,19478,'120147','deals-mobile','font-weight','bold',0,''),(61507,19478,'120147','deals-mobile','text-align','center',0,''),(61508,19478,'120147','deals-mobile','padding-bottom','10',0,''),(61509,19478,'120147','deals-mobile','padding-top','10',0,''),(61510,19479,'120148','deals-mobile','block_type','2',0,''),(61511,19479,'120148','deals-mobile','font-weight','normal',0,''),(61512,19479,'120148','deals-mobile','padding-bottom','20',0,''),(61513,19480,'120149','deals-mobile','font-weight','400',0,''),(61514,19480,'120149','deals-mobile','padding-top','20',0,''),(61516,19481,'120150','deals-mobile','block_type','1',0,''),(61517,19482,'120151','deals-mobile','font-weight','normal',0,''),(61518,19482,'120151','deals-mobile','text-align','right',0,''),(61519,19482,'120151','deals-mobile','padding-bottom','10',0,''),(61520,19482,'120151','deals-mobile','address_spacer',',',0,''),(61521,19482,'120151','deals-mobile','font-size','12',0,''),(61522,19483,'120152','deals-mobile','block_type','11',0,''),(61523,19483,'120152','deals-mobile','font-weight','normal',0,''),(61524,19484,'120153','deals-mobile','text','<p>Email:</p>',1,''),(61525,19484,'120153','deals-mobile','font-weight','normal',0,''),(61526,19484,'120153','deals-mobile','text-align','right',0,''),(61527,19485,'120154','deals-mobile','font-weight','normal',0,''),(61528,19485,'120154','deals-mobile','text-align','right',0,''),(61529,19486,'120155','deals-mobile','block_type','11',0,''),(61530,19486,'120155','deals-mobile','font-weight','normal',0,''),(61531,19487,'120156','deals-mobile','text','<p>Web:</p>',1,''),(61532,19487,'120156','deals-mobile','font-weight','normal',0,''),(61533,19487,'120156','deals-mobile','text-align','right',0,''),(61534,19488,'120157','deals-mobile','font-weight','normal',0,''),(61535,19488,'120157','deals-mobile','text-align','right',0,''),(61536,19489,'120158','deals-mobile','block_type','11',0,''),(61537,19489,'120158','deals-mobile','font-weight','normal',0,''),(61538,19490,'120159','deals-mobile','text','<p>Phone:</p>',1,''),(61539,19490,'120159','deals-mobile','font-weight','normal',0,''),(61540,19490,'120159','deals-mobile','text-align','right',0,''),(61541,19491,'120160','deals-mobile','font-weight','normal',0,''),(61542,19491,'120160','deals-mobile','text-align','right',0,''),(61543,19492,'120161','deals-mobile','block_type','3',0,''),(61544,19492,'120161','deals-mobile','font-weight','normal',0,''),(61545,19492,'120161','deals-mobile','padding-top','20',0,''),(61546,19493,'120162','deals-mobile','font-size','12',0,''),(61547,19494,'120163','deals-mobile','text','<p>If undelivered please return to:</p>',1,''),(61548,19494,'120163','deals-mobile','font-size','12',0,''),(61549,19494,'120163','deals-mobile','font-weight','bold',0,''),(61550,19495,'120164','deals-mobile','text','<p>Thank you for your order</p>',1,''),(61551,19495,'120164','deals-mobile','color','#1da1f2',0,''),(61552,19495,'120164','deals-mobile','font-size','13',0,''),(61553,19495,'120164','deals-mobile','font-weight','bold',0,''),(61554,19495,'120164','deals-mobile','padding-top','5',0,''),(61555,19495,'120164','deals-mobile','text-align','center',0,''),(61556,19496,'120165','deals-mobile','font-weight','400',0,''),(61557,19496,'120165','deals-mobile','text-align','center',0,''),(61558,19496,'120165','deals-mobile','padding-top','0',0,''),(61560,19496,'120165','deals-mobile','padding-left','20',0,''),(61561,19496,'120165','deals-mobile','padding-right','20',0,''),(61562,19497,'120166','deals-mobile','block_type','6',0,''),(61563,19497,'120166','deals-mobile','font-weight','normal',0,''),(61564,19497,'120166','deals-mobile','font-size','16',0,''),(61565,19498,'120167','deals-mobile','text','<p>Phone:</p>',1,''),(61566,19498,'120167','deals-mobile','font-weight','normal',0,''),(61567,19498,'120167','deals-mobile','text-align','right',0,''),(61568,19498,'120167','deals-mobile','font-size','12',0,''),(61569,19499,'120168','deals-mobile','font-weight','normal',0,''),(61570,19499,'120168','deals-mobile','text-align','right',0,''),(61571,19499,'120168','deals-mobile','font-size','12',0,''),(61572,19500,'120169','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(61573,19500,'120169','deals-mobile','font-size','12',0,''),(61574,19500,'120169','deals-mobile','font-weight','bold',0,''),(61575,19500,'120169','deals-mobile','text-align','right',0,''),(61576,19501,'120170','deals-mobile','block_type','6',0,''),(61577,19501,'120170','deals-mobile','font-weight','normal',0,''),(61578,19501,'120170','deals-mobile','font-size','16',0,''),(61579,19502,'120171','deals-mobile','text','<p>Email:</p>',1,''),(61580,19502,'120171','deals-mobile','font-weight','normal',0,''),(61581,19502,'120171','deals-mobile','text-align','right',0,''),(61582,19502,'120171','deals-mobile','font-size','12',0,''),(61583,19503,'120172','deals-mobile','font-weight','normal',0,''),(61584,19503,'120172','deals-mobile','text-align','right',0,''),(61585,19503,'120172','deals-mobile','font-size','12',0,''),(61586,19504,'120173','deals-mobile','font-weight','400',0,''),(61587,19504,'120173','deals-mobile','padding-top','20',0,''),(61588,19504,'120173','deals-mobile','padding-bottom','0',0,''),(61589,19504,'120173','deals-mobile','font-size','12',0,''),(61590,19505,'120174','deals-mobile','block_type','1',0,''),(61591,19506,'120175','deals-mobile','block_type','6',0,''),(61592,19506,'120175','deals-mobile','schema','6-3',0,'872'),(61593,19507,'120176','deals-mobile','aria_name','account-menu',0,''),(61594,19508,'120177','deals-mobile','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(61595,19509,'120178','deals-mobile','link','Quotation Info',0,''),(61596,19509,'120178','deals-mobile','margin-bottom','20',0,''),(61597,19510,'120179','deals-mobile','block_type','1',0,''),(61598,19511,'120180','deals-mobile','block_type','6',0,''),(61599,19511,'120180','deals-mobile','schema','6-3',0,''),(61600,19511,'120180','deals-mobile','schema','6-3',0,'872'),(61601,19512,'120181','deals-mobile','aria_name','account-menu',0,''),(61602,19515,'120184','deals-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(61603,19516,'120185','deals-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(61604,19518,'120187','deals-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(61605,19519,'120188','deals-mobile','block_type','2',0,''),(61606,19519,'120188','deals-mobile','padding-top','20',0,''),(61607,19519,'120188','deals-mobile','margin-bottom','20',0,''),(61608,19520,'120189','deals-mobile','like_button','1',0,''),(61609,19520,'120189','deals-mobile','text','IMAGE_BUTTON_BACK',0,''),(61610,19520,'120189','deals-mobile','link','Quotations',0,''),(61611,19521,'120190','deals-mobile','block_type','3',0,''),(61612,19521,'120190','deals-mobile','schema','3-4',0,'872'),(61613,19522,'120191','deals-mobile','block_type','1',0,''),(61614,19522,'120191','deals-mobile','padding-right','20',0,''),(61615,19522,'120191','deals-mobile','padding-bottom','20',0,''),(61616,19523,'120192','deals-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(61617,19524,'120193','deals-mobile','orders_data','telephone',0,''),(61618,19525,'120194','deals-mobile','block_type','1',0,''),(61619,19525,'120194','deals-mobile','padding-right','20',0,''),(61620,19525,'120194','deals-mobile','padding-bottom','20',0,''),(61621,19526,'120195','deals-mobile','orders_data','name',0,''),(61622,19527,'120196','deals-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(61623,19528,'120197','deals-mobile','block_type','1',0,''),(61624,19528,'120197','deals-mobile','padding-right','20',0,''),(61625,19529,'120198','deals-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(61626,19530,'120199','deals-mobile','orders_data','shipping_method',0,''),(61627,19531,'120200','deals-mobile','block_type','1',0,''),(61628,19531,'120200','deals-mobile','padding-right','20',0,''),(61629,19531,'120200','deals-mobile','padding-bottom','20',0,''),(61630,19532,'120201','deals-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(61631,19533,'120202','deals-mobile','orders_data','delivery_address',0,''),(61632,19534,'120203','deals-mobile','block_type','1',0,''),(61633,19534,'120203','deals-mobile','padding-bottom','20',0,''),(61634,19535,'120204','deals-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(61635,19536,'120205','deals-mobile','orders_data','billing_address',0,''),(61636,19537,'120206','deals-mobile','block_type','1',0,''),(61637,19538,'120207','deals-mobile','orders_data','payment_method',0,''),(61638,19539,'120208','deals-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(61639,19542,'120211','deals-mobile','text','<h1>Quotations</h1>',1,''),(61640,19543,'120212','deals-mobile','block_type','1',0,''),(61641,19544,'120213','deals-mobile','block_type','6',0,''),(61642,19544,'120213','deals-mobile','schema','6-3',0,''),(61643,19544,'120213','deals-mobile','schema','6-3',0,'872'),(61644,19545,'120214','deals-mobile','aria_name','account-menu',0,''),(61645,19546,'120215','deals-mobile','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(61646,19547,'120216','deals-mobile','margin-bottom','20',0,''),(61647,19548,'120217','deals-mobile','block_type','1',0,''),(61648,19549,'120218','deals-mobile','pagination','bottom',0,''),(61649,19551,'120220','deals-mobile','width','800',0,''),(61650,19552,'120221','deals-mobile','block_type','1',0,''),(61651,19552,'120221','deals-mobile','border-top-width','1',0,''),(61652,19552,'120221','deals-mobile','border-left-width','1',0,''),(61653,19552,'120221','deals-mobile','border-right-width','1',0,''),(61654,19552,'120221','deals-mobile','border-bottom-width','1',0,''),(61655,19552,'120221','deals-mobile','border-top-color','#000000',0,''),(61656,19552,'120221','deals-mobile','border-left-color','#000000',0,''),(61657,19552,'120221','deals-mobile','border-right-color','#000000',0,''),(61658,19552,'120221','deals-mobile','border-bottom-color','#000000',0,''),(61659,19553,'120222','deals-mobile','block_type','11',0,''),(61660,19554,'120223','deals-mobile','block_type','1',0,''),(61661,19554,'120223','deals-mobile','padding-top','10',0,''),(61662,19554,'120223','deals-mobile','padding-right','10',0,''),(61663,19554,'120223','deals-mobile','padding-bottom','10',0,''),(61664,19554,'120223','deals-mobile','border-right-width','1',0,''),(61665,19554,'120223','deals-mobile','border-right-color','#000000',0,''),(61666,19555,'120224','deals-mobile','block_type','1',0,''),(61667,19555,'120224','deals-mobile','padding-left','10',0,''),(61668,19555,'120224','deals-mobile','padding-right','10',0,''),(61669,19555,'120224','deals-mobile','padding-bottom','10',0,''),(61670,19556,'120225','deals-mobile','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(61671,19556,'120225','deals-mobile','font-size','11',0,''),(61672,19556,'120225','deals-mobile','font-style','italic',0,''),(61673,19557,'120226','deals-mobile','block_type','9',0,''),(61674,19558,'120227','deals-mobile','text','2.',0,''),(61675,19558,'120227','deals-mobile','font-size','12',0,''),(61676,19558,'120227','deals-mobile','text-align','right',0,''),(61677,19558,'120227','deals-mobile','padding-right','5',0,''),(61678,19559,'120228','deals-mobile','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(61679,19559,'120228','deals-mobile','font-size','12',0,''),(61680,19559,'120228','deals-mobile','padding-bottom','10',0,''),(61681,19560,'120229','deals-mobile','block_type','1',0,''),(61682,19561,'120230','deals-mobile','text','Shipping Instructions:',0,''),(61683,19561,'120230','deals-mobile','font-weight','bold',0,''),(61684,19561,'120230','deals-mobile','font-size','14',0,''),(61685,19561,'120230','deals-mobile','padding-bottom','5',0,''),(61686,19561,'120230','deals-mobile','padding-left','10',0,''),(61687,19562,'120231','deals-mobile','block_type','9',0,''),(61688,19563,'120232','deals-mobile','text','1.',0,''),(61689,19563,'120232','deals-mobile','font-size','12',0,''),(61690,19563,'120232','deals-mobile','text-align','right',0,''),(61691,19563,'120232','deals-mobile','padding-right','5',0,''),(61692,19564,'120233','deals-mobile','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(61693,19564,'120233','deals-mobile','font-size','12',0,''),(61694,19564,'120233','deals-mobile','padding-bottom','10',0,''),(61695,19565,'120234','deals-mobile','block_type','9',0,''),(61696,19566,'120235','deals-mobile','text','3.',0,''),(61697,19566,'120235','deals-mobile','font-size','12',0,''),(61698,19566,'120235','deals-mobile','text-align','right',0,''),(61699,19566,'120235','deals-mobile','padding-right','5',0,''),(61700,19567,'120236','deals-mobile','text','Ship only the items that are authorized.',0,''),(61701,19567,'120236','deals-mobile','font-size','12',0,''),(61702,19567,'120236','deals-mobile','padding-bottom','10',0,''),(61703,19568,'120237','deals-mobile','block_type','9',0,''),(61704,19569,'120238','deals-mobile','text','4.',0,''),(61705,19569,'120238','deals-mobile','font-size','12',0,''),(61706,19569,'120238','deals-mobile','text-align','right',0,''),(61707,19569,'120238','deals-mobile','padding-right','5',0,''),(61708,19570,'120239','deals-mobile','text','Ship returned items to:',0,''),(61709,19570,'120239','deals-mobile','font-size','12',0,''),(61710,19570,'120239','deals-mobile','padding-bottom','5',0,''),(61711,19571,'120240','deals-mobile','font-size','11',0,''),(61712,19571,'120240','deals-mobile','font-style','italic',0,''),(61713,19571,'120240','deals-mobile','padding-bottom','5',0,''),(61714,19572,'120241','deals-mobile','block_type','3',0,''),(61715,19572,'120241','deals-mobile','padding-right','10',0,''),(61716,19573,'120242','deals-mobile','text','Customer Signature:',0,''),(61717,19573,'120242','deals-mobile','font-weight','bold',0,''),(61718,19573,'120242','deals-mobile','font-size','11',0,''),(61719,19573,'120242','deals-mobile','padding-top','5',0,''),(61720,19573,'120242','deals-mobile','padding-left','10',0,''),(61721,19574,'120243','deals-mobile','text','&nbsp;',0,''),(61722,19574,'120243','deals-mobile','border-bottom-width','1',0,''),(61723,19574,'120243','deals-mobile','border-bottom-color','#000000',0,''),(61724,19575,'120244','deals-mobile','block_type','5',0,''),(61725,19576,'120245','deals-mobile','text','Date:',0,''),(61726,19576,'120245','deals-mobile','padding-top','5',0,''),(61727,19576,'120245','deals-mobile','font-size','11',0,''),(61728,19576,'120245','deals-mobile','font-weight','bold',0,''),(61729,19576,'120245','deals-mobile','padding-left','5',0,''),(61730,19577,'120246','deals-mobile','text','&nbsp;',0,''),(61731,19577,'120246','deals-mobile','border-bottom-width','1',0,''),(61732,19577,'120246','deals-mobile','border-bottom-color','#000000',0,''),(61733,19578,'120247','deals-mobile','block_type','3',0,''),(61734,19578,'120247','deals-mobile','padding-top','10',0,''),(61735,19578,'120247','deals-mobile','padding-bottom','10',0,''),(61736,19578,'120247','deals-mobile','padding-right','10',0,''),(61737,19579,'120248','deals-mobile','font-size','11',0,''),(61738,19579,'120248','deals-mobile','font-weight','bold',0,''),(61739,19579,'120248','deals-mobile','text','Return Approval:',0,''),(61740,19579,'120248','deals-mobile','padding-top','5',0,''),(61741,19579,'120248','deals-mobile','padding-left','10',0,''),(61742,19580,'120249','deals-mobile','border-bottom-width','1',0,''),(61743,19580,'120249','deals-mobile','border-bottom-color','#000000',0,''),(61744,19580,'120249','deals-mobile','text','&nbsp;',0,''),(61745,19581,'120250','deals-mobile','block_type','5',0,''),(61746,19582,'120251','deals-mobile','text','Date:',0,''),(61747,19582,'120251','deals-mobile','padding-top','5',0,''),(61748,19582,'120251','deals-mobile','font-size','11',0,''),(61749,19582,'120251','deals-mobile','font-weight','bold',0,''),(61750,19582,'120251','deals-mobile','padding-left','5',0,''),(61751,19583,'120252','deals-mobile','text','&nbsp;',0,''),(61752,19583,'120252','deals-mobile','border-bottom-width','1',0,''),(61753,19583,'120252','deals-mobile','border-bottom-color','#000000',0,''),(61754,19584,'120253','deals-mobile','block_type','1',0,''),(61755,19584,'120253','deals-mobile','padding-left','10',0,''),(61756,19584,'120253','deals-mobile','padding-right','10',0,''),(61757,19584,'120253','deals-mobile','padding-bottom','10',0,''),(61758,19585,'120254','deals-mobile','text','Use this space for additional Comments:',0,''),(61759,19585,'120254','deals-mobile','font-size','11',0,''),(61760,19585,'120254','deals-mobile','font-style','italic',0,''),(61761,19586,'120255','deals-mobile','text','&nbsp;',0,''),(61762,19586,'120255','deals-mobile','border-bottom-width','1',0,''),(61763,19586,'120255','deals-mobile','border-bottom-color','#000000',0,''),(61764,19587,'120256','deals-mobile','text','&nbsp;',0,''),(61765,19587,'120256','deals-mobile','border-bottom-width','1',0,''),(61766,19587,'120256','deals-mobile','border-bottom-color','#000000',0,''),(61767,19587,'120256','deals-mobile','padding-top','5',0,''),(61768,19588,'120257','deals-mobile','text','&nbsp;',0,''),(61769,19588,'120257','deals-mobile','border-bottom-width','1',0,''),(61770,19588,'120257','deals-mobile','border-bottom-color','#000000',0,''),(61771,19588,'120257','deals-mobile','padding-top','5',0,''),(61772,19589,'120258','deals-mobile','text','&nbsp;',0,''),(61773,19589,'120258','deals-mobile','border-bottom-width','1',0,''),(61774,19589,'120258','deals-mobile','border-bottom-color','#000000',0,''),(61775,19589,'120258','deals-mobile','padding-top','5',0,''),(61776,19590,'120259','deals-mobile','block_type','1',0,''),(61777,19590,'120259','deals-mobile','padding-top','10',0,''),(61778,19590,'120259','deals-mobile','padding-left','40',0,''),(61779,19590,'120259','deals-mobile','padding-right','40',0,''),(61780,19590,'120259','deals-mobile','padding-bottom','10',0,''),(61781,19591,'120260','deals-mobile','block_type','1',0,''),(61782,19591,'120260','deals-mobile','padding-top','10',0,''),(61783,19591,'120260','deals-mobile','padding-left','10',0,''),(61784,19591,'120260','deals-mobile','padding-right','10',0,''),(61785,19591,'120260','deals-mobile','padding-bottom','10',0,''),(61786,19591,'120260','deals-mobile','border-top-width','1',0,''),(61787,19591,'120260','deals-mobile','border-left-width','1',0,''),(61788,19591,'120260','deals-mobile','border-right-width','1',0,''),(61789,19591,'120260','deals-mobile','border-bottom-width','1',0,''),(61790,19591,'120260','deals-mobile','border-top-color','#000000',0,''),(61791,19591,'120260','deals-mobile','border-left-color','#000000',0,''),(61792,19591,'120260','deals-mobile','border-right-color','#000000',0,''),(61793,19591,'120260','deals-mobile','border-bottom-color','#000000',0,''),(61794,19592,'120261','deals-mobile','block_type','3',0,''),(61795,19593,'120262','deals-mobile','data','rrDelivery_name',0,''),(61796,19593,'120262','deals-mobile','font-size','9',0,''),(61797,19594,'120263','deals-mobile','block_type','2',0,''),(61798,19595,'120264','deals-mobile','text','RMA#:',0,''),(61799,19595,'120264','deals-mobile','font-size','10',0,''),(61800,19596,'120265','deals-mobile','data','rrNumber',0,''),(61801,19596,'120265','deals-mobile','font-size','9',0,''),(61802,19597,'120266','deals-mobile','block_type','5',0,''),(61803,19598,'120267','deals-mobile','font-size','9',0,''),(61804,19599,'120268','deals-mobile','block_type','1',0,''),(61805,19601,'120270','deals-mobile','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(61806,19601,'120270','deals-mobile','font-size','12',0,''),(61807,19601,'120270','deals-mobile','font-style','italic',0,''),(61808,19601,'120270','deals-mobile','padding-bottom','20',0,''),(61809,19602,'120271','deals-mobile','block_type','11',0,''),(61810,19602,'120271','deals-mobile','border-top-width','1',0,''),(61811,19602,'120271','deals-mobile','border-left-width','1',0,''),(61812,19602,'120271','deals-mobile','border-right-width','1',0,''),(61813,19602,'120271','deals-mobile','border-bottom-width','1',0,''),(61814,19602,'120271','deals-mobile','border-top-color','#000000',0,''),(61815,19602,'120271','deals-mobile','border-left-color','#000000',0,''),(61816,19602,'120271','deals-mobile','border-right-color','#000000',0,''),(61817,19602,'120271','deals-mobile','border-bottom-color','#000000',0,''),(61818,19603,'120272','deals-mobile','block_type','1',0,''),(61819,19603,'120272','deals-mobile','border-right-width','1',0,''),(61820,19603,'120272','deals-mobile','border-right-color','#000000',0,''),(61821,19603,'120272','deals-mobile','padding-top','10',0,''),(61822,19603,'120272','deals-mobile','padding-right','10',0,''),(61823,19603,'120272','deals-mobile','padding-bottom','10',0,''),(61824,19604,'120273','deals-mobile','block_type','1',0,''),(61825,19604,'120273','deals-mobile','padding-left','15',0,''),(61826,19605,'120274','deals-mobile','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(61827,19605,'120274','deals-mobile','font-size','11',0,''),(61828,19605,'120274','deals-mobile','font-style','italic',0,''),(61829,19605,'120274','deals-mobile','padding-bottom','5',0,''),(61830,19606,'120275','deals-mobile','text','Replacement Policy:',0,''),(61831,19606,'120275','deals-mobile','font-size','14',0,''),(61832,19606,'120275','deals-mobile','padding-bottom','5',0,''),(61833,19606,'120275','deals-mobile','font-weight','bold',0,''),(61834,19607,'120276','deals-mobile','block_type','9',0,''),(61835,19608,'120277','deals-mobile','text','2.',0,''),(61836,19608,'120277','deals-mobile','font-size','12',0,''),(61837,19608,'120277','deals-mobile','text-align','right',0,''),(61838,19608,'120277','deals-mobile','margin-right','5',0,''),(61839,19609,'120278','deals-mobile','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(61840,19609,'120278','deals-mobile','font-size','12',0,''),(61841,19609,'120278','deals-mobile','padding-bottom','5',0,''),(61842,19610,'120279','deals-mobile','block_type','9',0,''),(61843,19611,'120280','deals-mobile','text','1.',0,''),(61844,19611,'120280','deals-mobile','font-size','12',0,''),(61845,19611,'120280','deals-mobile','text-align','right',0,''),(61846,19611,'120280','deals-mobile','padding-right','5',0,''),(61847,19612,'120281','deals-mobile','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(61848,19612,'120281','deals-mobile','font-size','12',0,''),(61849,19612,'120281','deals-mobile','padding-bottom','5',0,''),(61850,19613,'120282','deals-mobile','block_type','9',0,''),(61851,19614,'120283','deals-mobile','text','3.',0,''),(61852,19614,'120283','deals-mobile','font-size','12',0,''),(61853,19614,'120283','deals-mobile','text-align','right',0,''),(61854,19614,'120283','deals-mobile','margin-right','5',0,''),(61855,19615,'120284','deals-mobile','text','Return the authorized item(s) per shipping instructions.',0,''),(61856,19615,'120284','deals-mobile','font-size','12',0,''),(61857,19615,'120284','deals-mobile','padding-bottom','5',0,''),(61858,19616,'120285','deals-mobile','block_type','9',0,''),(61859,19617,'120286','deals-mobile','text','4.',0,''),(61860,19617,'120286','deals-mobile','font-size','12',0,''),(61861,19617,'120286','deals-mobile','text-align','right',0,''),(61862,19617,'120286','deals-mobile','margin-right','5',0,''),(61863,19618,'120287','deals-mobile','text','Our Replacement Department will process your request.',0,''),(61864,19618,'120287','deals-mobile','font-size','12',0,''),(61865,19618,'120287','deals-mobile','padding-bottom','5',0,''),(61866,19619,'120288','deals-mobile','block_type','2',0,''),(61867,19619,'120288','deals-mobile','padding-left','10',0,''),(61868,19619,'120288','deals-mobile','padding-top','20',0,''),(61869,19619,'120288','deals-mobile','padding-right','10',0,''),(61870,19620,'120289','deals-mobile','block_type','5',0,''),(61871,19621,'120290','deals-mobile','text','RMA No:',0,''),(61872,19621,'120290','deals-mobile','font-size','12',0,''),(61873,19621,'120290','deals-mobile','font-weight','bold',0,''),(61874,19622,'120291','deals-mobile','data','rrNumber',0,''),(61875,19622,'120291','deals-mobile','font-size','12',0,''),(61876,19622,'120291','deals-mobile','font-weight','bold',0,''),(61877,19623,'120292','deals-mobile','block_type','2',0,''),(61878,19624,'120293','deals-mobile','text','Date Issued:',0,''),(61879,19624,'120293','deals-mobile','font-size','12',0,''),(61880,19624,'120293','deals-mobile','font-weight','bold',0,''),(61881,19625,'120294','deals-mobile','data','rrDateCreate',0,''),(61882,19625,'120294','deals-mobile','font-size','12',0,''),(61883,19625,'120294','deals-mobile','font-weight','bold',0,''),(61884,19626,'120295','deals-mobile','block_type','1',0,''),(61885,19626,'120295','deals-mobile','padding-top','10',0,''),(61886,19626,'120295','deals-mobile','padding-left','10',0,''),(61887,19626,'120295','deals-mobile','padding-right','10',0,''),(61888,19626,'120295','deals-mobile','padding-bottom','10',0,''),(61889,19627,'120296','deals-mobile','block_type','2',0,''),(61890,19628,'120297','deals-mobile','block_type','11',0,''),(61891,19629,'120298','deals-mobile','text','Company:',0,''),(61892,19629,'120298','deals-mobile','font-size','12',0,''),(61893,19630,'120299','deals-mobile','data','rrDelivery_company',0,''),(61894,19630,'120299','deals-mobile','font-size','12',0,''),(61895,19631,'120300','deals-mobile','block_type','2',0,''),(61896,19632,'120301','deals-mobile','text','Contact Name:',0,''),(61897,19632,'120301','deals-mobile','font-size','12',0,''),(61898,19633,'120302','deals-mobile','data','rrDelivery_name',0,''),(61899,19633,'120302','deals-mobile','font-size','12',0,''),(61900,19634,'120303','deals-mobile','block_type','9',0,''),(61901,19634,'120303','deals-mobile','padding-top','5',0,''),(61902,19635,'120304','deals-mobile','text','Address:',0,''),(61903,19635,'120304','deals-mobile','font-size','12',0,''),(61904,19636,'120305','deals-mobile','data','rrDelivery_street_address',0,''),(61905,19636,'120305','deals-mobile','font-size','12',0,''),(61906,19637,'120306','deals-mobile','block_type','2',0,''),(61907,19637,'120306','deals-mobile','padding-top','5',0,''),(61908,19638,'120307','deals-mobile','block_type','11',0,''),(61909,19639,'120308','deals-mobile','text','City:',0,''),(61910,19639,'120308','deals-mobile','font-size','12',0,''),(61911,19640,'120309','deals-mobile','data','rrDelivery_city',0,''),(61912,19640,'120309','deals-mobile','font-size','12',0,''),(61913,19641,'120310','deals-mobile','block_type','11',0,''),(61914,19642,'120311','deals-mobile','text','State:',0,''),(61915,19642,'120311','deals-mobile','font-size','12',0,''),(61916,19643,'120312','deals-mobile','data','rrDelivery_state',0,''),(61917,19643,'120312','deals-mobile','font-size','12',0,''),(61918,19644,'120313','deals-mobile','block_type','2',0,''),(61919,19644,'120313','deals-mobile','padding-top','5',0,''),(61920,19645,'120314','deals-mobile','block_type','11',0,''),(61921,19646,'120315','deals-mobile','text','Country:',0,''),(61922,19646,'120315','deals-mobile','font-size','12',0,''),(61923,19647,'120316','deals-mobile','data','rrDelivery_country',0,''),(61924,19647,'120316','deals-mobile','font-size','12',0,''),(61925,19648,'120317','deals-mobile','block_type','11',0,''),(61926,19649,'120318','deals-mobile','text','Postcode:',0,''),(61927,19649,'120318','deals-mobile','font-size','12',0,''),(61928,19650,'120319','deals-mobile','data','rrDelivery_postcode',0,''),(61929,19650,'120319','deals-mobile','font-size','12',0,''),(61930,19651,'120320','deals-mobile','block_type','2',0,''),(61931,19651,'120320','deals-mobile','padding-top','5',0,''),(61932,19652,'120321','deals-mobile','block_type','11',0,''),(61933,19653,'120322','deals-mobile','text','Email:',0,''),(61934,19653,'120322','deals-mobile','font-size','12',0,''),(61935,19654,'120323','deals-mobile','data','rrDelivery_email_address',0,''),(61936,19654,'120323','deals-mobile','font-size','12',0,''),(61937,19655,'120324','deals-mobile','block_type','11',0,''),(61938,19656,'120325','deals-mobile','text','Phone:',0,''),(61939,19656,'120325','deals-mobile','font-size','12',0,''),(61940,19657,'120326','deals-mobile','data','rrDelivery_telephone',0,''),(61941,19657,'120326','deals-mobile','font-size','12',0,''),(61942,19658,'120327','deals-mobile','block_type','1',0,''),(61943,19658,'120327','deals-mobile','border-bottom-width','1',0,''),(61944,19658,'120327','deals-mobile','border-bottom-color','#000000',0,''),(61945,19659,'120328','deals-mobile','text-align','center',0,''),(61946,19659,'120328','deals-mobile','logo','themes/deals-mobile/img/Furntech-1.jpg',1,''),(61947,19659,'120328','deals-mobile','padding-top','10',0,''),(61948,19659,'120328','deals-mobile','padding-bottom','10',0,''),(61949,19660,'120329','deals-mobile','text','Return Material Authorization (RMA) Form',0,''),(61950,19660,'120329','deals-mobile','text-align','center',0,''),(61951,19660,'120329','deals-mobile','font-size','12',0,''),(61952,19660,'120329','deals-mobile','font-weight','bold',0,''),(61953,19660,'120329','deals-mobile','font-family','Arial',0,''),(61954,19661,'120330','deals-mobile','block_type','1',0,''),(61955,19661,'120330','deals-mobile','style_class','item-holder',0,''),(61956,19661,'120330','deals-mobile','padding-top','25',0,''),(61957,19661,'120330','deals-mobile','padding-bottom','25',0,''),(61958,19661,'120330','deals-mobile','text-align','left',0,''),(61959,19661,'120330','deals-mobile','border-top-width','1',0,''),(61960,19661,'120330','deals-mobile','border-top-color','#e0e0e0',0,''),(61961,19662,'120331','deals-mobile','block_type','7',0,''),(61962,19662,'120331','deals-mobile','schema','7-2',0,''),(61963,19663,'120332','deals-mobile','block_type','5',0,''),(61964,19663,'120332','deals-mobile','schema','5-2',0,''),(61965,19664,'120333','deals-mobile','block_type','1',0,''),(61966,19665,'120334','deals-mobile','text-align','right',0,''),(61967,19665,'120334','deals-mobile','margin-top','4',0,''),(61968,19665,'120334','deals-mobile','margin-bottom','7',0,''),(61969,19665,'120334','deals-mobile','float','left',0,''),(61970,19666,'120335','deals-mobile','padding-top','6',0,''),(61971,19666,'120335','deals-mobile','padding-left','5',0,''),(61972,19666,'120335','deals-mobile','float','left',0,''),(61973,19666,'120335','deals-mobile','clear','none',0,''),(61974,19667,'120336','deals-mobile','clear','none',0,''),(61975,19667,'120336','deals-mobile','padding-right','20',0,''),(61976,19668,'120337','deals-mobile','padding-right','20',0,''),(61977,19668,'120337','deals-mobile','max-width','300',0,''),(61978,19668,'120337','deals-mobile','margin_left_measure','auto',0,''),(61979,19668,'120337','deals-mobile','margin_right_measure','auto',0,''),(61980,19669,'120338','deals-mobile','clear','none',0,''),(61981,19670,'120339','deals-mobile','padding-right','20',0,''),(61982,19671,'120340','deals-mobile','description_characters','200',0,''),(61983,19671,'120340','deals-mobile','clear','none',0,''),(61984,19671,'120340','deals-mobile','padding-right','20',0,''),(61985,19672,'120341','deals-mobile','margin-bottom','20',0,''),(61986,19673,'120342','deals-mobile','block_type','1',0,''),(61987,19673,'120342','deals-mobile','padding-left','40',0,''),(61988,19673,'120342','deals-mobile','style_class','right-aria',0,''),(61990,19674,'120343','deals-mobile','text-align','right',0,''),(61991,19674,'120343','deals-mobile','margin-bottom','10',0,''),(61992,19675,'120344','deals-mobile','margin-bottom','10',0,''),(61993,19675,'120344','deals-mobile','text-align','right',0,''),(61994,19677,'120346','deals-mobile','margin-bottom','15',0,''),(61995,19677,'120346','deals-mobile','text-align','right',0,''),(61996,19678,'120347','deals-mobile','margin-bottom','10',0,''),(61997,19679,'120348','deals-mobile','text-align','right',0,''),(61998,19679,'120348','deals-mobile','margin-bottom','15',0,''),(61999,19680,'120349','deals-mobile','block_type','1',0,''),(62000,19681,'120350','deals-mobile','padding-bottom','20',0,''),(62001,19682,'120351','deals-mobile','text-align','right',0,''),(62002,19682,'120351','deals-mobile','margin-bottom','40',0,''),(62003,19683,'120352','deals-mobile','text','<h1>Samples</h1>',1,''),(62004,19684,'120353','deals-mobile','block_type','1',0,''),(62005,19685,'120354','deals-mobile','block_type','6',0,''),(62006,19685,'120354','deals-mobile','schema','6-3',0,''),(62007,19685,'120354','deals-mobile','schema','6-3',0,'872'),(62008,19686,'120355','deals-mobile','aria_name','account-menu',0,''),(62009,19687,'120356','deals-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(62010,19688,'120357','deals-mobile','show_pagenation','1',0,''),(62011,19688,'120357','deals-mobile','link','Sample Info',0,''),(62012,19688,'120357','deals-mobile','margin-bottom','20',0,''),(62013,19689,'120358','deals-mobile','block_type','1',0,''),(62014,19690,'120359','deals-mobile','block_type','6',0,''),(62015,19691,'120360','deals-mobile','aria_name','account-menu',0,''),(62016,19692,'120361','deals-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(62017,19693,'120362','deals-mobile','block_type','3',0,''),(62018,19694,'120363','deals-mobile','block_type','1',0,''),(62019,19694,'120363','deals-mobile','padding-right','20',0,''),(62020,19694,'120363','deals-mobile','padding-bottom','20',0,''),(62021,19695,'120364','deals-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(62022,19696,'120365','deals-mobile','orders_data','telephone',0,''),(62023,19697,'120366','deals-mobile','block_type','1',0,''),(62024,19697,'120366','deals-mobile','padding-right','20',0,''),(62025,19697,'120366','deals-mobile','padding-bottom','20',0,''),(62026,19698,'120367','deals-mobile','orders_data','name',0,''),(62027,19699,'120368','deals-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(62028,19700,'120369','deals-mobile','block_type','1',0,''),(62029,19700,'120369','deals-mobile','padding-right','20',0,''),(62030,19700,'120369','deals-mobile','padding-bottom','20',0,''),(62031,19701,'120370','deals-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(62032,19702,'120371','deals-mobile','orders_data','delivery_address',0,''),(62033,19703,'120372','deals-mobile','block_type','1',0,''),(62034,19703,'120372','deals-mobile','padding-right','20',0,''),(62035,19704,'120373','deals-mobile','orders_data','shipping_method',0,''),(62036,19705,'120374','deals-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(62037,19706,'120375','deals-mobile','block_type','1',0,''),(62038,19706,'120375','deals-mobile','padding-bottom','20',0,''),(62039,19707,'120376','deals-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(62040,19708,'120377','deals-mobile','orders_data','billing_address',0,''),(62041,19709,'120378','deals-mobile','block_type','1',0,''),(62042,19710,'120379','deals-mobile','orders_data','payment_method',0,''),(62043,19711,'120380','deals-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(62044,19712,'120381','deals-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(62045,19715,'120384','deals-mobile','block_type','2',0,''),(62046,19715,'120384','deals-mobile','padding-top','20',0,''),(62047,19715,'120384','deals-mobile','margin-bottom','20',0,''),(62048,19716,'120385','deals-mobile','like_button','1',0,''),(62049,19716,'120385','deals-mobile','text','IMAGE_BUTTON_BACK',0,''),(62050,19716,'120385','deals-mobile','link','Samples',0,''),(62051,19718,'120387','deals-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(62052,19719,'120388','deals-mobile','block_type','1',0,''),(62053,19720,'120389','deals-mobile','block_type','6',0,''),(62054,19720,'120389','deals-mobile','schema','6-3',0,''),(62055,19720,'120389','deals-mobile','schema','6-3',0,'872'),(62056,19721,'120390','deals-mobile','aria_name','account-menu',0,''),(62057,19722,'120391','deals-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(62058,19723,'120392','deals-mobile','link','Order History Info',0,''),(62059,19723,'120392','deals-mobile','text','TEXT_VIEW',0,''),(62060,19723,'120392','deals-mobile','max_orders','3',0,''),(62061,19723,'120392','deals-mobile','link_pay','Order pay',0,''),(62062,19723,'120392','deals-mobile','margin-bottom','30',0,''),(62063,19723,'120392','deals-mobile','text_pay','ORDER_PAY',0,''),(62064,19724,'120393','deals-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(62065,19725,'120394','deals-mobile','block_type','15',0,''),(62066,19725,'120394','deals-mobile','margin-bottom','30',0,''),(62067,19725,'120394','deals-mobile','padding-top','20',0,''),(62068,19725,'120394','deals-mobile','padding-left','20',0,''),(62069,19725,'120394','deals-mobile','padding-right','20',0,''),(62070,19725,'120394','deals-mobile','padding-bottom','20',0,''),(62071,19725,'120394','deals-mobile','border-top-width','1',0,''),(62072,19725,'120394','deals-mobile','border-top-color','#e0e0e0',0,''),(62073,19725,'120394','deals-mobile','border-left-width','1',0,''),(62074,19725,'120394','deals-mobile','border-right-width','1',0,''),(62075,19725,'120394','deals-mobile','border-bottom-width','1',0,''),(62076,19725,'120394','deals-mobile','border-left-color','#e0e0e0',0,''),(62077,19725,'120394','deals-mobile','border-right-color','#e0e0e0',0,''),(62078,19725,'120394','deals-mobile','border-bottom-color','#e0e0e0',0,''),(62079,19725,'120394','deals-mobile','schema','15-2',0,'872'),(62080,19726,'120395','deals-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(62081,19726,'120395','deals-mobile','font-family','trueloaded',0,'3'),(62082,19726,'120395','deals-mobile','content','\\e920',0,'3'),(62083,19726,'120395','deals-mobile','color','#ee4225',0,'3'),(62084,19726,'120395','deals-mobile','font-size','30',0,'3'),(62085,19726,'120395','deals-mobile','text-align','center',0,'3'),(62086,19726,'120395','deals-mobile','margin-bottom','10',0,'3'),(62087,19726,'120395','deals-mobile','text-align','center',0,''),(62088,19726,'120395','deals-mobile','font-size','16',0,''),(62089,19726,'120395','deals-mobile','text-transform','uppercase',0,''),(62090,19726,'120395','deals-mobile','line-height','1',0,'3'),(62092,19727,'120396','deals-mobile','font-family','Varela Round',0,''),(62093,19727,'120396','deals-mobile','color','#ee4225',0,''),(62094,19727,'120396','deals-mobile','font-size','14',0,''),(62095,19727,'120396','deals-mobile','text-align','center',0,''),(62096,19728,'120397','deals-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(62097,19728,'120397','deals-mobile','font-family','trueloaded',0,'3'),(62098,19728,'120397','deals-mobile','content','\\e928',0,'3'),(62099,19728,'120397','deals-mobile','color','#ee4225',0,'3'),(62100,19728,'120397','deals-mobile','font-size','30',0,'3'),(62101,19728,'120397','deals-mobile','text-align','center',0,'3'),(62102,19728,'120397','deals-mobile','text-align','center',0,''),(62103,19728,'120397','deals-mobile','font-size','16',0,''),(62104,19728,'120397','deals-mobile','text-transform','uppercase',0,''),(62105,19728,'120397','deals-mobile','line-height','1',0,'3'),(62107,19729,'120398','deals-mobile','link','download_orders',0,''),(62108,19729,'120398','deals-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(62109,19729,'120398','deals-mobile','hide_link','orders',0,''),(62110,19729,'120398','deals-mobile','text-align','center',0,''),(62111,19729,'120398','deals-mobile','popup','2',0,''),(62112,19729,'120398','deals-mobile','font-size','14',0,''),(62113,19730,'120399','deals-mobile','font-family','Varela Round',0,''),(62114,19730,'120399','deals-mobile','color','#ee4225',0,''),(62115,19730,'120399','deals-mobile','font-size','14',0,''),(62116,19730,'120399','deals-mobile','text-align','center',0,''),(62117,19731,'120400','deals-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(62118,19731,'120400','deals-mobile','font-family','trueloaded',0,'3'),(62119,19731,'120400','deals-mobile','content','\\e922',0,'3'),(62120,19731,'120400','deals-mobile','color','#ee4225',0,'3'),(62121,19731,'120400','deals-mobile','font-size','30',0,'3'),(62122,19731,'120400','deals-mobile','line-height','1',0,'3'),(62123,19731,'120400','deals-mobile','font-size','16',0,''),(62124,19731,'120400','deals-mobile','text-align','center',0,''),(62125,19731,'120400','deals-mobile','text-transform','uppercase',0,''),(62127,19732,'120401','deals-mobile','font-family','Varela Round',0,''),(62128,19732,'120401','deals-mobile','color','#ee4225',0,''),(62129,19732,'120401','deals-mobile','line-height','1',0,''),(62130,19732,'120401','deals-mobile','text-align','center',0,''),(62131,19732,'120401','deals-mobile','font-size','14',0,''),(62132,19733,'120402','deals-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(62133,19733,'120402','deals-mobile','content','\\e994',0,'3'),(62134,19733,'120402','deals-mobile','font-family','trueloaded',0,'3'),(62135,19733,'120402','deals-mobile','color','#ee4225',0,'3'),(62136,19733,'120402','deals-mobile','font-size','30',0,'3'),(62137,19733,'120402','deals-mobile','line-height','1',0,'3'),(62138,19733,'120402','deals-mobile','font-size','16',0,''),(62139,19733,'120402','deals-mobile','text-align','center',0,''),(62140,19733,'120402','deals-mobile','text-transform','uppercase',0,''),(62142,19734,'120403','deals-mobile','link','Gift Certificate',0,''),(62143,19734,'120403','deals-mobile','text','GIFT_CERTIFICATE',0,''),(62144,19734,'120403','deals-mobile','popup','1',0,''),(62145,19734,'120403','deals-mobile','text-align','center',0,''),(62146,19734,'120403','deals-mobile','font-size','14',0,''),(62147,19735,'120404','deals-mobile','font-family','Varela Round',0,''),(62148,19735,'120404','deals-mobile','color','#ee4225',0,''),(62149,19735,'120404','deals-mobile','font-size','14',0,''),(62150,19735,'120404','deals-mobile','text-align','center',0,''),(62151,19736,'120405','deals-mobile','text','TEXT_VIEW_HISTORY',0,''),(62152,19736,'120405','deals-mobile','popup','1',0,''),(62153,19736,'120405','deals-mobile','text-align','center',0,''),(62154,19736,'120405','deals-mobile','link','Points Earnt History',0,''),(62155,19736,'120405','deals-mobile','font-size','14',0,''),(62156,19737,'120406','deals-mobile','font-family','Varela Round',0,''),(62157,19737,'120406','deals-mobile','color','#ee4225',0,''),(62158,19737,'120406','deals-mobile','font-size','14',0,''),(62159,19737,'120406','deals-mobile','text-align','center',0,''),(62160,19738,'120407','deals-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(62161,19738,'120407','deals-mobile','content','\\e990',0,'3'),(62162,19738,'120407','deals-mobile','font-family','trueloaded',0,'3'),(62163,19738,'120407','deals-mobile','font-size','30',0,'3'),(62164,19738,'120407','deals-mobile','text-align','center',0,'3'),(62165,19738,'120407','deals-mobile','line-height','1',0,'3'),(62166,19738,'120407','deals-mobile','color','#ee4225',0,'3'),(62167,19738,'120407','deals-mobile','font-size','16',0,''),(62168,19738,'120407','deals-mobile','text-align','center',0,''),(62169,19738,'120407','deals-mobile','text-transform','uppercase',0,''),(62171,19739,'120408','deals-mobile','block_type','1',0,''),(62172,19740,'120409','deals-mobile','hide_parents','2',0,''),(62173,19741,'120410','deals-mobile','text','<div class=\"heading-3\">##TEXT_GIFT_CARDS##</div>',0,''),(62174,19743,'120412','deals-mobile','block_type','1',0,''),(62175,19744,'120413','deals-mobile','block_type','6',0,''),(62176,19745,'120414','deals-mobile','class','menu-simple',0,''),(62177,19747,'120416','deals-mobile','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(62178,19749,'120418','deals-mobile','text','<div class=\"heading-4\">Categories</div>',0,''),(62179,19750,'120419','deals-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(62180,19751,'120420','deals-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(62181,19753,'120422','deals-mobile','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(62182,19754,'120423','deals-mobile','block_type','1',0,''),(62183,19755,'120424','deals-mobile','style_class','middle-form',0,''),(62184,19755,'120424','deals-mobile','margin-bottom','30',0,''),(62185,19756,'120425','deals-mobile','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(62186,19757,'120426','deals-mobile','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(62187,19757,'120426','deals-mobile','style_class','middle-form',0,''),(62188,19758,'120427','deals-mobile','style_class','middle-form',0,''),(62189,19759,'120428','deals-mobile','block_type','1',0,''),(62190,19760,'120429','deals-mobile','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(62191,19760,'120429','deals-mobile','padding-top','100',0,''),(62192,19760,'120429','deals-mobile','margin-bottom','100',0,''),(62193,19760,'120429','deals-mobile','text-align','center',0,''),(62194,19760,'120429','deals-mobile','font-size','20',0,''),(62195,19761,'120430','deals-mobile','block_type','1',0,''),(62196,19762,'120431','deals-mobile','block_type','6',0,''),(62197,19762,'120431','deals-mobile','schema','6-3',0,''),(62198,19762,'120431','deals-mobile','schema','6-3',0,'872'),(62199,19763,'120432','deals-mobile','aria_name','account-menu',0,''),(62200,19764,'120433','deals-mobile','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(62201,19765,'120434','deals-mobile','text','##SUBSCRIPTION_TEXT##',0,''),(62202,19767,'120436','deals-mobile','block_type','1',0,''),(62203,19768,'120437','deals-mobile','block_type','1',0,''),(62204,19768,'120437','deals-mobile','font-weight','normal',0,''),(62205,19769,'120438','deals-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',1,''),(62206,19769,'120438','deals-mobile','font-weight','400',0,''),(62207,19770,'120439','deals-mobile','block_type','3',0,''),(62208,19770,'120439','deals-mobile','font-weight','400',0,''),(62209,19770,'120439','deals-mobile','schema','3-4',0,'864'),(62210,19771,'120440','deals-mobile','text','&nbsp;',0,''),(62211,19771,'120440','deals-mobile','font-weight','normal',0,''),(62212,19772,'120441','deals-mobile','font-weight','normal',0,''),(62213,19772,'120441','deals-mobile','box_align','2',0,''),(62214,19772,'120441','deals-mobile','padding-top','40',0,''),(62215,19773,'120442','deals-mobile','font-weight','400',0,''),(62216,19773,'120442','deals-mobile','text-align','right',0,''),(62217,19773,'120442','deals-mobile','padding-top','40',0,''),(62218,19773,'120442','deals-mobile','padding-bottom','100',0,''),(62219,19773,'120442','deals-mobile','text-align','center',0,'864'),(62220,19773,'120442','deals-mobile','float','none',0,'864'),(62221,19774,'120443','deals-mobile','block_type','1',0,''),(62222,19775,'120444','deals-mobile','block_type','1',0,''),(62223,19775,'120444','deals-mobile','font-weight','normal',0,''),(62224,19776,'120445','deals-mobile','block_type','1',0,''),(62225,19776,'120445','deals-mobile','text-align','center',0,''),(62226,19776,'120445','deals-mobile','padding-top','30',0,''),(62227,19776,'120445','deals-mobile','margin-bottom','200',0,''),(62228,19777,'120446','deals-mobile','display','inline-block',0,''),(62229,19778,'120447','deals-mobile','display','inline-block',0,''),(62230,19778,'120447','deals-mobile','clear','none',0,''),(62231,19778,'120447','deals-mobile','margin-left','20',0,''),(62232,19779,'120448','deals-mobile','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(62234,19783,'120452','deals-mobile','width','680',0,''),(62235,19783,'120452','deals-mobile','font-weight','normal',0,''),(62236,19783,'120452','deals-mobile','font-size','12',0,''),(62237,19783,'120452','deals-mobile','padding-top','20',0,''),(62238,19783,'120452','deals-mobile','padding-bottom','20',0,''),(62239,19783,'120452','deals-mobile','color','#424242',0,''),(62240,19784,'120453','deals-mobile','block_type','2',0,''),(62241,19784,'120453','deals-mobile','font-weight','normal',0,''),(62242,19784,'120453','deals-mobile','padding-bottom','20',0,''),(62243,19785,'120454','deals-mobile','block_type','1',0,''),(62244,19786,'120455','deals-mobile','font-weight','normal',0,''),(62245,19786,'120455','deals-mobile','text-align','right',0,''),(62246,19786,'120455','deals-mobile','padding-bottom','10',0,''),(62247,19786,'120455','deals-mobile','address_spacer',',',0,''),(62248,19786,'120455','deals-mobile','font-size','12',0,''),(62249,19787,'120456','deals-mobile','block_type','11',0,''),(62250,19787,'120456','deals-mobile','font-weight','normal',0,''),(62251,19788,'120457','deals-mobile','text','<p>Phone:</p>',1,''),(62252,19788,'120457','deals-mobile','font-weight','normal',0,''),(62253,19788,'120457','deals-mobile','text-align','right',0,''),(62254,19789,'120458','deals-mobile','font-weight','normal',0,''),(62255,19789,'120458','deals-mobile','text-align','right',0,''),(62256,19790,'120459','deals-mobile','block_type','11',0,''),(62257,19790,'120459','deals-mobile','font-weight','normal',0,''),(62258,19791,'120460','deals-mobile','text','<p>Web:</p>',1,''),(62259,19791,'120460','deals-mobile','font-weight','normal',0,''),(62260,19791,'120460','deals-mobile','text-align','right',0,''),(62261,19792,'120461','deals-mobile','font-weight','normal',0,''),(62262,19792,'120461','deals-mobile','text-align','right',0,''),(62263,19793,'120462','deals-mobile','block_type','11',0,''),(62264,19793,'120462','deals-mobile','font-weight','normal',0,''),(62265,19794,'120463','deals-mobile','text','<p>Email:</p>',1,''),(62266,19794,'120463','deals-mobile','font-weight','normal',0,''),(62267,19794,'120463','deals-mobile','text-align','right',0,''),(62268,19795,'120464','deals-mobile','font-weight','normal',0,''),(62269,19795,'120464','deals-mobile','text-align','right',0,''),(62270,19796,'120465','deals-mobile','block_type','4',0,''),(62271,19796,'120465','deals-mobile','font-weight','normal',0,''),(62272,19796,'120465','deals-mobile','border-top-width','1',0,''),(62273,19796,'120465','deals-mobile','border-top-color','#e0e0e0',0,''),(62274,19796,'120465','deals-mobile','border-left-width','1',0,''),(62275,19796,'120465','deals-mobile','border-left-color','#e0e0e0',0,''),(62276,19796,'120465','deals-mobile','border-right-width','1',0,''),(62277,19796,'120465','deals-mobile','border-right-color','#e0e0e0',0,''),(62278,19796,'120465','deals-mobile','border-bottom-width','1',0,''),(62279,19796,'120465','deals-mobile','border-bottom-color','#e0e0e0',0,''),(62280,19797,'120466','deals-mobile','block_type','2',0,''),(62281,19797,'120466','deals-mobile','font-weight','normal',0,''),(62282,19797,'120466','deals-mobile','border-right-width','1',0,''),(62283,19797,'120466','deals-mobile','border-right-color','#e0e0e0',0,''),(62284,19798,'120467','deals-mobile','block_type','1',0,''),(62285,19798,'120467','deals-mobile','font-weight','400',0,''),(62286,19798,'120467','deals-mobile','background-color','#eeeeee',0,''),(62287,19798,'120467','deals-mobile','padding-top','10',0,''),(62288,19798,'120467','deals-mobile','padding-left','10',0,''),(62289,19798,'120467','deals-mobile','padding-right','10',0,''),(62290,19798,'120467','deals-mobile','padding-bottom','30',0,''),(62291,19799,'120468','deals-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(62292,19799,'120468','deals-mobile','font-size','14',0,''),(62293,19799,'120468','deals-mobile','font-weight','bold',0,''),(62294,19800,'120469','deals-mobile','font-size','12',0,''),(62295,19801,'120470','deals-mobile','block_type','1',0,''),(62296,19801,'120470','deals-mobile','font-weight','normal',0,''),(62297,19801,'120470','deals-mobile','padding-top','10',0,''),(62298,19801,'120470','deals-mobile','padding-left','10',0,''),(62299,19801,'120470','deals-mobile','padding-right','10',0,''),(62300,19801,'120470','deals-mobile','padding-bottom','10',0,''),(62301,19802,'120471','deals-mobile','text','<p>PHONE NUMBER:</p>',1,''),(62302,19802,'120471','deals-mobile','font-size','14',0,''),(62303,19802,'120471','deals-mobile','font-weight','bold',0,''),(62304,19802,'120471','deals-mobile','padding-top','10',0,''),(62305,19803,'120472','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(62306,19803,'120472','deals-mobile','font-weight','bold',0,''),(62307,19803,'120472','deals-mobile','font-size','14',0,''),(62308,19803,'120472','deals-mobile','padding-top','10',0,''),(62309,19804,'120473','deals-mobile','text','<p>CUSTOMER:</p>',1,''),(62310,19804,'120473','deals-mobile','font-size','13',0,''),(62311,19804,'120473','deals-mobile','font-weight','bold',0,''),(62312,19805,'120474','deals-mobile','font-weight','normal',0,''),(62313,19806,'120475','deals-mobile','font-weight','normal',0,''),(62314,19808,'120477','deals-mobile','block_type','2',0,''),(62315,19808,'120477','deals-mobile','font-weight','normal',0,''),(62316,19808,'120477','deals-mobile','border-top-width','1',0,''),(62317,19808,'120477','deals-mobile','border-top-color','#e0e0e0',0,''),(62318,19808,'120477','deals-mobile','border-right-width','1',0,''),(62319,19808,'120477','deals-mobile','border-right-color','#e0e0e0',0,''),(62320,19809,'120478','deals-mobile','block_type','1',0,''),(62321,19809,'120478','deals-mobile','font-weight','normal',0,''),(62322,19809,'120478','deals-mobile','padding-top','10',0,''),(62323,19809,'120478','deals-mobile','padding-left','10',0,''),(62324,19809,'120478','deals-mobile','padding-right','10',0,''),(62325,19809,'120478','deals-mobile','padding-bottom','10',0,''),(62326,19809,'120478','deals-mobile','border-right-width','1',0,''),(62327,19809,'120478','deals-mobile','border-right-color','#e0e0e0',0,''),(62328,19810,'120479','deals-mobile','text','<p>Shipping via</p>',1,''),(62329,19810,'120479','deals-mobile','font-weight','bold',0,''),(62330,19810,'120479','deals-mobile','font-size','14',0,''),(62331,19812,'120481','deals-mobile','block_type','1',0,''),(62332,19812,'120481','deals-mobile','font-weight','normal',0,''),(62333,19812,'120481','deals-mobile','padding-top','10',0,''),(62334,19812,'120481','deals-mobile','padding-left','10',0,''),(62335,19812,'120481','deals-mobile','padding-right','10',0,''),(62336,19812,'120481','deals-mobile','padding-bottom','10',0,''),(62337,19814,'120483','deals-mobile','text','<p>Shipping service</p>',1,''),(62338,19814,'120483','deals-mobile','font-weight','bold',0,''),(62339,19814,'120483','deals-mobile','font-size','14',0,''),(62340,19815,'120484','deals-mobile','text','<p>Payment date:</p>',1,''),(62341,19815,'120484','deals-mobile','font-weight','bold',0,''),(62342,19815,'120484','deals-mobile','text-align','center',0,''),(62343,19815,'120484','deals-mobile','font-size','12',0,''),(62344,19816,'120485','deals-mobile','font-weight','normal',0,''),(62345,19816,'120485','deals-mobile','text-align','center',0,''),(62346,19817,'120486','deals-mobile','text','<p>Payment Method:</p>',1,''),(62347,19817,'120486','deals-mobile','font-weight','bold',0,''),(62348,19817,'120486','deals-mobile','text-align','center',0,''),(62349,19818,'120487','deals-mobile','font-size','14',0,''),(62350,19818,'120487','deals-mobile','font-weight','bold',0,''),(62351,19818,'120487','deals-mobile','text-align','center',0,''),(62352,19818,'120487','deals-mobile','padding-bottom','10',0,''),(62353,19818,'120487','deals-mobile','padding-top','10',0,''),(62354,19819,'120488','deals-mobile','font-weight','normal',0,''),(62355,19819,'120488','deals-mobile','text-align','center',0,''),(62356,19819,'120488','deals-mobile','padding-bottom','10',0,''),(62357,19820,'120489','deals-mobile','font-weight','normal',0,''),(62358,19820,'120489','deals-mobile','text-align','center',0,''),(62359,19820,'120489','deals-mobile','padding-bottom','20',0,''),(62360,19821,'120490','deals-mobile','block_type','3',0,''),(62361,19821,'120490','deals-mobile','font-weight','normal',0,''),(62362,19821,'120490','deals-mobile','padding-top','20',0,''),(62363,19822,'120491','deals-mobile','text','<p>If undelivered please return to:</p>',1,''),(62364,19822,'120491','deals-mobile','font-size','12',0,''),(62365,19822,'120491','deals-mobile','font-weight','bold',0,''),(62366,19823,'120492','deals-mobile','font-size','12',0,''),(62367,19824,'120493','deals-mobile','font-weight','400',0,''),(62368,19824,'120493','deals-mobile','text-align','center',0,''),(62369,19824,'120493','deals-mobile','padding-top','0',0,''),(62371,19824,'120493','deals-mobile','padding-left','20',0,''),(62372,19824,'120493','deals-mobile','padding-right','20',0,''),(62373,19825,'120494','deals-mobile','text','<p>Thank you for your order</p>',1,''),(62374,19825,'120494','deals-mobile','color','#1da1f2',0,''),(62375,19825,'120494','deals-mobile','font-size','13',0,''),(62376,19825,'120494','deals-mobile','font-weight','bold',0,''),(62377,19825,'120494','deals-mobile','padding-top','5',0,''),(62378,19825,'120494','deals-mobile','text-align','center',0,''),(62379,19826,'120495','deals-mobile','block_type','6',0,''),(62380,19826,'120495','deals-mobile','font-weight','normal',0,''),(62381,19826,'120495','deals-mobile','font-size','16',0,''),(62382,19827,'120496','deals-mobile','text','<p>Phone:</p>',1,''),(62383,19827,'120496','deals-mobile','font-weight','normal',0,''),(62384,19827,'120496','deals-mobile','text-align','right',0,''),(62385,19827,'120496','deals-mobile','font-size','12',0,''),(62386,19828,'120497','deals-mobile','font-weight','normal',0,''),(62387,19828,'120497','deals-mobile','text-align','right',0,''),(62388,19828,'120497','deals-mobile','font-size','12',0,''),(62389,19829,'120498','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(62390,19829,'120498','deals-mobile','font-size','12',0,''),(62391,19829,'120498','deals-mobile','font-weight','bold',0,''),(62392,19829,'120498','deals-mobile','text-align','right',0,''),(62393,19830,'120499','deals-mobile','block_type','6',0,''),(62394,19830,'120499','deals-mobile','font-weight','normal',0,''),(62395,19830,'120499','deals-mobile','font-size','16',0,''),(62396,19831,'120500','deals-mobile','text','<p>Email:</p>',1,''),(62397,19831,'120500','deals-mobile','font-weight','normal',0,''),(62398,19831,'120500','deals-mobile','text-align','right',0,''),(62399,19831,'120500','deals-mobile','font-size','12',0,''),(62400,19832,'120501','deals-mobile','font-weight','normal',0,''),(62401,19832,'120501','deals-mobile','text-align','right',0,''),(62402,19832,'120501','deals-mobile','font-size','12',0,''),(62403,19833,'120502','deals-mobile','font-weight','400',0,''),(62404,19833,'120502','deals-mobile','padding-top','20',0,''),(62405,19833,'120502','deals-mobile','padding-bottom','0',0,''),(62406,19833,'120502','deals-mobile','font-size','12',0,''),(62407,19834,'120503','deals-mobile','block_type','5',0,''),(62408,19834,'120503','deals-mobile','font-weight','normal',0,''),(62409,19834,'120503','deals-mobile','border-bottom-width','1',0,''),(62410,19834,'120503','deals-mobile','border-bottom-color','#e0e0e0',0,''),(62411,19834,'120503','deals-mobile','border-top-width','1',0,''),(62412,19834,'120503','deals-mobile','border-top-color','#e0e0e0',0,''),(62413,19834,'120503','deals-mobile','border-left-color','#e0e0e0',0,''),(62414,19834,'120503','deals-mobile','border-left-width','1',0,''),(62415,19835,'120504','deals-mobile','block_type','1',0,''),(62416,19835,'120504','deals-mobile','font-weight','normal',0,''),(62417,19835,'120504','deals-mobile','padding-top','10',0,''),(62418,19835,'120504','deals-mobile','padding-left','10',0,''),(62419,19835,'120504','deals-mobile','padding-right','10',0,''),(62420,19836,'120505','deals-mobile','font-weight','400',0,''),(62421,19836,'120505','deals-mobile','line-height','120',0,''),(62422,19836,'120505','deals-mobile','line_height_measure','%',0,''),(62423,19836,'120505','deals-mobile','font-size','12',0,''),(62424,19837,'120506','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(62425,19837,'120506','deals-mobile','font-size','14',0,''),(62426,19837,'120506','deals-mobile','font-weight','bold',0,''),(62427,19837,'120506','deals-mobile','padding-bottom','10',0,''),(62428,19838,'120507','deals-mobile','block_type','1',0,''),(62429,19838,'120507','deals-mobile','background-color','#eeeeee',0,''),(62430,19838,'120507','deals-mobile','padding-top','20',0,''),(62431,19838,'120507','deals-mobile','padding-left','10',0,''),(62432,19838,'120507','deals-mobile','padding-right','10',0,''),(62433,19838,'120507','deals-mobile','padding-bottom','20',0,''),(62434,19838,'120507','deals-mobile','font-size','14',0,''),(62435,19839,'120508','deals-mobile','font-weight','normal',0,''),(62436,19839,'120508','deals-mobile','text-align','right',0,''),(62437,19839,'120508','deals-mobile','font-size','14',0,''),(62438,19839,'120508','deals-mobile','box_align','3',0,''),(62439,19840,'120509','deals-mobile','block_type','1',0,''),(62440,19840,'120509','deals-mobile','padding-top','35',0,''),(62441,19840,'120509','deals-mobile','padding-bottom','35',0,''),(62442,19841,'120510','deals-mobile','block_type','7',0,''),(62443,19841,'120510','deals-mobile','schema','7-2',0,''),(62444,19842,'120511','deals-mobile','block_type','1',0,''),(62445,19842,'120511','deals-mobile','style_class','blog_list_content',0,''),(62446,19844,'120513','deals-mobile','text-align','center',0,''),(62447,19845,'120514','deals-mobile','aria_name','blogsidebar',0,''),(62448,19845,'120514','deals-mobile','style_class','blogsidebar',0,''),(62449,19846,'120515','deals-mobile','block_type','1',0,''),(62450,19846,'120515','deals-mobile','padding-top','35',0,''),(62451,19846,'120515','deals-mobile','padding-bottom','35',0,''),(62452,19847,'120516','deals-mobile','block_type','7',0,''),(62453,19847,'120516','deals-mobile','schema','7-1',0,''),(62455,19848,'120517','deals-mobile','block_type','1',0,''),(62456,19848,'120517','deals-mobile','style_class','blog_list_content',0,''),(62457,19849,'120518','deals-mobile','items_on_page','12',0,''),(62458,19849,'120518','deals-mobile','items_cut_off','200',0,''),(62459,19850,'120519','deals-mobile','text-align','center',0,''),(62460,19850,'120519','deals-mobile','hide_parents','1',0,''),(62461,19851,'120520','deals-mobile','aria_name','blogsidebar',0,''),(62462,19851,'120520','deals-mobile','padding-left','35',0,''),(62463,19851,'120520','deals-mobile','style_class','blogsidebar',0,''),(62465,19852,'120521','deals-mobile','banners_group','blog',0,''),(62466,19852,'120521','deals-mobile','margin-bottom','40',0,''),(62467,19853,'120522','deals-mobile','block_type','1',0,''),(62468,19853,'120522','deals-mobile','padding-top','35',0,''),(62469,19853,'120522','deals-mobile','padding-bottom','35',0,''),(62470,19854,'120523','deals-mobile','block_type','7',0,''),(62471,19854,'120523','deals-mobile','schema','7-2',0,''),(62472,19856,'120525','deals-mobile','block_type','1',0,''),(62473,19857,'120526','deals-mobile','text','<div class=\"heading-3\">##TEXT_BLOG_RELATED_PRODUCTS##</div>',0,''),(62474,19858,'120527','deals-mobile','count_products','8',0,''),(62475,19858,'120527','deals-mobile','col_in_row','4',0,''),(62476,19858,'120527','deals-mobile','view_as','carousel',0,''),(62477,19858,'120527','deals-mobile','show_stock','1',0,''),(62478,19858,'120527','deals-mobile','show_description','1',0,''),(62479,19858,'120527','deals-mobile','show_properties','1',0,''),(62480,19858,'120527','deals-mobile','show_rating','1',0,''),(62481,19858,'120527','deals-mobile','show_rating_counts','1',0,''),(62482,19858,'120527','deals-mobile','show_qty_input','1',0,''),(62483,19858,'120527','deals-mobile','show_wishlist_button','1',0,''),(62484,19858,'120527','deals-mobile','show_compare','1',0,''),(62488,19858,'120527','deals-mobile','listing_type','productListing',0,''),(62489,19858,'120527','deals-mobile','hide_parents','2',0,''),(62490,19859,'120528','deals-mobile','block_type','1',0,''),(62491,19859,'120528','deals-mobile','style_class','blog-white-bg',0,''),(62492,19859,'120528','deals-mobile','padding-bottom','20',0,''),(62493,19863,'120532','deals-mobile','block_type','1',0,''),(62494,19863,'120532','deals-mobile','padding-top','20',0,''),(62495,19863,'120532','deals-mobile','margin-top','20',0,''),(62496,19863,'120532','deals-mobile','border-top-width','1',0,''),(62497,19863,'120532','deals-mobile','border-top-color','#EDE5D5',0,''),(62498,19863,'120532','deals-mobile','clear','both',0,''),(62499,19864,'120533','deals-mobile','box_align','4',0,''),(62500,19864,'120533','deals-mobile','text-align','center',0,''),(62501,19865,'120534','deals-mobile','text-align','center',0,''),(62502,19866,'120535','deals-mobile','aria_name','blogsidebar',0,''),(62503,19866,'120535','deals-mobile','style_class','blogsidebar',0,''),(62504,19867,'120536','deals-mobile','block_type','1',0,''),(62505,19867,'120536','deals-mobile','padding-top','35',0,''),(62506,19867,'120536','deals-mobile','padding-bottom','35',0,''),(62507,19868,'120537','deals-mobile','block_type','7',0,''),(62508,19868,'120537','deals-mobile','schema','7-2',0,''),(62509,19869,'120538','deals-mobile','block_type','1',0,''),(62510,19869,'120538','deals-mobile','style_class','blog_list_content',0,''),(62511,19871,'120540','deals-mobile','text-align','center',0,''),(62512,19871,'120540','deals-mobile','hide_parents','1',0,''),(62513,19872,'120541','deals-mobile','aria_name','blogsidebar',0,''),(62514,19872,'120541','deals-mobile','style_class','blogsidebar',0,''),(62515,19873,'120542','deals-mobile','block_type','1',0,''),(62516,19875,'120544','deals-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(62517,19876,'120545','deals-mobile','block_type','1',0,''),(62518,19877,'120546','deals-mobile','block_type','2',0,''),(62519,19877,'120546','deals-mobile','margin-bottom','20',0,''),(62520,19878,'120547','deals-mobile','block_type','1',0,''),(62521,19878,'120547','deals-mobile','padding-right','20',0,''),(62522,19879,'120548','deals-mobile','field','50',0,''),(62523,19880,'120549','deals-mobile','field','49',0,''),(62524,19881,'120550','deals-mobile','block_type','2',0,''),(62525,19883,'120552','deals-mobile','float','right',0,''),(62526,19883,'120552','deals-mobile','clear','none',0,''),(62527,19884,'120553','deals-mobile','float','right',0,''),(62528,19884,'120553','deals-mobile','margin-left','20',0,''),(62529,19885,'120554','deals-mobile','block_type','2',0,''),(62530,19885,'120554','deals-mobile','margin-bottom','20',0,''),(62531,19886,'120555','deals-mobile','block_type','1',0,''),(62532,19886,'120555','deals-mobile','padding-right','20',0,''),(62533,19887,'120556','deals-mobile','field','66',0,''),(62534,19888,'120557','deals-mobile','block_type','1',0,''),(62535,19888,'120557','deals-mobile','padding-left','20',0,''),(62536,19889,'120558','deals-mobile','field','67',0,''),(62537,19890,'120559','deals-mobile','text','<div class=\"heading-2\">##TRADE_REFERENCES##</div>',0,''),(62538,19890,'120559','deals-mobile','text-align','center',0,''),(62539,19891,'120560','deals-mobile','text','<div class=\"heading-2\">##BANK_ACCOUNT_DETAILS##</div>',0,''),(62540,19891,'120560','deals-mobile','text-align','center',0,''),(62541,19892,'120561','deals-mobile','text','<div class=\"heading-2\">##TEXT_DECLARATION##</div>',0,''),(62542,19892,'120561','deals-mobile','text-align','center',0,''),(62543,19893,'120562','deals-mobile','block_type','2',0,''),(62544,19893,'120562','deals-mobile','margin-bottom','20',0,''),(62545,19894,'120563','deals-mobile','block_type','1',0,''),(62546,19894,'120563','deals-mobile','padding-right','20',0,''),(62547,19895,'120564','deals-mobile','field','62',0,''),(62548,19896,'120565','deals-mobile','field','60',0,''),(62549,19897,'120566','deals-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 1</div>',0,''),(62550,19898,'120567','deals-mobile','field','61',0,''),(62551,19899,'120568','deals-mobile','block_type','1',0,''),(62552,19899,'120568','deals-mobile','padding-left','20',0,''),(62553,19900,'120569','deals-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 2</div>',0,''),(62554,19901,'120570','deals-mobile','field','64',0,''),(62555,19902,'120571','deals-mobile','field','63',0,''),(62556,19903,'120572','deals-mobile','field','65',0,''),(62557,19904,'120573','deals-mobile','block_type','2',0,''),(62558,19904,'120573','deals-mobile','margin-bottom','20',0,''),(62559,19905,'120574','deals-mobile','block_type','1',0,''),(62560,19905,'120574','deals-mobile','padding-right','20',0,''),(62561,19906,'120575','deals-mobile','field','52',0,''),(62562,19907,'120576','deals-mobile','field','51',0,''),(62563,19908,'120577','deals-mobile','block_type','2',0,''),(62564,19909,'120578','deals-mobile','block_type','1',0,''),(62565,19909,'120578','deals-mobile','padding-right','20',0,''),(62566,19910,'120579','deals-mobile','group','15',0,''),(62567,19911,'120580','deals-mobile','text','<div class=\"heading-3\">##CATEGORY_COMPANY##</div>',0,''),(62568,19913,'120582','deals-mobile','block_type','2',0,''),(62569,19914,'120583','deals-mobile','field','68',0,''),(62570,19914,'120583','deals-mobile','padding-right','10',0,''),(62571,19915,'120584','deals-mobile','block_type','2',0,''),(62572,19915,'120584','deals-mobile','border-bottom-width','1',0,''),(62573,19915,'120584','deals-mobile','border-bottom-color','#e0e0e0',0,''),(62574,19915,'120584','deals-mobile','padding-bottom','10',0,''),(62575,19915,'120584','deals-mobile','margin-bottom','20',0,''),(62576,19916,'120585','deals-mobile','block_type','1',0,''),(62577,19916,'120585','deals-mobile','padding-right','10',0,''),(62578,19917,'120586','deals-mobile','field','69',0,''),(62579,19918,'120587','deals-mobile','field','75',0,''),(62580,19919,'120588','deals-mobile','field','71',0,''),(62581,19920,'120589','deals-mobile','field','73',0,''),(62582,19921,'120590','deals-mobile','block_type','1',0,''),(62583,19921,'120590','deals-mobile','padding-left','10',0,''),(62584,19922,'120591','deals-mobile','field','76',0,''),(62585,19923,'120592','deals-mobile','field','74',0,''),(62586,19924,'120593','deals-mobile','field','72',0,''),(62587,19925,'120594','deals-mobile','field','70',0,''),(62588,19926,'120595','deals-mobile','block_type','1',0,''),(62589,19926,'120595','deals-mobile','padding-left','20',0,''),(62590,19927,'120596','deals-mobile','group','16',0,''),(62591,19928,'120597','deals-mobile','block_type','2',0,''),(62592,19929,'120598','deals-mobile','block_type','1',0,''),(62593,19929,'120598','deals-mobile','padding-right','10',0,''),(62594,19930,'120599','deals-mobile','field','77',0,''),(62595,19931,'120600','deals-mobile','field','79',0,''),(62596,19932,'120601','deals-mobile','block_type','1',0,''),(62597,19932,'120601','deals-mobile','padding-left','10',0,''),(62598,19933,'120602','deals-mobile','field','78',0,''),(62599,19934,'120603','deals-mobile','block_type','2',0,''),(62600,19935,'120604','deals-mobile','block_type','1',0,''),(62601,19935,'120604','deals-mobile','padding-right','10',0,''),(62602,19936,'120605','deals-mobile','field','82',0,''),(62603,19937,'120606','deals-mobile','field','80',0,''),(62604,19938,'120607','deals-mobile','field','84',0,''),(62605,19939,'120608','deals-mobile','block_type','1',0,''),(62606,19939,'120608','deals-mobile','padding-left','10',0,''),(62607,19940,'120609','deals-mobile','field','83',0,''),(62608,19941,'120610','deals-mobile','field','81',0,''),(62609,19942,'120611','deals-mobile','field','85',0,''),(62610,19943,'120612','deals-mobile','text','<div class=\"heading-3\">##OWNERS_DETAILS##</div>',0,''),(62611,19944,'120613','deals-mobile','block_type','2',0,''),(62612,19944,'120613','deals-mobile','margin-bottom','20',0,''),(62613,19945,'120614','deals-mobile','block_type','1',0,''),(62614,19945,'120614','deals-mobile','padding-right','20',0,''),(62615,19946,'120615','deals-mobile','field','53',0,''),(62616,19947,'120616','deals-mobile','field','54',0,''),(62617,19948,'120617','deals-mobile','block_type','1',0,''),(62618,19948,'120617','deals-mobile','padding-left','20',0,''),(62619,19949,'120618','deals-mobile','field','55',0,''),(62620,19950,'120619','deals-mobile','text','<div class=\"heading-2\">##TEXT_CUSTOMER_DETAILS##</div>',0,''),(62621,19950,'120619','deals-mobile','text-align','center',0,''),(62622,19951,'120620','deals-mobile','block_type','2',0,''),(62623,19951,'120620','deals-mobile','margin-bottom','20',0,''),(62624,19952,'120621','deals-mobile','block_type','1',0,''),(62625,19952,'120621','deals-mobile','padding-right','20',0,''),(62626,19953,'120622','deals-mobile','field','56',0,''),(62627,19954,'120623','deals-mobile','field','57',0,''),(62628,19955,'120624','deals-mobile','block_type','1',0,''),(62629,19955,'120624','deals-mobile','padding-left','20',0,''),(62630,19956,'120625','deals-mobile','field','58',0,''),(62631,19957,'120626','deals-mobile','field','59',0,''),(62632,19958,'120627','deals-mobile','text','<h1>##TRADE_FORM##</h1>',0,''),(62633,19959,'120628','deals-mobile','text','<div class=\"heading-2\">##DISCOUNT##</div>',0,''),(62634,19959,'120628','deals-mobile','text-align','center',0,''),(62635,19960,'120629','deals-mobile','block_type','1',0,''),(62636,19961,'120630','deals-mobile','block_type','6',0,''),(62637,19962,'120631','deals-mobile','text','Telephone No.',0,''),(62638,19962,'120631','deals-mobile','text-align','right',0,''),(62639,19963,'120632','deals-mobile','field','79',0,''),(62640,19963,'120632','deals-mobile','border-bottom-width','1',0,''),(62641,19963,'120632','deals-mobile','border-bottom-color','#000000',0,''),(62642,19963,'120632','deals-mobile','padding-left','10',0,''),(62643,19964,'120633','deals-mobile','block_type','6',0,''),(62644,19965,'120634','deals-mobile','text','Address',0,''),(62645,19965,'120634','deals-mobile','text-align','right',0,''),(62646,19966,'120635','deals-mobile','fields','company_street_address, company_suburb, company_city',0,''),(62647,19966,'120635','deals-mobile','padding-left','10',0,''),(62648,19966,'120635','deals-mobile','border-bottom-width','1',0,''),(62649,19966,'120635','deals-mobile','border-bottom-color','#000000',0,''),(62650,19967,'120636','deals-mobile','block_type','6',0,''),(62651,19968,'120637','deals-mobile','text','Postcode',0,''),(62652,19968,'120637','deals-mobile','text-align','right',0,''),(62653,19969,'120638','deals-mobile','field','80',0,''),(62654,19969,'120638','deals-mobile','border-bottom-width','1',0,''),(62655,19969,'120638','deals-mobile','border-bottom-color','#000000',0,''),(62656,19969,'120638','deals-mobile','padding-left','10',0,''),(62657,19970,'120639','deals-mobile','block_type','6',0,''),(62658,19971,'120640','deals-mobile','text','Address',0,''),(62659,19971,'120640','deals-mobile','text-align','right',0,''),(62660,19972,'120641','deals-mobile','fields','oner_street_address, owner_suburb, owner_city',0,''),(62661,19972,'120641','deals-mobile','padding-left','10',0,''),(62662,19972,'120641','deals-mobile','border-bottom-width','1',0,''),(62663,19972,'120641','deals-mobile','border-bottom-color','#000000',0,''),(62664,19973,'120642','deals-mobile','block_type','6',0,''),(62665,19973,'120642','deals-mobile','margin-top','20',0,''),(62666,19974,'120643','deals-mobile','text','Owner’s Name',0,''),(62667,19974,'120643','deals-mobile','text-align','right',0,''),(62668,19975,'120644','deals-mobile','fields','owner_firstname owner_lastname',0,''),(62669,19975,'120644','deals-mobile','padding-left','10',0,''),(62670,19975,'120644','deals-mobile','border-bottom-width','1',0,''),(62671,19975,'120644','deals-mobile','border-bottom-color','#000000',0,''),(62672,19976,'120645','deals-mobile','block_type','6',0,''),(62673,19977,'120646','deals-mobile','text','Email',0,''),(62674,19977,'120646','deals-mobile','text-align','right',0,''),(62675,19978,'120647','deals-mobile','field','70',0,''),(62676,19978,'120647','deals-mobile','border-bottom-width','1',0,''),(62677,19978,'120647','deals-mobile','border-bottom-color','#000000',0,''),(62678,19978,'120647','deals-mobile','padding-left','10',0,''),(62679,19979,'120648','deals-mobile','block_type','6',0,''),(62680,19979,'120648','deals-mobile','padding-bottom','20',0,''),(62681,19980,'120649','deals-mobile','text','Telephone No.',0,''),(62682,19980,'120649','deals-mobile','text-align','right',0,''),(62683,19981,'120650','deals-mobile','block_type','11',0,''),(62684,19982,'120651','deals-mobile','field','69',0,''),(62685,19982,'120651','deals-mobile','border-bottom-width','1',0,''),(62686,19982,'120651','deals-mobile','border-bottom-color','#000000',0,''),(62687,19982,'120651','deals-mobile','padding-left','10',0,''),(62688,19983,'120652','deals-mobile','block_type','5',0,''),(62689,19984,'120653','deals-mobile','text','Fax No.',0,''),(62690,19984,'120653','deals-mobile','text-align','right',0,''),(62691,19985,'120654','deals-mobile','field','51',0,''),(62692,19985,'120654','deals-mobile','padding-left','10',0,''),(62693,19985,'120654','deals-mobile','border-bottom-width','1',0,''),(62694,19985,'120654','deals-mobile','border-bottom-color','#000000',0,''),(62695,19986,'120655','deals-mobile','block_type','1',0,''),(62696,19987,'120656','deals-mobile','background-color','#000000',0,''),(62697,19987,'120656','deals-mobile','color','#ffffff',0,''),(62698,19987,'120656','deals-mobile','font-size','20',0,''),(62699,19987,'120656','deals-mobile','text','Customer Details',0,''),(62700,19987,'120656','deals-mobile','padding-left','10',0,''),(62701,19987,'120656','deals-mobile','padding-right','10',0,''),(62702,19988,'120657','deals-mobile','block_type','2',0,''),(62703,19988,'120657','deals-mobile','color','#ffffff',0,''),(62704,19988,'120657','deals-mobile','background-color','#000000',0,''),(62705,19989,'120658','deals-mobile','view_item','name',0,''),(62706,19989,'120658','deals-mobile','color','#ffffff',0,''),(62707,19989,'120658','deals-mobile','font-size','40',0,''),(62708,19990,'120659','deals-mobile','text','New Account Form',0,''),(62709,19990,'120659','deals-mobile','font-size','20',0,''),(62710,19990,'120659','deals-mobile','color','#ffffff',0,''),(62711,19990,'120659','deals-mobile','padding-top','20',0,''),(62712,19991,'120660','deals-mobile','block_type','2',0,''),(62713,19992,'120661','deals-mobile','block_type','2',0,''),(62714,19992,'120661','deals-mobile','padding-top','5',0,''),(62715,19993,'120662','deals-mobile','block_type','10',0,''),(62716,19994,'120663','deals-mobile','text','Limited Company',0,''),(62717,19994,'120663','deals-mobile','font-size','16',0,''),(62718,19995,'120664','deals-mobile','field','49',0,''),(62719,19995,'120664','deals-mobile','padding-left','5',0,''),(62720,19996,'120665','deals-mobile','block_type','10',0,''),(62721,19997,'120666','deals-mobile','text','Sole Trader',0,''),(62722,19997,'120666','deals-mobile','text-align','center',0,''),(62723,19998,'120667','deals-mobile','field','50',0,''),(62724,19998,'120667','deals-mobile','padding-left','5',0,''),(62725,19999,'120668','deals-mobile','block_type','5',0,''),(62726,20000,'120669','deals-mobile','view_item','data_format',0,''),(62727,20000,'120669','deals-mobile','data_format_content','##STREET_ADDRESS##, ##SUBURB##,\n##CITY##, ##POSTCODE##\nTel: ##TELEPHONE##\nEmail: ##EMAIL_ADDRESS##\n',0,''),(62728,20000,'120669','deals-mobile','font-size','14',0,''),(62729,20001,'120670','deals-mobile','block_type','6',0,''),(62730,20002,'120671','deals-mobile','text','Postcode',0,''),(62731,20002,'120671','deals-mobile','text-align','right',0,''),(62732,20003,'120672','deals-mobile','field','71',0,''),(62733,20003,'120672','deals-mobile','border-bottom-width','1',0,''),(62734,20003,'120672','deals-mobile','border-bottom-color','#000000',0,''),(62735,20003,'120672','deals-mobile','padding-left','10',0,''),(62736,20004,'120673','deals-mobile','block_type','6',0,''),(62737,20005,'120674','deals-mobile','text','Business Name',0,''),(62738,20005,'120674','deals-mobile','text-align','right',0,''),(62739,20006,'120675','deals-mobile','field','68',0,''),(62740,20006,'120675','deals-mobile','border-bottom-width','1',0,''),(62741,20006,'120675','deals-mobile','border-bottom-color','#000000',0,''),(62742,20006,'120675','deals-mobile','padding-left','10',0,''),(62743,20007,'120676','deals-mobile','block_type','6',0,''),(62744,20007,'120676','deals-mobile','padding-bottom','20',0,''),(62745,20008,'120677','deals-mobile','text','Nature of Business',0,''),(62746,20008,'120677','deals-mobile','text-align','right',0,''),(62747,20009,'120678','deals-mobile','field','52',0,''),(62748,20009,'120678','deals-mobile','border-bottom-width','1',0,''),(62749,20009,'120678','deals-mobile','border-bottom-color','#000000',0,''),(62750,20009,'120678','deals-mobile','padding-left','10',0,''),(62751,20010,'120679','deals-mobile','block_type','6',0,''),(62752,20011,'120680','deals-mobile','text','Bank Name',0,''),(62753,20011,'120680','deals-mobile','text-align','right',0,''),(62754,20011,'120680','deals-mobile','font-size','16',0,''),(62755,20012,'120681','deals-mobile','field','53',0,''),(62756,20012,'120681','deals-mobile','border-bottom-width','1',0,''),(62757,20012,'120681','deals-mobile','border-bottom-color','#000000',0,''),(62758,20012,'120681','deals-mobile','padding-left','10',0,''),(62759,20013,'120682','deals-mobile','block_type','1',0,''),(62760,20013,'120682','deals-mobile','padding-top','20',0,''),(62761,20013,'120682','deals-mobile','padding-bottom','10',0,''),(62762,20014,'120683','deals-mobile','background-color','#000000',0,''),(62763,20014,'120683','deals-mobile','color','#ffffff',0,''),(62764,20014,'120683','deals-mobile','font-size','20',0,''),(62765,20014,'120683','deals-mobile','text','Discount (%)',0,''),(62766,20014,'120683','deals-mobile','padding-left','10',0,''),(62767,20014,'120683','deals-mobile','padding-right','10',0,''),(62768,20015,'120684','deals-mobile','block_type','1',0,''),(62769,20015,'120684','deals-mobile','padding-bottom','10',0,''),(62770,20016,'120685','deals-mobile','background-color','#000000',0,''),(62771,20016,'120685','deals-mobile','color','#ffffff',0,''),(62772,20016,'120685','deals-mobile','font-size','20',0,''),(62773,20016,'120685','deals-mobile','text','Bank Account Details',0,''),(62774,20016,'120685','deals-mobile','padding-left','10',0,''),(62775,20016,'120685','deals-mobile','padding-right','10',0,''),(62776,20017,'120686','deals-mobile','block_type','6',0,''),(62777,20017,'120686','deals-mobile','padding-bottom','20',0,''),(62778,20018,'120687','deals-mobile','text','Account No',0,''),(62779,20018,'120687','deals-mobile','text-align','right',0,''),(62780,20019,'120688','deals-mobile','field','54',0,''),(62781,20019,'120688','deals-mobile','border-bottom-width','1',0,''),(62782,20019,'120688','deals-mobile','border-bottom-color','#000000',0,''),(62783,20019,'120688','deals-mobile','padding-left','10',0,''),(62784,20020,'120689','deals-mobile','block_type','6',0,''),(62785,20021,'120690','deals-mobile','text','Address',0,''),(62786,20021,'120690','deals-mobile','text-align','right',0,''),(62787,20022,'120691','deals-mobile','field','55',0,''),(62788,20022,'120691','deals-mobile','border-bottom-width','1',0,''),(62789,20022,'120691','deals-mobile','border-bottom-color','#000000',0,''),(62790,20022,'120691','deals-mobile','padding-left','10',0,''),(62791,20023,'120692','deals-mobile','block_type','14',0,''),(62792,20023,'120692','deals-mobile','padding-bottom','20',0,''),(62793,20024,'120693','deals-mobile','text','33.33% Sale or Return',0,''),(62794,20024,'120693','deals-mobile','text-align','right',0,''),(62795,20024,'120693','deals-mobile','font-size','16',0,''),(62796,20025,'120694','deals-mobile','block_type','13',0,''),(62797,20026,'120695','deals-mobile','field','56',0,''),(62798,20026,'120695','deals-mobile','padding-left','10',0,''),(62799,20027,'120696','deals-mobile','text','35% Firm',0,''),(62800,20027,'120696','deals-mobile','text-align','right',0,''),(62801,20028,'120697','deals-mobile','field','58',0,''),(62802,20028,'120697','deals-mobile','padding-left','10',0,''),(62803,20029,'120698','deals-mobile','block_type','10',0,''),(62804,20030,'120699','deals-mobile','block_type','6',0,''),(62805,20031,'120700','deals-mobile','text','Address',0,''),(62806,20031,'120700','deals-mobile','text-align','right',0,''),(62807,20032,'120701','deals-mobile','field','61',0,''),(62808,20032,'120701','deals-mobile','border-bottom-width','1',0,''),(62809,20032,'120701','deals-mobile','border-bottom-color','#000000',0,''),(62810,20032,'120701','deals-mobile','padding-left','10',0,''),(62811,20033,'120702','deals-mobile','block_type','1',0,''),(62812,20033,'120702','deals-mobile','padding-bottom','10',0,''),(62813,20034,'120703','deals-mobile','background-color','#000000',0,''),(62814,20034,'120703','deals-mobile','color','#ffffff',0,''),(62815,20034,'120703','deals-mobile','font-size','20',0,''),(62816,20034,'120703','deals-mobile','text','Trade References',0,''),(62817,20034,'120703','deals-mobile','padding-left','10',0,''),(62818,20034,'120703','deals-mobile','padding-right','10',0,''),(62819,20035,'120704','deals-mobile','block_type','1',0,''),(62820,20036,'120705','deals-mobile','text','I would like to open a trade account with Vladislav B. Malyshev and agree to abide by their General Terms & Conditions –\na signed copy of which is returned to them with this form in the supplied SAE. I have retained a copy for my reference. I\nam authorised to sign on behalf of the company I represent.',0,''),(62821,20036,'120705','deals-mobile','font-size','15',0,''),(62822,20036,'120705','deals-mobile','padding-left','10',0,''),(62823,20036,'120705','deals-mobile','padding-right','10',0,''),(62824,20037,'120706','deals-mobile','block_type','6',0,''),(62825,20037,'120706','deals-mobile','padding-bottom','20',0,''),(62826,20038,'120707','deals-mobile','text','Telephone No.',0,''),(62827,20038,'120707','deals-mobile','text-align','right',0,''),(62828,20039,'120708','deals-mobile','field','62',0,''),(62829,20039,'120708','deals-mobile','border-bottom-width','1',0,''),(62830,20039,'120708','deals-mobile','border-bottom-color','#000000',0,''),(62831,20039,'120708','deals-mobile','padding-left','10',0,''),(62832,20040,'120709','deals-mobile','block_type','1',0,''),(62833,20040,'120709','deals-mobile','padding-bottom','10',0,''),(62834,20041,'120710','deals-mobile','background-color','#000000',0,''),(62835,20041,'120710','deals-mobile','color','#ffffff',0,''),(62836,20041,'120710','deals-mobile','font-size','20',0,''),(62837,20041,'120710','deals-mobile','text','Customer Details',0,''),(62838,20041,'120710','deals-mobile','padding-left','10',0,''),(62839,20041,'120710','deals-mobile','padding-right','10',0,''),(62840,20042,'120711','deals-mobile','block_type','6',0,''),(62841,20043,'120712','deals-mobile','text','Name',0,''),(62842,20043,'120712','deals-mobile','text-align','right',0,''),(62843,20043,'120712','deals-mobile','font-size','16',0,''),(62844,20044,'120713','deals-mobile','field','60',0,''),(62845,20044,'120713','deals-mobile','border-bottom-width','1',0,''),(62846,20044,'120713','deals-mobile','border-bottom-color','#000000',0,''),(62847,20044,'120713','deals-mobile','padding-left','10',0,''),(62848,20045,'120714','deals-mobile','block_type','14',0,''),(62849,20046,'120715','deals-mobile','text','Signed',0,''),(62850,20046,'120715','deals-mobile','text-align','right',0,''),(62851,20047,'120716','deals-mobile','text','&nbsp;',0,''),(62852,20047,'120716','deals-mobile','border-bottom-width','1',0,''),(62853,20047,'120716','deals-mobile','border-bottom-color','#000000',0,''),(62854,20048,'120717','deals-mobile','text','Date',0,''),(62855,20048,'120717','deals-mobile','text-align','right',0,''),(62856,20049,'120718','deals-mobile','text','&nbsp;',0,''),(62857,20049,'120718','deals-mobile','border-bottom-width','1',0,''),(62858,20049,'120718','deals-mobile','border-bottom-color','#000000',0,''),(62859,20050,'120719','deals-mobile','block_type','14',0,''),(62860,20051,'120720','deals-mobile','text','Name in Full',0,''),(62861,20051,'120720','deals-mobile','text-align','right',0,''),(62862,20052,'120721','deals-mobile','field','66',0,''),(62863,20052,'120721','deals-mobile','padding-left','10',0,''),(62864,20052,'120721','deals-mobile','border-bottom-width','1',0,''),(62865,20052,'120721','deals-mobile','border-bottom-color','#000000',0,''),(62866,20053,'120722','deals-mobile','text','Position',0,''),(62867,20053,'120722','deals-mobile','text-align','right',0,''),(62868,20054,'120723','deals-mobile','field','67',0,''),(62869,20054,'120723','deals-mobile','border-bottom-width','1',0,''),(62870,20054,'120723','deals-mobile','border-bottom-color','#000000',0,''),(62871,20054,'120723','deals-mobile','padding-left','10',0,''),(62872,20055,'120724','deals-mobile','block_type','1',0,''),(62873,20056,'120725','deals-mobile','text','Scottish books of exceptional value',0,''),(62874,20056,'120725','deals-mobile','font-size','20',0,''),(62875,20056,'120725','deals-mobile','text-align','center',0,''),(62876,20056,'120725','deals-mobile','padding-top','20',0,''),(62877,20057,'120726','deals-mobile','block_type','1',0,''),(62878,20058,'120727','deals-mobile','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(62879,20058,'120727','deals-mobile','padding-top','100',0,''),(62880,20058,'120727','deals-mobile','margin-bottom','100',0,''),(62881,20058,'120727','deals-mobile','text-align','center',0,''),(62882,20058,'120727','deals-mobile','font-size','20',0,''),(62883,20059,'120728','deals-mobile','block_type','1',0,''),(62884,20059,'120728','deals-mobile','background-color','#eeeeee',0,''),(62885,20059,'120728','deals-mobile','padding-bottom','30',0,''),(62886,20060,'120729','deals-mobile','block_type','4',0,''),(62887,20060,'120729','deals-mobile','schema','4-2',0,''),(62888,20061,'120730','deals-mobile','block_type','1',0,''),(62889,20061,'120730','deals-mobile','padding-right','40',0,''),(62891,20062,'120731','deals-mobile','block_type','2',0,''),(62892,20062,'120731','deals-mobile','margin-bottom','20',0,''),(62893,20062,'120731','deals-mobile','schema','2-2',0,''),(62894,20062,'120731','deals-mobile','background-color','#ffffff',0,''),(62895,20063,'120732','deals-mobile','block_type','1',0,''),(62896,20063,'120732','deals-mobile','border-right-width','20',0,''),(62897,20063,'120732','deals-mobile','border-right-color','#e0e0e0',0,''),(62898,20063,'120732','deals-mobile','margin-right','-10',0,''),(62899,20063,'120732','deals-mobile','padding-right','30',0,''),(62900,20063,'120732','deals-mobile','padding-top','20',0,''),(62901,20063,'120732','deals-mobile','padding-left','30',0,''),(62902,20063,'120732','deals-mobile','padding-bottom','20',0,''),(62905,20063,'120732','deals-mobile','margin-bottom','20',0,''),(62908,20064,'120733','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(62909,20064,'120733','deals-mobile','clear','none',0,''),(62910,20065,'120734','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(62911,20065,'120734','deals-mobile','clear','none',0,''),(62912,20066,'120735','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(62913,20068,'120737','deals-mobile','margin-bottom','20',0,''),(62914,20072,'120741','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(62915,20072,'120741','deals-mobile','padding-top','20',0,''),(62916,20073,'120742','deals-mobile','block_type','1',0,''),(62917,20073,'120742','deals-mobile','padding-left','30',0,''),(62918,20073,'120742','deals-mobile','border-left-width','20',0,''),(62919,20073,'120742','deals-mobile','border-left-color','#e0e0e0',0,''),(62920,20073,'120742','deals-mobile','margin-left','-10',0,''),(62921,20073,'120742','deals-mobile','padding-right','30',0,''),(62922,20073,'120742','deals-mobile','padding-top','20',0,''),(62923,20073,'120742','deals-mobile','padding-bottom','20',0,''),(62925,20074,'120743','deals-mobile','margin-bottom','20',0,''),(62926,20076,'120745','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(62927,20077,'120746','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(62928,20077,'120746','deals-mobile','clear','none',0,''),(62929,20078,'120747','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(62930,20078,'120747','deals-mobile','clear','none',0,''),(62931,20079,'120748','deals-mobile','block_type','1',0,''),(62932,20079,'120748','deals-mobile','padding-right','30',0,''),(62933,20079,'120748','deals-mobile','background-color','#ffffff',0,''),(62934,20079,'120748','deals-mobile','padding-top','20',0,''),(62935,20079,'120748','deals-mobile','padding-left','30',0,''),(62936,20079,'120748','deals-mobile','padding-bottom','20',0,''),(62939,20081,'120750','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(62940,20082,'120751','deals-mobile','block_type','1',0,''),(62941,20082,'120751','deals-mobile','padding-top','20',0,''),(62942,20082,'120751','deals-mobile','padding-left','20',0,''),(62943,20082,'120751','deals-mobile','padding-right','20',0,''),(62944,20082,'120751','deals-mobile','padding-bottom','20',0,''),(62945,20082,'120751','deals-mobile','background-color','#ffffff',0,''),(62946,20082,'120751','deals-mobile','style_class','order-summary',0,''),(62947,20083,'120752','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(62948,20087,'120756','deals-mobile','block_type','1',0,''),(62949,20087,'120756','deals-mobile','background-color','#eeeeee',0,''),(62950,20087,'120756','deals-mobile','padding-bottom','30',0,''),(62951,20088,'120757','deals-mobile','block_type','4',0,''),(62952,20088,'120757','deals-mobile','schema','4-2',0,''),(62953,20089,'120758','deals-mobile','block_type','1',0,''),(62954,20089,'120758','deals-mobile','padding-right','40',0,''),(62956,20090,'120759','deals-mobile','block_type','1',0,''),(62957,20090,'120759','deals-mobile','padding-right','30',0,''),(62958,20090,'120759','deals-mobile','background-color','#ffffff',0,''),(62959,20090,'120759','deals-mobile','padding-top','20',0,''),(62960,20090,'120759','deals-mobile','padding-left','30',0,''),(62961,20090,'120759','deals-mobile','padding-bottom','20',0,''),(62964,20091,'120760','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(62965,20093,'120762','deals-mobile','block_type','2',0,''),(62966,20093,'120762','deals-mobile','margin-bottom','20',0,''),(62967,20093,'120762','deals-mobile','schema','2-2',0,''),(62968,20093,'120762','deals-mobile','background-color','#ffffff',0,''),(62969,20094,'120763','deals-mobile','block_type','1',0,''),(62970,20094,'120763','deals-mobile','border-right-width','20',0,''),(62971,20094,'120763','deals-mobile','border-right-color','#e0e0e0',0,''),(62972,20094,'120763','deals-mobile','margin-right','-10',0,''),(62973,20094,'120763','deals-mobile','padding-right','30',0,''),(62974,20094,'120763','deals-mobile','padding-top','20',0,''),(62975,20094,'120763','deals-mobile','padding-left','30',0,''),(62976,20094,'120763','deals-mobile','padding-bottom','20',0,''),(62979,20094,'120763','deals-mobile','margin-bottom','20',0,''),(62982,20097,'120766','deals-mobile','margin-bottom','20',0,''),(62983,20098,'120767','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(62984,20098,'120767','deals-mobile','padding-top','20',0,''),(62985,20100,'120769','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(62986,20100,'120769','deals-mobile','clear','none',0,''),(62987,20102,'120771','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(62988,20102,'120771','deals-mobile','clear','none',0,''),(62989,20103,'120772','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(62990,20104,'120773','deals-mobile','block_type','1',0,''),(62991,20104,'120773','deals-mobile','padding-left','30',0,''),(62992,20104,'120773','deals-mobile','border-left-width','20',0,''),(62993,20104,'120773','deals-mobile','border-left-color','#e0e0e0',0,''),(62994,20104,'120773','deals-mobile','margin-left','-10',0,''),(62995,20104,'120773','deals-mobile','padding-right','30',0,''),(62996,20104,'120773','deals-mobile','padding-top','20',0,''),(62997,20104,'120773','deals-mobile','padding-bottom','20',0,''),(62999,20105,'120774','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(63000,20105,'120774','deals-mobile','clear','none',0,''),(63001,20106,'120775','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(63002,20107,'120776','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(63003,20107,'120776','deals-mobile','clear','none',0,''),(63004,20108,'120777','deals-mobile','margin-bottom','20',0,''),(63005,20110,'120779','deals-mobile','block_type','1',0,''),(63006,20110,'120779','deals-mobile','padding-top','20',0,''),(63007,20110,'120779','deals-mobile','padding-left','20',0,''),(63008,20110,'120779','deals-mobile','padding-right','20',0,''),(63009,20110,'120779','deals-mobile','padding-bottom','20',0,''),(63010,20110,'120779','deals-mobile','background-color','#ffffff',0,''),(63011,20110,'120779','deals-mobile','style_class','order-summary',0,''),(63012,20112,'120781','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(63013,20115,'120784','deals-mobile','block_type','1',0,''),(63014,20115,'120784','deals-mobile','background_image','themes/deals-mobile/img/wedding-registry-page-1-1.jpg',0,''),(63015,20115,'120784','deals-mobile','background-position','top center',0,''),(63016,20115,'120784','deals-mobile','background-repeat','no-repeat',0,''),(63017,20115,'120784','deals-mobile','background-size','cover',0,''),(63018,20115,'120784','deals-mobile','padding-top','50',0,''),(63019,20115,'120784','deals-mobile','padding-bottom','50',0,''),(63020,20115,'120784','deals-mobile','margin-bottom','30',0,''),(63021,20116,'120785','deals-mobile','background-color','#ffffff',0,''),(63022,20116,'120785','deals-mobile','block_type','1',0,''),(63023,20116,'120785','deals-mobile','max-width','700',0,''),(63024,20116,'120785','deals-mobile','margin_left_measure','auto',0,''),(63025,20116,'120785','deals-mobile','margin_right_measure','auto',0,''),(63026,20117,'120786','deals-mobile','text-align','center',0,''),(63027,20117,'120786','deals-mobile','margin-bottom','30',0,''),(63028,20118,'120787','deals-mobile','padding-bottom','30',0,''),(63029,20118,'120787','deals-mobile','text-align','center',0,''),(63030,20119,'120788','deals-mobile','heading_type','h1',0,''),(63031,20120,'120789','deals-mobile','block_type','13',0,''),(63032,20120,'120789','deals-mobile','margin-bottom','20',0,''),(63033,20120,'120789','deals-mobile','schema','13-2',0,''),(63034,20121,'120790','deals-mobile','position','relative',0,''),(63035,20121,'120790','deals-mobile','margin-top','-100',0,''),(63037,20122,'120791','deals-mobile','font-family','Varela Round',0,''),(63038,20122,'120791','deals-mobile','font-size','30',0,''),(63039,20122,'120791','deals-mobile','text-transform','uppercase',0,''),(63040,20122,'120791','deals-mobile','text-align','center',0,''),(63042,20123,'120792','deals-mobile','block_type','1',0,''),(63043,20123,'120792','deals-mobile','float','left',0,''),(63045,20124,'120793','deals-mobile','display','inline-block',0,''),(63046,20124,'120793','deals-mobile','font-weight','700',0,''),(63047,20125,'120794','deals-mobile','clear','none',0,''),(63048,20125,'120794','deals-mobile','padding-left','20',0,''),(63049,20125,'120794','deals-mobile','font-weight','700',0,''),(63050,20125,'120794','deals-mobile','display','inline-block',0,''),(63051,20126,'120795','deals-mobile','font-weight','700',0,''),(63052,20126,'120795','deals-mobile','clear','none',0,''),(63053,20126,'120795','deals-mobile','padding-left','20',0,''),(63054,20126,'120795','deals-mobile','display','inline-block',0,''),(63055,20127,'120796','deals-mobile','font-family','Varela Round',0,''),(63056,20127,'120796','deals-mobile','font-size','18',0,''),(63057,20127,'120796','deals-mobile','margin-bottom','10',0,''),(63058,20127,'120796','deals-mobile','text-align','center',0,''),(63059,20128,'120797','deals-mobile','font-weight','700',0,''),(63060,20128,'120797','deals-mobile','text-align','right',0,''),(63061,20128,'120797','deals-mobile','max-width','110',0,''),(63062,20128,'120797','deals-mobile','float','right',0,''),(63063,20129,'120798','deals-mobile','margin-bottom','10',0,''),(63064,20130,'120799','deals-mobile','like_button','1',0,''),(63065,20130,'120799','deals-mobile','text-align','center',0,''),(63066,20130,'120799','deals-mobile','margin-bottom','20',0,''),(63067,20130,'120799','deals-mobile','margin-top','20',0,''),(63068,20130,'120799','deals-mobile','padding-top','30',0,''),(63069,20130,'120799','deals-mobile','border-top-width','1',0,''),(63070,20130,'120799','deals-mobile','border-top-color','#e0e0e0',0,''),(63078,20135,'120804','deals-mobile','block_type','1',0,''),(63079,20135,'120804','deals-mobile','padding-top','20',0,''),(63080,20135,'120804','deals-mobile','padding-bottom','20',0,''),(63081,20137,'120806','deals-mobile','padding-top','10',0,''),(63082,20137,'120806','deals-mobile','padding-bottom','10',0,''),(63083,20137,'120806','deals-mobile','border-top-width','1',0,''),(63084,20137,'120806','deals-mobile','border-top-color','#e0e0e0',0,''),(63085,20137,'120806','deals-mobile','text-align','right',0,''),(63086,20138,'120807','deals-mobile','block_type','1',0,''),(63087,20138,'120807','deals-mobile','border-top-width','1',0,''),(63088,20138,'120807','deals-mobile','border-left-width','1',0,''),(63089,20138,'120807','deals-mobile','border-right-width','1',0,''),(63090,20138,'120807','deals-mobile','border-bottom-width','1',0,''),(63091,20138,'120807','deals-mobile','border-top-color','#e0e0e0',0,''),(63092,20138,'120807','deals-mobile','border-left-color','#e0e0e0',0,''),(63093,20138,'120807','deals-mobile','border-right-color','#e0e0e0',0,''),(63094,20138,'120807','deals-mobile','border-bottom-color','#e0e0e0',0,''),(63095,20138,'120807','deals-mobile','padding-top','15',0,''),(63096,20138,'120807','deals-mobile','padding-left','15',0,''),(63097,20138,'120807','deals-mobile','padding-right','15',0,''),(63098,20138,'120807','deals-mobile','padding-bottom','15',0,''),(63099,20138,'120807','deals-mobile','margin-bottom','50',0,''),(63100,20139,'120808','deals-mobile','block_type','1',0,''),(63101,20139,'120808','deals-mobile','padding-top','20',0,''),(63102,20139,'120808','deals-mobile','padding-left','20',0,''),(63103,20139,'120808','deals-mobile','padding-right','20',0,''),(63104,20139,'120808','deals-mobile','background-color','#ffffff',0,''),(63105,20141,'120810','deals-mobile','text','<h1>##FIND_REGISTRY##</h1>',0,''),(63106,20142,'120811','deals-mobile','block_type','1',0,''),(63107,20143,'120812','deals-mobile','block_type','8',0,''),(63108,20143,'120812','deals-mobile','schema','8-6',0,''),(63109,20144,'120813','deals-mobile','text','<div class=\"heading-3\">##INVITE_GUESTS##</div>',0,''),(63110,20145,'120814','deals-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_PERSONALIZED_URL##</div>',0,''),(63111,20146,'120815','deals-mobile','margin-bottom','30',0,''),(63112,20149,'120818','deals-mobile','margin-top','-100',0,''),(63113,20150,'120819','deals-mobile','text','<h1>##SHARE_YOUR_WEDDING_REGISTRY##</h1>',0,''),(63114,20150,'120819','deals-mobile','margin-top','-80',0,''),(63116,20151,'120820','deals-mobile','text','<h1>##CREATE_WR_SUCCESS_MESSAGE##</h1>',0,''),(63117,20153,'120822','deals-mobile','block_type','2',0,''),(63118,20153,'120822','deals-mobile','schema','2-2',0,''),(63119,20154,'120823','deals-mobile','block_type','1',0,''),(63120,20154,'120823','deals-mobile','padding-right','15',0,''),(63122,20155,'120824','deals-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_REGISTRY##</div>',0,''),(63123,20156,'120825','deals-mobile','text','<div class=\"heading-3\">##TEXT_WEDDING_DETAILS##</div>',0,''),(63124,20157,'120826','deals-mobile','margin-bottom','20',0,''),(63125,20158,'120827','deals-mobile','margin-bottom','20',0,''),(63126,20159,'120828','deals-mobile','text','<div class=\"heading-3\">##TEXT_NAMES##</div>',0,''),(63127,20160,'120829','deals-mobile','padding-bottom','20',0,''),(63128,20161,'120830','deals-mobile','block_type','1',0,''),(63129,20161,'120830','deals-mobile','padding-left','15',0,''),(63131,20162,'120831','deals-mobile','margin-bottom','20',0,''),(63132,20163,'120832','deals-mobile','text','<div class=\"heading-3\">##TEXT_SHIPPING_DETAILS##</div>',0,''),(63133,20164,'120833','deals-mobile','text','<div class=\"heading-3\">##UPLOAD_PHOTO##</div>',0,''),(63134,20165,'120834','deals-mobile','margin-bottom','20',0,''),(63135,20165,'120834','deals-mobile','padding-left','1',0,''),(63136,20166,'120835','deals-mobile','text','<div class=\"heading-3\">##TEXT_ADDITIONAL_INFORMATION##</div>',0,''),(63137,20167,'120836','deals-mobile','margin-bottom','20',0,''),(63138,20168,'120837','deals-mobile','text','<h1>##WEDDING_REGISTRY_FORM_HEADING##</h1>',0,''),(63139,20169,'120838','deals-mobile','block_type','2',0,''),(63140,20169,'120838','deals-mobile','margin-bottom','20',0,''),(63141,20171,'120840','deals-mobile','text-align','right',0,''),(63142,20173,'120842','deals-mobile','block_type','13',0,''),(63143,20173,'120842','deals-mobile','margin-bottom','20',0,''),(63144,20174,'120843','deals-mobile','position','relative',0,''),(63145,20174,'120843','deals-mobile','margin-top','-100',0,''),(63146,20175,'120844','deals-mobile','font-family','Varela Round',0,''),(63147,20175,'120844','deals-mobile','font-size','18',0,''),(63148,20175,'120844','deals-mobile','margin-bottom','10',0,''),(63149,20176,'120845','deals-mobile','font-family','Varela Round',0,''),(63150,20176,'120845','deals-mobile','font-size','30',0,''),(63151,20176,'120845','deals-mobile','text-transform','uppercase',0,''),(63152,20177,'120846','deals-mobile','font-weight','700',0,''),(63153,20177,'120846','deals-mobile','text-align','right',0,''),(63154,20179,'120848','deals-mobile','block_type','1',0,''),(63155,20180,'120849','deals-mobile','block_type','6',0,''),(63156,20180,'120849','deals-mobile','schema','6-3',0,''),(63157,20181,'120850','deals-mobile','aria_name','account-menu',0,''),(63158,20182,'120851','deals-mobile','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(63159,20183,'120852','deals-mobile','margin-bottom','20',0,''),(63160,20184,'120853','deals-mobile','block_type','1',0,''),(63161,20184,'120853','deals-mobile','padding-top','20',0,''),(63162,20184,'120853','deals-mobile','padding-bottom','20',0,''),(63163,20186,'120855','deals-mobile','padding-top','20',0,''),(63164,20186,'120855','deals-mobile','padding-bottom','20',0,''),(99209,3156,'115990','watch-mobile','margin-left','0',0,'291'),(114043,3023,'94911','watch-mobile','style_class','account-index',0,''),(114044,3071,'94959','watch-mobile','style_class','account-address-book',0,''),(114045,3076,'94964','watch-mobile','style_class','account-address-book-process',0,''),(114046,3065,'94953','watch-mobile','style_class','account-edit-wrap',0,''),(114047,4369,'114698','watch-mobile','style_class','account-order-history',0,''),(114048,4374,'114703','watch-mobile','style_class','account-order-history-info',0,''),(114049,4414,'114743','watch-mobile','style_class','account-order-pay',0,''),(114050,4316,'114645','watch-mobile','style_class','account-password-wrap',0,''),(114051,4806,'115009','watch-mobile','style_class','account-samples',0,''),(114052,4841,'115715','watch-mobile','style_class','account-sample-info',0,''),(114053,4520,'75821','watch-mobile','style_class','catalog-product-wrap',0,''),(114054,3989,'75625','watch-mobile','style_class','checkout-order-confirmation',0,''),(114055,3677,'114155','watch-mobile','style_class','checkout-order-confirmation',0,''),(114059,36640,'1693578529.207944','watch-mobile','background-color','$background-6',0,''),(114060,36640,'1693578529.207944','watch-mobile','padding-top','30',0,''),(114061,36640,'1693578529.207944','watch-mobile','padding-bottom','30',0,''),(114062,36640,'1693578529.207944','watch-mobile','style_class','checkout-index-wrap',0,''),(114063,36641,'1693578529.311699','watch-mobile','block_type','2',0,''),(114064,36641,'1693578529.311699','watch-mobile','schema','4-2',0,'1314'),(114065,36641,'1693578529.311699','watch-mobile','style_class','checkoutDoubleBox',0,''),(114066,36642,'1693578529.313831','watch-mobile','block_type','1',0,''),(114067,36642,'1693578529.313831','watch-mobile','padding-right','40',0,''),(114068,36642,'1693578529.313831','watch-mobile','padding-right','0',0,'1314'),(114069,36643,'1693578529.315461','watch-mobile','block_type','1',0,''),(114070,36643,'1693578529.315461','watch-mobile','background-color','$background-7',0,''),(114071,36643,'1693578529.315461','watch-mobile','padding-top','30',0,''),(114072,36643,'1693578529.315461','watch-mobile','padding-left','30',0,''),(114073,36643,'1693578529.315461','watch-mobile','padding-right','30',0,''),(114074,36643,'1693578529.315461','watch-mobile','padding-bottom','30',0,''),(114075,36643,'1693578529.315461','watch-mobile','margin-bottom','20',0,''),(114076,36643,'1693578529.315461','watch-mobile','style_class','hiding-box closeable-box',0,''),(114077,36644,'1693578529.317368','watch-mobile','style_class','closeable-content',0,''),(114078,36644,'1693578529.317368','watch-mobile','padding-bottom','20',0,''),(114079,36645,'1693578529.319136','watch-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(114080,36645,'1693578529.319136','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(114081,36646,'1693578529.322437','watch-mobile','block_type','1',0,''),(114082,36646,'1693578529.322437','watch-mobile','padding-top','30',0,''),(114083,36646,'1693578529.322437','watch-mobile','padding-left','30',0,''),(114084,36646,'1693578529.322437','watch-mobile','padding-right','30',0,''),(114085,36646,'1693578529.322437','watch-mobile','padding-bottom','30',0,''),(114086,36646,'1693578529.322437','watch-mobile','margin-bottom','20',0,''),(114087,36646,'1693578529.322437','watch-mobile','background-color','$background-7',0,''),(114088,36646,'1693578529.322437','watch-mobile','style_class','hiding-box closeable-box',0,''),(114089,36647,'1693578529.324468','watch-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(114090,36647,'1693578529.324468','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(114091,36648,'1693578529.325521','watch-mobile','block_type','2',0,''),(114092,36648,'1693578529.325521','watch-mobile','style_class','closeable-content',0,''),(114093,36648,'1693578529.325521','watch-mobile','schema','2-2',0,'1314'),(114094,36649,'1693578529.326795','watch-mobile','padding-right','20',0,''),(114095,36649,'1693578529.326795','watch-mobile','padding-bottom','20',0,''),(114096,36649,'1693578529.326795','watch-mobile','padding-right','0',0,'1314'),(114097,36650,'1693578529.329372','watch-mobile','padding-left','20',0,''),(114098,36650,'1693578529.329372','watch-mobile','padding-bottom','20',0,''),(114099,36650,'1693578529.329372','watch-mobile','padding-left','0',0,'1314'),(114100,36651,'1693578529.331582','watch-mobile','padding-left','20',0,''),(114101,36651,'1693578529.331582','watch-mobile','padding-bottom','20',0,''),(114102,36651,'1693578529.331582','watch-mobile','padding-left','0',0,'1314'),(114103,36652,'1693578529.333680','watch-mobile','background-color','$background-7',0,''),(114104,36652,'1693578529.333680','watch-mobile','block_type','1',0,''),(114105,36652,'1693578529.333680','watch-mobile','padding-top','30',0,''),(114106,36652,'1693578529.333680','watch-mobile','padding-left','30',0,''),(114107,36652,'1693578529.333680','watch-mobile','padding-right','30',0,''),(114108,36652,'1693578529.333680','watch-mobile','padding-bottom','30',0,''),(114109,36652,'1693578529.333680','watch-mobile','margin-bottom','20',0,''),(114110,36652,'1693578529.333680','watch-mobile','style_class','hiding-box',0,''),(114111,36653,'1693578529.335514','watch-mobile','block_type','1',0,''),(114112,36653,'1693578529.335514','watch-mobile','content','\\_',0,'3'),(114113,36653,'1693578529.335514','watch-mobile','border-top-width','1',0,'3'),(114114,36653,'1693578529.335514','watch-mobile','border-top-color','#e0e0e0',0,'3'),(114115,36653,'1693578529.335514','watch-mobile','display','block',0,'3'),(114116,36653,'1693578529.335514','watch-mobile','position','absolute',0,'3'),(114117,36653,'1693578529.335514','watch-mobile','top','19',0,'3'),(114118,36653,'1693578529.335514','watch-mobile','left','0',0,'3'),(114119,36653,'1693578529.335514','watch-mobile','right','0',0,'3'),(114120,36653,'1693578529.335514','watch-mobile','margin-top','-2',0,'3'),(114121,36653,'1693578529.335514','watch-mobile','position','relative',0,''),(114122,36654,'1693578529.337997','watch-mobile','box_align','2',0,''),(114123,36654,'1693578529.337997','watch-mobile','margin-bottom','10',0,''),(114124,36654,'1693578529.337997','watch-mobile','background-color','$background-7',0,''),(114125,36654,'1693578529.337997','watch-mobile','position','relative',0,''),(114126,36655,'1693578529.34334','watch-mobile','background-color','$background-6',0,''),(114127,36655,'1693578529.34334','watch-mobile','padding-top','10',0,''),(114128,36655,'1693578529.34334','watch-mobile','padding-left','10',0,''),(114129,36655,'1693578529.34334','watch-mobile','padding-right','10',0,''),(114130,36655,'1693578529.34334','watch-mobile','padding-bottom','10',0,''),(114131,36655,'1693578529.34334','watch-mobile','margin-top','10',0,''),(114132,36656,'1693578529.345418','watch-mobile','block_type','2',0,''),(114133,36656,'1693578529.345418','watch-mobile','schema','2-2',0,'1314'),(114134,36657,'1693578529.346757','watch-mobile','block_type','1',0,''),(114135,36657,'1693578529.346757','watch-mobile','padding-right','20',0,''),(114136,36657,'1693578529.346757','watch-mobile','padding-left','0',0,'1314'),(114137,36657,'1693578529.346757','watch-mobile','margin-bottom','20',0,'1314'),(114138,36657,'1693578529.346757','watch-mobile','padding-right','0',0,'1314'),(114139,36658,'1693578529.348387','watch-mobile','address_in','popup',0,''),(114140,36659,'1693578529.351498','watch-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(114141,36662,'1693578529.357732','watch-mobile','block_type','1',0,''),(114142,36662,'1693578529.357732','watch-mobile','padding-left','20',0,''),(114143,36662,'1693578529.357732','watch-mobile','padding-left','0',0,'1314'),(114144,36664,'1693578529.360426','watch-mobile','border-top-width','1',0,''),(114145,36664,'1693578529.360426','watch-mobile','border-top-color','#e0e0e0',0,''),(114146,36664,'1693578529.360426','watch-mobile','padding-top','13',0,''),(114147,36664,'1693578529.360426','watch-mobile','padding-bottom','10',0,''),(114148,36665,'1693578529.361979','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(114149,36666,'1693578529.363439','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(114150,36667,'1693578529.364794','watch-mobile','margin-bottom','20',0,''),(114151,36667,'1693578529.364794','watch-mobile','style_class','hiding-box',0,''),(114152,36668,'1693578529.368484','watch-mobile','padding-top','30',0,''),(114153,36668,'1693578529.368484','watch-mobile','padding-left','30',0,''),(114154,36668,'1693578529.368484','watch-mobile','padding-right','30',0,''),(114155,36668,'1693578529.368484','watch-mobile','margin-top','20',0,''),(114156,36668,'1693578529.368484','watch-mobile','background-color','$background-7',0,''),(114157,36668,'1693578529.368484','watch-mobile','padding-bottom','30',0,''),(114158,36668,'1693578529.368484','watch-mobile','margin-bottom','20',0,''),(114159,36669,'1693578529.371247','watch-mobile','block_type','1',0,''),(114160,36669,'1693578529.371247','watch-mobile','padding-top','30',0,''),(114161,36669,'1693578529.371247','watch-mobile','padding-left','30',0,''),(114162,36669,'1693578529.371247','watch-mobile','padding-right','30',0,''),(114163,36669,'1693578529.371247','watch-mobile','padding-bottom','23',0,''),(114164,36669,'1693578529.371247','watch-mobile','margin-bottom','20',0,''),(114165,36669,'1693578529.371247','watch-mobile','background-color','$background-7',0,''),(114166,36669,'1693578529.371247','watch-mobile','style_class','hiding-box',0,''),(114167,36670,'1693578529.373462','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(114168,36671,'1693578529.374453','watch-mobile','block_type','2',0,''),(114169,36671,'1693578529.374453','watch-mobile','schema','2-2',0,'1314'),(114170,36672,'1693578529.375760','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(114171,36673,'1693578529.376655','watch-mobile','padding-right','20',0,''),(114172,36673,'1693578529.376655','watch-mobile','padding-right','0',0,'1314'),(114173,36673,'1693578529.376655','watch-mobile','padding-bottom','20',0,'1314'),(114174,36673,'1693578529.376655','watch-mobile','address_in','popup',0,''),(114175,36674,'1693578529.380694','watch-mobile','block_type','1',0,''),(114176,36674,'1693578529.380694','watch-mobile','padding-left','20',0,''),(114177,36674,'1693578529.380694','watch-mobile','padding-left','0',0,'1314'),(114178,36676,'1693578529.383416','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(114179,36677,'1693578529.384233','watch-mobile','block_type','1',0,''),(114180,36677,'1693578529.384233','watch-mobile','padding-top','30',0,''),(114181,36677,'1693578529.384233','watch-mobile','padding-left','30',0,''),(114182,36677,'1693578529.384233','watch-mobile','padding-right','30',0,''),(114183,36677,'1693578529.384233','watch-mobile','padding-bottom','30',0,''),(114184,36677,'1693578529.384233','watch-mobile','margin-bottom','20',0,''),(114185,36677,'1693578529.384233','watch-mobile','background-color','$background-7',0,''),(114186,36680,'1693578529.387946','watch-mobile','block_type','1',0,''),(114187,36680,'1693578529.387946','watch-mobile','padding-top','20',0,''),(114188,36680,'1693578529.387946','watch-mobile','padding-left','20',0,''),(114189,36680,'1693578529.387946','watch-mobile','padding-right','20',0,''),(114190,36680,'1693578529.387946','watch-mobile','padding-bottom','20',0,''),(114191,36680,'1693578529.387946','watch-mobile','background-color','$background-7',0,''),(114192,36680,'1693578529.387946','watch-mobile','style_class','order-summary',0,''),(114193,36681,'1693578529.434121','watch-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(114194,36681,'1693578529.434121','watch-mobile','text-align','center',0,''),(114195,36681,'1693578529.434121','watch-mobile','font-size','14',0,''),(114196,36681,'1693578529.434121','watch-mobile','color','$color-font-8',0,''),(114197,36681,'1693578529.434121','watch-mobile','padding-top','10',0,''),(114198,36682,'1693578529.436482','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(114199,36683,'1693578529.437493','watch-mobile','hide_page','1',0,''),(114200,36683,'1693578529.437493','watch-mobile','hide_continue_button','1',0,''),(114201,36684,'1693578529.439185','watch-mobile','margin-bottom','10',0,''),(114202,4206,'114547','watch-mobile','style_class','checkout-login-wrap',0,''),(114203,4889,'75873','watch-mobile','style_class','checkout-success-wrap',0,''),(114204,3134,'115968','watch-mobile','style_class','shopping-cart-index',0,''),(168370,53913,'116005','furniture-mobile','text','##TEXT_PAGE_NOT_FOUND##',0,''),(168371,53913,'116005','furniture-mobile','text-align','center',0,''),(168372,53913,'116005','furniture-mobile','padding-top','100',0,''),(168373,53913,'116005','furniture-mobile','padding-bottom','100',0,''),(168374,53914,'116006','furniture-mobile','block_type','1',0,''),(168493,53930,'116022','furniture-mobile','block_type','1',0,''),(168612,53946,'116038','furniture-mobile','block_type','1',0,''),(168731,53962,'116054','furniture-mobile','block_type','1',0,''),(168850,53978,'116070','furniture-mobile','block_type','1',0,''),(168969,53994,'116086','furniture-mobile','block_type','1',0,''),(169088,54010,'116102','furniture-mobile','block_type','1',0,''),(169089,54010,'116102','furniture-mobile','style_class','account-index',0,''),(169090,54011,'116103','furniture-mobile','block_type','6',0,''),(169091,54011,'116103','furniture-mobile','schema','6-3',0,'2885'),(169092,54012,'116104','furniture-mobile','aria_name','account-menu',0,''),(169149,54032,'116105','furniture-mobile','link','Order History Info',0,''),(169150,54032,'116105','furniture-mobile','text','TEXT_VIEW',0,''),(169151,54032,'116105','furniture-mobile','max_orders','3',0,''),(169152,54032,'116105','furniture-mobile','link_pay','Order pay',0,''),(169153,54032,'116105','furniture-mobile','margin-bottom','30',0,''),(169154,54032,'116105','furniture-mobile','text_pay','ORDER_PAY',0,''),(169155,54033,'116106','furniture-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(169156,54034,'116109','furniture-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(169157,54035,'116112','furniture-mobile','block_type','15',0,''),(169158,54035,'116112','furniture-mobile','margin-bottom','30',0,''),(169159,54035,'116112','furniture-mobile','padding-top','20',0,''),(169160,54035,'116112','furniture-mobile','padding-left','20',0,''),(169161,54035,'116112','furniture-mobile','padding-right','20',0,''),(169162,54035,'116112','furniture-mobile','padding-bottom','20',0,''),(169163,54035,'116112','furniture-mobile','border-top-width','1',0,''),(169164,54035,'116112','furniture-mobile','border-top-color','$border-color-4',0,''),(169165,54035,'116112','furniture-mobile','border-left-width','1',0,''),(169166,54035,'116112','furniture-mobile','border-right-width','1',0,''),(169167,54035,'116112','furniture-mobile','border-bottom-width','1',0,''),(169168,54035,'116112','furniture-mobile','border-left-color','$border-color-4',0,''),(169169,54035,'116112','furniture-mobile','border-right-color','$border-color-4',0,''),(169170,54035,'116112','furniture-mobile','border-bottom-color','$border-color-4',0,''),(169171,54035,'116112','furniture-mobile','schema','15-3',0,'2885'),(169172,54036,'116113','furniture-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(169173,54036,'116113','furniture-mobile','font-family','trueloaded',0,'3'),(169174,54036,'116113','furniture-mobile','content','\\e920',0,'3'),(169175,54036,'116113','furniture-mobile','color','$attention-color',0,'3'),(169176,54036,'116113','furniture-mobile','font-size','30',0,'3'),(169177,54036,'116113','furniture-mobile','text-align','center',0,'3'),(169178,54036,'116113','furniture-mobile','margin-bottom','10',0,'3'),(169179,54036,'116113','furniture-mobile','text-align','center',0,''),(169180,54036,'116113','furniture-mobile','font-size','16',0,''),(169181,54036,'116113','furniture-mobile','text-transform','uppercase',0,''),(169182,54036,'116113','furniture-mobile','line-height','1',0,'3'),(169183,54036,'116113','furniture-mobile','font-size','14',0,'2876'),(169184,54037,'116114','furniture-mobile','font-family','$font-1',0,''),(169185,54037,'116114','furniture-mobile','color','$attention-color',0,''),(169186,54037,'116114','furniture-mobile','font-size','14',0,''),(169187,54037,'116114','furniture-mobile','text-align','center',0,''),(169188,54038,'116115','furniture-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(169189,54038,'116115','furniture-mobile','font-family','trueloaded',0,'3'),(169190,54038,'116115','furniture-mobile','content','\\e928',0,'3'),(169191,54038,'116115','furniture-mobile','color','$attention-color',0,'3'),(169192,54038,'116115','furniture-mobile','font-size','30',0,'3'),(169193,54038,'116115','furniture-mobile','text-align','center',0,'3'),(169194,54038,'116115','furniture-mobile','text-align','center',0,''),(169195,54038,'116115','furniture-mobile','font-size','16',0,''),(169196,54038,'116115','furniture-mobile','text-transform','uppercase',0,''),(169197,54038,'116115','furniture-mobile','line-height','1',0,'3'),(169198,54038,'116115','furniture-mobile','font-size','14',0,'2876'),(169199,54039,'116116','furniture-mobile','font-family','$font-1',0,''),(169200,54039,'116116','furniture-mobile','color','$attention-color',0,''),(169201,54039,'116116','furniture-mobile','font-size','14',0,''),(169202,54039,'116116','furniture-mobile','text-align','center',0,''),(169203,54040,'116117','furniture-mobile','link','download_orders',0,''),(169204,54040,'116117','furniture-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(169205,54040,'116117','furniture-mobile','hide_link','orders',0,''),(169206,54040,'116117','furniture-mobile','text-align','center',0,''),(169207,54040,'116117','furniture-mobile','popup','2',0,''),(169208,54040,'116117','furniture-mobile','font-size','14',0,''),(169209,54041,'116118','furniture-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(169210,54041,'116118','furniture-mobile','font-family','trueloaded',0,'3'),(169211,54041,'116118','furniture-mobile','content','\\e922',0,'3'),(169212,54041,'116118','furniture-mobile','color','$attention-color',0,'3'),(169213,54041,'116118','furniture-mobile','font-size','30',0,'3'),(169214,54041,'116118','furniture-mobile','line-height','1',0,'3'),(169215,54041,'116118','furniture-mobile','font-size','16',0,''),(169216,54041,'116118','furniture-mobile','text-align','center',0,''),(169217,54041,'116118','furniture-mobile','text-transform','uppercase',0,''),(169218,54041,'116118','furniture-mobile','font-size','14',0,'2876'),(169219,54042,'116119','furniture-mobile','font-family','$font-1',0,''),(169220,54042,'116119','furniture-mobile','color','$attention-color',0,''),(169221,54042,'116119','furniture-mobile','line-height','1',0,''),(169222,54042,'116119','furniture-mobile','text-align','center',0,''),(169223,54042,'116119','furniture-mobile','font-size','14',0,''),(169224,54043,'116120','furniture-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(169225,54043,'116120','furniture-mobile','content','\\e994',0,'3'),(169226,54043,'116120','furniture-mobile','font-family','trueloaded',0,'3'),(169227,54043,'116120','furniture-mobile','color','$attention-color',0,'3'),(169228,54043,'116120','furniture-mobile','font-size','30',0,'3'),(169229,54043,'116120','furniture-mobile','line-height','1',0,'3'),(169230,54043,'116120','furniture-mobile','font-size','16',0,''),(169231,54043,'116120','furniture-mobile','text-align','center',0,''),(169232,54043,'116120','furniture-mobile','text-transform','uppercase',0,''),(169233,54043,'116120','furniture-mobile','font-size','14',0,'2876'),(169234,54044,'116121','furniture-mobile','font-family','$font-1',0,''),(169235,54044,'116121','furniture-mobile','color','$attention-color',0,''),(169236,54044,'116121','furniture-mobile','font-size','14',0,''),(169237,54044,'116121','furniture-mobile','text-align','center',0,''),(169238,54045,'116122','furniture-mobile','link','Gift Certificate',0,''),(169239,54045,'116122','furniture-mobile','text','GIFT_CERTIFICATE',0,''),(169240,54045,'116122','furniture-mobile','popup','1',0,''),(169241,54045,'116122','furniture-mobile','text-align','center',0,''),(169242,54045,'116122','furniture-mobile','font-size','14',0,''),(169243,54046,'116123','furniture-mobile','text','TEXT_VIEW_HISTORY',0,''),(169244,54046,'116123','furniture-mobile','popup','1',0,''),(169245,54046,'116123','furniture-mobile','text-align','center',0,''),(169246,54046,'116123','furniture-mobile','link','Points Earnt History',0,''),(169247,54046,'116123','furniture-mobile','font-size','14',0,''),(169248,54047,'116124','furniture-mobile','font-family','$font-1',0,''),(169249,54047,'116124','furniture-mobile','color','$attention-color',0,''),(169250,54047,'116124','furniture-mobile','font-size','14',0,''),(169251,54047,'116124','furniture-mobile','text-align','center',0,''),(169252,54048,'116125','furniture-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(169253,54048,'116125','furniture-mobile','content','\\e990',0,'3'),(169254,54048,'116125','furniture-mobile','font-family','trueloaded',0,'3'),(169255,54048,'116125','furniture-mobile','font-size','30',0,'3'),(169256,54048,'116125','furniture-mobile','text-align','center',0,'3'),(169257,54048,'116125','furniture-mobile','line-height','1',0,'3'),(169258,54048,'116125','furniture-mobile','color','$attention-color',0,'3'),(169259,54048,'116125','furniture-mobile','font-size','16',0,''),(169260,54048,'116125','furniture-mobile','text-align','center',0,''),(169261,54048,'116125','furniture-mobile','text-transform','uppercase',0,''),(169262,54048,'116125','furniture-mobile','font-size','14',0,'2876'),(169319,54070,'116145','furniture-mobile','block_type','1',0,''),(169320,54070,'116145','furniture-mobile','style_class','account-edit-wrap',0,''),(169321,54071,'116146','furniture-mobile','block_type','6',0,''),(169322,54071,'116146','furniture-mobile','schema','6-3',0,'2885'),(169323,54072,'116147','furniture-mobile','aria_name','account-menu',0,''),(169380,54093,'116149','furniture-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(169381,54094,'116150','furniture-mobile','block_type','1',0,''),(169382,54094,'116150','furniture-mobile','style_class','account-address-book',0,''),(169383,54095,'116151','furniture-mobile','block_type','6',0,''),(169384,54095,'116151','furniture-mobile','schema','6-3',0,'2885'),(169385,54096,'116152','furniture-mobile','aria_name','account-menu',0,''),(169442,54116,'116153','furniture-mobile','padding-top','15',0,''),(169443,54116,'116153','furniture-mobile','padding-bottom','15',0,''),(169444,54116,'116153','furniture-mobile','link','Address Book Process',0,''),(169445,54116,'116153','furniture-mobile','text','EDIT',0,''),(169446,54116,'116153','furniture-mobile','link_add','Address Book Process',0,''),(169447,54116,'116153','furniture-mobile','like_button_add','2',0,''),(169448,54116,'116153','furniture-mobile','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(169449,54117,'116154','furniture-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(169450,54118,'116155','furniture-mobile','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(169451,54119,'116156','furniture-mobile','block_type','1',0,''),(169452,54119,'116156','furniture-mobile','style_class','account-address-book-process',0,''),(169453,54120,'116157','furniture-mobile','block_type','6',0,''),(169454,54120,'116157','furniture-mobile','schema','6-3',0,'2885'),(169455,54121,'116158','furniture-mobile','aria_name','account-menu',0,''),(169512,54141,'116159','furniture-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(169513,54143,'117906.000001','furniture-mobile','block_type','1',0,''),(169514,54143,'117906.000001','furniture-mobile','style_class','item-holder',0,''),(169515,54143,'117906.000001','furniture-mobile','padding-top','25',0,''),(169516,54143,'117906.000001','furniture-mobile','padding-bottom','25',0,''),(169517,54143,'117906.000001','furniture-mobile','text-align','left',0,''),(169518,54143,'117906.000001','furniture-mobile','border-top-width','1',0,''),(169519,54143,'117906.000001','furniture-mobile','border-top-color','$border-color-3',0,''),(169520,54144,'117907.000001','furniture-mobile','block_type','7',0,''),(169521,54144,'117907.000001','furniture-mobile','schema','7-2',0,'2885'),(169522,54145,'117908.000001','furniture-mobile','block_type','5',0,''),(169523,54145,'117908.000001','furniture-mobile','schema','5-2',0,'2885'),(169524,54146,'117909.000001','furniture-mobile','clear','none',0,''),(169525,54146,'117909.000001','furniture-mobile','padding-right','20',0,''),(169526,54147,'117910.000001','furniture-mobile','padding-right','20',0,''),(169527,54147,'117910.000001','furniture-mobile','max-width','300',0,'2885'),(169528,54147,'117910.000001','furniture-mobile','margin_left_measure','auto',0,'2885'),(169529,54147,'117910.000001','furniture-mobile','margin_right_measure','auto',0,'2885'),(169530,54148,'117914.000001','furniture-mobile','padding-right','20',0,''),(169531,54149,'117915.000001','furniture-mobile','description_characters','200',0,''),(169532,54149,'117915.000001','furniture-mobile','clear','none',0,''),(169533,54149,'117915.000001','furniture-mobile','padding-right','20',0,''),(169534,54150,'117916.000001','furniture-mobile','clear','none',0,''),(169535,54151,'117917.000001','furniture-mobile','margin-bottom','20',0,''),(169536,54153,'117918.000001','furniture-mobile','block_type','1',0,''),(169537,54153,'117918.000001','furniture-mobile','padding-left','40',0,''),(169538,54153,'117918.000001','furniture-mobile','style_class','right-aria',0,''),(169539,54153,'117918.000001','furniture-mobile','padding-left','0',0,'2885'),(169540,54154,'117911.000001','furniture-mobile','block_type','1',0,''),(169541,54154,'117911.000001','furniture-mobile','text-align','center',0,''),(169542,54155,'117912.000001','furniture-mobile','margin-top','4',0,''),(169543,54155,'117912.000001','furniture-mobile','margin-bottom','7',0,''),(169544,54156,'117913.000001','furniture-mobile','padding-top','6',0,''),(169545,54156,'117913.000001','furniture-mobile','padding-left','5',0,''),(169546,54157,'117919.000001','furniture-mobile','margin-bottom','15',0,''),(169547,54157,'117919.000001','furniture-mobile','text-align','right',0,''),(169548,54158,'117920.000001','furniture-mobile','margin-bottom','10',0,''),(169549,54158,'117920.000001','furniture-mobile','text-align','center',0,''),(169550,54159,'117922.000001','furniture-mobile','text-align','right',0,''),(169551,54159,'117922.000001','furniture-mobile','margin-bottom','15',0,''),(169552,54160,'117924.000001','furniture-mobile','text-align','center',0,''),(169553,54160,'117924.000001','furniture-mobile','margin-bottom','10',0,''),(169554,54161,'120924.000001','furniture-mobile','block_type','1',0,''),(169555,54161,'120924.000001','furniture-mobile','style_class','item-nav',0,''),(169556,54165,'116176','furniture-mobile','block_type','1',0,''),(169557,54165,'116176','furniture-mobile','style_class','item-holder',0,''),(169558,54165,'116176','furniture-mobile','padding-top','25',0,''),(169559,54165,'116176','furniture-mobile','padding-left','25',0,''),(169560,54165,'116176','furniture-mobile','padding-right','25',0,''),(169561,54165,'116176','furniture-mobile','padding-bottom','25',0,''),(169562,54165,'116176','furniture-mobile','text-align','left',0,''),(169563,54167,'116178','furniture-mobile','margin-bottom','7',0,''),(169564,54168,'116179','furniture-mobile','clear','both',0,''),(169565,54171,'116182','furniture-mobile','block_type','1',0,''),(169566,54171,'116182','furniture-mobile','style_class','item-holder',0,''),(169567,54171,'116182','furniture-mobile','padding-top','25',0,''),(169568,54171,'116182','furniture-mobile','padding-left','25',0,''),(169569,54171,'116182','furniture-mobile','padding-right','25',0,''),(169570,54171,'116182','furniture-mobile','padding-bottom','25',0,''),(169571,54171,'116182','furniture-mobile','text-align','left',0,''),(169572,54172,'116183','furniture-mobile','block_type','5',0,''),(169573,54175,'116186','furniture-mobile','margin-bottom','7',0,''),(169574,54176,'116187','furniture-mobile','clear','both',0,''),(169575,54177,'116188','furniture-mobile','block_type','1',0,''),(169576,54178,'116189','furniture-mobile','block_type','6',0,''),(169577,54178,'116189','furniture-mobile','font-weight','400',0,''),(169578,54178,'116189','furniture-mobile','schema','6-2',0,'2906'),(169579,54178,'116189','furniture-mobile','schema','6-2',0,'2885'),(169580,54179,'116190','furniture-mobile','font-weight','400',0,''),(169581,54179,'116190','furniture-mobile','padding-right','40',0,''),(169582,54179,'116190','furniture-mobile','padding-right','0',0,'2906'),(169583,54179,'116190','furniture-mobile','padding-right','0',0,'2885'),(169584,54180,'116191','furniture-mobile','block_type','5',0,''),(169585,54180,'116191','furniture-mobile','padding-top','10',0,''),(169586,54180,'116191','furniture-mobile','padding-bottom','10',0,''),(169587,54180,'116191','furniture-mobile','schema','5-2',0,'2906'),(169588,54180,'116191','furniture-mobile','border-top-color','$border-color-4',0,''),(169589,54180,'116191','furniture-mobile','border-top-width','1',0,''),(169590,54182,'116193','furniture-mobile','float','right',0,''),(169591,54184,'116195','furniture-mobile','col_in_row','3',0,''),(169592,54184,'116195','furniture-mobile','products_align','left',0,''),(169593,54184,'116195','furniture-mobile','font-weight','400',0,''),(169594,54184,'116195','furniture-mobile','show_qty_input','0',0,''),(169595,54184,'116195','furniture-mobile','listing_type','productListing',0,''),(169596,54184,'116195','furniture-mobile','listing_type_rows','no',0,''),(169597,54184,'116195','furniture-mobile','show_buy_button_b2b','on',0,''),(169598,54184,'116195','furniture-mobile','show_wishlist_button_b2b','1',0,''),(169599,54184,'116195','furniture-mobile','show_compare_b2b','1',0,''),(169600,54184,'116195','furniture-mobile','show_stock','0',0,''),(169601,54184,'116195','furniture-mobile','show_description','0',0,''),(169602,54184,'116195','furniture-mobile','show_model','0',0,''),(169603,54184,'116195','furniture-mobile','show_properties','0',0,''),(169604,54184,'116195','furniture-mobile','show_rating','0',0,''),(169605,54184,'116195','furniture-mobile','show_rating_counts','0',0,''),(169606,54184,'116195','furniture-mobile','show_price','0',0,''),(169607,54184,'116195','furniture-mobile','show_buy_button','0',0,''),(169608,54184,'116195','furniture-mobile','show_view_button','0',0,''),(169609,54184,'116195','furniture-mobile','show_wishlist_button','0',0,''),(169610,54184,'116195','furniture-mobile','show_compare','0',0,''),(169611,54184,'116195','furniture-mobile','show_name_rows','0',0,''),(169612,54184,'116195','furniture-mobile','show_image_rows','0',0,''),(169613,54184,'116195','furniture-mobile','show_stock_rows','0',0,''),(169614,54184,'116195','furniture-mobile','show_description_rows','0',0,''),(169615,54184,'116195','furniture-mobile','show_model_rows','0',0,''),(169616,54184,'116195','furniture-mobile','show_properties_rows','0',0,''),(169617,54184,'116195','furniture-mobile','show_rating_rows','0',0,''),(169618,54184,'116195','furniture-mobile','show_rating_counts_rows','0',0,''),(169619,54184,'116195','furniture-mobile','show_price_rows','0',0,''),(169620,54184,'116195','furniture-mobile','show_buy_button_rows','0',0,''),(169621,54184,'116195','furniture-mobile','show_qty_input_rows','0',0,''),(169622,54184,'116195','furniture-mobile','show_view_button_rows','0',0,''),(169623,54184,'116195','furniture-mobile','show_wishlist_button_rows','0',0,''),(169624,54184,'116195','furniture-mobile','show_compare_rows','0',0,''),(169625,54184,'116195','furniture-mobile','show_name_b2b','0',0,''),(169626,54184,'116195','furniture-mobile','show_image_b2b','0',0,''),(169627,54184,'116195','furniture-mobile','show_stock_b2b','0',0,''),(169628,54184,'116195','furniture-mobile','show_description_b2b','0',0,''),(169629,54184,'116195','furniture-mobile','show_model_b2b','0',0,''),(169630,54184,'116195','furniture-mobile','show_properties_b2b','0',0,''),(169631,54184,'116195','furniture-mobile','show_rating_b2b','0',0,''),(169632,54184,'116195','furniture-mobile','show_rating_counts_b2b','0',0,''),(169633,54184,'116195','furniture-mobile','show_price_b2b','0',0,''),(169634,54184,'116195','furniture-mobile','show_qty_input_b2b','0',0,''),(169635,54184,'116195','furniture-mobile','show_view_button_b2b','0',0,''),(169636,54184,'116195','furniture-mobile','show_attributes_b2b','0',0,''),(169637,54184,'116195','furniture-mobile','items_on_page','9',0,''),(169638,54184,'116195','furniture-mobile','col_in_row','2',0,'2885'),(169639,54184,'116195','furniture-mobile','col_in_row','1',0,'2906'),(169640,54184,'116195','furniture-mobile','product_names_teg','h2',0,''),(169641,54185,'116196','furniture-mobile','listing_type','productListing',0,''),(169642,54186,'116197','furniture-mobile','block_type','1',0,''),(169643,54186,'116197','furniture-mobile','padding-top','10',0,''),(169644,54186,'116197','furniture-mobile','padding-bottom','10',0,''),(169645,54186,'116197','furniture-mobile','border-bottom-width','1',0,''),(169646,54186,'116197','furniture-mobile','border-bottom-color','$border-color-4',0,''),(169647,54186,'116197','furniture-mobile','margin-left','0',0,''),(169648,54186,'116197','furniture-mobile','margin-right','0',0,''),(169649,54187,'116198','furniture-mobile','float','right',0,''),(169650,54187,'116198','furniture-mobile','display','none',0,'2906'),(169651,54188,'116199','furniture-mobile','margin-right','20',0,''),(169652,54188,'116199','furniture-mobile','float','right',0,''),(169653,54188,'116199','furniture-mobile','clear','none',0,''),(169654,54188,'116199','furniture-mobile','display','none',0,'2885'),(169655,54189,'116200','furniture-mobile','float','left',0,''),(169656,54189,'116200','furniture-mobile','clear','none',0,''),(169657,54189,'116200','furniture-mobile','margin-left','20',0,''),(169658,54189,'116200','furniture-mobile','display','none',0,'2906'),(169659,54190,'116201','furniture-mobile','float','left',0,''),(169660,54190,'116201','furniture-mobile','clear','none',0,''),(169661,54190,'116201','furniture-mobile','sort_pos_3','1',0,''),(169662,54190,'116201','furniture-mobile','sort_pos_4','2',0,''),(169663,54190,'116201','furniture-mobile','sort_pos_10','3',0,''),(169664,54190,'116201','furniture-mobile','sort_pos_9','4',0,''),(169665,54190,'116201','furniture-mobile','sort_pos_11','5',0,''),(169666,54190,'116201','furniture-mobile','sort_pos_12','6',0,''),(169667,54190,'116201','furniture-mobile','sort_pos_14','7',0,''),(169668,54190,'116201','furniture-mobile','sort_pos_13','8',0,''),(169669,54190,'116201','furniture-mobile','sort_pos_8','9',0,''),(169670,54190,'116201','furniture-mobile','sort_pos_7','10',0,''),(169671,54190,'116201','furniture-mobile','sort_pos_2','11',0,''),(169672,54190,'116201','furniture-mobile','sort_pos_1','12',0,''),(169673,54190,'116201','furniture-mobile','sort_pos_6','13',0,''),(169674,54190,'116201','furniture-mobile','sort_pos_5','14',0,''),(169675,54190,'116201','furniture-mobile','sort_pos_0','15',0,''),(169676,54190,'116201','furniture-mobile','sort_hide_10','1',0,''),(169677,54190,'116201','furniture-mobile','sort_hide_9','1',0,''),(169678,54190,'116201','furniture-mobile','hide_icons','1',0,''),(169679,54190,'116201','furniture-mobile','sort_hide_16','1',0,''),(169680,54190,'116201','furniture-mobile','sort_hide_15','1',0,''),(169681,54190,'116201','furniture-mobile','sort_hide_3','0',0,''),(169682,54190,'116201','furniture-mobile','sort_hide_4','0',0,''),(169683,54190,'116201','furniture-mobile','sort_hide_11','1',0,''),(169684,54190,'116201','furniture-mobile','sort_hide_12','1',0,''),(169685,54190,'116201','furniture-mobile','sort_hide_14','1',0,''),(169686,54190,'116201','furniture-mobile','sort_hide_13','1',0,''),(169687,54190,'116201','furniture-mobile','sort_hide_8','0',0,''),(169688,54190,'116201','furniture-mobile','sort_hide_7','0',0,''),(169689,54190,'116201','furniture-mobile','sort_hide_2','1',0,''),(169690,54190,'116201','furniture-mobile','sort_hide_1','1',0,''),(169691,54190,'116201','furniture-mobile','sort_hide_6','1',0,''),(169692,54190,'116201','furniture-mobile','sort_hide_5','1',0,''),(169693,54190,'116201','furniture-mobile','sort_hide_0','1',0,''),(169694,54193,'116204','furniture-mobile','block_type','1',0,''),(169695,54194,'116205','furniture-mobile','block_type','7',0,''),(169696,54194,'116205','furniture-mobile','schema','7-2',0,'2885'),(169697,54195,'116206','furniture-mobile','padding-top','20',0,''),(169698,54195,'116206','furniture-mobile','padding-right','20',0,''),(169699,54196,'116207','furniture-mobile','blog_sidebar','1',0,''),(169700,54196,'116207','furniture-mobile','padding-top','20',0,''),(169701,54196,'116207','furniture-mobile','padding-left','20',0,''),(169703,54201,'1683110860.800967','furniture-mobile','block_type','1',0,''),(169704,54201,'1683110860.800967','furniture-mobile','font-weight','normal',0,''),(169705,54201,'1683110860.800967','furniture-mobile','padding-top','20',0,''),(169706,54201,'1683110860.800967','furniture-mobile','background-color','$background-6',0,''),(169707,54201,'1683110860.800967','furniture-mobile','style_class','shopping-cart-index',0,''),(169708,54202,'1683110860.811285','furniture-mobile','block_type','7',0,''),(169709,54202,'1683110860.811285','furniture-mobile','schema','4-1',0,'2890'),(169710,54202,'1683110860.811285','furniture-mobile','schema','4-2',0,'2885'),(169711,54203,'1683110860.81452','furniture-mobile','block_type','1',0,''),(169712,54203,'1683110860.81452','furniture-mobile','background-color','$background-7',0,''),(169713,54203,'1683110860.81452','furniture-mobile','padding-top','20',0,''),(169714,54203,'1683110860.81452','furniture-mobile','padding-bottom','20',0,''),(169715,54203,'1683110860.81452','furniture-mobile','padding-left','25',0,''),(169716,54203,'1683110860.81452','furniture-mobile','padding-right','25',0,''),(169717,54203,'1683110860.81452','furniture-mobile','margin-bottom','30',0,''),(169718,54204,'1683110860.815931','furniture-mobile','text','<div class=\"heading-3\">##TEXT_ALSO_INTERESTED##</div>',0,''),(169719,54204,'1683110860.815931','furniture-mobile','style_class','shipping-ico',0,''),(169720,54205,'1683110860.818836','furniture-mobile','col_in_row','4',0,''),(169721,54205,'1683110860.818836','furniture-mobile','show_description','1',0,''),(169722,54205,'1683110860.818836','furniture-mobile','show_model','1',0,''),(169723,54205,'1683110860.818836','furniture-mobile','show_properties','1',0,''),(169724,54205,'1683110860.818836','furniture-mobile','show_rating','1',0,''),(169725,54205,'1683110860.818836','furniture-mobile','show_rating_counts','1',0,''),(169726,54205,'1683110860.818836','furniture-mobile','show_qty_input','1',0,''),(169727,54205,'1683110860.818836','furniture-mobile','show_view_button','1',0,''),(169728,54205,'1683110860.818836','furniture-mobile','show_wishlist_button','1',0,''),(169729,54205,'1683110860.818836','furniture-mobile','show_compare','1',0,''),(169730,54205,'1683110860.818836','furniture-mobile','view_as','carousel',0,''),(169731,54205,'1683110860.818836','furniture-mobile','hide_parents','2',0,''),(169732,54205,'1683110860.818836','furniture-mobile','listing_type','productListing',0,''),(169733,54205,'1683110860.818836','furniture-mobile','show_bonus_points','1',0,''),(169734,54206,'1683110860.82112','furniture-mobile','block_type','1',0,''),(169735,54206,'1683110860.82112','furniture-mobile','background-color','$background-7',0,''),(169736,54206,'1683110860.82112','furniture-mobile','margin-bottom','25',0,''),(169737,54206,'1683110860.82112','furniture-mobile','padding-left','25',0,''),(169738,54206,'1683110860.82112','furniture-mobile','padding-right','25',0,''),(169739,54206,'1683110860.82112','furniture-mobile','padding-bottom','25',0,''),(169740,54207,'1683110860.82264','furniture-mobile','padding-top','20',0,''),(169741,54207,'1683110860.82264','furniture-mobile','padding-bottom','20',0,''),(169742,54208,'1683110860.823336','furniture-mobile','block_type','2',0,''),(169743,54208,'1683110860.823336','furniture-mobile','padding-bottom','20',0,''),(169744,54208,'1683110860.823336','furniture-mobile','padding-top','20',0,''),(169745,54208,'1683110860.823336','furniture-mobile','border-bottom-color','$border-color-4',0,''),(169746,54208,'1683110860.823336','furniture-mobile','border-bottom-width','1',0,''),(169747,54208,'1683110860.823336','furniture-mobile','schema','2-2',0,'2885'),(169748,54209,'1683110860.82490','furniture-mobile','float','left',0,''),(169749,54209,'1683110860.82490','furniture-mobile','float','none',0,'2885'),(169750,54210,'1683110860.825674','furniture-mobile','text-align','right',0,''),(169751,54210,'1683110860.825674','furniture-mobile','clear','none',0,''),(169752,54210,'1683110860.825674','furniture-mobile','float','right',0,''),(169753,54210,'1683110860.825674','furniture-mobile','padding-top','22',0,''),(169754,54210,'1683110860.825674','furniture-mobile','float','none',0,'2885'),(169755,54210,'1683110860.825674','furniture-mobile','text-align','left',0,'2885'),(169756,54211,'1683110860.826797','furniture-mobile','float','right',0,''),(169757,54211,'1683110860.826797','furniture-mobile','padding-top','26',0,''),(169758,54211,'1683110860.826797','furniture-mobile','float','none',0,'2885'),(169759,54211,'1683110860.826797','furniture-mobile','text-align','left',0,'2885'),(169760,54212,'1683110860.827896','furniture-mobile','block_type','3',0,''),(169761,54212,'1683110860.827896','furniture-mobile','font-weight','400',0,''),(169762,54212,'1683110860.827896','furniture-mobile','schema','2-2',0,'2876'),(169763,54212,'1683110860.827896','furniture-mobile','style_class','closeable-content',0,''),(169764,54212,'1683110860.827896','furniture-mobile','padding-top','10',0,''),(169765,54213,'1683110860.829995','furniture-mobile','font-weight','400',0,''),(169766,54213,'1683110860.829995','furniture-mobile','padding-right','24',0,''),(169767,54213,'1683110860.829995','furniture-mobile','padding-right','0',0,'2876'),(169768,54213,'1683110860.829995','furniture-mobile','padding-bottom','20',0,'2876'),(169769,54214,'1683110860.830980','furniture-mobile','padding-right','24',0,''),(169770,54214,'1683110860.830980','furniture-mobile','padding-right','0',0,'2876'),(169771,54214,'1683110860.830980','furniture-mobile','padding-bottom','20',0,'2876'),(169772,54216,'1683110860.83215','furniture-mobile','text-align','right',0,''),(169773,54217,'1683110860.833430','furniture-mobile','text','<div><span>##TEXT_YOUR_SHOPPING_CART##</span></div>',0,''),(169774,54217,'1683110860.833430','furniture-mobile','padding-top','20',0,''),(169775,54217,'1683110860.833430','furniture-mobile','margin-bottom','20',0,''),(169776,54217,'1683110860.833430','furniture-mobile','text-align','center',0,''),(169777,54217,'1683110860.833430','furniture-mobile','font-weight','bold',0,''),(169778,54217,'1683110860.833430','furniture-mobile','font-size','36',0,''),(169779,54217,'1683110860.833430','furniture-mobile','style_class','cartTitle',0,''),(169780,54218,'1683110860.835461','furniture-mobile','block_type','1',0,''),(169781,54218,'1683110860.835461','furniture-mobile','padding-top','20',0,''),(169782,54218,'1683110860.835461','furniture-mobile','padding-bottom','20',0,''),(169783,54218,'1683110860.835461','furniture-mobile','padding-left','25',0,''),(169784,54218,'1683110860.835461','furniture-mobile','padding-right','25',0,''),(169785,54218,'1683110860.835461','furniture-mobile','background-color','$background-7',0,''),(169786,54218,'1683110860.835461','furniture-mobile','margin-bottom','30',0,''),(169787,54219,'1683110860.837349','furniture-mobile','hide_parents','2',0,''),(169788,54220,'1683110860.83786','furniture-mobile','text','<div class=\"heading-3\">##TEXT_GA_PRODUCTS##</div>',0,''),(169789,54220,'1683110860.83786','furniture-mobile','style_class','shipping-ico',0,''),(169790,54221,'1683110860.839462','furniture-mobile','block_type','1',0,''),(169791,54221,'1683110860.839462','furniture-mobile','background-color','$background-7',0,''),(169792,54221,'1683110860.839462','furniture-mobile','padding-top','20',0,''),(169793,54221,'1683110860.839462','furniture-mobile','padding-left','25',0,''),(169794,54221,'1683110860.839462','furniture-mobile','padding-right','25',0,''),(169795,54221,'1683110860.839462','furniture-mobile','padding-bottom','20',0,''),(169796,54221,'1683110860.839462','furniture-mobile','margin-bottom','30',0,''),(169797,54221,'1683110860.839462','furniture-mobile','style_class','closeable-box',0,''),(169798,54222,'1683110860.841398','furniture-mobile','text','<div class=\"heading-3\">##TEXT_SHIPPING##</div>',0,''),(169799,54222,'1683110860.841398','furniture-mobile','style_class','shipping-ico',0,''),(169800,54223,'1683110860.84291','furniture-mobile','font-weight','normal',0,''),(169801,54223,'1683110860.84291','furniture-mobile','hide_parents','2',0,''),(169802,54224,'1683110860.843639','furniture-mobile','listing_type','productListing',0,''),(169803,54224,'1683110860.843639','furniture-mobile','col_in_row','4',0,''),(169804,54224,'1683110860.843639','furniture-mobile','show_popup','1',0,''),(169805,54224,'1683110860.843639','furniture-mobile','col_in_row','3',0,'2885'),(169806,54224,'1683110860.843639','furniture-mobile','col_in_row','2',0,'2876'),(169807,54224,'1683110860.843639','furniture-mobile','col_in_row','1',0,'2906'),(169808,54224,'1683110860.843639','furniture-mobile','padding-top','20',0,''),(169809,54224,'1683110860.843639','furniture-mobile','padding-left','25',0,''),(169810,54224,'1683110860.843639','furniture-mobile','padding-right','25',0,''),(169811,54224,'1683110860.843639','furniture-mobile','padding-bottom','20',0,''),(169812,54224,'1683110860.843639','furniture-mobile','background-color','$background-7',0,''),(169813,54224,'1683110860.843639','furniture-mobile','margin-bottom','25',0,''),(169814,54225,'1683110860.846971','furniture-mobile','style_class','order-summary',0,''),(169815,54225,'1683110860.846971','furniture-mobile','block_type','1',0,''),(169816,54225,'1683110860.846971','furniture-mobile','margin-left','25',0,''),(169817,54225,'1683110860.846971','furniture-mobile','margin-left','0',0,'2885'),(169818,54225,'1683110860.846971','furniture-mobile','margin-bottom','30',0,'2885'),(169819,54225,'1683110860.846971','furniture-mobile','padding-left','10',0,''),(169820,54225,'1683110860.846971','furniture-mobile','padding-right','10',0,''),(169821,54225,'1683110860.846971','furniture-mobile','padding-bottom','10',0,''),(169822,54225,'1683110860.846971','furniture-mobile','background-color','$background-7',0,''),(169823,54226,'1683110860.849323','furniture-mobile','block_type','1',0,''),(169824,54227,'1683110860.862447','furniture-mobile','font-weight','400',0,''),(169825,54227,'1683110860.862447','furniture-mobile','box_align','4',0,''),(169826,54227,'1683110860.862447','furniture-mobile','text-align','center',0,'2876'),(169827,54227,'1683110860.862447','furniture-mobile','float','none',0,'2876'),(169828,54227,'1683110860.862447','furniture-mobile','width','100',0,'2876'),(169829,54227,'1683110860.862447','furniture-mobile','width_measure','%',0,'2876'),(169830,54229,'1683110860.864695','furniture-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(169831,54230,'116242','furniture-mobile','block_type','1',0,''),(169832,54230,'116242','furniture-mobile','font-weight','normal',0,''),(169833,54230,'116242','furniture-mobile','padding-top','20',0,''),(169834,54230,'116242','furniture-mobile','background-color','$background-6',0,''),(169835,54232,'116244','furniture-mobile','block_type','4',0,''),(169836,54232,'116244','furniture-mobile','schema','4-1',0,'2890'),(169837,54232,'116244','furniture-mobile','schema','4-2',0,'2885'),(169838,54233,'116245','furniture-mobile','block_type','1',0,''),(169839,54233,'116245','furniture-mobile','background-color','$background-7',0,''),(169840,54233,'116245','furniture-mobile','padding-top','20',0,''),(169841,54233,'116245','furniture-mobile','padding-bottom','20',0,''),(169842,54233,'116245','furniture-mobile','padding-left','25',0,''),(169843,54233,'116245','furniture-mobile','padding-right','25',0,''),(169844,54233,'116245','furniture-mobile','margin-bottom','30',0,''),(169845,54234,'116246','furniture-mobile','col_in_row','3',0,''),(169846,54234,'116246','furniture-mobile','show_description','1',0,''),(169847,54234,'116246','furniture-mobile','show_model','1',0,''),(169848,54234,'116246','furniture-mobile','show_properties','1',0,''),(169849,54234,'116246','furniture-mobile','show_rating','1',0,''),(169850,54234,'116246','furniture-mobile','show_rating_counts','1',0,''),(169851,54234,'116246','furniture-mobile','show_qty_input','1',0,''),(169852,54234,'116246','furniture-mobile','show_view_button','1',0,''),(169853,54234,'116246','furniture-mobile','show_wishlist_button','1',0,''),(169854,54234,'116246','furniture-mobile','show_compare','1',0,''),(169855,54234,'116246','furniture-mobile','view_as','carousel',0,''),(169856,54234,'116246','furniture-mobile','hide_parents','2',0,''),(169857,54235,'116247','furniture-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(169858,54235,'116247','furniture-mobile','style_class','bell-ico',0,''),(169859,54236,'116248','furniture-mobile','block_type','1',0,''),(169860,54236,'116248','furniture-mobile','background-color','$background-7',0,''),(169861,54236,'116248','furniture-mobile','margin-bottom','30',0,''),(169862,54237,'116249','furniture-mobile','padding-top','20',0,''),(169863,54237,'116249','furniture-mobile','padding-left','25',0,''),(169864,54237,'116249','furniture-mobile','padding-right','25',0,''),(169865,54237,'116249','furniture-mobile','padding-bottom','20',0,''),(169866,54238,'116250','furniture-mobile','block_type','2',0,''),(169867,54238,'116250','furniture-mobile','padding-bottom','20',0,''),(169868,54238,'116250','furniture-mobile','padding-top','20',0,''),(169869,54238,'116250','furniture-mobile','padding-left','25',0,''),(169870,54238,'116250','furniture-mobile','padding-right','25',0,''),(169871,54238,'116250','furniture-mobile','border-bottom-color','$border-color-4',0,''),(169872,54238,'116250','furniture-mobile','border-bottom-width','1',0,''),(169873,54238,'116250','furniture-mobile','schema','2-2',0,'2885'),(169874,54239,'116251','furniture-mobile','float','left',0,''),(169875,54240,'116252','furniture-mobile','text-align','right',0,''),(169876,54240,'116252','furniture-mobile','clear','none',0,''),(169877,54240,'116252','furniture-mobile','float','right',0,''),(169878,54240,'116252','furniture-mobile','padding-top','22',0,''),(169879,54241,'116253','furniture-mobile','float','right',0,''),(169880,54241,'116253','furniture-mobile','padding-top','26',0,''),(169881,54242,'116254','furniture-mobile','block_type','1',0,''),(169882,54242,'116254','furniture-mobile','padding-top','20',0,''),(169883,54242,'116254','furniture-mobile','padding-bottom','20',0,''),(169884,54242,'116254','furniture-mobile','padding-left','25',0,''),(169885,54242,'116254','furniture-mobile','padding-right','25',0,''),(169886,54242,'116254','furniture-mobile','background-color','$background-7',0,''),(169887,54242,'116254','furniture-mobile','margin-bottom','30',0,''),(169888,54243,'116255','furniture-mobile','hide_parents','2',0,''),(169889,54244,'116256','furniture-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(169890,54245,'116257','furniture-mobile','block_type','1',0,''),(169891,54245,'116257','furniture-mobile','background-color','$background-7',0,''),(169892,54245,'116257','furniture-mobile','padding-top','20',0,''),(169893,54245,'116257','furniture-mobile','padding-bottom','20',0,''),(169894,54245,'116257','furniture-mobile','padding-left','25',0,''),(169895,54245,'116257','furniture-mobile','padding-right','25',0,''),(169896,54245,'116257','furniture-mobile','margin-bottom','30',0,''),(169897,54245,'116257','furniture-mobile','style_class','closeable-box',0,''),(169898,54246,'116258','furniture-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(169899,54246,'116258','furniture-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(169900,54247,'116259','furniture-mobile','block_type','3',0,''),(169901,54247,'116259','furniture-mobile','font-weight','400',0,''),(169902,54247,'116259','furniture-mobile','schema','2-2',0,'2876'),(169903,54247,'116259','furniture-mobile','style_class','closeable-content',0,''),(169904,54247,'116259','furniture-mobile','padding-top','10',0,''),(169905,54248,'116260','furniture-mobile','font-weight','400',0,''),(169906,54248,'116260','furniture-mobile','padding-top','12',0,'2876'),(169907,54248,'116260','furniture-mobile','padding-left','0',0,'2876'),(169908,54251,'116263','furniture-mobile','block_type','1',0,''),(169909,54251,'116263','furniture-mobile','background-color','$background-7',0,''),(169910,54251,'116263','furniture-mobile','padding-top','20',0,''),(169911,54251,'116263','furniture-mobile','padding-left','25',0,''),(169912,54251,'116263','furniture-mobile','padding-right','25',0,''),(169913,54251,'116263','furniture-mobile','padding-bottom','20',0,''),(169914,54251,'116263','furniture-mobile','margin-bottom','30',0,''),(169915,54251,'116263','furniture-mobile','style_class','closeable-box',0,''),(169916,54251,'116263','furniture-mobile','display','none',0,'2885'),(169917,54252,'116264','furniture-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(169918,54252,'116264','furniture-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(169919,54253,'116265','furniture-mobile','font-weight','normal',0,''),(169920,54253,'116265','furniture-mobile','style_class','closeable-content',0,''),(169921,54253,'116265','furniture-mobile','padding-top','10',0,''),(169922,54253,'116265','furniture-mobile','hide_parents','2',0,''),(169923,54254,'116266','furniture-mobile','style_class','order-summary',0,''),(169924,54254,'116266','furniture-mobile','block_type','1',0,''),(169925,54254,'116266','furniture-mobile','margin-left','30',0,''),(169926,54254,'116266','furniture-mobile','margin-left','0',0,'2885'),(169927,54254,'116266','furniture-mobile','margin-bottom','30',0,'2885'),(169928,54255,'116267','furniture-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(169929,54256,'116268','furniture-mobile','block_type','1',0,''),(169930,54256,'116268','furniture-mobile','padding-left','20',0,''),(169931,54256,'116268','furniture-mobile','padding-right','20',0,''),(169932,54256,'116268','furniture-mobile','padding-bottom','20',0,''),(169933,54257,'116269','furniture-mobile','font-weight','400',0,''),(169934,54257,'116269','furniture-mobile','logo','themes/furniture-mobile/img/payicons-1.png',1,''),(169935,54257,'116269','furniture-mobile','padding-top','20',0,''),(169936,54257,'116269','furniture-mobile','padding-bottom','10',0,''),(169937,54258,'116270','furniture-mobile','font-weight','400',0,''),(169938,54258,'116270','furniture-mobile','box_align','4',0,''),(169939,54258,'116270','furniture-mobile','text-align','center',0,'2876'),(169940,54258,'116270','furniture-mobile','float','none',0,'2876'),(169941,54258,'116270','furniture-mobile','width','100',0,'2876'),(169942,54258,'116270','furniture-mobile','width_measure','%',0,'2876'),(169947,54270,'116272','furniture-mobile','block_type','1',0,''),(169948,54271,'116273','furniture-mobile','block_type','6',0,''),(169949,54271,'116273','furniture-mobile','font-weight','400',0,''),(169950,54271,'116273','furniture-mobile','schema','6-2',0,'2906'),(169951,54271,'116273','furniture-mobile','schema','6-2',0,'2885'),(169952,54272,'116274','furniture-mobile','font-weight','400',0,''),(169953,54272,'116274','furniture-mobile','padding-right','40',0,''),(169954,54272,'116274','furniture-mobile','padding-right','0',0,'2906'),(169955,54272,'116274','furniture-mobile','padding-right','0',0,'2885'),(169956,54274,'116275','furniture-mobile','col_in_row','3',0,''),(169957,54274,'116275','furniture-mobile','products_align','left',0,''),(169958,54274,'116275','furniture-mobile','font-weight','400',0,''),(169959,54274,'116275','furniture-mobile','show_qty_input','0',0,''),(169960,54274,'116275','furniture-mobile','listing_type','productListing',0,''),(169961,54274,'116275','furniture-mobile','listing_type_rows','Rows',0,''),(169962,54274,'116275','furniture-mobile','show_buy_button_b2b','on',0,''),(169963,54274,'116275','furniture-mobile','show_wishlist_button_b2b','1',0,''),(169964,54274,'116275','furniture-mobile','show_compare_b2b','1',0,''),(169965,54274,'116275','furniture-mobile','listing_type_b2b','b2b',0,''),(169966,54274,'116275','furniture-mobile','show_stock','0',0,''),(169967,54274,'116275','furniture-mobile','show_description','0',0,''),(169968,54274,'116275','furniture-mobile','show_model','0',0,''),(169969,54274,'116275','furniture-mobile','show_properties','0',0,''),(169970,54274,'116275','furniture-mobile','show_rating','0',0,''),(169971,54274,'116275','furniture-mobile','show_rating_counts','0',0,''),(169972,54274,'116275','furniture-mobile','show_price','0',0,''),(169973,54274,'116275','furniture-mobile','show_buy_button','0',0,''),(169974,54274,'116275','furniture-mobile','show_view_button','0',0,''),(169975,54274,'116275','furniture-mobile','show_wishlist_button','0',0,''),(169976,54274,'116275','furniture-mobile','show_compare','0',0,''),(169977,54274,'116275','furniture-mobile','show_name_rows','0',0,''),(169978,54274,'116275','furniture-mobile','show_image_rows','0',0,''),(169979,54274,'116275','furniture-mobile','show_stock_rows','0',0,''),(169980,54274,'116275','furniture-mobile','show_description_rows','0',0,''),(169981,54274,'116275','furniture-mobile','show_model_rows','0',0,''),(169982,54274,'116275','furniture-mobile','show_properties_rows','0',0,''),(169983,54274,'116275','furniture-mobile','show_rating_rows','0',0,''),(169984,54274,'116275','furniture-mobile','show_rating_counts_rows','0',0,''),(169985,54274,'116275','furniture-mobile','show_price_rows','0',0,''),(169986,54274,'116275','furniture-mobile','show_buy_button_rows','0',0,''),(169987,54274,'116275','furniture-mobile','show_qty_input_rows','0',0,''),(169988,54274,'116275','furniture-mobile','show_view_button_rows','0',0,''),(169989,54274,'116275','furniture-mobile','show_wishlist_button_rows','0',0,''),(169990,54274,'116275','furniture-mobile','show_compare_rows','0',0,''),(169991,54274,'116275','furniture-mobile','show_name_b2b','0',0,''),(169992,54274,'116275','furniture-mobile','show_image_b2b','0',0,''),(169993,54274,'116275','furniture-mobile','show_stock_b2b','0',0,''),(169994,54274,'116275','furniture-mobile','show_description_b2b','0',0,''),(169995,54274,'116275','furniture-mobile','show_model_b2b','0',0,''),(169996,54274,'116275','furniture-mobile','show_properties_b2b','0',0,''),(169997,54274,'116275','furniture-mobile','show_rating_b2b','0',0,''),(169998,54274,'116275','furniture-mobile','show_rating_counts_b2b','0',0,''),(169999,54274,'116275','furniture-mobile','show_price_b2b','0',0,''),(170000,54274,'116275','furniture-mobile','show_qty_input_b2b','0',0,''),(170001,54274,'116275','furniture-mobile','show_view_button_b2b','0',0,''),(170002,54274,'116275','furniture-mobile','show_attributes_b2b','0',0,''),(170003,54274,'116275','furniture-mobile','items_on_page','9',0,''),(170004,54274,'116275','furniture-mobile','col_in_row','2',0,'2885'),(170005,54274,'116275','furniture-mobile','col_in_row','1',0,'2906'),(170006,54274,'116275','furniture-mobile','product_names_teg','h2',0,''),(170007,54276,'116277','furniture-mobile','block_type','5',0,''),(170008,54276,'116277','furniture-mobile','padding-top','10',0,''),(170009,54276,'116277','furniture-mobile','padding-bottom','10',0,''),(170010,54276,'116277','furniture-mobile','schema','5-2',0,'2906'),(170011,54276,'116277','furniture-mobile','border-top-color','$border-color-4',0,''),(170012,54276,'116277','furniture-mobile','border-top-width','1',0,''),(170013,54278,'116279','furniture-mobile','float','right',0,''),(170014,54279,'116280','furniture-mobile','listing_type','productListing',0,''),(170015,54281,'116282','furniture-mobile','block_type','1',0,''),(170016,54281,'116282','furniture-mobile','padding-top','10',0,''),(170017,54281,'116282','furniture-mobile','padding-bottom','10',0,''),(170018,54281,'116282','furniture-mobile','border-bottom-width','1',0,''),(170019,54281,'116282','furniture-mobile','border-bottom-color','$border-color-4',0,''),(170020,54281,'116282','furniture-mobile','margin-left','0',0,''),(170021,54281,'116282','furniture-mobile','margin-right','0',0,''),(170022,54282,'116283','furniture-mobile','float','right',0,''),(170023,54282,'116283','furniture-mobile','display','none',0,'2906'),(170024,54283,'116284','furniture-mobile','margin-right','20',0,''),(170025,54283,'116284','furniture-mobile','float','right',0,''),(170026,54283,'116284','furniture-mobile','clear','none',0,''),(170027,54283,'116284','furniture-mobile','display','none',0,'2885'),(170028,54284,'116285','furniture-mobile','float','left',0,''),(170029,54284,'116285','furniture-mobile','clear','none',0,''),(170030,54284,'116285','furniture-mobile','margin-left','20',0,''),(170031,54284,'116285','furniture-mobile','display','none',0,'2906'),(170032,54284,'116285','furniture-mobile','display','none',0,'2890'),(170033,54285,'116286','furniture-mobile','float','left',0,''),(170034,54285,'116286','furniture-mobile','clear','none',0,''),(170035,54285,'116286','furniture-mobile','sort_pos_3','1',0,''),(170036,54285,'116286','furniture-mobile','sort_pos_4','2',0,''),(170037,54285,'116286','furniture-mobile','sort_pos_10','3',0,''),(170038,54285,'116286','furniture-mobile','sort_pos_9','4',0,''),(170039,54285,'116286','furniture-mobile','sort_pos_11','5',0,''),(170040,54285,'116286','furniture-mobile','sort_pos_12','6',0,''),(170041,54285,'116286','furniture-mobile','sort_pos_14','7',0,''),(170042,54285,'116286','furniture-mobile','sort_pos_13','8',0,''),(170043,54285,'116286','furniture-mobile','sort_pos_8','9',0,''),(170044,54285,'116286','furniture-mobile','sort_pos_7','10',0,''),(170045,54285,'116286','furniture-mobile','sort_pos_2','11',0,''),(170046,54285,'116286','furniture-mobile','sort_pos_1','12',0,''),(170047,54285,'116286','furniture-mobile','sort_pos_6','13',0,''),(170048,54285,'116286','furniture-mobile','sort_pos_5','14',0,''),(170049,54285,'116286','furniture-mobile','sort_pos_0','15',0,''),(170050,54285,'116286','furniture-mobile','sort_hide_10','1',0,''),(170051,54285,'116286','furniture-mobile','sort_hide_9','1',0,''),(170052,54285,'116286','furniture-mobile','hide_icons','1',0,''),(170053,54285,'116286','furniture-mobile','sort_hide_16','1',0,''),(170054,54285,'116286','furniture-mobile','sort_hide_15','1',0,''),(170055,54285,'116286','furniture-mobile','sort_hide_3','0',0,''),(170056,54285,'116286','furniture-mobile','sort_hide_4','0',0,''),(170057,54285,'116286','furniture-mobile','sort_hide_11','1',0,''),(170058,54285,'116286','furniture-mobile','sort_hide_12','1',0,''),(170059,54285,'116286','furniture-mobile','sort_hide_14','1',0,''),(170060,54285,'116286','furniture-mobile','sort_hide_13','1',0,''),(170061,54285,'116286','furniture-mobile','sort_hide_8','0',0,''),(170062,54285,'116286','furniture-mobile','sort_hide_7','0',0,''),(170063,54285,'116286','furniture-mobile','sort_hide_2','1',0,''),(170064,54285,'116286','furniture-mobile','sort_hide_1','1',0,''),(170065,54285,'116286','furniture-mobile','sort_hide_6','1',0,''),(170066,54285,'116286','furniture-mobile','sort_hide_5','1',0,''),(170067,54285,'116286','furniture-mobile','sort_hide_0','1',0,''),(170068,54292,'116293','furniture-mobile','block_type','1',0,''),(170069,54294,'116295','furniture-mobile','block_type','6',0,''),(170070,54294,'116295','furniture-mobile','font-weight','400',0,''),(170071,54294,'116295','furniture-mobile','schema','6-2',0,'2906'),(170072,54294,'116295','furniture-mobile','schema','6-2',0,'2885'),(170073,54295,'116296','furniture-mobile','font-weight','400',0,''),(170074,54295,'116296','furniture-mobile','padding-right','40',0,''),(170075,54295,'116296','furniture-mobile','padding-right','0',0,'2906'),(170076,54295,'116296','furniture-mobile','padding-right','0',0,'2885'),(170077,54297,'116298','furniture-mobile','col_in_row','3',0,''),(170078,54297,'116298','furniture-mobile','products_align','left',0,''),(170079,54297,'116298','furniture-mobile','font-weight','400',0,''),(170080,54297,'116298','furniture-mobile','show_qty_input','0',0,''),(170081,54297,'116298','furniture-mobile','listing_type','productListing',0,''),(170082,54297,'116298','furniture-mobile','listing_type_rows','no',0,''),(170083,54297,'116298','furniture-mobile','show_buy_button_b2b','on',0,''),(170084,54297,'116298','furniture-mobile','show_wishlist_button_b2b','1',0,''),(170085,54297,'116298','furniture-mobile','show_compare_b2b','1',0,''),(170086,54297,'116298','furniture-mobile','show_stock','0',0,''),(170087,54297,'116298','furniture-mobile','show_description','0',0,''),(170088,54297,'116298','furniture-mobile','show_model','0',0,''),(170089,54297,'116298','furniture-mobile','show_properties','0',0,''),(170090,54297,'116298','furniture-mobile','show_rating','0',0,''),(170091,54297,'116298','furniture-mobile','show_rating_counts','0',0,''),(170092,54297,'116298','furniture-mobile','show_price','0',0,''),(170093,54297,'116298','furniture-mobile','show_buy_button','0',0,''),(170094,54297,'116298','furniture-mobile','show_view_button','0',0,''),(170095,54297,'116298','furniture-mobile','show_wishlist_button','0',0,''),(170096,54297,'116298','furniture-mobile','show_compare','0',0,''),(170097,54297,'116298','furniture-mobile','show_name_rows','0',0,''),(170098,54297,'116298','furniture-mobile','show_image_rows','0',0,''),(170099,54297,'116298','furniture-mobile','show_stock_rows','0',0,''),(170100,54297,'116298','furniture-mobile','show_description_rows','0',0,''),(170101,54297,'116298','furniture-mobile','show_model_rows','0',0,''),(170102,54297,'116298','furniture-mobile','show_properties_rows','0',0,''),(170103,54297,'116298','furniture-mobile','show_rating_rows','0',0,''),(170104,54297,'116298','furniture-mobile','show_rating_counts_rows','0',0,''),(170105,54297,'116298','furniture-mobile','show_price_rows','0',0,''),(170106,54297,'116298','furniture-mobile','show_buy_button_rows','0',0,''),(170107,54297,'116298','furniture-mobile','show_qty_input_rows','0',0,''),(170108,54297,'116298','furniture-mobile','show_view_button_rows','0',0,''),(170109,54297,'116298','furniture-mobile','show_wishlist_button_rows','0',0,''),(170110,54297,'116298','furniture-mobile','show_compare_rows','0',0,''),(170111,54297,'116298','furniture-mobile','show_name_b2b','0',0,''),(170112,54297,'116298','furniture-mobile','show_image_b2b','0',0,''),(170113,54297,'116298','furniture-mobile','show_stock_b2b','0',0,''),(170114,54297,'116298','furniture-mobile','show_description_b2b','0',0,''),(170115,54297,'116298','furniture-mobile','show_model_b2b','0',0,''),(170116,54297,'116298','furniture-mobile','show_properties_b2b','0',0,''),(170117,54297,'116298','furniture-mobile','show_rating_b2b','0',0,''),(170118,54297,'116298','furniture-mobile','show_rating_counts_b2b','0',0,''),(170119,54297,'116298','furniture-mobile','show_price_b2b','0',0,''),(170120,54297,'116298','furniture-mobile','show_qty_input_b2b','0',0,''),(170121,54297,'116298','furniture-mobile','show_view_button_b2b','0',0,''),(170122,54297,'116298','furniture-mobile','show_attributes_b2b','0',0,''),(170123,54297,'116298','furniture-mobile','items_on_page','9',0,''),(170124,54297,'116298','furniture-mobile','col_in_row','2',0,'2885'),(170125,54297,'116298','furniture-mobile','col_in_row','1',0,'2906'),(170126,54297,'116298','furniture-mobile','product_names_teg','h2',0,''),(170127,54298,'116299','furniture-mobile','block_type','1',0,''),(170128,54298,'116299','furniture-mobile','padding-top','10',0,''),(170129,54298,'116299','furniture-mobile','padding-bottom','10',0,''),(170130,54298,'116299','furniture-mobile','border-bottom-width','1',0,''),(170131,54298,'116299','furniture-mobile','border-bottom-color','$border-color-4',0,''),(170132,54298,'116299','furniture-mobile','margin-left','0',0,''),(170133,54298,'116299','furniture-mobile','margin-right','0',0,''),(170134,54299,'116300','furniture-mobile','float','left',0,''),(170135,54299,'116300','furniture-mobile','clear','none',0,''),(170136,54299,'116300','furniture-mobile','sort_pos_3','1',0,''),(170137,54299,'116300','furniture-mobile','sort_pos_4','2',0,''),(170138,54299,'116300','furniture-mobile','sort_pos_10','3',0,''),(170139,54299,'116300','furniture-mobile','sort_pos_9','4',0,''),(170140,54299,'116300','furniture-mobile','sort_pos_11','5',0,''),(170141,54299,'116300','furniture-mobile','sort_pos_12','6',0,''),(170142,54299,'116300','furniture-mobile','sort_pos_14','7',0,''),(170143,54299,'116300','furniture-mobile','sort_pos_13','8',0,''),(170144,54299,'116300','furniture-mobile','sort_pos_8','9',0,''),(170145,54299,'116300','furniture-mobile','sort_pos_7','10',0,''),(170146,54299,'116300','furniture-mobile','sort_pos_2','11',0,''),(170147,54299,'116300','furniture-mobile','sort_pos_1','12',0,''),(170148,54299,'116300','furniture-mobile','sort_pos_6','13',0,''),(170149,54299,'116300','furniture-mobile','sort_pos_5','14',0,''),(170150,54299,'116300','furniture-mobile','sort_pos_0','15',0,''),(170151,54299,'116300','furniture-mobile','sort_hide_10','1',0,''),(170152,54299,'116300','furniture-mobile','sort_hide_9','1',0,''),(170153,54299,'116300','furniture-mobile','hide_icons','1',0,''),(170154,54299,'116300','furniture-mobile','sort_hide_16','1',0,''),(170155,54299,'116300','furniture-mobile','sort_hide_15','1',0,''),(170156,54299,'116300','furniture-mobile','sort_hide_3','0',0,''),(170157,54299,'116300','furniture-mobile','sort_hide_4','0',0,''),(170158,54299,'116300','furniture-mobile','sort_hide_11','1',0,''),(170159,54299,'116300','furniture-mobile','sort_hide_12','1',0,''),(170160,54299,'116300','furniture-mobile','sort_hide_14','1',0,''),(170161,54299,'116300','furniture-mobile','sort_hide_13','1',0,''),(170162,54299,'116300','furniture-mobile','sort_hide_8','0',0,''),(170163,54299,'116300','furniture-mobile','sort_hide_7','0',0,''),(170164,54299,'116300','furniture-mobile','sort_hide_2','1',0,''),(170165,54299,'116300','furniture-mobile','sort_hide_1','1',0,''),(170166,54299,'116300','furniture-mobile','sort_hide_6','1',0,''),(170167,54299,'116300','furniture-mobile','sort_hide_5','1',0,''),(170168,54299,'116300','furniture-mobile','sort_hide_0','1',0,''),(170169,54300,'116301','furniture-mobile','float','left',0,''),(170170,54300,'116301','furniture-mobile','clear','none',0,''),(170171,54300,'116301','furniture-mobile','margin-left','20',0,''),(170172,54300,'116301','furniture-mobile','display','none',0,'2906'),(170173,54301,'116302','furniture-mobile','margin-right','20',0,''),(170174,54301,'116302','furniture-mobile','float','right',0,''),(170175,54301,'116302','furniture-mobile','clear','none',0,''),(170176,54301,'116302','furniture-mobile','display','none',0,'2885'),(170177,54302,'116303','furniture-mobile','float','right',0,''),(170178,54302,'116303','furniture-mobile','display','none',0,'2906'),(170179,54303,'116304','furniture-mobile','listing_type','productListing',0,''),(170180,54305,'116306','furniture-mobile','block_type','5',0,''),(170181,54305,'116306','furniture-mobile','padding-top','10',0,''),(170182,54305,'116306','furniture-mobile','padding-bottom','10',0,''),(170183,54305,'116306','furniture-mobile','schema','5-2',0,'2906'),(170184,54305,'116306','furniture-mobile','border-top-color','$border-color-4',0,''),(170185,54305,'116306','furniture-mobile','border-top-width','1',0,''),(170186,54307,'116308','furniture-mobile','float','right',0,''),(170187,54308,'116309','furniture-mobile','block_type','1',0,''),(170188,54311,'116312','furniture-mobile','block_type','1',0,''),(170189,54311,'116312','furniture-mobile','padding-top','10',0,''),(170190,54311,'116312','furniture-mobile','padding-bottom','10',0,''),(170191,54311,'116312','furniture-mobile','border-bottom-width','1',0,''),(170192,54311,'116312','furniture-mobile','border-bottom-color','$border-color-4',0,''),(170193,54311,'116312','furniture-mobile','margin-left','0',0,''),(170194,54311,'116312','furniture-mobile','margin-right','0',0,''),(170195,54312,'116313','furniture-mobile','float','left',0,''),(170196,54312,'116313','furniture-mobile','clear','none',0,''),(170197,54312,'116313','furniture-mobile','margin-left','20',0,''),(170198,54312,'116313','furniture-mobile','display','none',0,'2906'),(170199,54313,'116314','furniture-mobile','float','left',0,''),(170200,54313,'116314','furniture-mobile','clear','none',0,''),(170201,54313,'116314','furniture-mobile','sort_pos_3','1',0,''),(170202,54313,'116314','furniture-mobile','sort_pos_4','2',0,''),(170203,54313,'116314','furniture-mobile','sort_pos_10','3',0,''),(170204,54313,'116314','furniture-mobile','sort_pos_9','4',0,''),(170205,54313,'116314','furniture-mobile','sort_pos_11','5',0,''),(170206,54313,'116314','furniture-mobile','sort_pos_12','6',0,''),(170207,54313,'116314','furniture-mobile','sort_pos_14','7',0,''),(170208,54313,'116314','furniture-mobile','sort_pos_13','8',0,''),(170209,54313,'116314','furniture-mobile','sort_pos_8','9',0,''),(170210,54313,'116314','furniture-mobile','sort_pos_7','10',0,''),(170211,54313,'116314','furniture-mobile','sort_pos_2','11',0,''),(170212,54313,'116314','furniture-mobile','sort_pos_1','12',0,''),(170213,54313,'116314','furniture-mobile','sort_pos_6','13',0,''),(170214,54313,'116314','furniture-mobile','sort_pos_5','14',0,''),(170215,54313,'116314','furniture-mobile','sort_pos_0','15',0,''),(170216,54313,'116314','furniture-mobile','sort_hide_10','1',0,''),(170217,54313,'116314','furniture-mobile','sort_hide_9','1',0,''),(170218,54313,'116314','furniture-mobile','hide_icons','1',0,''),(170219,54313,'116314','furniture-mobile','sort_hide_16','1',0,''),(170220,54313,'116314','furniture-mobile','sort_hide_15','1',0,''),(170221,54313,'116314','furniture-mobile','sort_hide_3','0',0,''),(170222,54313,'116314','furniture-mobile','sort_hide_4','0',0,''),(170223,54313,'116314','furniture-mobile','sort_hide_11','1',0,''),(170224,54313,'116314','furniture-mobile','sort_hide_12','1',0,''),(170225,54313,'116314','furniture-mobile','sort_hide_14','1',0,''),(170226,54313,'116314','furniture-mobile','sort_hide_13','1',0,''),(170227,54313,'116314','furniture-mobile','sort_hide_8','0',0,''),(170228,54313,'116314','furniture-mobile','sort_hide_7','0',0,''),(170229,54313,'116314','furniture-mobile','sort_hide_2','1',0,''),(170230,54313,'116314','furniture-mobile','sort_hide_1','1',0,''),(170231,54313,'116314','furniture-mobile','sort_hide_6','1',0,''),(170232,54313,'116314','furniture-mobile','sort_hide_5','1',0,''),(170233,54313,'116314','furniture-mobile','sort_hide_0','1',0,''),(170234,54314,'116315','furniture-mobile','margin-right','20',0,''),(170235,54314,'116315','furniture-mobile','float','right',0,''),(170236,54314,'116315','furniture-mobile','clear','none',0,''),(170237,54314,'116315','furniture-mobile','display','none',0,'2885'),(170238,54315,'116316','furniture-mobile','float','right',0,''),(170239,54315,'116316','furniture-mobile','display','none',0,'2906'),(170240,54316,'116317','furniture-mobile','clear','none',0,''),(170241,54316,'116317','furniture-mobile','float','left',0,''),(170242,54316,'116317','furniture-mobile','padding-top','3',0,''),(170243,54316,'116317','furniture-mobile','padding-left','20',0,''),(170244,54317,'116318','furniture-mobile','block_type','5',0,''),(170245,54317,'116318','furniture-mobile','padding-top','10',0,''),(170246,54317,'116318','furniture-mobile','padding-bottom','10',0,''),(170247,54317,'116318','furniture-mobile','schema','5-2',0,'2906'),(170248,54317,'116318','furniture-mobile','border-top-color','$border-color-4',0,''),(170249,54317,'116318','furniture-mobile','border-top-width','1',0,''),(170250,54319,'116320','furniture-mobile','float','right',0,''),(170251,54320,'116321','furniture-mobile','col_in_row','4',0,''),(170252,54320,'116321','furniture-mobile','products_align','left',0,''),(170253,54320,'116321','furniture-mobile','font-weight','400',0,''),(170254,54320,'116321','furniture-mobile','show_qty_input','0',0,''),(170255,54320,'116321','furniture-mobile','listing_type','productListing',0,''),(170256,54320,'116321','furniture-mobile','listing_type_rows','Rows',0,''),(170257,54320,'116321','furniture-mobile','show_buy_button_b2b','on',0,''),(170258,54320,'116321','furniture-mobile','show_wishlist_button_b2b','1',0,''),(170259,54320,'116321','furniture-mobile','show_compare_b2b','1',0,''),(170260,54320,'116321','furniture-mobile','listing_type_b2b','b2b',0,''),(170261,54320,'116321','furniture-mobile','show_image','0',0,''),(170262,54320,'116321','furniture-mobile','show_stock','0',0,''),(170263,54320,'116321','furniture-mobile','show_description','0',0,''),(170264,54320,'116321','furniture-mobile','show_model','0',0,''),(170265,54320,'116321','furniture-mobile','show_properties','0',0,''),(170266,54320,'116321','furniture-mobile','show_rating','0',0,''),(170267,54320,'116321','furniture-mobile','show_rating_counts','0',0,''),(170268,54320,'116321','furniture-mobile','show_price','0',0,''),(170269,54320,'116321','furniture-mobile','show_buy_button','0',0,''),(170270,54320,'116321','furniture-mobile','show_view_button','0',0,''),(170271,54320,'116321','furniture-mobile','show_wishlist_button','0',0,''),(170272,54320,'116321','furniture-mobile','show_compare','0',0,''),(170273,54320,'116321','furniture-mobile','show_name_rows','0',0,''),(170274,54320,'116321','furniture-mobile','show_image_rows','0',0,''),(170275,54320,'116321','furniture-mobile','show_stock_rows','0',0,''),(170276,54320,'116321','furniture-mobile','show_description_rows','0',0,''),(170277,54320,'116321','furniture-mobile','show_model_rows','0',0,''),(170278,54320,'116321','furniture-mobile','show_properties_rows','0',0,''),(170279,54320,'116321','furniture-mobile','show_rating_rows','0',0,''),(170280,54320,'116321','furniture-mobile','show_rating_counts_rows','0',0,''),(170281,54320,'116321','furniture-mobile','show_price_rows','0',0,''),(170282,54320,'116321','furniture-mobile','show_buy_button_rows','0',0,''),(170283,54320,'116321','furniture-mobile','show_qty_input_rows','0',0,''),(170284,54320,'116321','furniture-mobile','show_view_button_rows','0',0,''),(170285,54320,'116321','furniture-mobile','show_wishlist_button_rows','0',0,''),(170286,54320,'116321','furniture-mobile','show_compare_rows','0',0,''),(170287,54320,'116321','furniture-mobile','show_name_b2b','0',0,''),(170288,54320,'116321','furniture-mobile','show_image_b2b','0',0,''),(170289,54320,'116321','furniture-mobile','show_stock_b2b','0',0,''),(170290,54320,'116321','furniture-mobile','show_description_b2b','0',0,''),(170291,54320,'116321','furniture-mobile','show_model_b2b','0',0,''),(170292,54320,'116321','furniture-mobile','show_properties_b2b','0',0,''),(170293,54320,'116321','furniture-mobile','show_rating_b2b','0',0,''),(170294,54320,'116321','furniture-mobile','show_rating_counts_b2b','0',0,''),(170295,54320,'116321','furniture-mobile','show_price_b2b','0',0,''),(170296,54320,'116321','furniture-mobile','show_qty_input_b2b','0',0,''),(170297,54320,'116321','furniture-mobile','show_view_button_b2b','0',0,''),(170298,54320,'116321','furniture-mobile','show_attributes_b2b','0',0,''),(170299,54320,'116321','furniture-mobile','items_on_page','12',0,''),(170300,54320,'116321','furniture-mobile','col_in_row','2',0,'2885'),(170301,54320,'116321','furniture-mobile','col_in_row','1',0,'2906'),(170302,54320,'116321','furniture-mobile','product_names_teg','h2',0,''),(170303,54323,'1683112094.454335','furniture-mobile','block_type','1',0,''),(170304,54323,'1683112094.454335','furniture-mobile','background-color','$background-6',0,''),(170305,54323,'1683112094.454335','furniture-mobile','padding-top','30',0,''),(170306,54323,'1683112094.454335','furniture-mobile','padding-bottom','30',0,''),(170307,54323,'1683112094.454335','furniture-mobile','style_class','checkout-index-wrap',0,''),(170308,54324,'1683112094.46510','furniture-mobile','block_type','7',0,''),(170309,54324,'1683112094.46510','furniture-mobile','schema','4-2',0,'2885'),(170310,54325,'1683112094.466634','furniture-mobile','block_type','1',0,''),(170311,54325,'1683112094.466634','furniture-mobile','padding-right','0',0,'2885'),(170312,54326,'1683112094.468254','furniture-mobile','block_type','1',0,''),(170313,54326,'1683112094.468254','furniture-mobile','background-color','$background-7',0,''),(170314,54326,'1683112094.468254','furniture-mobile','padding-top','30',0,''),(170315,54326,'1683112094.468254','furniture-mobile','padding-left','30',0,''),(170316,54326,'1683112094.468254','furniture-mobile','padding-right','30',0,''),(170317,54326,'1683112094.468254','furniture-mobile','padding-bottom','14',0,''),(170318,54326,'1683112094.468254','furniture-mobile','margin-bottom','20',0,''),(170319,54326,'1683112094.468254','furniture-mobile','style_class','hiding-box closeable-box',0,''),(170320,54327,'1683112094.470662','furniture-mobile','style_class','closeable-content',0,''),(170321,54327,'1683112094.470662','furniture-mobile','padding-bottom','20',0,''),(170322,54328,'1683112094.473482','furniture-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(170323,54328,'1683112094.473482','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(170324,54329,'1683112094.477128','furniture-mobile','block_type','1',0,''),(170325,54329,'1683112094.477128','furniture-mobile','padding-top','30',0,''),(170326,54329,'1683112094.477128','furniture-mobile','padding-left','30',0,''),(170327,54329,'1683112094.477128','furniture-mobile','padding-right','30',0,''),(170328,54329,'1683112094.477128','furniture-mobile','padding-bottom','14',0,''),(170329,54329,'1683112094.477128','furniture-mobile','margin-bottom','20',0,''),(170330,54329,'1683112094.477128','furniture-mobile','background-color','$background-7',0,''),(170331,54329,'1683112094.477128','furniture-mobile','style_class','hiding-box closeable-box',0,''),(170332,54330,'1683112094.479689','furniture-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(170333,54330,'1683112094.479689','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(170334,54331,'1683112094.481499','furniture-mobile','block_type','2',0,''),(170335,54331,'1683112094.481499','furniture-mobile','style_class','closeable-content',0,''),(170336,54331,'1683112094.481499','furniture-mobile','schema','2-2',0,'2885'),(170337,54332,'1683112094.482824','furniture-mobile','padding-right','20',0,''),(170338,54332,'1683112094.482824','furniture-mobile','padding-bottom','20',0,''),(170339,54332,'1683112094.482824','furniture-mobile','padding-right','0',0,'2885'),(170340,54333,'1683112094.484566','furniture-mobile','padding-left','20',0,''),(170341,54333,'1683112094.484566','furniture-mobile','padding-bottom','20',0,''),(170342,54333,'1683112094.484566','furniture-mobile','padding-left','0',0,'2885'),(170343,54334,'1683112094.486280','furniture-mobile','padding-left','20',0,''),(170344,54334,'1683112094.486280','furniture-mobile','padding-bottom','20',0,''),(170345,54334,'1683112094.486280','furniture-mobile','padding-left','0',0,'2885'),(170346,54335,'1683112094.487748','furniture-mobile','background-color','$background-7',0,''),(170347,54335,'1683112094.487748','furniture-mobile','block_type','1',0,''),(170348,54335,'1683112094.487748','furniture-mobile','padding-top','30',0,''),(170349,54335,'1683112094.487748','furniture-mobile','padding-left','30',0,''),(170350,54335,'1683112094.487748','furniture-mobile','padding-right','30',0,''),(170351,54335,'1683112094.487748','furniture-mobile','padding-bottom','30',0,''),(170352,54335,'1683112094.487748','furniture-mobile','margin-bottom','20',0,''),(170353,54335,'1683112094.487748','furniture-mobile','style_class','hiding-box',0,''),(170354,54336,'1683112094.489595','furniture-mobile','block_type','1',0,''),(170355,54336,'1683112094.489595','furniture-mobile','content','\\_',0,'3'),(170356,54336,'1683112094.489595','furniture-mobile','border-top-width','1',0,'3'),(170357,54336,'1683112094.489595','furniture-mobile','border-top-color','$border-color-4',0,'3'),(170358,54336,'1683112094.489595','furniture-mobile','display','block',0,'3'),(170359,54336,'1683112094.489595','furniture-mobile','position','absolute',0,'3'),(170360,54336,'1683112094.489595','furniture-mobile','top','19',0,'3'),(170361,54336,'1683112094.489595','furniture-mobile','left','0',0,'3'),(170362,54336,'1683112094.489595','furniture-mobile','right','0',0,'3'),(170363,54336,'1683112094.489595','furniture-mobile','margin-top','-2',0,'3'),(170364,54336,'1683112094.489595','furniture-mobile','position','relative',0,''),(170365,54337,'1683112094.491715','furniture-mobile','box_align','2',0,''),(170366,54337,'1683112094.491715','furniture-mobile','margin-bottom','10',0,''),(170367,54337,'1683112094.491715','furniture-mobile','background-color','$background-7',0,''),(170368,54337,'1683112094.491715','furniture-mobile','position','relative',0,''),(170369,54338,'1683112094.49547','furniture-mobile','background-color','$background-6',0,''),(170370,54338,'1683112094.49547','furniture-mobile','padding-top','10',0,''),(170371,54338,'1683112094.49547','furniture-mobile','padding-left','10',0,''),(170372,54338,'1683112094.49547','furniture-mobile','padding-right','10',0,''),(170373,54338,'1683112094.49547','furniture-mobile','padding-bottom','10',0,''),(170374,54338,'1683112094.49547','furniture-mobile','margin-top','10',0,''),(170375,54339,'1683112094.496940','furniture-mobile','block_type','2',0,''),(170376,54339,'1683112094.496940','furniture-mobile','schema','2-2',0,'2885'),(170377,54340,'1683112094.498374','furniture-mobile','block_type','1',0,''),(170378,54340,'1683112094.498374','furniture-mobile','padding-right','20',0,''),(170379,54340,'1683112094.498374','furniture-mobile','padding-left','0',0,'2885'),(170380,54340,'1683112094.498374','furniture-mobile','margin-bottom','20',0,'2885'),(170381,54340,'1683112094.498374','furniture-mobile','padding-right','0',0,'2885'),(170382,54341,'1683112094.499910','furniture-mobile','address_in','popup',0,''),(170383,54342,'1683112094.502626','furniture-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(170384,54345,'1683112094.508236','furniture-mobile','block_type','1',0,''),(170385,54345,'1683112094.508236','furniture-mobile','padding-left','20',0,''),(170386,54345,'1683112094.508236','furniture-mobile','padding-left','0',0,'2885'),(170387,54347,'1683112094.510627','furniture-mobile','border-top-width','1',0,''),(170388,54347,'1683112094.510627','furniture-mobile','border-top-color','$border-color-4',0,''),(170389,54347,'1683112094.510627','furniture-mobile','padding-top','13',0,''),(170390,54347,'1683112094.510627','furniture-mobile','padding-bottom','10',0,''),(170391,54348,'1683112094.511898','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(170392,54349,'1683112094.513380','furniture-mobile','show_day','next_day',0,''),(170393,54351,'1683112094.518294','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(170394,54352,'1683112094.5284','furniture-mobile','block_type','1',0,''),(170395,54352,'1683112094.5284','furniture-mobile','background-color','$background-7',0,''),(170396,54352,'1683112094.5284','furniture-mobile','padding-top','30',0,''),(170397,54352,'1683112094.5284','furniture-mobile','padding-left','30',0,''),(170398,54352,'1683112094.5284','furniture-mobile','padding-right','30',0,''),(170399,54352,'1683112094.5284','furniture-mobile','padding-bottom','30',0,''),(170400,54352,'1683112094.5284','furniture-mobile','margin-bottom','20',0,''),(170401,54352,'1683112094.5284','furniture-mobile','style_class','hiding-box',0,''),(170402,54353,'1683112094.522685','furniture-mobile','margin-bottom','20',0,''),(170403,54354,'1683112094.52788','furniture-mobile','padding-top','10',0,''),(170404,54354,'1683112094.52788','furniture-mobile','padding-left','20',0,''),(170405,54354,'1683112094.52788','furniture-mobile','padding-right','20',0,''),(170406,54354,'1683112094.52788','furniture-mobile','margin-top','20',0,''),(170407,54354,'1683112094.52788','furniture-mobile','background-color','$background-6',0,''),(170408,54354,'1683112094.52788','furniture-mobile','padding-bottom','8',0,''),(170409,54356,'1683112094.532112','furniture-mobile','block_type','1',0,''),(170410,54356,'1683112094.532112','furniture-mobile','padding-top','30',0,''),(170411,54356,'1683112094.532112','furniture-mobile','padding-left','30',0,''),(170412,54356,'1683112094.532112','furniture-mobile','padding-right','30',0,''),(170413,54356,'1683112094.532112','furniture-mobile','padding-bottom','23',0,''),(170414,54356,'1683112094.532112','furniture-mobile','margin-bottom','20',0,''),(170415,54356,'1683112094.532112','furniture-mobile','background-color','$background-7',0,''),(170416,54356,'1683112094.532112','furniture-mobile','style_class','hiding-box',0,''),(170417,54357,'1683112094.53526','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(170418,54358,'1683112094.536687','furniture-mobile','block_type','2',0,''),(170419,54358,'1683112094.536687','furniture-mobile','schema','2-2',0,'2885'),(170420,54359,'1683112094.53846','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170421,54360,'1683112094.539137','furniture-mobile','padding-right','20',0,''),(170422,54360,'1683112094.539137','furniture-mobile','padding-right','0',0,'2885'),(170423,54360,'1683112094.539137','furniture-mobile','padding-bottom','20',0,'2885'),(170424,54360,'1683112094.539137','furniture-mobile','address_in','popup',0,''),(170425,54361,'1683112094.542437','furniture-mobile','block_type','1',0,''),(170426,54361,'1683112094.542437','furniture-mobile','padding-left','20',0,''),(170427,54361,'1683112094.542437','furniture-mobile','padding-left','0',0,'2885'),(170428,54363,'1683112094.544994','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170429,54364,'1683112094.546257','furniture-mobile','block_type','1',0,''),(170430,54364,'1683112094.546257','furniture-mobile','background-color','$background-7',0,''),(170431,54364,'1683112094.546257','furniture-mobile','padding-top','20',0,''),(170432,54364,'1683112094.546257','furniture-mobile','padding-left','30',0,''),(170433,54364,'1683112094.546257','furniture-mobile','padding-right','30',0,''),(170434,54364,'1683112094.546257','furniture-mobile','padding-bottom','20',0,''),(170435,54364,'1683112094.546257','furniture-mobile','margin-bottom','20',0,''),(170436,54366,'1683112094.549336','furniture-mobile','block_type','1',0,''),(170437,54366,'1683112094.549336','furniture-mobile','padding-top','10',0,''),(170438,54366,'1683112094.549336','furniture-mobile','padding-left','10',0,''),(170439,54366,'1683112094.549336','furniture-mobile','padding-right','10',0,''),(170440,54366,'1683112094.549336','furniture-mobile','padding-bottom','10',0,''),(170441,54366,'1683112094.549336','furniture-mobile','background-color','$background-7',0,''),(170442,54366,'1683112094.549336','furniture-mobile','style_class','order-summary',0,''),(170443,54366,'1683112094.549336','furniture-mobile','margin-left','25',0,''),(170444,54366,'1683112094.549336','furniture-mobile','margin-left','0',0,'2885'),(170445,54367,'1683112094.554924','furniture-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(170446,54367,'1683112094.554924','furniture-mobile','text-align','center',0,''),(170447,54367,'1683112094.554924','furniture-mobile','font-size','14',0,''),(170448,54367,'1683112094.554924','furniture-mobile','color','$color-font-9',0,''),(170449,54367,'1683112094.554924','furniture-mobile','padding-top','10',0,''),(170450,54368,'1683112094.556948','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(170451,54369,'1683112094.558436','furniture-mobile','hide_page','1',0,''),(170452,54369,'1683112094.558436','furniture-mobile','hide_continue_button','1',0,''),(170453,54370,'1683112094.560477','furniture-mobile','margin-bottom','10',0,''),(170454,54372,'116368','furniture-mobile','block_type','1',0,''),(170455,54374,'116370','furniture-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(170456,54375,'116371','furniture-mobile','link','products',0,''),(170457,54375,'116371','furniture-mobile','margin-top','-33',0,''),(170458,54375,'116371','furniture-mobile','float','right',0,''),(170459,54376,'116372','furniture-mobile','block_type','2',0,''),(170460,54376,'116372','furniture-mobile','margin-bottom','20',0,''),(170461,54376,'116372','furniture-mobile','schema','2-2',0,'2876'),(170462,54377,'116373','furniture-mobile','block_type','1',0,''),(170463,54377,'116373','furniture-mobile','padding-right','20',0,''),(170464,54377,'116373','furniture-mobile','padding-right','0',0,'2876'),(170465,54378,'116374','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(170466,54378,'116374','furniture-mobile','clear','none',0,''),(170467,54380,'116376','furniture-mobile','padding-left','20',0,''),(170468,54380,'116376','furniture-mobile','block_type','1',0,''),(170469,54380,'116376','furniture-mobile','padding-left','0',0,'2876'),(170470,54382,'116378','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170471,54382,'116378','furniture-mobile','clear','none',0,''),(170472,54383,'116379','furniture-mobile','text-align','center',0,''),(170473,54383,'116379','furniture-mobile','margin-bottom','10',0,''),(170474,54384,'116380','furniture-mobile','block_type','2',0,''),(170475,54384,'116380','furniture-mobile','margin-bottom','20',0,''),(170476,54384,'116380','furniture-mobile','schema','2-2',0,'2876'),(170477,54385,'116381','furniture-mobile','block_type','1',0,''),(170478,54385,'116381','furniture-mobile','padding-right','20',0,''),(170479,54385,'116381','furniture-mobile','padding-right','0',0,'2876'),(170480,54387,'116383','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(170481,54387,'116383','furniture-mobile','clear','none',0,''),(170482,54388,'116384','furniture-mobile','block_type','1',0,''),(170483,54388,'116384','furniture-mobile','padding-left','20',0,''),(170484,54388,'116384','furniture-mobile','padding-left','0',0,'2876'),(170485,54389,'116385','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170486,54389,'116385','furniture-mobile','clear','none',0,''),(170487,54391,'116387','furniture-mobile','margin-bottom','20',0,''),(170488,54391,'116387','furniture-mobile','text-align','center',0,''),(170489,54393,'116402','furniture-mobile','block_type','1',0,''),(170490,54394,'116403','furniture-mobile','text-align','right',0,''),(170491,54394,'116403','furniture-mobile','margin-bottom','20',0,''),(170492,54395,'116404','furniture-mobile','block_type','2',0,''),(170493,54395,'116404','furniture-mobile','margin-bottom','20',0,''),(170494,54395,'116404','furniture-mobile','schema','2-2',0,'2876'),(170495,54396,'116405','furniture-mobile','block_type','1',0,''),(170496,54396,'116405','furniture-mobile','padding-right','20',0,''),(170497,54396,'116405','furniture-mobile','padding-right','0',0,'2876'),(170498,54397,'116406','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170499,54397,'116406','furniture-mobile','clear','none',0,''),(170500,54399,'116408','furniture-mobile','block_type','1',0,''),(170501,54399,'116408','furniture-mobile','padding-left','20',0,''),(170502,54399,'116408','furniture-mobile','padding-left','0',0,'2876'),(170503,54400,'116409','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170504,54400,'116409','furniture-mobile','clear','none',0,''),(170505,54402,'116411','furniture-mobile','margin-bottom','20',0,''),(170506,54402,'116411','furniture-mobile','text-align','right',0,''),(170507,54405,'116414','furniture-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(170508,54406,'116389','furniture-mobile','block_type','1',0,''),(170509,54407,'116390','furniture-mobile','margin-bottom','20',0,''),(170510,54408,'116391','furniture-mobile','margin-bottom','20',0,''),(170511,54408,'116391','furniture-mobile','text-align','right',0,''),(170512,54409,'116392','furniture-mobile','text-align','right',0,''),(170513,54409,'116392','furniture-mobile','margin-bottom','20',0,''),(170514,54410,'116393','furniture-mobile','block_type','2',0,''),(170515,54410,'116393','furniture-mobile','margin-bottom','20',0,''),(170516,54410,'116393','furniture-mobile','schema','2-2',0,'2876'),(170517,54411,'116394','furniture-mobile','block_type','1',0,''),(170518,54411,'116394','furniture-mobile','padding-right','20',0,''),(170519,54411,'116394','furniture-mobile','padding-right','0',0,'2876'),(170520,54413,'116396','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170521,54413,'116396','furniture-mobile','clear','none',0,''),(170522,54414,'116397','furniture-mobile','block_type','1',0,''),(170523,54414,'116397','furniture-mobile','padding-left','20',0,''),(170524,54414,'116397','furniture-mobile','padding-left','0',0,'2876'),(170525,54416,'116399','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170526,54416,'116399','furniture-mobile','clear','none',0,''),(170527,54417,'116400','furniture-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(170528,54418,'116401','furniture-mobile','margin-bottom','20',0,''),(170529,54419,'116415','furniture-mobile','block_type','1',0,''),(170530,54420,'116416','furniture-mobile','block_type','2',0,''),(170531,54420,'116416','furniture-mobile','margin-bottom','20',0,''),(170532,54420,'116416','furniture-mobile','schema','2-2',0,'2876'),(170533,54421,'116417','furniture-mobile','block_type','1',0,''),(170534,54421,'116417','furniture-mobile','padding-right','20',0,''),(170535,54421,'116417','furniture-mobile','padding-right','0',0,'2876'),(170536,54423,'116419','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(170537,54423,'116419','furniture-mobile','clear','none',0,''),(170538,54424,'116420','furniture-mobile','block_type','1',0,''),(170539,54424,'116420','furniture-mobile','padding-left','20',0,''),(170540,54424,'116420','furniture-mobile','padding-left','0',0,'2876'),(170541,54426,'116422','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170542,54426,'116422','furniture-mobile','clear','none',0,''),(170543,54427,'116423','furniture-mobile','margin-bottom','20',0,''),(170544,54428,'116424','furniture-mobile','margin-bottom','20',0,''),(170545,54429,'116425','furniture-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(170546,54430,'116426','furniture-mobile','link','products',0,''),(170547,54430,'116426','furniture-mobile','margin-top','-33',0,''),(170548,54430,'116426','furniture-mobile','float','right',0,''),(170549,54431,'116427','furniture-mobile','text-align','right',0,''),(170550,54431,'116427','furniture-mobile','margin-bottom','20',0,''),(170551,54432,'116428','furniture-mobile','margin-bottom','20',0,''),(170552,54432,'116428','furniture-mobile','text-align','right',0,''),(170553,54433,'116429','furniture-mobile','block_type','2',0,''),(170554,54433,'116429','furniture-mobile','margin-bottom','20',0,''),(170555,54433,'116429','furniture-mobile','schema','2-2',0,'2876'),(170556,54434,'116430','furniture-mobile','block_type','1',0,''),(170557,54434,'116430','furniture-mobile','padding-right','20',0,''),(170558,54434,'116430','furniture-mobile','padding-right','0',0,'2876'),(170559,54435,'116431','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(170560,54435,'116431','furniture-mobile','clear','none',0,''),(170561,54437,'116433','furniture-mobile','padding-left','20',0,''),(170562,54437,'116433','furniture-mobile','block_type','1',0,''),(170563,54437,'116433','furniture-mobile','padding-left','0',0,'2876'),(170564,54438,'116434','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170565,54438,'116434','furniture-mobile','clear','none',0,''),(170566,54440,'116436','furniture-mobile','text','##TEXT_CONFIRMATION##',0,''),(170567,54441,'116437','furniture-mobile','text','##TEXT_CONFIRMATION##',0,''),(170568,54442,'116439','furniture-mobile','text','##TEXT_CONFIRMATION##',0,''),(170569,54443,'116438','furniture-mobile','text','##TEXT_CONFIRMATION##',0,''),(170570,54444,'116440','furniture-mobile','text','##TEXT_CONFIRMATION##',0,''),(170571,54445,'116441','furniture-mobile','text','##TEXT_CONFIRMATION##',0,''),(170572,54446,'116442','furniture-mobile','block_type','1',0,''),(170573,54447,'116443','furniture-mobile','block_type','1',0,''),(170574,54447,'116443','furniture-mobile','padding-right','20',0,''),(170575,54448,'116444','furniture-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(170576,54450,'116446','furniture-mobile','block_type','1',0,''),(170577,54450,'116446','furniture-mobile','padding-left','20',0,''),(170578,54450,'116446','furniture-mobile','padding-left','0',0,'2885'),(170579,54451,'116447','furniture-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(170580,54453,'116449','furniture-mobile','block_type','4',0,''),(170581,54453,'116449','furniture-mobile','schema','4-2',0,'2906'),(170582,54454,'116450','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170583,54454,'116450','furniture-mobile','text-align','center',0,''),(170584,54454,'116450','furniture-mobile','padding-top','10',0,''),(170585,54454,'116450','furniture-mobile','font_size_measure','em',0,''),(170586,54454,'116450','furniture-mobile','font-size','1.2',0,''),(170587,54455,'116451','furniture-mobile','text-align','center',0,''),(170588,54456,'116452','furniture-mobile','block_type','1',0,''),(170589,54457,'116453','furniture-mobile','block_type','1',0,''),(170590,54457,'116453','furniture-mobile','padding-right','20',0,''),(170591,54457,'116453','furniture-mobile','padding-right','0',0,'2885'),(170593,54460,'116456','furniture-mobile','block_type','1',0,''),(170594,54460,'116456','furniture-mobile','padding-right','0',0,'2885'),(170596,54463,'116459','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(170597,54465,'116461','furniture-mobile','block_type','2',0,''),(170598,54466,'116462','furniture-mobile','block_type','1',0,''),(170599,54466,'116462','furniture-mobile','padding-right','20',0,''),(170600,54468,'116464','furniture-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(170601,54469,'116465','furniture-mobile','block_type','1',0,''),(170602,54469,'116465','furniture-mobile','padding-left','20',0,''),(170603,54469,'116465','furniture-mobile','padding-left','0',0,'2885'),(170604,54470,'116466','furniture-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(170605,54472,'116468','furniture-mobile','block_type','4',0,''),(170606,54472,'116468','furniture-mobile','schema','4-2',0,'2906'),(170607,54473,'116469','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170608,54473,'116469','furniture-mobile','text-align','right',0,''),(170609,54473,'116469','furniture-mobile','padding-top','10',0,''),(170610,54473,'116469','furniture-mobile','font_size_measure','em',0,''),(170611,54473,'116469','furniture-mobile','font-size','1.2',0,''),(170612,54474,'116470','furniture-mobile','text-align','right',0,''),(170613,54475,'116471','furniture-mobile','block_type','2',0,''),(170614,54476,'116472','furniture-mobile','block_type','1',0,''),(170615,54476,'116472','furniture-mobile','padding-right','20',0,''),(170616,54476,'116472','furniture-mobile','padding-right','0',0,'2885'),(170617,54478,'116474','furniture-mobile','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(170618,54479,'116475','furniture-mobile','block_type','1',0,''),(170619,54479,'116475','furniture-mobile','padding-right','0',0,'2885'),(170620,54479,'116475','furniture-mobile','padding-left','20',0,''),(170621,54481,'116477','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(170622,54484,'116480','furniture-mobile','block_type','4',0,''),(170623,54484,'116480','furniture-mobile','schema','4-2',0,'2906'),(170624,54485,'116481','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170625,54485,'116481','furniture-mobile','text-align','right',0,''),(170626,54485,'116481','furniture-mobile','padding-top','10',0,''),(170627,54485,'116481','furniture-mobile','font_size_measure','em',0,''),(170628,54485,'116481','furniture-mobile','font-size','1.2',0,''),(170629,54486,'116482','furniture-mobile','text-align','right',0,''),(170630,54487,'116483','furniture-mobile','block_type','2',0,''),(170631,54488,'116484','furniture-mobile','block_type','1',0,''),(170632,54488,'116484','furniture-mobile','padding-right','20',0,''),(170633,54490,'116486','furniture-mobile','block_type','1',0,''),(170634,54490,'116486','furniture-mobile','padding-left','20',0,''),(170635,54490,'116486','furniture-mobile','padding-left','0',0,'2885'),(170636,54491,'116487','furniture-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(170637,54493,'116489','furniture-mobile','block_type','4',0,''),(170638,54493,'116489','furniture-mobile','schema','4-2',0,'2906'),(170639,54494,'116490','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170640,54494,'116490','furniture-mobile','text-align','right',0,''),(170641,54494,'116490','furniture-mobile','padding-top','10',0,''),(170642,54494,'116490','furniture-mobile','font_size_measure','em',0,''),(170643,54494,'116490','furniture-mobile','font-size','1.2',0,''),(170644,54495,'116491','furniture-mobile','text-align','right',0,''),(170645,54496,'116492','furniture-mobile','block_type','2',0,''),(170646,54497,'116493','furniture-mobile','block_type','1',0,''),(170647,54497,'116493','furniture-mobile','padding-right','20',0,''),(170648,54499,'116495','furniture-mobile','block_type','1',0,''),(170649,54499,'116495','furniture-mobile','padding-left','20',0,''),(170650,54499,'116495','furniture-mobile','padding-left','0',0,'2885'),(170651,54501,'116497','furniture-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(170652,54502,'116498','furniture-mobile','text','##DELIVERY_DETAILS##',0,''),(170653,54503,'116499','furniture-mobile','text','##DELIVERY_DETAILS##',0,''),(170654,54504,'116501','furniture-mobile','text','##CONTACT_INFORMATION##',0,''),(170655,54505,'116500','furniture-mobile','text','##CONTACT_INFORMATION##',0,''),(170656,54506,'116502','furniture-mobile','text','##DELIVERY_DETAILS##',0,''),(170657,54507,'116503','furniture-mobile','text','##DELIVERY_DETAILS##',0,''),(170658,54508,'116504','furniture-mobile','block_type','1',0,''),(170659,54508,'116504','furniture-mobile','background-color','$background-6',0,''),(170660,54508,'116504','furniture-mobile','padding-top','30',0,''),(170661,54508,'116504','furniture-mobile','padding-bottom','30',0,''),(170662,54509,'116505','furniture-mobile','block_type','7',0,''),(170663,54509,'116505','furniture-mobile','schema','4-2',0,'2885'),(170664,54510,'116506','furniture-mobile','block_type','1',0,''),(170665,54510,'116506','furniture-mobile','padding-right','0',0,'2885'),(170666,54511,'116508','furniture-mobile','block_type','1',0,''),(170667,54511,'116508','furniture-mobile','background-color','$background-7',0,''),(170668,54511,'116508','furniture-mobile','padding-top','30',0,''),(170669,54511,'116508','furniture-mobile','padding-left','30',0,''),(170670,54511,'116508','furniture-mobile','padding-right','30',0,''),(170671,54511,'116508','furniture-mobile','padding-bottom','30',0,''),(170672,54511,'116508','furniture-mobile','margin-bottom','20',0,''),(170673,54511,'116508','furniture-mobile','style_class','hiding-box',0,''),(170674,54512,'116509','furniture-mobile','margin-bottom','20',0,''),(170675,54513,'116510','furniture-mobile','padding-top','10',0,''),(170676,54513,'116510','furniture-mobile','padding-left','20',0,''),(170677,54513,'116510','furniture-mobile','padding-right','20',0,''),(170678,54513,'116510','furniture-mobile','margin-top','20',0,''),(170679,54513,'116510','furniture-mobile','background-color','$background-6',0,''),(170680,54513,'116510','furniture-mobile','padding-bottom','8',0,''),(170681,54514,'116511','furniture-mobile','block_type','1',0,''),(170682,54514,'116511','furniture-mobile','background-color','$background-7',0,''),(170683,54514,'116511','furniture-mobile','padding-top','30',0,''),(170684,54514,'116511','furniture-mobile','padding-left','30',0,''),(170685,54514,'116511','furniture-mobile','padding-right','30',0,''),(170686,54514,'116511','furniture-mobile','padding-bottom','14',0,''),(170687,54514,'116511','furniture-mobile','margin-bottom','20',0,''),(170688,54514,'116511','furniture-mobile','style_class','hiding-box closeable-box',0,''),(170689,54515,'116512','furniture-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(170690,54515,'116512','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(170691,54516,'116513','furniture-mobile','style_class','closeable-content',0,''),(170692,54516,'116513','furniture-mobile','padding-bottom','20',0,''),(170693,54517,'116514','furniture-mobile','background-color','$background-7',0,''),(170694,54517,'116514','furniture-mobile','block_type','1',0,''),(170695,54517,'116514','furniture-mobile','padding-top','30',0,''),(170696,54517,'116514','furniture-mobile','padding-left','30',0,''),(170697,54517,'116514','furniture-mobile','padding-right','30',0,''),(170698,54517,'116514','furniture-mobile','padding-bottom','30',0,''),(170699,54517,'116514','furniture-mobile','margin-bottom','20',0,''),(170700,54517,'116514','furniture-mobile','style_class','hiding-box',0,''),(170701,54518,'116515','furniture-mobile','block_type','1',0,''),(170702,54518,'116515','furniture-mobile','content','\\_',0,'3'),(170703,54518,'116515','furniture-mobile','border-top-width','1',0,'3'),(170704,54518,'116515','furniture-mobile','border-top-color','$border-color-4',0,'3'),(170705,54518,'116515','furniture-mobile','display','block',0,'3'),(170706,54518,'116515','furniture-mobile','position','absolute',0,'3'),(170707,54518,'116515','furniture-mobile','top','19',0,'3'),(170708,54518,'116515','furniture-mobile','left','0',0,'3'),(170709,54518,'116515','furniture-mobile','right','0',0,'3'),(170710,54518,'116515','furniture-mobile','margin-top','-2',0,'3'),(170711,54518,'116515','furniture-mobile','position','relative',0,''),(170712,54519,'116516','furniture-mobile','box_align','2',0,''),(170713,54519,'116516','furniture-mobile','margin-bottom','10',0,''),(170714,54519,'116516','furniture-mobile','background-color','$background-7',0,''),(170715,54519,'116516','furniture-mobile','position','relative',0,''),(170716,54520,'116517','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(170717,54521,'116518','furniture-mobile','block_type','2',0,''),(170718,54521,'116518','furniture-mobile','schema','2-2',0,'2885'),(170719,54522,'116519','furniture-mobile','block_type','1',0,''),(170720,54522,'116519','furniture-mobile','padding-right','20',0,''),(170721,54522,'116519','furniture-mobile','padding-left','0',0,'2885'),(170722,54522,'116519','furniture-mobile','margin-bottom','20',0,'2885'),(170723,54522,'116519','furniture-mobile','padding-right','0',0,'2885'),(170724,54525,'116522','furniture-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(170725,54526,'116523','furniture-mobile','block_type','1',0,''),(170726,54526,'116523','furniture-mobile','padding-left','20',0,''),(170727,54526,'116523','furniture-mobile','padding-left','0',0,'2885'),(170728,54527,'116524','furniture-mobile','padding-bottom','10',0,''),(170729,54528,'116525','furniture-mobile','background-color','$background-6',0,''),(170730,54528,'116525','furniture-mobile','padding-top','10',0,''),(170731,54528,'116525','furniture-mobile','padding-left','10',0,''),(170732,54528,'116525','furniture-mobile','padding-right','10',0,''),(170733,54528,'116525','furniture-mobile','padding-bottom','10',0,''),(170734,54528,'116525','furniture-mobile','margin-top','10',0,''),(170735,54529,'116526','furniture-mobile','block_type','1',0,''),(170736,54529,'116526','furniture-mobile','padding-top','10',0,''),(170737,54529,'116526','furniture-mobile','padding-left','10',0,''),(170738,54529,'116526','furniture-mobile','padding-right','10',0,''),(170739,54529,'116526','furniture-mobile','padding-bottom','10',0,''),(170740,54529,'116526','furniture-mobile','background-color','$background-7',0,''),(170741,54529,'116526','furniture-mobile','style_class','order-summary',0,''),(170742,54529,'116526','furniture-mobile','margin-left','25',0,''),(170743,54529,'116526','furniture-mobile','margin-left','0',0,'2885'),(170744,54530,'116527','furniture-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(170745,54530,'116527','furniture-mobile','text-align','center',0,''),(170746,54530,'116527','furniture-mobile','font-size','14',0,''),(170747,54530,'116527','furniture-mobile','color','$color-font-9',0,''),(170748,54530,'116527','furniture-mobile','padding-top','10',0,''),(170749,54533,'1638957135.2709','furniture-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(170750,54534,'116529','furniture-mobile','block_type','1',0,''),(170751,54534,'116529','furniture-mobile','background-color','$background-6',0,''),(170752,54534,'116529','furniture-mobile','padding-top','30',0,''),(170753,54534,'116529','furniture-mobile','padding-bottom','30',0,''),(170754,54535,'116530','furniture-mobile','block_type','7',0,''),(170755,54536,'116531','furniture-mobile','block_type','1',0,''),(170756,54537,'116532','furniture-mobile','block_type','1',0,''),(170757,54537,'116532','furniture-mobile','background-color','$background-7',0,''),(170758,54537,'116532','furniture-mobile','padding-top','30',0,''),(170759,54537,'116532','furniture-mobile','padding-left','30',0,''),(170760,54537,'116532','furniture-mobile','padding-right','30',0,''),(170761,54537,'116532','furniture-mobile','padding-bottom','30',0,''),(170762,54537,'116532','furniture-mobile','margin-bottom','20',0,''),(170763,54537,'116532','furniture-mobile','style_class','hiding-box',0,''),(170764,54538,'116533','furniture-mobile','padding-top','10',0,''),(170765,54538,'116533','furniture-mobile','padding-left','20',0,''),(170766,54538,'116533','furniture-mobile','padding-right','20',0,''),(170767,54538,'116533','furniture-mobile','margin-top','20',0,''),(170768,54538,'116533','furniture-mobile','background-color','$background-6',0,''),(170769,54538,'116533','furniture-mobile','padding-bottom','8',0,''),(170770,54539,'116534','furniture-mobile','margin-bottom','20',0,''),(170771,54540,'116535','furniture-mobile','block_type','1',0,''),(170772,54540,'116535','furniture-mobile','padding-top','30',0,''),(170773,54540,'116535','furniture-mobile','padding-left','30',0,''),(170774,54540,'116535','furniture-mobile','padding-right','30',0,''),(170775,54540,'116535','furniture-mobile','padding-bottom','23',0,''),(170776,54540,'116535','furniture-mobile','margin-bottom','20',0,''),(170777,54540,'116535','furniture-mobile','background-color','$background-7',0,''),(170778,54540,'116535','furniture-mobile','style_class','hiding-box',0,''),(170779,54541,'116536','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(170780,54542,'116537','furniture-mobile','block_type','2',0,''),(170781,54543,'116538','furniture-mobile','padding-right','20',0,''),(170782,54544,'116539','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170783,54545,'116540','furniture-mobile','block_type','1',0,''),(170784,54545,'116540','furniture-mobile','padding-left','20',0,''),(170785,54546,'116541','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170786,54548,'116543','furniture-mobile','block_type','1',0,''),(170787,54548,'116543','furniture-mobile','padding-top','30',0,''),(170788,54548,'116543','furniture-mobile','padding-left','30',0,''),(170789,54548,'116543','furniture-mobile','padding-right','30',0,''),(170790,54548,'116543','furniture-mobile','padding-bottom','14',0,''),(170791,54548,'116543','furniture-mobile','margin-bottom','20',0,''),(170792,54548,'116543','furniture-mobile','background-color','$background-7',0,''),(170793,54548,'116543','furniture-mobile','style_class','hiding-box closeable-box',0,''),(170794,54549,'116544','furniture-mobile','block_type','2',0,''),(170795,54549,'116544','furniture-mobile','style_class','closeable-content',0,''),(170796,54550,'116545','furniture-mobile','padding-right','20',0,''),(170797,54550,'116545','furniture-mobile','padding-bottom','20',0,''),(170798,54551,'116546','furniture-mobile','padding-left','20',0,''),(170799,54551,'116546','furniture-mobile','padding-bottom','20',0,''),(170800,54552,'116547','furniture-mobile','padding-left','20',0,''),(170801,54552,'116547','furniture-mobile','padding-bottom','20',0,''),(170802,54553,'116548','furniture-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(170803,54553,'116548','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(170804,54554,'116549','furniture-mobile','block_type','1',0,''),(170805,54554,'116549','furniture-mobile','background-color','$background-7',0,''),(170806,54554,'116549','furniture-mobile','padding-top','30',0,''),(170807,54554,'116549','furniture-mobile','padding-left','30',0,''),(170808,54554,'116549','furniture-mobile','padding-right','30',0,''),(170809,54554,'116549','furniture-mobile','padding-bottom','14',0,''),(170810,54554,'116549','furniture-mobile','margin-bottom','20',0,''),(170811,54554,'116549','furniture-mobile','style_class','hiding-box closeable-box',0,''),(170812,54555,'116550','furniture-mobile','style_class','closeable-content',0,''),(170813,54555,'116550','furniture-mobile','padding-bottom','20',0,''),(170814,54556,'116551','furniture-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(170815,54556,'116551','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(170816,54557,'116552','furniture-mobile','block_type','1',0,''),(170817,54557,'116552','furniture-mobile','padding-top','10',0,''),(170818,54557,'116552','furniture-mobile','padding-left','10',0,''),(170819,54557,'116552','furniture-mobile','padding-right','10',0,''),(170820,54557,'116552','furniture-mobile','padding-bottom','10',0,''),(170821,54557,'116552','furniture-mobile','background-color','$background-7',0,''),(170822,54557,'116552','furniture-mobile','style_class','order-summary hiding-box',0,''),(170823,54557,'116552','furniture-mobile','margin-left','25',0,''),(170824,54558,'116553','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(170825,54559,'116554','furniture-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(170826,54559,'116554','furniture-mobile','text-align','center',0,''),(170827,54559,'116554','furniture-mobile','font-size','14',0,''),(170828,54559,'116554','furniture-mobile','color','$color-font-9',0,''),(170829,54559,'116554','furniture-mobile','padding-top','10',0,''),(170830,54560,'116555','furniture-mobile','margin-bottom','10',0,''),(170831,54562,'116557','furniture-mobile','hide_page','1',0,''),(170832,54562,'116557','furniture-mobile','hide_continue_button','1',0,''),(170833,54563,'116558','furniture-mobile','block_type','1',0,''),(170834,54565,'116560','furniture-mobile','block_type','4',0,''),(170835,54565,'116560','furniture-mobile','schema','4-2',0,'2906'),(170836,54566,'116561','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170837,54566,'116561','furniture-mobile','text-align','right',0,''),(170838,54566,'116561','furniture-mobile','padding-top','10',0,''),(170839,54566,'116561','furniture-mobile','font_size_measure','em',0,''),(170840,54566,'116561','furniture-mobile','font-size','1.2',0,''),(170841,54567,'116562','furniture-mobile','text-align','right',0,''),(170842,54568,'116563','furniture-mobile','block_type','2',0,''),(170843,54568,'116563','furniture-mobile','schema','2-2',0,'2885'),(170844,54569,'116564','furniture-mobile','block_type','1',0,''),(170845,54569,'116564','furniture-mobile','padding-right','20',0,''),(170846,54569,'116564','furniture-mobile','padding-right','0',0,'2885'),(170847,54571,'116566','furniture-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(170848,54572,'116567','furniture-mobile','block_type','1',0,''),(170849,54572,'116567','furniture-mobile','padding-left','20',0,''),(170850,54572,'116567','furniture-mobile','padding-left','0',0,'2885'),(170851,54574,'116569','furniture-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(170852,54575,'116570','furniture-mobile','block_type','2',0,''),(170853,54575,'116570','furniture-mobile','schema','2-2',0,'2885'),(170854,54576,'116571','furniture-mobile','block_type','1',0,''),(170855,54576,'116571','furniture-mobile','padding-right','20',0,''),(170856,54576,'116571','furniture-mobile','padding-right','0',0,'2885'),(170857,54577,'116572','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170858,54579,'116574','furniture-mobile','block_type','1',0,''),(170859,54579,'116574','furniture-mobile','padding-left','20',0,''),(170860,54579,'116574','furniture-mobile','padding-left','0',0,'2885'),(170861,54584,'116579','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170862,54585,'116580','furniture-mobile','margin-bottom','20',0,''),(170863,54586,'116581','furniture-mobile','block_type','1',0,''),(170864,54586,'116581','furniture-mobile','background-color','$background-6',0,''),(170865,54586,'116581','furniture-mobile','padding-top','30',0,''),(170866,54586,'116581','furniture-mobile','padding-bottom','30',0,''),(170867,54587,'116582','furniture-mobile','block_type','7',0,''),(170868,54587,'116582','furniture-mobile','schema','4-2',0,'2885'),(170869,54587,'116582','furniture-mobile','margin-bottom','30',0,''),(170870,54588,'116583','furniture-mobile','block_type','1',0,''),(170871,54588,'116583','furniture-mobile','padding-right','0',0,'2885'),(170872,54589,'116585','furniture-mobile','block_type','1',0,''),(170873,54589,'116585','furniture-mobile','background-color','$background-7',0,''),(170874,54589,'116585','furniture-mobile','padding-top','30',0,''),(170875,54589,'116585','furniture-mobile','padding-left','30',0,''),(170876,54589,'116585','furniture-mobile','padding-right','30',0,''),(170877,54589,'116585','furniture-mobile','padding-bottom','14',0,''),(170878,54589,'116585','furniture-mobile','margin-bottom','20',0,''),(170879,54589,'116585','furniture-mobile','style_class','hiding-box closeable-box',0,''),(170880,54590,'116586','furniture-mobile','style_class','closeable-content',0,''),(170881,54590,'116586','furniture-mobile','padding-bottom','20',0,''),(170882,54591,'116587','furniture-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(170883,54591,'116587','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(170884,54592,'116588','furniture-mobile','block_type','1',0,''),(170885,54592,'116588','furniture-mobile','background-color','$background-7',0,''),(170886,54592,'116588','furniture-mobile','padding-top','30',0,''),(170887,54592,'116588','furniture-mobile','padding-left','30',0,''),(170888,54592,'116588','furniture-mobile','padding-right','30',0,''),(170889,54592,'116588','furniture-mobile','padding-bottom','30',0,''),(170890,54592,'116588','furniture-mobile','margin-bottom','20',0,''),(170891,54592,'116588','furniture-mobile','style_class','hiding-box',0,''),(170892,54593,'116589','furniture-mobile','padding-top','10',0,''),(170893,54593,'116589','furniture-mobile','padding-left','20',0,''),(170894,54593,'116589','furniture-mobile','padding-right','20',0,''),(170895,54593,'116589','furniture-mobile','margin-top','20',0,''),(170896,54593,'116589','furniture-mobile','background-color','$background-6',0,''),(170897,54593,'116589','furniture-mobile','padding-bottom','8',0,''),(170898,54594,'116590','furniture-mobile','margin-bottom','20',0,''),(170899,54595,'116591','furniture-mobile','block_type','1',0,''),(170900,54595,'116591','furniture-mobile','padding-top','30',0,''),(170901,54595,'116591','furniture-mobile','padding-left','30',0,''),(170902,54595,'116591','furniture-mobile','padding-right','30',0,''),(170903,54595,'116591','furniture-mobile','padding-bottom','23',0,''),(170904,54595,'116591','furniture-mobile','margin-bottom','20',0,''),(170905,54595,'116591','furniture-mobile','background-color','$background-7',0,''),(170906,54595,'116591','furniture-mobile','style_class','hiding-box',0,''),(170907,54596,'116592','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(170908,54597,'116593','furniture-mobile','block_type','2',0,''),(170909,54597,'116593','furniture-mobile','schema','2-2',0,'2885'),(170910,54598,'116594','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170911,54599,'116595','furniture-mobile','padding-right','20',0,''),(170912,54599,'116595','furniture-mobile','padding-right','0',0,'2885'),(170913,54599,'116595','furniture-mobile','padding-bottom','20',0,'2885'),(170914,54600,'116596','furniture-mobile','block_type','1',0,''),(170915,54600,'116596','furniture-mobile','padding-left','20',0,''),(170916,54600,'116596','furniture-mobile','padding-left','0',0,'2885'),(170917,54602,'116598','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170918,54603,'116599','furniture-mobile','block_type','1',0,''),(170919,54603,'116599','furniture-mobile','padding-top','10',0,''),(170920,54603,'116599','furniture-mobile','padding-left','10',0,''),(170921,54603,'116599','furniture-mobile','padding-right','10',0,''),(170922,54603,'116599','furniture-mobile','padding-bottom','10',0,''),(170923,54603,'116599','furniture-mobile','background-color','$background-7',0,''),(170924,54603,'116599','furniture-mobile','style_class','order-summary',0,''),(170925,54603,'116599','furniture-mobile','margin-left','25',0,''),(170926,54605,'116601','furniture-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(170927,54605,'116601','furniture-mobile','text-align','center',0,''),(170928,54605,'116601','furniture-mobile','font-size','14',0,''),(170929,54605,'116601','furniture-mobile','color','$color-font-9',0,''),(170930,54605,'116601','furniture-mobile','padding-top','10',0,''),(170931,54606,'116602','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(170932,54607,'116603','furniture-mobile','margin-bottom','10',0,''),(170933,54609,'116604','furniture-mobile','block_type','1',0,''),(170934,54610,'116605','furniture-mobile','block_type','1',0,''),(170935,54610,'116605','furniture-mobile','padding-left','0',0,'2885'),(170936,54610,'116605','furniture-mobile','padding-right','20',0,''),(170937,54612,'116607','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170938,54613,'116608','furniture-mobile','block_type','1',0,''),(170939,54613,'116608','furniture-mobile','padding-left','20',0,''),(170940,54613,'116608','furniture-mobile','padding-left','0',0,'2885'),(170941,54618,'116613','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170942,54619,'116614','furniture-mobile','block_type','4',0,''),(170943,54619,'116614','furniture-mobile','schema','4-2',0,'2906'),(170944,54620,'116615','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170945,54620,'116615','furniture-mobile','text-align','center',0,''),(170946,54620,'116615','furniture-mobile','padding-top','10',0,''),(170947,54620,'116615','furniture-mobile','font_size_measure','em',0,''),(170948,54620,'116615','furniture-mobile','font-size','1.2',0,''),(170949,54621,'116616','furniture-mobile','text-align','center',0,''),(170950,54622,'116617','furniture-mobile','block_type','2',0,''),(170951,54623,'116618','furniture-mobile','block_type','1',0,''),(170952,54623,'116618','furniture-mobile','padding-left','0',0,'2885'),(170953,54623,'116618','furniture-mobile','padding-right','20',0,''),(170954,54625,'116620','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170955,54626,'116621','furniture-mobile','block_type','1',0,''),(170956,54626,'116621','furniture-mobile','padding-left','20',0,''),(170957,54626,'116621','furniture-mobile','padding-left','0',0,'2885'),(170958,54628,'116623','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170959,54632,'116627','furniture-mobile','block_type','4',0,''),(170960,54632,'116627','furniture-mobile','schema','4-2',0,'2906'),(170961,54633,'116628','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170962,54633,'116628','furniture-mobile','text-align','right',0,''),(170963,54633,'116628','furniture-mobile','padding-top','10',0,''),(170964,54633,'116628','furniture-mobile','font_size_measure','em',0,''),(170965,54633,'116628','furniture-mobile','font-size','1.2',0,''),(170966,54634,'116629','furniture-mobile','text-align','right',0,''),(170967,54635,'116630','furniture-mobile','block_type','4',0,''),(170968,54635,'116630','furniture-mobile','schema','4-2',0,'2906'),(170969,54636,'116631','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170970,54636,'116631','furniture-mobile','text-align','right',0,''),(170971,54636,'116631','furniture-mobile','padding-top','10',0,''),(170972,54636,'116631','furniture-mobile','font_size_measure','em',0,''),(170973,54636,'116631','furniture-mobile','font-size','1.2',0,''),(170974,54637,'116632','furniture-mobile','text-align','right',0,''),(170975,54638,'116633','furniture-mobile','block_type','2',0,''),(170976,54639,'116634','furniture-mobile','block_type','1',0,''),(170977,54639,'116634','furniture-mobile','padding-left','0',0,'2885'),(170978,54639,'116634','furniture-mobile','padding-right','20',0,''),(170979,54640,'116635','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170980,54642,'116637','furniture-mobile','block_type','1',0,''),(170981,54642,'116637','furniture-mobile','padding-left','20',0,''),(170982,54642,'116637','furniture-mobile','padding-left','0',0,'2885'),(170983,54647,'116642','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170984,54648,'116643','furniture-mobile','block_type','4',0,''),(170985,54648,'116643','furniture-mobile','schema','4-2',0,'2906'),(170986,54649,'116644','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170987,54649,'116644','furniture-mobile','text-align','right',0,''),(170988,54649,'116644','furniture-mobile','padding-top','10',0,''),(170989,54649,'116644','furniture-mobile','font_size_measure','em',0,''),(170990,54649,'116644','furniture-mobile','font-size','1.2',0,''),(170991,54650,'116645','furniture-mobile','text-align','right',0,''),(170992,54651,'116646','furniture-mobile','block_type','2',0,''),(170993,54652,'116647','furniture-mobile','block_type','1',0,''),(170994,54652,'116647','furniture-mobile','padding-left','0',0,'2885'),(170995,54652,'116647','furniture-mobile','padding-right','20',0,''),(170996,54654,'116649','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170997,54655,'116650','furniture-mobile','block_type','1',0,''),(170998,54655,'116650','furniture-mobile','padding-left','20',0,''),(170999,54655,'116650','furniture-mobile','padding-left','0',0,'2885'),(171000,54659,'116654','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171001,54661,'116656','furniture-mobile','text','##PAYMENT_DETAILS##',0,''),(171002,54662,'116657','furniture-mobile','text','##PAYMENT_DETAILS##',0,''),(171003,54663,'116658','furniture-mobile','text','##PAYMENT_DETAILS##',0,''),(171004,54664,'116659','furniture-mobile','text','##PAYMENT_DETAILS##',0,''),(171005,54665,'116660','furniture-mobile','text','##PAYMENT_DETAILS##',0,''),(171006,54666,'116661','furniture-mobile','text','##PAYMENT_DETAILS##',0,''),(171007,54667,'120947','furniture-mobile','block_type','1',0,''),(171008,54667,'120947','furniture-mobile','background-color','$background-6',0,''),(171009,54667,'120947','furniture-mobile','padding-top','30',0,''),(171010,54667,'120947','furniture-mobile','padding-bottom','30',0,''),(171011,54668,'120948','furniture-mobile','block_type','7',0,''),(171012,54668,'120948','furniture-mobile','schema','4-2',0,'2885'),(171013,54669,'120949','furniture-mobile','block_type','1',0,''),(171014,54669,'120949','furniture-mobile','padding-right','0',0,'2885'),(171015,54670,'120950','furniture-mobile','block_type','1',0,''),(171016,54670,'120950','furniture-mobile','background-color','$background-7',0,''),(171017,54670,'120950','furniture-mobile','padding-top','30',0,''),(171018,54670,'120950','furniture-mobile','padding-left','30',0,''),(171019,54670,'120950','furniture-mobile','padding-right','30',0,''),(171020,54670,'120950','furniture-mobile','padding-bottom','30',0,''),(171021,54670,'120950','furniture-mobile','margin-bottom','20',0,''),(171022,54670,'120950','furniture-mobile','style_class','hiding-box',0,''),(171023,54671,'120951','furniture-mobile','padding-top','10',0,''),(171024,54671,'120951','furniture-mobile','padding-left','20',0,''),(171025,54671,'120951','furniture-mobile','padding-right','20',0,''),(171026,54671,'120951','furniture-mobile','margin-top','20',0,''),(171027,54671,'120951','furniture-mobile','background-color','$background-6',0,''),(171028,54671,'120951','furniture-mobile','padding-bottom','8',0,''),(171029,54672,'120952','furniture-mobile','margin-bottom','20',0,''),(171030,54673,'120953','furniture-mobile','background-color','$background-7',0,''),(171031,54673,'120953','furniture-mobile','block_type','1',0,''),(171032,54673,'120953','furniture-mobile','padding-top','30',0,''),(171033,54673,'120953','furniture-mobile','padding-left','30',0,''),(171034,54673,'120953','furniture-mobile','padding-right','30',0,''),(171035,54673,'120953','furniture-mobile','padding-bottom','30',0,''),(171036,54673,'120953','furniture-mobile','margin-bottom','20',0,''),(171037,54673,'120953','furniture-mobile','style_class','hiding-box',0,''),(171038,54674,'120954','furniture-mobile','block_type','1',0,''),(171039,54674,'120954','furniture-mobile','content','\\_',0,'3'),(171040,54674,'120954','furniture-mobile','border-top-width','1',0,'3'),(171041,54674,'120954','furniture-mobile','border-top-color','$border-color-4',0,'3'),(171042,54674,'120954','furniture-mobile','display','block',0,'3'),(171043,54674,'120954','furniture-mobile','position','absolute',0,'3'),(171044,54674,'120954','furniture-mobile','top','19',0,'3'),(171045,54674,'120954','furniture-mobile','left','0',0,'3'),(171046,54674,'120954','furniture-mobile','right','0',0,'3'),(171047,54674,'120954','furniture-mobile','margin-top','-2',0,'3'),(171048,54674,'120954','furniture-mobile','position','relative',0,''),(171049,54675,'120955','furniture-mobile','box_align','2',0,''),(171050,54675,'120955','furniture-mobile','margin-bottom','10',0,''),(171051,54675,'120955','furniture-mobile','background-color','$background-7',0,''),(171052,54675,'120955','furniture-mobile','position','relative',0,''),(171053,54676,'120956','furniture-mobile','background-color','$background-6',0,''),(171054,54676,'120956','furniture-mobile','padding-top','10',0,''),(171055,54676,'120956','furniture-mobile','padding-left','10',0,''),(171056,54676,'120956','furniture-mobile','padding-right','10',0,''),(171057,54676,'120956','furniture-mobile','padding-bottom','10',0,''),(171058,54676,'120956','furniture-mobile','margin-top','10',0,''),(171059,54677,'120957','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(171060,54678,'120958','furniture-mobile','block_type','2',0,''),(171061,54678,'120958','furniture-mobile','schema','2-2',0,'2885'),(171062,54679,'120959','furniture-mobile','block_type','1',0,''),(171063,54679,'120959','furniture-mobile','padding-right','20',0,''),(171064,54679,'120959','furniture-mobile','padding-left','0',0,'2885'),(171065,54679,'120959','furniture-mobile','margin-bottom','20',0,'2885'),(171066,54679,'120959','furniture-mobile','padding-right','0',0,'2885'),(171067,54682,'120962','furniture-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(171068,54683,'120963','furniture-mobile','block_type','1',0,''),(171069,54683,'120963','furniture-mobile','padding-left','20',0,''),(171070,54683,'120963','furniture-mobile','padding-left','0',0,'2885'),(171071,54685,'120965','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(171072,54686,'120966','furniture-mobile','border-top-width','1',0,''),(171073,54686,'120966','furniture-mobile','border-top-color','$border-color-4',0,''),(171074,54686,'120966','furniture-mobile','padding-top','13',0,''),(171075,54686,'120966','furniture-mobile','padding-bottom','10',0,''),(171076,54687,'120967','furniture-mobile','block_type','1',0,''),(171077,54687,'120967','furniture-mobile','background-color','$background-7',0,''),(171078,54687,'120967','furniture-mobile','padding-top','30',0,''),(171079,54687,'120967','furniture-mobile','padding-left','30',0,''),(171080,54687,'120967','furniture-mobile','padding-right','30',0,''),(171081,54687,'120967','furniture-mobile','padding-bottom','14',0,''),(171082,54687,'120967','furniture-mobile','margin-bottom','20',0,''),(171083,54687,'120967','furniture-mobile','style_class','hiding-box closeable-box',0,''),(171084,54688,'120968','furniture-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(171085,54688,'120968','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(171086,54689,'120969','furniture-mobile','style_class','closeable-content',0,''),(171087,54689,'120969','furniture-mobile','padding-bottom','20',0,''),(171088,54690,'120970','furniture-mobile','block_type','1',0,''),(171089,54690,'120970','furniture-mobile','padding-top','30',0,''),(171090,54690,'120970','furniture-mobile','padding-left','30',0,''),(171091,54690,'120970','furniture-mobile','padding-right','30',0,''),(171092,54690,'120970','furniture-mobile','padding-bottom','23',0,''),(171093,54690,'120970','furniture-mobile','margin-bottom','20',0,''),(171094,54690,'120970','furniture-mobile','background-color','$background-7',0,''),(171095,54690,'120970','furniture-mobile','style_class','hiding-box',0,''),(171096,54691,'120971','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(171097,54692,'120972','furniture-mobile','block_type','2',0,''),(171098,54692,'120972','furniture-mobile','schema','2-2',0,'2885'),(171099,54693,'120973','furniture-mobile','padding-right','20',0,''),(171100,54693,'120973','furniture-mobile','padding-right','0',0,'2885'),(171101,54693,'120973','furniture-mobile','padding-bottom','20',0,'2885'),(171102,54694,'120974','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171103,54695,'120975','furniture-mobile','block_type','1',0,''),(171104,54695,'120975','furniture-mobile','padding-left','20',0,''),(171105,54695,'120975','furniture-mobile','padding-left','0',0,'2885'),(171106,54697,'120977','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171107,54698,'120978','furniture-mobile','block_type','1',0,''),(171108,54698,'120978','furniture-mobile','padding-left','10',0,''),(171109,54698,'120978','furniture-mobile','padding-right','10',0,''),(171110,54698,'120978','furniture-mobile','padding-bottom','10',0,''),(171111,54698,'120978','furniture-mobile','background-color','$background-7',0,''),(171112,54698,'120978','furniture-mobile','style_class','order-summary',0,''),(171113,54698,'120978','furniture-mobile','margin-left','25',0,''),(171114,54698,'120978','furniture-mobile','margin-left','0',0,'2885'),(171115,54699,'120979','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171116,54700,'120980','furniture-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(171117,54700,'120980','furniture-mobile','text-align','center',0,''),(171118,54700,'120980','furniture-mobile','font-size','14',0,''),(171119,54700,'120980','furniture-mobile','color','$color-font-9',0,''),(171120,54700,'120980','furniture-mobile','padding-top','10',0,''),(171121,54701,'120981','furniture-mobile','margin-bottom','10',0,''),(171122,54703,'120983','furniture-mobile','hide_continue_button','1',0,''),(171123,54704,'116699','furniture-mobile','block_type','1',0,''),(171124,54704,'116699','furniture-mobile','background-color','$background-6',0,''),(171125,54704,'116699','furniture-mobile','padding-top','30',0,''),(171126,54704,'116699','furniture-mobile','padding-bottom','30',0,''),(171127,54705,'116700','furniture-mobile','block_type','7',0,''),(171128,54705,'116700','furniture-mobile','schema','7-2',0,'2885'),(171129,54706,'116701','furniture-mobile','block_type','1',0,''),(171130,54706,'116701','furniture-mobile','padding-right','0',0,'2885'),(171131,54707,'116703','furniture-mobile','block_type','1',0,''),(171132,54707,'116703','furniture-mobile','background-color','$background-7',0,''),(171133,54707,'116703','furniture-mobile','padding-top','30',0,''),(171134,54707,'116703','furniture-mobile','padding-left','30',0,''),(171135,54707,'116703','furniture-mobile','padding-right','30',0,''),(171136,54707,'116703','furniture-mobile','padding-bottom','30',0,''),(171137,54707,'116703','furniture-mobile','margin-bottom','20',0,''),(171138,54707,'116703','furniture-mobile','style_class','hiding-box',0,''),(171139,54708,'116704','furniture-mobile','margin-bottom','20',0,''),(171140,54709,'116705','furniture-mobile','padding-top','10',0,''),(171141,54709,'116705','furniture-mobile','padding-left','20',0,''),(171142,54709,'116705','furniture-mobile','padding-right','20',0,''),(171143,54709,'116705','furniture-mobile','margin-top','20',0,''),(171144,54709,'116705','furniture-mobile','background-color','$background-6',0,''),(171145,54709,'116705','furniture-mobile','padding-bottom','8',0,''),(171146,54710,'116706','furniture-mobile','background-color','$background-7',0,''),(171147,54710,'116706','furniture-mobile','block_type','1',0,''),(171148,54710,'116706','furniture-mobile','padding-top','30',0,''),(171149,54710,'116706','furniture-mobile','padding-left','30',0,''),(171150,54710,'116706','furniture-mobile','padding-right','30',0,''),(171151,54710,'116706','furniture-mobile','padding-bottom','30',0,''),(171152,54710,'116706','furniture-mobile','margin-bottom','20',0,''),(171153,54710,'116706','furniture-mobile','style_class','hiding-box',0,''),(171154,54711,'116707','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(171155,54712,'116708','furniture-mobile','background-color','$background-6',0,''),(171156,54712,'116708','furniture-mobile','padding-top','10',0,''),(171157,54712,'116708','furniture-mobile','padding-left','10',0,''),(171158,54712,'116708','furniture-mobile','padding-right','10',0,''),(171159,54712,'116708','furniture-mobile','padding-bottom','10',0,''),(171160,54712,'116708','furniture-mobile','margin-top','10',0,''),(171161,54713,'116709','furniture-mobile','block_type','1',0,''),(171162,54713,'116709','furniture-mobile','content','\\_',0,'3'),(171163,54713,'116709','furniture-mobile','border-top-width','1',0,'3'),(171164,54713,'116709','furniture-mobile','border-top-color','$border-color-4',0,'3'),(171165,54713,'116709','furniture-mobile','display','block',0,'3'),(171166,54713,'116709','furniture-mobile','position','absolute',0,'3'),(171167,54713,'116709','furniture-mobile','top','19',0,'3'),(171168,54713,'116709','furniture-mobile','left','0',0,'3'),(171169,54713,'116709','furniture-mobile','right','0',0,'3'),(171170,54713,'116709','furniture-mobile','margin-top','-2',0,'3'),(171171,54713,'116709','furniture-mobile','position','relative',0,''),(171172,54714,'116710','furniture-mobile','box_align','2',0,''),(171173,54714,'116710','furniture-mobile','margin-bottom','10',0,''),(171174,54714,'116710','furniture-mobile','background-color','$background-7',0,''),(171175,54714,'116710','furniture-mobile','position','relative',0,''),(171176,54715,'116711','furniture-mobile','block_type','2',0,''),(171177,54715,'116711','furniture-mobile','schema','2-2',0,'2885'),(171178,54716,'116712','furniture-mobile','block_type','1',0,''),(171179,54716,'116712','furniture-mobile','padding-right','20',0,''),(171180,54716,'116712','furniture-mobile','padding-left','0',0,'2885'),(171181,54716,'116712','furniture-mobile','margin-bottom','20',0,'2885'),(171182,54716,'116712','furniture-mobile','padding-right','0',0,'2885'),(171183,54719,'116715','furniture-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(171184,54720,'116716','furniture-mobile','block_type','1',0,''),(171185,54720,'116716','furniture-mobile','padding-left','20',0,''),(171186,54720,'116716','furniture-mobile','padding-left','0',0,'2885'),(171187,54722,'116718','furniture-mobile','border-top-width','1',0,''),(171188,54722,'116718','furniture-mobile','border-top-color','$border-color-4',0,''),(171189,54722,'116718','furniture-mobile','padding-top','13',0,''),(171190,54722,'116718','furniture-mobile','padding-bottom','10',0,''),(171191,54723,'116719','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(171192,54724,'116720','furniture-mobile','block_type','1',0,''),(171193,54724,'116720','furniture-mobile','padding-top','30',0,''),(171194,54724,'116720','furniture-mobile','padding-left','30',0,''),(171195,54724,'116720','furniture-mobile','padding-right','30',0,''),(171196,54724,'116720','furniture-mobile','padding-bottom','23',0,''),(171197,54724,'116720','furniture-mobile','margin-bottom','20',0,''),(171198,54724,'116720','furniture-mobile','background-color','$background-7',0,''),(171199,54724,'116720','furniture-mobile','style_class','hiding-box',0,''),(171200,54725,'116721','furniture-mobile','block_type','2',0,''),(171201,54725,'116721','furniture-mobile','schema','2-2',0,'2885'),(171202,54726,'116722','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171203,54727,'116723','furniture-mobile','padding-right','20',0,''),(171204,54727,'116723','furniture-mobile','padding-right','0',0,'2885'),(171205,54727,'116723','furniture-mobile','padding-bottom','20',0,'2885'),(171206,54728,'116724','furniture-mobile','block_type','1',0,''),(171207,54728,'116724','furniture-mobile','padding-left','20',0,''),(171208,54728,'116724','furniture-mobile','padding-left','0',0,'2885'),(171209,54729,'116725','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171210,54731,'116727','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(171211,54732,'116728','furniture-mobile','block_type','1',0,''),(171212,54732,'116728','furniture-mobile','background-color','$background-7',0,''),(171213,54732,'116728','furniture-mobile','padding-top','30',0,''),(171214,54732,'116728','furniture-mobile','padding-left','30',0,''),(171215,54732,'116728','furniture-mobile','padding-right','30',0,''),(171216,54732,'116728','furniture-mobile','padding-bottom','14',0,''),(171217,54732,'116728','furniture-mobile','margin-bottom','20',0,''),(171218,54732,'116728','furniture-mobile','style_class','hiding-box closeable-box',0,''),(171219,54733,'116729','furniture-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(171220,54733,'116729','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(171221,54734,'116730','furniture-mobile','style_class','closeable-content',0,''),(171222,54734,'116730','furniture-mobile','padding-bottom','20',0,''),(171223,54735,'116731','furniture-mobile','block_type','1',0,''),(171224,54735,'116731','furniture-mobile','padding-top','30',0,''),(171225,54735,'116731','furniture-mobile','padding-left','30',0,''),(171226,54735,'116731','furniture-mobile','padding-right','30',0,''),(171227,54735,'116731','furniture-mobile','padding-bottom','14',0,''),(171228,54735,'116731','furniture-mobile','margin-bottom','20',0,''),(171229,54735,'116731','furniture-mobile','background-color','$background-7',0,''),(171230,54735,'116731','furniture-mobile','style_class','hiding-box closeable-box',0,''),(171231,54736,'116732','furniture-mobile','block_type','2',0,''),(171232,54736,'116732','furniture-mobile','style_class','closeable-content',0,''),(171233,54736,'116732','furniture-mobile','schema','2-2',0,'2885'),(171234,54737,'116733','furniture-mobile','padding-right','20',0,''),(171235,54737,'116733','furniture-mobile','padding-bottom','20',0,''),(171236,54737,'116733','furniture-mobile','padding-right','0',0,'2885'),(171237,54738,'116734','furniture-mobile','padding-left','20',0,''),(171238,54738,'116734','furniture-mobile','padding-bottom','20',0,''),(171239,54738,'116734','furniture-mobile','padding-left','0',0,'2885'),(171240,54739,'116735','furniture-mobile','padding-left','20',0,''),(171241,54739,'116735','furniture-mobile','padding-bottom','20',0,''),(171242,54739,'116735','furniture-mobile','padding-left','0',0,'2885'),(171243,54740,'116736','furniture-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(171244,54740,'116736','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(171245,54741,'116737','furniture-mobile','block_type','1',0,''),(171246,54741,'116737','furniture-mobile','padding-top','20',0,''),(171247,54741,'116737','furniture-mobile','padding-left','20',0,''),(171248,54741,'116737','furniture-mobile','padding-right','20',0,''),(171249,54741,'116737','furniture-mobile','padding-bottom','20',0,''),(171250,54741,'116737','furniture-mobile','background-color','$background-7',0,''),(171251,54741,'116737','furniture-mobile','style_class','order-summary',0,''),(171252,54741,'116737','furniture-mobile','margin-left','25',0,''),(171253,54741,'116737','furniture-mobile','padding-left','0',0,'2885'),(171254,54742,'116738','furniture-mobile','margin-bottom','10',0,''),(171255,54743,'116739','furniture-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(171256,54743,'116739','furniture-mobile','text-align','center',0,''),(171257,54743,'116739','furniture-mobile','font-size','14',0,''),(171258,54743,'116739','furniture-mobile','color','$color-font-9',0,''),(171259,54743,'116739','furniture-mobile','padding-top','10',0,''),(171260,54744,'116740','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171261,54746,'120986','furniture-mobile','hide_continue_button','1',0,''),(171262,54747,'116742','furniture-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(171263,54752,'116747','furniture-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(171264,54753,'116749','furniture-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(171265,54754,'116750','furniture-mobile','style_class','order-summary',0,''),(171266,54754,'116750','furniture-mobile','box_align','3',0,''),(171267,54754,'116750','furniture-mobile','width','400',0,''),(171268,54756,'116748','furniture-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(171269,54759,'116754','furniture-mobile','block_type','1',0,''),(171270,54760,'116755','furniture-mobile','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(171271,54761,'116756','furniture-mobile','float','right',0,''),(171272,54761,'116756','furniture-mobile','position','relative',0,''),(171273,54761,'116756','furniture-mobile','z-index','1',0,''),(171274,54761,'116756','furniture-mobile','top','30',0,''),(171275,54761,'116756','furniture-mobile','margin-bottom','-10',0,''),(171276,54762,'116757','furniture-mobile','margin-bottom','30',0,''),(171277,54763,'116758','furniture-mobile','block_type','1',0,''),(171278,54764,'116759','furniture-mobile','listing_type','CompareProduct',0,''),(171279,54765,'117665.000001','furniture-mobile','block_type','1',0,''),(171280,54765,'117665.000001','furniture-mobile','style_class','item-holder',0,''),(171281,54765,'117665.000001','furniture-mobile','padding-top','25',0,''),(171282,54765,'117665.000001','furniture-mobile','padding-left','25',0,''),(171283,54765,'117665.000001','furniture-mobile','padding-right','25',0,''),(171284,54765,'117665.000001','furniture-mobile','padding-bottom','25',0,''),(171285,54765,'117665.000001','furniture-mobile','text-align','left',0,''),(171286,54766,'120921.000001','furniture-mobile','block_type','1',0,''),(171287,54766,'120921.000001','furniture-mobile','style_class','item-wrapper',0,''),(171288,54767,'120919.000001','furniture-mobile','block_type','1',0,''),(171289,54767,'120919.000001','furniture-mobile','style_class','item-content',0,''),(171290,54768,'1638872990.9609','furniture-mobile','block_type','5',0,''),(171291,54770,'117677.000001','furniture-mobile','float','right',0,''),(171292,54771,'117675.000001','furniture-mobile','clear','none',0,''),(171293,54772,'117676.000001','furniture-mobile','margin-bottom','10',0,''),(171294,54773,'1638873112.0384','furniture-mobile','block_type','2',0,''),(171295,54775,'117673.000001','furniture-mobile','margin-bottom','7',0,''),(171296,54775,'117673.000001','furniture-mobile','text-align','right',0,''),(171297,54776,'116760','furniture-mobile','block_type','1',0,''),(171298,54776,'116760','furniture-mobile','style_class','item-holder',0,''),(171299,54776,'116760','furniture-mobile','padding-top','10',0,''),(171300,54776,'116760','furniture-mobile','padding-left','20',0,''),(171301,54776,'116760','furniture-mobile','padding-right','20',0,''),(171302,54776,'116760','furniture-mobile','padding-bottom','10',0,''),(171303,54776,'116760','furniture-mobile','text-align','left',0,''),(171304,54779,'116763','furniture-mobile','margin-bottom','10',0,''),(171305,54780,'116764','furniture-mobile','block_type','5',0,''),(171306,54782,'116766','furniture-mobile','clear','both',0,''),(171307,54783,'116767','furniture-mobile','block_type','2',0,''),(171308,54784,'116768','furniture-mobile','margin-bottom','7',0,''),(171309,54785,'116769','furniture-mobile','text-align','right',0,''),(171310,54785,'116769','furniture-mobile','margin-bottom','10',0,''),(171311,54785,'116769','furniture-mobile','float','right',0,''),(171312,54786,'116770','furniture-mobile','block_type','1',0,''),(171313,54786,'116770','furniture-mobile','background-color','$background-6',0,''),(171314,54786,'116770','furniture-mobile','padding-bottom','30',0,''),(171315,54786,'116770','furniture-mobile','style_class','checkout-order-confirmation',0,''),(171316,54787,'116771','furniture-mobile','block_type','4',0,''),(171317,54787,'116771','furniture-mobile','schema','4-2',0,'2885'),(171318,54788,'116772','furniture-mobile','block_type','1',0,''),(171319,54788,'116772','furniture-mobile','padding-right','40',0,''),(171320,54788,'116772','furniture-mobile','padding-right','0',0,'2885'),(171321,54789,'116773','furniture-mobile','block_type','1',0,''),(171322,54789,'116773','furniture-mobile','padding-right','30',0,''),(171323,54789,'116773','furniture-mobile','background-color','$background-7',0,''),(171324,54789,'116773','furniture-mobile','padding-top','20',0,''),(171325,54789,'116773','furniture-mobile','padding-left','30',0,''),(171326,54789,'116773','furniture-mobile','padding-bottom','20',0,''),(171327,54789,'116773','furniture-mobile','padding-left','20',0,'2885'),(171328,54789,'116773','furniture-mobile','padding-right','20',0,'2885'),(171329,54790,'116774','furniture-mobile','link','products',0,''),(171330,54790,'116774','furniture-mobile','float','right',0,''),(171331,54790,'116774','furniture-mobile','margin-top','-37',0,''),(171332,54792,'116776','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(171333,54793,'116777','furniture-mobile','block_type','1',0,''),(171334,54793,'116777','furniture-mobile','background-color','$background-7',0,''),(171335,54793,'116777','furniture-mobile','padding-top','20',0,''),(171336,54793,'116777','furniture-mobile','padding-bottom','20',0,''),(171337,54793,'116777','furniture-mobile','padding-left','30',0,''),(171338,54793,'116777','furniture-mobile','padding-right','30',0,''),(171339,54793,'116777','furniture-mobile','margin-bottom','20',0,''),(171340,54794,'116778','furniture-mobile','float','right',0,''),(171341,54794,'116778','furniture-mobile','margin-top','-37',0,''),(171342,54794,'116778','furniture-mobile','link','comments',0,''),(171343,54795,'116779','furniture-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(171344,54796,'116780','furniture-mobile','hide_parents','2',0,''),(171345,54797,'116781','furniture-mobile','block_type','2',0,''),(171346,54797,'116781','furniture-mobile','margin-bottom','20',0,''),(171347,54797,'116781','furniture-mobile','schema','2-2',0,'2876'),(171348,54797,'116781','furniture-mobile','background-color','$background-7',0,''),(171349,54798,'116782','furniture-mobile','block_type','1',0,''),(171350,54798,'116782','furniture-mobile','border-right-width','20',0,''),(171351,54798,'116782','furniture-mobile','border-right-color','$border-color-4',0,''),(171352,54798,'116782','furniture-mobile','margin-right','-10',0,''),(171353,54798,'116782','furniture-mobile','padding-right','30',0,''),(171354,54798,'116782','furniture-mobile','padding-top','20',0,''),(171355,54798,'116782','furniture-mobile','padding-left','30',0,''),(171356,54798,'116782','furniture-mobile','padding-bottom','20',0,''),(171357,54798,'116782','furniture-mobile','border-right-width','0',0,'2885'),(171358,54798,'116782','furniture-mobile','margin-right','0',0,'2885'),(171359,54798,'116782','furniture-mobile','margin-bottom','20',0,'2885'),(171360,54798,'116782','furniture-mobile','padding-left','20',0,'2885'),(171361,54798,'116782','furniture-mobile','padding-right','20',0,'2885'),(171362,54799,'116783','furniture-mobile','link','shipping_method',0,''),(171363,54799,'116783','furniture-mobile','float','right',0,''),(171364,54799,'116783','furniture-mobile','margin-top','-31',0,''),(171365,54801,'116785','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(171366,54801,'116785','furniture-mobile','padding-top','20',0,''),(171367,54802,'116786','furniture-mobile','link','contact_information',0,''),(171368,54802,'116786','furniture-mobile','margin-top','-31',0,''),(171369,54802,'116786','furniture-mobile','float','right',0,''),(171370,54803,'116787','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(171371,54803,'116787','furniture-mobile','clear','none',0,''),(171372,54805,'116789','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(171373,54806,'116790','furniture-mobile','link','shipping_address',0,''),(171374,54806,'116790','furniture-mobile','float','right',0,''),(171375,54806,'116790','furniture-mobile','margin-top','-31',0,''),(171376,54808,'116792','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(171377,54808,'116792','furniture-mobile','clear','none',0,''),(171378,54809,'116793','furniture-mobile','margin-bottom','20',0,''),(171379,54810,'116794','furniture-mobile','block_type','1',0,''),(171380,54810,'116794','furniture-mobile','padding-left','30',0,''),(171381,54810,'116794','furniture-mobile','border-left-width','20',0,''),(171382,54810,'116794','furniture-mobile','border-left-color','$border-color-4',0,''),(171383,54810,'116794','furniture-mobile','margin-left','-10',0,''),(171384,54810,'116794','furniture-mobile','padding-right','30',0,''),(171385,54810,'116794','furniture-mobile','padding-top','20',0,''),(171386,54810,'116794','furniture-mobile','padding-bottom','20',0,''),(171387,54810,'116794','furniture-mobile','border-left-width','0',0,'2885'),(171388,54811,'116795','furniture-mobile','link','payment_method',0,''),(171389,54811,'116795','furniture-mobile','float','right',0,''),(171390,54811,'116795','furniture-mobile','margin-top','-31',0,''),(171391,54812,'116796','furniture-mobile','link','billing_address',0,''),(171392,54812,'116796','furniture-mobile','float','right',0,''),(171393,54812,'116796','furniture-mobile','margin-top','-31',0,''),(171394,54814,'116798','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171395,54814,'116798','furniture-mobile','clear','none',0,''),(171396,54815,'116799','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(171397,54816,'116800','furniture-mobile','margin-bottom','20',0,''),(171398,54817,'116801','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171399,54817,'116801','furniture-mobile','clear','none',0,''),(171400,54819,'116803','furniture-mobile','block_type','1',0,''),(171401,54819,'116803','furniture-mobile','padding-top','20',0,''),(171402,54819,'116803','furniture-mobile','padding-left','20',0,''),(171403,54819,'116803','furniture-mobile','padding-right','20',0,''),(171404,54819,'116803','furniture-mobile','padding-bottom','20',0,''),(171405,54819,'116803','furniture-mobile','background-color','$background-7',0,''),(171406,54819,'116803','furniture-mobile','style_class','order-summary2 hiding-box',0,''),(171407,54820,'116804','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171408,54821,'116805','furniture-mobile','margin-bottom','20',0,''),(171409,54821,'116805','furniture-mobile','text-align','right',0,''),(171410,54823,'116807','furniture-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(171411,54824,'116808','furniture-mobile','block_type','1',0,''),(171412,54824,'116808','furniture-mobile','background-color','$background-6',0,''),(171413,54824,'116808','furniture-mobile','padding-bottom','30',0,''),(171414,54825,'116809','furniture-mobile','block_type','4',0,''),(171415,54825,'116809','furniture-mobile','schema','4-2',0,'2885'),(171416,54826,'116810','furniture-mobile','block_type','1',0,''),(171417,54826,'116810','furniture-mobile','padding-right','40',0,''),(171418,54826,'116810','furniture-mobile','padding-right','0',0,'2885'),(171419,54827,'116811','furniture-mobile','block_type','1',0,''),(171420,54827,'116811','furniture-mobile','background-color','$background-7',0,''),(171421,54827,'116811','furniture-mobile','padding-top','20',0,''),(171422,54827,'116811','furniture-mobile','padding-bottom','20',0,''),(171423,54827,'116811','furniture-mobile','padding-left','30',0,''),(171424,54827,'116811','furniture-mobile','padding-right','30',0,''),(171425,54827,'116811','furniture-mobile','margin-bottom','20',0,''),(171426,54828,'116812','furniture-mobile','hide_parents','2',0,''),(171427,54829,'116813','furniture-mobile','float','right',0,''),(171428,54829,'116813','furniture-mobile','margin-top','-37',0,''),(171429,54829,'116813','furniture-mobile','link','comments',0,''),(171430,54830,'116814','furniture-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(171431,54831,'116815','furniture-mobile','block_type','1',0,''),(171432,54831,'116815','furniture-mobile','padding-right','30',0,''),(171433,54831,'116815','furniture-mobile','background-color','$background-7',0,''),(171434,54831,'116815','furniture-mobile','padding-top','20',0,''),(171435,54831,'116815','furniture-mobile','padding-left','30',0,''),(171436,54831,'116815','furniture-mobile','padding-bottom','20',0,''),(171437,54831,'116815','furniture-mobile','padding-left','20',0,'2885'),(171438,54831,'116815','furniture-mobile','padding-right','20',0,'2885'),(171439,54832,'116816','furniture-mobile','link','products',0,''),(171440,54832,'116816','furniture-mobile','float','right',0,''),(171441,54832,'116816','furniture-mobile','margin-top','-37',0,''),(171442,54833,'116817','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(171443,54835,'116819','furniture-mobile','block_type','2',0,''),(171444,54835,'116819','furniture-mobile','margin-bottom','20',0,''),(171445,54835,'116819','furniture-mobile','schema','2-2',0,'2876'),(171446,54835,'116819','furniture-mobile','background-color','$background-7',0,''),(171447,54836,'116820','furniture-mobile','block_type','1',0,''),(171448,54836,'116820','furniture-mobile','border-right-width','20',0,''),(171449,54836,'116820','furniture-mobile','border-right-color','$border-color-4',0,''),(171450,54836,'116820','furniture-mobile','margin-right','-10',0,''),(171451,54836,'116820','furniture-mobile','padding-right','30',0,''),(171452,54836,'116820','furniture-mobile','padding-top','20',0,''),(171453,54836,'116820','furniture-mobile','padding-left','30',0,''),(171454,54836,'116820','furniture-mobile','padding-bottom','20',0,''),(171455,54836,'116820','furniture-mobile','border-right-width','0',0,'2885'),(171456,54836,'116820','furniture-mobile','margin-right','0',0,'2885'),(171457,54836,'116820','furniture-mobile','margin-bottom','20',0,'2885'),(171458,54836,'116820','furniture-mobile','padding-left','20',0,'2885'),(171459,54836,'116820','furniture-mobile','padding-right','20',0,'2885'),(171460,54837,'116821','furniture-mobile','link','shipping_address',0,''),(171461,54837,'116821','furniture-mobile','float','right',0,''),(171462,54837,'116821','furniture-mobile','margin-top','-31',0,''),(171463,54839,'116823','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(171464,54839,'116823','furniture-mobile','clear','none',0,''),(171465,54840,'116824','furniture-mobile','link','shipping_method',0,''),(171466,54840,'116824','furniture-mobile','float','right',0,''),(171467,54840,'116824','furniture-mobile','margin-top','-31',0,''),(171468,54841,'116825','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(171469,54841,'116825','furniture-mobile','clear','none',0,''),(171470,54842,'116826','furniture-mobile','margin-bottom','20',0,''),(171471,54843,'116827','furniture-mobile','block_type','1',0,''),(171472,54843,'116827','furniture-mobile','padding-left','30',0,''),(171473,54843,'116827','furniture-mobile','border-left-width','20',0,''),(171474,54843,'116827','furniture-mobile','border-left-color','$border-color-4',0,''),(171475,54843,'116827','furniture-mobile','margin-left','-10',0,''),(171476,54843,'116827','furniture-mobile','padding-right','30',0,''),(171477,54843,'116827','furniture-mobile','padding-top','20',0,''),(171478,54843,'116827','furniture-mobile','padding-bottom','20',0,''),(171479,54843,'116827','furniture-mobile','border-left-width','0',0,'2885'),(171480,54846,'116830','furniture-mobile','link','contact_information',0,''),(171481,54846,'116830','furniture-mobile','margin-top','-31',0,''),(171482,54846,'116830','furniture-mobile','float','right',0,''),(171483,54847,'116831','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(171484,54848,'116832','furniture-mobile','block_type','1',0,''),(171485,54848,'116832','furniture-mobile','padding-top','20',0,''),(171486,54848,'116832','furniture-mobile','padding-left','20',0,''),(171487,54848,'116832','furniture-mobile','padding-right','20',0,''),(171488,54848,'116832','furniture-mobile','padding-bottom','20',0,''),(171489,54848,'116832','furniture-mobile','background-color','$background-7',0,''),(171490,54848,'116832','furniture-mobile','style_class','order-summary',0,''),(171491,54849,'116833','furniture-mobile','margin-bottom','20',0,''),(171492,54849,'116833','furniture-mobile','text-align','right',0,''),(171493,54850,'116834','furniture-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(171494,54851,'116835','furniture-mobile','block_type','1',0,''),(171495,54851,'116835','furniture-mobile','background-color','$background-6',0,''),(171496,54851,'116835','furniture-mobile','padding-bottom','30',0,''),(171497,54852,'116836','furniture-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(171498,54853,'116837','furniture-mobile','block_type','4',0,''),(171499,54854,'116838','furniture-mobile','block_type','1',0,''),(171500,54854,'116838','furniture-mobile','padding-right','40',0,''),(171501,54855,'116839','furniture-mobile','block_type','2',0,''),(171502,54855,'116839','furniture-mobile','margin-bottom','20',0,''),(171503,54855,'116839','furniture-mobile','schema','2-2',0,'2876'),(171504,54855,'116839','furniture-mobile','background-color','$background-7',0,''),(171505,54856,'116840','furniture-mobile','block_type','1',0,''),(171506,54856,'116840','furniture-mobile','padding-right','0',0,'2876'),(171507,54856,'116840','furniture-mobile','border-right-width','20',0,''),(171508,54856,'116840','furniture-mobile','border-right-color','$border-color-4',0,''),(171509,54856,'116840','furniture-mobile','margin-right','-10',0,''),(171510,54856,'116840','furniture-mobile','padding-right','30',0,''),(171511,54856,'116840','furniture-mobile','padding-top','20',0,''),(171512,54856,'116840','furniture-mobile','padding-left','30',0,''),(171513,54856,'116840','furniture-mobile','padding-bottom','20',0,''),(171514,54857,'116841','furniture-mobile','link','contact_information',0,''),(171515,54857,'116841','furniture-mobile','float','right',0,''),(171516,54858,'116842','furniture-mobile','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(171517,54860,'116844','furniture-mobile','block_type','1',0,''),(171518,54860,'116844','furniture-mobile','padding-left','30',0,''),(171519,54860,'116844','furniture-mobile','padding-left','0',0,'2876'),(171520,54860,'116844','furniture-mobile','border-left-width','20',0,''),(171521,54860,'116844','furniture-mobile','border-left-color','$border-color-4',0,''),(171522,54860,'116844','furniture-mobile','margin-left','-10',0,''),(171523,54860,'116844','furniture-mobile','padding-right','30',0,''),(171524,54860,'116844','furniture-mobile','padding-top','20',0,''),(171525,54860,'116844','furniture-mobile','padding-bottom','20',0,''),(171526,54862,'116846','furniture-mobile','link','payment_method',0,''),(171527,54862,'116846','furniture-mobile','float','right',0,''),(171528,54862,'116846','furniture-mobile','margin-top','-31',0,''),(171529,54863,'116847','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171530,54863,'116847','furniture-mobile','clear','none',0,''),(171531,54864,'116848','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(171532,54865,'116849','furniture-mobile','link','billing_address',0,''),(171533,54865,'116849','furniture-mobile','float','right',0,''),(171534,54865,'116849','furniture-mobile','margin-top','-31',0,''),(171535,54866,'116850','furniture-mobile','margin-bottom','20',0,''),(171536,54867,'116851','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171537,54867,'116851','furniture-mobile','clear','none',0,''),(171538,54868,'116852','furniture-mobile','block_type','1',0,''),(171539,54868,'116852','furniture-mobile','background-color','$background-7',0,''),(171540,54868,'116852','furniture-mobile','padding-top','20',0,''),(171541,54868,'116852','furniture-mobile','padding-bottom','20',0,''),(171542,54868,'116852','furniture-mobile','padding-left','30',0,''),(171543,54868,'116852','furniture-mobile','padding-right','30',0,''),(171544,54868,'116852','furniture-mobile','margin-bottom','20',0,''),(171545,54869,'116853','furniture-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(171546,54870,'116854','furniture-mobile','hide_parents','2',0,''),(171547,54871,'116855','furniture-mobile','float','right',0,''),(171548,54871,'116855','furniture-mobile','margin-top','-37',0,''),(171549,54871,'116855','furniture-mobile','link','comments',0,''),(171550,54872,'116856','furniture-mobile','block_type','1',0,''),(171551,54872,'116856','furniture-mobile','padding-right','30',0,''),(171552,54872,'116856','furniture-mobile','padding-right','0',0,'2876'),(171553,54872,'116856','furniture-mobile','background-color','$background-7',0,''),(171554,54872,'116856','furniture-mobile','padding-top','20',0,''),(171555,54872,'116856','furniture-mobile','padding-left','30',0,''),(171556,54872,'116856','furniture-mobile','padding-bottom','20',0,''),(171557,54873,'116857','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(171558,54874,'116858','furniture-mobile','link','products',0,''),(171559,54874,'116858','furniture-mobile','float','right',0,''),(171560,54874,'116858','furniture-mobile','margin-top','-37',0,''),(171561,54876,'116860','furniture-mobile','block_type','1',0,''),(171562,54876,'116860','furniture-mobile','padding-top','20',0,''),(171563,54876,'116860','furniture-mobile','padding-left','20',0,''),(171564,54876,'116860','furniture-mobile','padding-right','20',0,''),(171565,54876,'116860','furniture-mobile','padding-bottom','20',0,''),(171566,54876,'116860','furniture-mobile','background-color','$background-7',0,''),(171567,54876,'116860','furniture-mobile','style_class','order-summary2 hiding-box',0,''),(171568,54877,'116861','furniture-mobile','margin-bottom','20',0,''),(171569,54877,'116861','furniture-mobile','text-align','right',0,''),(171570,54878,'116862','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171571,54880,'116864','furniture-mobile','block_type','1',0,''),(171572,54880,'116864','furniture-mobile','background-color','$background-6',0,''),(171573,54880,'116864','furniture-mobile','padding-bottom','30',0,''),(171574,54881,'116865','furniture-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(171575,54882,'116866','furniture-mobile','block_type','4',0,''),(171576,54882,'116866','furniture-mobile','schema','4-2',0,'2885'),(171577,54883,'116867','furniture-mobile','block_type','1',0,''),(171578,54883,'116867','furniture-mobile','padding-right','40',0,''),(171579,54883,'116867','furniture-mobile','padding-right','0',0,'2885'),(171580,54884,'116868','furniture-mobile','block_type','1',0,''),(171581,54884,'116868','furniture-mobile','background-color','$background-7',0,''),(171582,54884,'116868','furniture-mobile','padding-top','20',0,''),(171583,54884,'116868','furniture-mobile','padding-bottom','20',0,''),(171584,54884,'116868','furniture-mobile','padding-left','30',0,''),(171585,54884,'116868','furniture-mobile','padding-right','30',0,''),(171586,54884,'116868','furniture-mobile','margin-bottom','20',0,''),(171587,54885,'116869','furniture-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(171588,54886,'116870','furniture-mobile','hide_parents','2',0,''),(171589,54887,'116871','furniture-mobile','float','right',0,''),(171590,54887,'116871','furniture-mobile','margin-top','-37',0,''),(171591,54887,'116871','furniture-mobile','link','comments',0,''),(171592,54888,'116872','furniture-mobile','block_type','2',0,''),(171593,54888,'116872','furniture-mobile','margin-bottom','20',0,''),(171594,54888,'116872','furniture-mobile','schema','2-2',0,'2876'),(171595,54888,'116872','furniture-mobile','background-color','$background-7',0,''),(171596,54889,'116873','furniture-mobile','block_type','1',0,''),(171597,54889,'116873','furniture-mobile','border-right-width','20',0,''),(171598,54889,'116873','furniture-mobile','border-right-color','$border-color-4',0,''),(171599,54889,'116873','furniture-mobile','margin-right','-10',0,''),(171600,54889,'116873','furniture-mobile','padding-right','30',0,''),(171601,54889,'116873','furniture-mobile','padding-top','20',0,''),(171602,54889,'116873','furniture-mobile','padding-left','30',0,''),(171603,54889,'116873','furniture-mobile','padding-bottom','20',0,''),(171604,54889,'116873','furniture-mobile','border-right-width','0',0,'2885'),(171605,54889,'116873','furniture-mobile','margin-right','0',0,'2885'),(171606,54889,'116873','furniture-mobile','margin-bottom','20',0,'2885'),(171607,54889,'116873','furniture-mobile','padding-left','20',0,'2885'),(171608,54889,'116873','furniture-mobile','padding-right','20',0,'2885'),(171609,54890,'116874','furniture-mobile','link','contact_information',0,''),(171610,54890,'116874','furniture-mobile','margin-top','-31',0,''),(171611,54890,'116874','furniture-mobile','float','right',0,''),(171612,54893,'116877','furniture-mobile','link','payment_method',0,''),(171613,54893,'116877','furniture-mobile','float','right',0,''),(171614,54893,'116877','furniture-mobile','margin-top','-31',0,''),(171615,54894,'116878','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(171616,54894,'116878','furniture-mobile','padding-top','20',0,''),(171617,54895,'116879','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171618,54895,'116879','furniture-mobile','clear','none',0,''),(171619,54896,'116880','furniture-mobile','block_type','1',0,''),(171620,54896,'116880','furniture-mobile','padding-left','30',0,''),(171621,54896,'116880','furniture-mobile','border-left-width','20',0,''),(171622,54896,'116880','furniture-mobile','border-left-color','$border-color-4',0,''),(171623,54896,'116880','furniture-mobile','margin-left','-10',0,''),(171624,54896,'116880','furniture-mobile','padding-right','30',0,''),(171625,54896,'116880','furniture-mobile','padding-top','20',0,''),(171626,54896,'116880','furniture-mobile','padding-bottom','20',0,''),(171627,54896,'116880','furniture-mobile','border-left-width','0',0,'2885'),(171628,54897,'116881','furniture-mobile','margin-bottom','20',0,''),(171629,54898,'116882','furniture-mobile','link','billing_address',0,''),(171630,54898,'116882','furniture-mobile','float','right',0,''),(171631,54898,'116882','furniture-mobile','margin-top','-31',0,''),(171632,54899,'116883','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171633,54899,'116883','furniture-mobile','clear','none',0,''),(171634,54900,'116884','furniture-mobile','block_type','1',0,''),(171635,54900,'116884','furniture-mobile','padding-right','30',0,''),(171636,54900,'116884','furniture-mobile','background-color','$background-7',0,''),(171637,54900,'116884','furniture-mobile','padding-top','20',0,''),(171638,54900,'116884','furniture-mobile','padding-left','30',0,''),(171639,54900,'116884','furniture-mobile','padding-bottom','20',0,''),(171640,54900,'116884','furniture-mobile','padding-left','20',0,'2885'),(171641,54900,'116884','furniture-mobile','padding-right','20',0,'2885'),(171642,54901,'116885','furniture-mobile','link','products',0,''),(171643,54901,'116885','furniture-mobile','float','right',0,''),(171644,54901,'116885','furniture-mobile','margin-top','-37',0,''),(171645,54902,'116886','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(171646,54903,'116887','furniture-mobile','margin-bottom','20',0,''),(171647,54904,'116888','furniture-mobile','block_type','1',0,''),(171648,54904,'116888','furniture-mobile','padding-top','20',0,''),(171649,54904,'116888','furniture-mobile','padding-left','20',0,''),(171650,54904,'116888','furniture-mobile','padding-right','20',0,''),(171651,54904,'116888','furniture-mobile','padding-bottom','20',0,''),(171652,54904,'116888','furniture-mobile','background-color','$background-7',0,''),(171653,54904,'116888','furniture-mobile','style_class','order-summary',0,''),(171654,54905,'116889','furniture-mobile','margin-bottom','20',0,''),(171655,54905,'116889','furniture-mobile','text-align','right',0,''),(171656,54907,'116891','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171657,54908,'116892','furniture-mobile','block_type','1',0,''),(171658,54908,'116892','furniture-mobile','background-color','$background-6',0,''),(171659,54908,'116892','furniture-mobile','padding-bottom','30',0,''),(171660,54909,'116893','furniture-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(171661,54910,'116894','furniture-mobile','block_type','4',0,''),(171662,54910,'116894','furniture-mobile','schema','4-2',0,'2885'),(171663,54911,'116895','furniture-mobile','block_type','1',0,''),(171664,54911,'116895','furniture-mobile','padding-right','40',0,''),(171665,54911,'116895','furniture-mobile','padding-right','0',0,'2885'),(171666,54912,'116896','furniture-mobile','block_type','1',0,''),(171667,54912,'116896','furniture-mobile','padding-right','30',0,''),(171668,54912,'116896','furniture-mobile','background-color','$background-7',0,''),(171669,54912,'116896','furniture-mobile','padding-top','20',0,''),(171670,54912,'116896','furniture-mobile','padding-left','30',0,''),(171671,54912,'116896','furniture-mobile','padding-bottom','20',0,''),(171672,54912,'116896','furniture-mobile','padding-left','20',0,'2885'),(171673,54912,'116896','furniture-mobile','padding-right','20',0,'2885'),(171674,54914,'116898','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(171675,54915,'116899','furniture-mobile','link','products',0,''),(171676,54915,'116899','furniture-mobile','float','right',0,''),(171677,54915,'116899','furniture-mobile','margin-top','-37',0,''),(171678,54916,'116900','furniture-mobile','block_type','2',0,''),(171679,54916,'116900','furniture-mobile','margin-bottom','20',0,''),(171680,54916,'116900','furniture-mobile','schema','2-2',0,'2876'),(171681,54916,'116900','furniture-mobile','background-color','$background-7',0,''),(171682,54917,'116901','furniture-mobile','block_type','1',0,''),(171683,54917,'116901','furniture-mobile','border-right-width','20',0,''),(171684,54917,'116901','furniture-mobile','border-right-color','$border-color-4',0,''),(171685,54917,'116901','furniture-mobile','margin-right','-10',0,''),(171686,54917,'116901','furniture-mobile','padding-right','30',0,''),(171687,54917,'116901','furniture-mobile','padding-top','20',0,''),(171688,54917,'116901','furniture-mobile','padding-left','30',0,''),(171689,54917,'116901','furniture-mobile','padding-bottom','20',0,''),(171690,54917,'116901','furniture-mobile','border-right-width','0',0,'2885'),(171691,54917,'116901','furniture-mobile','margin-right','0',0,'2885'),(171692,54917,'116901','furniture-mobile','margin-bottom','20',0,'2885'),(171693,54917,'116901','furniture-mobile','padding-left','20',0,'2885'),(171694,54917,'116901','furniture-mobile','padding-right','20',0,'2885'),(171695,54918,'116902','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(171696,54919,'116903','furniture-mobile','link','contact_information',0,''),(171697,54919,'116903','furniture-mobile','margin-top','-31',0,''),(171698,54919,'116903','furniture-mobile','float','right',0,''),(171699,54920,'116904','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(171700,54920,'116904','furniture-mobile','clear','none',0,''),(171701,54922,'116906','furniture-mobile','margin-bottom','20',0,''),(171702,54924,'116908','furniture-mobile','link','shipping_address',0,''),(171703,54924,'116908','furniture-mobile','float','right',0,''),(171704,54924,'116908','furniture-mobile','margin-top','-31',0,''),(171705,54926,'116910','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(171706,54926,'116910','furniture-mobile','padding-top','20',0,''),(171707,54927,'116911','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(171708,54927,'116911','furniture-mobile','clear','none',0,''),(171709,54928,'116912','furniture-mobile','link','shipping_method',0,''),(171710,54928,'116912','furniture-mobile','float','right',0,''),(171711,54928,'116912','furniture-mobile','margin-top','-31',0,''),(171712,54929,'116913','furniture-mobile','block_type','1',0,''),(171713,54929,'116913','furniture-mobile','padding-left','30',0,''),(171714,54929,'116913','furniture-mobile','border-left-width','20',0,''),(171715,54929,'116913','furniture-mobile','border-left-color','$border-color-4',0,''),(171716,54929,'116913','furniture-mobile','margin-left','-10',0,''),(171717,54929,'116913','furniture-mobile','padding-right','30',0,''),(171718,54929,'116913','furniture-mobile','padding-top','20',0,''),(171719,54929,'116913','furniture-mobile','padding-bottom','20',0,''),(171720,54929,'116913','furniture-mobile','border-left-width','0',0,'2885'),(171721,54930,'116914','furniture-mobile','link','billing_address',0,''),(171722,54930,'116914','furniture-mobile','float','right',0,''),(171723,54930,'116914','furniture-mobile','margin-top','-31',0,''),(171724,54931,'116915','furniture-mobile','margin-bottom','20',0,''),(171725,54933,'116917','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(171726,54934,'116918','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171727,54934,'116918','furniture-mobile','clear','none',0,''),(171728,54935,'116919','furniture-mobile','link','payment_method',0,''),(171729,54935,'116919','furniture-mobile','float','right',0,''),(171730,54935,'116919','furniture-mobile','margin-top','-31',0,''),(171731,54936,'116920','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171732,54936,'116920','furniture-mobile','clear','none',0,''),(171733,54937,'116921','furniture-mobile','block_type','1',0,''),(171734,54937,'116921','furniture-mobile','background-color','$background-7',0,''),(171735,54937,'116921','furniture-mobile','padding-top','20',0,''),(171736,54937,'116921','furniture-mobile','padding-bottom','20',0,''),(171737,54937,'116921','furniture-mobile','padding-left','30',0,''),(171738,54937,'116921','furniture-mobile','padding-right','30',0,''),(171739,54937,'116921','furniture-mobile','margin-bottom','20',0,''),(171740,54938,'116922','furniture-mobile','hide_parents','2',0,''),(171741,54939,'116923','furniture-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(171742,54940,'116924','furniture-mobile','float','right',0,''),(171743,54940,'116924','furniture-mobile','margin-top','-37',0,''),(171744,54940,'116924','furniture-mobile','link','comments',0,''),(171745,54941,'116925','furniture-mobile','block_type','1',0,''),(171746,54941,'116925','furniture-mobile','padding-top','20',0,''),(171747,54941,'116925','furniture-mobile','padding-left','20',0,''),(171748,54941,'116925','furniture-mobile','padding-right','20',0,''),(171749,54941,'116925','furniture-mobile','padding-bottom','20',0,''),(171750,54941,'116925','furniture-mobile','background-color','$background-7',0,''),(171751,54941,'116925','furniture-mobile','style_class','order-summary',0,''),(171752,54942,'116926','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171753,54944,'116928','furniture-mobile','margin-bottom','20',0,''),(171754,54944,'116928','furniture-mobile','text-align','right',0,''),(171755,54945,'116929','furniture-mobile','block_type','1',0,''),(171756,54945,'116929','furniture-mobile','background-color','$background-6',0,''),(171757,54945,'116929','furniture-mobile','padding-bottom','30',0,''),(171758,54946,'116930','furniture-mobile','block_type','4',0,''),(171759,54946,'116930','furniture-mobile','schema','4-2',0,'2885'),(171760,54947,'116931','furniture-mobile','block_type','1',0,''),(171761,54947,'116931','furniture-mobile','padding-right','40',0,''),(171762,54947,'116931','furniture-mobile','padding-right','0',0,'2885'),(171763,54948,'116932','furniture-mobile','block_type','2',0,''),(171764,54948,'116932','furniture-mobile','margin-bottom','20',0,''),(171765,54948,'116932','furniture-mobile','schema','2-2',0,'2876'),(171766,54948,'116932','furniture-mobile','background-color','$background-7',0,''),(171767,54949,'116933','furniture-mobile','block_type','1',0,''),(171768,54949,'116933','furniture-mobile','border-right-width','20',0,''),(171769,54949,'116933','furniture-mobile','border-right-color','$border-color-4',0,''),(171770,54949,'116933','furniture-mobile','margin-right','-10',0,''),(171771,54949,'116933','furniture-mobile','padding-right','30',0,''),(171772,54949,'116933','furniture-mobile','padding-top','20',0,''),(171773,54949,'116933','furniture-mobile','padding-left','30',0,''),(171774,54949,'116933','furniture-mobile','padding-bottom','20',0,''),(171775,54949,'116933','furniture-mobile','border-right-width','0',0,'2885'),(171776,54949,'116933','furniture-mobile','margin-right','0',0,'2885'),(171777,54949,'116933','furniture-mobile','margin-bottom','20',0,'2885'),(171778,54949,'116933','furniture-mobile','padding-left','20',0,'2885'),(171779,54949,'116933','furniture-mobile','padding-right','20',0,'2885'),(171780,54950,'116934','furniture-mobile','margin-bottom','20',0,''),(171781,54951,'116935','furniture-mobile','link','shipping_address',0,''),(171782,54951,'116935','furniture-mobile','float','right',0,''),(171783,54951,'116935','furniture-mobile','margin-top','-31',0,''),(171784,54952,'116936','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(171785,54952,'116936','furniture-mobile','clear','none',0,''),(171786,54955,'116939','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(171787,54956,'116940','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(171788,54956,'116940','furniture-mobile','clear','none',0,''),(171789,54957,'116941','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(171790,54957,'116941','furniture-mobile','padding-top','20',0,''),(171791,54959,'116943','furniture-mobile','link','shipping_method',0,''),(171792,54959,'116943','furniture-mobile','float','right',0,''),(171793,54959,'116943','furniture-mobile','margin-top','-31',0,''),(171794,54960,'116944','furniture-mobile','link','contact_information',0,''),(171795,54960,'116944','furniture-mobile','margin-top','-31',0,''),(171796,54960,'116944','furniture-mobile','float','right',0,''),(171797,54961,'116945','furniture-mobile','block_type','1',0,''),(171798,54961,'116945','furniture-mobile','padding-left','30',0,''),(171799,54961,'116945','furniture-mobile','border-left-width','20',0,''),(171800,54961,'116945','furniture-mobile','border-left-color','$border-color-4',0,''),(171801,54961,'116945','furniture-mobile','margin-left','-10',0,''),(171802,54961,'116945','furniture-mobile','padding-right','30',0,''),(171803,54961,'116945','furniture-mobile','padding-top','20',0,''),(171804,54961,'116945','furniture-mobile','padding-bottom','20',0,''),(171805,54961,'116945','furniture-mobile','border-left-width','0',0,'2885'),(171806,54962,'116946','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171807,54962,'116946','furniture-mobile','clear','none',0,''),(171808,54963,'116947','furniture-mobile','margin-bottom','20',0,''),(171809,54964,'116948','furniture-mobile','link','billing_address',0,''),(171810,54964,'116948','furniture-mobile','float','right',0,''),(171811,54964,'116948','furniture-mobile','margin-top','-31',0,''),(171812,54966,'116950','furniture-mobile','link','payment_method',0,''),(171813,54966,'116950','furniture-mobile','float','right',0,''),(171814,54966,'116950','furniture-mobile','margin-top','-31',0,''),(171815,54967,'116951','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(171816,54968,'116952','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171817,54968,'116952','furniture-mobile','clear','none',0,''),(171818,54969,'116953','furniture-mobile','block_type','1',0,''),(171819,54969,'116953','furniture-mobile','padding-right','30',0,''),(171820,54969,'116953','furniture-mobile','background-color','$background-7',0,''),(171821,54969,'116953','furniture-mobile','padding-top','20',0,''),(171822,54969,'116953','furniture-mobile','padding-left','30',0,''),(171823,54969,'116953','furniture-mobile','padding-bottom','20',0,''),(171824,54969,'116953','furniture-mobile','padding-left','20',0,'2885'),(171825,54969,'116953','furniture-mobile','padding-right','20',0,'2885'),(171826,54970,'116954','furniture-mobile','link','products',0,''),(171827,54970,'116954','furniture-mobile','float','right',0,''),(171828,54970,'116954','furniture-mobile','margin-top','-37',0,''),(171829,54971,'116955','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(171830,54973,'116957','furniture-mobile','block_type','1',0,''),(171831,54973,'116957','furniture-mobile','background-color','$background-7',0,''),(171832,54973,'116957','furniture-mobile','padding-top','20',0,''),(171833,54973,'116957','furniture-mobile','padding-bottom','20',0,''),(171834,54973,'116957','furniture-mobile','padding-left','30',0,''),(171835,54973,'116957','furniture-mobile','padding-right','30',0,''),(171836,54973,'116957','furniture-mobile','margin-bottom','20',0,''),(171837,54974,'116958','furniture-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(171838,54975,'116959','furniture-mobile','float','right',0,''),(171839,54975,'116959','furniture-mobile','margin-top','-37',0,''),(171840,54975,'116959','furniture-mobile','link','comments',0,''),(171841,54976,'116960','furniture-mobile','hide_parents','2',0,''),(171842,54977,'116961','furniture-mobile','block_type','1',0,''),(171843,54977,'116961','furniture-mobile','padding-top','20',0,''),(171844,54977,'116961','furniture-mobile','padding-left','20',0,''),(171845,54977,'116961','furniture-mobile','padding-right','20',0,''),(171846,54977,'116961','furniture-mobile','padding-bottom','20',0,''),(171847,54977,'116961','furniture-mobile','background-color','$background-7',0,''),(171848,54977,'116961','furniture-mobile','style_class','order-summary',0,''),(171849,54979,'116963','furniture-mobile','margin-bottom','20',0,''),(171850,54979,'116963','furniture-mobile','text-align','right',0,''),(171851,54980,'116964','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171852,54981,'116965','furniture-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(171853,54982,'116966','furniture-mobile','block_type','1',0,''),(171854,54984,'116968','furniture-mobile','block_type','2',0,''),(171855,54984,'116968','furniture-mobile','font-weight','400',0,''),(171856,54984,'116968','furniture-mobile','padding-bottom','20',0,''),(171857,54984,'116968','furniture-mobile','schema','2-2',0,'2885'),(171858,54985,'116969','furniture-mobile','show_captcha','on',0,''),(171859,54986,'116970','furniture-mobile','font-weight','400',0,''),(171860,54986,'116970','furniture-mobile','padding-left','40',0,''),(171861,54986,'116970','furniture-mobile','time_format','24',0,''),(171862,54986,'116970','furniture-mobile','show_icons','on',0,''),(171863,54986,'116970','furniture-mobile','padding-left','0',0,'2885'),(171864,54987,'116971','furniture-mobile','block_type','1',0,''),(171865,54988,'116972','furniture-mobile','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(171866,54989,'116973','furniture-mobile','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(171867,54989,'116973','furniture-mobile','margin-bottom','40',0,''),(171868,54990,'116102.000001','furniture-mobile','block_type','1',0,''),(171869,54991,'116103.000001','furniture-mobile','block_type','6',0,''),(171870,54991,'116103.000001','furniture-mobile','schema','6-3',0,'2885'),(171871,54992,'116104.000001','furniture-mobile','aria_name','account-menu',0,''),(171928,55012,'116109.000001','furniture-mobile','text','<h1>##CREDIT_AMOUNT_HISTORY##</h1>',0,''),(171929,55013,'1638895944.9672','furniture-mobile','margin-bottom','20',0,''),(171930,55014,'116974','furniture-mobile','width','680',0,''),(171931,55014,'116974','furniture-mobile','font-weight','normal',0,''),(171932,55014,'116974','furniture-mobile','font-size','12',0,''),(171933,55014,'116974','furniture-mobile','padding-top','20',0,''),(171934,55014,'116974','furniture-mobile','padding-bottom','20',0,''),(171935,55014,'116974','furniture-mobile','color','$color-font-8',0,''),(171936,55015,'116975','furniture-mobile','block_type','3',0,''),(171937,55015,'116975','furniture-mobile','font-weight','normal',0,''),(171938,55015,'116975','furniture-mobile','padding-top','20',0,''),(171939,55016,'116976','furniture-mobile','font-size','12',0,''),(171940,55017,'116977','furniture-mobile','text','<p>If undelivered please return to:</p>',1,''),(171941,55017,'116977','furniture-mobile','font-size','12',0,''),(171942,55017,'116977','furniture-mobile','font-weight','bold',0,''),(171943,55018,'116978','furniture-mobile','text','<p>Thank you for your order</p>',1,''),(171944,55018,'116978','furniture-mobile','color','$color-font-10',0,''),(171945,55018,'116978','furniture-mobile','font-size','13',0,''),(171946,55018,'116978','furniture-mobile','font-weight','bold',0,''),(171947,55018,'116978','furniture-mobile','padding-top','5',0,''),(171948,55018,'116978','furniture-mobile','text-align','center',0,''),(171949,55019,'116979','furniture-mobile','font-weight','400',0,''),(171950,55019,'116979','furniture-mobile','text-align','center',0,''),(171951,55019,'116979','furniture-mobile','padding-top','0',0,''),(171953,55019,'116979','furniture-mobile','padding-left','20',0,''),(171954,55019,'116979','furniture-mobile','padding-right','20',0,''),(171955,55020,'116980','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(171956,55020,'116980','furniture-mobile','font-size','12',0,''),(171957,55020,'116980','furniture-mobile','font-weight','bold',0,''),(171958,55020,'116980','furniture-mobile','text-align','right',0,''),(171959,55021,'116981','furniture-mobile','block_type','6',0,''),(171960,55021,'116981','furniture-mobile','font-weight','normal',0,''),(171961,55021,'116981','furniture-mobile','font-size','16',0,''),(171962,55022,'116982','furniture-mobile','text','<p>Email:</p>',1,''),(171963,55022,'116982','furniture-mobile','font-weight','normal',0,''),(171964,55022,'116982','furniture-mobile','text-align','right',0,''),(171965,55022,'116982','furniture-mobile','font-size','12',0,''),(171966,55023,'116983','furniture-mobile','font-weight','normal',0,''),(171967,55023,'116983','furniture-mobile','text-align','right',0,''),(171968,55023,'116983','furniture-mobile','font-size','12',0,''),(171969,55024,'116984','furniture-mobile','block_type','6',0,''),(171970,55024,'116984','furniture-mobile','font-weight','normal',0,''),(171971,55024,'116984','furniture-mobile','font-size','16',0,''),(171972,55025,'116985','furniture-mobile','text','<p>Phone:</p>',1,''),(171973,55025,'116985','furniture-mobile','font-weight','normal',0,''),(171974,55025,'116985','furniture-mobile','text-align','right',0,''),(171975,55025,'116985','furniture-mobile','font-size','12',0,''),(171976,55026,'116986','furniture-mobile','font-weight','normal',0,''),(171977,55026,'116986','furniture-mobile','text-align','right',0,''),(171978,55026,'116986','furniture-mobile','font-size','12',0,''),(171979,55027,'116987','furniture-mobile','font-weight','400',0,''),(171980,55027,'116987','furniture-mobile','padding-top','20',0,''),(171981,55027,'116987','furniture-mobile','padding-bottom','0',0,''),(171982,55027,'116987','furniture-mobile','font-size','12',0,''),(171983,55028,'116988','furniture-mobile','block_type','2',0,''),(171984,55028,'116988','furniture-mobile','font-weight','normal',0,''),(171985,55028,'116988','furniture-mobile','padding-bottom','20',0,''),(171986,55029,'116989','furniture-mobile','font-weight','400',0,''),(171987,55029,'116989','furniture-mobile','padding-top','20',0,''),(171989,55030,'116990','furniture-mobile','block_type','11',0,''),(171990,55030,'116990','furniture-mobile','font-weight','normal',0,''),(171991,55031,'116991','furniture-mobile','text','<p>Web:</p>',1,''),(171992,55031,'116991','furniture-mobile','font-weight','normal',0,''),(171993,55031,'116991','furniture-mobile','text-align','right',0,''),(171994,55032,'116992','furniture-mobile','font-weight','normal',0,''),(171995,55032,'116992','furniture-mobile','text-align','right',0,''),(171996,55033,'116993','furniture-mobile','block_type','11',0,''),(171997,55033,'116993','furniture-mobile','font-weight','normal',0,''),(171998,55034,'116994','furniture-mobile','text','<p>Phone:</p>',1,''),(171999,55034,'116994','furniture-mobile','font-weight','normal',0,''),(172000,55034,'116994','furniture-mobile','text-align','right',0,''),(172001,55035,'116995','furniture-mobile','font-weight','normal',0,''),(172002,55035,'116995','furniture-mobile','text-align','right',0,''),(172003,55036,'116996','furniture-mobile','block_type','11',0,''),(172004,55036,'116996','furniture-mobile','font-weight','normal',0,''),(172005,55037,'116997','furniture-mobile','text','<p>Email:</p>',1,''),(172006,55037,'116997','furniture-mobile','font-weight','normal',0,''),(172007,55037,'116997','furniture-mobile','text-align','right',0,''),(172008,55038,'116998','furniture-mobile','font-weight','normal',0,''),(172009,55038,'116998','furniture-mobile','text-align','right',0,''),(172010,55039,'116999','furniture-mobile','block_type','1',0,''),(172011,55040,'117000','furniture-mobile','font-weight','normal',0,''),(172012,55040,'117000','furniture-mobile','text-align','right',0,''),(172013,55040,'117000','furniture-mobile','padding-bottom','10',0,''),(172014,55040,'117000','furniture-mobile','address_spacer',',',0,''),(172015,55040,'117000','furniture-mobile','font-size','12',0,''),(172016,55041,'117001','furniture-mobile','block_type','5',0,''),(172017,55041,'117001','furniture-mobile','font-weight','normal',0,''),(172018,55041,'117001','furniture-mobile','border-bottom-width','1',0,''),(172019,55041,'117001','furniture-mobile','border-bottom-color','$border-color-4',0,''),(172020,55041,'117001','furniture-mobile','border-top-width','1',0,''),(172021,55041,'117001','furniture-mobile','border-top-color','$border-color-4',0,''),(172022,55041,'117001','furniture-mobile','border-left-color','$border-color-4',0,''),(172023,55041,'117001','furniture-mobile','border-left-width','1',0,''),(172024,55042,'117002','furniture-mobile','block_type','1',0,''),(172025,55042,'117002','furniture-mobile','font-weight','normal',0,''),(172026,55042,'117002','furniture-mobile','padding-top','10',0,''),(172027,55042,'117002','furniture-mobile','padding-left','10',0,''),(172028,55042,'117002','furniture-mobile','padding-right','10',0,''),(172029,55043,'117003','furniture-mobile','font-weight','400',0,''),(172030,55043,'117003','furniture-mobile','line-height','120',0,''),(172031,55043,'117003','furniture-mobile','line_height_measure','%',0,''),(172032,55043,'117003','furniture-mobile','font-size','12',0,''),(172033,55044,'117004','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(172034,55044,'117004','furniture-mobile','font-size','14',0,''),(172035,55044,'117004','furniture-mobile','font-weight','bold',0,''),(172036,55044,'117004','furniture-mobile','padding-bottom','10',0,''),(172037,55045,'117005','furniture-mobile','block_type','1',0,''),(172038,55045,'117005','furniture-mobile','background-color','$background-6',0,''),(172039,55045,'117005','furniture-mobile','padding-top','20',0,''),(172040,55045,'117005','furniture-mobile','padding-left','10',0,''),(172041,55045,'117005','furniture-mobile','padding-right','10',0,''),(172042,55045,'117005','furniture-mobile','padding-bottom','20',0,''),(172043,55045,'117005','furniture-mobile','font-size','14',0,''),(172044,55046,'117006','furniture-mobile','block_type','4',0,''),(172045,55046,'117006','furniture-mobile','font-weight','normal',0,''),(172046,55046,'117006','furniture-mobile','border-top-width','1',0,''),(172047,55046,'117006','furniture-mobile','border-top-color','$border-color-4',0,''),(172048,55046,'117006','furniture-mobile','border-left-width','1',0,''),(172049,55046,'117006','furniture-mobile','border-left-color','$border-color-4',0,''),(172050,55046,'117006','furniture-mobile','border-right-width','1',0,''),(172051,55046,'117006','furniture-mobile','border-right-color','$border-color-4',0,''),(172052,55046,'117006','furniture-mobile','border-bottom-width','1',0,''),(172053,55046,'117006','furniture-mobile','border-bottom-color','$border-color-4',0,''),(172054,55047,'117007','furniture-mobile','block_type','2',0,''),(172055,55047,'117007','furniture-mobile','font-weight','normal',0,''),(172056,55047,'117007','furniture-mobile','border-right-width','1',0,''),(172057,55047,'117007','furniture-mobile','border-right-color','$border-color-4',0,''),(172058,55048,'117008','furniture-mobile','block_type','1',0,''),(172059,55048,'117008','furniture-mobile','font-weight','400',0,''),(172060,55048,'117008','furniture-mobile','background-color','$background-6',0,''),(172061,55048,'117008','furniture-mobile','padding-top','10',0,''),(172062,55048,'117008','furniture-mobile','padding-left','10',0,''),(172063,55048,'117008','furniture-mobile','padding-right','10',0,''),(172064,55048,'117008','furniture-mobile','padding-bottom','30',0,''),(172065,55049,'117009','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(172066,55049,'117009','furniture-mobile','font-size','14',0,''),(172067,55049,'117009','furniture-mobile','font-weight','bold',0,''),(172068,55050,'117010','furniture-mobile','font-size','12',0,''),(172069,55051,'117011','furniture-mobile','block_type','1',0,''),(172070,55051,'117011','furniture-mobile','font-weight','normal',0,''),(172071,55051,'117011','furniture-mobile','padding-top','10',0,''),(172072,55051,'117011','furniture-mobile','padding-left','10',0,''),(172073,55051,'117011','furniture-mobile','padding-right','10',0,''),(172074,55051,'117011','furniture-mobile','padding-bottom','10',0,''),(172075,55052,'117012','furniture-mobile','font-weight','normal',0,''),(172076,55053,'117013','furniture-mobile','text','<p>CUSTOMER:</p>',1,''),(172077,55053,'117013','furniture-mobile','font-size','13',0,''),(172078,55053,'117013','furniture-mobile','font-weight','bold',0,''),(172079,55054,'117014','furniture-mobile','text','<p>PHONE NUMBER:</p>',1,''),(172080,55054,'117014','furniture-mobile','font-size','14',0,''),(172081,55054,'117014','furniture-mobile','font-weight','bold',0,''),(172082,55054,'117014','furniture-mobile','padding-top','10',0,''),(172083,55055,'117015','furniture-mobile','font-weight','normal',0,''),(172084,55057,'117017','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(172085,55057,'117017','furniture-mobile','font-weight','bold',0,''),(172086,55057,'117017','furniture-mobile','font-size','14',0,''),(172087,55057,'117017','furniture-mobile','padding-top','10',0,''),(172088,55058,'117018','furniture-mobile','block_type','2',0,''),(172089,55058,'117018','furniture-mobile','font-weight','normal',0,''),(172090,55058,'117018','furniture-mobile','border-top-width','1',0,''),(172091,55058,'117018','furniture-mobile','border-top-color','$border-color-4',0,''),(172092,55058,'117018','furniture-mobile','border-right-width','1',0,''),(172093,55058,'117018','furniture-mobile','border-right-color','$border-color-4',0,''),(172094,55059,'117019','furniture-mobile','block_type','1',0,''),(172095,55059,'117019','furniture-mobile','font-weight','normal',0,''),(172096,55059,'117019','furniture-mobile','padding-top','10',0,''),(172097,55059,'117019','furniture-mobile','padding-left','10',0,''),(172098,55059,'117019','furniture-mobile','padding-right','10',0,''),(172099,55059,'117019','furniture-mobile','padding-bottom','10',0,''),(172100,55059,'117019','furniture-mobile','border-right-width','1',0,''),(172101,55059,'117019','furniture-mobile','border-right-color','$border-color-4',0,''),(172102,55061,'117021','furniture-mobile','text','<p>Shipping via</p>',1,''),(172103,55061,'117021','furniture-mobile','font-weight','bold',0,''),(172104,55061,'117021','furniture-mobile','font-size','14',0,''),(172105,55062,'117022','furniture-mobile','block_type','1',0,''),(172106,55062,'117022','furniture-mobile','font-weight','normal',0,''),(172107,55062,'117022','furniture-mobile','padding-top','10',0,''),(172108,55062,'117022','furniture-mobile','padding-left','10',0,''),(172109,55062,'117022','furniture-mobile','padding-right','10',0,''),(172110,55062,'117022','furniture-mobile','padding-bottom','10',0,''),(172111,55063,'117023','furniture-mobile','text','<p>Shipping service</p>',1,''),(172112,55063,'117023','furniture-mobile','font-weight','bold',0,''),(172113,55063,'117023','furniture-mobile','font-size','14',0,''),(172114,55065,'117025','furniture-mobile','font-size','14',0,''),(172115,55065,'117025','furniture-mobile','font-weight','bold',0,''),(172116,55065,'117025','furniture-mobile','text-align','center',0,''),(172117,55065,'117025','furniture-mobile','padding-bottom','10',0,''),(172118,55065,'117025','furniture-mobile','padding-top','10',0,''),(172119,55066,'117026','furniture-mobile','text','<p>Payment date:</p>',1,''),(172120,55066,'117026','furniture-mobile','font-weight','bold',0,''),(172121,55066,'117026','furniture-mobile','text-align','center',0,''),(172122,55066,'117026','furniture-mobile','font-size','12',0,''),(172123,55067,'117027','furniture-mobile','font-weight','normal',0,''),(172124,55067,'117027','furniture-mobile','text-align','center',0,''),(172125,55067,'117027','furniture-mobile','padding-bottom','10',0,''),(172130,55069,'117034','furniture-mobile','text-align','center',0,''),(172131,55069,'117034','furniture-mobile','padding-top','10',0,''),(172132,55070,'1639155816.3893','furniture-mobile','block_type','1',0,''),(172133,55071,'117028','furniture-mobile','padding-top','30',0,''),(172134,55071,'117028','furniture-mobile','padding-bottom','30',0,''),(172135,55075,'117032','furniture-mobile','col_in_row','4',0,''),(172136,55075,'117032','furniture-mobile','listing_type','productListing',0,''),(172137,55075,'117032','furniture-mobile','view_as','carousel',0,''),(172138,55075,'117032','furniture-mobile','col_in_row','3',0,'2885'),(172139,55075,'117032','furniture-mobile','col_in_row','2',0,'2876'),(172140,55075,'117032','furniture-mobile','col_in_row','1',0,'2906'),(172141,55077,'1639485067.5512','furniture-mobile','padding-top','30',0,''),(172142,55077,'1639485067.5512','furniture-mobile','padding-bottom','30',0,''),(172143,55079,'1639154415.2739','furniture-mobile','block_type','1',0,''),(172144,55081,'117036','furniture-mobile','heading_type','h1',0,''),(172145,55082,'1639419797.9718','furniture-mobile','page_id','4',0,''),(172146,55082,'1639419797.9718','furniture-mobile','padding-top','30',0,''),(172147,55082,'1639419797.9718','furniture-mobile','padding-bottom','30',0,''),(172148,55085,'117039','furniture-mobile','text-align','center',0,''),(172149,55085,'117039','furniture-mobile','padding-top','10',0,''),(172150,55090,'117044','furniture-mobile','block_type','1',0,''),(172151,55091,'117045','furniture-mobile','block_type','1',0,''),(172152,55091,'117045','furniture-mobile','max-width','800',0,''),(172153,55091,'117045','furniture-mobile','margin','0 auto',0,''),(172154,55091,'117045','furniture-mobile','background-color','$background-7',0,''),(172155,55092,'117046','furniture-mobile','color','$color-font-8',0,''),(172156,55092,'117046','furniture-mobile','font-size','12',0,''),(172157,55092,'117046','furniture-mobile','padding-top','20',0,''),(172158,55092,'117046','furniture-mobile','padding-bottom','20',0,''),(172159,55092,'117046','furniture-mobile','border-top-width','1',0,''),(172160,55092,'117046','furniture-mobile','border-top-color','$border-color-4',0,''),(172161,55093,'117047','furniture-mobile','font-weight','normal',0,''),(172162,55093,'117047','furniture-mobile','padding-top','20',0,''),(172163,55093,'117047','furniture-mobile','padding-left','10',0,''),(172164,55093,'117047','furniture-mobile','padding-right','10',0,''),(172165,55093,'117047','furniture-mobile','padding-bottom','20',0,''),(172166,55093,'117047','furniture-mobile','color','$color-font-8',0,''),(172167,55093,'117047','furniture-mobile','font-size','14',0,''),(172168,55094,'117048','furniture-mobile','block_type','7',0,''),(172169,55094,'117048','furniture-mobile','font-weight','normal',0,''),(172170,55094,'117048','furniture-mobile','background-color','$background-2',0,''),(172171,55094,'117048','furniture-mobile','padding-top','5',0,''),(172172,55094,'117048','furniture-mobile','padding-left','10',0,''),(172173,55094,'117048','furniture-mobile','padding-right','10',0,''),(172174,55094,'117048','furniture-mobile','padding-bottom','5',0,''),(172175,55095,'117049','furniture-mobile','color','$color-font-1',0,''),(172176,55095,'117049','furniture-mobile','font-size','14',0,''),(172177,55095,'117049','furniture-mobile','font-weight','normal',0,''),(172178,55096,'117050','furniture-mobile','font-weight','normal',0,''),(172179,55096,'117050','furniture-mobile','text-align','right',0,''),(172180,55096,'117050','furniture-mobile','color','$color-font-1',0,''),(172181,55096,'117050','furniture-mobile','font-size','12',0,''),(172182,55097,'117051','furniture-mobile','font-weight','normal',0,''),(172183,55097,'117051','furniture-mobile','padding-bottom','10',0,''),(172184,55097,'117051','furniture-mobile','padding-top','10',0,''),(172185,55097,'117051','furniture-mobile','logo_from','theme',0,''),(172186,55097,'117051','furniture-mobile','padding-left','20',0,''),(172187,55097,'117051','furniture-mobile','background-color','$background-1',0,''),(172188,55098,'117052','furniture-mobile','block_type','1',0,''),(172189,55099,'117053','furniture-mobile','block_type','1',0,''),(172190,55099,'117053','furniture-mobile','max-width','800',0,''),(172191,55099,'117053','furniture-mobile','margin','0 auto',0,''),(172192,55099,'117053','furniture-mobile','background-color','$background-7',0,''),(172193,55100,'117054','furniture-mobile','color','$color-font-8',0,''),(172194,55100,'117054','furniture-mobile','font-size','12',0,''),(172195,55100,'117054','furniture-mobile','padding-top','20',0,''),(172196,55100,'117054','furniture-mobile','padding-bottom','20',0,''),(172197,55100,'117054','furniture-mobile','border-top-width','1',0,''),(172198,55100,'117054','furniture-mobile','border-top-color','$border-color-4',0,''),(172199,55101,'117055','furniture-mobile','font-weight','normal',0,''),(172200,55101,'117055','furniture-mobile','padding-bottom','10',0,''),(172201,55101,'117055','furniture-mobile','background-color','$background-2',0,''),(172202,55101,'117055','furniture-mobile','logo','themes/furniture-mobile/img/logo-white-1.png',1,''),(172203,55101,'117055','furniture-mobile','padding-left','20',0,''),(172204,55101,'117055','furniture-mobile','padding-top','10',0,''),(172205,55102,'117056','furniture-mobile','font-weight','normal',0,''),(172206,55102,'117056','furniture-mobile','padding-top','20',0,''),(172207,55102,'117056','furniture-mobile','padding-left','10',0,''),(172208,55102,'117056','furniture-mobile','padding-right','10',0,''),(172209,55102,'117056','furniture-mobile','padding-bottom','20',0,''),(172210,55102,'117056','furniture-mobile','color','$color-font-8',0,''),(172211,55102,'117056','furniture-mobile','font-size','14',0,''),(172212,55103,'117057','furniture-mobile','block_type','7',0,''),(172213,55103,'117057','furniture-mobile','font-weight','normal',0,''),(172214,55103,'117057','furniture-mobile','background-color','$background-2',0,''),(172215,55103,'117057','furniture-mobile','padding-top','5',0,''),(172216,55103,'117057','furniture-mobile','padding-left','10',0,''),(172217,55103,'117057','furniture-mobile','padding-right','10',0,''),(172218,55103,'117057','furniture-mobile','padding-bottom','5',0,''),(172219,55104,'117058','furniture-mobile','color','$color-font-1',0,''),(172220,55104,'117058','furniture-mobile','font-size','15',0,''),(172221,55104,'117058','furniture-mobile','font-weight','700',0,''),(172222,55105,'117059','furniture-mobile','font-weight','normal',0,''),(172223,55105,'117059','furniture-mobile','text-align','right',0,''),(172224,55105,'117059','furniture-mobile','color','$color-font-9',0,''),(172225,55105,'117059','furniture-mobile','font-size','12',0,''),(172226,55106,'117060','furniture-mobile','block_type','1',0,''),(172227,55106,'117060','furniture-mobile','background-color','$background-6',0,''),(172228,55107,'117061','furniture-mobile','block_type','1',0,''),(172229,55107,'117061','furniture-mobile','max-width','800',0,''),(172230,55107,'117061','furniture-mobile','margin','0 auto',0,''),(172231,55108,'117062','furniture-mobile','block_type','1',0,''),(172232,55108,'117062','furniture-mobile','background-color','$background-7',0,''),(172233,55108,'117062','furniture-mobile','padding-top','20',0,''),(172234,55108,'117062','furniture-mobile','padding-left','20',0,''),(172235,55108,'117062','furniture-mobile','padding-right','20',0,''),(172236,55108,'117062','furniture-mobile','padding-bottom','20',0,''),(172237,55109,'117063','furniture-mobile','font-weight','normal',0,''),(172238,55109,'117063','furniture-mobile','padding-top','20',0,''),(172239,55109,'117063','furniture-mobile','padding-bottom','20',0,''),(172240,55109,'117063','furniture-mobile','color','$color-font-8',0,''),(172241,55109,'117063','furniture-mobile','font-size','14',0,''),(172242,55110,'117064','furniture-mobile','block_type','7',0,''),(172243,55110,'117064','furniture-mobile','font-weight','normal',0,''),(172244,55110,'117064','furniture-mobile','padding-left','10',0,''),(172245,55110,'117064','furniture-mobile','padding-right','10',0,''),(172246,55110,'117064','furniture-mobile','padding-bottom','15',0,''),(172247,55110,'117064','furniture-mobile','border-bottom-width','1',0,''),(172248,55110,'117064','furniture-mobile','border-bottom-color','$border-color-4',0,''),(172249,55111,'117065','furniture-mobile','color','$color-font-8',0,''),(172250,55111,'117065','furniture-mobile','font-size','14',0,''),(172251,55111,'117065','furniture-mobile','font-weight','700',0,''),(172252,55112,'117066','furniture-mobile','font-weight','normal',0,''),(172253,55112,'117066','furniture-mobile','text-align','right',0,''),(172254,55112,'117066','furniture-mobile','color','$color-font-9',0,''),(172255,55112,'117066','furniture-mobile','font-size','11',0,''),(172256,55112,'117066','furniture-mobile','text-transform','uppercase',0,''),(172257,55113,'117067','furniture-mobile','color','$color-font-9',0,''),(172258,55113,'117067','furniture-mobile','font-size','12',0,''),(172259,55113,'117067','furniture-mobile','padding-top','20',0,''),(172260,55113,'117067','furniture-mobile','padding-bottom','20',0,''),(172261,55113,'117067','furniture-mobile','text-align','center',0,''),(172262,55114,'117068','furniture-mobile','font-weight','normal',0,''),(172263,55114,'117068','furniture-mobile','padding-bottom','10',0,''),(172264,55114,'117068','furniture-mobile','padding-top','10',0,''),(172265,55114,'117068','furniture-mobile','text-align','center',0,''),(172266,55114,'117068','furniture-mobile','logo_from','theme',0,''),(172267,55115,'117069','furniture-mobile','block_type','1',0,''),(172268,55115,'117069','furniture-mobile','background-color','$background-6',0,''),(172269,55115,'117069','furniture-mobile','padding-top','20',0,''),(172270,55115,'117069','furniture-mobile','padding-bottom','20',0,''),(172271,55116,'117070','furniture-mobile','block_type','1',0,''),(172272,55116,'117070','furniture-mobile','max-width','800',0,''),(172273,55116,'117070','furniture-mobile','margin','0 auto',0,''),(172274,55117,'117071','furniture-mobile','color','$color-font-9',0,''),(172275,55117,'117071','furniture-mobile','font-size','12',0,''),(172276,55117,'117071','furniture-mobile','padding-top','20',0,''),(172277,55117,'117071','furniture-mobile','padding-bottom','20',0,''),(172278,55117,'117071','furniture-mobile','text-align','left',0,''),(172279,55118,'117072','furniture-mobile','block_type','1',0,''),(172280,55118,'117072','furniture-mobile','background-color','$background-7',0,''),(172281,55118,'117072','furniture-mobile','padding-top','20',0,''),(172282,55118,'117072','furniture-mobile','padding-left','20',0,''),(172283,55118,'117072','furniture-mobile','padding-right','20',0,''),(172284,55118,'117072','furniture-mobile','padding-bottom','20',0,''),(172285,55118,'117072','furniture-mobile','border-top-width','1',0,''),(172286,55118,'117072','furniture-mobile','border-left-width','1',0,''),(172287,55118,'117072','furniture-mobile','border-right-width','1',0,''),(172288,55118,'117072','furniture-mobile','border-bottom-width','1',0,''),(172289,55118,'117072','furniture-mobile','border-top-color','$border-color-4',0,''),(172290,55118,'117072','furniture-mobile','border-left-color','$border-color-4',0,''),(172291,55118,'117072','furniture-mobile','border-bottom-color','$border-color-4',0,''),(172292,55118,'117072','furniture-mobile','border-right-color','$border-color-4',0,''),(172293,55119,'117073','furniture-mobile','block_type','2',0,''),(172294,55120,'117074','furniture-mobile','font-weight','normal',0,''),(172295,55120,'117074','furniture-mobile','padding-bottom','10',0,''),(172296,55120,'117074','furniture-mobile','padding-top','10',0,''),(172297,55120,'117074','furniture-mobile','logo_from','theme',0,''),(172298,55121,'117075','furniture-mobile','font-weight','normal',0,''),(172299,55121,'117075','furniture-mobile','text-align','right',0,''),(172300,55121,'117075','furniture-mobile','color','$color-font-9',0,''),(172301,55121,'117075','furniture-mobile','font-size','11',0,''),(172302,55121,'117075','furniture-mobile','text-transform','uppercase',0,''),(172303,55122,'117076','furniture-mobile','color','$color-font-8',0,''),(172304,55122,'117076','furniture-mobile','font-size','14',0,''),(172305,55122,'117076','furniture-mobile','font-weight','700',0,''),(172306,55122,'117076','furniture-mobile','text-align','right',0,''),(172307,55123,'117077','furniture-mobile','font-weight','normal',0,''),(172308,55123,'117077','furniture-mobile','padding-top','20',0,''),(172309,55123,'117077','furniture-mobile','padding-bottom','20',0,''),(172310,55123,'117077','furniture-mobile','color','$color-font-8',0,''),(172311,55123,'117077','furniture-mobile','font-size','14',0,''),(172312,55124,'121029','furniture-mobile','block_type','1',0,''),(172313,55127,'121032','furniture-mobile','margin-bottom','30',0,''),(172314,55128,'121025','furniture-mobile','block_type','1',0,''),(172315,55129,'121026','furniture-mobile','text','<h1>CATALOGUE</h1>',0,''),(172316,55131,'117078','furniture-mobile','block_type','1',0,''),(172317,55131,'117078','furniture-mobile','font-weight','normal',0,''),(172318,55131,'117078','furniture-mobile','padding-top','20',0,''),(172319,55131,'117078','furniture-mobile','background-color','$background-2',0,''),(172320,55131,'117078','furniture-mobile','style_class','preFooter',0,''),(172321,55131,'117078','furniture-mobile','padding-bottom','25',0,''),(172322,55132,'120866','furniture-mobile','block_type','6',0,''),(172323,55132,'120866','furniture-mobile','schema','6-3',0,'2876'),(172324,55133,'117091','furniture-mobile','view_item','data_format',0,''),(172325,55133,'117091','furniture-mobile','address_spacer',',<span> </span>',0,''),(172326,55133,'117091','furniture-mobile','color','$color-font-3',0,''),(172327,55133,'117091','furniture-mobile','data_format_content','<div>##TITLE##</div><div>Location: ##POST_ADDRESS##</div><div>Phone number: ##TELEPHONE##</div>',0,''),(172328,55133,'117091','furniture-mobile','margin-top','20',0,'2876'),(172329,55134,'120868','furniture-mobile','logo_from','theme',0,''),(172330,55134,'120868','furniture-mobile','margin-bottom','25',0,''),(172331,55134,'120868','furniture-mobile','padding-right','20',0,''),(172332,55134,'120868','furniture-mobile','display_none','1',0,'2876'),(172333,55135,'120871','furniture-mobile','block_type','1',0,''),(172334,55135,'120871','furniture-mobile','padding-left','15',0,''),(172335,55135,'120871','furniture-mobile','padding-right','15',0,''),(172336,55135,'120871','furniture-mobile','border-left-width','1',0,''),(172337,55135,'120871','furniture-mobile','border-right-width','1',0,''),(172338,55135,'120871','furniture-mobile','border-left-color','$border-color-2',0,''),(172339,55135,'120871','furniture-mobile','border-right-color','$border-color-2',0,''),(172340,55135,'120871','furniture-mobile','padding-left','0',0,'2876'),(172341,55135,'120871','furniture-mobile','padding-right','0',0,'2876'),(172342,55135,'120871','furniture-mobile','border-left-width','0',0,'2876'),(172343,55135,'120871','furniture-mobile','border-right-width','0',0,'2876'),(172344,55136,'117085','furniture-mobile','class','menu-style-2',0,''),(172345,55136,'117085','furniture-mobile','type','builder',0,''),(172346,55136,'117085','furniture-mobile','style','3',0,''),(172347,55136,'117085','furniture-mobile','lev2_vis','click',0,'2885'),(172348,55137,'117093','furniture-mobile','block_type','1',0,''),(172349,55137,'117093','furniture-mobile','font-weight','400',0,''),(172350,55137,'117093','furniture-mobile','padding-top','20',0,''),(172351,55137,'117093','furniture-mobile','padding-bottom','20',0,''),(172352,55137,'117093','furniture-mobile','schema','2-2',0,''),(172353,55137,'117093','furniture-mobile','schema','2-3',0,'2885'),(172354,55137,'117093','furniture-mobile','background-color','$background-1',0,''),(172355,55138,'117094','furniture-mobile','color','$color-font-3',0,''),(172356,55138,'117094','furniture-mobile','text-align','center',0,''),(172357,55138,'117094','furniture-mobile','font-size','14',0,''),(172358,55139,'117096','furniture-mobile','block_type','5',0,''),(172359,55140,'117097','furniture-mobile','text','##TEXT_LANGUAGE##',0,''),(172360,55142,'117099','furniture-mobile','block_type','5',0,''),(172361,55143,'117100','furniture-mobile','text','##TEXT_CURRENCY##',0,''),(172362,55145,'117102','furniture-mobile','block_type','1',0,''),(172363,55145,'117102','furniture-mobile','font-weight','normal',0,''),(172364,55146,'117103','furniture-mobile','block_type','2',0,''),(172365,55146,'117103','furniture-mobile','font-weight','normal',0,''),(172366,55146,'117103','furniture-mobile','padding-bottom','20',0,''),(172367,55147,'117104','furniture-mobile','block_type','1',0,''),(172368,55147,'117104','furniture-mobile','margin-right','20',0,''),(172369,55150,'117107','furniture-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(172370,55150,'117107','furniture-mobile','font-weight','normal',0,''),(172371,55150,'117107','furniture-mobile','padding-bottom','20',0,''),(172372,55152,'117109','furniture-mobile','block_type','1',0,''),(172373,55152,'117109','furniture-mobile','font-weight','normal',0,''),(172374,55152,'117109','furniture-mobile','style_class','gift-card-view',0,''),(172375,55152,'117109','furniture-mobile','text-align','center',0,''),(172376,55152,'117109','furniture-mobile','padding-bottom','20',0,''),(172377,55152,'117109','furniture-mobile','background-color','$background-2',0,''),(172378,55152,'117109','furniture-mobile','padding-left','20',0,''),(172379,55152,'117109','furniture-mobile','padding-right','20',0,''),(172380,55152,'117109','furniture-mobile','color','$color-font-3',0,''),(172381,55153,'117110','furniture-mobile','block_type','1',0,''),(172382,55153,'117110','furniture-mobile','font-weight','normal',0,''),(172383,55153,'117110','furniture-mobile','padding-top','10',0,''),(172384,55154,'117111','furniture-mobile','font-size','12',0,''),(172385,55154,'117111','furniture-mobile','font-weight','bold',0,''),(172386,55154,'117111','furniture-mobile','text-align','center',0,''),(172387,55154,'117111','furniture-mobile','style_class','email',0,''),(172388,55155,'117112','furniture-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(172389,55155,'117112','furniture-mobile','font-weight','normal',0,''),(172390,55155,'117112','furniture-mobile','text-align','center',0,''),(172391,55155,'117112','furniture-mobile','font-size','12',0,''),(172392,55155,'117112','furniture-mobile','padding-top','10',0,''),(172393,55155,'117112','furniture-mobile','padding-bottom','5',0,''),(172394,55155,'117112','furniture-mobile','border-top-width','1',0,''),(172395,55155,'117112','furniture-mobile','border-top-color','$border-color-8',0,''),(172396,55156,'117113','furniture-mobile','font-size','12',0,''),(172397,55156,'117113','furniture-mobile','font-weight','bold',0,''),(172398,55156,'117113','furniture-mobile','text-align','center',0,''),(172399,55156,'117113','furniture-mobile','style_class','phone',0,''),(172400,55156,'117113','furniture-mobile','padding-bottom','5',0,''),(172401,55157,'117114','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(172402,55157,'117114','furniture-mobile','font-weight','normal',0,''),(172403,55157,'117114','furniture-mobile','text-align','center',0,''),(172404,55157,'117114','furniture-mobile','padding-top','20',0,''),(172405,55157,'117114','furniture-mobile','padding-bottom','10',0,''),(172406,55157,'117114','furniture-mobile','style_class','question-ico',0,''),(172407,55157,'117114','furniture-mobile','border-top-width','1',0,''),(172408,55157,'117114','furniture-mobile','border-top-color','$border-color-8',0,''),(172409,55157,'117114','furniture-mobile','font-size','18',0,''),(172410,55158,'117115','furniture-mobile','text','<p>osCommerce</p>\n',1,''),(172411,55158,'117115','furniture-mobile','font-family','$font-1',0,''),(172412,55158,'117115','furniture-mobile','font-size','24',0,''),(172413,55158,'117115','furniture-mobile','font-weight','normal',0,''),(172414,55158,'117115','furniture-mobile','text-align','center',0,''),(172415,55158,'117115','furniture-mobile','padding-top','10',0,''),(172416,55158,'117115','furniture-mobile','padding-bottom','20',0,''),(172417,55159,'117116','furniture-mobile','block_type','4',0,''),(172418,55159,'117116','furniture-mobile','color','$color-font-7',0,''),(172419,55159,'117116','furniture-mobile','font-size','30',0,''),(172420,55159,'117116','furniture-mobile','font-weight','normal',0,''),(172421,55159,'117116','furniture-mobile','background-color','$background-9',0,''),(172422,55159,'117116','furniture-mobile','padding-top','5',0,''),(172423,55159,'117116','furniture-mobile','padding-left','10',0,''),(172424,55159,'117116','furniture-mobile','padding-right','10',0,''),(172425,55159,'117116','furniture-mobile','padding-bottom','5',0,''),(172426,55160,'117117','furniture-mobile','text','<p>Your code is:</p>',1,''),(172427,55160,'117117','furniture-mobile','font-weight','normal',0,''),(172428,55162,'117119','furniture-mobile','font-weight','normal',0,''),(172429,55162,'117119','furniture-mobile','text-align','center',0,''),(172430,55162,'117119','furniture-mobile','padding-bottom','20',0,''),(172431,55163,'117120','furniture-mobile','font-size','60',0,''),(172432,55163,'117120','furniture-mobile','font-weight','bold',0,''),(172433,55163,'117120','furniture-mobile','text-align','center',0,''),(172434,55163,'117120','furniture-mobile','line-height','100',0,''),(172435,55163,'117120','furniture-mobile','padding-bottom','20',0,''),(172436,55163,'117120','furniture-mobile','line_height_measure','px',0,''),(172437,55164,'117121','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(172438,55164,'117121','furniture-mobile','font-size','18',0,''),(172439,55164,'117121','furniture-mobile','font-weight','normal',0,''),(172440,55164,'117121','furniture-mobile','text-align','center',0,''),(172441,55164,'117121','furniture-mobile','padding-top','20',0,''),(172442,55164,'117121','furniture-mobile','padding-bottom','10',0,''),(172443,55164,'117121','furniture-mobile','border-top-width','1',0,''),(172444,55164,'117121','furniture-mobile','border-top-color','$border-color-8',0,''),(172445,55165,'117123','furniture-mobile','logo','themes/furniture-mobile/img/Logo-1.jpg',1,''),(172446,55165,'117123','furniture-mobile','logo_from','theme',0,''),(172447,55165,'117123','furniture-mobile','padding-top','20',0,''),(172448,55165,'117123','furniture-mobile','text-align','center',0,''),(172449,55166,'117124','furniture-mobile','text','<p>GIFT CARD</p>',1,''),(172450,55166,'117124','furniture-mobile','font-size','30',0,''),(172451,55166,'117124','furniture-mobile','font-weight','normal',0,''),(172452,55166,'117124','furniture-mobile','border-top-width','1',0,''),(172453,55166,'117124','furniture-mobile','border-top-color','$border-color-8',0,''),(172454,55166,'117124','furniture-mobile','style_class','gift-ico',0,''),(172455,55166,'117124','furniture-mobile','text-align','center',0,''),(172456,55166,'117124','furniture-mobile','padding-top','15',0,''),(172457,55167,'117125','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(172458,55167,'117125','furniture-mobile','font-weight','normal',0,''),(172459,55167,'117125','furniture-mobile','text-align','center',0,''),(172460,55167,'117125','furniture-mobile','padding-bottom','10',0,''),(172461,55167,'117125','furniture-mobile','font-size','14',0,''),(172462,55168,'117126','furniture-mobile','block_type','1',0,''),(172463,55168,'117126','furniture-mobile','font-weight','normal',0,''),(172464,55168,'117126','furniture-mobile','style_class','gift-card-view',0,''),(172465,55168,'117126','furniture-mobile','text-align','center',0,''),(172466,55168,'117126','furniture-mobile','padding-bottom','20',0,''),(172467,55168,'117126','furniture-mobile','background-color','$background-10',0,''),(172468,55168,'117126','furniture-mobile','padding-left','20',0,''),(172469,55168,'117126','furniture-mobile','padding-right','20',0,''),(172470,55168,'117126','furniture-mobile','color','$color-font-3',0,''),(172471,55169,'117127','furniture-mobile','font-size','60',0,''),(172472,55169,'117127','furniture-mobile','font-weight','bold',0,''),(172473,55169,'117127','furniture-mobile','text-align','center',0,''),(172474,55169,'117127','furniture-mobile','line-height','100',0,''),(172475,55169,'117127','furniture-mobile','padding-bottom','20',0,''),(172476,55169,'117127','furniture-mobile','line_height_measure','px',0,''),(172477,55170,'117128','furniture-mobile','block_type','4',0,''),(172478,55170,'117128','furniture-mobile','color','$color-font-1',0,''),(172479,55170,'117128','furniture-mobile','font-size','30',0,''),(172480,55170,'117128','furniture-mobile','font-weight','normal',0,''),(172481,55170,'117128','furniture-mobile','background-color','$background-5',0,''),(172482,55170,'117128','furniture-mobile','padding-top','5',0,''),(172483,55170,'117128','furniture-mobile','padding-left','10',0,''),(172484,55170,'117128','furniture-mobile','padding-right','10',0,''),(172485,55170,'117128','furniture-mobile','padding-bottom','5',0,''),(172486,55171,'117129','furniture-mobile','text','<p>Your code is:</p>',1,''),(172487,55171,'117129','furniture-mobile','font-weight','normal',0,''),(172488,55173,'117131','furniture-mobile','block_type','1',0,''),(172489,55173,'117131','furniture-mobile','font-weight','normal',0,''),(172490,55173,'117131','furniture-mobile','padding-top','10',0,''),(172491,55174,'117132','furniture-mobile','font-size','12',0,''),(172492,55174,'117132','furniture-mobile','font-weight','bold',0,''),(172493,55174,'117132','furniture-mobile','text-align','center',0,''),(172494,55174,'117132','furniture-mobile','style_class','email',0,''),(172495,55175,'117133','furniture-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(172496,55175,'117133','furniture-mobile','font-weight','normal',0,''),(172497,55175,'117133','furniture-mobile','text-align','center',0,''),(172498,55175,'117133','furniture-mobile','font-size','12',0,''),(172499,55175,'117133','furniture-mobile','padding-top','10',0,''),(172500,55175,'117133','furniture-mobile','padding-bottom','5',0,''),(172501,55175,'117133','furniture-mobile','border-top-width','1',0,''),(172502,55175,'117133','furniture-mobile','border-top-color','$border-color-8',0,''),(172503,55176,'117134','furniture-mobile','font-size','12',0,''),(172504,55176,'117134','furniture-mobile','font-weight','bold',0,''),(172505,55176,'117134','furniture-mobile','text-align','center',0,''),(172506,55176,'117134','furniture-mobile','style_class','phone',0,''),(172507,55176,'117134','furniture-mobile','padding-bottom','5',0,''),(172508,55177,'117135','furniture-mobile','font-weight','normal',0,''),(172509,55177,'117135','furniture-mobile','text-align','center',0,''),(172510,55177,'117135','furniture-mobile','padding-bottom','20',0,''),(172511,55178,'117136','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(172512,55178,'117136','furniture-mobile','font-size','18',0,''),(172513,55178,'117136','furniture-mobile','font-weight','normal',0,''),(172514,55178,'117136','furniture-mobile','text-align','center',0,''),(172515,55178,'117136','furniture-mobile','padding-top','20',0,''),(172516,55178,'117136','furniture-mobile','padding-bottom','10',0,''),(172517,55178,'117136','furniture-mobile','border-top-width','1',0,''),(172518,55178,'117136','furniture-mobile','border-top-color','$border-color-8',0,''),(172519,55179,'117137','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(172520,55179,'117137','furniture-mobile','font-weight','normal',0,''),(172521,55179,'117137','furniture-mobile','text-align','center',0,''),(172522,55179,'117137','furniture-mobile','padding-bottom','10',0,''),(172523,55179,'117137','furniture-mobile','font-size','14',0,''),(172524,55180,'117138','furniture-mobile','text','<p>GIFT CARD</p>',1,''),(172525,55180,'117138','furniture-mobile','font-size','30',0,''),(172526,55180,'117138','furniture-mobile','font-weight','normal',0,''),(172527,55180,'117138','furniture-mobile','border-top-width','1',0,''),(172528,55180,'117138','furniture-mobile','border-top-color','$border-color-8',0,''),(172529,55180,'117138','furniture-mobile','style_class','gift-ico',0,''),(172530,55180,'117138','furniture-mobile','text-align','center',0,''),(172531,55180,'117138','furniture-mobile','padding-top','15',0,''),(172532,55181,'117139','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(172533,55181,'117139','furniture-mobile','font-weight','normal',0,''),(172534,55181,'117139','furniture-mobile','text-align','center',0,''),(172535,55181,'117139','furniture-mobile','padding-top','20',0,''),(172536,55181,'117139','furniture-mobile','padding-bottom','10',0,''),(172537,55181,'117139','furniture-mobile','style_class','question-ico',0,''),(172538,55181,'117139','furniture-mobile','border-top-width','1',0,''),(172539,55181,'117139','furniture-mobile','border-top-color','$border-color-8',0,''),(172540,55181,'117139','furniture-mobile','font-size','18',0,''),(172541,55182,'1638804282.8587','furniture-mobile','logo_from','theme',0,''),(172542,55182,'1638804282.8587','furniture-mobile','padding-top','20',0,''),(172543,55182,'1638804282.8587','furniture-mobile','text-align','center',0,''),(172544,55182,'1638804282.8587','furniture-mobile','padding-bottom','20',0,''),(172545,55183,'117141','furniture-mobile','block_type','1',0,''),(172546,55183,'117141','furniture-mobile','font-weight','normal',0,''),(172547,55183,'117141','furniture-mobile','style_class','gift-card-view',0,''),(172548,55183,'117141','furniture-mobile','text-align','center',0,''),(172549,55183,'117141','furniture-mobile','padding-bottom','20',0,''),(172550,55183,'117141','furniture-mobile','background-color','$background-10',0,''),(172551,55183,'117141','furniture-mobile','padding-left','20',0,''),(172552,55183,'117141','furniture-mobile','padding-right','20',0,''),(172553,55183,'117141','furniture-mobile','color','$color-font-3',0,''),(172554,55184,'117142','furniture-mobile','block_type','1',0,''),(172555,55184,'117142','furniture-mobile','font-weight','normal',0,''),(172556,55184,'117142','furniture-mobile','padding-top','10',0,''),(172557,55185,'117143','furniture-mobile','font-size','12',0,''),(172558,55185,'117143','furniture-mobile','font-weight','bold',0,''),(172559,55185,'117143','furniture-mobile','text-align','center',0,''),(172560,55185,'117143','furniture-mobile','style_class','email',0,''),(172561,55185,'117143','furniture-mobile','color','$color-font-1',0,''),(172562,55186,'117144','furniture-mobile','font-size','12',0,''),(172563,55186,'117144','furniture-mobile','font-weight','bold',0,''),(172564,55186,'117144','furniture-mobile','text-align','center',0,''),(172565,55186,'117144','furniture-mobile','style_class','phone',0,''),(172566,55186,'117144','furniture-mobile','padding-bottom','5',0,''),(172567,55186,'117144','furniture-mobile','color','$color-font-1',0,''),(172568,55187,'117145','furniture-mobile','text','If you require further assistance please contact us',0,''),(172569,55187,'117145','furniture-mobile','font-size','12',0,''),(172570,55187,'117145','furniture-mobile','color','$color-font-1',0,''),(172571,55187,'117145','furniture-mobile','text-align','center',0,''),(172572,55187,'117145','furniture-mobile','padding-top','10',0,''),(172573,55188,'117146','furniture-mobile','block_type','4',0,''),(172574,55188,'117146','furniture-mobile','color','$color-font-1',0,''),(172575,55188,'117146','furniture-mobile','font-size','30',0,''),(172576,55188,'117146','furniture-mobile','font-weight','normal',0,''),(172577,55188,'117146','furniture-mobile','background-color','$background-5',0,''),(172578,55188,'117146','furniture-mobile','padding-top','5',0,''),(172579,55188,'117146','furniture-mobile','padding-left','10',0,''),(172580,55188,'117146','furniture-mobile','padding-right','10',0,''),(172581,55188,'117146','furniture-mobile','padding-bottom','5',0,''),(172582,55189,'117147','furniture-mobile','text','Your code is:',0,''),(172583,55189,'117147','furniture-mobile','font-size','30',0,''),(172584,55189,'117147','furniture-mobile','color','$color-font-1',0,''),(172585,55190,'117148','furniture-mobile','color','$color-font-1',0,''),(172586,55190,'117148','furniture-mobile','font-size','30',0,''),(172587,55191,'117149','furniture-mobile','block_type','1',0,''),(172588,55192,'117150','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(172589,55192,'117150','furniture-mobile','font-size','18',0,''),(172590,55192,'117150','furniture-mobile','font-weight','normal',0,''),(172591,55192,'117150','furniture-mobile','text-align','center',0,''),(172592,55192,'117150','furniture-mobile','padding-top','20',0,''),(172593,55192,'117150','furniture-mobile','padding-bottom','10',0,''),(172594,55192,'117150','furniture-mobile','border-top-width','1',0,''),(172595,55192,'117150','furniture-mobile','border-top-color','$border-color-8',0,''),(172602,55194,'117152','furniture-mobile','border-top-color','$border-color-8',0,''),(172603,55194,'117152','furniture-mobile','border-top-width','1',0,''),(172604,55194,'117152','furniture-mobile','padding-top','20',0,''),(172605,55194,'117152','furniture-mobile','font-size','30',0,''),(172606,55194,'117152','furniture-mobile','text-align','center',0,''),(172607,55194,'117152','furniture-mobile','color','$color-font-1',0,''),(172608,55194,'117152','furniture-mobile','text','GIFT CARD',0,''),(172609,55195,'117153','furniture-mobile','text-align','center',0,''),(172610,55195,'117153','furniture-mobile','font-weight','bold',0,''),(172611,55195,'117153','furniture-mobile','font-size','60',0,''),(172612,55195,'117153','furniture-mobile','color','$color-font-1',0,''),(172613,55196,'117154','furniture-mobile','font-size','20',0,''),(172614,55196,'117154','furniture-mobile','text-align','center',0,''),(172615,55196,'117154','furniture-mobile','color','$color-font-1',0,''),(172616,55196,'117154','furniture-mobile','padding-top','20',0,''),(172617,55196,'117154','furniture-mobile','padding-bottom','20',0,''),(172618,55197,'117155','furniture-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(172619,55197,'117155','furniture-mobile','text-align','center',0,''),(172620,55197,'117155','furniture-mobile','color','$color-font-1',0,''),(172621,55197,'117155','furniture-mobile','font-size','14',0,''),(172622,55197,'117155','furniture-mobile','padding-bottom','20',0,''),(172623,55198,'117156','furniture-mobile','text','WHAT TO DO NEXT:',0,''),(172624,55198,'117156','furniture-mobile','font-size','18',0,''),(172625,55198,'117156','furniture-mobile','text-align','center',0,''),(172626,55198,'117156','furniture-mobile','color','$color-font-1',0,''),(172627,55198,'117156','furniture-mobile','padding-top','20',0,''),(172628,55198,'117156','furniture-mobile','padding-bottom','10',0,''),(172629,55198,'117156','furniture-mobile','border-top-width','1',0,''),(172630,55198,'117156','furniture-mobile','border-top-color','$border-color-8',0,''),(172631,55200,'117158','furniture-mobile','block_type','1',0,''),(172632,55200,'117158','furniture-mobile','font-weight','normal',0,''),(172633,55200,'117158','furniture-mobile','style_class','gift-card-view',0,''),(172634,55200,'117158','furniture-mobile','text-align','center',0,''),(172635,55200,'117158','furniture-mobile','padding-bottom','20',0,''),(172636,55200,'117158','furniture-mobile','background-color','$background-2',0,''),(172637,55200,'117158','furniture-mobile','padding-left','20',0,''),(172638,55200,'117158','furniture-mobile','padding-right','20',0,''),(172639,55200,'117158','furniture-mobile','color','$color-font-3',0,''),(172640,55201,'117159','furniture-mobile','block_type','1',0,''),(172641,55201,'117159','furniture-mobile','font-weight','normal',0,''),(172642,55201,'117159','furniture-mobile','padding-top','10',0,''),(172643,55202,'117160','furniture-mobile','font-size','12',0,''),(172644,55202,'117160','furniture-mobile','font-weight','bold',0,''),(172645,55202,'117160','furniture-mobile','text-align','center',0,''),(172646,55202,'117160','furniture-mobile','style_class','email',0,''),(172647,55202,'117160','furniture-mobile','color','$color-font-1',0,''),(172648,55203,'117161','furniture-mobile','font-size','12',0,''),(172649,55203,'117161','furniture-mobile','font-weight','bold',0,''),(172650,55203,'117161','furniture-mobile','text-align','center',0,''),(172651,55203,'117161','furniture-mobile','style_class','phone',0,''),(172652,55203,'117161','furniture-mobile','padding-bottom','5',0,''),(172653,55203,'117161','furniture-mobile','color','$color-font-1',0,''),(172654,55204,'117162','furniture-mobile','text','If you require further assistance please contact us',0,''),(172655,55204,'117162','furniture-mobile','font-size','12',0,''),(172656,55204,'117162','furniture-mobile','color','$color-font-1',0,''),(172657,55204,'117162','furniture-mobile','text-align','center',0,''),(172658,55204,'117162','furniture-mobile','padding-top','10',0,''),(172659,55205,'117163','furniture-mobile','block_type','2',0,''),(172660,55205,'117163','furniture-mobile','color','$color-font-1',0,''),(172661,55205,'117163','furniture-mobile','font-size','30',0,''),(172662,55205,'117163','furniture-mobile','font-weight','normal',0,''),(172663,55205,'117163','furniture-mobile','background-color','$background-5',0,''),(172664,55205,'117163','furniture-mobile','padding-top','5',0,''),(172665,55205,'117163','furniture-mobile','padding-left','10',0,''),(172666,55205,'117163','furniture-mobile','padding-right','10',0,''),(172667,55205,'117163','furniture-mobile','padding-bottom','5',0,''),(172668,55206,'117164','furniture-mobile','text','Your code is:',0,''),(172669,55206,'117164','furniture-mobile','font-size','30',0,''),(172670,55206,'117164','furniture-mobile','color','$color-font-1',0,''),(172671,55207,'117165','furniture-mobile','color','$color-font-1',0,''),(172672,55207,'117165','furniture-mobile','font-size','30',0,''),(172673,55208,'117166','furniture-mobile','block_type','1',0,''),(172674,55209,'117167','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(172675,55209,'117167','furniture-mobile','font-size','18',0,''),(172676,55209,'117167','furniture-mobile','font-weight','normal',0,''),(172677,55209,'117167','furniture-mobile','text-align','center',0,''),(172678,55209,'117167','furniture-mobile','padding-top','20',0,''),(172679,55209,'117167','furniture-mobile','padding-bottom','10',0,''),(172680,55209,'117167','furniture-mobile','border-top-width','1',0,''),(172681,55209,'117167','furniture-mobile','border-top-color','$border-color-8',0,''),(172682,55210,'117169','furniture-mobile','border-top-color','$border-color-8',0,''),(172683,55210,'117169','furniture-mobile','border-top-width','1',0,''),(172684,55210,'117169','furniture-mobile','padding-top','20',0,''),(172685,55210,'117169','furniture-mobile','font-size','30',0,''),(172686,55210,'117169','furniture-mobile','text-align','center',0,''),(172687,55210,'117169','furniture-mobile','color','$color-font-1',0,''),(172688,55210,'117169','furniture-mobile','text','GIFT CARD',0,''),(172689,55211,'117170','furniture-mobile','text-align','center',0,''),(172690,55211,'117170','furniture-mobile','font-weight','bold',0,''),(172691,55211,'117170','furniture-mobile','font-size','60',0,''),(172692,55211,'117170','furniture-mobile','color','$color-font-1',0,''),(172693,55212,'117171','furniture-mobile','font-size','20',0,''),(172694,55212,'117171','furniture-mobile','text-align','center',0,''),(172695,55212,'117171','furniture-mobile','color','$color-font-1',0,''),(172696,55212,'117171','furniture-mobile','padding-top','20',0,''),(172697,55212,'117171','furniture-mobile','padding-bottom','20',0,''),(172698,55213,'117172','furniture-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(172699,55213,'117172','furniture-mobile','text-align','center',0,''),(172700,55213,'117172','furniture-mobile','color','$color-font-1',0,''),(172701,55213,'117172','furniture-mobile','font-size','14',0,''),(172702,55213,'117172','furniture-mobile','padding-bottom','20',0,''),(172703,55214,'117173','furniture-mobile','text','WHAT TO DO NEXT:',0,''),(172704,55214,'117173','furniture-mobile','font-size','18',0,''),(172705,55214,'117173','furniture-mobile','text-align','center',0,''),(172706,55214,'117173','furniture-mobile','color','$color-font-1',0,''),(172707,55214,'117173','furniture-mobile','padding-top','20',0,''),(172708,55214,'117173','furniture-mobile','padding-bottom','10',0,''),(172709,55214,'117173','furniture-mobile','border-top-width','1',0,''),(172710,55214,'117173','furniture-mobile','border-top-color','$border-color-8',0,''),(172711,55215,'1638978695.8384','furniture-mobile','logo_from','theme',0,''),(172712,55215,'1638978695.8384','furniture-mobile','text-align','center',0,''),(172713,55215,'1638978695.8384','furniture-mobile','padding-top','20',0,''),(172714,55215,'1638978695.8384','furniture-mobile','padding-bottom','20',0,''),(172715,55216,'117175','furniture-mobile','block_type','1',0,''),(172716,55216,'117175','furniture-mobile','padding-left','20',0,''),(172717,55216,'117175','furniture-mobile','padding-right','20',0,''),(172718,55216,'117175','furniture-mobile','padding-bottom','20',0,''),(172719,55218,'117177','furniture-mobile','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(172720,55218,'117177','furniture-mobile','text-align','center',0,''),(172721,55219,'117178','furniture-mobile','block_type','1',0,''),(172722,55219,'117178','furniture-mobile','font-weight','normal',0,''),(172723,55219,'117178','furniture-mobile','style_class','gift-card-view',0,''),(172724,55219,'117178','furniture-mobile','text-align','center',0,''),(172725,55219,'117178','furniture-mobile','padding-bottom','20',0,''),(172726,55219,'117178','furniture-mobile','background-color','$background-4',0,''),(172727,55219,'117178','furniture-mobile','padding-left','20',0,''),(172728,55219,'117178','furniture-mobile','padding-right','20',0,''),(172729,55219,'117178','furniture-mobile','color','$color-font-3',0,''),(172730,55220,'117179','furniture-mobile','block_type','4',0,''),(172731,55220,'117179','furniture-mobile','color','$color-font-1',0,''),(172732,55220,'117179','furniture-mobile','font-size','30',0,''),(172733,55220,'117179','furniture-mobile','font-weight','normal',0,''),(172734,55220,'117179','furniture-mobile','background-color','$background-5',0,''),(172735,55220,'117179','furniture-mobile','padding-top','5',0,''),(172736,55220,'117179','furniture-mobile','padding-left','10',0,''),(172737,55220,'117179','furniture-mobile','padding-right','10',0,''),(172738,55220,'117179','furniture-mobile','padding-bottom','5',0,''),(172739,55221,'117180','furniture-mobile','text','<p>Your code is:</p>',1,''),(172740,55221,'117180','furniture-mobile','font-weight','normal',0,''),(172741,55223,'117182','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(172742,55223,'117182','furniture-mobile','font-weight','normal',0,''),(172743,55223,'117182','furniture-mobile','text-align','center',0,''),(172744,55223,'117182','furniture-mobile','padding-top','20',0,''),(172745,55223,'117182','furniture-mobile','padding-bottom','10',0,''),(172746,55223,'117182','furniture-mobile','style_class','question-ico',0,''),(172747,55223,'117182','furniture-mobile','border-top-width','1',0,''),(172748,55223,'117182','furniture-mobile','border-top-color','$border-color-8',0,''),(172749,55223,'117182','furniture-mobile','font-size','18',0,''),(172750,55224,'117184','furniture-mobile','block_type','1',0,''),(172751,55224,'117184','furniture-mobile','font-weight','normal',0,''),(172752,55224,'117184','furniture-mobile','padding-top','10',0,''),(172753,55225,'117185','furniture-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(172754,55225,'117185','furniture-mobile','font-weight','normal',0,''),(172755,55225,'117185','furniture-mobile','text-align','center',0,''),(172756,55225,'117185','furniture-mobile','font-size','12',0,''),(172757,55225,'117185','furniture-mobile','padding-top','10',0,''),(172758,55225,'117185','furniture-mobile','padding-bottom','5',0,''),(172759,55225,'117185','furniture-mobile','border-top-width','1',0,''),(172760,55225,'117185','furniture-mobile','border-top-color','$border-color-8',0,''),(172761,55226,'117186','furniture-mobile','font-size','12',0,''),(172762,55226,'117186','furniture-mobile','font-weight','bold',0,''),(172763,55226,'117186','furniture-mobile','text-align','center',0,''),(172764,55226,'117186','furniture-mobile','style_class','email',0,''),(172765,55227,'117187','furniture-mobile','font-size','12',0,''),(172766,55227,'117187','furniture-mobile','font-weight','bold',0,''),(172767,55227,'117187','furniture-mobile','text-align','center',0,''),(172768,55227,'117187','furniture-mobile','style_class','phone',0,''),(172769,55227,'117187','furniture-mobile','padding-bottom','5',0,''),(172770,55228,'117188','furniture-mobile','font-weight','normal',0,''),(172771,55228,'117188','furniture-mobile','text-align','center',0,''),(172772,55228,'117188','furniture-mobile','padding-bottom','20',0,''),(172773,55229,'117189','furniture-mobile','text','<p>GIFT CARD</p>',1,''),(172774,55229,'117189','furniture-mobile','font-size','30',0,''),(172775,55229,'117189','furniture-mobile','font-weight','normal',0,''),(172776,55229,'117189','furniture-mobile','border-top-width','1',0,''),(172777,55229,'117189','furniture-mobile','border-top-color','$border-color-8',0,''),(172778,55229,'117189','furniture-mobile','style_class','gift-ico',0,''),(172779,55229,'117189','furniture-mobile','text-align','center',0,''),(172780,55229,'117189','furniture-mobile','padding-top','15',0,''),(172781,55230,'117190','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(172782,55230,'117190','furniture-mobile','font-size','18',0,''),(172783,55230,'117190','furniture-mobile','font-weight','normal',0,''),(172784,55230,'117190','furniture-mobile','text-align','center',0,''),(172785,55230,'117190','furniture-mobile','padding-top','20',0,''),(172786,55230,'117190','furniture-mobile','padding-bottom','10',0,''),(172787,55230,'117190','furniture-mobile','border-top-width','1',0,''),(172788,55230,'117190','furniture-mobile','border-top-color','$border-color-8',0,''),(172789,55231,'117191','furniture-mobile','font-size','60',0,''),(172790,55231,'117191','furniture-mobile','font-weight','bold',0,''),(172791,55231,'117191','furniture-mobile','text-align','center',0,''),(172792,55231,'117191','furniture-mobile','line-height','100',0,''),(172793,55231,'117191','furniture-mobile','padding-bottom','20',0,''),(172794,55231,'117191','furniture-mobile','line_height_measure','px',0,''),(172795,55232,'117192','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(172796,55232,'117192','furniture-mobile','font-weight','normal',0,''),(172797,55232,'117192','furniture-mobile','text-align','center',0,''),(172798,55232,'117192','furniture-mobile','padding-bottom','10',0,''),(172799,55232,'117192','furniture-mobile','font-size','14',0,''),(172800,55233,'1638804328.7281','furniture-mobile','logo_from','theme',0,''),(172801,55233,'1638804328.7281','furniture-mobile','padding-top','20',0,''),(172802,55233,'1638804328.7281','furniture-mobile','text-align','center',0,''),(172803,55233,'1638804328.7281','furniture-mobile','padding-bottom','20',0,''),(172804,55234,'117193','furniture-mobile','block_type','1',0,''),(172805,55234,'117193','furniture-mobile','font-weight','normal',0,''),(172806,55234,'117193','furniture-mobile','style_class','gift-card-view',0,''),(172807,55234,'117193','furniture-mobile','text-align','center',0,''),(172808,55234,'117193','furniture-mobile','padding-bottom','20',0,''),(172809,55234,'117193','furniture-mobile','background-color','$background-4',0,''),(172810,55234,'117193','furniture-mobile','padding-left','20',0,''),(172811,55234,'117193','furniture-mobile','padding-right','20',0,''),(172812,55234,'117193','furniture-mobile','color','$color-font-3',0,''),(172813,55235,'117194','furniture-mobile','block_type','1',0,''),(172814,55235,'117194','furniture-mobile','font-weight','normal',0,''),(172815,55235,'117194','furniture-mobile','padding-top','10',0,''),(172816,55236,'117195','furniture-mobile','font-size','12',0,''),(172817,55236,'117195','furniture-mobile','font-weight','bold',0,''),(172818,55236,'117195','furniture-mobile','text-align','center',0,''),(172819,55236,'117195','furniture-mobile','style_class','email',0,''),(172820,55236,'117195','furniture-mobile','color','$color-font-1',0,''),(172821,55237,'117196','furniture-mobile','font-size','12',0,''),(172822,55237,'117196','furniture-mobile','font-weight','bold',0,''),(172823,55237,'117196','furniture-mobile','text-align','center',0,''),(172824,55237,'117196','furniture-mobile','style_class','phone',0,''),(172825,55237,'117196','furniture-mobile','padding-bottom','5',0,''),(172826,55237,'117196','furniture-mobile','color','$color-font-1',0,''),(172827,55238,'117197','furniture-mobile','text','If you require further assistance please contact us',0,''),(172828,55238,'117197','furniture-mobile','font-size','12',0,''),(172829,55238,'117197','furniture-mobile','color','$color-font-1',0,''),(172830,55238,'117197','furniture-mobile','text-align','center',0,''),(172831,55238,'117197','furniture-mobile','padding-top','10',0,''),(172832,55239,'117198','furniture-mobile','block_type','4',0,''),(172833,55239,'117198','furniture-mobile','color','$color-font-1',0,''),(172834,55239,'117198','furniture-mobile','font-size','30',0,''),(172835,55239,'117198','furniture-mobile','font-weight','normal',0,''),(172836,55239,'117198','furniture-mobile','background-color','$background-5',0,''),(172837,55239,'117198','furniture-mobile','padding-top','5',0,''),(172838,55239,'117198','furniture-mobile','padding-left','10',0,''),(172839,55239,'117198','furniture-mobile','padding-right','10',0,''),(172840,55239,'117198','furniture-mobile','padding-bottom','5',0,''),(172841,55240,'117199','furniture-mobile','text','Your code is:',0,''),(172842,55240,'117199','furniture-mobile','font-size','30',0,''),(172843,55240,'117199','furniture-mobile','color','$color-font-1',0,''),(172844,55241,'117200','furniture-mobile','color','$color-font-1',0,''),(172845,55241,'117200','furniture-mobile','font-size','30',0,''),(172846,55242,'117201','furniture-mobile','block_type','1',0,''),(172847,55243,'117202','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(172848,55243,'117202','furniture-mobile','font-size','18',0,''),(172849,55243,'117202','furniture-mobile','font-weight','normal',0,''),(172850,55243,'117202','furniture-mobile','text-align','center',0,''),(172851,55243,'117202','furniture-mobile','padding-top','20',0,''),(172852,55243,'117202','furniture-mobile','padding-bottom','10',0,''),(172853,55243,'117202','furniture-mobile','border-top-width','1',0,''),(172854,55243,'117202','furniture-mobile','border-top-color','$border-color-8',0,''),(172855,55244,'117203','furniture-mobile','text','HOLBI',0,''),(172856,55244,'117203','furniture-mobile','color','$color-font-1',0,''),(172857,55244,'117203','furniture-mobile','font-size','24',0,''),(172858,55244,'117203','furniture-mobile','padding-top','20',0,''),(172859,55244,'117203','furniture-mobile','text-align','center',0,''),(172860,55244,'117203','furniture-mobile','padding-bottom','20',0,''),(172861,55245,'117204','furniture-mobile','border-top-color','$border-color-8',0,''),(172862,55245,'117204','furniture-mobile','border-top-width','1',0,''),(172863,55245,'117204','furniture-mobile','padding-top','20',0,''),(172864,55245,'117204','furniture-mobile','font-size','30',0,''),(172865,55245,'117204','furniture-mobile','text-align','center',0,''),(172866,55245,'117204','furniture-mobile','color','$color-font-1',0,''),(172867,55245,'117204','furniture-mobile','text','GIFT CARD',0,''),(172868,55246,'117205','furniture-mobile','text-align','center',0,''),(172869,55246,'117205','furniture-mobile','font-weight','bold',0,''),(172870,55246,'117205','furniture-mobile','font-size','60',0,''),(172871,55246,'117205','furniture-mobile','color','$color-font-1',0,''),(172872,55247,'117206','furniture-mobile','font-size','20',0,''),(172873,55247,'117206','furniture-mobile','text-align','center',0,''),(172874,55247,'117206','furniture-mobile','color','$color-font-1',0,''),(172875,55247,'117206','furniture-mobile','padding-top','20',0,''),(172876,55247,'117206','furniture-mobile','padding-bottom','20',0,''),(172877,55248,'117207','furniture-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(172878,55248,'117207','furniture-mobile','text-align','center',0,''),(172879,55248,'117207','furniture-mobile','color','$color-font-1',0,''),(172880,55248,'117207','furniture-mobile','font-size','14',0,''),(172881,55248,'117207','furniture-mobile','padding-bottom','20',0,''),(172882,55249,'117208','furniture-mobile','text','WHAT TO DO NEXT:',0,''),(172883,55249,'117208','furniture-mobile','font-size','18',0,''),(172884,55249,'117208','furniture-mobile','text-align','center',0,''),(172885,55249,'117208','furniture-mobile','color','$color-font-1',0,''),(172886,55249,'117208','furniture-mobile','padding-top','20',0,''),(172887,55249,'117208','furniture-mobile','padding-bottom','10',0,''),(172888,55249,'117208','furniture-mobile','border-top-width','1',0,''),(172889,55249,'117208','furniture-mobile','border-top-color','$border-color-8',0,''),(172890,55250,'117209','furniture-mobile','block_type','1',0,''),(172891,55250,'117209','furniture-mobile','font-weight','400',0,''),(172892,55250,'117209','furniture-mobile','background-color','$background-2',0,''),(172893,55250,'117209','furniture-mobile','visibility_checkout','1',0,''),(172894,55250,'117209','furniture-mobile','style_class','menu-header',0,''),(172895,55251,'117210','furniture-mobile','class','menu-style-1',0,''),(172896,55251,'117210','furniture-mobile','box_align','4',0,''),(172897,55251,'117210','furniture-mobile','font-weight','400',0,''),(172898,55251,'117210','furniture-mobile','hide_menu','on',0,''),(172899,55251,'117210','furniture-mobile','color','$color-font-1',0,''),(172900,55251,'117210','furniture-mobile','hide_menu','1',0,'2885'),(172901,55251,'117210','furniture-mobile','show_new','1',0,''),(172902,55251,'117210','furniture-mobile','type','builder',0,''),(172903,55251,'117210','furniture-mobile','style','1',0,'2945'),(172904,55251,'117210','furniture-mobile','burger_icon','1',0,'2885'),(172905,55251,'117210','furniture-mobile','style','2',0,'2885'),(172906,55251,'117210','furniture-mobile','open_from','left',0,'2885'),(172907,55251,'117210','furniture-mobile','lev2_vis','over',0,'2945'),(172908,55251,'117210','furniture-mobile','lev2_display','down',0,'2945'),(172909,55251,'117210','furniture-mobile','lev2_vis','click',0,'2885'),(172910,55251,'117210','furniture-mobile','lev3_vis','over',0,'2945'),(172911,55251,'117210','furniture-mobile','lev4_vis','over',0,'2945'),(172912,55251,'117210','furniture-mobile','lev5_vis','over',0,'2945'),(172913,55251,'117210','furniture-mobile','lev5_display','lra',0,'2945'),(172914,55251,'117210','furniture-mobile','lev4_display','lra',0,'2945'),(172915,55251,'117210','furniture-mobile','lev3_display','lra',0,'2945'),(172916,55251,'117210','furniture-mobile','position','horizontal_flex',0,'2945'),(172917,55251,'117210','furniture-mobile','z-index','92',0,''),(172918,55252,'117212','furniture-mobile','block_type','1',0,''),(172919,55252,'117212','furniture-mobile','padding-top','3',0,''),(172920,55252,'117212','furniture-mobile','padding-top','0',0,'2906'),(172921,55252,'117212','furniture-mobile','padding-bottom','0',0,'2906'),(172922,55252,'117212','furniture-mobile','background-color','$background-1',0,''),(172923,55252,'117212','furniture-mobile','color','$color-font-1',0,''),(172924,55252,'117212','furniture-mobile','style_class','header-middle',0,''),(172925,55253,'117213','furniture-mobile','font-weight','400',0,''),(172926,55253,'117213','furniture-mobile','box_align','1',0,''),(172928,55253,'117213','furniture-mobile','text-align','center',0,'2906'),(172929,55253,'117213','furniture-mobile','width_measure','%',0,'2906'),(172930,55253,'117213','furniture-mobile','logo_from','theme',0,''),(172931,55253,'117213','furniture-mobile','float','left',0,''),(172932,55253,'117213','furniture-mobile','clear','both',0,''),(172933,55253,'117213','furniture-mobile','margin-top','22',0,''),(172934,55253,'117213','furniture-mobile','margin-bottom','22',0,''),(172935,55253,'117213','furniture-mobile','width','100',0,'2885'),(172936,55253,'117213','furniture-mobile','padding-top','10',0,'2885'),(172937,55253,'117213','furniture-mobile','padding-bottom','10',0,'2885'),(172938,55253,'117213','furniture-mobile','margin-top','1',0,'2885'),(172939,55253,'117213','furniture-mobile','margin-bottom','9',0,'2885'),(172940,55253,'117213','furniture-mobile','position','relative',0,''),(172941,55253,'117213','furniture-mobile','z-index','5',0,''),(172942,55254,'117214','furniture-mobile','font-weight','400',0,''),(172943,55254,'117214','furniture-mobile','visibility_checkout','1',0,''),(172944,55254,'117214','furniture-mobile','float','right',0,''),(172945,55254,'117214','furniture-mobile','clear','none',0,''),(172946,55254,'117214','furniture-mobile','margin-top','42',0,''),(172947,55254,'117214','furniture-mobile','margin-top','7',0,'2885'),(172948,55254,'117214','furniture-mobile','color','$color-font-7',0,''),(172949,55255,'117215','furniture-mobile','box_align','1',0,''),(172950,55255,'117215','furniture-mobile','visibility_cart','1',0,''),(172951,55255,'117215','furniture-mobile','visibility_checkout','1',0,''),(172952,55256,'117216','furniture-mobile','font-weight','400',0,''),(172953,55256,'117216','furniture-mobile','box_align','3',0,''),(172954,55256,'117216','furniture-mobile','only_icon','on',0,''),(172955,55256,'117216','furniture-mobile','color','$color-font-4',0,''),(172956,55256,'117216','furniture-mobile','margin-top','34',0,''),(172957,55256,'117216','furniture-mobile','margin-top','7',0,'2885'),(172958,55256,'117216','furniture-mobile','items','1',0,''),(172959,55256,'117216','furniture-mobile','total','1',0,''),(172960,55256,'117216','furniture-mobile','show_products','dropdown',0,''),(172961,55257,'117217','furniture-mobile','font-weight','normal',0,''),(172962,55257,'117217','furniture-mobile','box_align','3',0,''),(172963,55257,'117217','furniture-mobile','only_icon','on',0,''),(172964,55257,'117217','furniture-mobile','margin-top','34',0,''),(172965,55257,'117217','furniture-mobile','margin-left','20',0,''),(172966,55257,'117217','furniture-mobile','margin-top','7',0,'2885'),(172967,55257,'117217','furniture-mobile','margin-left','10',0,'2885'),(172968,55257,'117217','furniture-mobile','link_or_dropdown','1',0,''),(172969,55258,'117218','furniture-mobile','float','left',0,''),(172970,55258,'117218','furniture-mobile','clear','none',0,''),(172971,55258,'117218','furniture-mobile','logo','themes/furniture-mobile/img/header-img-1.png',1,''),(172972,55258,'117218','furniture-mobile','display_none','1',0,'2890'),(172973,55259,'120877','furniture-mobile','text','<span class=\"searchIcon\"></span>',0,''),(172974,55259,'120877','furniture-mobile','box_align','3',0,''),(172975,55259,'120877','furniture-mobile','margin-top','34',0,''),(172976,55259,'120877','furniture-mobile','margin-top','15',0,'2906'),(172977,55260,'117219','furniture-mobile','block_type','1',0,''),(172978,55260,'117219','furniture-mobile','border-bottom-width','1',0,''),(172979,55260,'117219','furniture-mobile','border-bottom-color','$border-color-2',0,''),(172980,55260,'117219','furniture-mobile','font-weight','normal',0,''),(172981,55260,'117219','furniture-mobile','visibility_checkout','1',0,''),(172982,55260,'117219','furniture-mobile','background-color','$background-1',0,''),(172983,55260,'117219','furniture-mobile','color','$color-font-1',0,''),(172984,55260,'117219','furniture-mobile','display_none','1',0,'2885'),(172985,55261,'117220','furniture-mobile','block_type','1',0,''),(172986,55261,'117220','furniture-mobile','font-weight','400',0,''),(172987,55261,'117220','furniture-mobile','schema','2-2',0,''),(172988,55261,'117220','furniture-mobile','schema','5-1',0,'2885'),(172989,55262,'117221','furniture-mobile','class','menu-horizontal',0,''),(172990,55262,'117221','furniture-mobile','box_align','1',0,''),(172991,55262,'117221','furniture-mobile','font-weight','400',0,''),(172992,55262,'117221','furniture-mobile','float','left',0,''),(172993,55262,'117221','furniture-mobile','display_none','1',0,'2906'),(172994,55263,'117222','furniture-mobile','box_align','3',0,''),(172995,55263,'117222','furniture-mobile','font-weight','normal',0,''),(172996,55263,'117222','furniture-mobile','padding-top','2',0,''),(172997,55263,'117222','furniture-mobile','padding-bottom','1',0,''),(172998,55263,'117222','furniture-mobile','padding-top','0',0,'2885'),(172999,55263,'117222','furniture-mobile','padding-right','0',0,'2885'),(173000,55263,'117222','furniture-mobile','padding-bottom','0',0,'2885'),(173001,55263,'117222','furniture-mobile','padding-left','0',0,'2885'),(173002,55264,'117223','furniture-mobile','box_align','3',0,''),(173003,55264,'117223','furniture-mobile','font-weight','normal',0,''),(173004,55264,'117223','furniture-mobile','padding-top','2',0,''),(173005,55264,'117223','furniture-mobile','border-left-width','1',0,''),(173006,55264,'117223','furniture-mobile','border-left-color','$border-color-4',0,''),(173007,55264,'117223','furniture-mobile','padding-bottom','1',0,''),(173008,55264,'117223','furniture-mobile','padding-top','0',0,'2885'),(173009,55264,'117223','furniture-mobile','padding-right','0',0,'2885'),(173010,55264,'117223','furniture-mobile','padding-bottom','0',0,'2885'),(173011,55264,'117223','furniture-mobile','padding-left','0',0,'2885'),(173012,55268,'117224','furniture-mobile','block_type','1',0,''),(173013,55274,'117229','furniture-mobile','width','680',0,''),(173014,55274,'117229','furniture-mobile','font-weight','normal',0,''),(173015,55274,'117229','furniture-mobile','font-size','12',0,''),(173016,55274,'117229','furniture-mobile','padding-top','20',0,''),(173017,55274,'117229','furniture-mobile','padding-bottom','20',0,''),(173018,55274,'117229','furniture-mobile','color','$color-font-8',0,''),(173019,55275,'117230','furniture-mobile','block_type','4',0,''),(173020,55275,'117230','furniture-mobile','font-weight','normal',0,''),(173021,55275,'117230','furniture-mobile','border-top-width','1',0,''),(173022,55275,'117230','furniture-mobile','border-top-color','$border-color-4',0,''),(173023,55275,'117230','furniture-mobile','border-left-width','1',0,''),(173024,55275,'117230','furniture-mobile','border-left-color','$border-color-4',0,''),(173025,55275,'117230','furniture-mobile','border-right-width','1',0,''),(173026,55275,'117230','furniture-mobile','border-right-color','$border-color-4',0,''),(173027,55275,'117230','furniture-mobile','border-bottom-width','1',0,''),(173028,55275,'117230','furniture-mobile','border-bottom-color','$border-color-4',0,''),(173029,55276,'117231','furniture-mobile','block_type','2',0,''),(173030,55276,'117231','furniture-mobile','font-weight','normal',0,''),(173031,55276,'117231','furniture-mobile','border-top-width','1',0,''),(173032,55276,'117231','furniture-mobile','border-top-color','$border-color-4',0,''),(173033,55276,'117231','furniture-mobile','border-right-width','1',0,''),(173034,55276,'117231','furniture-mobile','border-right-color','$border-color-4',0,''),(173035,55277,'117232','furniture-mobile','block_type','1',0,''),(173036,55277,'117232','furniture-mobile','font-weight','normal',0,''),(173037,55277,'117232','furniture-mobile','padding-top','10',0,''),(173038,55277,'117232','furniture-mobile','padding-left','10',0,''),(173039,55277,'117232','furniture-mobile','padding-right','10',0,''),(173040,55277,'117232','furniture-mobile','padding-bottom','10',0,''),(173041,55277,'117232','furniture-mobile','border-right-width','1',0,''),(173042,55277,'117232','furniture-mobile','border-right-color','$border-color-4',0,''),(173043,55279,'117234','furniture-mobile','text','<p>Shipping via</p>',1,''),(173044,55279,'117234','furniture-mobile','font-weight','bold',0,''),(173045,55279,'117234','furniture-mobile','font-size','14',0,''),(173046,55280,'117235','furniture-mobile','block_type','1',0,''),(173047,55280,'117235','furniture-mobile','font-weight','normal',0,''),(173048,55280,'117235','furniture-mobile','padding-top','10',0,''),(173049,55280,'117235','furniture-mobile','padding-left','10',0,''),(173050,55280,'117235','furniture-mobile','padding-right','10',0,''),(173051,55280,'117235','furniture-mobile','padding-bottom','10',0,''),(173052,55281,'117236','furniture-mobile','text','<p>Shipping service</p>',1,''),(173053,55281,'117236','furniture-mobile','font-weight','bold',0,''),(173054,55281,'117236','furniture-mobile','font-size','14',0,''),(173055,55283,'117238','furniture-mobile','block_type','2',0,''),(173056,55283,'117238','furniture-mobile','font-weight','normal',0,''),(173057,55283,'117238','furniture-mobile','border-right-width','1',0,''),(173058,55283,'117238','furniture-mobile','border-right-color','$border-color-4',0,''),(173059,55284,'117239','furniture-mobile','block_type','1',0,''),(173060,55284,'117239','furniture-mobile','font-weight','400',0,''),(173061,55284,'117239','furniture-mobile','background-color','$background-6',0,''),(173062,55284,'117239','furniture-mobile','padding-top','10',0,''),(173063,55284,'117239','furniture-mobile','padding-left','10',0,''),(173064,55284,'117239','furniture-mobile','padding-right','10',0,''),(173065,55284,'117239','furniture-mobile','padding-bottom','30',0,''),(173066,55285,'117240','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(173067,55285,'117240','furniture-mobile','font-size','14',0,''),(173068,55285,'117240','furniture-mobile','font-weight','bold',0,''),(173069,55286,'117241','furniture-mobile','font-size','12',0,''),(173070,55288,'117242','furniture-mobile','block_type','1',0,''),(173071,55288,'117242','furniture-mobile','font-weight','normal',0,''),(173072,55288,'117242','furniture-mobile','padding-top','10',0,''),(173073,55288,'117242','furniture-mobile','padding-left','10',0,''),(173074,55288,'117242','furniture-mobile','padding-right','10',0,''),(173075,55288,'117242','furniture-mobile','padding-bottom','10',0,''),(173076,55289,'117243','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(173077,55289,'117243','furniture-mobile','font-weight','bold',0,''),(173078,55289,'117243','furniture-mobile','font-size','14',0,''),(173079,55289,'117243','furniture-mobile','padding-top','10',0,''),(173080,55290,'117244','furniture-mobile','font-weight','normal',0,''),(173081,55291,'117245','furniture-mobile','font-weight','normal',0,''),(173082,55292,'117246','furniture-mobile','text','<p>CUSTOMER:</p>',1,''),(173083,55292,'117246','furniture-mobile','font-size','13',0,''),(173084,55292,'117246','furniture-mobile','font-weight','bold',0,''),(173085,55293,'117247','furniture-mobile','text','<p>PHONE NUMBER:</p>',1,''),(173086,55293,'117247','furniture-mobile','font-size','14',0,''),(173087,55293,'117247','furniture-mobile','font-weight','bold',0,''),(173088,55293,'117247','furniture-mobile','padding-top','10',0,''),(173089,55295,'117249','furniture-mobile','font-weight','normal',0,''),(173090,55295,'117249','furniture-mobile','text-align','center',0,''),(173091,55295,'117249','furniture-mobile','padding-bottom','20',0,''),(173092,55296,'117250','furniture-mobile','text','<p>Payment Method:</p>',1,''),(173093,55296,'117250','furniture-mobile','font-weight','bold',0,''),(173094,55296,'117250','furniture-mobile','text-align','center',0,''),(173095,55297,'117251','furniture-mobile','text','<p>Payment date:</p>',1,''),(173096,55297,'117251','furniture-mobile','font-weight','bold',0,''),(173097,55297,'117251','furniture-mobile','text-align','center',0,''),(173098,55297,'117251','furniture-mobile','font-size','12',0,''),(173099,55298,'117252','furniture-mobile','font-size','14',0,''),(173100,55298,'117252','furniture-mobile','font-weight','bold',0,''),(173101,55298,'117252','furniture-mobile','text-align','center',0,''),(173102,55298,'117252','furniture-mobile','padding-bottom','10',0,''),(173103,55298,'117252','furniture-mobile','padding-top','10',0,''),(173104,55299,'117253','furniture-mobile','font-weight','normal',0,''),(173105,55299,'117253','furniture-mobile','text-align','center',0,''),(173106,55299,'117253','furniture-mobile','padding-bottom','10',0,''),(173107,55300,'117254','furniture-mobile','font-weight','normal',0,''),(173108,55300,'117254','furniture-mobile','text-align','center',0,''),(173109,55301,'117255','furniture-mobile','block_type','3',0,''),(173110,55301,'117255','furniture-mobile','font-weight','normal',0,''),(173111,55301,'117255','furniture-mobile','padding-top','20',0,''),(173112,55302,'117256','furniture-mobile','font-size','12',0,''),(173113,55303,'117257','furniture-mobile','text','<p>If undelivered please return to:</p>',1,''),(173114,55303,'117257','furniture-mobile','font-size','12',0,''),(173115,55303,'117257','furniture-mobile','font-weight','bold',0,''),(173116,55304,'117258','furniture-mobile','text','<p>Thank you for your order</p>',1,''),(173117,55304,'117258','furniture-mobile','color','$color-font-10',0,''),(173118,55304,'117258','furniture-mobile','font-size','13',0,''),(173119,55304,'117258','furniture-mobile','font-weight','bold',0,''),(173120,55304,'117258','furniture-mobile','padding-top','5',0,''),(173121,55304,'117258','furniture-mobile','text-align','center',0,''),(173122,55305,'117260','furniture-mobile','block_type','6',0,''),(173123,55305,'117260','furniture-mobile','font-weight','normal',0,''),(173124,55305,'117260','furniture-mobile','font-size','16',0,''),(173125,55306,'117261','furniture-mobile','text','<p>Email:</p>',1,''),(173126,55306,'117261','furniture-mobile','font-weight','normal',0,''),(173127,55306,'117261','furniture-mobile','text-align','right',0,''),(173128,55306,'117261','furniture-mobile','font-size','12',0,''),(173129,55307,'117262','furniture-mobile','font-weight','normal',0,''),(173130,55307,'117262','furniture-mobile','text-align','right',0,''),(173131,55307,'117262','furniture-mobile','font-size','12',0,''),(173132,55308,'117263','furniture-mobile','block_type','6',0,''),(173133,55308,'117263','furniture-mobile','font-weight','normal',0,''),(173134,55308,'117263','furniture-mobile','font-size','16',0,''),(173135,55309,'117264','furniture-mobile','text','<p>Phone:</p>',1,''),(173136,55309,'117264','furniture-mobile','font-weight','normal',0,''),(173137,55309,'117264','furniture-mobile','text-align','right',0,''),(173138,55309,'117264','furniture-mobile','font-size','12',0,''),(173139,55310,'117265','furniture-mobile','font-weight','normal',0,''),(173140,55310,'117265','furniture-mobile','text-align','right',0,''),(173141,55310,'117265','furniture-mobile','font-size','12',0,''),(173142,55311,'117266','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(173143,55311,'117266','furniture-mobile','font-size','12',0,''),(173144,55311,'117266','furniture-mobile','font-weight','bold',0,''),(173145,55311,'117266','furniture-mobile','text-align','right',0,''),(173146,55312,'117267','furniture-mobile','font-weight','400',0,''),(173147,55312,'117267','furniture-mobile','padding-top','20',0,''),(173148,55312,'117267','furniture-mobile','padding-bottom','0',0,''),(173149,55312,'117267','furniture-mobile','font-size','12',0,''),(173150,55313,'117268','furniture-mobile','block_type','5',0,''),(173151,55313,'117268','furniture-mobile','font-weight','normal',0,''),(173152,55313,'117268','furniture-mobile','border-bottom-width','1',0,''),(173153,55313,'117268','furniture-mobile','border-bottom-color','$border-color-4',0,''),(173154,55313,'117268','furniture-mobile','border-top-width','1',0,''),(173155,55313,'117268','furniture-mobile','border-top-color','$border-color-4',0,''),(173156,55313,'117268','furniture-mobile','border-left-color','$border-color-4',0,''),(173157,55313,'117268','furniture-mobile','border-left-width','1',0,''),(173158,55314,'117269','furniture-mobile','block_type','1',0,''),(173159,55314,'117269','furniture-mobile','font-weight','normal',0,''),(173160,55314,'117269','furniture-mobile','padding-top','10',0,''),(173161,55314,'117269','furniture-mobile','padding-left','10',0,''),(173162,55314,'117269','furniture-mobile','padding-right','10',0,''),(173163,55315,'117270','furniture-mobile','font-weight','400',0,''),(173164,55315,'117270','furniture-mobile','line-height','120',0,''),(173165,55315,'117270','furniture-mobile','line_height_measure','%',0,''),(173166,55315,'117270','furniture-mobile','font-size','12',0,''),(173167,55316,'117271','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(173168,55316,'117271','furniture-mobile','font-size','14',0,''),(173169,55316,'117271','furniture-mobile','font-weight','bold',0,''),(173170,55316,'117271','furniture-mobile','padding-bottom','10',0,''),(173171,55317,'117272','furniture-mobile','block_type','1',0,''),(173172,55317,'117272','furniture-mobile','background-color','$background-6',0,''),(173173,55317,'117272','furniture-mobile','padding-top','20',0,''),(173174,55317,'117272','furniture-mobile','padding-left','10',0,''),(173175,55317,'117272','furniture-mobile','padding-right','10',0,''),(173176,55317,'117272','furniture-mobile','padding-bottom','20',0,''),(173177,55317,'117272','furniture-mobile','font-size','14',0,''),(173178,55318,'117273','furniture-mobile','font-weight','normal',0,''),(173179,55318,'117273','furniture-mobile','text-align','right',0,''),(173180,55318,'117273','furniture-mobile','font-size','14',0,''),(173181,55318,'117273','furniture-mobile','box_align','3',0,''),(173182,55319,'117274','furniture-mobile','block_type','2',0,''),(173183,55319,'117274','furniture-mobile','font-weight','normal',0,''),(173184,55319,'117274','furniture-mobile','padding-bottom','20',0,''),(173185,55320,'117275','furniture-mobile','font-weight','400',0,''),(173186,55320,'117275','furniture-mobile','padding-top','20',0,''),(173187,55320,'117275','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',1,''),(173188,55320,'117275','furniture-mobile','padding-bottom','20',0,''),(173189,55321,'117276','furniture-mobile','block_type','11',0,''),(173190,55321,'117276','furniture-mobile','font-weight','normal',0,''),(173191,55322,'117277','furniture-mobile','text','<p>Web:</p>',1,''),(173192,55322,'117277','furniture-mobile','font-weight','normal',0,''),(173193,55322,'117277','furniture-mobile','text-align','right',0,''),(173194,55323,'117278','furniture-mobile','font-weight','normal',0,''),(173195,55323,'117278','furniture-mobile','text-align','right',0,''),(173196,55324,'117279','furniture-mobile','block_type','11',0,''),(173197,55324,'117279','furniture-mobile','font-weight','normal',0,''),(173198,55325,'117280','furniture-mobile','text','<p>Email:</p>',1,''),(173199,55325,'117280','furniture-mobile','font-weight','normal',0,''),(173200,55325,'117280','furniture-mobile','text-align','right',0,''),(173201,55326,'117281','furniture-mobile','font-weight','normal',0,''),(173202,55326,'117281','furniture-mobile','text-align','right',0,''),(173203,55327,'117282','furniture-mobile','block_type','1',0,''),(173204,55328,'117283','furniture-mobile','font-weight','normal',0,''),(173205,55328,'117283','furniture-mobile','text-align','right',0,''),(173206,55328,'117283','furniture-mobile','padding-bottom','10',0,''),(173207,55328,'117283','furniture-mobile','address_spacer',',',0,''),(173208,55328,'117283','furniture-mobile','font-size','12',0,''),(173209,55329,'117284','furniture-mobile','block_type','11',0,''),(173210,55329,'117284','furniture-mobile','font-weight','normal',0,''),(173211,55330,'117285','furniture-mobile','text','<p>Phone:</p>',1,''),(173212,55330,'117285','furniture-mobile','font-weight','normal',0,''),(173213,55330,'117285','furniture-mobile','text-align','right',0,''),(173214,55331,'117286','furniture-mobile','font-weight','normal',0,''),(173215,55331,'117286','furniture-mobile','text-align','right',0,''),(173216,55332,'1640103567.8175','furniture-mobile','column_qty','1',0,''),(173217,55332,'1640103567.8175','furniture-mobile','column_name','1',0,''),(173218,55332,'1640103567.8175','furniture-mobile','column_model','1',0,''),(173219,55333,'1640180896.2131','furniture-mobile','block_type','1',0,''),(173220,55334,'1639994189.268','furniture-mobile','background_image','themes/furniture-mobile/img/paid2.png',0,''),(173221,55334,'1639994189.268','furniture-mobile','background-position','center',0,''),(173222,55334,'1639994189.268','furniture-mobile','background-repeat','no-repeat',0,''),(173223,55334,'1639994189.268','furniture-mobile','position','absolute',0,''),(173224,55334,'1639994189.268','furniture-mobile','width','100',0,''),(173225,55334,'1639994189.268','furniture-mobile','width_measure','%',0,''),(173226,55334,'1639994189.268','furniture-mobile','height','100',0,''),(173227,55334,'1639994189.268','furniture-mobile','height_measure','%',0,''),(173228,55334,'1639994189.268','furniture-mobile','top','0',0,''),(173229,55334,'1639994189.268','furniture-mobile','left','0',0,''),(173230,55334,'1639994189.268','furniture-mobile','opacity','0.7',0,''),(173231,55335,'1639996119.9463','furniture-mobile','position','absolute',0,''),(173232,55335,'1639996119.9463','furniture-mobile','top','0',0,''),(173233,55335,'1639996119.9463','furniture-mobile','left','0',0,''),(173234,55335,'1639996119.9463','furniture-mobile','width','100',0,''),(173235,55335,'1639996119.9463','furniture-mobile','width_measure','%',0,''),(173236,55335,'1639996119.9463','furniture-mobile','min_width_measure','%',0,''),(173237,55335,'1639996119.9463','furniture-mobile','background_image','themes/furniture-mobile/img/unpaind.png',0,''),(173238,55335,'1639996119.9463','furniture-mobile','background-position','center',0,''),(173239,55335,'1639996119.9463','furniture-mobile','background-repeat','no-repeat',0,''),(173240,55335,'1639996119.9463','furniture-mobile','height','100',0,''),(173241,55335,'1639996119.9463','furniture-mobile','height_measure','%',0,''),(173242,55336,'117287','furniture-mobile','block_type','1',0,''),(173243,55336,'117287','furniture-mobile','padding-top','20',0,''),(173244,55337,'117288','furniture-mobile','tab_1','RETURNING CUSTOMER',1,''),(173245,55337,'117288','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(173246,55338,'117289','furniture-mobile','max-width','600',0,''),(173247,55338,'117289','furniture-mobile','margin_left_measure','auto',0,''),(173248,55338,'117289','furniture-mobile','margin_right_measure','auto',0,''),(173249,55339,'117290','furniture-mobile','block_type','8',0,''),(173250,55339,'117290','furniture-mobile','schema','8-6',0,'2885'),(173251,55340,'117291','furniture-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(173252,55341,'117292','furniture-mobile','block_type','1',0,''),(173253,55341,'117292','furniture-mobile','padding-left','20',0,''),(173254,55341,'117292','furniture-mobile','padding-right','20',0,''),(173255,55342,'117293','furniture-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(173256,55344,'117295','furniture-mobile','block_type','1',0,''),(173257,55345,'117296','furniture-mobile','text','##TEXT_OR##',0,''),(173258,55345,'117296','furniture-mobile','font-size','18',0,''),(173259,55345,'117296','furniture-mobile','font-weight','700',0,''),(173260,55345,'117296','furniture-mobile','padding-top','15',0,''),(173261,55345,'117296','furniture-mobile','text-align','center',0,''),(173262,55345,'117296','furniture-mobile','content','\\_',0,'3'),(173263,55345,'117296','furniture-mobile','height','5',0,'3'),(173264,55345,'117296','furniture-mobile','width','70',0,'3'),(173265,55345,'117296','furniture-mobile','display','inline-block',0,'3'),(173266,55345,'117296','furniture-mobile','border-top-width','1',0,'3'),(173267,55345,'117296','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173268,55345,'117296','furniture-mobile','margin-left','10',0,'3'),(173269,55345,'117296','furniture-mobile','margin-right','10',0,'3'),(173270,55345,'117296','furniture-mobile','content','\\_',0,'4'),(173271,55345,'117296','furniture-mobile','display','inline-block',0,'4'),(173272,55345,'117296','furniture-mobile','width','70',0,'4'),(173273,55345,'117296','furniture-mobile','height','5',0,'4'),(173274,55345,'117296','furniture-mobile','border-top-width','1',0,'4'),(173275,55345,'117296','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173276,55345,'117296','furniture-mobile','margin-left','10',0,'4'),(173277,55345,'117296','furniture-mobile','margin-right','10',0,'4'),(173278,55345,'117296','furniture-mobile','position','relative',0,''),(173279,55345,'117296','furniture-mobile','top','-10',0,''),(173280,55346,'117297','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173281,55346,'117297','furniture-mobile','font-size','26',0,''),(173282,55346,'117297','furniture-mobile','font-family','$font-1',0,''),(173283,55346,'117297','furniture-mobile','padding-top','15',0,''),(173284,55346,'117297','furniture-mobile','padding-bottom','15',0,''),(173285,55346,'117297','furniture-mobile','text-align','center',0,''),(173286,55347,'117298','furniture-mobile','text-align','center',0,''),(173287,55347,'117298','furniture-mobile','hide_parents','2',0,''),(173288,55348,'117299','furniture-mobile','block_type','1',0,''),(173289,55348,'117299','furniture-mobile','padding-top','40',0,''),(173290,55348,'117299','furniture-mobile','background-color','$background-6',0,''),(173291,55348,'117299','furniture-mobile','padding-bottom','40',0,''),(173292,55348,'117299','furniture-mobile','style_class','checkout-login-wrap',0,''),(173293,55349,'117300','furniture-mobile','block_type','2',0,''),(173294,55349,'117300','furniture-mobile','background-color','$background-7',0,''),(173295,55349,'117300','furniture-mobile','max-width','830',0,''),(173296,55349,'117300','furniture-mobile','margin_left_measure','auto',0,''),(173297,55349,'117300','furniture-mobile','margin_right_measure','auto',0,''),(173298,55349,'117300','furniture-mobile','padding-top','40',0,''),(173299,55349,'117300','furniture-mobile','padding-bottom','40',0,''),(173300,55349,'117300','furniture-mobile','schema','2-3',0,'2885'),(173301,55350,'117301','furniture-mobile','text-align','center',0,''),(173302,55350,'117301','furniture-mobile','margin-bottom','40',0,''),(173303,55351,'117302','furniture-mobile','text-align','center',0,''),(173304,55352,'117303','furniture-mobile','text','##TEXT_OR##',0,''),(173305,55352,'117303','furniture-mobile','font-size','18',0,''),(173306,55352,'117303','furniture-mobile','font-weight','700',0,''),(173307,55352,'117303','furniture-mobile','text-align','center',0,''),(173308,55352,'117303','furniture-mobile','content','\\_',0,'3'),(173309,55352,'117303','furniture-mobile','height','5',0,'3'),(173310,55352,'117303','furniture-mobile','width','70',0,'3'),(173311,55352,'117303','furniture-mobile','display','inline-block',0,'3'),(173312,55352,'117303','furniture-mobile','border-top-width','1',0,'3'),(173313,55352,'117303','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173314,55352,'117303','furniture-mobile','margin-left','10',0,'3'),(173315,55352,'117303','furniture-mobile','margin-right','10',0,'3'),(173316,55352,'117303','furniture-mobile','content','\\_',0,'4'),(173317,55352,'117303','furniture-mobile','display','inline-block',0,'4'),(173318,55352,'117303','furniture-mobile','width','70',0,'4'),(173319,55352,'117303','furniture-mobile','height','5',0,'4'),(173320,55352,'117303','furniture-mobile','border-top-width','1',0,'4'),(173321,55352,'117303','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173322,55352,'117303','furniture-mobile','margin-left','10',0,'4'),(173323,55352,'117303','furniture-mobile','margin-right','10',0,'4'),(173324,55352,'117303','furniture-mobile','position','relative',0,''),(173325,55352,'117303','furniture-mobile','padding-top','10',0,''),(173326,55352,'117303','furniture-mobile','padding-bottom','10',0,''),(173327,55353,'117304','furniture-mobile','block_type','1',0,''),(173328,55354,'117305','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173329,55354,'117305','furniture-mobile','font-size','18',0,''),(173330,55354,'117305','furniture-mobile','font-family','$font-1',0,''),(173331,55354,'117305','furniture-mobile','padding-top','15',0,''),(173332,55354,'117305','furniture-mobile','padding-bottom','15',0,''),(173333,55354,'117305','furniture-mobile','text-align','center',0,''),(173334,55354,'117305','furniture-mobile','text-transform','uppercase',0,''),(173335,55355,'117306','furniture-mobile','text-align','center',0,''),(173336,55355,'117306','furniture-mobile','hide_parents','2',0,''),(173337,55356,'117307','furniture-mobile','text','##NEW_CUSTOMER##',0,''),(173338,55356,'117307','furniture-mobile','font-size','18',0,''),(173339,55356,'117307','furniture-mobile','font-family','$font-1',0,''),(173340,55356,'117307','furniture-mobile','text-align','center',0,''),(173341,55356,'117307','furniture-mobile','text-transform','uppercase',0,''),(173342,55356,'117307','furniture-mobile','margin-bottom','10',0,''),(173343,55357,'117308','furniture-mobile','max-width','230',0,''),(173344,55357,'117308','furniture-mobile','margin_left_measure','auto',0,''),(173345,55357,'117308','furniture-mobile','margin_right_measure','auto',0,''),(173346,55358,'117309','furniture-mobile','text','##RETURNING_CUSTOMER##',0,''),(173347,55358,'117309','furniture-mobile','font-size','18',0,''),(173348,55358,'117309','furniture-mobile','font-family','$font-1',0,''),(173349,55358,'117309','furniture-mobile','text-transform','uppercase',0,''),(173350,55358,'117309','furniture-mobile','text-align','center',0,''),(173351,55359,'117310','furniture-mobile','block_type','1',0,''),(173352,55359,'117310','furniture-mobile','padding-top','20',0,''),(173353,55360,'117311','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(173354,55360,'117311','furniture-mobile','tab_2','RETURNING CUSTOMER',1,''),(173355,55360,'117311','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(173356,55361,'117312','furniture-mobile','block_type','8',0,''),(173357,55362,'117313','furniture-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(173358,55363,'117314','furniture-mobile','block_type','1',0,''),(173359,55363,'117314','furniture-mobile','padding-left','20',0,''),(173360,55363,'117314','furniture-mobile','padding-right','20',0,''),(173361,55365,'117316','furniture-mobile','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(173362,55365,'117316','furniture-mobile','border-top-width','1',0,''),(173363,55365,'117316','furniture-mobile','border-top-color','$border-color-4',0,''),(173364,55367,'117318','furniture-mobile','block_type','8',0,''),(173365,55368,'117319','furniture-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(173366,55369,'117320','furniture-mobile','block_type','1',0,''),(173367,55369,'117320','furniture-mobile','padding-left','20',0,''),(173368,55369,'117320','furniture-mobile','padding-right','20',0,''),(173369,55370,'117321','furniture-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(173370,55372,'117323','furniture-mobile','text-align','center',0,''),(173371,55373,'117324','furniture-mobile','text','##TEXT_OR##',0,''),(173372,55373,'117324','furniture-mobile','font-size','18',0,''),(173373,55373,'117324','furniture-mobile','font-weight','700',0,''),(173374,55373,'117324','furniture-mobile','padding-top','15',0,''),(173375,55373,'117324','furniture-mobile','text-align','center',0,''),(173376,55373,'117324','furniture-mobile','content','\\_',0,'3'),(173377,55373,'117324','furniture-mobile','height','5',0,'3'),(173378,55373,'117324','furniture-mobile','width','70',0,'3'),(173379,55373,'117324','furniture-mobile','display','inline-block',0,'3'),(173380,55373,'117324','furniture-mobile','border-top-width','1',0,'3'),(173381,55373,'117324','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173382,55373,'117324','furniture-mobile','margin-left','10',0,'3'),(173383,55373,'117324','furniture-mobile','margin-right','10',0,'3'),(173384,55373,'117324','furniture-mobile','content','\\_',0,'4'),(173385,55373,'117324','furniture-mobile','display','inline-block',0,'4'),(173386,55373,'117324','furniture-mobile','width','70',0,'4'),(173387,55373,'117324','furniture-mobile','height','5',0,'4'),(173388,55373,'117324','furniture-mobile','border-top-width','1',0,'4'),(173389,55373,'117324','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173390,55373,'117324','furniture-mobile','margin-left','10',0,'4'),(173391,55373,'117324','furniture-mobile','margin-right','10',0,'4'),(173392,55373,'117324','furniture-mobile','position','relative',0,''),(173393,55373,'117324','furniture-mobile','top','-10',0,''),(173394,55374,'117325','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173395,55374,'117325','furniture-mobile','font-size','26',0,''),(173396,55374,'117325','furniture-mobile','font-family','$font-1',0,''),(173397,55374,'117325','furniture-mobile','padding-top','15',0,''),(173398,55374,'117325','furniture-mobile','padding-bottom','15',0,''),(173399,55374,'117325','furniture-mobile','text-align','center',0,''),(173400,55375,'117326','furniture-mobile','block_type','1',0,''),(173401,55375,'117326','furniture-mobile','padding-top','20',0,''),(173402,55376,'117327','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(173403,55376,'117327','furniture-mobile','tab_2','RETURNING CUSTOMER',1,''),(173404,55376,'117327','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(173405,55377,'117328','furniture-mobile','block_type','8',0,''),(173406,55378,'117329','furniture-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(173407,55381,'117332','furniture-mobile','block_type','8',0,''),(173408,55382,'117333','furniture-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(173409,55384,'117335','furniture-mobile','block_type','1',0,''),(173410,55384,'117335','furniture-mobile','padding-left','20',0,''),(173411,55384,'117335','furniture-mobile','padding-right','20',0,''),(173412,55386,'117337','furniture-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(173413,55387,'117338','furniture-mobile','text','##TEXT_OR##',0,''),(173414,55387,'117338','furniture-mobile','font-size','18',0,''),(173415,55387,'117338','furniture-mobile','font-weight','700',0,''),(173416,55387,'117338','furniture-mobile','padding-top','15',0,''),(173417,55387,'117338','furniture-mobile','text-align','center',0,''),(173418,55387,'117338','furniture-mobile','content','\\_',0,'3'),(173419,55387,'117338','furniture-mobile','height','5',0,'3'),(173420,55387,'117338','furniture-mobile','width','70',0,'3'),(173421,55387,'117338','furniture-mobile','display','inline-block',0,'3'),(173422,55387,'117338','furniture-mobile','border-top-width','1',0,'3'),(173423,55387,'117338','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173424,55387,'117338','furniture-mobile','margin-left','10',0,'3'),(173425,55387,'117338','furniture-mobile','margin-right','10',0,'3'),(173426,55387,'117338','furniture-mobile','content','\\_',0,'4'),(173427,55387,'117338','furniture-mobile','display','inline-block',0,'4'),(173428,55387,'117338','furniture-mobile','width','70',0,'4'),(173429,55387,'117338','furniture-mobile','height','5',0,'4'),(173430,55387,'117338','furniture-mobile','border-top-width','1',0,'4'),(173431,55387,'117338','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173432,55387,'117338','furniture-mobile','margin-left','10',0,'4'),(173433,55387,'117338','furniture-mobile','margin-right','10',0,'4'),(173434,55387,'117338','furniture-mobile','position','relative',0,''),(173435,55387,'117338','furniture-mobile','top','-10',0,''),(173436,55388,'117339','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173437,55388,'117339','furniture-mobile','font-size','26',0,''),(173438,55388,'117339','furniture-mobile','font-family','$font-1',0,''),(173439,55388,'117339','furniture-mobile','padding-top','15',0,''),(173440,55388,'117339','furniture-mobile','padding-bottom','15',0,''),(173441,55388,'117339','furniture-mobile','text-align','center',0,''),(173442,55389,'117340','furniture-mobile','text-align','center',0,''),(173443,55390,'117341','furniture-mobile','block_type','1',0,''),(173444,55390,'117341','furniture-mobile','padding-top','20',0,''),(173445,55391,'117342','furniture-mobile','text-align','center',0,''),(173446,55392,'117343','furniture-mobile','text','##TEXT_OR##',0,''),(173447,55392,'117343','furniture-mobile','font-size','18',0,''),(173448,55392,'117343','furniture-mobile','font-weight','700',0,''),(173449,55392,'117343','furniture-mobile','padding-top','15',0,''),(173450,55392,'117343','furniture-mobile','text-align','center',0,''),(173451,55392,'117343','furniture-mobile','content','\\_',0,'3'),(173452,55392,'117343','furniture-mobile','height','5',0,'3'),(173453,55392,'117343','furniture-mobile','width','70',0,'3'),(173454,55392,'117343','furniture-mobile','display','inline-block',0,'3'),(173455,55392,'117343','furniture-mobile','border-top-width','1',0,'3'),(173456,55392,'117343','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173457,55392,'117343','furniture-mobile','margin-left','10',0,'3'),(173458,55392,'117343','furniture-mobile','margin-right','10',0,'3'),(173459,55392,'117343','furniture-mobile','content','\\_',0,'4'),(173460,55392,'117343','furniture-mobile','display','inline-block',0,'4'),(173461,55392,'117343','furniture-mobile','width','70',0,'4'),(173462,55392,'117343','furniture-mobile','height','5',0,'4'),(173463,55392,'117343','furniture-mobile','border-top-width','1',0,'4'),(173464,55392,'117343','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173465,55392,'117343','furniture-mobile','margin-left','10',0,'4'),(173466,55392,'117343','furniture-mobile','margin-right','10',0,'4'),(173467,55392,'117343','furniture-mobile','position','relative',0,''),(173468,55392,'117343','furniture-mobile','top','-10',0,''),(173469,55393,'117344','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(173470,55393,'117344','furniture-mobile','tab_2','RETURNING CUSTOMER',1,''),(173471,55393,'117344','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(173472,55394,'117345','furniture-mobile','block_type','8',0,''),(173473,55395,'117346','furniture-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(173474,55398,'117349','furniture-mobile','block_type','8',0,''),(173475,55399,'117350','furniture-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(173476,55400,'117351','furniture-mobile','block_type','1',0,''),(173477,55400,'117351','furniture-mobile','padding-left','20',0,''),(173478,55400,'117351','furniture-mobile','padding-right','20',0,''),(173479,55402,'117353','furniture-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(173480,55403,'117354','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173481,55403,'117354','furniture-mobile','font-size','26',0,''),(173482,55403,'117354','furniture-mobile','font-family','$font-1',0,''),(173483,55403,'117354','furniture-mobile','padding-top','15',0,''),(173484,55403,'117354','furniture-mobile','padding-bottom','15',0,''),(173485,55403,'117354','furniture-mobile','text-align','center',0,''),(173486,55404,'117355','furniture-mobile','block_type','1',0,''),(173487,55404,'117355','furniture-mobile','padding-top','40',0,''),(173488,55404,'117355','furniture-mobile','background-color','$background-6',0,''),(173489,55404,'117355','furniture-mobile','padding-bottom','40',0,''),(173490,55405,'117356','furniture-mobile','block_type','2',0,''),(173491,55405,'117356','furniture-mobile','background-color','$background-7',0,''),(173492,55405,'117356','furniture-mobile','max-width','830',0,''),(173493,55405,'117356','furniture-mobile','margin_left_measure','auto',0,''),(173494,55405,'117356','furniture-mobile','margin_right_measure','auto',0,''),(173495,55405,'117356','furniture-mobile','padding-top','40',0,''),(173496,55405,'117356','furniture-mobile','padding-bottom','40',0,''),(173497,55405,'117356','furniture-mobile','schema','2-3',0,'2885'),(173498,55406,'117357','furniture-mobile','block_type','1',0,''),(173499,55407,'117358','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173500,55407,'117358','furniture-mobile','font-size','18',0,''),(173501,55407,'117358','furniture-mobile','font-family','$font-1',0,''),(173502,55407,'117358','furniture-mobile','padding-top','15',0,''),(173503,55407,'117358','furniture-mobile','padding-bottom','15',0,''),(173504,55407,'117358','furniture-mobile','text-align','center',0,''),(173505,55407,'117358','furniture-mobile','text-transform','uppercase',0,''),(173506,55408,'117359','furniture-mobile','text-align','center',0,''),(173507,55408,'117359','furniture-mobile','hide_parents','2',0,''),(173508,55409,'117360','furniture-mobile','text-align','center',0,''),(173509,55410,'117361','furniture-mobile','text-align','center',0,''),(173510,55410,'117361','furniture-mobile','margin-bottom','40',0,''),(173511,55411,'117362','furniture-mobile','text','##TEXT_OR##',0,''),(173512,55411,'117362','furniture-mobile','font-size','18',0,''),(173513,55411,'117362','furniture-mobile','font-weight','700',0,''),(173514,55411,'117362','furniture-mobile','text-align','center',0,''),(173515,55411,'117362','furniture-mobile','content','\\_',0,'3'),(173516,55411,'117362','furniture-mobile','height','5',0,'3'),(173517,55411,'117362','furniture-mobile','width','70',0,'3'),(173518,55411,'117362','furniture-mobile','display','inline-block',0,'3'),(173519,55411,'117362','furniture-mobile','border-top-width','1',0,'3'),(173520,55411,'117362','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173521,55411,'117362','furniture-mobile','margin-left','10',0,'3'),(173522,55411,'117362','furniture-mobile','margin-right','10',0,'3'),(173523,55411,'117362','furniture-mobile','content','\\_',0,'4'),(173524,55411,'117362','furniture-mobile','display','inline-block',0,'4'),(173525,55411,'117362','furniture-mobile','width','70',0,'4'),(173526,55411,'117362','furniture-mobile','height','5',0,'4'),(173527,55411,'117362','furniture-mobile','border-top-width','1',0,'4'),(173528,55411,'117362','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173529,55411,'117362','furniture-mobile','margin-left','10',0,'4'),(173530,55411,'117362','furniture-mobile','margin-right','10',0,'4'),(173531,55411,'117362','furniture-mobile','position','relative',0,''),(173532,55411,'117362','furniture-mobile','padding-top','10',0,''),(173533,55411,'117362','furniture-mobile','padding-bottom','10',0,''),(173534,55412,'117363','furniture-mobile','text','##NEW_CUSTOMER##',0,''),(173535,55412,'117363','furniture-mobile','font-size','18',0,''),(173536,55412,'117363','furniture-mobile','font-family','$font-1',0,''),(173537,55412,'117363','furniture-mobile','text-align','center',0,''),(173538,55412,'117363','furniture-mobile','text-transform','uppercase',0,''),(173539,55412,'117363','furniture-mobile','margin-bottom','10',0,''),(173540,55413,'117364','furniture-mobile','text','##RETURNING_CUSTOMER##',0,''),(173541,55413,'117364','furniture-mobile','font-size','18',0,''),(173542,55413,'117364','furniture-mobile','font-family','$font-1',0,''),(173543,55413,'117364','furniture-mobile','text-transform','uppercase',0,''),(173544,55413,'117364','furniture-mobile','text-align','center',0,''),(173545,55414,'117365','furniture-mobile','max-width','230',0,''),(173546,55414,'117365','furniture-mobile','margin_left_measure','auto',0,''),(173547,55414,'117365','furniture-mobile','margin_right_measure','auto',0,''),(173548,55415,'117366','furniture-mobile','block_type','1',0,''),(173549,55415,'117366','furniture-mobile','padding-top','40',0,''),(173550,55415,'117366','furniture-mobile','background-color','$background-6',0,''),(173551,55415,'117366','furniture-mobile','padding-bottom','40',0,''),(173552,55416,'117367','furniture-mobile','block_type','2',0,''),(173553,55416,'117367','furniture-mobile','background-color','$background-7',0,''),(173554,55416,'117367','furniture-mobile','max-width','830',0,''),(173555,55416,'117367','furniture-mobile','margin_left_measure','auto',0,''),(173556,55416,'117367','furniture-mobile','margin_right_measure','auto',0,''),(173557,55416,'117367','furniture-mobile','padding-top','40',0,''),(173558,55416,'117367','furniture-mobile','padding-bottom','40',0,''),(173559,55416,'117367','furniture-mobile','schema','2-3',0,'2885'),(173560,55417,'117368','furniture-mobile','text','##NEW_CUSTOMER##',0,''),(173561,55417,'117368','furniture-mobile','font-size','18',0,''),(173562,55417,'117368','furniture-mobile','font-family','$font-1',0,''),(173563,55417,'117368','furniture-mobile','text-align','center',0,''),(173564,55417,'117368','furniture-mobile','text-transform','uppercase',0,''),(173565,55417,'117368','furniture-mobile','margin-bottom','10',0,''),(173566,55418,'117369','furniture-mobile','text-align','center',0,''),(173567,55419,'117370','furniture-mobile','text-align','center',0,''),(173568,55419,'117370','furniture-mobile','margin-bottom','40',0,''),(173569,55420,'117371','furniture-mobile','text','##TEXT_OR##',0,''),(173570,55420,'117371','furniture-mobile','font-size','18',0,''),(173571,55420,'117371','furniture-mobile','font-weight','700',0,''),(173572,55420,'117371','furniture-mobile','text-align','center',0,''),(173573,55420,'117371','furniture-mobile','content','\\_',0,'3'),(173574,55420,'117371','furniture-mobile','height','5',0,'3'),(173575,55420,'117371','furniture-mobile','width','70',0,'3'),(173576,55420,'117371','furniture-mobile','display','inline-block',0,'3'),(173577,55420,'117371','furniture-mobile','border-top-width','1',0,'3'),(173578,55420,'117371','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173579,55420,'117371','furniture-mobile','margin-left','10',0,'3'),(173580,55420,'117371','furniture-mobile','margin-right','10',0,'3'),(173581,55420,'117371','furniture-mobile','content','\\_',0,'4'),(173582,55420,'117371','furniture-mobile','display','inline-block',0,'4'),(173583,55420,'117371','furniture-mobile','width','70',0,'4'),(173584,55420,'117371','furniture-mobile','height','5',0,'4'),(173585,55420,'117371','furniture-mobile','border-top-width','1',0,'4'),(173586,55420,'117371','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173587,55420,'117371','furniture-mobile','margin-left','10',0,'4'),(173588,55420,'117371','furniture-mobile','margin-right','10',0,'4'),(173589,55420,'117371','furniture-mobile','position','relative',0,''),(173590,55420,'117371','furniture-mobile','padding-top','10',0,''),(173591,55420,'117371','furniture-mobile','padding-bottom','10',0,''),(173592,55421,'117372','furniture-mobile','block_type','1',0,''),(173593,55422,'117373','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173594,55422,'117373','furniture-mobile','font-size','18',0,''),(173595,55422,'117373','furniture-mobile','font-family','$font-1',0,''),(173596,55422,'117373','furniture-mobile','padding-top','15',0,''),(173597,55422,'117373','furniture-mobile','padding-bottom','15',0,''),(173598,55422,'117373','furniture-mobile','text-align','center',0,''),(173599,55422,'117373','furniture-mobile','text-transform','uppercase',0,''),(173600,55423,'117374','furniture-mobile','text-align','center',0,''),(173601,55423,'117374','furniture-mobile','hide_parents','2',0,''),(173602,55424,'117375','furniture-mobile','text','##RETURNING_CUSTOMER##',0,''),(173603,55424,'117375','furniture-mobile','font-size','18',0,''),(173604,55424,'117375','furniture-mobile','font-family','$font-1',0,''),(173605,55424,'117375','furniture-mobile','text-transform','uppercase',0,''),(173606,55424,'117375','furniture-mobile','text-align','center',0,''),(173607,55425,'117376','furniture-mobile','max-width','230',0,''),(173608,55425,'117376','furniture-mobile','margin_left_measure','auto',0,''),(173609,55425,'117376','furniture-mobile','margin_right_measure','auto',0,''),(173610,55426,'117377','furniture-mobile','block_type','1',0,''),(173611,55427,'117378','furniture-mobile','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(173612,55427,'117378','furniture-mobile','margin-bottom','30',0,''),(173613,55428,'117379','furniture-mobile','block_type','1',0,''),(173614,55429,'117380','furniture-mobile','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(173615,55429,'117380','furniture-mobile','margin-bottom','30',0,''),(173616,55430,'117386','furniture-mobile','block_type','1',0,''),(173617,55430,'117386','furniture-mobile','font-weight','normal',0,''),(173618,55431,'120856','furniture-mobile','block_type','1',0,''),(173619,55431,'120856','furniture-mobile','style_class','lowestPricedBox',0,''),(173620,55432,'120857','furniture-mobile','banners_group','21',0,''),(173621,55433,'120858','furniture-mobile','block_type','3',0,''),(173622,55433,'120858','furniture-mobile','style_class','tripleBanner',0,''),(173623,55434,'120859','furniture-mobile','text','<div>Returns and Exchanges</div>\n<div>30 Day Satisfaction Guarantee</div>\n',0,''),(173624,55434,'120859','furniture-mobile','style_class','returns',0,''),(173625,55435,'120860','furniture-mobile','text','<div>Warranty</div>\n<div>Min 12 months manufacturer’s warranty</div>',0,''),(173626,55435,'120860','furniture-mobile','style_class','warranty',0,''),(173627,55436,'120861','furniture-mobile','text','<div>Track your order</div>\n<div>Check the current status of your order</div>',0,''),(173628,55436,'120861','furniture-mobile','style_class','track',0,''),(173629,55437,'120862','furniture-mobile','block_type','1',0,''),(173630,55438,'117389','furniture-mobile','col_in_row','4',0,''),(173631,55438,'117389','furniture-mobile','view_as','carousel',0,''),(173632,55438,'117389','furniture-mobile','show_attributes','1',0,''),(173633,55438,'117389','furniture-mobile','col_in_row','3',0,'2885'),(173634,55438,'117389','furniture-mobile','col_in_row','2',0,'2876'),(173635,55438,'117389','furniture-mobile','col_in_row','1',0,'2906'),(173636,55438,'117389','furniture-mobile','listing_type','productListing',0,''),(173637,55438,'117389','furniture-mobile','show_qty_input','1',0,''),(173638,55438,'117389','furniture-mobile','show_compare','1',0,''),(173639,55438,'117389','furniture-mobile','lazy_load','1',0,''),(173640,55438,'117389','furniture-mobile','show_model','1',0,''),(173641,55438,'117389','furniture-mobile','show_properties','1',0,''),(173642,55438,'117389','furniture-mobile','show_bonus_points','1',0,''),(173643,55438,'117389','furniture-mobile','show_buy_button','1',0,''),(173644,55438,'117389','furniture-mobile','show_view_button','1',0,''),(173645,55438,'117389','furniture-mobile','show_wishlist_button','1',0,''),(173646,55438,'117389','furniture-mobile','hide_parents','2',0,''),(173647,55439,'121014','furniture-mobile','text','<h2>Furniture deals</h2>',0,''),(173648,55440,'120864','furniture-mobile','block_type','1',0,''),(173649,55440,'120864','furniture-mobile','style_class','shopByCollectionBox',0,''),(173650,55440,'120864','furniture-mobile','padding-bottom','30',0,''),(173651,55441,'120865','furniture-mobile','banners_group','Shop_by_co',0,''),(173652,55441,'120865','furniture-mobile','banners_type','banner',0,''),(173653,55442,'121015','furniture-mobile','text','<h2>Shop by collection</h2> ',0,''),(173654,55443,'1683022993.8509','furniture-mobile','block_type','1',0,''),(173655,55443,'1683022993.8509','furniture-mobile','style_class','mainBanner',0,''),(173656,55444,'1683023028.4274','furniture-mobile','banners_type','carousel',0,''),(173657,55444,'1683023028.4274','furniture-mobile','banners_group','3',0,''),(173658,55445,'117394','furniture-mobile','block_type','1',0,''),(173659,55446,'117395','furniture-mobile','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(173660,55448,'117397','furniture-mobile','block_type','1',0,''),(173661,55448,'117397','furniture-mobile','padding-top','40',0,''),(173662,55448,'117397','furniture-mobile','padding-bottom','80',0,''),(173663,55449,'117398','furniture-mobile','block_type','6',0,''),(173664,55450,'117399','furniture-mobile','block_type','1',0,''),(173665,55450,'117399','furniture-mobile','padding-top','20',0,''),(173666,55450,'117399','furniture-mobile','padding-left','20',0,''),(173667,55450,'117399','furniture-mobile','padding-right','20',0,''),(173668,55450,'117399','furniture-mobile','padding-bottom','20',0,''),(173669,55450,'117399','furniture-mobile','border-top-width','1',0,''),(173670,55450,'117399','furniture-mobile','border-left-width','1',0,''),(173671,55450,'117399','furniture-mobile','border-right-width','1',0,''),(173672,55450,'117399','furniture-mobile','border-bottom-width','1',0,''),(173673,55450,'117399','furniture-mobile','border-top-color','$border-color-4',0,''),(173674,55450,'117399','furniture-mobile','border-left-color','$border-color-4',0,''),(173675,55450,'117399','furniture-mobile','border-right-color','$border-color-4',0,''),(173676,55450,'117399','furniture-mobile','border-bottom-color','$border-color-4',0,''),(173677,55450,'117399','furniture-mobile','margin-right','20',0,''),(173678,55453,'117402','furniture-mobile','block_type','1',0,''),(173679,55453,'117402','furniture-mobile','padding-top','20',0,''),(173680,55454,'117403','furniture-mobile','block_type','6',0,''),(173681,55455,'117404','furniture-mobile','padding-right','20',0,''),(173682,55457,'117406','furniture-mobile','block_type','1',0,''),(173683,55457,'117406','furniture-mobile','padding-top','20',0,''),(173684,55458,'117407','furniture-mobile','block_type','6',0,''),(173685,55459,'117408','furniture-mobile','padding-right','20',0,''),(173686,55461,'117410','furniture-mobile','block_type','1',0,''),(173687,55461,'117410','furniture-mobile','style_class','account-password-wrap',0,''),(173688,55462,'117411','furniture-mobile','block_type','6',0,''),(173689,55462,'117411','furniture-mobile','schema','6-3',0,'2885'),(173690,55463,'117412','furniture-mobile','aria_name','account-menu',0,''),(173747,55484,'117414','furniture-mobile','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(173748,55485,'117415','furniture-mobile','block_type','1',0,''),(173749,55485,'117415','furniture-mobile','padding-top','20',0,''),(173750,55486,'117416','furniture-mobile','tab_1','RETURNING CUSTOMER',1,''),(173751,55486,'117416','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(173752,55487,'117417','furniture-mobile','max-width','800',0,''),(173753,55487,'117417','furniture-mobile','margin_left_measure','auto',0,''),(173754,55487,'117417','furniture-mobile','margin_right_measure','auto',0,''),(173755,55488,'117418','furniture-mobile','block_type','8',0,''),(173756,55489,'117419','furniture-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(173757,55490,'117420','furniture-mobile','block_type','1',0,''),(173758,55490,'117420','furniture-mobile','padding-left','20',0,''),(173759,55490,'117420','furniture-mobile','padding-right','20',0,''),(173760,55492,'117422','furniture-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(173761,55493,'117423','furniture-mobile','block_type','1',0,''),(173762,55494,'117424','furniture-mobile','block_type','1',0,''),(173763,55495,'117425','furniture-mobile','margin-left','0',0,''),(173764,55495,'117425','furniture-mobile','margin-right','0',0,''),(173765,55495,'117425','furniture-mobile','margin-bottom','20',0,''),(173766,55496,'117426','furniture-mobile','margin-bottom','30',0,''),(173767,55497,'117427','furniture-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(173768,55498,'117428','furniture-mobile','block_type','1',0,''),(173769,55500,'117430','furniture-mobile','block_type','6',0,''),(173770,55500,'117430','furniture-mobile','font-weight','400',0,''),(173771,55500,'117430','furniture-mobile','schema','6-2',0,'2906'),(173772,55500,'117430','furniture-mobile','schema','6-2',0,'2885'),(173773,55501,'117431','furniture-mobile','font-weight','400',0,''),(173774,55501,'117431','furniture-mobile','padding-right','40',0,''),(173775,55501,'117431','furniture-mobile','padding-right','0',0,'2906'),(173776,55501,'117431','furniture-mobile','padding-right','0',0,'2885'),(173777,55502,'117432','furniture-mobile','col_in_row','3',0,''),(173778,55502,'117432','furniture-mobile','products_align','left',0,''),(173779,55502,'117432','furniture-mobile','font-weight','400',0,''),(173780,55502,'117432','furniture-mobile','show_qty_input','0',0,''),(173781,55502,'117432','furniture-mobile','listing_type','productListing',0,''),(173782,55502,'117432','furniture-mobile','listing_type_rows','no',0,''),(173783,55502,'117432','furniture-mobile','show_buy_button_b2b','on',0,''),(173784,55502,'117432','furniture-mobile','show_wishlist_button_b2b','1',0,''),(173785,55502,'117432','furniture-mobile','show_compare_b2b','1',0,''),(173786,55502,'117432','furniture-mobile','show_stock','0',0,''),(173787,55502,'117432','furniture-mobile','show_description','0',0,''),(173788,55502,'117432','furniture-mobile','show_model','0',0,''),(173789,55502,'117432','furniture-mobile','show_properties','0',0,''),(173790,55502,'117432','furniture-mobile','show_rating','0',0,''),(173791,55502,'117432','furniture-mobile','show_rating_counts','0',0,''),(173792,55502,'117432','furniture-mobile','show_price','0',0,''),(173793,55502,'117432','furniture-mobile','show_buy_button','0',0,''),(173794,55502,'117432','furniture-mobile','show_view_button','0',0,''),(173795,55502,'117432','furniture-mobile','show_wishlist_button','0',0,''),(173796,55502,'117432','furniture-mobile','show_compare','0',0,''),(173797,55502,'117432','furniture-mobile','show_name_rows','0',0,''),(173798,55502,'117432','furniture-mobile','show_image_rows','0',0,''),(173799,55502,'117432','furniture-mobile','show_stock_rows','0',0,''),(173800,55502,'117432','furniture-mobile','show_description_rows','0',0,''),(173801,55502,'117432','furniture-mobile','show_model_rows','0',0,''),(173802,55502,'117432','furniture-mobile','show_properties_rows','0',0,''),(173803,55502,'117432','furniture-mobile','show_rating_rows','0',0,''),(173804,55502,'117432','furniture-mobile','show_rating_counts_rows','0',0,''),(173805,55502,'117432','furniture-mobile','show_price_rows','0',0,''),(173806,55502,'117432','furniture-mobile','show_buy_button_rows','0',0,''),(173807,55502,'117432','furniture-mobile','show_qty_input_rows','0',0,''),(173808,55502,'117432','furniture-mobile','show_view_button_rows','0',0,''),(173809,55502,'117432','furniture-mobile','show_wishlist_button_rows','0',0,''),(173810,55502,'117432','furniture-mobile','show_compare_rows','0',0,''),(173811,55502,'117432','furniture-mobile','show_name_b2b','0',0,''),(173812,55502,'117432','furniture-mobile','show_image_b2b','0',0,''),(173813,55502,'117432','furniture-mobile','show_stock_b2b','0',0,''),(173814,55502,'117432','furniture-mobile','show_description_b2b','0',0,''),(173815,55502,'117432','furniture-mobile','show_model_b2b','0',0,''),(173816,55502,'117432','furniture-mobile','show_properties_b2b','0',0,''),(173817,55502,'117432','furniture-mobile','show_rating_b2b','0',0,''),(173818,55502,'117432','furniture-mobile','show_rating_counts_b2b','0',0,''),(173819,55502,'117432','furniture-mobile','show_price_b2b','0',0,''),(173820,55502,'117432','furniture-mobile','show_qty_input_b2b','0',0,''),(173821,55502,'117432','furniture-mobile','show_view_button_b2b','0',0,''),(173822,55502,'117432','furniture-mobile','show_attributes_b2b','0',0,''),(173823,55502,'117432','furniture-mobile','items_on_page','9',0,''),(173824,55502,'117432','furniture-mobile','col_in_row','2',0,'2885'),(173825,55502,'117432','furniture-mobile','col_in_row','1',0,'2906'),(173826,55502,'117432','furniture-mobile','product_names_teg','h2',0,''),(173827,55504,'117434','furniture-mobile','block_type','5',0,''),(173828,55504,'117434','furniture-mobile','padding-top','10',0,''),(173829,55504,'117434','furniture-mobile','padding-bottom','10',0,''),(173830,55504,'117434','furniture-mobile','schema','5-2',0,'2906'),(173831,55504,'117434','furniture-mobile','border-top-color','$border-color-4',0,''),(173832,55504,'117434','furniture-mobile','border-top-width','1',0,''),(173833,55506,'117436','furniture-mobile','float','right',0,''),(173834,55507,'117437','furniture-mobile','listing_type','productListing',0,''),(173835,55509,'117439','furniture-mobile','block_type','1',0,''),(173836,55509,'117439','furniture-mobile','padding-top','10',0,''),(173837,55509,'117439','furniture-mobile','padding-bottom','10',0,''),(173838,55509,'117439','furniture-mobile','border-bottom-width','1',0,''),(173839,55509,'117439','furniture-mobile','border-bottom-color','$border-color-4',0,''),(173840,55509,'117439','furniture-mobile','margin-left','0',0,''),(173841,55509,'117439','furniture-mobile','margin-right','0',0,''),(173842,55510,'117440','furniture-mobile','float','right',0,''),(173843,55510,'117440','furniture-mobile','display','none',0,'2906'),(173844,55511,'117441','furniture-mobile','float','left',0,''),(173845,55511,'117441','furniture-mobile','clear','none',0,''),(173846,55511,'117441','furniture-mobile','margin-left','20',0,''),(173847,55511,'117441','furniture-mobile','display','none',0,'2906'),(173848,55512,'117442','furniture-mobile','margin-right','20',0,''),(173849,55512,'117442','furniture-mobile','float','right',0,''),(173850,55512,'117442','furniture-mobile','clear','none',0,''),(173851,55512,'117442','furniture-mobile','display','none',0,'2885'),(173852,55513,'117443','furniture-mobile','float','left',0,''),(173853,55513,'117443','furniture-mobile','clear','none',0,''),(173854,55513,'117443','furniture-mobile','sort_pos_3','1',0,''),(173855,55513,'117443','furniture-mobile','sort_pos_4','2',0,''),(173856,55513,'117443','furniture-mobile','sort_pos_10','3',0,''),(173857,55513,'117443','furniture-mobile','sort_pos_9','4',0,''),(173858,55513,'117443','furniture-mobile','sort_pos_11','5',0,''),(173859,55513,'117443','furniture-mobile','sort_pos_12','6',0,''),(173860,55513,'117443','furniture-mobile','sort_pos_14','7',0,''),(173861,55513,'117443','furniture-mobile','sort_pos_13','8',0,''),(173862,55513,'117443','furniture-mobile','sort_pos_8','9',0,''),(173863,55513,'117443','furniture-mobile','sort_pos_7','10',0,''),(173864,55513,'117443','furniture-mobile','sort_pos_2','11',0,''),(173865,55513,'117443','furniture-mobile','sort_pos_1','12',0,''),(173866,55513,'117443','furniture-mobile','sort_pos_6','13',0,''),(173867,55513,'117443','furniture-mobile','sort_pos_5','14',0,''),(173868,55513,'117443','furniture-mobile','sort_pos_0','15',0,''),(173869,55513,'117443','furniture-mobile','sort_hide_10','1',0,''),(173870,55513,'117443','furniture-mobile','sort_hide_9','1',0,''),(173871,55513,'117443','furniture-mobile','hide_icons','1',0,''),(173872,55513,'117443','furniture-mobile','sort_hide_16','1',0,''),(173873,55513,'117443','furniture-mobile','sort_hide_15','1',0,''),(173874,55513,'117443','furniture-mobile','sort_hide_3','0',0,''),(173875,55513,'117443','furniture-mobile','sort_hide_4','0',0,''),(173876,55513,'117443','furniture-mobile','sort_hide_11','1',0,''),(173877,55513,'117443','furniture-mobile','sort_hide_12','1',0,''),(173878,55513,'117443','furniture-mobile','sort_hide_14','1',0,''),(173879,55513,'117443','furniture-mobile','sort_hide_13','1',0,''),(173880,55513,'117443','furniture-mobile','sort_hide_8','0',0,''),(173881,55513,'117443','furniture-mobile','sort_hide_7','0',0,''),(173882,55513,'117443','furniture-mobile','sort_hide_2','1',0,''),(173883,55513,'117443','furniture-mobile','sort_hide_1','1',0,''),(173884,55513,'117443','furniture-mobile','sort_hide_6','1',0,''),(173885,55513,'117443','furniture-mobile','sort_hide_5','1',0,''),(173886,55513,'117443','furniture-mobile','sort_hide_0','1',0,''),(173887,55514,'117444','furniture-mobile','block_type','1',0,''),(173888,55515,'117445','furniture-mobile','margin-bottom','30',0,''),(173889,55516,'117446','furniture-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(173890,55517,'117447','furniture-mobile','block_type','1',0,''),(173891,55518,'117448','furniture-mobile','block_type','5',0,''),(173892,55518,'117448','furniture-mobile','padding-top','10',0,''),(173893,55518,'117448','furniture-mobile','padding-bottom','10',0,''),(173894,55518,'117448','furniture-mobile','schema','5-2',0,'2906'),(173895,55518,'117448','furniture-mobile','border-top-color','$border-color-4',0,''),(173896,55518,'117448','furniture-mobile','border-top-width','1',0,''),(173897,55519,'117449','furniture-mobile','padding-top','3',0,''),(173898,55520,'117450','furniture-mobile','float','right',0,''),(173899,55520,'117450','furniture-mobile','height','31',0,''),(173900,55521,'117451','furniture-mobile','col_in_row','4',0,''),(173901,55521,'117451','furniture-mobile','products_align','left',0,''),(173902,55521,'117451','furniture-mobile','font-weight','400',0,''),(173903,55521,'117451','furniture-mobile','listing_type','productListing',0,''),(173904,55521,'117451','furniture-mobile','listing_type_rows','Rows',0,''),(173905,55521,'117451','furniture-mobile','show_buy_button_b2b','on',0,''),(173906,55521,'117451','furniture-mobile','show_wishlist_button_b2b','1',0,''),(173907,55521,'117451','furniture-mobile','show_compare_b2b','1',0,''),(173908,55521,'117451','furniture-mobile','listing_type_b2b','b2b',0,''),(173909,55521,'117451','furniture-mobile','show_image','0',0,''),(173910,55521,'117451','furniture-mobile','show_stock','0',0,''),(173911,55521,'117451','furniture-mobile','show_description','0',0,''),(173912,55521,'117451','furniture-mobile','show_model','0',0,''),(173913,55521,'117451','furniture-mobile','show_properties','0',0,''),(173914,55521,'117451','furniture-mobile','show_rating','0',0,''),(173915,55521,'117451','furniture-mobile','show_rating_counts','0',0,''),(173916,55521,'117451','furniture-mobile','show_price','0',0,''),(173917,55521,'117451','furniture-mobile','show_buy_button','0',0,''),(173918,55521,'117451','furniture-mobile','show_view_button','0',0,''),(173919,55521,'117451','furniture-mobile','show_wishlist_button','0',0,''),(173920,55521,'117451','furniture-mobile','show_compare','0',0,''),(173921,55521,'117451','furniture-mobile','show_name_rows','0',0,''),(173922,55521,'117451','furniture-mobile','show_image_rows','0',0,''),(173923,55521,'117451','furniture-mobile','show_stock_rows','0',0,''),(173924,55521,'117451','furniture-mobile','show_description_rows','0',0,''),(173925,55521,'117451','furniture-mobile','show_model_rows','0',0,''),(173926,55521,'117451','furniture-mobile','show_properties_rows','0',0,''),(173927,55521,'117451','furniture-mobile','show_rating_rows','0',0,''),(173928,55521,'117451','furniture-mobile','show_rating_counts_rows','0',0,''),(173929,55521,'117451','furniture-mobile','show_price_rows','0',0,''),(173930,55521,'117451','furniture-mobile','show_buy_button_rows','0',0,''),(173931,55521,'117451','furniture-mobile','show_qty_input_rows','0',0,''),(173932,55521,'117451','furniture-mobile','show_view_button_rows','0',0,''),(173933,55521,'117451','furniture-mobile','show_wishlist_button_rows','0',0,''),(173934,55521,'117451','furniture-mobile','show_compare_rows','0',0,''),(173935,55521,'117451','furniture-mobile','show_name_b2b','0',0,''),(173936,55521,'117451','furniture-mobile','show_image_b2b','0',0,''),(173937,55521,'117451','furniture-mobile','show_stock_b2b','0',0,''),(173938,55521,'117451','furniture-mobile','show_description_b2b','0',0,''),(173939,55521,'117451','furniture-mobile','show_model_b2b','0',0,''),(173940,55521,'117451','furniture-mobile','show_properties_b2b','0',0,''),(173941,55521,'117451','furniture-mobile','show_rating_b2b','0',0,''),(173942,55521,'117451','furniture-mobile','show_rating_counts_b2b','0',0,''),(173943,55521,'117451','furniture-mobile','show_price_b2b','0',0,''),(173944,55521,'117451','furniture-mobile','show_qty_input_b2b','0',0,''),(173945,55521,'117451','furniture-mobile','show_view_button_b2b','0',0,''),(173946,55521,'117451','furniture-mobile','show_attributes_b2b','0',0,''),(173947,55521,'117451','furniture-mobile','items_on_page','12',0,''),(173948,55521,'117451','furniture-mobile','col_in_row','2',0,'2885'),(173949,55521,'117451','furniture-mobile','col_in_row','1',0,'2906'),(173950,55521,'117451','furniture-mobile','product_names_teg','h2',0,''),(173951,55524,'117454','furniture-mobile','block_type','1',0,''),(173952,55525,'117455','furniture-mobile','block_type','1',0,''),(173953,55525,'117455','furniture-mobile','padding-top','10',0,''),(173954,55525,'117455','furniture-mobile','padding-bottom','10',0,''),(173955,55525,'117455','furniture-mobile','border-bottom-width','1',0,''),(173956,55525,'117455','furniture-mobile','border-bottom-color','$border-color-4',0,''),(173957,55525,'117455','furniture-mobile','margin-left','0',0,''),(173958,55525,'117455','furniture-mobile','margin-right','0',0,''),(173959,55526,'117456','furniture-mobile','clear','none',0,''),(173960,55526,'117456','furniture-mobile','float','left',0,''),(173961,55526,'117456','furniture-mobile','padding-top','3',0,''),(173962,55526,'117456','furniture-mobile','margin-left','20',0,''),(173963,55527,'117457','furniture-mobile','float','right',0,''),(173964,55527,'117457','furniture-mobile','display','none',0,'2906'),(173965,55528,'117458','furniture-mobile','margin-right','20',0,''),(173966,55528,'117458','furniture-mobile','float','right',0,''),(173967,55528,'117458','furniture-mobile','clear','none',0,''),(173968,55528,'117458','furniture-mobile','display','none',0,'2885'),(173969,55529,'117459','furniture-mobile','float','left',0,''),(173970,55529,'117459','furniture-mobile','clear','none',0,''),(173971,55529,'117459','furniture-mobile','margin-left','20',0,''),(173972,55529,'117459','furniture-mobile','display','none',0,'2906'),(173973,55530,'117460','furniture-mobile','float','left',0,''),(173974,55530,'117460','furniture-mobile','clear','none',0,''),(173975,55530,'117460','furniture-mobile','sort_pos_3','2',0,''),(173976,55530,'117460','furniture-mobile','sort_pos_4','1',0,''),(173977,55530,'117460','furniture-mobile','sort_pos_10','5',0,''),(173978,55530,'117460','furniture-mobile','sort_pos_9','6',0,''),(173979,55530,'117460','furniture-mobile','sort_pos_11','7',0,''),(173980,55530,'117460','furniture-mobile','sort_pos_12','8',0,''),(173981,55530,'117460','furniture-mobile','sort_pos_14','9',0,''),(173982,55530,'117460','furniture-mobile','sort_pos_13','10',0,''),(173983,55530,'117460','furniture-mobile','sort_pos_8','11',0,''),(173984,55530,'117460','furniture-mobile','sort_pos_7','12',0,''),(173985,55530,'117460','furniture-mobile','sort_pos_2','13',0,''),(173986,55530,'117460','furniture-mobile','sort_pos_1','14',0,''),(173987,55530,'117460','furniture-mobile','sort_pos_6','15',0,''),(173988,55530,'117460','furniture-mobile','sort_pos_5','16',0,''),(173989,55530,'117460','furniture-mobile','sort_pos_0','17',0,''),(173990,55530,'117460','furniture-mobile','sort_hide_10','1',0,''),(173991,55530,'117460','furniture-mobile','sort_hide_9','1',0,''),(173992,55530,'117460','furniture-mobile','sort_pos_15','4',0,''),(173993,55530,'117460','furniture-mobile','sort_pos_16','3',0,''),(173994,55530,'117460','furniture-mobile','sort_hide_4','0',0,''),(173995,55530,'117460','furniture-mobile','sort_hide_3','0',0,''),(173996,55530,'117460','furniture-mobile','sort_hide_16','1',0,''),(173997,55530,'117460','furniture-mobile','sort_hide_15','1',0,''),(173998,55530,'117460','furniture-mobile','sort_hide_11','1',0,''),(173999,55530,'117460','furniture-mobile','sort_hide_12','1',0,''),(174000,55530,'117460','furniture-mobile','sort_hide_14','1',0,''),(174001,55530,'117460','furniture-mobile','sort_hide_13','1',0,''),(174002,55530,'117460','furniture-mobile','sort_hide_8','0',0,''),(174003,55530,'117460','furniture-mobile','sort_hide_7','0',0,''),(174004,55530,'117460','furniture-mobile','sort_hide_2','1',0,''),(174005,55530,'117460','furniture-mobile','sort_hide_1','1',0,''),(174006,55530,'117460','furniture-mobile','sort_hide_6','1',0,''),(174007,55530,'117460','furniture-mobile','sort_hide_5','1',0,''),(174008,55530,'117460','furniture-mobile','sort_hide_0','1',0,''),(174009,55530,'117460','furniture-mobile','hide_icons','1',0,''),(174010,55531,'117461','furniture-mobile','margin-bottom','20',0,''),(174011,55532,'117462','furniture-mobile','block_type','1',0,''),(174012,55532,'117462','furniture-mobile','style_class','account-order-history',0,''),(174013,55533,'117463','furniture-mobile','block_type','6',0,''),(174014,55533,'117463','furniture-mobile','schema','6-3',0,'2885'),(174015,55534,'117464','furniture-mobile','aria_name','account-menu',0,''),(174072,55554,'117465','furniture-mobile','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(174073,55555,'117466','furniture-mobile','link','Order History Info',0,''),(174074,55555,'117466','furniture-mobile','text','TEXT_VIEW',0,''),(174075,55555,'117466','furniture-mobile','show_pagenation','1',0,''),(174076,55555,'117466','furniture-mobile','link_pay','Order pay',0,''),(174077,55555,'117466','furniture-mobile','margin-bottom','20',0,''),(174078,55556,'117467','furniture-mobile','block_type','1',0,''),(174079,55556,'117467','furniture-mobile','style_class','account-order-history-info',0,''),(174080,55557,'117468','furniture-mobile','block_type','6',0,''),(174081,55557,'117468','furniture-mobile','schema','6-3',0,'2885'),(174082,55558,'117469','furniture-mobile','aria_name','account-menu',0,''),(174139,55578,'117470','furniture-mobile','float','right',0,''),(174140,55578,'117470','furniture-mobile','clear','none',0,''),(174141,55578,'117470','furniture-mobile','margin-left','20',0,''),(174142,55580,'117472','furniture-mobile','float','right',0,''),(174143,55580,'117472','furniture-mobile','clear','none',0,''),(174144,55580,'117472','furniture-mobile','like_button','2',0,''),(174145,55580,'117472','furniture-mobile','link','Order pay',0,''),(174146,55581,'117473','furniture-mobile','block_type','2',0,''),(174147,55581,'117473','furniture-mobile','padding-top','20',0,''),(174148,55581,'117473','furniture-mobile','margin-bottom','20',0,''),(174149,55582,'117474','furniture-mobile','like_button','1',0,''),(174150,55582,'117474','furniture-mobile','text','IMAGE_BUTTON_BACK',0,''),(174151,55582,'117474','furniture-mobile','link','Order History',0,''),(174152,55583,'117475','furniture-mobile','text-align','right',0,''),(174153,55584,'117476','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(174154,55586,'117478','furniture-mobile','float','right',0,''),(174155,55586,'117478','furniture-mobile','clear','none',0,''),(174156,55586,'117478','furniture-mobile','margin-left','20',0,''),(174157,55588,'117480','furniture-mobile','clear','both',0,''),(174158,55589,'117481','furniture-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(174159,55591,'117483','furniture-mobile','float','left',0,''),(174160,55592,'117484','furniture-mobile','block_type','3',0,''),(174161,55592,'117484','furniture-mobile','clear','both',0,''),(174162,55592,'117484','furniture-mobile','padding-top','20',0,''),(174163,55593,'117485','furniture-mobile','block_type','1',0,''),(174164,55593,'117485','furniture-mobile','margin-bottom','20',0,''),(174165,55593,'117485','furniture-mobile','padding-right','20',0,''),(174166,55594,'117486','furniture-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(174167,55595,'117487','furniture-mobile','padding-left','30',0,''),(174168,55595,'117487','furniture-mobile','orders_data','telephone',0,''),(174169,55595,'117487','furniture-mobile','hide_parents','2',0,''),(174170,55596,'117488','furniture-mobile','block_type','1',0,''),(174171,55596,'117488','furniture-mobile','padding-right','20',0,''),(174172,55596,'117488','furniture-mobile','padding-bottom','20',0,''),(174173,55597,'117489','furniture-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(174174,55598,'117490','furniture-mobile','orders_data','name',0,''),(174175,55598,'117490','furniture-mobile','padding-left','30',0,''),(174176,55599,'117491','furniture-mobile','block_type','1',0,''),(174177,55599,'117491','furniture-mobile','padding-right','20',0,''),(174178,55599,'117491','furniture-mobile','margin-bottom','20',0,''),(174179,55600,'117492','furniture-mobile','short_view','1',0,''),(174180,55600,'117492','furniture-mobile','hide_parents','2',0,''),(174181,55601,'117493','furniture-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(174182,55602,'117494','furniture-mobile','link','Tracking numbers',0,''),(174183,55602,'117494','furniture-mobile','text','MORE_TRACKING_NUMBER',0,''),(174184,55602,'117494','furniture-mobile','popup','1',0,''),(174185,55602,'117494','furniture-mobile','order_id','1',0,''),(174186,55602,'117494','furniture-mobile','popup_class','tracking-numbers-popup',0,''),(174187,55602,'117494','furniture-mobile','font-weight','700',0,''),(174188,55602,'117494','furniture-mobile','font-size','18',0,''),(174189,55603,'117495','furniture-mobile','block_type','1',0,''),(174190,55603,'117495','furniture-mobile','padding-right','20',0,''),(174191,55604,'117496','furniture-mobile','orders_data','shipping_method',0,''),(174192,55604,'117496','furniture-mobile','padding-left','30',0,''),(174193,55605,'117497','furniture-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(174194,55606,'117498','furniture-mobile','block_type','1',0,''),(174195,55606,'117498','furniture-mobile','padding-right','20',0,''),(174196,55606,'117498','furniture-mobile','padding-bottom','20',0,''),(174197,55607,'117499','furniture-mobile','orders_data','delivery_address',0,''),(174198,55607,'117499','furniture-mobile','padding-left','30',0,''),(174199,55608,'117500','furniture-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(174200,55609,'117501','furniture-mobile','block_type','1',0,''),(174201,55610,'117502','furniture-mobile','orders_data','payment_method',0,''),(174202,55610,'117502','furniture-mobile','padding-left','30',0,''),(174203,55611,'117503','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(174204,55612,'117504','furniture-mobile','block_type','1',0,''),(174205,55612,'117504','furniture-mobile','padding-bottom','20',0,''),(174206,55613,'117505','furniture-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(174207,55614,'117506','furniture-mobile','orders_data','billing_address',0,''),(174208,55614,'117506','furniture-mobile','padding-left','30',0,''),(174209,55615,'117507','furniture-mobile','block_type','1',0,''),(174210,55615,'117507','furniture-mobile','style_class','account-order-pay',0,''),(174211,55616,'117508','furniture-mobile','block_type','6',0,''),(174212,55616,'117508','furniture-mobile','schema','6-3',0,'2885'),(174213,55617,'117509','furniture-mobile','aria_name','account-menu',0,''),(174270,55638,'117511','furniture-mobile','block_type','3',0,''),(174271,55639,'117512','furniture-mobile','block_type','1',0,''),(174272,55639,'117512','furniture-mobile','padding-right','20',0,''),(174273,55639,'117512','furniture-mobile','padding-bottom','20',0,''),(174274,55640,'117513','furniture-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(174275,55641,'117514','furniture-mobile','orders_data','name',0,''),(174276,55641,'117514','furniture-mobile','padding-left','30',0,''),(174277,55642,'117515','furniture-mobile','block_type','1',0,''),(174278,55643,'117516','furniture-mobile','padding-left','30',0,''),(174279,55644,'117517','furniture-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(174280,55645,'117518','furniture-mobile','block_type','1',0,''),(174281,55645,'117518','furniture-mobile','padding-right','20',0,''),(174282,55645,'117518','furniture-mobile','padding-bottom','20',0,''),(174283,55646,'117519','furniture-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(174284,55647,'117520','furniture-mobile','orders_data','delivery_address',0,''),(174285,55647,'117520','furniture-mobile','padding-left','30',0,''),(174286,55648,'117521','furniture-mobile','block_type','1',0,''),(174287,55648,'117521','furniture-mobile','padding-right','20',0,''),(174288,55649,'117522','furniture-mobile','orders_data','shipping_method',0,''),(174289,55649,'117522','furniture-mobile','padding-left','30',0,''),(174290,55650,'117523','furniture-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(174291,55651,'117524','furniture-mobile','block_type','1',0,''),(174292,55652,'117525','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(174293,55653,'117526','furniture-mobile','orders_data','payment_method',0,''),(174294,55653,'117526','furniture-mobile','padding-left','30',0,''),(174295,55654,'117527','furniture-mobile','block_type','1',0,''),(174296,55654,'117527','furniture-mobile','padding-bottom','20',0,''),(174297,55655,'117528','furniture-mobile','orders_data','billing_address',0,''),(174298,55655,'117528','furniture-mobile','padding-left','30',0,''),(174299,55656,'117529','furniture-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(174300,55657,'117530','furniture-mobile','margin-bottom','20',0,''),(174301,55657,'117530','furniture-mobile','orders_data','name',0,''),(174302,55658,'117531','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(174303,55661,'117534','furniture-mobile','width','680',0,''),(174304,55661,'117534','furniture-mobile','font-weight','400',0,''),(174305,55661,'117534','furniture-mobile','font-size','12',0,''),(174306,55661,'117534','furniture-mobile','padding-top','20',0,''),(174307,55661,'117534','furniture-mobile','padding-bottom','20',0,''),(174308,55662,'117535','furniture-mobile','block_type','2',0,''),(174309,55662,'117535','furniture-mobile','font-weight','normal',0,''),(174310,55662,'117535','furniture-mobile','padding-bottom','20',0,''),(174311,55663,'117536','furniture-mobile','font-weight','400',0,''),(174312,55663,'117536','furniture-mobile','text-align','center',0,''),(174313,55663,'117536','furniture-mobile','padding-top','10',0,''),(174314,55663,'117536','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',1,''),(174315,55664,'117537','furniture-mobile','block_type','11',0,''),(174316,55664,'117537','furniture-mobile','font-weight','normal',0,''),(174317,55665,'117538','furniture-mobile','text','<p>Email:</p>',1,''),(174318,55665,'117538','furniture-mobile','font-weight','normal',0,''),(174319,55665,'117538','furniture-mobile','text-align','right',0,''),(174320,55666,'117539','furniture-mobile','font-weight','normal',0,''),(174321,55666,'117539','furniture-mobile','text-align','right',0,''),(174322,55667,'117540','furniture-mobile','block_type','11',0,''),(174323,55667,'117540','furniture-mobile','font-weight','normal',0,''),(174324,55668,'117541','furniture-mobile','text','<p>Phone:</p>',1,''),(174325,55668,'117541','furniture-mobile','font-weight','normal',0,''),(174326,55668,'117541','furniture-mobile','text-align','right',0,''),(174327,55669,'117542','furniture-mobile','font-weight','normal',0,''),(174328,55669,'117542','furniture-mobile','text-align','right',0,''),(174329,55670,'117543','furniture-mobile','block_type','1',0,''),(174330,55671,'117544','furniture-mobile','font-weight','400',0,''),(174331,55671,'117544','furniture-mobile','text-align','right',0,''),(174332,55671,'117544','furniture-mobile','padding-bottom','10',0,''),(174333,55671,'117544','furniture-mobile','address_spacer',',',0,''),(174334,55671,'117544','furniture-mobile','font-size','12',0,''),(174335,55672,'117545','furniture-mobile','block_type','11',0,''),(174336,55672,'117545','furniture-mobile','font-weight','400',0,''),(174337,55673,'117546','furniture-mobile','text','<p>Web:</p>',1,''),(174338,55673,'117546','furniture-mobile','font-weight','400',0,''),(174339,55673,'117546','furniture-mobile','text-align','right',0,''),(174340,55674,'117547','furniture-mobile','font-weight','normal',0,''),(174341,55674,'117547','furniture-mobile','text-align','right',0,''),(174342,55675,'117548','furniture-mobile','font-weight','normal',0,''),(174343,55675,'117548','furniture-mobile','padding-top','20',0,''),(174344,55675,'117548','furniture-mobile','font-size','12',0,''),(174345,55676,'117549','furniture-mobile','block_type','1',0,''),(174346,55676,'117549','furniture-mobile','font-weight','normal',0,''),(174347,55676,'117549','furniture-mobile','padding-top','10',0,''),(174348,55676,'117549','furniture-mobile','padding-bottom','10',0,''),(174349,55678,'117551','furniture-mobile','text','<p>If undelivered please return to:</p>',1,''),(174350,55678,'117551','furniture-mobile','font-weight','bold',0,''),(174351,55679,'117552','furniture-mobile','block_type','4',0,''),(174352,55679,'117552','furniture-mobile','font-weight','400',0,''),(174353,55679,'117552','furniture-mobile','border-top-width','1',0,''),(174354,55679,'117552','furniture-mobile','border-top-color','$border-color-4',0,''),(174355,55679,'117552','furniture-mobile','border-left-width','1',0,''),(174356,55679,'117552','furniture-mobile','border-left-color','$border-color-4',0,''),(174357,55679,'117552','furniture-mobile','border-right-width','1',0,''),(174358,55679,'117552','furniture-mobile','border-right-color','$border-color-4',0,''),(174359,55679,'117552','furniture-mobile','border-bottom-width','1',0,''),(174360,55679,'117552','furniture-mobile','border-bottom-color','$border-color-4',0,''),(174361,55680,'117553','furniture-mobile','block_type','2',0,''),(174362,55680,'117553','furniture-mobile','font-weight','normal',0,''),(174363,55680,'117553','furniture-mobile','border-right-width','1',0,''),(174364,55680,'117553','furniture-mobile','border-right-color','$border-color-4',0,''),(174365,55681,'117554','furniture-mobile','block_type','1',0,''),(174366,55681,'117554','furniture-mobile','font-weight','normal',0,''),(174367,55681,'117554','furniture-mobile','border-right-width','1',0,''),(174368,55681,'117554','furniture-mobile','border-right-color','$border-color-4',0,''),(174369,55681,'117554','furniture-mobile','background-color','$background-6',0,''),(174370,55681,'117554','furniture-mobile','padding-top','10',0,''),(174371,55681,'117554','furniture-mobile','padding-left','10',0,''),(174372,55681,'117554','furniture-mobile','padding-right','10',0,''),(174373,55681,'117554','furniture-mobile','padding-bottom','10',0,''),(174374,55682,'117555','furniture-mobile','font-size','12',0,''),(174375,55682,'117555','furniture-mobile','font-weight','normal',0,''),(174376,55683,'117556','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(174377,55683,'117556','furniture-mobile','font-size','13',0,''),(174378,55683,'117556','furniture-mobile','font-weight','bold',0,''),(174379,55683,'117556','furniture-mobile','padding-bottom','10',0,''),(174380,55684,'117557','furniture-mobile','block_type','1',0,''),(174381,55684,'117557','furniture-mobile','font-weight','normal',0,''),(174382,55684,'117557','furniture-mobile','padding-top','10',0,''),(174383,55684,'117557','furniture-mobile','padding-left','10',0,''),(174384,55684,'117557','furniture-mobile','padding-right','10',0,''),(174385,55684,'117557','furniture-mobile','padding-bottom','10',0,''),(174386,55685,'117558','furniture-mobile','text','<p>CUSTOMER:</p>',1,''),(174387,55685,'117558','furniture-mobile','font-size','13',0,''),(174388,55685,'117558','furniture-mobile','font-weight','bold',0,''),(174389,55686,'117559','furniture-mobile','font-size','12',0,''),(174390,55688,'117561','furniture-mobile','text','<p>PHONE NUMBER:</p>',1,''),(174391,55688,'117561','furniture-mobile','font-size','13',0,''),(174392,55688,'117561','furniture-mobile','font-weight','bold',0,''),(174393,55688,'117561','furniture-mobile','padding-top','10',0,''),(174394,55689,'117562','furniture-mobile','font-size','12',0,''),(174395,55690,'117563','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(174396,55690,'117563','furniture-mobile','font-size','13',0,''),(174397,55690,'117563','furniture-mobile','font-weight','bold',0,''),(174398,55690,'117563','furniture-mobile','padding-top','10',0,''),(174399,55691,'117564','furniture-mobile','block_type','2',0,''),(174400,55691,'117564','furniture-mobile','font-weight','normal',0,''),(174401,55691,'117564','furniture-mobile','border-right-width','1',0,''),(174402,55691,'117564','furniture-mobile','border-right-color','$border-color-4',0,''),(174403,55691,'117564','furniture-mobile','border-top-width','1',0,''),(174404,55691,'117564','furniture-mobile','border-top-color','$border-color-4',0,''),(174405,55692,'117565','furniture-mobile','block_type','1',0,''),(174406,55692,'117565','furniture-mobile','font-weight','normal',0,''),(174407,55692,'117565','furniture-mobile','padding-top','10',0,''),(174408,55692,'117565','furniture-mobile','padding-left','10',0,''),(174409,55692,'117565','furniture-mobile','padding-right','10',0,''),(174410,55692,'117565','furniture-mobile','padding-bottom','10',0,''),(174411,55692,'117565','furniture-mobile','border-right-width','1',0,''),(174412,55692,'117565','furniture-mobile','border-right-color','$border-color-4',0,''),(174413,55694,'117567','furniture-mobile','text','<p>Shipping via</p>',1,''),(174414,55694,'117567','furniture-mobile','font-weight','bold',0,''),(174415,55695,'117568','furniture-mobile','block_type','1',0,''),(174416,55695,'117568','furniture-mobile','font-weight','normal',0,''),(174417,55695,'117568','furniture-mobile','padding-top','10',0,''),(174418,55695,'117568','furniture-mobile','padding-left','10',0,''),(174419,55695,'117568','furniture-mobile','padding-right','10',0,''),(174420,55695,'117568','furniture-mobile','padding-bottom','10',0,''),(174421,55697,'117570','furniture-mobile','text','<p>Shipping service</p>',1,''),(174422,55697,'117570','furniture-mobile','font-weight','bold',0,''),(174423,55698,'117571','furniture-mobile','font-weight','normal',0,''),(174424,55698,'117571','furniture-mobile','text-align','center',0,''),(174425,55698,'117571','furniture-mobile','padding-top','40',0,''),(174426,55700,'1639661081.5616','furniture-mobile','padding-top','15',0,''),(174427,55701,'117572','furniture-mobile','block_type','1',0,''),(174428,55702,'117573','furniture-mobile','block_type','8',0,''),(174429,55703,'1638807246.6206','furniture-mobile','text','<span></span>',0,''),(174430,55704,'117574','furniture-mobile','text','##TEXT_MAIN##',0,''),(174431,55704,'117574','furniture-mobile','margin-bottom','20',0,''),(174432,55704,'117574','furniture-mobile','text-align','center',0,''),(174433,55705,'117575','furniture-mobile','margin-bottom','20',0,''),(174434,55706,'117576','furniture-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(174435,55708,'117578','furniture-mobile','block_type','2',0,''),(174436,55709,'117579','furniture-mobile','block_type','1',0,''),(174437,55709,'117579','furniture-mobile','style_class','product',0,''),(174438,55709,'117579','furniture-mobile','padding-right','10',0,''),(174439,55709,'117579','furniture-mobile','padding-bottom','20',0,''),(174440,55710,'117580','furniture-mobile','block_type','1',0,''),(174441,55711,'117581','furniture-mobile','product_element','products_name',0,''),(174442,55711,'117581','furniture-mobile','font-family','$font-1',0,''),(174443,55711,'117581','furniture-mobile','padding-bottom','10',0,''),(174444,55711,'117581','furniture-mobile','font-size','16',0,''),(174445,55712,'117582','furniture-mobile','block_type','2',0,''),(174446,55713,'117583','furniture-mobile','product_element','image',0,''),(174447,55713,'117583','furniture-mobile','padding-right','10',0,''),(174448,55714,'117584','furniture-mobile','product_element','products_price_old',0,''),(174449,55714,'117584','furniture-mobile','font-family','$font-1',0,''),(174450,55714,'117584','furniture-mobile','font-size','14',0,''),(174451,55714,'117584','furniture-mobile','text-decoration','line-through',0,''),(174452,55715,'117585','furniture-mobile','product_element','products_price',0,''),(174453,55715,'117585','furniture-mobile','font-family','$font-1',0,''),(174454,55715,'117585','furniture-mobile','font-size','20',0,''),(174455,55715,'117585','furniture-mobile','padding-top','20',0,''),(174456,55716,'117586','furniture-mobile','block_type','1',0,''),(174457,55716,'117586','furniture-mobile','style_class','product',0,''),(174458,55716,'117586','furniture-mobile','padding-left','10',0,''),(174459,55716,'117586','furniture-mobile','padding-bottom','20',0,''),(174460,55717,'117587','furniture-mobile','block_type','2',0,''),(174461,55718,'117588','furniture-mobile','product_element','image',0,''),(174462,55718,'117588','furniture-mobile','padding-right','10',0,''),(174463,55719,'117589','furniture-mobile','font-size','14',0,''),(174464,55719,'117589','furniture-mobile','font-family','$font-1',0,''),(174465,55719,'117589','furniture-mobile','text-decoration','line-through',0,''),(174466,55719,'117589','furniture-mobile','product_element','products_price_old',0,''),(174467,55720,'117590','furniture-mobile','product_element','products_price',0,''),(174468,55720,'117590','furniture-mobile','font-family','$font-1',0,''),(174469,55720,'117590','furniture-mobile','font-size','20',0,''),(174470,55720,'117590','furniture-mobile','padding-top','20',0,''),(174471,55721,'117591','furniture-mobile','block_type','1',0,''),(174472,55722,'117592','furniture-mobile','product_element','products_name',0,''),(174473,55722,'117592','furniture-mobile','font-family','$font-1',0,''),(174474,55722,'117592','furniture-mobile','font-size','16',0,''),(174475,55722,'117592','furniture-mobile','padding-bottom','10',0,''),(174476,55723,'117593','furniture-mobile','font-size','30',0,''),(174477,55723,'117593','furniture-mobile','font-family','$font-1',0,''),(174478,55723,'117593','furniture-mobile','text-align','center',0,''),(174479,55723,'117593','furniture-mobile','padding-bottom','50',0,''),(174480,55724,'117594','furniture-mobile','padding-bottom','20',0,''),(174481,55724,'117594','furniture-mobile','text-align','center',0,''),(174482,55725,'117595','furniture-mobile','width','680',0,''),(174483,55726,'117596','furniture-mobile','padding-top','200',0,''),(174484,55726,'117596','furniture-mobile','padding-left','200',0,''),(174485,55726,'117596','furniture-mobile','logo','themes/furniture-mobile/img/oscommerce_logo-1.jpg',1,''),(174486,55727,'117597','furniture-mobile','text','osCommerce 4',1,''),(174487,55727,'117597','furniture-mobile','font-family','$font-1',0,''),(174488,55727,'117597','furniture-mobile','font-size','40',0,''),(174489,55727,'117597','furniture-mobile','padding-top','50',0,''),(174490,55727,'117597','furniture-mobile','text-align','center',0,''),(174491,55728,'117598','furniture-mobile','block_type','2',0,''),(174492,55728,'117598','furniture-mobile','border-top-width','1',0,''),(174493,55728,'117598','furniture-mobile','border-top-color','$border-color-4',0,''),(174494,55729,'117599','furniture-mobile','text-align','right',0,''),(174495,55729,'117599','furniture-mobile','padding-top','15',0,''),(174496,55729,'117599','furniture-mobile','padding-bottom','15',0,''),(174497,55729,'117599','furniture-mobile','font-size','14',0,''),(174498,55730,'117600','furniture-mobile','font-family','$font-1',0,''),(174499,55730,'117600','furniture-mobile','text-align','center',0,''),(174500,55730,'117600','furniture-mobile','font-size','20',0,''),(174501,55730,'117600','furniture-mobile','color','$color-font-7',0,''),(174502,55730,'117600','furniture-mobile','border-bottom-width','1',0,''),(174503,55730,'117600','furniture-mobile','border-bottom-color','$border-color-4',0,''),(174504,55730,'117600','furniture-mobile','padding-top','10',0,''),(174505,55730,'117600','furniture-mobile','padding-bottom','10',0,''),(174506,55731,'117601','furniture-mobile','block_type','1',0,''),(174507,55732,'117602','furniture-mobile','block_type','6',0,''),(174508,55732,'117602','furniture-mobile','schema','6-3',0,'2885'),(174509,55733,'117603','furniture-mobile','aria_name','account-menu',0,''),(174566,55753,'117604','furniture-mobile','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(174567,55754,'117606','furniture-mobile','max_items','10',0,''),(174568,55754,'117606','furniture-mobile','padding-bottom','20',0,''),(174569,55755,'117607','furniture-mobile','block_type','1',0,''),(174570,55755,'117607','furniture-mobile','padding-top','20',0,''),(174571,55755,'117607','furniture-mobile','padding-left','20',0,''),(174572,55755,'117607','furniture-mobile','padding-right','20',0,''),(174573,55755,'117607','furniture-mobile','padding-bottom','20',0,''),(174574,55756,'117608','furniture-mobile','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(174575,55758,'117610','furniture-mobile','block_type','1',0,''),(174576,55759,'117611','furniture-mobile','margin_left_measure','auto',0,''),(174577,55759,'117611','furniture-mobile','margin_right_measure','auto',0,''),(174578,55759,'117611','furniture-mobile','max-width','560',0,''),(174579,55760,'117612','furniture-mobile','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(174580,55761,'117613','furniture-mobile','margin-bottom','30',0,''),(174581,55762,'117614','furniture-mobile','block_type','1',0,''),(174582,55762,'117614','furniture-mobile','padding-top','25',0,''),(174583,55762,'117614','furniture-mobile','padding-bottom','25',0,''),(174584,55762,'117614','furniture-mobile','style_class','catalog-product-wrap',0,''),(174585,55763,'120997','furniture-mobile','block_type','1',0,''),(174586,55764,'117646','furniture-mobile','tab_1','Product Overview',1,''),(174587,55764,'117646','furniture-mobile','tab_2','Delivery and returns',1,''),(174588,55764,'117646','furniture-mobile','font-weight','400',0,''),(174589,55764,'117646','furniture-mobile','tab_3','Assembly',1,''),(174590,55765,'117647','furniture-mobile','hTagsInline','block',0,''),(174591,55766,'117648','furniture-mobile','margin-bottom','20',0,''),(174592,55766,'117648','furniture-mobile','max-width','500',0,''),(174593,55767,'121011','furniture-mobile','text','<span></span>',0,''),(174594,55769,'117654','furniture-mobile','font-weight','normal',0,''),(174595,55769,'117654','furniture-mobile','padding-bottom','20',0,''),(174596,55769,'117654','furniture-mobile','show_compare','1',0,''),(174597,55769,'117654','furniture-mobile','show_cart_button','1',0,''),(174598,55769,'117654','furniture-mobile','listing_type','productListing',0,''),(174599,55769,'117654','furniture-mobile','col_in_row','4',0,''),(174600,55769,'117654','furniture-mobile','view_as','carousel',0,''),(174601,55770,'121002','furniture-mobile','tab_1','Customer also bought',0,''),(174602,55770,'121002','furniture-mobile','tab_2','You recently viewed',0,''),(174603,55770,'121002','furniture-mobile','margin-bottom','20',0,''),(174604,55771,'117645','furniture-mobile','font-weight','400',0,''),(174605,55771,'117645','furniture-mobile','padding-bottom','20',0,''),(174606,55771,'117645','furniture-mobile','show_qty_input','1',0,''),(174607,55771,'117645','furniture-mobile','show_compare','1',0,''),(174608,55771,'117645','furniture-mobile','listing_type','productListing',0,''),(174609,55771,'117645','furniture-mobile','view_as','carousel',0,''),(174610,55771,'117645','furniture-mobile','show_name','0',0,''),(174611,55771,'117645','furniture-mobile','show_image','0',0,''),(174612,55771,'117645','furniture-mobile','show_stock','0',0,''),(174613,55771,'117645','furniture-mobile','show_description','0',0,''),(174614,55771,'117645','furniture-mobile','show_model','1',0,''),(174615,55771,'117645','furniture-mobile','show_properties','1',0,''),(174616,55771,'117645','furniture-mobile','show_rating','0',0,''),(174617,55771,'117645','furniture-mobile','show_rating_counts','0',0,''),(174618,55771,'117645','furniture-mobile','show_price','0',0,''),(174619,55771,'117645','furniture-mobile','show_buy_button','1',0,''),(174620,55771,'117645','furniture-mobile','show_view_button','1',0,''),(174621,55771,'117645','furniture-mobile','show_wishlist_button','1',0,''),(174622,55771,'117645','furniture-mobile','display','none',0,'2885'),(174623,55771,'117645','furniture-mobile','product_names_teg','h2',0,''),(174624,55771,'117645','furniture-mobile','show_attributes','1',0,''),(174625,55771,'117645','furniture-mobile','col_in_row','4',0,''),(174626,55771,'117645','furniture-mobile','show_bonus_points','1',0,''),(174627,55772,'117641','furniture-mobile','font-weight','400',0,''),(174628,55772,'117641','furniture-mobile','padding-bottom','20',0,''),(174629,55772,'117641','furniture-mobile','show_compare','1',0,''),(174630,55772,'117641','furniture-mobile','show_name','0',0,''),(174631,55772,'117641','furniture-mobile','show_image','0',0,''),(174632,55772,'117641','furniture-mobile','show_stock','0',0,''),(174633,55772,'117641','furniture-mobile','show_description','0',0,''),(174634,55772,'117641','furniture-mobile','show_model','1',0,''),(174635,55772,'117641','furniture-mobile','show_properties','1',0,''),(174636,55772,'117641','furniture-mobile','show_rating','0',0,''),(174637,55772,'117641','furniture-mobile','show_rating_counts','0',0,''),(174638,55772,'117641','furniture-mobile','show_price','0',0,''),(174639,55772,'117641','furniture-mobile','show_buy_button','1',0,''),(174640,55772,'117641','furniture-mobile','show_view_button','1',0,''),(174641,55772,'117641','furniture-mobile','show_wishlist_button','1',0,''),(174642,55772,'117641','furniture-mobile','listing_type','productListing',0,''),(174643,55772,'117641','furniture-mobile','col_in_row','2',0,'2885'),(174644,55772,'117641','furniture-mobile','col_in_row','1',0,'2906'),(174645,55772,'117641','furniture-mobile','col_in_row','4',0,''),(174646,55772,'117641','furniture-mobile','view_as','carousel',0,''),(174647,55772,'117641','furniture-mobile','show_bonus_points','1',0,''),(174648,55772,'117641','furniture-mobile','show_qty_input','1',0,''),(174649,55772,'117641','furniture-mobile','show_attributes','1',0,''),(174650,55773,'121004','furniture-mobile','block_type','3',0,''),(174651,55773,'121004','furniture-mobile','style_class','tripleBanner',0,''),(174652,55774,'121005','furniture-mobile','text','<div>Returns and Exchanges</div>\n<div>30 Day Satisfaction Guarantee</div>\n',0,''),(174653,55774,'121005','furniture-mobile','style_class','returns',0,''),(174654,55775,'121006','furniture-mobile','text','<div>Warranty</div>\n<div>Min 12 months manufacturer’s warranty</div>',0,''),(174655,55775,'121006','furniture-mobile','style_class','warranty',0,''),(174656,55776,'121007','furniture-mobile','text','<div>Track your order</div>\n<div>Check the current status of your order</div>',0,''),(174657,55776,'121007','furniture-mobile','style_class','track',0,''),(174658,55777,'121010','furniture-mobile','block_type','1',0,''),(174659,55778,'117649','furniture-mobile','padding-bottom','10',0,''),(174660,55778,'117649','furniture-mobile','padding-top','5',0,''),(174661,55779,'1639053401.678','furniture-mobile','block_type','1',0,''),(174662,55780,'117616','furniture-mobile','block_type','2',0,''),(174663,55780,'117616','furniture-mobile','font-weight','400',0,''),(174664,55780,'117616','furniture-mobile','padding-bottom','20',0,''),(174665,55780,'117616','furniture-mobile','schema','2-2',0,'2906'),(174666,55780,'117616','furniture-mobile','schema','2-2',0,'2885'),(174667,55781,'117618','furniture-mobile','font-weight','400',0,''),(174668,55781,'117618','furniture-mobile','padding-top','20',0,''),(174669,55781,'117618','furniture-mobile','padding-right','20',0,''),(174670,55781,'117618','furniture-mobile','box_align','4',0,''),(174671,55781,'117618','furniture-mobile','margin-bottom','50',0,''),(174672,55781,'117618','furniture-mobile','align_position','horizontal',0,''),(174673,55782,'117620','furniture-mobile','float','left',0,''),(174674,55783,'1638463239.7427','furniture-mobile','padding-right','20',0,''),(174675,55783,'1638463239.7427','furniture-mobile','margin-bottom','20',0,''),(174676,55784,'1639416584.6039','furniture-mobile','padding-bottom','20',0,''),(174677,55788,'120988','furniture-mobile','block_type','2',0,''),(174678,55788,'120988','furniture-mobile','schema','2-2',0,'2890'),(174679,55789,'121009','furniture-mobile','block_type','1',0,''),(174680,55789,'121009','furniture-mobile','padding-right','9',0,''),(174681,55789,'121009','furniture-mobile','padding-right','0',0,'2890'),(174682,55790,'117629','furniture-mobile','cat_description','on',0,''),(174683,55790,'117629','furniture-mobile','length_description','250',0,''),(174684,55790,'117629','furniture-mobile','padding-bottom','7',0,''),(174685,55790,'117629','furniture-mobile','link_description','1',0,''),(174686,55790,'117629','furniture-mobile','border-bottom-width','1',0,''),(174687,55790,'117629','furniture-mobile','border-bottom-color','$border-color-3',0,''),(174688,55791,'117638','furniture-mobile','margin-bottom','7',0,''),(174689,55791,'117638','furniture-mobile','border-bottom-width','1',0,''),(174690,55791,'117638','furniture-mobile','border-bottom-color','$border-color-3',0,''),(174691,55792,'121016','furniture-mobile','text','<div class=\"warranty\">\n <div class=\"title\">##TITLE_WARRANTY_PRODUCT##</div>\n <div class=\"seeDetails\"><a href=\"warranty\">##TITLE_SEE_DETAILS_PRODUCT##</a></div>\n</div>\n<div class=\"delivery\">\n <div class=\"title\">##TITLE_DELIVERY_PRODUCT##</div>\n <div class=\"seeDetails\"><a href=\"shipping\">##TITLE_SEE_DETAILS_PRODUCT##</a></div>\n</div>',0,''),(174692,55792,'121016','furniture-mobile','style_class','warrantyProduct',0,''),(174693,55792,'121016','furniture-mobile','margin-bottom','20',0,''),(174694,55795,'121008','furniture-mobile','block_type','1',0,''),(174695,55795,'121008','furniture-mobile','padding-left','9',0,''),(174696,55795,'121008','furniture-mobile','margin-top','20',0,'2890'),(174697,55795,'121008','furniture-mobile','padding-left','0',0,'2890'),(174698,55796,'120991','furniture-mobile','block_type','1',0,''),(174699,55796,'120991','furniture-mobile','style_class','productNavigation',0,''),(174700,55796,'120991','furniture-mobile','border-top-width','1',0,''),(174701,55796,'120991','furniture-mobile','border-left-width','1',0,''),(174702,55796,'120991','furniture-mobile','border-right-width','1',0,''),(174703,55796,'120991','furniture-mobile','border-bottom-width','1',0,''),(174704,55796,'120991','furniture-mobile','border-top-color','$border-color-3',0,''),(174705,55796,'120991','furniture-mobile','border-left-color','$border-color-3',0,''),(174706,55796,'120991','furniture-mobile','border-right-color','$border-color-3',0,''),(174707,55796,'120991','furniture-mobile','border-bottom-color','$border-color-3',0,''),(174708,55797,'120989','furniture-mobile','padding-top','15',0,''),(174709,55797,'120989','furniture-mobile','padding-left','20',0,''),(174710,55797,'120989','furniture-mobile','padding-right','20',0,''),(174711,55797,'120989','furniture-mobile','padding-bottom','20',0,''),(174712,55797,'120989','furniture-mobile','border-bottom-width','1',0,''),(174713,55797,'120989','furniture-mobile','border-bottom-color','$border-color-3',0,''),(174714,55798,'120990','furniture-mobile','block_type','1',0,''),(174715,55798,'120990','furniture-mobile','padding-top','20',0,''),(174716,55798,'120990','furniture-mobile','padding-left','20',0,''),(174717,55798,'120990','furniture-mobile','padding-right','20',0,''),(174718,55798,'120990','furniture-mobile','padding-bottom','20',0,''),(174719,55799,'117622','furniture-mobile','text-align','center',0,''),(174720,55799,'117622','furniture-mobile','padding-bottom','10',0,''),(174721,55799,'117622','furniture-mobile','border-bottom-color','$border-color-3',0,''),(174722,55799,'117622','furniture-mobile','border-bottom-width','1',0,''),(174723,55799,'117622','furniture-mobile','margin-bottom','10',0,''),(174724,55799,'117622','furniture-mobile','padding-top','10',0,''),(174725,55799,'117622','furniture-mobile','margin-top','10',0,''),(174726,55799,'117622','furniture-mobile','border-top-color','$border-color-3',0,''),(174727,55799,'117622','furniture-mobile','border-top-width','1',0,''),(174728,55800,'117624','furniture-mobile','font-size','38',0,''),(174729,55800,'117624','furniture-mobile','font-weight','400',0,''),(174730,55800,'117624','furniture-mobile','line-height','35',0,''),(174731,55800,'117624','furniture-mobile','font-family','$font-1',0,''),(174732,55800,'117624','furniture-mobile','line_height_measure','px',0,''),(174733,55800,'117624','furniture-mobile','padding-top','5',0,''),(174734,55800,'117624','furniture-mobile','text-align','center',0,''),(174735,55800,'117624','furniture-mobile','padding-bottom','15',0,''),(174736,55801,'117625','furniture-mobile','box_align','2',0,''),(174737,55801,'117625','furniture-mobile','margin-bottom','15',0,'2885'),(174738,55801,'117625','furniture-mobile','text-align','right',0,'2885'),(174739,55801,'117625','furniture-mobile','padding-top','5',0,''),(174740,55801,'117625','furniture-mobile','text-align','center',0,''),(174741,55801,'117625','furniture-mobile','margin-bottom','25',0,''),(174742,55802,'117627','furniture-mobile','text-align','center',0,''),(174743,55802,'117627','furniture-mobile','width','100',0,'2876'),(174744,55802,'117627','furniture-mobile','width_measure','%',0,'2876'),(174745,55802,'117627','furniture-mobile','float','none',0,'2876'),(174746,55802,'117627','furniture-mobile','hide_additional_buttons','1',0,''),(174747,55802,'117627','furniture-mobile','margin-bottom','15',0,''),(174748,55803,'117628','furniture-mobile','text-align','center',0,''),(174749,55804,'117635','furniture-mobile','text-align','center',0,''),(174750,55805,'117640','furniture-mobile','text-align','center',0,''),(174751,55806,'1642500303.417','furniture-mobile','margin-bottom','10',0,''),(174752,55807,'1639582674.022','furniture-mobile','block_type','2',0,''),(174753,55808,'117626','furniture-mobile','margin-bottom','15',0,''),(174754,55808,'117626','furniture-mobile','padding-top','15',0,''),(174755,55809,'117639','furniture-mobile','font-weight','400',0,''),(174756,55810,'117644','furniture-mobile','font-weight','normal',0,''),(174757,55810,'117644','furniture-mobile','padding-top','10',0,''),(174758,55810,'117644','furniture-mobile','padding-bottom','10',0,''),(174759,55810,'117644','furniture-mobile','box_align','4',0,''),(174760,55811,'120996','furniture-mobile','block_type','1',0,''),(174761,55812,'117651','furniture-mobile','font-weight','normal',0,''),(174762,55812,'117651','furniture-mobile','padding-bottom','20',0,''),(174763,55814,'120998','furniture-mobile','block_type','1',0,''),(174764,55814,'120998','furniture-mobile','padding-bottom','30',0,''),(174765,55815,'121000','furniture-mobile','reviews_count','right',0,''),(174766,55815,'121000','furniture-mobile','display','inline-block',0,''),(174767,55815,'121000','furniture-mobile','padding-right','12',0,''),(174768,55815,'121000','furniture-mobile','border-right-width','1',0,''),(174769,55815,'121000','furniture-mobile','border-right-color','$border-color-6',0,''),(174770,55815,'121000','furniture-mobile','line-height','1',0,''),(174771,55816,'121001','furniture-mobile','text','##TEXT_WRITE_REVIEW##',0,''),(174772,55816,'121001','furniture-mobile','style_class','writeReview',0,''),(174773,55816,'121001','furniture-mobile','display','inline-block',0,''),(174774,55816,'121001','furniture-mobile','padding-left','12',0,''),(174775,55816,'121001','furniture-mobile','line-height','1',0,''),(174776,55816,'121001','furniture-mobile','font-size','14',0,''),(174777,55817,'1639053523.9657','furniture-mobile','block_type','1',0,''),(174778,55817,'1639053523.9657','furniture-mobile','background-color','$background-6',0,''),(174779,55817,'1639053523.9657','furniture-mobile','padding-top','25',0,''),(174780,55817,'1639053523.9657','furniture-mobile','padding-bottom','25',0,''),(174781,55818,'1638963486.2331','furniture-mobile','background-color','$background-7',0,''),(174782,55818,'1638963486.2331','furniture-mobile','padding-top','20',0,''),(174783,55818,'1638963486.2331','furniture-mobile','padding-left','20',0,''),(174784,55818,'1638963486.2331','furniture-mobile','padding-right','20',0,''),(174785,55818,'1638963486.2331','furniture-mobile','padding-bottom','20',0,''),(174786,55819,'1639149261.0383','furniture-mobile','padding-top','20',0,''),(174787,55819,'1639149261.0383','furniture-mobile','padding-bottom','20',0,''),(174788,55819,'1639149261.0383','furniture-mobile','padding-left','20',0,''),(174789,55819,'1639149261.0383','furniture-mobile','padding-right','20',0,''),(174790,55819,'1639149261.0383','furniture-mobile','background-color','$background-7',0,''),(174791,55820,'1639659357.0881','furniture-mobile','block_type','1',0,''),(174792,55820,'1639659357.0881','furniture-mobile','background-color','$background-7',0,''),(174793,55820,'1639659357.0881','furniture-mobile','padding-top','20',0,''),(174794,55820,'1639659357.0881','furniture-mobile','padding-left','20',0,''),(174795,55820,'1639659357.0881','furniture-mobile','padding-right','20',0,''),(174796,55820,'1639659357.0881','furniture-mobile','padding-bottom','20',0,''),(174797,55820,'1639659357.0881','furniture-mobile','margin-bottom','20',0,''),(174798,55821,'1639659044.5523','furniture-mobile','count_products','4',0,''),(174799,55821,'1639659044.5523','furniture-mobile','view_as','carousel',0,''),(174800,55821,'1639659044.5523','furniture-mobile','col_in_row','4',0,''),(174801,55821,'1639659044.5523','furniture-mobile','listing_type','productListing',0,''),(174802,55821,'1639659044.5523','furniture-mobile','col_in_row','3',0,'2885'),(174803,55821,'1639659044.5523','furniture-mobile','col_in_row','2',0,'2876'),(174804,55821,'1639659044.5523','furniture-mobile','col_in_row','1',0,'2906'),(174805,55832,'117665','furniture-mobile','block_type','1',0,''),(174806,55832,'117665','furniture-mobile','style_class','item-holder',0,''),(174807,55832,'117665','furniture-mobile','padding-top','25',0,''),(174808,55832,'117665','furniture-mobile','padding-left','25',0,''),(174809,55832,'117665','furniture-mobile','padding-right','25',0,''),(174810,55832,'117665','furniture-mobile','padding-bottom','25',0,''),(174811,55832,'117665','furniture-mobile','text-align','left',0,''),(174812,55833,'120921','furniture-mobile','block_type','1',0,''),(174813,55833,'120921','furniture-mobile','style_class','item-wrapper',0,''),(174814,55834,'120896','furniture-mobile','block_type','1',0,''),(174815,55834,'120896','furniture-mobile','style_class','item-nav',0,''),(174816,55838,'120919','furniture-mobile','block_type','1',0,''),(174817,55838,'120919','furniture-mobile','style_class','item-content',0,''),(174818,55840,'117668','furniture-mobile','description_characters','90',0,''),(174819,55843,'117673','furniture-mobile','margin-bottom','7',0,''),(174820,55844,'117675','furniture-mobile','clear','both',0,''),(174821,55845,'117676','furniture-mobile','margin-bottom','10',0,''),(174822,55848,'117678','furniture-mobile','block_type','1',0,''),(174823,55848,'117678','furniture-mobile','padding-bottom','30',0,''),(174824,55849,'117679','furniture-mobile','block_type','6',0,''),(174825,55849,'117679','furniture-mobile','font-weight','400',0,''),(174826,55849,'117679','furniture-mobile','schema','6-2',0,'2906'),(174827,55849,'117679','furniture-mobile','schema','6-2',0,'2885'),(174828,55850,'117680','furniture-mobile','font-weight','400',0,''),(174829,55850,'117680','furniture-mobile','padding-right','40',0,''),(174830,55850,'117680','furniture-mobile','padding-right','0',0,'2906'),(174831,55850,'117680','furniture-mobile','padding-right','0',0,'2885'),(174832,55850,'117680','furniture-mobile','margin-bottom','20',0,''),(174833,55851,'117681','furniture-mobile','margin-bottom','20',0,''),(174834,55852,'120916','furniture-mobile','block_type','1',0,''),(174835,55852,'120916','furniture-mobile','padding-right','40',0,''),(174836,55852,'120916','furniture-mobile','style_class','leftCategories',0,''),(174837,55852,'120916','furniture-mobile','padding-bottom','25',0,''),(174838,55852,'120916','furniture-mobile','padding-right','0',0,'2885'),(174839,55853,'120918','furniture-mobile','block_type','1',0,''),(174840,55853,'120918','furniture-mobile','background-color','$background-6',0,''),(174841,55854,'120884','furniture-mobile','type','default',0,''),(174842,55854,'120884','furniture-mobile','class','menu-simple',0,''),(174843,55854,'120884','furniture-mobile','style_class','LeftCategories',0,''),(174844,55855,'120917','furniture-mobile','text','##TEXT_CATEGORIES##',0,''),(174845,55855,'120917','furniture-mobile','padding-top','10',0,''),(174846,55855,'120917','furniture-mobile','padding-left','25',0,''),(174847,55855,'120917','furniture-mobile','padding-right','25',0,''),(174848,55855,'120917','furniture-mobile','padding-bottom','10',0,''),(174849,55855,'120917','furniture-mobile','color','$color-font-7',0,''),(174850,55855,'120917','furniture-mobile','font-size','24',0,''),(174851,55855,'120917','furniture-mobile','font-weight','bold',0,''),(174852,55857,'117683','furniture-mobile','block_type','1',0,''),(174853,55857,'117683','furniture-mobile','padding-top','10',0,''),(174854,55857,'117683','furniture-mobile','padding-bottom','10',0,''),(174855,55857,'117683','furniture-mobile','border-bottom-width','1',0,''),(174856,55857,'117683','furniture-mobile','border-bottom-color','$border-color-3',0,''),(174857,55857,'117683','furniture-mobile','margin-left','0',0,''),(174858,55857,'117683','furniture-mobile','margin-right','0',0,''),(174859,55858,'117684','furniture-mobile','float','left',0,''),(174860,55858,'117684','furniture-mobile','clear','none',0,''),(174861,55858,'117684','furniture-mobile','sort_pos_3','2',0,''),(174862,55858,'117684','furniture-mobile','sort_pos_4','1',0,''),(174863,55858,'117684','furniture-mobile','sort_pos_10','5',0,''),(174864,55858,'117684','furniture-mobile','sort_pos_9','6',0,''),(174865,55858,'117684','furniture-mobile','sort_pos_11','7',0,''),(174866,55858,'117684','furniture-mobile','sort_pos_12','8',0,''),(174867,55858,'117684','furniture-mobile','sort_pos_14','9',0,''),(174868,55858,'117684','furniture-mobile','sort_pos_13','10',0,''),(174869,55858,'117684','furniture-mobile','sort_pos_8','11',0,''),(174870,55858,'117684','furniture-mobile','sort_pos_7','12',0,''),(174871,55858,'117684','furniture-mobile','sort_pos_2','13',0,''),(174872,55858,'117684','furniture-mobile','sort_pos_1','14',0,''),(174873,55858,'117684','furniture-mobile','sort_pos_6','15',0,''),(174874,55858,'117684','furniture-mobile','sort_pos_5','16',0,''),(174875,55858,'117684','furniture-mobile','sort_pos_0','17',0,''),(174876,55858,'117684','furniture-mobile','sort_hide_10','1',0,''),(174877,55858,'117684','furniture-mobile','sort_hide_9','1',0,''),(174878,55858,'117684','furniture-mobile','sort_pos_15','4',0,''),(174879,55858,'117684','furniture-mobile','sort_pos_16','3',0,''),(174880,55858,'117684','furniture-mobile','sort_hide_4','0',0,''),(174881,55858,'117684','furniture-mobile','sort_hide_3','0',0,''),(174882,55858,'117684','furniture-mobile','sort_hide_16','1',0,''),(174883,55858,'117684','furniture-mobile','sort_hide_15','1',0,''),(174884,55858,'117684','furniture-mobile','sort_hide_11','1',0,''),(174885,55858,'117684','furniture-mobile','sort_hide_12','1',0,''),(174886,55858,'117684','furniture-mobile','sort_hide_14','1',0,''),(174887,55858,'117684','furniture-mobile','sort_hide_13','1',0,''),(174888,55858,'117684','furniture-mobile','sort_hide_8','0',0,''),(174889,55858,'117684','furniture-mobile','sort_hide_7','0',0,''),(174890,55858,'117684','furniture-mobile','sort_hide_2','1',0,''),(174891,55858,'117684','furniture-mobile','sort_hide_1','1',0,''),(174892,55858,'117684','furniture-mobile','sort_hide_6','1',0,''),(174893,55858,'117684','furniture-mobile','sort_hide_5','1',0,''),(174894,55858,'117684','furniture-mobile','sort_hide_0','1',0,''),(174895,55858,'117684','furniture-mobile','hide_icons','1',0,''),(174896,55859,'117685','furniture-mobile','float','right',0,''),(174897,55859,'117685','furniture-mobile','display','none',0,'2906'),(174898,55860,'117686','furniture-mobile','float','left',0,''),(174899,55860,'117686','furniture-mobile','clear','none',0,''),(174900,55860,'117686','furniture-mobile','margin-left','20',0,''),(174901,55860,'117686','furniture-mobile','display','none',0,'2906'),(174902,55860,'117686','furniture-mobile','display','none',0,'2890'),(174903,55861,'117687','furniture-mobile','margin-right','20',0,''),(174904,55861,'117687','furniture-mobile','float','right',0,''),(174905,55861,'117687','furniture-mobile','clear','none',0,''),(174906,55861,'117687','furniture-mobile','display','none',0,'2885'),(174907,55862,'117688','furniture-mobile','block_type','5',0,''),(174908,55862,'117688','furniture-mobile','padding-top','10',0,''),(174909,55862,'117688','furniture-mobile','padding-bottom','10',0,''),(174910,55862,'117688','furniture-mobile','schema','5-2',0,'2906'),(174911,55862,'117688','furniture-mobile','border-top-color','$border-color-3',0,''),(174912,55862,'117688','furniture-mobile','border-top-width','1',0,''),(174913,55863,'117689','furniture-mobile','padding-top','3',0,''),(174914,55864,'117690','furniture-mobile','float','right',0,''),(174915,55864,'117690','furniture-mobile','height','31',0,''),(174916,55865,'117691','furniture-mobile','col_in_row','3',0,''),(174917,55865,'117691','furniture-mobile','products_align','left',0,''),(174918,55865,'117691','furniture-mobile','font-weight','400',0,''),(174919,55865,'117691','furniture-mobile','listing_type','productListing',0,''),(174920,55865,'117691','furniture-mobile','listing_type_rows','Rows',0,''),(174921,55865,'117691','furniture-mobile','show_buy_button_b2b','on',0,''),(174922,55865,'117691','furniture-mobile','show_wishlist_button_b2b','1',0,''),(174923,55865,'117691','furniture-mobile','show_compare_b2b','1',0,''),(174924,55865,'117691','furniture-mobile','listing_type_b2b','b2b',0,''),(174925,55865,'117691','furniture-mobile','show_image','0',0,''),(174926,55865,'117691','furniture-mobile','show_stock','0',0,''),(174927,55865,'117691','furniture-mobile','show_description','0',0,''),(174928,55865,'117691','furniture-mobile','show_rating','0',0,''),(174929,55865,'117691','furniture-mobile','show_rating_counts','0',0,''),(174930,55865,'117691','furniture-mobile','show_price','0',0,''),(174931,55865,'117691','furniture-mobile','show_view_button','0',0,''),(174932,55865,'117691','furniture-mobile','show_wishlist_button','0',0,''),(174933,55865,'117691','furniture-mobile','show_compare','0',0,''),(174934,55865,'117691','furniture-mobile','show_name_rows','0',0,''),(174935,55865,'117691','furniture-mobile','show_image_rows','0',0,''),(174936,55865,'117691','furniture-mobile','show_stock_rows','0',0,''),(174937,55865,'117691','furniture-mobile','show_description_rows','0',0,''),(174938,55865,'117691','furniture-mobile','show_model_rows','0',0,''),(174939,55865,'117691','furniture-mobile','show_properties_rows','0',0,''),(174940,55865,'117691','furniture-mobile','show_rating_rows','0',0,''),(174941,55865,'117691','furniture-mobile','show_rating_counts_rows','0',0,''),(174942,55865,'117691','furniture-mobile','show_price_rows','0',0,''),(174943,55865,'117691','furniture-mobile','show_buy_button_rows','0',0,''),(174944,55865,'117691','furniture-mobile','show_qty_input_rows','0',0,''),(174945,55865,'117691','furniture-mobile','show_view_button_rows','0',0,''),(174946,55865,'117691','furniture-mobile','show_wishlist_button_rows','0',0,''),(174947,55865,'117691','furniture-mobile','show_compare_rows','0',0,''),(174948,55865,'117691','furniture-mobile','show_name_b2b','0',0,''),(174949,55865,'117691','furniture-mobile','show_image_b2b','0',0,''),(174950,55865,'117691','furniture-mobile','show_stock_b2b','0',0,''),(174951,55865,'117691','furniture-mobile','show_description_b2b','0',0,''),(174952,55865,'117691','furniture-mobile','show_model_b2b','0',0,''),(174953,55865,'117691','furniture-mobile','show_properties_b2b','0',0,''),(174954,55865,'117691','furniture-mobile','show_rating_b2b','0',0,''),(174955,55865,'117691','furniture-mobile','show_rating_counts_b2b','0',0,''),(174956,55865,'117691','furniture-mobile','show_price_b2b','0',0,''),(174957,55865,'117691','furniture-mobile','show_qty_input_b2b','0',0,''),(174958,55865,'117691','furniture-mobile','show_view_button_b2b','0',0,''),(174959,55865,'117691','furniture-mobile','show_attributes_b2b','0',0,''),(174960,55865,'117691','furniture-mobile','items_on_page','9',0,''),(174961,55865,'117691','furniture-mobile','col_in_row','2',0,'2885'),(174962,55865,'117691','furniture-mobile','col_in_row','1',0,'2906'),(174963,55865,'117691','furniture-mobile','product_names_teg','h2',0,''),(174964,55865,'117691','furniture-mobile','padding-top','20',0,''),(174965,55865,'117691','furniture-mobile','padding-bottom','20',0,''),(174966,55865,'117691','furniture-mobile','col_in_row','2',0,'2890'),(174967,55866,'120912','furniture-mobile','block_type','5',0,''),(174968,55866,'120912','furniture-mobile','padding-top','10',0,''),(174969,55866,'120912','furniture-mobile','schema','5-2',0,'2906'),(174970,55867,'120913','furniture-mobile','padding-top','3',0,''),(174971,55868,'120914','furniture-mobile','float','right',0,''),(174972,55868,'120914','furniture-mobile','height','31',0,''),(174973,55869,'1639760443.0645','furniture-mobile','carousel','1',0,''),(174974,55869,'1639760443.0645','furniture-mobile','col_in_row','4',0,''),(174975,55869,'1639760443.0645','furniture-mobile','fancibox','1',0,''),(174976,55871,'117693','furniture-mobile','block_type','1',0,''),(174977,55872,'117694','furniture-mobile','margin-bottom','20',0,''),(174978,55876,'117696','furniture-mobile','block_type','1',0,''),(174979,55878,'117698','furniture-mobile','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(174980,55879,'117699','furniture-mobile','width','680',0,''),(174981,55879,'117699','furniture-mobile','font-weight','normal',0,''),(174982,55879,'117699','furniture-mobile','font-size','12',0,''),(174983,55879,'117699','furniture-mobile','padding-top','20',0,''),(174984,55879,'117699','furniture-mobile','padding-bottom','20',0,''),(174985,55879,'117699','furniture-mobile','color','$color-font-8',0,''),(174986,55880,'117700','furniture-mobile','font-weight','400',0,''),(174987,55880,'117700','furniture-mobile','padding-top','20',0,''),(174988,55880,'117700','furniture-mobile','padding-bottom','0',0,''),(174989,55880,'117700','furniture-mobile','font-size','12',0,''),(174990,55881,'117701','furniture-mobile','block_type','3',0,''),(174991,55881,'117701','furniture-mobile','font-weight','normal',0,''),(174992,55881,'117701','furniture-mobile','padding-top','20',0,''),(174993,55882,'117702','furniture-mobile','text','<p>If undelivered please return to:</p>',1,''),(174994,55882,'117702','furniture-mobile','font-size','12',0,''),(174995,55882,'117702','furniture-mobile','font-weight','bold',0,''),(174996,55883,'117703','furniture-mobile','font-size','12',0,''),(174997,55884,'117704','furniture-mobile','text','<p>Thank you for your order</p>',1,''),(174998,55884,'117704','furniture-mobile','color','$color-font-10',0,''),(174999,55884,'117704','furniture-mobile','font-size','13',0,''),(175000,55884,'117704','furniture-mobile','font-weight','bold',0,''),(175001,55884,'117704','furniture-mobile','padding-top','5',0,''),(175002,55884,'117704','furniture-mobile','text-align','center',0,''),(175003,55885,'117705','furniture-mobile','font-weight','400',0,''),(175004,55885,'117705','furniture-mobile','text-align','center',0,''),(175005,55885,'117705','furniture-mobile','padding-top','0',0,''),(175007,55885,'117705','furniture-mobile','padding-left','20',0,''),(175008,55885,'117705','furniture-mobile','padding-right','20',0,''),(175009,55886,'117706','furniture-mobile','block_type','6',0,''),(175010,55886,'117706','furniture-mobile','font-weight','normal',0,''),(175011,55886,'117706','furniture-mobile','font-size','16',0,''),(175012,55887,'117707','furniture-mobile','text','<p>Email:</p>',1,''),(175013,55887,'117707','furniture-mobile','font-weight','normal',0,''),(175014,55887,'117707','furniture-mobile','text-align','right',0,''),(175015,55887,'117707','furniture-mobile','font-size','12',0,''),(175016,55888,'117708','furniture-mobile','font-weight','normal',0,''),(175017,55888,'117708','furniture-mobile','text-align','right',0,''),(175018,55888,'117708','furniture-mobile','font-size','12',0,''),(175019,55889,'117709','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(175020,55889,'117709','furniture-mobile','font-size','12',0,''),(175021,55889,'117709','furniture-mobile','font-weight','bold',0,''),(175022,55889,'117709','furniture-mobile','text-align','right',0,''),(175023,55890,'117710','furniture-mobile','block_type','6',0,''),(175024,55890,'117710','furniture-mobile','font-weight','normal',0,''),(175025,55890,'117710','furniture-mobile','font-size','16',0,''),(175026,55891,'117711','furniture-mobile','text','<p>Phone:</p>',1,''),(175027,55891,'117711','furniture-mobile','font-weight','normal',0,''),(175028,55891,'117711','furniture-mobile','text-align','right',0,''),(175029,55891,'117711','furniture-mobile','font-size','12',0,''),(175030,55892,'117712','furniture-mobile','font-weight','normal',0,''),(175031,55892,'117712','furniture-mobile','text-align','right',0,''),(175032,55892,'117712','furniture-mobile','font-size','12',0,''),(175033,55893,'117713','furniture-mobile','block_type','2',0,''),(175034,55893,'117713','furniture-mobile','font-weight','normal',0,''),(175035,55893,'117713','furniture-mobile','padding-bottom','20',0,''),(175036,55894,'117714','furniture-mobile','font-weight','400',0,''),(175037,55894,'117714','furniture-mobile','padding-top','20',0,''),(175039,55895,'117715','furniture-mobile','block_type','11',0,''),(175040,55895,'117715','furniture-mobile','font-weight','normal',0,''),(175041,55896,'117716','furniture-mobile','text','<p>Phone:</p>',1,''),(175042,55896,'117716','furniture-mobile','font-weight','normal',0,''),(175043,55896,'117716','furniture-mobile','text-align','right',0,''),(175044,55897,'117717','furniture-mobile','font-weight','normal',0,''),(175045,55897,'117717','furniture-mobile','text-align','right',0,''),(175046,55898,'117718','furniture-mobile','block_type','11',0,''),(175047,55898,'117718','furniture-mobile','font-weight','normal',0,''),(175048,55899,'117719','furniture-mobile','text','<p>Web:</p>',1,''),(175049,55899,'117719','furniture-mobile','font-weight','normal',0,''),(175050,55899,'117719','furniture-mobile','text-align','right',0,''),(175051,55900,'117720','furniture-mobile','font-weight','normal',0,''),(175052,55900,'117720','furniture-mobile','text-align','right',0,''),(175053,55901,'117721','furniture-mobile','block_type','1',0,''),(175054,55902,'117722','furniture-mobile','font-weight','normal',0,''),(175055,55902,'117722','furniture-mobile','text-align','right',0,''),(175056,55902,'117722','furniture-mobile','padding-bottom','10',0,''),(175057,55902,'117722','furniture-mobile','address_spacer',',',0,''),(175058,55902,'117722','furniture-mobile','font-size','12',0,''),(175059,55903,'117723','furniture-mobile','block_type','11',0,''),(175060,55903,'117723','furniture-mobile','font-weight','normal',0,''),(175061,55904,'117724','furniture-mobile','text','<p>Email:</p>',1,''),(175062,55904,'117724','furniture-mobile','font-weight','normal',0,''),(175063,55904,'117724','furniture-mobile','text-align','right',0,''),(175064,55905,'117725','furniture-mobile','font-weight','normal',0,''),(175065,55905,'117725','furniture-mobile','text-align','right',0,''),(175066,55906,'117726','furniture-mobile','block_type','4',0,''),(175067,55906,'117726','furniture-mobile','font-weight','normal',0,''),(175068,55906,'117726','furniture-mobile','border-top-width','1',0,''),(175069,55906,'117726','furniture-mobile','border-top-color','$border-color-4',0,''),(175070,55906,'117726','furniture-mobile','border-left-width','1',0,''),(175071,55906,'117726','furniture-mobile','border-left-color','$border-color-4',0,''),(175072,55906,'117726','furniture-mobile','border-right-width','1',0,''),(175073,55906,'117726','furniture-mobile','border-right-color','$border-color-4',0,''),(175074,55906,'117726','furniture-mobile','border-bottom-width','1',0,''),(175075,55906,'117726','furniture-mobile','border-bottom-color','$border-color-4',0,''),(175076,55907,'117727','furniture-mobile','block_type','2',0,''),(175077,55907,'117727','furniture-mobile','font-weight','normal',0,''),(175078,55907,'117727','furniture-mobile','border-right-width','1',0,''),(175079,55907,'117727','furniture-mobile','border-right-color','$border-color-4',0,''),(175080,55908,'117728','furniture-mobile','block_type','1',0,''),(175081,55908,'117728','furniture-mobile','font-weight','400',0,''),(175082,55908,'117728','furniture-mobile','background-color','$background-6',0,''),(175083,55908,'117728','furniture-mobile','padding-top','10',0,''),(175084,55908,'117728','furniture-mobile','padding-left','10',0,''),(175085,55908,'117728','furniture-mobile','padding-right','10',0,''),(175086,55908,'117728','furniture-mobile','padding-bottom','30',0,''),(175087,55909,'117729','furniture-mobile','font-size','12',0,''),(175088,55910,'117730','furniture-mobile','text','<p>ADDRESS:</p>\n',1,''),(175089,55910,'117730','furniture-mobile','font-size','14',0,''),(175090,55910,'117730','furniture-mobile','font-weight','bold',0,''),(175091,55911,'117731','furniture-mobile','block_type','1',0,''),(175092,55911,'117731','furniture-mobile','font-weight','normal',0,''),(175093,55911,'117731','furniture-mobile','padding-top','10',0,''),(175094,55911,'117731','furniture-mobile','padding-left','10',0,''),(175095,55911,'117731','furniture-mobile','padding-right','10',0,''),(175096,55911,'117731','furniture-mobile','padding-bottom','10',0,''),(175097,55913,'117733','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(175098,55913,'117733','furniture-mobile','font-weight','bold',0,''),(175099,55913,'117733','furniture-mobile','font-size','14',0,''),(175100,55913,'117733','furniture-mobile','padding-top','10',0,''),(175101,55914,'117734','furniture-mobile','font-weight','normal',0,''),(175102,55915,'117735','furniture-mobile','font-weight','normal',0,''),(175103,55916,'117736','furniture-mobile','text','<p>PHONE NUMBER:</p>',1,''),(175104,55916,'117736','furniture-mobile','font-size','14',0,''),(175105,55916,'117736','furniture-mobile','font-weight','bold',0,''),(175106,55916,'117736','furniture-mobile','padding-top','10',0,''),(175107,55917,'117737','furniture-mobile','text','<p>CUSTOMER:</p>',1,''),(175108,55917,'117737','furniture-mobile','font-size','13',0,''),(175109,55917,'117737','furniture-mobile','font-weight','bold',0,''),(175110,55918,'117738','furniture-mobile','font-size','14',0,''),(175111,55918,'117738','furniture-mobile','font-weight','bold',0,''),(175112,55918,'117738','furniture-mobile','text-align','center',0,''),(175113,55918,'117738','furniture-mobile','padding-bottom','10',0,''),(175114,55918,'117738','furniture-mobile','padding-top','10',0,''),(175115,55919,'117739','furniture-mobile','text','<p>Order date:</p>\n',1,''),(175116,55919,'117739','furniture-mobile','font-weight','bold',0,''),(175117,55919,'117739','furniture-mobile','text-align','center',0,''),(175118,55919,'117739','furniture-mobile','font-size','12',0,''),(175119,55920,'117740','furniture-mobile','font-weight','normal',0,''),(175120,55920,'117740','furniture-mobile','text-align','center',0,''),(175121,55920,'117740','furniture-mobile','padding-bottom','10',0,''),(175122,55921,'117741','furniture-mobile','block_type','5',0,''),(175123,55921,'117741','furniture-mobile','font-weight','normal',0,''),(175124,55921,'117741','furniture-mobile','border-bottom-width','1',0,''),(175125,55921,'117741','furniture-mobile','border-bottom-color','$border-color-4',0,''),(175126,55921,'117741','furniture-mobile','border-top-width','1',0,''),(175127,55921,'117741','furniture-mobile','border-top-color','$border-color-4',0,''),(175128,55921,'117741','furniture-mobile','border-left-color','$border-color-4',0,''),(175129,55921,'117741','furniture-mobile','border-left-width','1',0,''),(175130,55922,'117742','furniture-mobile','block_type','1',0,''),(175131,55922,'117742','furniture-mobile','font-weight','normal',0,''),(175132,55922,'117742','furniture-mobile','padding-top','10',0,''),(175133,55922,'117742','furniture-mobile','padding-left','10',0,''),(175134,55922,'117742','furniture-mobile','padding-right','10',0,''),(175135,55923,'117743','furniture-mobile','font-weight','400',0,''),(175136,55923,'117743','furniture-mobile','line-height','120',0,''),(175137,55923,'117743','furniture-mobile','line_height_measure','%',0,''),(175138,55923,'117743','furniture-mobile','font-size','12',0,''),(175139,55924,'117744','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(175140,55924,'117744','furniture-mobile','font-size','14',0,''),(175141,55924,'117744','furniture-mobile','font-weight','bold',0,''),(175142,55924,'117744','furniture-mobile','padding-bottom','10',0,''),(175145,55928,'117745','furniture-mobile','block_type','1',0,''),(175146,55929,'117746','furniture-mobile','block_type','6',0,''),(175147,55929,'117746','furniture-mobile','schema','6-3',0,'2885'),(175148,55930,'117747','furniture-mobile','aria_name','account-menu',0,''),(175205,55950,'117748','furniture-mobile','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(175206,55951,'117749','furniture-mobile','link','Quotation Info',0,''),(175207,55951,'117749','furniture-mobile','margin-bottom','20',0,''),(175208,55952,'117750','furniture-mobile','block_type','1',0,''),(175209,55953,'117751','furniture-mobile','block_type','6',0,''),(175210,55953,'117751','furniture-mobile','schema','6-3',0,'2885'),(175211,55954,'117752','furniture-mobile','aria_name','account-menu',0,''),(175268,55974,'117753','furniture-mobile','block_type','3',0,''),(175269,55975,'117754','furniture-mobile','block_type','1',0,''),(175270,55975,'117754','furniture-mobile','padding-right','20',0,''),(175271,55975,'117754','furniture-mobile','padding-bottom','20',0,''),(175272,55976,'117755','furniture-mobile','orders_data','name',0,''),(175273,55977,'117756','furniture-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(175274,55978,'117757','furniture-mobile','block_type','1',0,''),(175275,55978,'117757','furniture-mobile','padding-right','20',0,''),(175276,55978,'117757','furniture-mobile','padding-bottom','20',0,''),(175277,55979,'117758','furniture-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(175278,55980,'117759','furniture-mobile','orders_data','telephone',0,''),(175279,55981,'117760','furniture-mobile','block_type','1',0,''),(175280,55981,'117760','furniture-mobile','padding-right','20',0,''),(175281,55982,'117761','furniture-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(175282,55983,'117762','furniture-mobile','orders_data','shipping_method',0,''),(175283,55984,'117763','furniture-mobile','block_type','1',0,''),(175284,55984,'117763','furniture-mobile','padding-right','20',0,''),(175285,55984,'117763','furniture-mobile','padding-bottom','20',0,''),(175286,55985,'117764','furniture-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(175287,55986,'117765','furniture-mobile','orders_data','delivery_address',0,''),(175288,55987,'117766','furniture-mobile','block_type','1',0,''),(175289,55987,'117766','furniture-mobile','padding-bottom','20',0,''),(175290,55988,'117767','furniture-mobile','orders_data','billing_address',0,''),(175291,55989,'117768','furniture-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(175292,55990,'117769','furniture-mobile','block_type','1',0,''),(175293,55991,'117770','furniture-mobile','orders_data','payment_method',0,''),(175294,55992,'117771','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(175295,55993,'117772','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(175296,55995,'117774','furniture-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(175297,55998,'117777','furniture-mobile','block_type','2',0,''),(175298,55998,'117777','furniture-mobile','padding-top','20',0,''),(175299,55998,'117777','furniture-mobile','margin-bottom','20',0,''),(175300,55999,'117778','furniture-mobile','like_button','1',0,''),(175301,55999,'117778','furniture-mobile','text','IMAGE_BUTTON_BACK',0,''),(175302,55999,'117778','furniture-mobile','link','Quotations',0,''),(175303,56000,'117779','furniture-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(175304,56001,'117780','furniture-mobile','padding-top','20',0,''),(175305,56001,'117780','furniture-mobile','padding-bottom','20',0,''),(175306,56001,'117780','furniture-mobile','block_type','1',0,''),(175307,56001,'117780','furniture-mobile','background-color','$background-6',0,''),(175308,56003,'117782','furniture-mobile','block_type','4',0,''),(175309,56003,'117782','furniture-mobile','schema','4-2',0,'2885'),(175310,56003,'117782','furniture-mobile','schema','4-2',0,'2876'),(175311,56004,'117783','furniture-mobile','background-color','$background-7',0,''),(175312,56005,'117784','furniture-mobile','block_type','1',0,''),(175313,56005,'117784','furniture-mobile','style_class','order-summary',0,''),(175314,56005,'117784','furniture-mobile','margin-left','30',0,''),(175315,56005,'117784','furniture-mobile','margin-left','0',0,'2885'),(175316,56006,'117785','furniture-mobile','block_type','1',0,''),(175317,56006,'117785','furniture-mobile','padding-left','20',0,''),(175318,56006,'117785','furniture-mobile','padding-right','20',0,''),(175319,56006,'117785','furniture-mobile','padding-bottom','30',0,''),(175320,56007,'117786','furniture-mobile','max-width','300',0,'2885'),(175321,56007,'117786','furniture-mobile','margin_left_measure','auto',0,'2885'),(175322,56007,'117786','furniture-mobile','margin_right_measure','auto',0,'2885'),(175323,56007,'117786','furniture-mobile','margin-bottom','0',0,''),(175324,56009,'117788','furniture-mobile','block_type','1',0,''),(175325,56010,'117789','furniture-mobile','block_type','6',0,''),(175326,56010,'117789','furniture-mobile','schema','6-3',0,'2885'),(175327,56011,'117790','furniture-mobile','aria_name','account-menu',0,''),(175384,56031,'117791','furniture-mobile','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(175385,56032,'117792','furniture-mobile','margin-bottom','20',0,''),(175386,56033,'117793','furniture-mobile','block_type','1',0,''),(175387,56035,'117795','furniture-mobile','pagination','bottom',0,''),(175388,56036,'117796','furniture-mobile','width','800',0,''),(175389,56037,'117797','furniture-mobile','block_type','11',0,''),(175390,56037,'117797','furniture-mobile','border-top-width','1',0,''),(175391,56037,'117797','furniture-mobile','border-left-width','1',0,''),(175392,56037,'117797','furniture-mobile','border-right-width','1',0,''),(175393,56037,'117797','furniture-mobile','border-bottom-width','1',0,''),(175394,56037,'117797','furniture-mobile','border-top-color','$border-color-5',0,''),(175395,56037,'117797','furniture-mobile','border-left-color','$border-color-5',0,''),(175396,56037,'117797','furniture-mobile','border-right-color','$border-color-5',0,''),(175397,56037,'117797','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175398,56038,'117798','furniture-mobile','block_type','1',0,''),(175399,56038,'117798','furniture-mobile','border-right-width','1',0,''),(175400,56038,'117798','furniture-mobile','border-right-color','$border-color-5',0,''),(175401,56038,'117798','furniture-mobile','padding-top','10',0,''),(175402,56038,'117798','furniture-mobile','padding-right','10',0,''),(175403,56038,'117798','furniture-mobile','padding-bottom','10',0,''),(175404,56039,'117799','furniture-mobile','block_type','9',0,''),(175405,56040,'117800','furniture-mobile','text','1.',0,''),(175406,56040,'117800','furniture-mobile','font-size','12',0,''),(175407,56040,'117800','furniture-mobile','text-align','right',0,''),(175408,56040,'117800','furniture-mobile','padding-right','5',0,''),(175409,56041,'117801','furniture-mobile','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(175410,56041,'117801','furniture-mobile','font-size','12',0,''),(175411,56041,'117801','furniture-mobile','padding-bottom','5',0,''),(175412,56042,'117802','furniture-mobile','block_type','9',0,''),(175413,56043,'117803','furniture-mobile','text','4.',0,''),(175414,56043,'117803','furniture-mobile','font-size','12',0,''),(175415,56043,'117803','furniture-mobile','text-align','right',0,''),(175416,56043,'117803','furniture-mobile','margin-right','5',0,''),(175417,56044,'117804','furniture-mobile','text','Our Replacement Department will process your request.',0,''),(175418,56044,'117804','furniture-mobile','font-size','12',0,''),(175419,56044,'117804','furniture-mobile','padding-bottom','5',0,''),(175420,56045,'117805','furniture-mobile','block_type','9',0,''),(175421,56046,'117806','furniture-mobile','text','3.',0,''),(175422,56046,'117806','furniture-mobile','font-size','12',0,''),(175423,56046,'117806','furniture-mobile','text-align','right',0,''),(175424,56046,'117806','furniture-mobile','margin-right','5',0,''),(175425,56047,'117807','furniture-mobile','text','Return the authorized item(s) per shipping instructions.',0,''),(175426,56047,'117807','furniture-mobile','font-size','12',0,''),(175427,56047,'117807','furniture-mobile','padding-bottom','5',0,''),(175428,56048,'117808','furniture-mobile','block_type','9',0,''),(175429,56049,'117809','furniture-mobile','text','2.',0,''),(175430,56049,'117809','furniture-mobile','font-size','12',0,''),(175431,56049,'117809','furniture-mobile','text-align','right',0,''),(175432,56049,'117809','furniture-mobile','margin-right','5',0,''),(175433,56050,'117810','furniture-mobile','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(175434,56050,'117810','furniture-mobile','font-size','12',0,''),(175435,56050,'117810','furniture-mobile','padding-bottom','5',0,''),(175436,56051,'117811','furniture-mobile','block_type','1',0,''),(175437,56051,'117811','furniture-mobile','padding-left','15',0,''),(175438,56052,'117812','furniture-mobile','text','Replacement Policy:',0,''),(175439,56052,'117812','furniture-mobile','font-size','14',0,''),(175440,56052,'117812','furniture-mobile','padding-bottom','5',0,''),(175441,56052,'117812','furniture-mobile','font-weight','bold',0,''),(175442,56053,'117813','furniture-mobile','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(175443,56053,'117813','furniture-mobile','font-size','11',0,''),(175444,56053,'117813','furniture-mobile','font-style','italic',0,''),(175445,56053,'117813','furniture-mobile','padding-bottom','5',0,''),(175446,56054,'117814','furniture-mobile','block_type','1',0,''),(175447,56054,'117814','furniture-mobile','border-bottom-width','1',0,''),(175448,56054,'117814','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175449,56055,'117815','furniture-mobile','text','Return Material Authorization (RMA) Form',0,''),(175450,56055,'117815','furniture-mobile','text-align','center',0,''),(175451,56055,'117815','furniture-mobile','font-size','16',0,''),(175452,56055,'117815','furniture-mobile','font-weight','bold',0,''),(175453,56056,'117816','furniture-mobile','text-align','center',0,''),(175454,56056,'117816','furniture-mobile','logo','themes/furniture-mobile/img/Furntech-1.jpg',1,''),(175455,56056,'117816','furniture-mobile','padding-top','10',0,''),(175456,56056,'117816','furniture-mobile','padding-bottom','10',0,''),(175457,56057,'117817','furniture-mobile','block_type','1',0,''),(175458,56057,'117817','furniture-mobile','padding-top','10',0,''),(175459,56057,'117817','furniture-mobile','padding-left','10',0,''),(175460,56057,'117817','furniture-mobile','padding-right','10',0,''),(175461,56057,'117817','furniture-mobile','padding-bottom','20',0,''),(175462,56058,'117818','furniture-mobile','block_type','2',0,''),(175463,56058,'117818','furniture-mobile','padding-top','5',0,''),(175464,56059,'117819','furniture-mobile','block_type','11',0,''),(175465,56060,'117820','furniture-mobile','text','Email:',0,''),(175466,56060,'117820','furniture-mobile','font-size','12',0,''),(175467,56061,'117821','furniture-mobile','data','rrDelivery_email_address',0,''),(175468,56061,'117821','furniture-mobile','font-size','12',0,''),(175469,56062,'117822','furniture-mobile','block_type','11',0,''),(175470,56063,'117823','furniture-mobile','text','Phone:',0,''),(175471,56063,'117823','furniture-mobile','font-size','12',0,''),(175472,56064,'117824','furniture-mobile','data','rrDelivery_telephone',0,''),(175473,56064,'117824','furniture-mobile','font-size','12',0,''),(175474,56065,'117825','furniture-mobile','block_type','2',0,''),(175475,56065,'117825','furniture-mobile','padding-top','5',0,''),(175476,56066,'117826','furniture-mobile','block_type','11',0,''),(175477,56067,'117827','furniture-mobile','text','Country:',0,''),(175478,56067,'117827','furniture-mobile','font-size','12',0,''),(175479,56068,'117828','furniture-mobile','data','rrDelivery_country',0,''),(175480,56068,'117828','furniture-mobile','font-size','12',0,''),(175481,56069,'117829','furniture-mobile','block_type','11',0,''),(175482,56070,'117830','furniture-mobile','text','Postcode:',0,''),(175483,56070,'117830','furniture-mobile','font-size','12',0,''),(175484,56071,'117831','furniture-mobile','data','rrDelivery_postcode',0,''),(175485,56071,'117831','furniture-mobile','font-size','12',0,''),(175486,56072,'117832','furniture-mobile','block_type','2',0,''),(175487,56072,'117832','furniture-mobile','padding-top','5',0,''),(175488,56073,'117833','furniture-mobile','block_type','11',0,''),(175489,56074,'117834','furniture-mobile','text','City:',0,''),(175490,56074,'117834','furniture-mobile','font-size','12',0,''),(175491,56075,'117835','furniture-mobile','data','rrDelivery_city',0,''),(175492,56075,'117835','furniture-mobile','font-size','12',0,''),(175493,56076,'117836','furniture-mobile','block_type','11',0,''),(175494,56077,'117837','furniture-mobile','text','State:',0,''),(175495,56077,'117837','furniture-mobile','font-size','12',0,''),(175496,56078,'117838','furniture-mobile','data','rrDelivery_state',0,''),(175497,56078,'117838','furniture-mobile','font-size','12',0,''),(175498,56079,'117839','furniture-mobile','block_type','9',0,''),(175499,56079,'117839','furniture-mobile','padding-top','5',0,''),(175500,56080,'117840','furniture-mobile','text','Address:',0,''),(175501,56080,'117840','furniture-mobile','font-size','12',0,''),(175502,56081,'117841','furniture-mobile','data','rrDelivery_street_address',0,''),(175503,56081,'117841','furniture-mobile','font-size','12',0,''),(175504,56082,'117842','furniture-mobile','block_type','2',0,''),(175505,56083,'117843','furniture-mobile','block_type','11',0,''),(175506,56084,'117844','furniture-mobile','text','Company:',0,''),(175507,56084,'117844','furniture-mobile','font-size','12',0,''),(175508,56085,'117845','furniture-mobile','data','rrDelivery_company',0,''),(175509,56085,'117845','furniture-mobile','font-size','12',0,''),(175510,56086,'117846','furniture-mobile','block_type','2',0,''),(175511,56087,'117847','furniture-mobile','text','Contact Name:',0,''),(175512,56087,'117847','furniture-mobile','font-size','12',0,''),(175513,56088,'117848','furniture-mobile','data','rrDelivery_name',0,''),(175514,56088,'117848','furniture-mobile','font-size','12',0,''),(175515,56089,'117849','furniture-mobile','block_type','2',0,''),(175516,56089,'117849','furniture-mobile','padding-left','10',0,''),(175517,56089,'117849','furniture-mobile','padding-top','20',0,''),(175518,56089,'117849','furniture-mobile','padding-right','10',0,''),(175519,56090,'117850','furniture-mobile','block_type','5',0,''),(175520,56091,'117851','furniture-mobile','text','RMA No:',0,''),(175521,56091,'117851','furniture-mobile','font-size','12',0,''),(175522,56091,'117851','furniture-mobile','font-weight','bold',0,''),(175523,56092,'117852','furniture-mobile','data','rrNumber',0,''),(175524,56092,'117852','furniture-mobile','font-size','12',0,''),(175525,56092,'117852','furniture-mobile','font-weight','bold',0,''),(175526,56093,'117853','furniture-mobile','block_type','2',0,''),(175527,56094,'117854','furniture-mobile','text','Date Issued:',0,''),(175528,56094,'117854','furniture-mobile','font-size','12',0,''),(175529,56094,'117854','furniture-mobile','font-weight','bold',0,''),(175530,56095,'117855','furniture-mobile','data','rrDateCreate',0,''),(175531,56095,'117855','furniture-mobile','font-size','12',0,''),(175532,56095,'117855','furniture-mobile','font-weight','bold',0,''),(175533,56096,'117856','furniture-mobile','block_type','1',0,''),(175534,56097,'117857','furniture-mobile','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(175535,56097,'117857','furniture-mobile','font-size','12',0,''),(175536,56097,'117857','furniture-mobile','font-style','italic',0,''),(175537,56097,'117857','furniture-mobile','padding-bottom','20',0,''),(175538,56099,'117859','furniture-mobile','block_type','1',0,''),(175539,56099,'117859','furniture-mobile','border-top-width','1',0,''),(175540,56099,'117859','furniture-mobile','border-left-width','1',0,''),(175541,56099,'117859','furniture-mobile','border-right-width','1',0,''),(175542,56099,'117859','furniture-mobile','border-bottom-width','1',0,''),(175543,56099,'117859','furniture-mobile','border-top-color','$border-color-5',0,''),(175544,56099,'117859','furniture-mobile','border-left-color','$border-color-5',0,''),(175545,56099,'117859','furniture-mobile','border-right-color','$border-color-5',0,''),(175546,56099,'117859','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175547,56100,'117860','furniture-mobile','block_type','11',0,''),(175548,56101,'117861','furniture-mobile','block_type','1',0,''),(175549,56101,'117861','furniture-mobile','padding-top','10',0,''),(175550,56101,'117861','furniture-mobile','padding-right','10',0,''),(175551,56101,'117861','furniture-mobile','padding-bottom','10',0,''),(175552,56101,'117861','furniture-mobile','border-right-width','1',0,''),(175553,56101,'117861','furniture-mobile','border-right-color','$border-color-5',0,''),(175554,56102,'117862','furniture-mobile','block_type','9',0,''),(175555,56103,'117863','furniture-mobile','text','4.',0,''),(175556,56103,'117863','furniture-mobile','font-size','12',0,''),(175557,56103,'117863','furniture-mobile','text-align','right',0,''),(175558,56103,'117863','furniture-mobile','padding-right','5',0,''),(175559,56104,'117864','furniture-mobile','font-size','11',0,''),(175560,56104,'117864','furniture-mobile','font-style','italic',0,''),(175561,56104,'117864','furniture-mobile','padding-bottom','5',0,''),(175562,56105,'117865','furniture-mobile','text','Ship returned items to:',0,''),(175563,56105,'117865','furniture-mobile','font-size','12',0,''),(175564,56105,'117865','furniture-mobile','padding-bottom','5',0,''),(175565,56106,'117866','furniture-mobile','block_type','9',0,''),(175566,56107,'117867','furniture-mobile','text','3.',0,''),(175567,56107,'117867','furniture-mobile','font-size','12',0,''),(175568,56107,'117867','furniture-mobile','text-align','right',0,''),(175569,56107,'117867','furniture-mobile','padding-right','5',0,''),(175570,56108,'117868','furniture-mobile','text','Ship only the items that are authorized.',0,''),(175571,56108,'117868','furniture-mobile','font-size','12',0,''),(175572,56108,'117868','furniture-mobile','padding-bottom','10',0,''),(175573,56109,'117869','furniture-mobile','block_type','9',0,''),(175574,56110,'117870','furniture-mobile','text','1.',0,''),(175575,56110,'117870','furniture-mobile','font-size','12',0,''),(175576,56110,'117870','furniture-mobile','text-align','right',0,''),(175577,56110,'117870','furniture-mobile','padding-right','5',0,''),(175578,56111,'117871','furniture-mobile','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(175579,56111,'117871','furniture-mobile','font-size','12',0,''),(175580,56111,'117871','furniture-mobile','padding-bottom','10',0,''),(175581,56112,'117872','furniture-mobile','block_type','1',0,''),(175582,56113,'117873','furniture-mobile','text','Shipping Instructions:',0,''),(175583,56113,'117873','furniture-mobile','font-weight','bold',0,''),(175584,56113,'117873','furniture-mobile','font-size','14',0,''),(175585,56113,'117873','furniture-mobile','padding-bottom','5',0,''),(175586,56113,'117873','furniture-mobile','padding-left','10',0,''),(175587,56114,'117874','furniture-mobile','block_type','9',0,''),(175588,56115,'117875','furniture-mobile','text','2.',0,''),(175589,56115,'117875','furniture-mobile','font-size','12',0,''),(175590,56115,'117875','furniture-mobile','text-align','right',0,''),(175591,56115,'117875','furniture-mobile','padding-right','5',0,''),(175592,56116,'117876','furniture-mobile','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(175593,56116,'117876','furniture-mobile','font-size','12',0,''),(175594,56116,'117876','furniture-mobile','padding-bottom','10',0,''),(175595,56117,'117877','furniture-mobile','block_type','1',0,''),(175596,56117,'117877','furniture-mobile','padding-left','10',0,''),(175597,56117,'117877','furniture-mobile','padding-right','10',0,''),(175598,56117,'117877','furniture-mobile','padding-bottom','10',0,''),(175599,56118,'117878','furniture-mobile','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(175600,56118,'117878','furniture-mobile','font-size','11',0,''),(175601,56118,'117878','furniture-mobile','font-style','italic',0,''),(175602,56119,'117879','furniture-mobile','block_type','1',0,''),(175603,56119,'117879','furniture-mobile','padding-top','10',0,''),(175604,56119,'117879','furniture-mobile','padding-left','40',0,''),(175605,56119,'117879','furniture-mobile','padding-right','40',0,''),(175606,56119,'117879','furniture-mobile','padding-bottom','10',0,''),(175607,56120,'117880','furniture-mobile','block_type','1',0,''),(175608,56120,'117880','furniture-mobile','padding-top','10',0,''),(175609,56120,'117880','furniture-mobile','padding-left','10',0,''),(175610,56120,'117880','furniture-mobile','padding-right','10',0,''),(175611,56120,'117880','furniture-mobile','padding-bottom','10',0,''),(175612,56120,'117880','furniture-mobile','border-top-width','1',0,''),(175613,56120,'117880','furniture-mobile','border-left-width','1',0,''),(175614,56120,'117880','furniture-mobile','border-right-width','1',0,''),(175615,56120,'117880','furniture-mobile','border-bottom-width','1',0,''),(175616,56120,'117880','furniture-mobile','border-top-color','$border-color-5',0,''),(175617,56120,'117880','furniture-mobile','border-left-color','$border-color-5',0,''),(175618,56120,'117880','furniture-mobile','border-right-color','$border-color-5',0,''),(175619,56120,'117880','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175620,56121,'117881','furniture-mobile','block_type','3',0,''),(175621,56122,'117882','furniture-mobile','data','rrDelivery_name',0,''),(175622,56122,'117882','furniture-mobile','font-size','9',0,''),(175623,56123,'117883','furniture-mobile','block_type','2',0,''),(175624,56124,'117884','furniture-mobile','text','RMA#:',0,''),(175625,56124,'117884','furniture-mobile','font-size','10',0,''),(175626,56125,'117885','furniture-mobile','data','rrNumber',0,''),(175627,56125,'117885','furniture-mobile','font-size','9',0,''),(175628,56126,'117886','furniture-mobile','block_type','5',0,''),(175629,56127,'117887','furniture-mobile','font-size','9',0,''),(175630,56128,'117888','furniture-mobile','block_type','1',0,''),(175631,56128,'117888','furniture-mobile','padding-left','10',0,''),(175632,56128,'117888','furniture-mobile','padding-right','10',0,''),(175633,56128,'117888','furniture-mobile','padding-bottom','10',0,''),(175634,56129,'117889','furniture-mobile','text','Use this space for additional Comments:',0,''),(175635,56129,'117889','furniture-mobile','font-size','11',0,''),(175636,56129,'117889','furniture-mobile','font-style','italic',0,''),(175637,56130,'117890','furniture-mobile','text','&nbsp;',0,''),(175638,56130,'117890','furniture-mobile','border-bottom-width','1',0,''),(175639,56130,'117890','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175640,56131,'117891','furniture-mobile','text','&nbsp;',0,''),(175641,56131,'117891','furniture-mobile','border-bottom-width','1',0,''),(175642,56131,'117891','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175643,56131,'117891','furniture-mobile','padding-top','5',0,''),(175644,56132,'117892','furniture-mobile','text','&nbsp;',0,''),(175645,56132,'117892','furniture-mobile','border-bottom-width','1',0,''),(175646,56132,'117892','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175647,56132,'117892','furniture-mobile','padding-top','5',0,''),(175648,56133,'117893','furniture-mobile','text','&nbsp;',0,''),(175649,56133,'117893','furniture-mobile','border-bottom-width','1',0,''),(175650,56133,'117893','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175651,56133,'117893','furniture-mobile','padding-top','5',0,''),(175652,56134,'117894','furniture-mobile','block_type','3',0,''),(175653,56134,'117894','furniture-mobile','padding-top','10',0,''),(175654,56134,'117894','furniture-mobile','padding-bottom','10',0,''),(175655,56134,'117894','furniture-mobile','padding-right','10',0,''),(175656,56135,'117895','furniture-mobile','font-size','11',0,''),(175657,56135,'117895','furniture-mobile','font-weight','bold',0,''),(175658,56135,'117895','furniture-mobile','text','Return Approval:',0,''),(175659,56135,'117895','furniture-mobile','padding-top','5',0,''),(175660,56135,'117895','furniture-mobile','padding-left','10',0,''),(175661,56136,'117896','furniture-mobile','border-bottom-width','1',0,''),(175662,56136,'117896','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175663,56136,'117896','furniture-mobile','text','&nbsp;',0,''),(175664,56137,'117897','furniture-mobile','block_type','5',0,''),(175665,56138,'117898','furniture-mobile','text','Date:',0,''),(175666,56138,'117898','furniture-mobile','padding-top','5',0,''),(175667,56138,'117898','furniture-mobile','font-size','11',0,''),(175668,56138,'117898','furniture-mobile','font-weight','bold',0,''),(175669,56138,'117898','furniture-mobile','padding-left','5',0,''),(175670,56139,'117899','furniture-mobile','text','&nbsp;',0,''),(175671,56139,'117899','furniture-mobile','border-bottom-width','1',0,''),(175672,56139,'117899','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175673,56140,'117900','furniture-mobile','block_type','3',0,''),(175674,56140,'117900','furniture-mobile','padding-right','10',0,''),(175675,56141,'117901','furniture-mobile','text','Customer Signature:',0,''),(175676,56141,'117901','furniture-mobile','font-weight','bold',0,''),(175677,56141,'117901','furniture-mobile','font-size','11',0,''),(175678,56141,'117901','furniture-mobile','padding-top','5',0,''),(175679,56141,'117901','furniture-mobile','padding-left','10',0,''),(175680,56142,'117902','furniture-mobile','text','&nbsp;',0,''),(175681,56142,'117902','furniture-mobile','border-bottom-width','1',0,''),(175682,56142,'117902','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175683,56143,'117903','furniture-mobile','block_type','5',0,''),(175684,56144,'117904','furniture-mobile','text','Date:',0,''),(175685,56144,'117904','furniture-mobile','padding-top','5',0,''),(175686,56144,'117904','furniture-mobile','font-size','11',0,''),(175687,56144,'117904','furniture-mobile','font-weight','bold',0,''),(175688,56144,'117904','furniture-mobile','padding-left','5',0,''),(175689,56145,'117905','furniture-mobile','text','&nbsp;',0,''),(175690,56145,'117905','furniture-mobile','border-bottom-width','1',0,''),(175691,56145,'117905','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175692,56146,'117906','furniture-mobile','block_type','1',0,''),(175693,56146,'117906','furniture-mobile','style_class','item-holder',0,''),(175694,56146,'117906','furniture-mobile','padding-top','25',0,''),(175695,56146,'117906','furniture-mobile','padding-bottom','25',0,''),(175696,56146,'117906','furniture-mobile','text-align','left',0,''),(175697,56146,'117906','furniture-mobile','border-top-width','1',0,''),(175698,56146,'117906','furniture-mobile','border-top-color','$border-color-3',0,''),(175699,56147,'117907','furniture-mobile','block_type','7',0,''),(175700,56147,'117907','furniture-mobile','schema','7-2',0,'2885'),(175701,56148,'117908','furniture-mobile','block_type','5',0,''),(175702,56148,'117908','furniture-mobile','schema','5-2',0,'2885'),(175703,56149,'117909','furniture-mobile','clear','none',0,''),(175704,56149,'117909','furniture-mobile','padding-right','20',0,''),(175705,56150,'117910','furniture-mobile','padding-right','20',0,''),(175706,56150,'117910','furniture-mobile','max-width','300',0,'2885'),(175707,56150,'117910','furniture-mobile','margin_left_measure','auto',0,'2885'),(175708,56150,'117910','furniture-mobile','margin_right_measure','auto',0,'2885'),(175709,56151,'117914','furniture-mobile','padding-right','20',0,''),(175710,56152,'117915','furniture-mobile','description_characters','200',0,''),(175711,56152,'117915','furniture-mobile','clear','none',0,''),(175712,56152,'117915','furniture-mobile','padding-right','20',0,''),(175713,56153,'117916','furniture-mobile','clear','none',0,''),(175714,56154,'117917','furniture-mobile','margin-bottom','20',0,''),(175715,56157,'117918','furniture-mobile','block_type','1',0,''),(175716,56157,'117918','furniture-mobile','padding-left','40',0,''),(175717,56157,'117918','furniture-mobile','style_class','right-aria',0,''),(175718,56157,'117918','furniture-mobile','padding-left','0',0,'2885'),(175719,56158,'117911','furniture-mobile','block_type','1',0,''),(175720,56158,'117911','furniture-mobile','text-align','center',0,''),(175721,56159,'117912','furniture-mobile','margin-top','4',0,''),(175722,56159,'117912','furniture-mobile','margin-bottom','7',0,''),(175723,56160,'117913','furniture-mobile','padding-top','6',0,''),(175724,56160,'117913','furniture-mobile','padding-left','5',0,''),(175725,56161,'117919','furniture-mobile','margin-bottom','15',0,''),(175726,56161,'117919','furniture-mobile','text-align','right',0,''),(175727,56162,'117920','furniture-mobile','margin-bottom','10',0,''),(175728,56162,'117920','furniture-mobile','text-align','center',0,''),(175729,56163,'117922','furniture-mobile','text-align','right',0,''),(175730,56163,'117922','furniture-mobile','margin-bottom','15',0,''),(175731,56164,'117924','furniture-mobile','text-align','center',0,''),(175732,56164,'117924','furniture-mobile','margin-bottom','10',0,''),(175733,56165,'120924','furniture-mobile','block_type','1',0,''),(175734,56165,'120924','furniture-mobile','style_class','item-nav',0,''),(175735,56169,'117925','furniture-mobile','block_type','1',0,''),(175736,56169,'117925','furniture-mobile','padding-top','20',0,''),(175737,56169,'117925','furniture-mobile','padding-bottom','20',0,''),(175738,56169,'117925','furniture-mobile','background-color','$background-6',0,''),(175739,56171,'117927','furniture-mobile','block_type','7',0,''),(175740,56171,'117927','furniture-mobile','schema','4-2',0,'2885'),(175741,56172,'117928','furniture-mobile','padding-bottom','20',0,''),(175742,56172,'117928','furniture-mobile','background-color','$background-7',0,''),(175743,56173,'117929','furniture-mobile','style_class','order-summary',0,''),(175744,56173,'117929','furniture-mobile','padding-left','25',0,''),(175745,56173,'117929','furniture-mobile','block_type','1',0,''),(175746,56173,'117929','furniture-mobile','padding-left','0',0,'2885'),(175747,56173,'117929','furniture-mobile','margin-top','30',0,'2885'),(175748,56174,'117930','furniture-mobile','block_type','1',0,''),(175749,56174,'117930','furniture-mobile','padding-left','20',0,''),(175750,56174,'117930','furniture-mobile','padding-right','20',0,''),(175751,56174,'117930','furniture-mobile','padding-bottom','20',0,''),(175752,56174,'117930','furniture-mobile','padding-top','20',0,''),(175753,56175,'117931','furniture-mobile','max-width','300',0,'2885'),(175754,56175,'117931','furniture-mobile','margin_left_measure','auto',0,'2885'),(175755,56175,'117931','furniture-mobile','margin_right_measure','auto',0,'2885'),(175756,56176,'117932','furniture-mobile','block_type','1',0,''),(175757,56176,'117932','furniture-mobile','style_class','account-samples',0,''),(175758,56177,'117933','furniture-mobile','block_type','6',0,''),(175759,56177,'117933','furniture-mobile','schema','6-3',0,'2885'),(175760,56178,'117934','furniture-mobile','aria_name','account-menu',0,''),(175817,56198,'117935','furniture-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(175818,56199,'117936','furniture-mobile','show_pagenation','1',0,''),(175819,56199,'117936','furniture-mobile','link','Sample Info',0,''),(175820,56199,'117936','furniture-mobile','margin-bottom','20',0,''),(175821,56200,'117937','furniture-mobile','block_type','1',0,''),(175822,56200,'117937','furniture-mobile','style_class','account-sample-info',0,''),(175823,56201,'117938','furniture-mobile','block_type','6',0,''),(175824,56201,'117938','furniture-mobile','schema','6-3',0,'2885'),(175825,56202,'117939','furniture-mobile','aria_name','account-menu',0,''),(175882,56222,'117940','furniture-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(175883,56223,'117941','furniture-mobile','block_type','2',0,''),(175884,56223,'117941','furniture-mobile','padding-top','20',0,''),(175885,56223,'117941','furniture-mobile','margin-bottom','20',0,''),(175886,56224,'117942','furniture-mobile','like_button','1',0,''),(175887,56224,'117942','furniture-mobile','text','IMAGE_BUTTON_BACK',0,''),(175888,56224,'117942','furniture-mobile','link','Samples',0,''),(175889,56226,'117944','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(175890,56229,'117947','furniture-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(175891,56230,'117948','furniture-mobile','block_type','3',0,''),(175892,56231,'117949','furniture-mobile','block_type','1',0,''),(175893,56231,'117949','furniture-mobile','padding-right','20',0,''),(175894,56231,'117949','furniture-mobile','padding-bottom','20',0,''),(175895,56232,'117950','furniture-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(175896,56233,'117951','furniture-mobile','orders_data','telephone',0,''),(175897,56234,'117952','furniture-mobile','block_type','1',0,''),(175898,56234,'117952','furniture-mobile','padding-right','20',0,''),(175899,56234,'117952','furniture-mobile','padding-bottom','20',0,''),(175900,56235,'117953','furniture-mobile','orders_data','name',0,''),(175901,56236,'117954','furniture-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(175902,56237,'117955','furniture-mobile','block_type','1',0,''),(175903,56237,'117955','furniture-mobile','padding-right','20',0,''),(175904,56238,'117956','furniture-mobile','orders_data','shipping_method',0,''),(175905,56239,'117957','furniture-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(175906,56240,'117958','furniture-mobile','block_type','1',0,''),(175907,56240,'117958','furniture-mobile','padding-right','20',0,''),(175908,56240,'117958','furniture-mobile','padding-bottom','20',0,''),(175909,56241,'117959','furniture-mobile','orders_data','delivery_address',0,''),(175910,56242,'117960','furniture-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(175911,56243,'117961','furniture-mobile','block_type','1',0,''),(175912,56244,'117962','furniture-mobile','orders_data','payment_method',0,''),(175913,56245,'117963','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(175914,56246,'117964','furniture-mobile','block_type','1',0,''),(175915,56246,'117964','furniture-mobile','padding-bottom','20',0,''),(175916,56247,'117965','furniture-mobile','orders_data','billing_address',0,''),(175917,56248,'117966','furniture-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(175918,56249,'117967','furniture-mobile','block_type','1',0,''),(175919,56250,'117968','furniture-mobile','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(175920,56251,'117969','furniture-mobile','block_type','6',0,''),(175921,56252,'117970','furniture-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(175922,56253,'117971','furniture-mobile','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(175923,56254,'117972','furniture-mobile','text','<div class=\"heading-4\">Categories</div>',0,''),(175924,56257,'117975','furniture-mobile','class','menu-simple',0,''),(175925,56259,'117977','furniture-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(175926,56260,'120878','furniture-mobile','float','left',0,''),(175927,56260,'120878','furniture-mobile','margin-right','10',0,''),(175928,56261,'117978','furniture-mobile','block_type','1',0,''),(175929,56262,'117979','furniture-mobile','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(175930,56262,'117979','furniture-mobile','style_class','middle-form',0,''),(175931,56263,'117980','furniture-mobile','style_class','middle-form',0,''),(175932,56264,'117981','furniture-mobile','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(175933,56265,'117982','furniture-mobile','style_class','middle-form',0,''),(175934,56265,'117982','furniture-mobile','margin-bottom','30',0,''),(175935,56266,'117983','furniture-mobile','block_type','1',0,''),(175936,56267,'117984','furniture-mobile','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(175937,56267,'117984','furniture-mobile','padding-top','100',0,''),(175938,56267,'117984','furniture-mobile','margin-bottom','100',0,''),(175939,56267,'117984','furniture-mobile','text-align','center',0,''),(175940,56267,'117984','furniture-mobile','font-size','20',0,''),(175941,56268,'117985','furniture-mobile','block_type','1',0,''),(175942,56269,'117986','furniture-mobile','block_type','6',0,''),(175943,56269,'117986','furniture-mobile','schema','6-3',0,'2885'),(175944,56270,'117987','furniture-mobile','aria_name','account-menu',0,''),(176001,56290,'117988','furniture-mobile','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(176002,56291,'117989','furniture-mobile','text','##SUBSCRIPTION_TEXT##',0,''),(176003,56293,'117991','furniture-mobile','block_type','1',0,''),(176004,56293,'117991','furniture-mobile','style_class','checkout-success-wrap',0,''),(176005,56294,'117992','furniture-mobile','block_type','1',0,''),(176006,56294,'117992','furniture-mobile','font-weight','normal',0,''),(176007,56295,'117993','furniture-mobile','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>\n',0,''),(176008,56296,'117994','furniture-mobile','block_type','1',0,''),(176009,56296,'117994','furniture-mobile','text-align','center',0,''),(176010,56296,'117994','furniture-mobile','padding-top','30',0,''),(176011,56296,'117994','furniture-mobile','margin-bottom','200',0,''),(176012,56297,'117995','furniture-mobile','display','inline-block',0,''),(176013,56298,'117996','furniture-mobile','display','inline-block',0,''),(176014,56298,'117996','furniture-mobile','clear','none',0,''),(176015,56298,'117996','furniture-mobile','margin-left','20',0,''),(176016,56299,'1639413072.5477','furniture-mobile','box_align','4',0,''),(176017,56299,'1639413072.5477','furniture-mobile','margin-top','15',0,''),(176018,56300,'117997','furniture-mobile','block_type','1',0,''),(176019,56301,'117998','furniture-mobile','block_type','1',0,''),(176020,56301,'117998','furniture-mobile','font-weight','normal',0,''),(176021,56302,'117999','furniture-mobile','block_type','1',0,''),(176022,56302,'117999','furniture-mobile','text-align','center',0,''),(176023,56302,'117999','furniture-mobile','padding-top','30',0,''),(176024,56302,'117999','furniture-mobile','margin-bottom','200',0,''),(176025,56303,'118000','furniture-mobile','display','inline-block',0,''),(176026,56303,'118000','furniture-mobile','clear','none',0,''),(176027,56303,'118000','furniture-mobile','margin-left','20',0,''),(176028,56304,'118001','furniture-mobile','display','inline-block',0,''),(176029,56305,'118002','furniture-mobile','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(176034,56310,'118007','furniture-mobile','width','680',0,''),(176035,56310,'118007','furniture-mobile','font-weight','normal',0,''),(176036,56310,'118007','furniture-mobile','font-size','12',0,''),(176037,56310,'118007','furniture-mobile','padding-top','20',0,''),(176038,56310,'118007','furniture-mobile','padding-bottom','20',0,''),(176039,56310,'118007','furniture-mobile','color','$color-font-8',0,''),(176040,56311,'118008','furniture-mobile','block_type','5',0,''),(176041,56311,'118008','furniture-mobile','font-weight','normal',0,''),(176042,56311,'118008','furniture-mobile','border-bottom-width','1',0,''),(176043,56311,'118008','furniture-mobile','border-bottom-color','$border-color-4',0,''),(176044,56311,'118008','furniture-mobile','border-top-width','1',0,''),(176045,56311,'118008','furniture-mobile','border-top-color','$border-color-4',0,''),(176046,56311,'118008','furniture-mobile','border-left-color','$border-color-4',0,''),(176047,56311,'118008','furniture-mobile','border-left-width','1',0,''),(176048,56312,'118009','furniture-mobile','block_type','1',0,''),(176049,56312,'118009','furniture-mobile','font-weight','normal',0,''),(176050,56312,'118009','furniture-mobile','padding-top','10',0,''),(176051,56312,'118009','furniture-mobile','padding-left','10',0,''),(176052,56312,'118009','furniture-mobile','padding-right','10',0,''),(176053,56313,'118010','furniture-mobile','font-weight','400',0,''),(176054,56313,'118010','furniture-mobile','line-height','120',0,''),(176055,56313,'118010','furniture-mobile','line_height_measure','%',0,''),(176056,56313,'118010','furniture-mobile','font-size','12',0,''),(176057,56314,'118011','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(176058,56314,'118011','furniture-mobile','font-size','14',0,''),(176059,56314,'118011','furniture-mobile','font-weight','bold',0,''),(176060,56314,'118011','furniture-mobile','padding-bottom','10',0,''),(176061,56315,'118012','furniture-mobile','block_type','1',0,''),(176062,56315,'118012','furniture-mobile','background-color','$background-6',0,''),(176063,56315,'118012','furniture-mobile','padding-top','20',0,''),(176064,56315,'118012','furniture-mobile','padding-left','10',0,''),(176065,56315,'118012','furniture-mobile','padding-right','10',0,''),(176066,56315,'118012','furniture-mobile','padding-bottom','20',0,''),(176067,56315,'118012','furniture-mobile','font-size','14',0,''),(176068,56316,'118013','furniture-mobile','font-weight','normal',0,''),(176069,56316,'118013','furniture-mobile','text-align','right',0,''),(176070,56316,'118013','furniture-mobile','font-size','14',0,''),(176071,56316,'118013','furniture-mobile','box_align','3',0,''),(176072,56317,'118014','furniture-mobile','block_type','3',0,''),(176073,56317,'118014','furniture-mobile','font-weight','normal',0,''),(176074,56317,'118014','furniture-mobile','padding-top','20',0,''),(176075,56318,'118015','furniture-mobile','text','<p>If undelivered please return to:</p>',1,''),(176076,56318,'118015','furniture-mobile','font-size','12',0,''),(176077,56318,'118015','furniture-mobile','font-weight','bold',0,''),(176078,56319,'118016','furniture-mobile','font-size','12',0,''),(176079,56320,'118018','furniture-mobile','text','<p>Thank you for your order</p>',1,''),(176080,56320,'118018','furniture-mobile','color','$color-font-10',0,''),(176081,56320,'118018','furniture-mobile','font-size','13',0,''),(176082,56320,'118018','furniture-mobile','font-weight','bold',0,''),(176083,56320,'118018','furniture-mobile','padding-top','5',0,''),(176084,56320,'118018','furniture-mobile','text-align','center',0,''),(176085,56321,'118019','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(176086,56321,'118019','furniture-mobile','font-size','12',0,''),(176087,56321,'118019','furniture-mobile','font-weight','bold',0,''),(176088,56321,'118019','furniture-mobile','text-align','right',0,''),(176089,56322,'118020','furniture-mobile','block_type','6',0,''),(176090,56322,'118020','furniture-mobile','font-weight','normal',0,''),(176091,56322,'118020','furniture-mobile','font-size','16',0,''),(176092,56323,'118021','furniture-mobile','text','<p>Email:</p>',1,''),(176093,56323,'118021','furniture-mobile','font-weight','normal',0,''),(176094,56323,'118021','furniture-mobile','text-align','right',0,''),(176095,56323,'118021','furniture-mobile','font-size','12',0,''),(176096,56324,'118022','furniture-mobile','font-weight','normal',0,''),(176097,56324,'118022','furniture-mobile','text-align','right',0,''),(176098,56324,'118022','furniture-mobile','font-size','12',0,''),(176099,56325,'118023','furniture-mobile','block_type','6',0,''),(176100,56325,'118023','furniture-mobile','font-weight','normal',0,''),(176101,56325,'118023','furniture-mobile','font-size','16',0,''),(176102,56326,'118024','furniture-mobile','text','<p>Phone:</p>',1,''),(176103,56326,'118024','furniture-mobile','font-weight','normal',0,''),(176104,56326,'118024','furniture-mobile','text-align','right',0,''),(176105,56326,'118024','furniture-mobile','font-size','12',0,''),(176106,56327,'118025','furniture-mobile','font-weight','normal',0,''),(176107,56327,'118025','furniture-mobile','text-align','right',0,''),(176108,56327,'118025','furniture-mobile','font-size','12',0,''),(176109,56328,'118026','furniture-mobile','font-weight','400',0,''),(176110,56328,'118026','furniture-mobile','padding-top','20',0,''),(176111,56328,'118026','furniture-mobile','padding-bottom','0',0,''),(176112,56328,'118026','furniture-mobile','font-size','12',0,''),(176113,56329,'118027','furniture-mobile','block_type','2',0,''),(176114,56329,'118027','furniture-mobile','font-weight','normal',0,''),(176115,56329,'118027','furniture-mobile','padding-bottom','20',0,''),(176116,56330,'118028','furniture-mobile','block_type','11',0,''),(176117,56330,'118028','furniture-mobile','font-weight','normal',0,''),(176118,56331,'118029','furniture-mobile','text','<p>Email:</p>',1,''),(176119,56331,'118029','furniture-mobile','font-weight','normal',0,''),(176120,56331,'118029','furniture-mobile','text-align','right',0,''),(176121,56332,'118030','furniture-mobile','font-weight','normal',0,''),(176122,56332,'118030','furniture-mobile','text-align','right',0,''),(176123,56333,'118031','furniture-mobile','block_type','11',0,''),(176124,56333,'118031','furniture-mobile','font-weight','normal',0,''),(176125,56334,'118032','furniture-mobile','text','<p>Web:</p>',1,''),(176126,56334,'118032','furniture-mobile','font-weight','normal',0,''),(176127,56334,'118032','furniture-mobile','text-align','right',0,''),(176128,56335,'118033','furniture-mobile','font-weight','normal',0,''),(176129,56335,'118033','furniture-mobile','text-align','right',0,''),(176130,56336,'118034','furniture-mobile','block_type','1',0,''),(176131,56337,'118035','furniture-mobile','font-weight','normal',0,''),(176132,56337,'118035','furniture-mobile','text-align','right',0,''),(176133,56337,'118035','furniture-mobile','padding-bottom','10',0,''),(176134,56337,'118035','furniture-mobile','address_spacer',',',0,''),(176135,56337,'118035','furniture-mobile','font-size','12',0,''),(176136,56338,'118036','furniture-mobile','block_type','11',0,''),(176137,56338,'118036','furniture-mobile','font-weight','normal',0,''),(176138,56339,'118037','furniture-mobile','text','<p>Phone:</p>',1,''),(176139,56339,'118037','furniture-mobile','font-weight','normal',0,''),(176140,56339,'118037','furniture-mobile','text-align','right',0,''),(176141,56340,'118038','furniture-mobile','font-weight','normal',0,''),(176142,56340,'118038','furniture-mobile','text-align','right',0,''),(176143,56341,'118039','furniture-mobile','block_type','4',0,''),(176144,56341,'118039','furniture-mobile','font-weight','normal',0,''),(176145,56341,'118039','furniture-mobile','border-top-width','1',0,''),(176146,56341,'118039','furniture-mobile','border-top-color','$border-color-4',0,''),(176147,56341,'118039','furniture-mobile','border-left-width','1',0,''),(176148,56341,'118039','furniture-mobile','border-left-color','$border-color-4',0,''),(176149,56341,'118039','furniture-mobile','border-right-width','1',0,''),(176150,56341,'118039','furniture-mobile','border-right-color','$border-color-4',0,''),(176151,56341,'118039','furniture-mobile','border-bottom-width','1',0,''),(176152,56341,'118039','furniture-mobile','border-bottom-color','$border-color-4',0,''),(176153,56342,'118040','furniture-mobile','block_type','2',0,''),(176154,56342,'118040','furniture-mobile','font-weight','normal',0,''),(176155,56342,'118040','furniture-mobile','border-top-width','1',0,''),(176156,56342,'118040','furniture-mobile','border-top-color','$border-color-4',0,''),(176157,56342,'118040','furniture-mobile','border-right-width','1',0,''),(176158,56342,'118040','furniture-mobile','border-right-color','$border-color-4',0,''),(176159,56343,'118041','furniture-mobile','block_type','1',0,''),(176160,56343,'118041','furniture-mobile','font-weight','normal',0,''),(176161,56343,'118041','furniture-mobile','padding-top','10',0,''),(176162,56343,'118041','furniture-mobile','padding-left','10',0,''),(176163,56343,'118041','furniture-mobile','padding-right','10',0,''),(176164,56343,'118041','furniture-mobile','padding-bottom','10',0,''),(176165,56343,'118041','furniture-mobile','border-right-width','1',0,''),(176166,56343,'118041','furniture-mobile','border-right-color','$border-color-4',0,''),(176167,56344,'118042','furniture-mobile','text','<p>Shipping via</p>',1,''),(176168,56344,'118042','furniture-mobile','font-weight','bold',0,''),(176169,56344,'118042','furniture-mobile','font-size','14',0,''),(176170,56346,'118044','furniture-mobile','block_type','1',0,''),(176171,56346,'118044','furniture-mobile','font-weight','normal',0,''),(176172,56346,'118044','furniture-mobile','padding-top','10',0,''),(176173,56346,'118044','furniture-mobile','padding-left','10',0,''),(176174,56346,'118044','furniture-mobile','padding-right','10',0,''),(176175,56346,'118044','furniture-mobile','padding-bottom','10',0,''),(176176,56347,'118045','furniture-mobile','text','<p>Shipping service</p>',1,''),(176177,56347,'118045','furniture-mobile','font-weight','bold',0,''),(176178,56347,'118045','furniture-mobile','font-size','14',0,''),(176179,56349,'118047','furniture-mobile','block_type','2',0,''),(176180,56349,'118047','furniture-mobile','font-weight','normal',0,''),(176181,56349,'118047','furniture-mobile','border-right-width','1',0,''),(176182,56349,'118047','furniture-mobile','border-right-color','$border-color-4',0,''),(176183,56350,'118048','furniture-mobile','block_type','1',0,''),(176184,56350,'118048','furniture-mobile','font-weight','400',0,''),(176185,56350,'118048','furniture-mobile','background-color','$background-6',0,''),(176186,56350,'118048','furniture-mobile','padding-top','10',0,''),(176187,56350,'118048','furniture-mobile','padding-left','10',0,''),(176188,56350,'118048','furniture-mobile','padding-right','10',0,''),(176189,56350,'118048','furniture-mobile','padding-bottom','30',0,''),(176190,56351,'118049','furniture-mobile','font-size','12',0,''),(176191,56352,'118050','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(176192,56352,'118050','furniture-mobile','font-size','14',0,''),(176193,56352,'118050','furniture-mobile','font-weight','bold',0,''),(176194,56353,'118051','furniture-mobile','block_type','1',0,''),(176195,56353,'118051','furniture-mobile','font-weight','normal',0,''),(176196,56353,'118051','furniture-mobile','padding-top','10',0,''),(176197,56353,'118051','furniture-mobile','padding-left','10',0,''),(176198,56353,'118051','furniture-mobile','padding-right','10',0,''),(176199,56353,'118051','furniture-mobile','padding-bottom','10',0,''),(176200,56354,'118052','furniture-mobile','font-weight','normal',0,''),(176201,56355,'118053','furniture-mobile','text','<p>PHONE NUMBER:</p>',1,''),(176202,56355,'118053','furniture-mobile','font-size','14',0,''),(176203,56355,'118053','furniture-mobile','font-weight','bold',0,''),(176204,56355,'118053','furniture-mobile','padding-top','10',0,''),(176205,56357,'118055','furniture-mobile','font-weight','normal',0,''),(176206,56358,'118056','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(176207,56358,'118056','furniture-mobile','font-weight','bold',0,''),(176208,56358,'118056','furniture-mobile','font-size','14',0,''),(176209,56358,'118056','furniture-mobile','padding-top','10',0,''),(176210,56359,'118057','furniture-mobile','text','<p>CUSTOMER:</p>',1,''),(176211,56359,'118057','furniture-mobile','font-size','13',0,''),(176212,56359,'118057','furniture-mobile','font-weight','bold',0,''),(176213,56360,'118058','furniture-mobile','font-weight','normal',0,''),(176214,56360,'118058','furniture-mobile','text-align','center',0,''),(176215,56360,'118058','furniture-mobile','padding-bottom','10',0,''),(176216,56361,'118059','furniture-mobile','text','<p>Payment date:</p>',1,''),(176217,56361,'118059','furniture-mobile','font-weight','bold',0,''),(176218,56361,'118059','furniture-mobile','text-align','center',0,''),(176219,56361,'118059','furniture-mobile','font-size','12',0,''),(176220,56362,'118060','furniture-mobile','text','<p>Payment Method:</p>',1,''),(176221,56362,'118060','furniture-mobile','font-weight','bold',0,''),(176222,56362,'118060','furniture-mobile','text-align','center',0,''),(176223,56363,'118061','furniture-mobile','font-size','14',0,''),(176224,56363,'118061','furniture-mobile','font-weight','bold',0,''),(176225,56363,'118061','furniture-mobile','text-align','center',0,''),(176226,56363,'118061','furniture-mobile','padding-bottom','10',0,''),(176227,56363,'118061','furniture-mobile','padding-top','10',0,''),(176228,56364,'118062','furniture-mobile','font-weight','normal',0,''),(176229,56364,'118062','furniture-mobile','text-align','center',0,''),(176230,56364,'118062','furniture-mobile','padding-bottom','20',0,''),(176231,56365,'118063','furniture-mobile','font-weight','normal',0,''),(176232,56365,'118063','furniture-mobile','text-align','center',0,''),(176233,56366,'118064','furniture-mobile','block_type','1',0,''),(176234,56366,'118064','furniture-mobile','padding-top','35',0,''),(176235,56366,'118064','furniture-mobile','padding-bottom','35',0,''),(176236,56367,'118065','furniture-mobile','block_type','7',0,''),(176237,56367,'118065','furniture-mobile','schema','7-2',0,'2885'),(176238,56368,'118066','furniture-mobile','block_type','1',0,''),(176239,56368,'118066','furniture-mobile','style_class','blog_list_content',0,''),(176240,56370,'118068','furniture-mobile','text-align','center',0,''),(176241,56371,'118069','furniture-mobile','aria_name','blogsidebar',0,''),(176242,56371,'118069','furniture-mobile','style_class','blogsidebar',0,''),(176244,56376,'118070','furniture-mobile','block_type','1',0,''),(176245,56376,'118070','furniture-mobile','padding-top','35',0,''),(176246,56376,'118070','furniture-mobile','padding-bottom','35',0,''),(176247,56377,'118071','furniture-mobile','banners_group','blog',0,''),(176248,56377,'118071','furniture-mobile','margin-bottom','40',0,''),(176249,56378,'118072','furniture-mobile','block_type','7',0,''),(176250,56378,'118072','furniture-mobile','schema','7-1',0,'2885'),(176251,56379,'118073','furniture-mobile','block_type','1',0,''),(176252,56379,'118073','furniture-mobile','style_class','blog_list_content',0,''),(176253,56380,'118074','furniture-mobile','text-align','center',0,''),(176254,56380,'118074','furniture-mobile','hide_parents','1',0,''),(176255,56381,'118075','furniture-mobile','items_on_page','12',0,''),(176256,56381,'118075','furniture-mobile','items_cut_off','200',0,''),(176257,56382,'118076','furniture-mobile','aria_name','blogsidebar',0,''),(176258,56382,'118076','furniture-mobile','padding-left','35',0,''),(176259,56382,'118076','furniture-mobile','style_class','blogsidebar',0,''),(176260,56382,'118076','furniture-mobile','padding-left','15',0,'2890'),(176262,56387,'118077','furniture-mobile','block_type','1',0,''),(176263,56387,'118077','furniture-mobile','padding-top','35',0,''),(176264,56387,'118077','furniture-mobile','padding-bottom','35',0,''),(176265,56388,'118078','furniture-mobile','block_type','7',0,''),(176266,56388,'118078','furniture-mobile','schema','7-2',0,'2885'),(176267,56389,'118079','furniture-mobile','count_products','8',0,''),(176268,56389,'118079','furniture-mobile','col_in_row','4',0,''),(176269,56389,'118079','furniture-mobile','view_as','carousel',0,''),(176270,56389,'118079','furniture-mobile','show_stock','1',0,''),(176271,56389,'118079','furniture-mobile','show_description','1',0,''),(176272,56389,'118079','furniture-mobile','show_properties','1',0,''),(176273,56389,'118079','furniture-mobile','show_rating','1',0,''),(176274,56389,'118079','furniture-mobile','show_rating_counts','1',0,''),(176275,56389,'118079','furniture-mobile','show_qty_input','1',0,''),(176276,56389,'118079','furniture-mobile','show_wishlist_button','1',0,''),(176277,56389,'118079','furniture-mobile','show_compare','1',0,''),(176278,56389,'118079','furniture-mobile','col_in_row','3',0,'2890'),(176279,56389,'118079','furniture-mobile','col_in_row','2',0,'2885'),(176280,56389,'118079','furniture-mobile','col_in_row','1',0,'2906'),(176281,56389,'118079','furniture-mobile','listing_type','productListing',0,''),(176282,56390,'118080','furniture-mobile','block_type','1',0,''),(176283,56390,'118080','furniture-mobile','style_class','blog-white-bg',0,''),(176284,56390,'118080','furniture-mobile','padding-bottom','20',0,''),(176285,56392,'118082','furniture-mobile','text-align','center',0,''),(176286,56395,'118085','furniture-mobile','block_type','1',0,''),(176287,56395,'118085','furniture-mobile','padding-top','20',0,''),(176288,56395,'118085','furniture-mobile','margin-top','20',0,''),(176289,56395,'118085','furniture-mobile','border-top-width','1',0,''),(176290,56395,'118085','furniture-mobile','border-top-color','$border-color-4',0,''),(176291,56395,'118085','furniture-mobile','clear','both',0,''),(176292,56396,'118086','furniture-mobile','box_align','4',0,''),(176293,56396,'118086','furniture-mobile','text-align','center',0,''),(176294,56397,'118087','furniture-mobile','aria_name','blogsidebar',0,''),(176295,56397,'118087','furniture-mobile','style_class','blogsidebar',0,''),(176297,56402,'118088','furniture-mobile','block_type','1',0,''),(176298,56402,'118088','furniture-mobile','padding-top','35',0,''),(176299,56402,'118088','furniture-mobile','padding-bottom','35',0,''),(176300,56403,'118089','furniture-mobile','block_type','7',0,''),(176301,56403,'118089','furniture-mobile','schema','7-2',0,'2885'),(176302,56404,'118090','furniture-mobile','block_type','1',0,''),(176303,56404,'118090','furniture-mobile','style_class','blog_list_content',0,''),(176304,56406,'118092','furniture-mobile','text-align','center',0,''),(176305,56406,'118092','furniture-mobile','hide_parents','1',0,''),(176306,56407,'118093','furniture-mobile','aria_name','blogsidebar',0,''),(176307,56407,'118093','furniture-mobile','style_class','blogsidebar',0,''),(176308,56408,'116208','furniture-mobile','block_type','1',0,''),(176309,56412,'118094','furniture-mobile','block_type','1',0,''),(176310,56413,'118095','furniture-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(176311,56415,'118097','furniture-mobile','block_type','1',0,''),(176312,56416,'118098','furniture-mobile','text','<div class=\"heading-2\">##DISCOUNT##</div>',0,''),(176313,56416,'118098','furniture-mobile','text-align','center',0,''),(176314,56417,'118099','furniture-mobile','block_type','2',0,''),(176315,56417,'118099','furniture-mobile','margin-bottom','20',0,''),(176316,56418,'118100','furniture-mobile','block_type','1',0,''),(176317,56418,'118100','furniture-mobile','padding-right','20',0,''),(176318,56419,'118101','furniture-mobile','field','57',0,''),(176319,56420,'118102','furniture-mobile','field','56',0,''),(176320,56421,'118103','furniture-mobile','block_type','1',0,''),(176321,56421,'118103','furniture-mobile','padding-left','20',0,''),(176322,56422,'118104','furniture-mobile','field','59',0,''),(176323,56423,'118105','furniture-mobile','field','58',0,''),(176324,56424,'118106','furniture-mobile','block_type','2',0,''),(176325,56424,'118106','furniture-mobile','margin-bottom','20',0,''),(176326,56425,'118107','furniture-mobile','block_type','1',0,''),(176327,56425,'118107','furniture-mobile','padding-right','20',0,''),(176328,56426,'118108','furniture-mobile','field','51',0,''),(176329,56427,'118109','furniture-mobile','field','52',0,''),(176330,56428,'118110','furniture-mobile','text','<div class=\"heading-2\">##TEXT_CUSTOMER_DETAILS##</div>',0,''),(176331,56428,'118110','furniture-mobile','text-align','center',0,''),(176332,56429,'118111','furniture-mobile','block_type','2',0,''),(176333,56430,'118112','furniture-mobile','block_type','1',0,''),(176334,56430,'118112','furniture-mobile','padding-right','20',0,''),(176335,56431,'118113','furniture-mobile','group','15',0,''),(176336,56432,'118114','furniture-mobile','block_type','2',0,''),(176337,56432,'118114','furniture-mobile','border-bottom-width','1',0,''),(176338,56432,'118114','furniture-mobile','border-bottom-color','$border-color-4',0,''),(176339,56432,'118114','furniture-mobile','padding-bottom','10',0,''),(176340,56432,'118114','furniture-mobile','margin-bottom','20',0,''),(176341,56433,'118115','furniture-mobile','block_type','1',0,''),(176342,56433,'118115','furniture-mobile','padding-right','10',0,''),(176343,56434,'118116','furniture-mobile','field','73',0,''),(176344,56435,'118117','furniture-mobile','field','69',0,''),(176345,56436,'118118','furniture-mobile','field','71',0,''),(176346,56437,'118119','furniture-mobile','field','75',0,''),(176347,56438,'118120','furniture-mobile','block_type','1',0,''),(176348,56438,'118120','furniture-mobile','padding-left','10',0,''),(176349,56439,'118121','furniture-mobile','field','76',0,''),(176350,56440,'118122','furniture-mobile','field','70',0,''),(176351,56441,'118123','furniture-mobile','field','72',0,''),(176352,56442,'118124','furniture-mobile','field','74',0,''),(176353,56443,'118125','furniture-mobile','block_type','2',0,''),(176354,56444,'118126','furniture-mobile','field','68',0,''),(176355,56444,'118126','furniture-mobile','padding-right','10',0,''),(176356,56445,'118127','furniture-mobile','text','<div class=\"heading-3\">##CATEGORY_COMPANY##</div>',0,''),(176357,56446,'118128','furniture-mobile','block_type','1',0,''),(176358,56446,'118128','furniture-mobile','padding-left','20',0,''),(176359,56447,'118129','furniture-mobile','group','16',0,''),(176360,56448,'118130','furniture-mobile','text','<div class=\"heading-3\">##OWNERS_DETAILS##</div>',0,''),(176361,56449,'118131','furniture-mobile','block_type','2',0,''),(176362,56450,'118132','furniture-mobile','block_type','1',0,''),(176363,56450,'118132','furniture-mobile','padding-right','10',0,''),(176364,56451,'118133','furniture-mobile','field','84',0,''),(176365,56452,'118134','furniture-mobile','field','80',0,''),(176366,56453,'118135','furniture-mobile','field','82',0,''),(176367,56454,'118136','furniture-mobile','block_type','1',0,''),(176368,56454,'118136','furniture-mobile','padding-left','10',0,''),(176369,56455,'118137','furniture-mobile','field','81',0,''),(176370,56456,'118138','furniture-mobile','field','85',0,''),(176371,56457,'118139','furniture-mobile','field','83',0,''),(176372,56458,'118140','furniture-mobile','block_type','2',0,''),(176373,56459,'118141','furniture-mobile','block_type','1',0,''),(176374,56459,'118141','furniture-mobile','padding-right','10',0,''),(176375,56460,'118142','furniture-mobile','field','79',0,''),(176376,56461,'118143','furniture-mobile','field','77',0,''),(176377,56462,'118144','furniture-mobile','block_type','1',0,''),(176378,56462,'118144','furniture-mobile','padding-left','10',0,''),(176379,56463,'118145','furniture-mobile','field','78',0,''),(176380,56464,'118146','furniture-mobile','text','<h1>##TRADE_FORM##</h1>',0,''),(176381,56465,'118147','furniture-mobile','block_type','2',0,''),(176382,56465,'118147','furniture-mobile','margin-bottom','20',0,''),(176383,56466,'118148','furniture-mobile','block_type','1',0,''),(176384,56466,'118148','furniture-mobile','padding-right','20',0,''),(176385,56467,'118149','furniture-mobile','field','54',0,''),(176386,56468,'118150','furniture-mobile','field','53',0,''),(176387,56469,'118151','furniture-mobile','block_type','1',0,''),(176388,56469,'118151','furniture-mobile','padding-left','20',0,''),(176389,56470,'118152','furniture-mobile','field','55',0,''),(176390,56471,'118153','furniture-mobile','text','<div class=\"heading-2\">##TRADE_REFERENCES##</div>',0,''),(176391,56471,'118153','furniture-mobile','text-align','center',0,''),(176392,56472,'118154','furniture-mobile','text','<div class=\"heading-2\">##BANK_ACCOUNT_DETAILS##</div>',0,''),(176393,56472,'118154','furniture-mobile','text-align','center',0,''),(176394,56473,'118155','furniture-mobile','block_type','2',0,''),(176395,56473,'118155','furniture-mobile','margin-bottom','20',0,''),(176396,56474,'118156','furniture-mobile','block_type','1',0,''),(176397,56474,'118156','furniture-mobile','padding-right','20',0,''),(176398,56475,'118157','furniture-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 1</div>',0,''),(176399,56476,'118158','furniture-mobile','field','60',0,''),(176400,56477,'118159','furniture-mobile','field','62',0,''),(176401,56478,'118160','furniture-mobile','field','61',0,''),(176402,56479,'118161','furniture-mobile','block_type','1',0,''),(176403,56479,'118161','furniture-mobile','padding-left','20',0,''),(176404,56480,'118162','furniture-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 2</div>',0,''),(176405,56481,'118163','furniture-mobile','field','63',0,''),(176406,56482,'118164','furniture-mobile','field','64',0,''),(176407,56483,'118165','furniture-mobile','field','65',0,''),(176408,56484,'118166','furniture-mobile','text','<div class=\"heading-2\">##TEXT_DECLARATION##</div>',0,''),(176409,56484,'118166','furniture-mobile','text-align','center',0,''),(176410,56485,'118167','furniture-mobile','block_type','2',0,''),(176411,56485,'118167','furniture-mobile','margin-bottom','20',0,''),(176412,56486,'118168','furniture-mobile','block_type','1',0,''),(176413,56486,'118168','furniture-mobile','padding-right','20',0,''),(176414,56487,'118169','furniture-mobile','field','66',0,''),(176415,56488,'118170','furniture-mobile','block_type','1',0,''),(176416,56488,'118170','furniture-mobile','padding-left','20',0,''),(176417,56489,'118171','furniture-mobile','field','67',0,''),(176418,56490,'118172','furniture-mobile','block_type','2',0,''),(176419,56490,'118172','furniture-mobile','margin-bottom','20',0,''),(176420,56492,'118174','furniture-mobile','float','right',0,''),(176421,56492,'118174','furniture-mobile','margin-left','20',0,''),(176422,56493,'118175','furniture-mobile','float','right',0,''),(176423,56493,'118175','furniture-mobile','clear','none',0,''),(176424,56494,'118176','furniture-mobile','block_type','2',0,''),(176425,56494,'118176','furniture-mobile','margin-bottom','20',0,''),(176426,56495,'118177','furniture-mobile','block_type','1',0,''),(176427,56495,'118177','furniture-mobile','padding-right','20',0,''),(176428,56496,'118178','furniture-mobile','field','50',0,''),(176429,56497,'118179','furniture-mobile','field','49',0,''),(176430,56498,'118180','furniture-mobile','block_type','1',0,''),(176431,56499,'118181','furniture-mobile','block_type','1',0,''),(176432,56500,'118182','furniture-mobile','text','Scottish books of exceptional value',0,''),(176433,56500,'118182','furniture-mobile','font-size','20',0,''),(176434,56500,'118182','furniture-mobile','text-align','center',0,''),(176435,56500,'118182','furniture-mobile','padding-top','20',0,''),(176436,56501,'118183','furniture-mobile','block_type','14',0,''),(176437,56502,'118184','furniture-mobile','text','Name in Full',0,''),(176438,56502,'118184','furniture-mobile','text-align','right',0,''),(176439,56503,'118185','furniture-mobile','field','66',0,''),(176440,56503,'118185','furniture-mobile','padding-left','10',0,''),(176441,56503,'118185','furniture-mobile','border-bottom-width','1',0,''),(176442,56503,'118185','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176443,56504,'118186','furniture-mobile','text','Position',0,''),(176444,56504,'118186','furniture-mobile','text-align','right',0,''),(176445,56505,'118187','furniture-mobile','field','67',0,''),(176446,56505,'118187','furniture-mobile','border-bottom-width','1',0,''),(176447,56505,'118187','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176448,56505,'118187','furniture-mobile','padding-left','10',0,''),(176449,56506,'118188','furniture-mobile','block_type','14',0,''),(176450,56507,'118189','furniture-mobile','text','Signed',0,''),(176451,56507,'118189','furniture-mobile','text-align','right',0,''),(176452,56508,'118190','furniture-mobile','text','&nbsp;',0,''),(176453,56508,'118190','furniture-mobile','border-bottom-width','1',0,''),(176454,56508,'118190','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176455,56509,'118191','furniture-mobile','text','Date',0,''),(176456,56509,'118191','furniture-mobile','text-align','right',0,''),(176457,56510,'118192','furniture-mobile','text','&nbsp;',0,''),(176458,56510,'118192','furniture-mobile','border-bottom-width','1',0,''),(176459,56510,'118192','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176460,56511,'118193','furniture-mobile','block_type','6',0,''),(176461,56512,'118194','furniture-mobile','text','Name',0,''),(176462,56512,'118194','furniture-mobile','text-align','right',0,''),(176463,56512,'118194','furniture-mobile','font-size','16',0,''),(176464,56513,'118195','furniture-mobile','field','60',0,''),(176465,56513,'118195','furniture-mobile','border-bottom-width','1',0,''),(176466,56513,'118195','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176467,56513,'118195','furniture-mobile','padding-left','10',0,''),(176468,56514,'118196','furniture-mobile','block_type','1',0,''),(176469,56515,'118197','furniture-mobile','text','I would like to open a trade account with Vladislav B. Malyshev and agree to abide by their General Terms & Conditions –\na signed copy of which is returned to them with this form in the supplied SAE. I have retained a copy for my reference. I\nam authorised to sign on behalf of the company I represent.',0,''),(176470,56515,'118197','furniture-mobile','font-size','15',0,''),(176471,56515,'118197','furniture-mobile','padding-left','10',0,''),(176472,56515,'118197','furniture-mobile','padding-right','10',0,''),(176473,56516,'118198','furniture-mobile','block_type','6',0,''),(176474,56516,'118198','furniture-mobile','padding-bottom','20',0,''),(176475,56517,'118199','furniture-mobile','text','Telephone No.',0,''),(176476,56517,'118199','furniture-mobile','text-align','right',0,''),(176477,56518,'118200','furniture-mobile','field','62',0,''),(176478,56518,'118200','furniture-mobile','border-bottom-width','1',0,''),(176479,56518,'118200','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176480,56518,'118200','furniture-mobile','padding-left','10',0,''),(176481,56519,'118201','furniture-mobile','block_type','1',0,''),(176482,56519,'118201','furniture-mobile','padding-bottom','10',0,''),(176483,56520,'118202','furniture-mobile','background-color','$background-1',0,''),(176484,56520,'118202','furniture-mobile','color','$color-font-1',0,''),(176485,56520,'118202','furniture-mobile','font-size','20',0,''),(176486,56520,'118202','furniture-mobile','text','Customer Details',0,''),(176487,56520,'118202','furniture-mobile','padding-left','10',0,''),(176488,56520,'118202','furniture-mobile','padding-right','10',0,''),(176489,56521,'118203','furniture-mobile','block_type','1',0,''),(176490,56521,'118203','furniture-mobile','padding-bottom','10',0,''),(176491,56522,'118204','furniture-mobile','background-color','$background-1',0,''),(176492,56522,'118204','furniture-mobile','color','$color-font-1',0,''),(176493,56522,'118204','furniture-mobile','font-size','20',0,''),(176494,56522,'118204','furniture-mobile','text','Trade References',0,''),(176495,56522,'118204','furniture-mobile','padding-left','10',0,''),(176496,56522,'118204','furniture-mobile','padding-right','10',0,''),(176497,56523,'118205','furniture-mobile','block_type','6',0,''),(176498,56524,'118206','furniture-mobile','text','Address',0,''),(176499,56524,'118206','furniture-mobile','text-align','right',0,''),(176500,56525,'118207','furniture-mobile','field','61',0,''),(176501,56525,'118207','furniture-mobile','border-bottom-width','1',0,''),(176502,56525,'118207','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176503,56525,'118207','furniture-mobile','padding-left','10',0,''),(176504,56526,'118208','furniture-mobile','block_type','6',0,''),(176505,56527,'118209','furniture-mobile','text','Address',0,''),(176506,56527,'118209','furniture-mobile','text-align','right',0,''),(176507,56528,'118210','furniture-mobile','field','55',0,''),(176508,56528,'118210','furniture-mobile','border-bottom-width','1',0,''),(176509,56528,'118210','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176510,56528,'118210','furniture-mobile','padding-left','10',0,''),(176511,56529,'118211','furniture-mobile','block_type','14',0,''),(176512,56529,'118211','furniture-mobile','padding-bottom','20',0,''),(176513,56530,'118212','furniture-mobile','text','33.33% Sale or Return',0,''),(176514,56530,'118212','furniture-mobile','text-align','right',0,''),(176515,56530,'118212','furniture-mobile','font-size','16',0,''),(176516,56531,'118213','furniture-mobile','block_type','13',0,''),(176517,56532,'118214','furniture-mobile','field','56',0,''),(176518,56532,'118214','furniture-mobile','padding-left','10',0,''),(176519,56533,'118215','furniture-mobile','text','35% Firm',0,''),(176520,56533,'118215','furniture-mobile','text-align','right',0,''),(176521,56534,'118216','furniture-mobile','field','58',0,''),(176522,56534,'118216','furniture-mobile','padding-left','10',0,''),(176523,56535,'118217','furniture-mobile','block_type','10',0,''),(176524,56536,'118218','furniture-mobile','block_type','6',0,''),(176525,56537,'118219','furniture-mobile','text','Bank Name',0,''),(176526,56537,'118219','furniture-mobile','text-align','right',0,''),(176527,56537,'118219','furniture-mobile','font-size','16',0,''),(176528,56538,'118220','furniture-mobile','field','53',0,''),(176529,56538,'118220','furniture-mobile','border-bottom-width','1',0,''),(176530,56538,'118220','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176531,56538,'118220','furniture-mobile','padding-left','10',0,''),(176532,56539,'118221','furniture-mobile','block_type','1',0,''),(176533,56539,'118221','furniture-mobile','padding-top','20',0,''),(176534,56539,'118221','furniture-mobile','padding-bottom','10',0,''),(176535,56540,'118222','furniture-mobile','background-color','$background-1',0,''),(176536,56540,'118222','furniture-mobile','color','$color-font-1',0,''),(176537,56540,'118222','furniture-mobile','font-size','20',0,''),(176538,56540,'118222','furniture-mobile','text','Discount (%)',0,''),(176539,56540,'118222','furniture-mobile','padding-left','10',0,''),(176540,56540,'118222','furniture-mobile','padding-right','10',0,''),(176541,56541,'118223','furniture-mobile','block_type','6',0,''),(176542,56541,'118223','furniture-mobile','padding-bottom','20',0,''),(176543,56542,'118224','furniture-mobile','text','Account No',0,''),(176544,56542,'118224','furniture-mobile','text-align','right',0,''),(176545,56543,'118225','furniture-mobile','field','54',0,''),(176546,56543,'118225','furniture-mobile','border-bottom-width','1',0,''),(176547,56543,'118225','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176548,56543,'118225','furniture-mobile','padding-left','10',0,''),(176549,56544,'118226','furniture-mobile','block_type','1',0,''),(176550,56544,'118226','furniture-mobile','padding-bottom','10',0,''),(176551,56545,'118227','furniture-mobile','background-color','$background-1',0,''),(176552,56545,'118227','furniture-mobile','color','$color-font-1',0,''),(176553,56545,'118227','furniture-mobile','font-size','20',0,''),(176554,56545,'118227','furniture-mobile','text','Bank Account Details',0,''),(176555,56545,'118227','furniture-mobile','padding-left','10',0,''),(176556,56545,'118227','furniture-mobile','padding-right','10',0,''),(176557,56546,'118228','furniture-mobile','block_type','6',0,''),(176558,56546,'118228','furniture-mobile','padding-bottom','20',0,''),(176559,56547,'118229','furniture-mobile','text','Nature of Business',0,''),(176560,56547,'118229','furniture-mobile','text-align','right',0,''),(176561,56548,'118230','furniture-mobile','field','52',0,''),(176562,56548,'118230','furniture-mobile','border-bottom-width','1',0,''),(176563,56548,'118230','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176564,56548,'118230','furniture-mobile','padding-left','10',0,''),(176565,56549,'118231','furniture-mobile','block_type','6',0,''),(176566,56550,'118232','furniture-mobile','text','Telephone No.',0,''),(176567,56550,'118232','furniture-mobile','text-align','right',0,''),(176568,56551,'118233','furniture-mobile','field','79',0,''),(176569,56551,'118233','furniture-mobile','border-bottom-width','1',0,''),(176570,56551,'118233','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176571,56551,'118233','furniture-mobile','padding-left','10',0,''),(176572,56552,'118234','furniture-mobile','block_type','6',0,''),(176573,56553,'118235','furniture-mobile','text','Address',0,''),(176574,56553,'118235','furniture-mobile','text-align','right',0,''),(176575,56554,'118236','furniture-mobile','fields','company_street_address, company_suburb, company_city',0,''),(176576,56554,'118236','furniture-mobile','padding-left','10',0,''),(176577,56554,'118236','furniture-mobile','border-bottom-width','1',0,''),(176578,56554,'118236','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176579,56555,'118237','furniture-mobile','block_type','6',0,''),(176580,56556,'118238','furniture-mobile','text','Postcode',0,''),(176581,56556,'118238','furniture-mobile','text-align','right',0,''),(176582,56557,'118239','furniture-mobile','field','80',0,''),(176583,56557,'118239','furniture-mobile','border-bottom-width','1',0,''),(176584,56557,'118239','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176585,56557,'118239','furniture-mobile','padding-left','10',0,''),(176586,56558,'118240','furniture-mobile','block_type','6',0,''),(176587,56559,'118241','furniture-mobile','text','Address',0,''),(176588,56559,'118241','furniture-mobile','text-align','right',0,''),(176589,56560,'118242','furniture-mobile','fields','oner_street_address, owner_suburb, owner_city',0,''),(176590,56560,'118242','furniture-mobile','padding-left','10',0,''),(176591,56560,'118242','furniture-mobile','border-bottom-width','1',0,''),(176592,56560,'118242','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176593,56561,'118243','furniture-mobile','block_type','6',0,''),(176594,56562,'118244','furniture-mobile','text','Email',0,''),(176595,56562,'118244','furniture-mobile','text-align','right',0,''),(176596,56563,'118245','furniture-mobile','field','70',0,''),(176597,56563,'118245','furniture-mobile','border-bottom-width','1',0,''),(176598,56563,'118245','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176599,56563,'118245','furniture-mobile','padding-left','10',0,''),(176600,56564,'118246','furniture-mobile','block_type','6',0,''),(176601,56564,'118246','furniture-mobile','margin-top','20',0,''),(176602,56565,'118247','furniture-mobile','text','Owner’s Name',0,''),(176603,56565,'118247','furniture-mobile','text-align','right',0,''),(176604,56566,'118248','furniture-mobile','fields','owner_firstname owner_lastname',0,''),(176605,56566,'118248','furniture-mobile','padding-left','10',0,''),(176606,56566,'118248','furniture-mobile','border-bottom-width','1',0,''),(176607,56566,'118248','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176608,56567,'118249','furniture-mobile','block_type','6',0,''),(176609,56567,'118249','furniture-mobile','padding-bottom','20',0,''),(176610,56568,'118250','furniture-mobile','text','Telephone No.',0,''),(176611,56568,'118250','furniture-mobile','text-align','right',0,''),(176612,56569,'118251','furniture-mobile','block_type','11',0,''),(176613,56570,'118252','furniture-mobile','field','69',0,''),(176614,56570,'118252','furniture-mobile','border-bottom-width','1',0,''),(176615,56570,'118252','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176616,56570,'118252','furniture-mobile','padding-left','10',0,''),(176617,56570,'118252','furniture-mobile','cells','34',0,''),(176618,56571,'118253','furniture-mobile','block_type','5',0,''),(176619,56572,'118254','furniture-mobile','text','Fax No.',0,''),(176620,56572,'118254','furniture-mobile','text-align','right',0,''),(176621,56573,'118255','furniture-mobile','field','51',0,''),(176622,56573,'118255','furniture-mobile','padding-left','10',0,''),(176623,56573,'118255','furniture-mobile','border-bottom-width','1',0,''),(176624,56573,'118255','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176625,56574,'118256','furniture-mobile','block_type','1',0,''),(176626,56575,'118257','furniture-mobile','background-color','$background-1',0,''),(176627,56575,'118257','furniture-mobile','color','$color-font-1',0,''),(176628,56575,'118257','furniture-mobile','font-size','20',0,''),(176629,56575,'118257','furniture-mobile','text','Customer Details',0,''),(176630,56575,'118257','furniture-mobile','padding-left','10',0,''),(176631,56575,'118257','furniture-mobile','padding-right','10',0,''),(176632,56576,'118258','furniture-mobile','block_type','2',0,''),(176633,56577,'118259','furniture-mobile','block_type','2',0,''),(176634,56577,'118259','furniture-mobile','padding-top','5',0,''),(176635,56578,'118260','furniture-mobile','block_type','10',0,''),(176636,56579,'118261','furniture-mobile','text','Limited Company',0,''),(176637,56579,'118261','furniture-mobile','font-size','16',0,''),(176638,56580,'118262','furniture-mobile','field','49',0,''),(176639,56580,'118262','furniture-mobile','padding-left','5',0,''),(176640,56581,'118263','furniture-mobile','block_type','10',0,''),(176641,56582,'118264','furniture-mobile','text','Sole Trader',0,''),(176642,56582,'118264','furniture-mobile','text-align','center',0,''),(176643,56583,'118265','furniture-mobile','field','50',0,''),(176644,56583,'118265','furniture-mobile','padding-left','5',0,''),(176645,56584,'118266','furniture-mobile','block_type','2',0,''),(176646,56584,'118266','furniture-mobile','color','$color-font-1',0,''),(176647,56584,'118266','furniture-mobile','background-color','$background-1',0,''),(176648,56585,'118267','furniture-mobile','view_item','name',0,''),(176649,56585,'118267','furniture-mobile','color','$color-font-1',0,''),(176650,56585,'118267','furniture-mobile','font-size','40',0,''),(176651,56586,'118268','furniture-mobile','text','New Account Form',0,''),(176652,56586,'118268','furniture-mobile','font-size','20',0,''),(176653,56586,'118268','furniture-mobile','color','$color-font-1',0,''),(176654,56586,'118268','furniture-mobile','padding-top','20',0,''),(176655,56587,'118269','furniture-mobile','block_type','5',0,''),(176656,56588,'118270','furniture-mobile','view_item','data_format',0,''),(176657,56588,'118270','furniture-mobile','data_format_content','##STREET_ADDRESS##, ##SUBURB##,\n##CITY##, ##POSTCODE##\nTel: ##TELEPHONE##\nEmail: ##EMAIL_ADDRESS##\n',0,''),(176658,56588,'118270','furniture-mobile','font-size','14',0,''),(176659,56589,'118271','furniture-mobile','block_type','6',0,''),(176660,56590,'118272','furniture-mobile','text','Business Name',0,''),(176661,56590,'118272','furniture-mobile','text-align','right',0,''),(176662,56591,'118273','furniture-mobile','field','68',0,''),(176663,56591,'118273','furniture-mobile','border-bottom-width','1',0,''),(176664,56591,'118273','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176665,56591,'118273','furniture-mobile','padding-left','10',0,''),(176666,56592,'118274','furniture-mobile','block_type','6',0,''),(176667,56593,'118275','furniture-mobile','text','Postcode',0,''),(176668,56593,'118275','furniture-mobile','text-align','right',0,''),(176669,56594,'118276','furniture-mobile','field','71',0,''),(176670,56594,'118276','furniture-mobile','border-bottom-width','1',0,''),(176671,56594,'118276','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176672,56594,'118276','furniture-mobile','padding-left','10',0,''),(176677,56598,'118280','furniture-mobile','margin-bottom','20',0,''),(176678,56598,'118280','furniture-mobile','max-width','500',0,''),(176797,56636,'118318','furniture-mobile','block_type','1',0,''),(176798,56637,'118319','furniture-mobile','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(176799,56637,'118319','furniture-mobile','padding-top','100',0,''),(176800,56637,'118319','furniture-mobile','margin-bottom','100',0,''),(176801,56637,'118319','furniture-mobile','text-align','center',0,''),(176802,56637,'118319','furniture-mobile','font-size','20',0,''),(176803,56638,'118320','furniture-mobile','block_type','1',0,''),(176804,56638,'118320','furniture-mobile','background-color','$background-6',0,''),(176805,56638,'118320','furniture-mobile','padding-bottom','30',0,''),(176806,56639,'118321','furniture-mobile','block_type','4',0,''),(176807,56639,'118321','furniture-mobile','schema','4-2',0,'2885'),(176808,56640,'118322','furniture-mobile','block_type','1',0,''),(176809,56640,'118322','furniture-mobile','padding-right','40',0,''),(176810,56640,'118322','furniture-mobile','padding-right','0',0,'2885'),(176811,56641,'118323','furniture-mobile','block_type','2',0,''),(176812,56641,'118323','furniture-mobile','margin-bottom','20',0,''),(176813,56641,'118323','furniture-mobile','schema','2-2',0,'2876'),(176814,56641,'118323','furniture-mobile','background-color','$background-7',0,''),(176815,56642,'118324','furniture-mobile','block_type','1',0,''),(176816,56642,'118324','furniture-mobile','border-right-width','20',0,''),(176817,56642,'118324','furniture-mobile','border-right-color','$border-color-4',0,''),(176818,56642,'118324','furniture-mobile','margin-right','-10',0,''),(176819,56642,'118324','furniture-mobile','padding-right','30',0,''),(176820,56642,'118324','furniture-mobile','padding-top','20',0,''),(176821,56642,'118324','furniture-mobile','padding-left','30',0,''),(176822,56642,'118324','furniture-mobile','padding-bottom','20',0,''),(176823,56642,'118324','furniture-mobile','border-right-width','0',0,'2885'),(176824,56642,'118324','furniture-mobile','margin-right','0',0,'2885'),(176825,56642,'118324','furniture-mobile','margin-bottom','20',0,'2885'),(176826,56642,'118324','furniture-mobile','padding-left','20',0,'2885'),(176827,56642,'118324','furniture-mobile','padding-right','20',0,'2885'),(176828,56644,'118326','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(176829,56644,'118326','furniture-mobile','clear','none',0,''),(176830,56645,'118327','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(176831,56645,'118327','furniture-mobile','clear','none',0,''),(176832,56646,'118328','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(176833,56648,'118330','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(176834,56648,'118330','furniture-mobile','padding-top','20',0,''),(176835,56651,'118333','furniture-mobile','margin-bottom','20',0,''),(176836,56652,'118334','furniture-mobile','block_type','1',0,''),(176837,56652,'118334','furniture-mobile','padding-left','30',0,''),(176838,56652,'118334','furniture-mobile','border-left-width','20',0,''),(176839,56652,'118334','furniture-mobile','border-left-color','$border-color-4',0,''),(176840,56652,'118334','furniture-mobile','margin-left','-10',0,''),(176841,56652,'118334','furniture-mobile','padding-right','30',0,''),(176842,56652,'118334','furniture-mobile','padding-top','20',0,''),(176843,56652,'118334','furniture-mobile','padding-bottom','20',0,''),(176844,56652,'118334','furniture-mobile','border-left-width','0',0,'2885'),(176845,56653,'118335','furniture-mobile','margin-bottom','20',0,''),(176846,56655,'118337','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(176847,56656,'118338','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(176848,56656,'118338','furniture-mobile','clear','none',0,''),(176849,56657,'118339','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(176850,56657,'118339','furniture-mobile','clear','none',0,''),(176851,56658,'118340','furniture-mobile','block_type','1',0,''),(176852,56658,'118340','furniture-mobile','padding-right','30',0,''),(176853,56658,'118340','furniture-mobile','background-color','$background-7',0,''),(176854,56658,'118340','furniture-mobile','padding-top','20',0,''),(176855,56658,'118340','furniture-mobile','padding-left','30',0,''),(176856,56658,'118340','furniture-mobile','padding-bottom','20',0,''),(176857,56658,'118340','furniture-mobile','padding-left','20',0,'2885'),(176858,56658,'118340','furniture-mobile','padding-right','20',0,'2885'),(176859,56660,'118342','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(176860,56661,'118343','furniture-mobile','block_type','1',0,''),(176861,56661,'118343','furniture-mobile','padding-top','20',0,''),(176862,56661,'118343','furniture-mobile','padding-left','20',0,''),(176863,56661,'118343','furniture-mobile','padding-right','20',0,''),(176864,56661,'118343','furniture-mobile','padding-bottom','20',0,''),(176865,56661,'118343','furniture-mobile','background-color','$background-7',0,''),(176866,56661,'118343','furniture-mobile','style_class','order-summary',0,''),(176867,56662,'118344','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(176868,56666,'118348','furniture-mobile','block_type','1',0,''),(176869,56666,'118348','furniture-mobile','background-color','$background-6',0,''),(176870,56666,'118348','furniture-mobile','padding-bottom','30',0,''),(176871,56667,'118349','furniture-mobile','block_type','4',0,''),(176872,56667,'118349','furniture-mobile','schema','4-2',0,'2885'),(176873,56668,'118350','furniture-mobile','block_type','1',0,''),(176874,56668,'118350','furniture-mobile','padding-right','40',0,''),(176875,56668,'118350','furniture-mobile','padding-right','0',0,'2885'),(176876,56669,'118351','furniture-mobile','block_type','2',0,''),(176877,56669,'118351','furniture-mobile','margin-bottom','20',0,''),(176878,56669,'118351','furniture-mobile','schema','2-2',0,'2876'),(176879,56669,'118351','furniture-mobile','background-color','$background-7',0,''),(176880,56670,'118352','furniture-mobile','block_type','1',0,''),(176881,56670,'118352','furniture-mobile','border-right-width','20',0,''),(176882,56670,'118352','furniture-mobile','border-right-color','$border-color-4',0,''),(176883,56670,'118352','furniture-mobile','margin-right','-10',0,''),(176884,56670,'118352','furniture-mobile','padding-right','30',0,''),(176885,56670,'118352','furniture-mobile','padding-top','20',0,''),(176886,56670,'118352','furniture-mobile','padding-left','30',0,''),(176887,56670,'118352','furniture-mobile','padding-bottom','20',0,''),(176888,56670,'118352','furniture-mobile','border-right-width','0',0,'2885'),(176889,56670,'118352','furniture-mobile','margin-right','0',0,'2885'),(176890,56670,'118352','furniture-mobile','margin-bottom','20',0,'2885'),(176891,56670,'118352','furniture-mobile','padding-left','20',0,'2885'),(176892,56670,'118352','furniture-mobile','padding-right','20',0,'2885'),(176893,56671,'118353','furniture-mobile','margin-bottom','20',0,''),(176894,56674,'118356','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(176895,56674,'118356','furniture-mobile','padding-top','20',0,''),(176896,56676,'118358','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(176897,56676,'118358','furniture-mobile','clear','none',0,''),(176898,56678,'118360','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(176899,56679,'118361','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(176900,56679,'118361','furniture-mobile','clear','none',0,''),(176901,56681,'118362','furniture-mobile','block_type','1',0,''),(176902,56681,'118362','furniture-mobile','padding-left','30',0,''),(176903,56681,'118362','furniture-mobile','border-left-width','20',0,''),(176904,56681,'118362','furniture-mobile','border-left-color','$border-color-4',0,''),(176905,56681,'118362','furniture-mobile','margin-left','-10',0,''),(176906,56681,'118362','furniture-mobile','padding-right','30',0,''),(176907,56681,'118362','furniture-mobile','padding-top','20',0,''),(176908,56681,'118362','furniture-mobile','padding-bottom','20',0,''),(176909,56681,'118362','furniture-mobile','border-left-width','0',0,'2885'),(176910,56682,'118363','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(176911,56683,'118364','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(176912,56683,'118364','furniture-mobile','clear','none',0,''),(176913,56684,'118365','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(176914,56684,'118365','furniture-mobile','clear','none',0,''),(176915,56685,'118366','furniture-mobile','margin-bottom','20',0,''),(176916,56686,'118367','furniture-mobile','orders_data','name',0,''),(176917,56687,'118368','furniture-mobile','block_type','1',0,''),(176918,56687,'118368','furniture-mobile','padding-right','30',0,''),(176919,56687,'118368','furniture-mobile','background-color','$background-7',0,''),(176920,56687,'118368','furniture-mobile','padding-top','20',0,''),(176921,56687,'118368','furniture-mobile','padding-left','30',0,''),(176922,56687,'118368','furniture-mobile','padding-bottom','20',0,''),(176923,56687,'118368','furniture-mobile','padding-left','20',0,'2885'),(176924,56687,'118368','furniture-mobile','padding-right','20',0,'2885'),(176925,56688,'118369','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(176926,56690,'118371','furniture-mobile','block_type','1',0,''),(176927,56690,'118371','furniture-mobile','padding-top','20',0,''),(176928,56690,'118371','furniture-mobile','padding-left','20',0,''),(176929,56690,'118371','furniture-mobile','padding-right','20',0,''),(176930,56690,'118371','furniture-mobile','padding-bottom','20',0,''),(176931,56690,'118371','furniture-mobile','background-color','$background-7',0,''),(176932,56690,'118371','furniture-mobile','style_class','order-summary',0,''),(176933,56693,'118374','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(176934,56695,'118392','furniture-mobile','margin-bottom','10',0,''),(176935,56696,'1639406339.5675','furniture-mobile','block_type','1',0,''),(176936,56697,'118381','furniture-mobile','margin-bottom','30',0,''),(176937,56698,'118382','furniture-mobile','like_button','1',0,''),(176938,56698,'118382','furniture-mobile','text-align','center',0,''),(176939,56698,'118382','furniture-mobile','margin-bottom','20',0,''),(176940,56698,'118382','furniture-mobile','margin-top','20',0,''),(176941,56698,'118382','furniture-mobile','padding-top','30',0,''),(176942,56698,'118382','furniture-mobile','border-top-width','1',0,''),(176943,56698,'118382','furniture-mobile','border-top-color','$border-color-3',0,''),(176944,56698,'118382','furniture-mobile','padding-bottom','30',0,''),(176945,56698,'118382','furniture-mobile','border-bottom-width','1',0,''),(176946,56698,'118382','furniture-mobile','border-bottom-color','$border-color-3',0,''),(176947,56699,'118383','furniture-mobile','block_type','13',0,''),(176948,56699,'118383','furniture-mobile','margin-bottom','20',0,''),(176949,56699,'118383','furniture-mobile','schema','13-2',0,'2890'),(176950,56699,'118383','furniture-mobile','schema','13-4',0,'2876'),(176951,56700,'118384','furniture-mobile','position','relative',0,''),(176952,56700,'118384','furniture-mobile','margin-top','-100',0,''),(176953,56700,'118384','furniture-mobile','margin-top','-50',0,'2876'),(176954,56701,'118385','furniture-mobile','font-family','$font-1',0,''),(176955,56701,'118385','furniture-mobile','font-size','18',0,''),(176956,56701,'118385','furniture-mobile','margin-bottom','10',0,''),(176957,56701,'118385','furniture-mobile','text-align','center',0,'2890'),(176958,56702,'118386','furniture-mobile','font-family','$font-1',0,''),(176959,56702,'118386','furniture-mobile','font-size','30',0,''),(176960,56702,'118386','furniture-mobile','text-transform','uppercase',0,''),(176961,56702,'118386','furniture-mobile','text-align','center',0,'2890'),(176962,56702,'118386','furniture-mobile','font-size','26',0,'2876'),(176963,56702,'118386','furniture-mobile','padding-top','20',0,'2885'),(176964,56703,'118387','furniture-mobile','block_type','1',0,''),(176965,56703,'118387','furniture-mobile','float','left',0,''),(176966,56703,'118387','furniture-mobile','float','none',0,'2890'),(176967,56704,'118388','furniture-mobile','display','inline-block',0,''),(176968,56704,'118388','furniture-mobile','font-weight','700',0,''),(176969,56705,'118389','furniture-mobile','font-weight','700',0,''),(176970,56705,'118389','furniture-mobile','clear','none',0,''),(176971,56705,'118389','furniture-mobile','padding-left','20',0,''),(176972,56705,'118389','furniture-mobile','display','inline-block',0,''),(176973,56706,'118390','furniture-mobile','clear','none',0,''),(176974,56706,'118390','furniture-mobile','padding-left','20',0,''),(176975,56706,'118390','furniture-mobile','font-weight','700',0,''),(176976,56706,'118390','furniture-mobile','display','inline-block',0,''),(176977,56707,'118391','furniture-mobile','font-weight','700',0,''),(176978,56707,'118391','furniture-mobile','text-align','right',0,''),(176979,56707,'118391','furniture-mobile','text-align','center',0,'2876'),(176980,56707,'118391','furniture-mobile','padding-top','15',0,'2876'),(176988,56711,'118396','furniture-mobile','block_type','1',0,''),(176989,56711,'118396','furniture-mobile','padding-top','20',0,''),(176990,56711,'118396','furniture-mobile','padding-bottom','20',0,''),(176991,56712,'118397','furniture-mobile','block_type','1',0,''),(176992,56712,'118397','furniture-mobile','border-top-width','1',0,''),(176993,56712,'118397','furniture-mobile','border-left-width','1',0,''),(176994,56712,'118397','furniture-mobile','border-right-width','1',0,''),(176995,56712,'118397','furniture-mobile','border-bottom-width','1',0,''),(176996,56712,'118397','furniture-mobile','border-top-color','$border-color-3',0,''),(176997,56712,'118397','furniture-mobile','border-left-color','$border-color-3',0,''),(176998,56712,'118397','furniture-mobile','border-right-color','$border-color-3',0,''),(176999,56712,'118397','furniture-mobile','border-bottom-color','$border-color-3',0,''),(177000,56712,'118397','furniture-mobile','padding-top','15',0,''),(177001,56712,'118397','furniture-mobile','padding-left','15',0,''),(177002,56712,'118397','furniture-mobile','padding-right','15',0,''),(177003,56712,'118397','furniture-mobile','padding-bottom','15',0,''),(177004,56712,'118397','furniture-mobile','margin-bottom','50',0,''),(177005,56713,'118398','furniture-mobile','block_type','1',0,''),(177006,56713,'118398','furniture-mobile','padding-top','20',0,''),(177007,56713,'118398','furniture-mobile','padding-left','20',0,''),(177008,56713,'118398','furniture-mobile','padding-right','20',0,''),(177009,56713,'118398','furniture-mobile','background-color','$background-7',0,''),(177010,56713,'118398','furniture-mobile','padding-top','10',0,'2906'),(177011,56713,'118398','furniture-mobile','padding-left','0',0,'2906'),(177012,56713,'118398','furniture-mobile','padding-right','0',0,'2906'),(177013,56715,'118400','furniture-mobile','text','<h1>##FIND_REGISTRY##</h1>',0,''),(177014,56717,'118402','furniture-mobile','padding-top','10',0,''),(177015,56717,'118402','furniture-mobile','padding-bottom','10',0,''),(177016,56717,'118402','furniture-mobile','border-top-width','1',0,''),(177017,56717,'118402','furniture-mobile','border-top-color','$border-color-4',0,''),(177018,56717,'118402','furniture-mobile','text-align','right',0,''),(177019,56718,'118403','furniture-mobile','block_type','1',0,''),(177020,56719,'118404','furniture-mobile','block_type','8',0,''),(177021,56719,'118404','furniture-mobile','schema','8-6',0,'2885'),(177022,56720,'1639410195.9973','furniture-mobile','text','<span></span>',0,''),(177023,56721,'118405','furniture-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_PERSONALIZED_URL##</div>',0,''),(177024,56723,'118407','furniture-mobile','text','<div class=\"heading-3\">##INVITE_GUESTS##</div>',0,''),(177025,56724,'118408','furniture-mobile','margin-bottom','30',0,''),(177026,56725,'118410','furniture-mobile','margin-top','-100',0,''),(177027,56726,'118411','furniture-mobile','text','<h1>##SHARE_YOUR_WEDDING_REGISTRY##</h1>',0,''),(177028,56726,'118411','furniture-mobile','margin-top','-80',0,''),(177029,56726,'118411','furniture-mobile','margin-top','0',0,'2885'),(177030,56728,'1639405874.8749','furniture-mobile','block_type','1',0,''),(177031,56728,'1639405874.8749','furniture-mobile','padding-bottom','30',0,''),(177032,56730,'118413','furniture-mobile','text','<h1>##CREATE_WR_SUCCESS_MESSAGE##</h1>',0,''),(177033,56731,'1639393156.401','furniture-mobile','block_type','1',0,''),(177034,56732,'118414','furniture-mobile','block_type','2',0,''),(177035,56732,'118414','furniture-mobile','schema','2-2',0,'2885'),(177036,56733,'118415','furniture-mobile','block_type','1',0,''),(177037,56733,'118415','furniture-mobile','padding-right','15',0,''),(177038,56733,'118415','furniture-mobile','padding-right','0',0,'2885'),(177039,56734,'118416','furniture-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_REGISTRY##</div>',0,''),(177040,56735,'118417','furniture-mobile','padding-bottom','15',0,''),(177041,56735,'118417','furniture-mobile','padding-top','15',0,''),(177042,56735,'118417','furniture-mobile','padding-left','15',0,''),(177043,56735,'118417','furniture-mobile','padding-right','15',0,''),(177044,56735,'118417','furniture-mobile','margin-bottom','20',0,''),(177045,56735,'118417','furniture-mobile','border-top-width','1',0,''),(177046,56735,'118417','furniture-mobile','border-left-width','1',0,''),(177047,56735,'118417','furniture-mobile','border-right-width','1',0,''),(177048,56735,'118417','furniture-mobile','border-bottom-width','1',0,''),(177049,56735,'118417','furniture-mobile','border-top-color','$border-color-3',0,''),(177050,56735,'118417','furniture-mobile','border-left-color','$border-color-3',0,''),(177051,56735,'118417','furniture-mobile','border-right-color','$border-color-3',0,''),(177052,56735,'118417','furniture-mobile','border-bottom-color','$border-color-3',0,''),(177053,56736,'118418','furniture-mobile','text','<div class=\"heading-3\">##TEXT_WEDDING_DETAILS##</div>',0,''),(177054,56737,'118419','furniture-mobile','text','<div class=\"heading-3\">##TEXT_NAMES##</div>',0,''),(177055,56738,'118420','furniture-mobile','margin-bottom','20',0,''),(177056,56738,'118420','furniture-mobile','padding-top','15',0,''),(177057,56738,'118420','furniture-mobile','padding-left','15',0,''),(177058,56738,'118420','furniture-mobile','padding-right','15',0,''),(177059,56738,'118420','furniture-mobile','padding-bottom','15',0,''),(177060,56738,'118420','furniture-mobile','border-top-width','1',0,''),(177061,56738,'118420','furniture-mobile','border-left-width','1',0,''),(177062,56738,'118420','furniture-mobile','border-right-width','1',0,''),(177063,56738,'118420','furniture-mobile','border-bottom-width','1',0,''),(177064,56738,'118420','furniture-mobile','border-top-color','$border-color-3',0,''),(177065,56738,'118420','furniture-mobile','border-left-color','$border-color-3',0,''),(177066,56738,'118420','furniture-mobile','border-right-color','$border-color-3',0,''),(177067,56738,'118420','furniture-mobile','border-bottom-color','$border-color-3',0,''),(177068,56739,'118421','furniture-mobile','margin-bottom','20',0,''),(177069,56739,'118421','furniture-mobile','padding-top','15',0,''),(177070,56739,'118421','furniture-mobile','padding-left','15',0,''),(177071,56739,'118421','furniture-mobile','padding-right','15',0,''),(177072,56739,'118421','furniture-mobile','padding-bottom','15',0,''),(177073,56739,'118421','furniture-mobile','border-top-width','1',0,''),(177074,56739,'118421','furniture-mobile','border-left-width','1',0,''),(177075,56739,'118421','furniture-mobile','border-right-width','1',0,''),(177076,56739,'118421','furniture-mobile','border-bottom-width','1',0,''),(177077,56739,'118421','furniture-mobile','border-top-color','$border-color-3',0,''),(177078,56739,'118421','furniture-mobile','border-left-color','$border-color-3',0,''),(177079,56739,'118421','furniture-mobile','border-right-color','$border-color-3',0,''),(177080,56739,'118421','furniture-mobile','border-bottom-color','$border-color-3',0,''),(177081,56740,'118422','furniture-mobile','block_type','1',0,''),(177082,56740,'118422','furniture-mobile','padding-left','15',0,''),(177083,56740,'118422','furniture-mobile','padding-left','0',0,'2885'),(177084,56741,'118423','furniture-mobile','margin-bottom','20',0,''),(177085,56741,'118423','furniture-mobile','padding-top','15',0,''),(177086,56741,'118423','furniture-mobile','padding-left','15',0,''),(177087,56741,'118423','furniture-mobile','padding-right','15',0,''),(177088,56741,'118423','furniture-mobile','padding-bottom','15',0,''),(177089,56741,'118423','furniture-mobile','border-top-width','1',0,''),(177090,56741,'118423','furniture-mobile','border-left-width','1',0,''),(177091,56741,'118423','furniture-mobile','border-right-width','1',0,''),(177092,56741,'118423','furniture-mobile','border-bottom-width','1',0,''),(177093,56741,'118423','furniture-mobile','border-top-color','$border-color-3',0,''),(177094,56741,'118423','furniture-mobile','border-left-color','$border-color-3',0,''),(177095,56741,'118423','furniture-mobile','border-right-color','$border-color-3',0,''),(177096,56741,'118423','furniture-mobile','border-bottom-color','$border-color-3',0,''),(177097,56742,'118424','furniture-mobile','text','<div class=\"heading-3\">##UPLOAD_PHOTO##</div>',0,''),(177098,56743,'118425','furniture-mobile','margin-bottom','20',0,''),(177099,56743,'118425','furniture-mobile','padding-top','15',0,''),(177100,56743,'118425','furniture-mobile','padding-left','15',0,''),(177101,56743,'118425','furniture-mobile','padding-right','15',0,''),(177102,56743,'118425','furniture-mobile','padding-bottom','15',0,''),(177103,56743,'118425','furniture-mobile','border-top-width','1',0,''),(177104,56743,'118425','furniture-mobile','border-left-width','1',0,''),(177105,56743,'118425','furniture-mobile','border-right-width','1',0,''),(177106,56743,'118425','furniture-mobile','border-bottom-width','1',0,''),(177107,56743,'118425','furniture-mobile','border-top-color','$border-color-3',0,''),(177108,56743,'118425','furniture-mobile','border-left-color','$border-color-3',0,''),(177109,56743,'118425','furniture-mobile','border-right-color','$border-color-3',0,''),(177110,56743,'118425','furniture-mobile','border-bottom-color','$border-color-3',0,''),(177111,56744,'118426','furniture-mobile','margin-bottom','20',0,''),(177112,56744,'118426','furniture-mobile','padding-left','1',0,''),(177113,56745,'118427','furniture-mobile','text','<div class=\"heading-3\">##TEXT_SHIPPING_DETAILS##</div>',0,''),(177114,56746,'118428','furniture-mobile','text','<div class=\"heading-3\">##TEXT_ADDITIONAL_INFORMATION##</div>',0,''),(177115,56747,'118429','furniture-mobile','block_type','2',0,''),(177116,56747,'118429','furniture-mobile','margin-bottom','20',0,''),(177117,56749,'118431','furniture-mobile','text-align','right',0,''),(177118,56750,'118432','furniture-mobile','text','<h1>##WEDDING_REGISTRY_FORM_HEADING##</h1>',0,''),(177119,56752,'1639500465.781','furniture-mobile','block_type','1',0,''),(177120,56753,'118433','furniture-mobile','block_type','13',0,''),(177121,56753,'118433','furniture-mobile','margin-bottom','20',0,''),(177122,56753,'118433','furniture-mobile','margin-top','10',0,''),(177123,56753,'118433','furniture-mobile','schema','13-2',0,'2885'),(177124,56753,'118433','furniture-mobile','schema','13-4',0,'2876'),(177125,56754,'118434','furniture-mobile','position','relative',0,''),(177126,56754,'118434','furniture-mobile','margin-top','-100',0,''),(177127,56755,'118435','furniture-mobile','font-family','$font-1',0,''),(177128,56755,'118435','furniture-mobile','font-size','18',0,''),(177129,56755,'118435','furniture-mobile','margin-bottom','10',0,''),(177130,56755,'118435','furniture-mobile','text-align','center',0,'2885'),(177131,56756,'118436','furniture-mobile','font-family','$font-1',0,''),(177138,56758,'118438','furniture-mobile','padding-top','30',0,''),(177139,56758,'118438','furniture-mobile','padding-bottom','30',0,''),(177140,56759,'118440','furniture-mobile','block_type','1',0,''),(177141,56760,'118441','furniture-mobile','block_type','6',0,''),(177142,56760,'118441','furniture-mobile','schema','6-3',0,'2885'),(177143,56761,'118442','furniture-mobile','aria_name','account-menu',0,''),(177144,56762,'116126','furniture-mobile','block_type','1',0,''),(177145,56762,'116126','furniture-mobile','padding-top','70',0,''),(177146,56762,'116126','furniture-mobile','padding-right','30',0,''),(177147,56762,'116126','furniture-mobile','padding-bottom','30',0,''),(177148,56762,'116126','furniture-mobile','padding-top','0',0,'2885'),(177149,56762,'116126','furniture-mobile','padding-left','0',0,'2885'),(177150,56762,'116126','furniture-mobile','padding-right','0',0,'2885'),(177151,56762,'116126','furniture-mobile','padding-bottom','0',0,'2885'),(177152,56763,'116127','furniture-mobile','block_type','1',0,''),(177153,56763,'116127','furniture-mobile','padding-right','20',0,''),(177154,56763,'116127','furniture-mobile','style_class','account-menu',0,''),(177155,56763,'116127','furniture-mobile','padding-top','20',0,''),(177156,56763,'116127','furniture-mobile','margin-bottom','20',0,''),(177157,56763,'116127','furniture-mobile','background-color','$background-6',0,''),(177158,56763,'116127','furniture-mobile','padding-left','20',0,''),(177159,56763,'116127','furniture-mobile','padding-bottom','20',0,''),(177160,56764,'116128','furniture-mobile','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(177161,56764,'116128','furniture-mobile','style_class','heading-settings',0,''),(177162,56765,'116129','furniture-mobile','link','logoff',0,''),(177163,56766,'116130','furniture-mobile','link','delete',0,''),(177164,56766,'116130','furniture-mobile','text','DELETE_ACCOUNT',0,''),(177165,56767,'116131','furniture-mobile','text','TEXT_DASHBOARD',0,''),(177166,56767,'116131','furniture-mobile','font-family','$font-1',0,''),(177167,56767,'116131','furniture-mobile','font-size','18',0,''),(177168,56767,'116131','furniture-mobile','text-transform','uppercase',0,''),(177169,56768,'116132','furniture-mobile','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(177170,56768,'116132','furniture-mobile','style_class','heading-saved-lists',0,''),(177171,56769,'116133','furniture-mobile','link','Personal Catalog',0,''),(177172,56769,'116133','furniture-mobile','text','TEXT_PERSONAL_CATALOG',0,''),(177173,56769,'116133','furniture-mobile','hide_link','personal_catalog',0,''),(177174,56770,'116134','furniture-mobile','link','Order History',0,''),(177175,56770,'116134','furniture-mobile','text','HEADING_ORDER_HISTORY',0,''),(177176,56770,'116134','furniture-mobile','active_link','Order History Info,Order pay',0,''),(177177,56771,'116135','furniture-mobile','link','Address Book',0,''),(177178,56771,'116135','furniture-mobile','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(177179,56772,'116136','furniture-mobile','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(177180,56772,'116136','furniture-mobile','style_class','heading-ordered-items',0,''),(177181,56773,'116137','furniture-mobile','link','Wishlist',0,''),(177182,56773,'116137','furniture-mobile','hide_link','wishlist',0,''),(177183,56773,'116137','furniture-mobile','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(177184,56774,'116138','furniture-mobile','link','My password',0,''),(177185,56774,'116138','furniture-mobile','text','TEXT_MY_PASSWORD',0,''),(177186,56775,'116139','furniture-mobile','link','Samples',0,''),(177187,56775,'116139','furniture-mobile','text','TEXT_HEADING_SAMPLE_CART',0,''),(177188,56775,'116139','furniture-mobile','hide_link','samples',0,''),(177189,56776,'116140','furniture-mobile','link','Review',0,''),(177190,56776,'116140','furniture-mobile','text','REVIEWS',0,''),(177191,56777,'116141','furniture-mobile','link','Quotations',0,''),(177192,56777,'116141','furniture-mobile','hide_link','quotations',0,''),(177193,56777,'116141','furniture-mobile','text','TEXT_HEADING_QUOTE_CART',0,''),(177194,56778,'116142','furniture-mobile','link','Account edit',0,''),(177195,56778,'116142','furniture-mobile','text','ACCOUNT_EDIT',0,''),(177196,56779,'116143','furniture-mobile','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(177197,56779,'116143','furniture-mobile','style_class','heading-settings',0,''),(177198,56780,'116144','furniture-mobile','link','trade_form',0,''),(177199,56780,'116144','furniture-mobile','text','TRADE_FORM',0,''),(177200,56781,'118443','furniture-mobile','margin-bottom','20',0,''),(177201,56782,'118444','furniture-mobile','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(177202,56783,'118445','furniture-mobile','block_type','1',0,''),(177203,56783,'118445','furniture-mobile','padding-top','20',0,''),(177204,56783,'118445','furniture-mobile','padding-bottom','20',0,''),(177205,56785,'118447','furniture-mobile','padding-top','20',0,''),(177206,56785,'118447','furniture-mobile','padding-bottom','20',0,''),(177210,54383,'116379','furniture-mobile','margin-top','15',0,''),(177250,3291,'113763','watch-mobile','margin-top','15',0,''),(177251,3682,'114160','watch-mobile','padding-left','15',0,''),(177252,3682,'114160','watch-mobile','padding-right','15',0,''),(336065,108861,'117044','splash','block_type','1',0,''),(336066,108862,'117045','splash','block_type','1',0,''),(336067,108862,'117045','splash','max-width','800',0,''),(336068,108862,'117045','splash','margin','0 auto',0,''),(336069,108862,'117045','splash','background-color','#ffffff',0,''),(336070,108863,'117046','splash','color','#424242',0,''),(336071,108863,'117046','splash','font-size','12',0,''),(336072,108863,'117046','splash','padding-top','20',0,''),(336073,108863,'117046','splash','padding-bottom','20',0,''),(336074,108863,'117046','splash','border-top-width','1',0,''),(336075,108863,'117046','splash','border-top-color','#e0e0e0',0,''),(336076,108864,'117047','splash','font-weight','normal',0,''),(336077,108864,'117047','splash','padding-top','20',0,''),(336078,108864,'117047','splash','padding-left','10',0,''),(336079,108864,'117047','splash','padding-right','10',0,''),(336080,108864,'117047','splash','padding-bottom','20',0,''),(336081,108864,'117047','splash','color','#424242',0,''),(336082,108864,'117047','splash','font-size','14',0,''),(336083,108865,'117048','splash','block_type','7',0,''),(336084,108865,'117048','splash','font-weight','normal',0,''),(336085,108865,'117048','splash','background-color','#212121',0,''),(336086,108865,'117048','splash','padding-top','5',0,''),(336087,108865,'117048','splash','padding-left','10',0,''),(336088,108865,'117048','splash','padding-right','10',0,''),(336089,108865,'117048','splash','padding-bottom','5',0,''),(336090,108866,'117049','splash','color','#ffffff',0,''),(336091,108866,'117049','splash','font-size','14',0,''),(336092,108866,'117049','splash','font-weight','normal',0,''),(336093,108867,'117050','splash','font-weight','normal',0,''),(336094,108867,'117050','splash','text-align','right',0,''),(336095,108867,'117050','splash','color','#ffffff',0,''),(336096,108867,'117050','splash','font-size','12',0,''),(336097,108868,'117051','splash','font-weight','normal',0,''),(336098,108868,'117051','splash','padding-bottom','10',0,''),(336099,108868,'117051','splash','padding-top','10',0,''),(336100,108868,'117051','splash','padding-left','20',0,''),(336101,108868,'117051','splash','background-color','#000000',0,''),(336102,108868,'117051','splash','logo','themes/splash/img/oscommerce_logo_(2)-1.png',1,''),(336103,108869,'1661353033.436213','splash','block_type','1',0,''),(336104,108870,'1661353033.440468','splash','show_heading','h1',0,''),(336105,108872,'1661353032.24842','splash','width','680',0,''),(336106,108872,'1661353032.24842','splash','font-weight','normal',0,''),(336107,108872,'1661353032.24842','splash','font-size','12',0,''),(336108,108872,'1661353032.24842','splash','padding-top','20',0,''),(336109,108872,'1661353032.24842','splash','padding-bottom','20',0,''),(336110,108872,'1661353032.24842','splash','color','#424242',0,''),(336111,108873,'1661353032.270236','splash','block_type','4',0,''),(336112,108873,'1661353032.270236','splash','font-weight','normal',0,''),(336113,108873,'1661353032.270236','splash','border-top-width','1',0,''),(336114,108873,'1661353032.270236','splash','border-top-color','#e0e0e0',0,''),(336115,108873,'1661353032.270236','splash','border-left-width','1',0,''),(336116,108873,'1661353032.270236','splash','border-left-color','#e0e0e0',0,''),(336117,108873,'1661353032.270236','splash','border-right-width','1',0,''),(336118,108873,'1661353032.270236','splash','border-right-color','#e0e0e0',0,''),(336119,108873,'1661353032.270236','splash','border-bottom-width','1',0,''),(336120,108873,'1661353032.270236','splash','border-bottom-color','#e0e0e0',0,''),(336121,108874,'1661353032.296769','splash','block_type','2',0,''),(336122,108874,'1661353032.296769','splash','font-weight','normal',0,''),(336123,108874,'1661353032.296769','splash','border-top-width','1',0,''),(336124,108874,'1661353032.296769','splash','border-top-color','#e0e0e0',0,''),(336125,108874,'1661353032.296769','splash','border-right-width','1',0,''),(336126,108874,'1661353032.296769','splash','border-right-color','#e0e0e0',0,''),(336127,108875,'1661353032.306393','splash','block_type','1',0,''),(336128,108875,'1661353032.306393','splash','font-weight','normal',0,''),(336129,108875,'1661353032.306393','splash','padding-top','10',0,''),(336130,108875,'1661353032.306393','splash','padding-left','10',0,''),(336131,108875,'1661353032.306393','splash','padding-right','10',0,''),(336132,108875,'1661353032.306393','splash','padding-bottom','10',0,''),(336133,108875,'1661353032.306393','splash','border-right-width','1',0,''),(336134,108875,'1661353032.306393','splash','border-right-color','#e0e0e0',0,''),(336135,108877,'1661353032.323757','splash','text','##TEXT_INVOICE_SHIPPING_VIA##',0,''),(336136,108877,'1661353032.323757','splash','font-size','14',0,''),(336137,108877,'1661353032.323757','splash','font-weight','bold',0,''),(336138,108878,'1661353032.337230','splash','block_type','1',0,''),(336139,108878,'1661353032.337230','splash','font-weight','normal',0,''),(336140,108878,'1661353032.337230','splash','padding-top','10',0,''),(336141,108878,'1661353032.337230','splash','padding-left','10',0,''),(336142,108878,'1661353032.337230','splash','padding-right','10',0,''),(336143,108878,'1661353032.337230','splash','padding-bottom','10',0,''),(336144,108880,'1661353032.34962','splash','text','##TEXT_INVOICE_SHIPPING_SERVICE##',0,''),(336145,108880,'1661353032.34962','splash','font-size','14',0,''),(336146,108880,'1661353032.34962','splash','font-weight','bold',0,''),(336147,108881,'1661353032.356416','splash','block_type','2',0,''),(336148,108881,'1661353032.356416','splash','font-weight','normal',0,''),(336149,108881,'1661353032.356416','splash','border-right-width','1',0,''),(336150,108881,'1661353032.356416','splash','border-right-color','#e0e0e0',0,''),(336151,108882,'1661353032.363923','splash','block_type','1',0,''),(336152,108882,'1661353032.363923','splash','font-weight','400',0,''),(336153,108882,'1661353032.363923','splash','background-color','#eeeeee',0,''),(336154,108882,'1661353032.363923','splash','padding-top','10',0,''),(336155,108882,'1661353032.363923','splash','padding-left','10',0,''),(336156,108882,'1661353032.363923','splash','padding-right','10',0,''),(336157,108882,'1661353032.363923','splash','padding-bottom','30',0,''),(336158,108883,'1661353032.374368','splash','font-size','12',0,''),(336159,108884,'1661353032.380968','splash','text','##TEXT_INVOICE_ADDRESS##',0,''),(336160,108884,'1661353032.380968','splash','font-size','14',0,''),(336161,108884,'1661353032.380968','splash','font-weight','bold',0,''),(336162,108884,'1661353032.380968','splash','text-transform','uppercase',0,''),(336163,108886,'1661353032.39417','splash','block_type','1',0,''),(336164,108886,'1661353032.39417','splash','font-weight','normal',0,''),(336165,108886,'1661353032.39417','splash','padding-top','10',0,''),(336166,108886,'1661353032.39417','splash','padding-left','10',0,''),(336167,108886,'1661353032.39417','splash','padding-right','10',0,''),(336168,108886,'1661353032.39417','splash','padding-bottom','10',0,''),(336169,108887,'1661353032.40481','splash','font-weight','normal',0,''),(336170,108888,'1661353032.410660','splash','font-weight','normal',0,''),(336171,108890,'1661353032.4242','splash','text','##TEXT_INVOICE_CUSTOMER##',0,''),(336172,108890,'1661353032.4242','splash','font-size','14',0,''),(336173,108890,'1661353032.4242','splash','font-weight','bold',0,''),(336174,108890,'1661353032.4242','splash','text-transform','uppercase',0,''),(336175,108891,'1661353032.430173','splash','text','##TEXT_INVOICE_PHONE_NUMBER##',0,''),(336176,108891,'1661353032.430173','splash','text-transform','uppercase',0,''),(336177,108891,'1661353032.430173','splash','font-weight','bold',0,''),(336178,108891,'1661353032.430173','splash','font-size','14',0,''),(336179,108891,'1661353032.430173','splash','padding-top','10',0,''),(336180,108892,'1661353032.440350','splash','text','##TEXT_INVOICE_EMAIL_ADDRESS##',0,''),(336181,108892,'1661353032.440350','splash','font-size','14',0,''),(336182,108892,'1661353032.440350','splash','font-weight','bold',0,''),(336183,108892,'1661353032.440350','splash','text-transform','uppercase',0,''),(336184,108892,'1661353032.440350','splash','padding-top','10',0,''),(336185,108893,'1661353032.449537','splash','font-weight','normal',0,''),(336186,108893,'1661353032.449537','splash','text-align','center',0,''),(336187,108893,'1661353032.449537','splash','padding-bottom','20',0,''),(336188,108894,'1661353032.456412','splash','font-size','14',0,''),(336189,108894,'1661353032.456412','splash','font-weight','bold',0,''),(336190,108894,'1661353032.456412','splash','text-align','center',0,''),(336191,108894,'1661353032.456412','splash','padding-bottom','10',0,''),(336192,108894,'1661353032.456412','splash','padding-top','10',0,''),(336193,108895,'1661353032.464888','splash','font-weight','normal',0,''),(336194,108895,'1661353032.464888','splash','text-align','center',0,''),(336195,108895,'1661353032.464888','splash','padding-bottom','10',0,''),(336196,108896,'1661353032.471888','splash','font-weight','normal',0,''),(336197,108896,'1661353032.471888','splash','text-align','center',0,''),(336198,108897,'1661353032.47812','splash','text','##TEXT_INVOICE_PAYMENT_DATE##',0,''),(336199,108897,'1661353032.47812','splash','font-size','12',0,''),(336200,108897,'1661353032.47812','splash','font-weight','bold',0,''),(336201,108897,'1661353032.47812','splash','text-align','center',0,''),(336202,108898,'1661353032.486692','splash','text','##TEXT_INVOICE_PAYMENT_METHOD##',0,''),(336203,108898,'1661353032.486692','splash','font-size','12',0,''),(336204,108898,'1661353032.486692','splash','font-weight','bold',0,''),(336205,108898,'1661353032.486692','splash','text-align','center',0,''),(336206,108899,'1661353032.495713','splash','block_type','3',0,''),(336207,108899,'1661353032.495713','splash','font-weight','normal',0,''),(336208,108899,'1661353032.495713','splash','padding-top','20',0,''),(336209,108900,'1661353032.50157','splash','font-size','12',0,''),(336210,108901,'1661353032.50664','splash','text','##TEXT_INVOICE_IF_UNDELIVERED##',0,''),(336211,108901,'1661353032.50664','splash','font-size','12',0,''),(336212,108901,'1661353032.50664','splash','font-weight','bold',0,''),(336213,108902,'1661353032.514429','splash','text','##TEXT_INVOICE_THANK_YOU_FOR_ORDER##',0,''),(336214,108902,'1661353032.514429','splash','color','#1da1f2',0,''),(336215,108902,'1661353032.514429','splash','font-size','13',0,''),(336216,108902,'1661353032.514429','splash','font-weight','bold',0,''),(336217,108902,'1661353032.514429','splash','text-align','center',0,''),(336218,108902,'1661353032.514429','splash','padding-top','5',0,''),(336219,108903,'1661353032.527783','splash','block_type','6',0,''),(336220,108903,'1661353032.527783','splash','font-weight','normal',0,''),(336221,108903,'1661353032.527783','splash','font-size','16',0,''),(336222,108904,'1661353032.533932','splash','text','##TEXT_INVOICE_EMAIL##',0,''),(336223,108904,'1661353032.533932','splash','font-size','12',0,''),(336224,108904,'1661353032.533932','splash','text-align','right',0,''),(336225,108904,'1661353032.533932','splash','font-weight','400',0,''),(336226,108905,'1661353032.54216','splash','font-weight','normal',0,''),(336227,108905,'1661353032.54216','splash','text-align','right',0,''),(336228,108905,'1661353032.54216','splash','font-size','12',0,''),(336229,108906,'1661353032.549414','splash','block_type','6',0,''),(336230,108906,'1661353032.549414','splash','font-weight','normal',0,''),(336231,108906,'1661353032.549414','splash','font-size','16',0,''),(336232,108907,'1661353032.556356','splash','text','##TEXT_INVOICE_PHONE##',0,''),(336233,108907,'1661353032.556356','splash','font-size','12',0,''),(336234,108907,'1661353032.556356','splash','font-weight','400',0,''),(336235,108907,'1661353032.556356','splash','text-align','right',0,''),(336236,108908,'1661353032.56487','splash','font-weight','normal',0,''),(336237,108908,'1661353032.56487','splash','text-align','right',0,''),(336238,108908,'1661353032.56487','splash','font-size','12',0,''),(336239,108909,'1661353032.572983','splash','text','##TEXT_INVOICE_SOMETHING_WRONG##',0,''),(336240,108909,'1661353032.572983','splash','font-size','12',0,''),(336241,108909,'1661353032.572983','splash','font-weight','bold',0,''),(336242,108909,'1661353032.572983','splash','text-align','right',0,''),(336243,108910,'1661353032.588254','splash','font-weight','400',0,''),(336244,108910,'1661353032.588254','splash','padding-top','20',0,''),(336245,108910,'1661353032.588254','splash','padding-bottom','0',0,''),(336246,108910,'1661353032.588254','splash','font-size','12',0,''),(336247,108911,'1661353032.596366','splash','block_type','5',0,''),(336248,108911,'1661353032.596366','splash','font-weight','normal',0,''),(336249,108911,'1661353032.596366','splash','border-bottom-width','1',0,''),(336250,108911,'1661353032.596366','splash','border-bottom-color','#e0e0e0',0,''),(336251,108911,'1661353032.596366','splash','border-top-width','1',0,''),(336252,108911,'1661353032.596366','splash','border-top-color','#e0e0e0',0,''),(336253,108911,'1661353032.596366','splash','border-left-color','#e0e0e0',0,''),(336254,108911,'1661353032.596366','splash','border-left-width','1',0,''),(336255,108912,'1661353032.616225','splash','block_type','1',0,''),(336256,108912,'1661353032.616225','splash','font-weight','normal',0,''),(336257,108912,'1661353032.616225','splash','padding-top','10',0,''),(336258,108912,'1661353032.616225','splash','padding-left','10',0,''),(336259,108912,'1661353032.616225','splash','padding-right','10',0,''),(336260,108913,'1661353032.624746','splash','font-weight','400',0,''),(336261,108913,'1661353032.624746','splash','line-height','120',0,''),(336262,108913,'1661353032.624746','splash','line_height_measure','%',0,''),(336263,108913,'1661353032.624746','splash','font-size','12',0,''),(336264,108914,'1661353032.6344','splash','text','##SHIPPING_ADDRESS##',0,''),(336265,108914,'1661353032.6344','splash','font-size','14',0,''),(336266,108914,'1661353032.6344','splash','text-transform','uppercase',0,''),(336267,108914,'1661353032.6344','splash','font-weight','bold',0,''),(336268,108914,'1661353032.6344','splash','padding-bottom','10',0,''),(336269,108915,'1661353032.645291','splash','block_type','1',0,''),(336270,108915,'1661353032.645291','splash','background-color','#eeeeee',0,''),(336271,108915,'1661353032.645291','splash','padding-top','20',0,''),(336272,108915,'1661353032.645291','splash','padding-left','10',0,''),(336273,108915,'1661353032.645291','splash','padding-right','10',0,''),(336274,108915,'1661353032.645291','splash','padding-bottom','20',0,''),(336275,108915,'1661353032.645291','splash','font-size','14',0,''),(336276,108916,'1661353032.656840','splash','font-weight','normal',0,''),(336277,108916,'1661353032.656840','splash','text-align','right',0,''),(336278,108916,'1661353032.656840','splash','font-size','12',0,''),(336279,108916,'1661353032.656840','splash','box_align','3',0,''),(336280,108917,'1661353032.665237','splash','block_type','2',0,''),(336281,108917,'1661353032.665237','splash','font-weight','normal',0,''),(336282,108917,'1661353032.665237','splash','padding-bottom','20',0,''),(336283,108918,'1661353032.672459','splash','logo','themes/splash/img/oscommerce_logo.jpg',1,''),(336284,108919,'1661353032.693794','splash','block_type','11',0,''),(336285,108919,'1661353032.693794','splash','font-weight','normal',0,''),(336286,108920,'1661353032.699666','splash','text','##TEXT_INVOICE_WEB##',0,''),(336287,108920,'1661353032.699666','splash','text-align','right',0,''),(336288,108921,'1661353032.705757','splash','font-weight','normal',0,''),(336289,108921,'1661353032.705757','splash','text-align','right',0,''),(336290,108922,'1661353032.712713','splash','block_type','11',0,''),(336291,108922,'1661353032.712713','splash','font-weight','normal',0,''),(336292,108923,'1661353032.717779','splash','text','##TEXT_INVOICE_EMAIL##',0,''),(336293,108923,'1661353032.717779','splash','font-weight','400',0,''),(336294,108923,'1661353032.717779','splash','text-align','right',0,''),(336295,108924,'1661353032.724733','splash','font-weight','normal',0,''),(336296,108924,'1661353032.724733','splash','text-align','right',0,''),(336297,108925,'1661353032.729329','splash','block_type','1',0,''),(336298,108926,'1661353032.73418','splash','font-weight','normal',0,''),(336299,108926,'1661353032.73418','splash','text-align','right',0,''),(336300,108926,'1661353032.73418','splash','padding-bottom','10',0,''),(336301,108926,'1661353032.73418','splash','address_spacer',',',0,''),(336302,108926,'1661353032.73418','splash','font-size','12',0,''),(336303,108927,'1661353032.745349','splash','block_type','11',0,''),(336304,108927,'1661353032.745349','splash','font-weight','normal',0,''),(336305,108928,'1661353032.752179','splash','text','##TEXT_INVOICE_PHONE##',0,''),(336306,108928,'1661353032.752179','splash','text-align','right',0,''),(336307,108928,'1661353032.752179','splash','font-weight','400',0,''),(336308,108929,'1661353032.759958','splash','font-weight','normal',0,''),(336309,108929,'1661353032.759958','splash','text-align','right',0,''),(336310,108930,'1661353032.765438','splash','column_qty','1',0,''),(336311,108930,'1661353032.765438','splash','column_name','1',0,''),(336312,108930,'1661353032.765438','splash','column_model','1',0,''),(336313,108931,'1640168549.8258','splash','block_type','1',0,''),(336314,108931,'1640168549.8258','splash','background_image','themes/splash/img/bg2.jpg',0,''),(336315,108931,'1640168549.8258','splash','background-size','contain',0,''),(336316,108931,'1640168549.8258','splash','background-repeat','no-repeat',0,''),(336317,108931,'1640168549.8258','splash','style_class','mainbg',0,''),(336318,108932,'1640168603.5833','splash','block_type','1',0,''),(336319,108933,'1640168618.7708','splash','logo','themes/splash/img/oscommerce_logo (2).png',1,''),(336320,108933,'1640168618.7708','splash','margin-top','30',0,''),(336321,108933,'1640168618.7708','splash','margin-bottom','30',0,''),(336322,108933,'1640168618.7708','splash','box_align','2',0,''),(336323,108934,'1640181569.3506','splash','block_type','1',0,''),(336324,108935,'1640168851.5282','splash','block_type','3',0,''),(336325,108935,'1640168851.5282','splash','schema','3-6',0,'5107'),(336326,108936,'1640169872.1589','splash','logo','themes/splash/img/Splash_furniture_BGlogo.png',1,''),(336327,108936,'1640169872.1589','splash','box_align','2',0,''),(336328,108936,'1640169872.1589','splash','style_class','scale',0,''),(336329,108936,'1640169872.1589','splash','img_link','furniture/',1,''),(336330,108936,'1640169872.1589','splash','target_blank','1',1,''),(336331,108937,'1640276640.1123','splash','text','<h1>osCommerce v4 Splash page</h1>\r\n\r\n<p>osCommerce supports multiple sales CHANNELS.</p>\r\n\r\n<p>Your installation of osCommerce comes with &nbsp;&quot;Furniture&quot;, &quot;Watch&quot;, &quot;B2B Supermarket&quot;, and &quot;Print shop&quot; Ecommerce sales channels and &quot;cms&quot; brochure website example.</p>\r\n\r\n<p>Each sales channel has its own URLs, design, and demo product sets.</p>\r\n\r\n<p>&quot;Admin&quot; is the back end of your osCommerce.</p>\r\n\r\n<p>Use osCommerce Wiki to learn how to manage sales channels, &nbsp;assign design themes, and content to the sales channels.<br />\r\nThank you for choosing &nbsp;osCommerce - the most powerful on-premise open source Ecommerce platform!</p>\r\n',1,''),(336332,108937,'1640276640.1123','splash','color','#ffffff',0,''),(336333,108937,'1640276640.1123','splash','font-size','16',0,''),(336334,108937,'1640276640.1123','splash','text-align','center',0,''),(336335,108937,'1640276640.1123','splash','padding-top','50',0,'5107'),(336336,108937,'1640276640.1123','splash','padding-left','30',0,'5107'),(336337,108937,'1640276640.1123','splash','padding-right','30',0,'5107'),(336338,108937,'1640276640.1123','splash','padding-bottom','50',0,'5107'),(336339,108937,'1640276640.1123','splash','font-size','14',0,'5109'),(336340,108938,'1640170154.7803','splash','logo','themes/splash/img/Splash_watch_BGlogo.png',1,''),(336341,108938,'1640170154.7803','splash','box_align','2',0,''),(336342,108938,'1640170154.7803','splash','style_class','scale',0,''),(336343,108938,'1640170154.7803','splash','img_link','watch/',1,''),(336344,108938,'1640170154.7803','splash','target_blank','1',1,''),(336345,108938,'1640170154.7803','splash','padding-top','30',0,'5107'),(336346,108939,'1645204049.8114','splash','block_type','3',0,''),(336347,108939,'1645204049.8114','splash','schema','3-6',0,'5107'),(336348,108940,'1640170023.0001','splash','logo','themes/splash/img/print shop.jpg',1,''),(336349,108940,'1640170023.0001','splash','box_align','2',0,''),(336350,108940,'1640170023.0001','splash','margin-top','30',0,''),(336351,108940,'1640170023.0001','splash','margin-bottom','30',0,''),(336352,108940,'1640170023.0001','splash','img_link','printshop/',1,''),(336353,108940,'1640170023.0001','splash','style_class','scale',0,''),(336354,108940,'1640170023.0001','splash','target_blank','1',1,''),(336355,108941,'1640170023.1491','splash','logo','themes/splash/img/Splash_admin_BGlogo.png',1,''),(336356,108941,'1640170023.1491','splash','box_align','2',0,''),(336357,108941,'1640170023.1491','splash','margin-top','30',0,''),(336358,108941,'1640170023.1491','splash','margin-bottom','30',0,''),(336359,108941,'1640170023.1491','splash','img_link','admin/',1,''),(336360,108941,'1640170023.1491','splash','style_class','scale',0,''),(336361,108941,'1640170023.1491','splash','target_blank','1',1,''),(336362,108942,'1640170023','splash','logo','themes/splash/img/b2b supermarket.jpg',1,''),(336363,108942,'1640170023','splash','box_align','2',0,''),(336364,108942,'1640170023','splash','margin-top','30',0,''),(336365,108942,'1640170023','splash','margin-bottom','30',0,''),(336366,108942,'1640170023','splash','img_link','b2b-supermarket/',1,''),(336367,108942,'1640170023','splash','style_class','scale',0,''),(336368,108942,'1640170023','splash','target_blank','1',1,''),(336369,108943,'1661353032.958564','splash','width','680',0,''),(336370,108943,'1661353032.958564','splash','font-weight','400',0,''),(336371,108943,'1661353032.958564','splash','font-size','12',0,''),(336372,108943,'1661353032.958564','splash','padding-top','20',0,''),(336373,108943,'1661353032.958564','splash','padding-bottom','20',0,''),(336374,108944,'1661353032.968771','splash','block_type','2',0,''),(336375,108944,'1661353032.968771','splash','font-weight','normal',0,''),(336376,108944,'1661353032.968771','splash','padding-bottom','20',0,''),(336377,108945,'1661353032.975845','splash','font-weight','400',0,''),(336378,108945,'1661353032.975845','splash','padding-top','10',0,''),(336379,108945,'1661353032.975845','splash','logo','themes/splash/img/oscommerce_logo-1.jpg',1,''),(336380,108946,'1661353032.991276','splash','block_type','11',0,''),(336381,108946,'1661353032.991276','splash','font-weight','normal',0,''),(336382,108947,'1661353032.99777','splash','text','##TEXT_INVOICE_EMAIL##',0,''),(336383,108947,'1661353032.99777','splash','text-align','right',0,''),(336384,108948,'1661353033.00539','splash','font-weight','normal',0,''),(336385,108948,'1661353033.00539','splash','text-align','right',0,''),(336386,108949,'1661353033.010798','splash','block_type','11',0,''),(336387,108949,'1661353033.010798','splash','font-weight','normal',0,''),(336388,108950,'1661353033.017634','splash','text','##TEXT_INVOICE_PHONE##',0,''),(336389,108950,'1661353033.017634','splash','font-weight','400',0,''),(336390,108950,'1661353033.017634','splash','text-align','right',0,''),(336391,108951,'1661353033.027946','splash','font-weight','normal',0,''),(336392,108951,'1661353033.027946','splash','text-align','right',0,''),(336393,108952,'1661353033.033296','splash','block_type','1',0,''),(336394,108953,'1661353033.03754','splash','font-weight','400',0,''),(336395,108953,'1661353033.03754','splash','text-align','right',0,''),(336396,108953,'1661353033.03754','splash','padding-bottom','10',0,''),(336397,108953,'1661353033.03754','splash','address_spacer',',',0,''),(336398,108953,'1661353033.03754','splash','font-size','12',0,''),(336399,108954,'1661353033.046342','splash','block_type','11',0,''),(336400,108954,'1661353033.046342','splash','font-weight','400',0,''),(336401,108955,'1661353033.052669','splash','text','##TEXT_INVOICE_WEB##',0,''),(336402,108955,'1661353033.052669','splash','text-align','right',0,''),(336403,108956,'1661353033.060721','splash','font-weight','normal',0,''),(336404,108956,'1661353033.060721','splash','text-align','right',0,''),(336405,108957,'1661353033.065977','splash','font-weight','normal',0,''),(336406,108957,'1661353033.065977','splash','padding-top','20',0,''),(336407,108957,'1661353033.065977','splash','font-size','12',0,''),(336408,108958,'1661353033.073678','splash','block_type','1',0,''),(336409,108958,'1661353033.073678','splash','font-weight','normal',0,''),(336410,108958,'1661353033.073678','splash','padding-top','10',0,''),(336411,108958,'1661353033.073678','splash','padding-bottom','10',0,''),(336412,108960,'1661353033.085331','splash','text','##TEXT_INVOICE_IF_UNDELIVERED##',0,''),(336413,108960,'1661353033.085331','splash','font-weight','bold',0,''),(336414,108961,'1661353033.093224','splash','block_type','4',0,''),(336415,108961,'1661353033.093224','splash','font-weight','400',0,''),(336416,108961,'1661353033.093224','splash','border-top-width','1',0,''),(336417,108961,'1661353033.093224','splash','border-top-color','#e0e0e0',0,''),(336418,108961,'1661353033.093224','splash','border-left-width','1',0,''),(336419,108961,'1661353033.093224','splash','border-left-color','#e0e0e0',0,''),(336420,108961,'1661353033.093224','splash','border-right-width','1',0,''),(336421,108961,'1661353033.093224','splash','border-right-color','#e0e0e0',0,''),(336422,108961,'1661353033.093224','splash','border-bottom-width','1',0,''),(336423,108961,'1661353033.093224','splash','border-bottom-color','#e0e0e0',0,''),(336424,108962,'1661353033.108992','splash','block_type','2',0,''),(336425,108962,'1661353033.108992','splash','font-weight','normal',0,''),(336426,108962,'1661353033.108992','splash','border-right-width','1',0,''),(336427,108962,'1661353033.108992','splash','border-right-color','#e0e0e0',0,''),(336428,108963,'1661353033.11758','splash','block_type','1',0,''),(336429,108963,'1661353033.11758','splash','font-weight','normal',0,''),(336430,108963,'1661353033.11758','splash','border-right-width','1',0,''),(336431,108963,'1661353033.11758','splash','border-right-color','#e0e0e0',0,''),(336432,108963,'1661353033.11758','splash','background-color','#eeeeee',0,''),(336433,108963,'1661353033.11758','splash','padding-top','10',0,''),(336434,108963,'1661353033.11758','splash','padding-left','10',0,''),(336435,108963,'1661353033.11758','splash','padding-right','10',0,''),(336436,108963,'1661353033.11758','splash','padding-bottom','10',0,''),(336437,108964,'1661353033.129825','splash','font-size','12',0,''),(336438,108964,'1661353033.129825','splash','font-weight','normal',0,''),(336439,108965,'1661353033.136397','splash','text','##SHIPPING_ADDRESS##:',0,''),(336440,108965,'1661353033.136397','splash','font-size','13',0,''),(336441,108965,'1661353033.136397','splash','font-weight','bold',0,''),(336442,108965,'1661353033.136397','splash','text-transform','uppercase',0,''),(336443,108966,'1661353033.145276','splash','block_type','1',0,''),(336444,108966,'1661353033.145276','splash','font-weight','normal',0,''),(336445,108966,'1661353033.145276','splash','padding-top','10',0,''),(336446,108966,'1661353033.145276','splash','padding-left','10',0,''),(336447,108966,'1661353033.145276','splash','padding-right','10',0,''),(336448,108966,'1661353033.145276','splash','padding-bottom','10',0,''),(336449,108967,'1661353033.15637','splash','font-size','12',0,''),(336450,108969,'1661353033.16397','splash','font-size','12',0,''),(336451,108970,'1661353033.168995','splash','text','##TEXT_INVOICE_CUSTOMER##',0,''),(336452,108970,'1661353033.168995','splash','font-size','13',0,''),(336453,108970,'1661353033.168995','splash','font-weight','bold',0,''),(336454,108970,'1661353033.168995','splash','text-transform','uppercase',0,''),(336455,108971,'1661353033.176872','splash','text','##TEXT_INVOICE_PHONE_NUMBER##',0,''),(336456,108971,'1661353033.176872','splash','font-size','13',0,''),(336457,108971,'1661353033.176872','splash','font-weight','bold',0,''),(336458,108971,'1661353033.176872','splash','text-transform','uppercase',0,''),(336459,108971,'1661353033.176872','splash','padding-top','10',0,''),(336460,108972,'1661353033.185817','splash','text','##TEXT_INVOICE_EMAIL_ADDRESS##',0,''),(336461,108972,'1661353033.185817','splash','font-size','13',0,''),(336462,108972,'1661353033.185817','splash','font-weight','bold',0,''),(336463,108972,'1661353033.185817','splash','text-transform','uppercase',0,''),(336464,108972,'1661353033.185817','splash','padding-top','10',0,''),(336465,108973,'1661353033.197558','splash','block_type','2',0,''),(336466,108973,'1661353033.197558','splash','font-weight','normal',0,''),(336467,108973,'1661353033.197558','splash','border-right-width','1',0,''),(336468,108973,'1661353033.197558','splash','border-right-color','#e0e0e0',0,''),(336469,108973,'1661353033.197558','splash','border-top-width','1',0,''),(336470,108973,'1661353033.197558','splash','border-top-color','#e0e0e0',0,''),(336471,108974,'1661353033.208111','splash','block_type','1',0,''),(336472,108974,'1661353033.208111','splash','font-weight','normal',0,''),(336473,108974,'1661353033.208111','splash','padding-top','10',0,''),(336474,108974,'1661353033.208111','splash','padding-left','10',0,''),(336475,108974,'1661353033.208111','splash','padding-right','10',0,''),(336476,108974,'1661353033.208111','splash','padding-bottom','10',0,''),(336477,108974,'1661353033.208111','splash','border-right-width','1',0,''),(336478,108974,'1661353033.208111','splash','border-right-color','#e0e0e0',0,''),(336479,108976,'1661353033.22360','splash','text','##TEXT_INVOICE_SHIPPING_VIA##',0,''),(336480,108976,'1661353033.22360','splash','font-weight','bold',0,''),(336481,108977,'1661353033.2314','splash','block_type','1',0,''),(336482,108977,'1661353033.2314','splash','font-weight','normal',0,''),(336483,108977,'1661353033.2314','splash','padding-top','10',0,''),(336484,108977,'1661353033.2314','splash','padding-left','10',0,''),(336485,108977,'1661353033.2314','splash','padding-right','10',0,''),(336486,108977,'1661353033.2314','splash','padding-bottom','10',0,''),(336487,108979,'1661353033.243986','splash','text','##TEXT_INVOICE_SHIPPING_SERVICE##',0,''),(336488,108979,'1661353033.243986','splash','font-weight','bold',0,''),(336489,108980,'1661353033.250617','splash','font-weight','normal',0,''),(336490,108980,'1661353033.250617','splash','text-align','center',0,''),(336491,108980,'1661353033.250617','splash','padding-top','40',0,''),(336492,108981,'1661353033.258425','splash','padding-top','15',0,''),(336493,108983,'74684','splash','block_type','2',0,''),(336494,108984,'74685','splash','block_type','1',0,''),(336495,108984,'74685','splash','style_class','product',0,''),(336496,108984,'74685','splash','padding-right','10',0,''),(336497,108984,'74685','splash','padding-bottom','20',0,''),(336498,108985,'74686','splash','block_type','1',0,''),(336499,108986,'74687','splash','product_element','products_name',0,''),(336500,108986,'74687','splash','font-family','Varela Round',0,''),(336501,108986,'74687','splash','padding-bottom','10',0,''),(336502,108986,'74687','splash','font-size','16',0,''),(336503,108987,'74688','splash','block_type','2',0,''),(336504,108988,'74689','splash','product_element','image',0,''),(336505,108988,'74689','splash','padding-right','10',0,''),(336506,108989,'74690','splash','product_element','products_price_old',0,''),(336507,108989,'74690','splash','font-family','Varela Round',0,''),(336508,108989,'74690','splash','font-size','14',0,''),(336509,108989,'74690','splash','text-decoration','line-through',0,''),(336510,108990,'74691','splash','product_element','products_price',0,''),(336511,108990,'74691','splash','font-family','Varela Round',0,''),(336512,108990,'74691','splash','font-size','20',0,''),(336513,108990,'74691','splash','padding-top','20',0,''),(336514,108991,'74692','splash','block_type','1',0,''),(336515,108991,'74692','splash','style_class','product',0,''),(336516,108991,'74692','splash','padding-left','10',0,''),(336517,108991,'74692','splash','padding-bottom','20',0,''),(336518,108992,'74693','splash','block_type','2',0,''),(336519,108993,'74694','splash','product_element','image',0,''),(336520,108993,'74694','splash','padding-right','10',0,''),(336521,108994,'74695','splash','font-size','14',0,''),(336522,108994,'74695','splash','font-family','Varela Round',0,''),(336523,108994,'74695','splash','text-decoration','line-through',0,''),(336524,108994,'74695','splash','product_element','products_price_old',0,''),(336525,108995,'74696','splash','product_element','products_price',0,''),(336526,108995,'74696','splash','font-family','Varela Round',0,''),(336527,108995,'74696','splash','font-size','20',0,''),(336528,108995,'74696','splash','padding-top','20',0,''),(336529,108996,'74697','splash','block_type','1',0,''),(336530,108997,'74698','splash','product_element','products_name',0,''),(336531,108997,'74698','splash','font-family','Varela Round',0,''),(336532,108997,'74698','splash','font-size','16',0,''),(336533,108997,'74698','splash','padding-bottom','10',0,''),(336534,108998,'74700','splash','padding-bottom','20',0,''),(336535,108998,'74700','splash','text-align','center',0,''),(336536,108999,'74699','splash','font-size','30',0,''),(336537,108999,'74699','splash','font-family','Varela Round',0,''),(336538,108999,'74699','splash','text-align','center',0,''),(336539,108999,'74699','splash','padding-bottom','50',0,''),(336540,109000,'74701','splash','width','680',0,''),(336541,109001,'74702','splash','padding-top','200',0,''),(336542,109001,'74702','splash','padding-left','200',0,''),(336543,109001,'74702','splash','logo','themes/splash/img/oscommerce_logo.jpg',1,''),(336544,109002,'74703','splash','text','osCommerce 4',1,''),(336545,109002,'74703','splash','font-family','Varela Round',0,''),(336546,109002,'74703','splash','font-size','40',0,''),(336547,109002,'74703','splash','padding-top','50',0,''),(336548,109002,'74703','splash','text-align','center',0,''),(336549,109003,'74704','splash','block_type','2',0,''),(336550,109003,'74704','splash','border-top-width','1',0,''),(336551,109003,'74704','splash','border-top-color','#e0e0e0',0,''),(336552,109004,'74705','splash','text-align','right',0,''),(336553,109004,'74705','splash','padding-top','15',0,''),(336554,109004,'74705','splash','padding-bottom','15',0,''),(336555,109004,'74705','splash','font-size','14',0,''),(336556,109005,'74706','splash','font-family','Varela Round',0,''),(336557,109005,'74706','splash','text-align','center',0,''),(336558,109005,'74706','splash','font-size','20',0,''),(336559,109005,'74706','splash','color','#183d78',0,''),(336560,109005,'74706','splash','border-bottom-width','1',0,''),(336561,109005,'74706','splash','border-bottom-color','#e0e0e0',0,''),(336562,109005,'74706','splash','padding-top','10',0,''),(336563,109005,'74706','splash','padding-bottom','10',0,''),(336708,3158,'115992','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',2,''),(336709,3189,'113675','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',2,''),(336710,3888,'114358','watch-mobile','text','<p>Shipping via</p>',2,''),(336711,3892,'114362','watch-mobile','text','<p>Shipping service</p>',2,''),(336712,3896,'114366','watch-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(336713,3898,'114368','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(336714,3901,'114371','watch-mobile','text','<p>PHONE NUMBER:</p>',2,''),(336715,3902,'114372','watch-mobile','text','<p>CUSTOMER:</p>',2,''),(336716,3905,'114375','watch-mobile','text','<p>Payment date:</p>',2,''),(336717,3909,'114379','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(336719,3917,'114387','watch-mobile','text','<p>Email:</p>',2,''),(336720,3920,'114390','watch-mobile','text','<p>Phone:</p>',2,''),(336721,3923,'114393','watch-mobile','text','<p>Web:</p>',2,''),(336722,3928,'114398','watch-mobile','text','<p>If undelivered please return to:</p>',2,''),(336723,3929,'114399','watch-mobile','text','<p>Thank you for your order</p>',2,''),(336725,3932,'114402','watch-mobile','text','<p>Phone:</p>',2,''),(336726,3935,'114405','watch-mobile','text','<p>Email:</p>',2,''),(336727,3937,'114407','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(336728,3956,'75618','watch-mobile','logo','themes/watch-mobile/img/watchlogo-1-1.png',2,''),(336729,3959,'75621','watch-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',2,''),(336730,3970,'114422','watch-mobile','logo','themes/watch-mobile/img/logo-white-1.png',2,''),(336731,3991,'75629','watch-mobile','text','Account',2,''),(336732,3996,'75635','watch-mobile','text','Shop',2,''),(336733,3998,'75637','watch-mobile','text','Products',2,''),(336734,4002,'75642','watch-mobile','text','Contact Us',2,''),(336735,4014,'75655','watch-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(336736,4017,'75658','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(336737,4018,'75659','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336738,4019,'75660','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(336739,4020,'75661','watch-mobile','text','<p>GIFT CARD</p>',2,''),(336740,4022,'75663','watch-mobile','text','<p>Your code is:</p>',2,''),(336741,4026,'75667','watch-mobile','text','<p>HOLBI</p>',2,''),(336742,4028,'75669','watch-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(336743,4031,'114448','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(336744,4032,'114449','watch-mobile','text','<p>GIFT CARD</p>',2,''),(336745,4033,'114450','watch-mobile','logo','themes/watch-mobile/img/logo-1.png',2,''),(336746,4034,'114451','watch-mobile','logo','themes/watch-mobile/img/bestseller-1.png',2,''),(336747,4035,'114452','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336748,4039,'114456','watch-mobile','text','<p>Your code is:</p>',2,''),(336749,4041,'114458','watch-mobile','text','<p>HOLBI</p>',2,''),(336750,4042,'114459','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(336751,4045,'114462','watch-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(336752,4048,'114465','watch-mobile','text','<p>HOLBI</p>',2,''),(336753,4049,'114466','watch-mobile','text','<p>GIFT CARD</p>',2,''),(336754,4050,'114467','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(336755,4052,'114469','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(336756,4053,'114470','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336757,4056,'114473','watch-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(336758,4059,'114476','watch-mobile','text','<p>Your code is:</p>',2,''),(336759,4071,'114488','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336760,4088,'114505','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336761,4100,'114517','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(336762,4101,'114518','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336763,4103,'114520','watch-mobile','text','<p>GIFT CARD</p>',2,''),(336764,4105,'114522','watch-mobile','text','<p>HOLBI</p>',2,''),(336765,4109,'114526','watch-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(336766,4110,'114527','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(336767,4112,'114529','watch-mobile','text','<p>Your code is:</p>',2,''),(336768,4123,'114540','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336769,4130,'75671','watch-mobile','logo','themes/watch-mobile/img/oscommerce_logo.png',2,''),(336770,4144,'75693','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(336771,4149,'75698','watch-mobile','logo','themes/watch-mobile/img/watchlogo-2-1.png',2,''),(336772,4151,'75700','watch-mobile','text','<p>Phone:</p>',2,''),(336773,4156,'75705','watch-mobile','text','<p>Web:</p>',2,''),(336774,4159,'75708','watch-mobile','text','<p>Email:</p>',2,''),(336775,4162,'75711','watch-mobile','text','<p>If undelivered please return to:</p>',2,''),(336776,4164,'75713','watch-mobile','text','<p>Thank you for your order</p>',2,''),(336778,4167,'75716','watch-mobile','text','<p>Email:</p>',2,''),(336779,4170,'75719','watch-mobile','text','<p>Phone:</p>',2,''),(336780,4172,'75721','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(336781,4176,'75725','watch-mobile','text','<p>Shipping via</p>',2,''),(336782,4180,'75729','watch-mobile','text','<p>Shipping service</p>',2,''),(336783,4183,'75732','watch-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(336784,4187,'75736','watch-mobile','text','<p>CUSTOMER:</p>',2,''),(336785,4189,'75738','watch-mobile','text','<p>PHONE NUMBER:</p>',2,''),(336786,4190,'75739','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(336787,4196,'75745','watch-mobile','text','<p>Payment date:</p>',2,''),(336788,4197,'75746','watch-mobile','text','<p>Payment Method:</p>',2,''),(336789,4199,'94803','watch-mobile','tab_1','RETURNING CUSTOMER',2,''),(336790,4199,'94803','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(336791,4221,'114562','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(336792,4221,'114562','watch-mobile','tab_2','RETURNING CUSTOMER',2,''),(336793,4221,'114562','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(336794,4237,'114578','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(336795,4237,'114578','watch-mobile','tab_2','RETURNING CUSTOMER',2,''),(336796,4237,'114578','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(336797,4250,'114591','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(336798,4250,'114591','watch-mobile','tab_2','RETURNING CUSTOMER',2,''),(336799,4250,'114591','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(336800,4291,'75750','watch-mobile','tab_1','New products',2,''),(336801,4291,'75750','watch-mobile','tab_2','Specials products',2,''),(336802,4291,'75750','watch-mobile','tab_3','Featured',2,''),(336803,4324,'114653','watch-mobile','tab_1','RETURNING CUSTOMER',2,''),(336804,4324,'114653','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(336805,4446,'75764','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(336806,4452,'75770','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(336807,4453,'75771','watch-mobile','text','<p>CUSTOMER:</p>',2,''),(336808,4454,'75772','watch-mobile','text','<p>PHONE NUMBER:</p>',2,''),(336809,4458,'75776','watch-mobile','text','<p>Shipping via</p>',2,''),(336810,4460,'75778','watch-mobile','text','<p>Shipping service</p>',2,''),(336811,4464,'75782','watch-mobile','text','<p>If undelivered please return to:</p>',2,''),(336812,4467,'75785','watch-mobile','logo','themes/watch-mobile/img/watchlogo-3.png',2,''),(336813,4471,'75789','watch-mobile','text','<p>Phone:</p>',2,''),(336814,4474,'75792','watch-mobile','text','<p>Web:</p>',2,''),(336815,4477,'75795','watch-mobile','text','<p>Email:</p>',2,''),(336817,4504,'75817','watch-mobile','text','osCommerce 4',2,''),(336818,4539,'75840','watch-mobile','tab_1','Description',2,''),(336819,4539,'75840','watch-mobile','tab_2','Reviews',2,''),(336820,4584,'114794','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(336821,4589,'114799','watch-mobile','text','<p>ADDRESS:</p>\n',2,''),(336822,4592,'114802','watch-mobile','text','<p>CUSTOMER:</p>',2,''),(336823,4593,'114803','watch-mobile','text','<p>PHONE NUMBER:</p>',2,''),(336824,4594,'114804','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(336825,4598,'114808','watch-mobile','text','<p>Order date:</p>\n',2,''),(336827,4606,'114816','watch-mobile','text','<p>Email:</p>',2,''),(336828,4609,'114819','watch-mobile','text','<p>Web:</p>',2,''),(336829,4612,'114822','watch-mobile','text','<p>Phone:</p>',2,''),(336830,4616,'114826','watch-mobile','text','<p>If undelivered please return to:</p>',2,''),(336831,4617,'114827','watch-mobile','text','<p>Thank you for your order</p>',2,''),(336833,4620,'114830','watch-mobile','text','<p>Phone:</p>',2,''),(336834,4622,'114832','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(336835,4624,'114834','watch-mobile','text','<p>Email:</p>',2,''),(336836,4664,'75868','watch-mobile','text','<h1>Quotations</h1>',2,''),(336837,4781,'114988','watch-mobile','logo','themes/watch-mobile/img/Furntech-1.jpg',2,''),(336838,4805,'75872','watch-mobile','text','<h1>Samples</h1>',2,''),(336839,4891,'75875','watch-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',2,''),(336840,4910,'115079','watch-mobile','text','<p>Phone:</p>',2,''),(336841,4913,'115082','watch-mobile','text','<p>Web:</p>',2,''),(336842,4916,'115085','watch-mobile','text','<p>Email:</p>',2,''),(336843,4921,'115090','watch-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(336844,4924,'115093','watch-mobile','text','<p>PHONE NUMBER:</p>',2,''),(336845,4925,'115094','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(336846,4926,'115095','watch-mobile','text','<p>CUSTOMER:</p>',2,''),(336847,4932,'115101','watch-mobile','text','<p>Shipping via</p>',2,''),(336848,4936,'115105','watch-mobile','text','<p>Shipping service</p>',2,''),(336849,4937,'115106','watch-mobile','text','<p>Payment date:</p>',2,''),(336850,4939,'115108','watch-mobile','text','<p>Payment Method:</p>',2,''),(336851,4944,'115113','watch-mobile','text','<p>If undelivered please return to:</p>',2,''),(336853,4947,'115116','watch-mobile','text','<p>Thank you for your order</p>',2,''),(336854,4949,'115118','watch-mobile','text','<p>Phone:</p>',2,''),(336855,4951,'115120','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(336856,4953,'115122','watch-mobile','text','<p>Email:</p>',2,''),(336857,4959,'115128','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(336986,13141,'118691','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',2,''),(336987,13172,'118722','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',2,''),(336988,13877,'119427','printshop-mobile','text','<p>Shipping via</p>',2,''),(336989,13881,'119431','printshop-mobile','text','<p>Shipping service</p>',2,''),(336990,13885,'119435','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(336991,13887,'119437','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(336992,13890,'119440','printshop-mobile','text','<p>PHONE NUMBER:</p>',2,''),(336993,13891,'119441','printshop-mobile','text','<p>CUSTOMER:</p>',2,''),(336994,13894,'119444','printshop-mobile','text','<p>Payment date:</p>',2,''),(336995,13898,'119448','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(336997,13906,'119456','printshop-mobile','text','<p>Email:</p>',2,''),(336998,13909,'119459','printshop-mobile','text','<p>Phone:</p>',2,''),(336999,13912,'119462','printshop-mobile','text','<p>Web:</p>',2,''),(337000,13917,'119467','printshop-mobile','text','<p>If undelivered please return to:</p>',2,''),(337001,13918,'119468','printshop-mobile','text','<p>Thank you for your order</p>',2,''),(337003,13921,'119471','printshop-mobile','text','<p>Phone:</p>',2,''),(337004,13924,'119474','printshop-mobile','text','<p>Email:</p>',2,''),(337005,13926,'119476','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337006,13948,'119498','printshop-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',2,''),(337007,13959,'119509','printshop-mobile','logo','themes/printshop-mobile/img/logo-white-1.png',2,''),(337008,13980,'119530','printshop-mobile','text','Account',2,''),(337009,13985,'119535','printshop-mobile','text','Account',2,''),(337010,13987,'119537','printshop-mobile','text','Account',2,''),(337011,13991,'119541','printshop-mobile','text','Account',2,''),(337012,14003,'119553','printshop-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337013,14006,'119556','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337014,14007,'119557','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337015,14008,'119558','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(337016,14009,'119559','printshop-mobile','text','<p>GIFT CARD</p>',2,''),(337017,14011,'119561','printshop-mobile','text','<p>Your code is:</p>',2,''),(337018,14015,'119565','printshop-mobile','text','<p>HOLBI</p>',2,''),(337019,14017,'119567','printshop-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(337020,14020,'119570','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(337021,14021,'119571','printshop-mobile','text','<p>GIFT CARD</p>',2,''),(337022,14022,'119572','printshop-mobile','logo','themes/printshop-mobile/img/logo-1.png',2,''),(337023,14023,'119573','printshop-mobile','logo','themes/printshop-mobile/img/bestseller-1.png',2,''),(337024,14024,'119574','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337025,14028,'119578','printshop-mobile','text','<p>Your code is:</p>',2,''),(337026,14030,'119580','printshop-mobile','text','<p>HOLBI</p>',2,''),(337027,14031,'119581','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337028,14034,'119584','printshop-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337029,14037,'119587','printshop-mobile','text','<p>HOLBI</p>',2,''),(337030,14038,'119588','printshop-mobile','text','<p>GIFT CARD</p>',2,''),(337031,14039,'119589','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337032,14041,'119591','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(337033,14042,'119592','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337034,14045,'119595','printshop-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337035,14048,'119598','printshop-mobile','text','<p>Your code is:</p>',2,''),(337036,14060,'119610','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337037,14077,'119627','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337038,14089,'119639','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(337039,14090,'119640','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337040,14092,'119642','printshop-mobile','text','<p>GIFT CARD</p>',2,''),(337041,14094,'119644','printshop-mobile','text','<p>HOLBI</p>',2,''),(337042,14098,'119648','printshop-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337043,14099,'119649','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337044,14101,'119651','printshop-mobile','text','<p>Your code is:</p>',2,''),(337045,14112,'119662','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337046,14119,'119669','printshop-mobile','logo','themes/printshop-mobile/img/oscommerce_logo.png',2,''),(337047,14122,'119672','printshop-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',2,''),(337048,14124,'119674','printshop-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',2,''),(337049,14125,'119675','printshop-mobile','logo','themes/printshop-mobile/img/check-2.png',2,''),(337050,14141,'119691','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337052,14148,'119698','printshop-mobile','text','<p>Phone:</p>',2,''),(337053,14153,'119703','printshop-mobile','text','<p>Web:</p>',2,''),(337054,14156,'119706','printshop-mobile','text','<p>Email:</p>',2,''),(337055,14159,'119709','printshop-mobile','text','<p>If undelivered please return to:</p>',2,''),(337056,14161,'119711','printshop-mobile','text','<p>Thank you for your order</p>',2,''),(337058,14164,'119714','printshop-mobile','text','<p>Email:</p>',2,''),(337059,14167,'119717','printshop-mobile','text','<p>Phone:</p>',2,''),(337060,14169,'119719','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337061,14173,'119723','printshop-mobile','text','<p>Shipping via</p>',2,''),(337062,14177,'119727','printshop-mobile','text','<p>Shipping service</p>',2,''),(337063,14180,'119730','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337064,14184,'119734','printshop-mobile','text','<p>CUSTOMER:</p>',2,''),(337065,14186,'119736','printshop-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337066,14187,'119737','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337067,14193,'119743','printshop-mobile','text','<p>Payment date:</p>',2,''),(337068,14194,'119744','printshop-mobile','text','<p>Payment Method:</p>',2,''),(337069,14196,'119746','printshop-mobile','tab_1','RETURNING CUSTOMER',2,''),(337070,14196,'119746','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(337071,14218,'119768','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337072,14218,'119768','printshop-mobile','tab_2','RETURNING CUSTOMER',2,''),(337073,14218,'119768','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337074,14234,'119784','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337075,14234,'119784','printshop-mobile','tab_2','RETURNING CUSTOMER',2,''),(337076,14234,'119784','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337077,14247,'119797','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337078,14247,'119797','printshop-mobile','tab_2','RETURNING CUSTOMER',2,''),(337079,14247,'119797','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337080,14288,'119838','printshop-mobile','tab_1','New products',2,''),(337081,14288,'119838','printshop-mobile','tab_2','Specials products',2,''),(337082,14288,'119838','printshop-mobile','tab_3','Featured',2,''),(337083,14321,'119871','printshop-mobile','tab_1','RETURNING CUSTOMER',2,''),(337084,14321,'119871','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(337085,14443,'119993','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337086,14449,'119999','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337087,14450,'120000','printshop-mobile','text','<p>CUSTOMER:</p>',2,''),(337088,14451,'120001','printshop-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337089,14455,'120005','printshop-mobile','text','<p>Shipping via</p>',2,''),(337090,14457,'120007','printshop-mobile','text','<p>Shipping service</p>',2,''),(337091,14461,'120011','printshop-mobile','text','<p>If undelivered please return to:</p>',2,''),(337093,14468,'120018','printshop-mobile','text','<p>Phone:</p>',2,''),(337094,14471,'120021','printshop-mobile','text','<p>Web:</p>',2,''),(337095,14474,'120024','printshop-mobile','text','<p>Email:</p>',2,''),(337097,14501,'120051','printshop-mobile','text','osCommerce 4',2,''),(337098,14536,'120086','printshop-mobile','tab_1','Description',2,''),(337099,14536,'120086','printshop-mobile','tab_2','Reviews',2,''),(337100,14581,'120131','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337101,14586,'120136','printshop-mobile','text','<p>ADDRESS:</p>\n',2,''),(337102,14589,'120139','printshop-mobile','text','<p>CUSTOMER:</p>',2,''),(337103,14590,'120140','printshop-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337104,14591,'120141','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337105,14595,'120145','printshop-mobile','text','<p>Order date:</p>\n',2,''),(337107,14603,'120153','printshop-mobile','text','<p>Email:</p>',2,''),(337108,14606,'120156','printshop-mobile','text','<p>Web:</p>',2,''),(337109,14609,'120159','printshop-mobile','text','<p>Phone:</p>',2,''),(337110,14613,'120163','printshop-mobile','text','<p>If undelivered please return to:</p>',2,''),(337111,14614,'120164','printshop-mobile','text','<p>Thank you for your order</p>',2,''),(337113,14617,'120167','printshop-mobile','text','<p>Phone:</p>',2,''),(337114,14619,'120169','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337115,14621,'120171','printshop-mobile','text','<p>Email:</p>',2,''),(337116,14661,'120211','printshop-mobile','text','<h1>Quotations</h1>',2,''),(337117,14778,'120328','printshop-mobile','logo','themes/printshop-mobile/img/Furntech-1.jpg',2,''),(337118,14802,'120352','printshop-mobile','text','<h1>Samples</h1>',2,''),(337119,14888,'120438','printshop-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',2,''),(337120,14907,'120457','printshop-mobile','text','<p>Phone:</p>',2,''),(337121,14910,'120460','printshop-mobile','text','<p>Web:</p>',2,''),(337122,14913,'120463','printshop-mobile','text','<p>Email:</p>',2,''),(337123,14918,'120468','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337124,14921,'120471','printshop-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337125,14922,'120472','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337126,14923,'120473','printshop-mobile','text','<p>CUSTOMER:</p>',2,''),(337127,14929,'120479','printshop-mobile','text','<p>Shipping via</p>',2,''),(337128,14933,'120483','printshop-mobile','text','<p>Shipping service</p>',2,''),(337129,14934,'120484','printshop-mobile','text','<p>Payment date:</p>',2,''),(337130,14936,'120486','printshop-mobile','text','<p>Payment Method:</p>',2,''),(337131,14941,'120491','printshop-mobile','text','<p>If undelivered please return to:</p>',2,''),(337133,14944,'120494','printshop-mobile','text','<p>Thank you for your order</p>',2,''),(337134,14946,'120496','printshop-mobile','text','<p>Phone:</p>',2,''),(337135,14948,'120498','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337136,14950,'120500','printshop-mobile','text','<p>Email:</p>',2,''),(337137,14956,'120506','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337262,18022,'118691','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',2,''),(337263,18053,'118722','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',2,''),(337264,18758,'119427','deals-mobile','text','<p>Shipping via</p>',2,''),(337265,18762,'119431','deals-mobile','text','<p>Shipping service</p>',2,''),(337266,18766,'119435','deals-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337267,18768,'119437','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337268,18771,'119440','deals-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337269,18772,'119441','deals-mobile','text','<p>CUSTOMER:</p>',2,''),(337270,18775,'119444','deals-mobile','text','<p>Payment date:</p>',2,''),(337271,18779,'119448','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337273,18787,'119456','deals-mobile','text','<p>Email:</p>',2,''),(337274,18790,'119459','deals-mobile','text','<p>Phone:</p>',2,''),(337275,18793,'119462','deals-mobile','text','<p>Web:</p>',2,''),(337276,18798,'119467','deals-mobile','text','<p>If undelivered please return to:</p>',2,''),(337277,18799,'119468','deals-mobile','text','<p>Thank you for your order</p>',2,''),(337279,18802,'119471','deals-mobile','text','<p>Phone:</p>',2,''),(337280,18805,'119474','deals-mobile','text','<p>Email:</p>',2,''),(337281,18807,'119476','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337282,18829,'119498','deals-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',2,''),(337283,18840,'119509','deals-mobile','logo','themes/deals-mobile/img/logo-white-1.png',2,''),(337284,18861,'119530','deals-mobile','text','Account',2,''),(337285,18866,'119535','deals-mobile','text','Account',2,''),(337286,18868,'119537','deals-mobile','text','Account',2,''),(337287,18872,'119541','deals-mobile','text','Account',2,''),(337288,18884,'119553','deals-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337289,18887,'119556','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337290,18888,'119557','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337291,18889,'119558','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(337292,18890,'119559','deals-mobile','text','<p>GIFT CARD</p>',2,''),(337293,18892,'119561','deals-mobile','text','<p>Your code is:</p>',2,''),(337294,18896,'119565','deals-mobile','text','<p>HOLBI</p>',2,''),(337295,18898,'119567','deals-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(337296,18901,'119570','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(337297,18902,'119571','deals-mobile','text','<p>GIFT CARD</p>',2,''),(337298,18903,'119572','deals-mobile','logo','themes/deals-mobile/img/logo-1.png',2,''),(337299,18904,'119573','deals-mobile','logo','themes/deals-mobile/img/bestseller-1.png',2,''),(337300,18905,'119574','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337301,18909,'119578','deals-mobile','text','<p>Your code is:</p>',2,''),(337302,18911,'119580','deals-mobile','text','<p>HOLBI</p>',2,''),(337303,18912,'119581','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337304,18915,'119584','deals-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337305,18918,'119587','deals-mobile','text','<p>HOLBI</p>',2,''),(337306,18919,'119588','deals-mobile','text','<p>GIFT CARD</p>',2,''),(337307,18920,'119589','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337308,18922,'119591','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(337309,18923,'119592','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337310,18926,'119595','deals-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337311,18929,'119598','deals-mobile','text','<p>Your code is:</p>',2,''),(337312,18941,'119610','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337313,18958,'119627','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337314,18970,'119639','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(337315,18971,'119640','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337316,18973,'119642','deals-mobile','text','<p>GIFT CARD</p>',2,''),(337317,18975,'119644','deals-mobile','text','<p>HOLBI</p>',2,''),(337318,18979,'119648','deals-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337319,18980,'119649','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337320,18982,'119651','deals-mobile','text','<p>Your code is:</p>',2,''),(337321,18993,'119662','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337322,19000,'119669','deals-mobile','logo','themes/deals-mobile/img/oscommerce_logo.png',2,''),(337323,19003,'119672','deals-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',2,''),(337324,19005,'119674','deals-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',2,''),(337325,19006,'119675','deals-mobile','logo','themes/deals-mobile/img/check-2.png',2,''),(337326,19022,'119691','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337328,19029,'119698','deals-mobile','text','<p>Phone:</p>',2,''),(337329,19034,'119703','deals-mobile','text','<p>Web:</p>',2,''),(337330,19037,'119706','deals-mobile','text','<p>Email:</p>',2,''),(337331,19040,'119709','deals-mobile','text','<p>If undelivered please return to:</p>',2,''),(337332,19042,'119711','deals-mobile','text','<p>Thank you for your order</p>',2,''),(337334,19045,'119714','deals-mobile','text','<p>Email:</p>',2,''),(337335,19048,'119717','deals-mobile','text','<p>Phone:</p>',2,''),(337336,19050,'119719','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337337,19054,'119723','deals-mobile','text','<p>Shipping via</p>',2,''),(337338,19058,'119727','deals-mobile','text','<p>Shipping service</p>',2,''),(337339,19061,'119730','deals-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337340,19065,'119734','deals-mobile','text','<p>CUSTOMER:</p>',2,''),(337341,19067,'119736','deals-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337342,19068,'119737','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337343,19074,'119743','deals-mobile','text','<p>Payment date:</p>',2,''),(337344,19075,'119744','deals-mobile','text','<p>Payment Method:</p>',2,''),(337345,19077,'119746','deals-mobile','tab_1','RETURNING CUSTOMER',2,''),(337346,19077,'119746','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(337347,19099,'119768','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337348,19099,'119768','deals-mobile','tab_2','RETURNING CUSTOMER',2,''),(337349,19099,'119768','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337350,19115,'119784','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337351,19115,'119784','deals-mobile','tab_2','RETURNING CUSTOMER',2,''),(337352,19115,'119784','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337353,19128,'119797','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337354,19128,'119797','deals-mobile','tab_2','RETURNING CUSTOMER',2,''),(337355,19128,'119797','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337356,19169,'119838','deals-mobile','tab_1','New products',2,''),(337357,19169,'119838','deals-mobile','tab_2','Specials products',2,''),(337358,19169,'119838','deals-mobile','tab_3','Featured',2,''),(337359,19202,'119871','deals-mobile','tab_1','RETURNING CUSTOMER',2,''),(337360,19202,'119871','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(337361,19324,'119993','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337362,19330,'119999','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337363,19331,'120000','deals-mobile','text','<p>CUSTOMER:</p>',2,''),(337364,19332,'120001','deals-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337365,19336,'120005','deals-mobile','text','<p>Shipping via</p>',2,''),(337366,19338,'120007','deals-mobile','text','<p>Shipping service</p>',2,''),(337367,19342,'120011','deals-mobile','text','<p>If undelivered please return to:</p>',2,''),(337369,19349,'120018','deals-mobile','text','<p>Phone:</p>',2,''),(337370,19352,'120021','deals-mobile','text','<p>Web:</p>',2,''),(337371,19355,'120024','deals-mobile','text','<p>Email:</p>',2,''),(337373,19382,'120051','deals-mobile','text','osCommerce 4',2,''),(337374,19417,'120086','deals-mobile','tab_1','Description',2,''),(337375,19417,'120086','deals-mobile','tab_2','Reviews',2,''),(337376,19462,'120131','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337377,19467,'120136','deals-mobile','text','<p>ADDRESS:</p>\n',2,''),(337378,19470,'120139','deals-mobile','text','<p>CUSTOMER:</p>',2,''),(337379,19471,'120140','deals-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337380,19472,'120141','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337381,19476,'120145','deals-mobile','text','<p>Order date:</p>\n',2,''),(337383,19484,'120153','deals-mobile','text','<p>Email:</p>',2,''),(337384,19487,'120156','deals-mobile','text','<p>Web:</p>',2,''),(337385,19490,'120159','deals-mobile','text','<p>Phone:</p>',2,''),(337386,19494,'120163','deals-mobile','text','<p>If undelivered please return to:</p>',2,''),(337387,19495,'120164','deals-mobile','text','<p>Thank you for your order</p>',2,''),(337389,19498,'120167','deals-mobile','text','<p>Phone:</p>',2,''),(337390,19500,'120169','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337391,19502,'120171','deals-mobile','text','<p>Email:</p>',2,''),(337392,19542,'120211','deals-mobile','text','<h1>Quotations</h1>',2,''),(337393,19659,'120328','deals-mobile','logo','themes/deals-mobile/img/Furntech-1.jpg',2,''),(337394,19683,'120352','deals-mobile','text','<h1>Samples</h1>',2,''),(337395,19769,'120438','deals-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',2,''),(337396,19788,'120457','deals-mobile','text','<p>Phone:</p>',2,''),(337397,19791,'120460','deals-mobile','text','<p>Web:</p>',2,''),(337398,19794,'120463','deals-mobile','text','<p>Email:</p>',2,''),(337399,19799,'120468','deals-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337400,19802,'120471','deals-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337401,19803,'120472','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337402,19804,'120473','deals-mobile','text','<p>CUSTOMER:</p>',2,''),(337403,19810,'120479','deals-mobile','text','<p>Shipping via</p>',2,''),(337404,19814,'120483','deals-mobile','text','<p>Shipping service</p>',2,''),(337405,19815,'120484','deals-mobile','text','<p>Payment date:</p>',2,''),(337406,19817,'120486','deals-mobile','text','<p>Payment Method:</p>',2,''),(337407,19822,'120491','deals-mobile','text','<p>If undelivered please return to:</p>',2,''),(337409,19825,'120494','deals-mobile','text','<p>Thank you for your order</p>',2,''),(337410,19827,'120496','deals-mobile','text','<p>Phone:</p>',2,''),(337411,19829,'120498','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337412,19831,'120500','deals-mobile','text','<p>Email:</p>',2,''),(337413,19837,'120506','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337546,54257,'116269','furniture-mobile','logo','themes/furniture-mobile/img/payicons-1.png',2,''),(337547,55017,'116977','furniture-mobile','text','<p>If undelivered please return to:</p>',2,''),(337548,55018,'116978','furniture-mobile','text','<p>Thank you for your order</p>',2,''),(337550,55020,'116980','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337551,55022,'116982','furniture-mobile','text','<p>Email:</p>',2,''),(337552,55025,'116985','furniture-mobile','text','<p>Phone:</p>',2,''),(337554,55031,'116991','furniture-mobile','text','<p>Web:</p>',2,''),(337555,55034,'116994','furniture-mobile','text','<p>Phone:</p>',2,''),(337556,55037,'116997','furniture-mobile','text','<p>Email:</p>',2,''),(337557,55044,'117004','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337558,55049,'117009','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337559,55053,'117013','furniture-mobile','text','<p>CUSTOMER:</p>',2,''),(337560,55054,'117014','furniture-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337561,55057,'117017','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337562,55061,'117021','furniture-mobile','text','<p>Shipping via</p>',2,''),(337563,55063,'117023','furniture-mobile','text','<p>Shipping service</p>',2,''),(337564,55066,'117026','furniture-mobile','text','<p>Payment date:</p>',2,''),(337565,55101,'117055','furniture-mobile','logo','themes/furniture-mobile/img/logo-white-1.png',2,''),(337566,55150,'117107','furniture-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(337567,55155,'117112','furniture-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337568,55157,'117114','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337569,55158,'117115','furniture-mobile','text','<p>osCommerce</p>\n',2,''),(337570,55160,'117117','furniture-mobile','text','<p>Your code is:</p>',2,''),(337571,55164,'117121','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337572,55165,'117123','furniture-mobile','logo','themes/furniture-mobile/img/Logo-1.jpg',2,''),(337573,55166,'117124','furniture-mobile','text','<p>GIFT CARD</p>',2,''),(337574,55167,'117125','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(337575,55171,'117129','furniture-mobile','text','<p>Your code is:</p>',2,''),(337576,55175,'117133','furniture-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337577,55178,'117136','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337578,55179,'117137','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(337579,55180,'117138','furniture-mobile','text','<p>GIFT CARD</p>',2,''),(337580,55181,'117139','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337581,55192,'117150','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337582,55209,'117167','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337583,55221,'117180','furniture-mobile','text','<p>Your code is:</p>',2,''),(337584,55223,'117182','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337585,55225,'117185','furniture-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337586,55229,'117189','furniture-mobile','text','<p>GIFT CARD</p>',2,''),(337587,55230,'117190','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337588,55232,'117192','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(337589,55243,'117202','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337591,55258,'117218','furniture-mobile','logo','themes/furniture-mobile/img/header-img-1.png',2,''),(337592,55279,'117234','furniture-mobile','text','<p>Shipping via</p>',2,''),(337593,55281,'117236','furniture-mobile','text','<p>Shipping service</p>',2,''),(337594,55285,'117240','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337595,55289,'117243','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337596,55292,'117246','furniture-mobile','text','<p>CUSTOMER:</p>',2,''),(337597,55293,'117247','furniture-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337598,55296,'117250','furniture-mobile','text','<p>Payment Method:</p>',2,''),(337599,55297,'117251','furniture-mobile','text','<p>Payment date:</p>',2,''),(337600,55303,'117257','furniture-mobile','text','<p>If undelivered please return to:</p>',2,''),(337601,55304,'117258','furniture-mobile','text','<p>Thank you for your order</p>',2,''),(337602,55306,'117261','furniture-mobile','text','<p>Email:</p>',2,''),(337603,55309,'117264','furniture-mobile','text','<p>Phone:</p>',2,''),(337604,55311,'117266','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337605,55316,'117271','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337606,55320,'117275','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',2,''),(337607,55322,'117277','furniture-mobile','text','<p>Web:</p>',2,''),(337608,55325,'117280','furniture-mobile','text','<p>Email:</p>',2,''),(337609,55330,'117285','furniture-mobile','text','<p>Phone:</p>',2,''),(337610,55337,'117288','furniture-mobile','tab_1','RETURNING CUSTOMER',2,''),(337611,55337,'117288','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(337612,55360,'117311','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337613,55360,'117311','furniture-mobile','tab_2','RETURNING CUSTOMER',2,''),(337614,55360,'117311','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337615,55376,'117327','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337616,55376,'117327','furniture-mobile','tab_2','RETURNING CUSTOMER',2,''),(337617,55376,'117327','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337618,55393,'117344','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337619,55393,'117344','furniture-mobile','tab_2','RETURNING CUSTOMER',2,''),(337620,55393,'117344','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337621,55486,'117416','furniture-mobile','tab_1','RETURNING CUSTOMER',2,''),(337622,55486,'117416','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(337623,55663,'117536','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',2,''),(337624,55665,'117538','furniture-mobile','text','<p>Email:</p>',2,''),(337625,55668,'117541','furniture-mobile','text','<p>Phone:</p>',2,''),(337626,55673,'117546','furniture-mobile','text','<p>Web:</p>',2,''),(337627,55678,'117551','furniture-mobile','text','<p>If undelivered please return to:</p>',2,''),(337628,55683,'117556','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337629,55685,'117558','furniture-mobile','text','<p>CUSTOMER:</p>',2,''),(337630,55688,'117561','furniture-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337631,55690,'117563','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337632,55694,'117567','furniture-mobile','text','<p>Shipping via</p>',2,''),(337633,55697,'117570','furniture-mobile','text','<p>Shipping service</p>',2,''),(337634,55726,'117596','furniture-mobile','logo','themes/furniture-mobile/img/oscommerce_logo-1.jpg',2,''),(337635,55727,'117597','furniture-mobile','text','osCommerce 4',2,''),(337636,55764,'117646','furniture-mobile','tab_1','Product Overview',2,''),(337637,55764,'117646','furniture-mobile','tab_2','Delivery and returns',2,''),(337638,55764,'117646','furniture-mobile','tab_3','Assembly',2,''),(337639,55882,'117702','furniture-mobile','text','<p>If undelivered please return to:</p>',2,''),(337640,55884,'117704','furniture-mobile','text','<p>Thank you for your order</p>',2,''),(337642,55887,'117707','furniture-mobile','text','<p>Email:</p>',2,''),(337643,55889,'117709','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337644,55891,'117711','furniture-mobile','text','<p>Phone:</p>',2,''),(337646,55896,'117716','furniture-mobile','text','<p>Phone:</p>',2,''),(337647,55899,'117719','furniture-mobile','text','<p>Web:</p>',2,''),(337648,55904,'117724','furniture-mobile','text','<p>Email:</p>',2,''),(337649,55910,'117730','furniture-mobile','text','<p>ADDRESS:</p>\n',2,''),(337650,55913,'117733','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337651,55916,'117736','furniture-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337652,55917,'117737','furniture-mobile','text','<p>CUSTOMER:</p>',2,''),(337653,55919,'117739','furniture-mobile','text','<p>Order date:</p>\n',2,''),(337654,55924,'117744','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337655,56056,'117816','furniture-mobile','logo','themes/furniture-mobile/img/Furntech-1.jpg',2,''),(337656,56314,'118011','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337657,56318,'118015','furniture-mobile','text','<p>If undelivered please return to:</p>',2,''),(337658,56320,'118018','furniture-mobile','text','<p>Thank you for your order</p>',2,''),(337659,56321,'118019','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337660,56323,'118021','furniture-mobile','text','<p>Email:</p>',2,''),(337661,56326,'118024','furniture-mobile','text','<p>Phone:</p>',2,''),(337662,56331,'118029','furniture-mobile','text','<p>Email:</p>',2,''),(337663,56334,'118032','furniture-mobile','text','<p>Web:</p>',2,''),(337664,56339,'118037','furniture-mobile','text','<p>Phone:</p>',2,''),(337665,56344,'118042','furniture-mobile','text','<p>Shipping via</p>',2,''),(337666,56347,'118045','furniture-mobile','text','<p>Shipping service</p>',2,''),(337667,56352,'118050','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337668,56355,'118053','furniture-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337669,56358,'118056','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337670,56359,'118057','furniture-mobile','text','<p>CUSTOMER:</p>',2,''),(337671,56361,'118059','furniture-mobile','text','<p>Payment date:</p>',2,''),(337672,56362,'118060','furniture-mobile','text','<p>Payment Method:</p>',2,''),(337937,108868,'117051','splash','logo','themes/splash/img/oscommerce_logo_(2)-1.png',2,''),(337938,108918,'1661353032.672459','splash','logo','themes/splash/img/oscommerce_logo.jpg',2,''),(337939,108933,'1640168618.7708','splash','logo','themes/splash/img/oscommerce_logo (2).png',2,''),(337940,108936,'1640169872.1589','splash','img_link','furniture/',2,''),(337941,108936,'1640169872.1589','splash','logo','themes/splash/img/Splash_furniture_BGlogo.png',2,''),(337942,108936,'1640169872.1589','splash','target_blank','1',2,''),(337943,108937,'1640276640.1123','splash','text','<h1>osCommerce v4 Splash page</h1>\r\n\r\n<p>osCommerce supports multiple sales CHANNELS.</p>\r\n\r\n<p>Your installation of osCommerce comes with &nbsp;&quot;Furniture&quot;, &quot;Watch&quot;, &quot;B2B Supermarket&quot;, and &quot;Print shop&quot; Ecommerce sales channels and &quot;cms&quot; brochure website example.</p>\r\n\r\n<p>Each sales channel has its own URLs, design, and demo product sets.</p>\r\n\r\n<p>&quot;Admin&quot; is the back end of your osCommerce.</p>\r\n\r\n<p>Use osCommerce Wiki to learn how to manage sales channels, &nbsp;assign design themes, and content to the sales channels.<br />\r\nThank you for choosing &nbsp;osCommerce - the most powerful on-premise open source Ecommerce platform!</p>\r\n',2,''),(337944,108938,'1640170154.7803','splash','img_link','watch/',2,''),(337945,108938,'1640170154.7803','splash','logo','themes/splash/img/Splash_watch_BGlogo.png',2,''),(337946,108938,'1640170154.7803','splash','target_blank','1',2,''),(337947,108940,'1640170023.0001','splash','img_link','printshop/',2,''),(337948,108940,'1640170023.0001','splash','logo','themes/splash/img/print shop.jpg',2,''),(337949,108940,'1640170023.0001','splash','target_blank','1',2,''),(337950,108941,'1640170023.1491','splash','img_link','admin/',2,''),(337951,108941,'1640170023.1491','splash','logo','themes/splash/img/Splash_admin_BGlogo.png',2,''),(337952,108941,'1640170023.1491','splash','target_blank','1',2,''),(337953,108942,'1640170023','splash','img_link','b2b-supermarket/',2,''),(337954,108942,'1640170023','splash','logo','themes/splash/img/b2b supermarket.jpg',2,''),(337955,108942,'1640170023','splash','target_blank','1',2,''),(337956,108945,'1661353032.975845','splash','logo','themes/splash/img/oscommerce_logo-1.jpg',2,''),(337957,109001,'74702','splash','logo','themes/splash/img/oscommerce_logo.jpg',2,''),(337958,109002,'74703','splash','text','osCommerce 4',2,''),(338090,3158,'115992','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',3,''),(338091,3189,'113675','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',3,''),(338092,3888,'114358','watch-mobile','text','<p>Shipping via</p>',3,''),(338093,3892,'114362','watch-mobile','text','<p>Shipping service</p>',3,''),(338094,3896,'114366','watch-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338095,3898,'114368','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338096,3901,'114371','watch-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338097,3902,'114372','watch-mobile','text','<p>CUSTOMER:</p>',3,''),(338098,3905,'114375','watch-mobile','text','<p>Payment date:</p>',3,''),(338099,3909,'114379','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338101,3917,'114387','watch-mobile','text','<p>Email:</p>',3,''),(338102,3920,'114390','watch-mobile','text','<p>Phone:</p>',3,''),(338103,3923,'114393','watch-mobile','text','<p>Web:</p>',3,''),(338104,3928,'114398','watch-mobile','text','<p>If undelivered please return to:</p>',3,''),(338105,3929,'114399','watch-mobile','text','<p>Thank you for your order</p>',3,''),(338107,3932,'114402','watch-mobile','text','<p>Phone:</p>',3,''),(338108,3935,'114405','watch-mobile','text','<p>Email:</p>',3,''),(338109,3937,'114407','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338110,3956,'75618','watch-mobile','logo','themes/watch-mobile/img/watchlogo-1-1.png',3,''),(338111,3959,'75621','watch-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',3,''),(338112,3970,'114422','watch-mobile','logo','themes/watch-mobile/img/logo-white-1.png',3,''),(338113,3991,'75629','watch-mobile','text','Account',3,''),(338114,3996,'75635','watch-mobile','text','Shop',3,''),(338115,3998,'75637','watch-mobile','text','Products',3,''),(338116,4002,'75642','watch-mobile','text','Contact Us',3,''),(338117,4014,'75655','watch-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338118,4017,'75658','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338119,4018,'75659','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338120,4019,'75660','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(338121,4020,'75661','watch-mobile','text','<p>GIFT CARD</p>',3,''),(338122,4022,'75663','watch-mobile','text','<p>Your code is:</p>',3,''),(338123,4026,'75667','watch-mobile','text','<p>HOLBI</p>',3,''),(338124,4028,'75669','watch-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(338125,4031,'114448','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338126,4032,'114449','watch-mobile','text','<p>GIFT CARD</p>',3,''),(338127,4033,'114450','watch-mobile','logo','themes/watch-mobile/img/logo-1.png',3,''),(338128,4034,'114451','watch-mobile','logo','themes/watch-mobile/img/bestseller-1.png',3,''),(338129,4035,'114452','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338130,4039,'114456','watch-mobile','text','<p>Your code is:</p>',3,''),(338131,4041,'114458','watch-mobile','text','<p>HOLBI</p>',3,''),(338132,4042,'114459','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338133,4045,'114462','watch-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338134,4048,'114465','watch-mobile','text','<p>HOLBI</p>',3,''),(338135,4049,'114466','watch-mobile','text','<p>GIFT CARD</p>',3,''),(338136,4050,'114467','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338137,4052,'114469','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338138,4053,'114470','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338139,4056,'114473','watch-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338140,4059,'114476','watch-mobile','text','<p>Your code is:</p>',3,''),(338141,4071,'114488','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338142,4088,'114505','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338143,4100,'114517','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338144,4101,'114518','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338145,4103,'114520','watch-mobile','text','<p>GIFT CARD</p>',3,''),(338146,4105,'114522','watch-mobile','text','<p>HOLBI</p>',3,''),(338147,4109,'114526','watch-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338148,4110,'114527','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338149,4112,'114529','watch-mobile','text','<p>Your code is:</p>',3,''),(338150,4123,'114540','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338151,4130,'75671','watch-mobile','logo','themes/watch-mobile/img/oscommerce_logo.png',3,''),(338152,4144,'75693','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338153,4149,'75698','watch-mobile','logo','themes/watch-mobile/img/watchlogo-2-1.png',3,''),(338154,4151,'75700','watch-mobile','text','<p>Phone:</p>',3,''),(338155,4156,'75705','watch-mobile','text','<p>Web:</p>',3,''),(338156,4159,'75708','watch-mobile','text','<p>Email:</p>',3,''),(338157,4162,'75711','watch-mobile','text','<p>If undelivered please return to:</p>',3,''),(338158,4164,'75713','watch-mobile','text','<p>Thank you for your order</p>',3,''),(338160,4167,'75716','watch-mobile','text','<p>Email:</p>',3,''),(338161,4170,'75719','watch-mobile','text','<p>Phone:</p>',3,''),(338162,4172,'75721','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338163,4176,'75725','watch-mobile','text','<p>Shipping via</p>',3,''),(338164,4180,'75729','watch-mobile','text','<p>Shipping service</p>',3,''),(338165,4183,'75732','watch-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338166,4187,'75736','watch-mobile','text','<p>CUSTOMER:</p>',3,''),(338167,4189,'75738','watch-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338168,4190,'75739','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338169,4196,'75745','watch-mobile','text','<p>Payment date:</p>',3,''),(338170,4197,'75746','watch-mobile','text','<p>Payment Method:</p>',3,''),(338171,4199,'94803','watch-mobile','tab_1','RETURNING CUSTOMER',3,''),(338172,4199,'94803','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338173,4221,'114562','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338174,4221,'114562','watch-mobile','tab_2','RETURNING CUSTOMER',3,''),(338175,4221,'114562','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338176,4237,'114578','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338177,4237,'114578','watch-mobile','tab_2','RETURNING CUSTOMER',3,''),(338178,4237,'114578','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338179,4250,'114591','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338180,4250,'114591','watch-mobile','tab_2','RETURNING CUSTOMER',3,''),(338181,4250,'114591','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338182,4291,'75750','watch-mobile','tab_1','New products',3,''),(338183,4291,'75750','watch-mobile','tab_2','Specials products',3,''),(338184,4291,'75750','watch-mobile','tab_3','Featured',3,''),(338185,4324,'114653','watch-mobile','tab_1','RETURNING CUSTOMER',3,''),(338186,4324,'114653','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338187,4446,'75764','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338188,4452,'75770','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338189,4453,'75771','watch-mobile','text','<p>CUSTOMER:</p>',3,''),(338190,4454,'75772','watch-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338191,4458,'75776','watch-mobile','text','<p>Shipping via</p>',3,''),(338192,4460,'75778','watch-mobile','text','<p>Shipping service</p>',3,''),(338193,4464,'75782','watch-mobile','text','<p>If undelivered please return to:</p>',3,''),(338194,4467,'75785','watch-mobile','logo','themes/watch-mobile/img/watchlogo-3.png',3,''),(338195,4471,'75789','watch-mobile','text','<p>Phone:</p>',3,''),(338196,4474,'75792','watch-mobile','text','<p>Web:</p>',3,''),(338197,4477,'75795','watch-mobile','text','<p>Email:</p>',3,''),(338199,4504,'75817','watch-mobile','text','osCommerce 4',3,''),(338200,4539,'75840','watch-mobile','tab_1','Description',3,''),(338201,4539,'75840','watch-mobile','tab_2','Reviews',3,''),(338202,4584,'114794','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338203,4589,'114799','watch-mobile','text','<p>ADDRESS:</p>\n',3,''),(338204,4592,'114802','watch-mobile','text','<p>CUSTOMER:</p>',3,''),(338205,4593,'114803','watch-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338206,4594,'114804','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338207,4598,'114808','watch-mobile','text','<p>Order date:</p>\n',3,''),(338209,4606,'114816','watch-mobile','text','<p>Email:</p>',3,''),(338210,4609,'114819','watch-mobile','text','<p>Web:</p>',3,''),(338211,4612,'114822','watch-mobile','text','<p>Phone:</p>',3,''),(338212,4616,'114826','watch-mobile','text','<p>If undelivered please return to:</p>',3,''),(338213,4617,'114827','watch-mobile','text','<p>Thank you for your order</p>',3,''),(338215,4620,'114830','watch-mobile','text','<p>Phone:</p>',3,''),(338216,4622,'114832','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338217,4624,'114834','watch-mobile','text','<p>Email:</p>',3,''),(338218,4664,'75868','watch-mobile','text','<h1>Quotations</h1>',3,''),(338219,4781,'114988','watch-mobile','logo','themes/watch-mobile/img/Furntech-1.jpg',3,''),(338220,4805,'75872','watch-mobile','text','<h1>Samples</h1>',3,''),(338221,4891,'75875','watch-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',3,''),(338222,4910,'115079','watch-mobile','text','<p>Phone:</p>',3,''),(338223,4913,'115082','watch-mobile','text','<p>Web:</p>',3,''),(338224,4916,'115085','watch-mobile','text','<p>Email:</p>',3,''),(338225,4921,'115090','watch-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338226,4924,'115093','watch-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338227,4925,'115094','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338228,4926,'115095','watch-mobile','text','<p>CUSTOMER:</p>',3,''),(338229,4932,'115101','watch-mobile','text','<p>Shipping via</p>',3,''),(338230,4936,'115105','watch-mobile','text','<p>Shipping service</p>',3,''),(338231,4937,'115106','watch-mobile','text','<p>Payment date:</p>',3,''),(338232,4939,'115108','watch-mobile','text','<p>Payment Method:</p>',3,''),(338233,4944,'115113','watch-mobile','text','<p>If undelivered please return to:</p>',3,''),(338235,4947,'115116','watch-mobile','text','<p>Thank you for your order</p>',3,''),(338236,4949,'115118','watch-mobile','text','<p>Phone:</p>',3,''),(338237,4951,'115120','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338238,4953,'115122','watch-mobile','text','<p>Email:</p>',3,''),(338239,4959,'115128','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338368,13141,'118691','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',3,''),(338369,13172,'118722','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',3,''),(338370,13877,'119427','printshop-mobile','text','<p>Shipping via</p>',3,''),(338371,13881,'119431','printshop-mobile','text','<p>Shipping service</p>',3,''),(338372,13885,'119435','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338373,13887,'119437','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338374,13890,'119440','printshop-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338375,13891,'119441','printshop-mobile','text','<p>CUSTOMER:</p>',3,''),(338376,13894,'119444','printshop-mobile','text','<p>Payment date:</p>',3,''),(338377,13898,'119448','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338379,13906,'119456','printshop-mobile','text','<p>Email:</p>',3,''),(338380,13909,'119459','printshop-mobile','text','<p>Phone:</p>',3,''),(338381,13912,'119462','printshop-mobile','text','<p>Web:</p>',3,''),(338382,13917,'119467','printshop-mobile','text','<p>If undelivered please return to:</p>',3,''),(338383,13918,'119468','printshop-mobile','text','<p>Thank you for your order</p>',3,''),(338385,13921,'119471','printshop-mobile','text','<p>Phone:</p>',3,''),(338386,13924,'119474','printshop-mobile','text','<p>Email:</p>',3,''),(338387,13926,'119476','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338388,13948,'119498','printshop-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',3,''),(338389,13959,'119509','printshop-mobile','logo','themes/printshop-mobile/img/logo-white-1.png',3,''),(338390,13980,'119530','printshop-mobile','text','Account',3,''),(338391,13985,'119535','printshop-mobile','text','Account',3,''),(338392,13987,'119537','printshop-mobile','text','Account',3,''),(338393,13991,'119541','printshop-mobile','text','Account',3,''),(338394,14003,'119553','printshop-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338395,14006,'119556','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338396,14007,'119557','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338397,14008,'119558','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(338398,14009,'119559','printshop-mobile','text','<p>GIFT CARD</p>',3,''),(338399,14011,'119561','printshop-mobile','text','<p>Your code is:</p>',3,''),(338400,14015,'119565','printshop-mobile','text','<p>HOLBI</p>',3,''),(338401,14017,'119567','printshop-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(338402,14020,'119570','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338403,14021,'119571','printshop-mobile','text','<p>GIFT CARD</p>',3,''),(338404,14022,'119572','printshop-mobile','logo','themes/printshop-mobile/img/logo-1.png',3,''),(338405,14023,'119573','printshop-mobile','logo','themes/printshop-mobile/img/bestseller-1.png',3,''),(338406,14024,'119574','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338407,14028,'119578','printshop-mobile','text','<p>Your code is:</p>',3,''),(338408,14030,'119580','printshop-mobile','text','<p>HOLBI</p>',3,''),(338409,14031,'119581','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338410,14034,'119584','printshop-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338411,14037,'119587','printshop-mobile','text','<p>HOLBI</p>',3,''),(338412,14038,'119588','printshop-mobile','text','<p>GIFT CARD</p>',3,''),(338413,14039,'119589','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338414,14041,'119591','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338415,14042,'119592','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338416,14045,'119595','printshop-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338417,14048,'119598','printshop-mobile','text','<p>Your code is:</p>',3,''),(338418,14060,'119610','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338419,14077,'119627','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338420,14089,'119639','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338421,14090,'119640','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338422,14092,'119642','printshop-mobile','text','<p>GIFT CARD</p>',3,''),(338423,14094,'119644','printshop-mobile','text','<p>HOLBI</p>',3,''),(338424,14098,'119648','printshop-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338425,14099,'119649','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338426,14101,'119651','printshop-mobile','text','<p>Your code is:</p>',3,''),(338427,14112,'119662','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338428,14119,'119669','printshop-mobile','logo','themes/printshop-mobile/img/oscommerce_logo.png',3,''),(338429,14122,'119672','printshop-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',3,''),(338430,14124,'119674','printshop-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',3,''),(338431,14125,'119675','printshop-mobile','logo','themes/printshop-mobile/img/check-2.png',3,''),(338432,14141,'119691','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338434,14148,'119698','printshop-mobile','text','<p>Phone:</p>',3,''),(338435,14153,'119703','printshop-mobile','text','<p>Web:</p>',3,''),(338436,14156,'119706','printshop-mobile','text','<p>Email:</p>',3,''),(338437,14159,'119709','printshop-mobile','text','<p>If undelivered please return to:</p>',3,''),(338438,14161,'119711','printshop-mobile','text','<p>Thank you for your order</p>',3,''),(338440,14164,'119714','printshop-mobile','text','<p>Email:</p>',3,''),(338441,14167,'119717','printshop-mobile','text','<p>Phone:</p>',3,''),(338442,14169,'119719','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338443,14173,'119723','printshop-mobile','text','<p>Shipping via</p>',3,''),(338444,14177,'119727','printshop-mobile','text','<p>Shipping service</p>',3,''),(338445,14180,'119730','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338446,14184,'119734','printshop-mobile','text','<p>CUSTOMER:</p>',3,''),(338447,14186,'119736','printshop-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338448,14187,'119737','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338449,14193,'119743','printshop-mobile','text','<p>Payment date:</p>',3,''),(338450,14194,'119744','printshop-mobile','text','<p>Payment Method:</p>',3,''),(338451,14196,'119746','printshop-mobile','tab_1','RETURNING CUSTOMER',3,''),(338452,14196,'119746','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338453,14218,'119768','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338454,14218,'119768','printshop-mobile','tab_2','RETURNING CUSTOMER',3,''),(338455,14218,'119768','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338456,14234,'119784','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338457,14234,'119784','printshop-mobile','tab_2','RETURNING CUSTOMER',3,''),(338458,14234,'119784','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338459,14247,'119797','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338460,14247,'119797','printshop-mobile','tab_2','RETURNING CUSTOMER',3,''),(338461,14247,'119797','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338462,14288,'119838','printshop-mobile','tab_1','New products',3,''),(338463,14288,'119838','printshop-mobile','tab_2','Specials products',3,''),(338464,14288,'119838','printshop-mobile','tab_3','Featured',3,''),(338465,14321,'119871','printshop-mobile','tab_1','RETURNING CUSTOMER',3,''),(338466,14321,'119871','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338467,14443,'119993','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338468,14449,'119999','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338469,14450,'120000','printshop-mobile','text','<p>CUSTOMER:</p>',3,''),(338470,14451,'120001','printshop-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338471,14455,'120005','printshop-mobile','text','<p>Shipping via</p>',3,''),(338472,14457,'120007','printshop-mobile','text','<p>Shipping service</p>',3,''),(338473,14461,'120011','printshop-mobile','text','<p>If undelivered please return to:</p>',3,''),(338475,14468,'120018','printshop-mobile','text','<p>Phone:</p>',3,''),(338476,14471,'120021','printshop-mobile','text','<p>Web:</p>',3,''),(338477,14474,'120024','printshop-mobile','text','<p>Email:</p>',3,''),(338479,14501,'120051','printshop-mobile','text','osCommerce 4',3,''),(338480,14536,'120086','printshop-mobile','tab_1','Description',3,''),(338481,14536,'120086','printshop-mobile','tab_2','Reviews',3,''),(338482,14581,'120131','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338483,14586,'120136','printshop-mobile','text','<p>ADDRESS:</p>\n',3,''),(338484,14589,'120139','printshop-mobile','text','<p>CUSTOMER:</p>',3,''),(338485,14590,'120140','printshop-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338486,14591,'120141','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338487,14595,'120145','printshop-mobile','text','<p>Order date:</p>\n',3,''),(338489,14603,'120153','printshop-mobile','text','<p>Email:</p>',3,''),(338490,14606,'120156','printshop-mobile','text','<p>Web:</p>',3,''),(338491,14609,'120159','printshop-mobile','text','<p>Phone:</p>',3,''),(338492,14613,'120163','printshop-mobile','text','<p>If undelivered please return to:</p>',3,''),(338493,14614,'120164','printshop-mobile','text','<p>Thank you for your order</p>',3,''),(338495,14617,'120167','printshop-mobile','text','<p>Phone:</p>',3,''),(338496,14619,'120169','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338497,14621,'120171','printshop-mobile','text','<p>Email:</p>',3,''),(338498,14661,'120211','printshop-mobile','text','<h1>Quotations</h1>',3,''),(338499,14778,'120328','printshop-mobile','logo','themes/printshop-mobile/img/Furntech-1.jpg',3,''),(338500,14802,'120352','printshop-mobile','text','<h1>Samples</h1>',3,''),(338501,14888,'120438','printshop-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',3,''),(338502,14907,'120457','printshop-mobile','text','<p>Phone:</p>',3,''),(338503,14910,'120460','printshop-mobile','text','<p>Web:</p>',3,''),(338504,14913,'120463','printshop-mobile','text','<p>Email:</p>',3,''),(338505,14918,'120468','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338506,14921,'120471','printshop-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338507,14922,'120472','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338508,14923,'120473','printshop-mobile','text','<p>CUSTOMER:</p>',3,''),(338509,14929,'120479','printshop-mobile','text','<p>Shipping via</p>',3,''),(338510,14933,'120483','printshop-mobile','text','<p>Shipping service</p>',3,''),(338511,14934,'120484','printshop-mobile','text','<p>Payment date:</p>',3,''),(338512,14936,'120486','printshop-mobile','text','<p>Payment Method:</p>',3,''),(338513,14941,'120491','printshop-mobile','text','<p>If undelivered please return to:</p>',3,''),(338515,14944,'120494','printshop-mobile','text','<p>Thank you for your order</p>',3,''),(338516,14946,'120496','printshop-mobile','text','<p>Phone:</p>',3,''),(338517,14948,'120498','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338518,14950,'120500','printshop-mobile','text','<p>Email:</p>',3,''),(338519,14956,'120506','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338644,18022,'118691','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',3,''),(338645,18053,'118722','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',3,''),(338646,18758,'119427','deals-mobile','text','<p>Shipping via</p>',3,''),(338647,18762,'119431','deals-mobile','text','<p>Shipping service</p>',3,''),(338648,18766,'119435','deals-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338649,18768,'119437','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338650,18771,'119440','deals-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338651,18772,'119441','deals-mobile','text','<p>CUSTOMER:</p>',3,''),(338652,18775,'119444','deals-mobile','text','<p>Payment date:</p>',3,''),(338653,18779,'119448','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338655,18787,'119456','deals-mobile','text','<p>Email:</p>',3,''),(338656,18790,'119459','deals-mobile','text','<p>Phone:</p>',3,''),(338657,18793,'119462','deals-mobile','text','<p>Web:</p>',3,''),(338658,18798,'119467','deals-mobile','text','<p>If undelivered please return to:</p>',3,''),(338659,18799,'119468','deals-mobile','text','<p>Thank you for your order</p>',3,''),(338661,18802,'119471','deals-mobile','text','<p>Phone:</p>',3,''),(338662,18805,'119474','deals-mobile','text','<p>Email:</p>',3,''),(338663,18807,'119476','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338664,18829,'119498','deals-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',3,''),(338665,18840,'119509','deals-mobile','logo','themes/deals-mobile/img/logo-white-1.png',3,''),(338666,18861,'119530','deals-mobile','text','Account',3,''),(338667,18866,'119535','deals-mobile','text','Account',3,''),(338668,18868,'119537','deals-mobile','text','Account',3,''),(338669,18872,'119541','deals-mobile','text','Account',3,''),(338670,18884,'119553','deals-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338671,18887,'119556','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338672,18888,'119557','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338673,18889,'119558','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(338674,18890,'119559','deals-mobile','text','<p>GIFT CARD</p>',3,''),(338675,18892,'119561','deals-mobile','text','<p>Your code is:</p>',3,''),(338676,18896,'119565','deals-mobile','text','<p>HOLBI</p>',3,''),(338677,18898,'119567','deals-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(338678,18901,'119570','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338679,18902,'119571','deals-mobile','text','<p>GIFT CARD</p>',3,''),(338680,18903,'119572','deals-mobile','logo','themes/deals-mobile/img/logo-1.png',3,''),(338681,18904,'119573','deals-mobile','logo','themes/deals-mobile/img/bestseller-1.png',3,''),(338682,18905,'119574','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338683,18909,'119578','deals-mobile','text','<p>Your code is:</p>',3,''),(338684,18911,'119580','deals-mobile','text','<p>HOLBI</p>',3,''),(338685,18912,'119581','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338686,18915,'119584','deals-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338687,18918,'119587','deals-mobile','text','<p>HOLBI</p>',3,''),(338688,18919,'119588','deals-mobile','text','<p>GIFT CARD</p>',3,''),(338689,18920,'119589','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338690,18922,'119591','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338691,18923,'119592','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338692,18926,'119595','deals-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338693,18929,'119598','deals-mobile','text','<p>Your code is:</p>',3,''),(338694,18941,'119610','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338695,18958,'119627','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338696,18970,'119639','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338697,18971,'119640','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338698,18973,'119642','deals-mobile','text','<p>GIFT CARD</p>',3,''),(338699,18975,'119644','deals-mobile','text','<p>HOLBI</p>',3,''),(338700,18979,'119648','deals-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338701,18980,'119649','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338702,18982,'119651','deals-mobile','text','<p>Your code is:</p>',3,''),(338703,18993,'119662','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338704,19000,'119669','deals-mobile','logo','themes/deals-mobile/img/oscommerce_logo.png',3,''),(338705,19003,'119672','deals-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',3,''),(338706,19005,'119674','deals-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',3,''),(338707,19006,'119675','deals-mobile','logo','themes/deals-mobile/img/check-2.png',3,''),(338708,19022,'119691','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338710,19029,'119698','deals-mobile','text','<p>Phone:</p>',3,''),(338711,19034,'119703','deals-mobile','text','<p>Web:</p>',3,''),(338712,19037,'119706','deals-mobile','text','<p>Email:</p>',3,''),(338713,19040,'119709','deals-mobile','text','<p>If undelivered please return to:</p>',3,''),(338714,19042,'119711','deals-mobile','text','<p>Thank you for your order</p>',3,''),(338716,19045,'119714','deals-mobile','text','<p>Email:</p>',3,''),(338717,19048,'119717','deals-mobile','text','<p>Phone:</p>',3,''),(338718,19050,'119719','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338719,19054,'119723','deals-mobile','text','<p>Shipping via</p>',3,''),(338720,19058,'119727','deals-mobile','text','<p>Shipping service</p>',3,''),(338721,19061,'119730','deals-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338722,19065,'119734','deals-mobile','text','<p>CUSTOMER:</p>',3,''),(338723,19067,'119736','deals-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338724,19068,'119737','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338725,19074,'119743','deals-mobile','text','<p>Payment date:</p>',3,''),(338726,19075,'119744','deals-mobile','text','<p>Payment Method:</p>',3,''),(338727,19077,'119746','deals-mobile','tab_1','RETURNING CUSTOMER',3,''),(338728,19077,'119746','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338729,19099,'119768','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338730,19099,'119768','deals-mobile','tab_2','RETURNING CUSTOMER',3,''),(338731,19099,'119768','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338732,19115,'119784','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338733,19115,'119784','deals-mobile','tab_2','RETURNING CUSTOMER',3,''),(338734,19115,'119784','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338735,19128,'119797','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338736,19128,'119797','deals-mobile','tab_2','RETURNING CUSTOMER',3,''),(338737,19128,'119797','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338738,19169,'119838','deals-mobile','tab_1','New products',3,''),(338739,19169,'119838','deals-mobile','tab_2','Specials products',3,''),(338740,19169,'119838','deals-mobile','tab_3','Featured',3,''),(338741,19202,'119871','deals-mobile','tab_1','RETURNING CUSTOMER',3,''),(338742,19202,'119871','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338743,19324,'119993','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338744,19330,'119999','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338745,19331,'120000','deals-mobile','text','<p>CUSTOMER:</p>',3,''),(338746,19332,'120001','deals-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338747,19336,'120005','deals-mobile','text','<p>Shipping via</p>',3,''),(338748,19338,'120007','deals-mobile','text','<p>Shipping service</p>',3,''),(338749,19342,'120011','deals-mobile','text','<p>If undelivered please return to:</p>',3,''),(338751,19349,'120018','deals-mobile','text','<p>Phone:</p>',3,''),(338752,19352,'120021','deals-mobile','text','<p>Web:</p>',3,''),(338753,19355,'120024','deals-mobile','text','<p>Email:</p>',3,''),(338755,19382,'120051','deals-mobile','text','osCommerce 4',3,''),(338756,19417,'120086','deals-mobile','tab_1','Description',3,''),(338757,19417,'120086','deals-mobile','tab_2','Reviews',3,''),(338758,19462,'120131','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338759,19467,'120136','deals-mobile','text','<p>ADDRESS:</p>\n',3,''),(338760,19470,'120139','deals-mobile','text','<p>CUSTOMER:</p>',3,''),(338761,19471,'120140','deals-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338762,19472,'120141','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338763,19476,'120145','deals-mobile','text','<p>Order date:</p>\n',3,''),(338765,19484,'120153','deals-mobile','text','<p>Email:</p>',3,''),(338766,19487,'120156','deals-mobile','text','<p>Web:</p>',3,''),(338767,19490,'120159','deals-mobile','text','<p>Phone:</p>',3,''),(338768,19494,'120163','deals-mobile','text','<p>If undelivered please return to:</p>',3,''),(338769,19495,'120164','deals-mobile','text','<p>Thank you for your order</p>',3,''),(338771,19498,'120167','deals-mobile','text','<p>Phone:</p>',3,''),(338772,19500,'120169','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338773,19502,'120171','deals-mobile','text','<p>Email:</p>',3,''),(338774,19542,'120211','deals-mobile','text','<h1>Quotations</h1>',3,''),(338775,19659,'120328','deals-mobile','logo','themes/deals-mobile/img/Furntech-1.jpg',3,''),(338776,19683,'120352','deals-mobile','text','<h1>Samples</h1>',3,''),(338777,19769,'120438','deals-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',3,''),(338778,19788,'120457','deals-mobile','text','<p>Phone:</p>',3,''),(338779,19791,'120460','deals-mobile','text','<p>Web:</p>',3,''),(338780,19794,'120463','deals-mobile','text','<p>Email:</p>',3,''),(338781,19799,'120468','deals-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338782,19802,'120471','deals-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338783,19803,'120472','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338784,19804,'120473','deals-mobile','text','<p>CUSTOMER:</p>',3,''),(338785,19810,'120479','deals-mobile','text','<p>Shipping via</p>',3,''),(338786,19814,'120483','deals-mobile','text','<p>Shipping service</p>',3,''),(338787,19815,'120484','deals-mobile','text','<p>Payment date:</p>',3,''),(338788,19817,'120486','deals-mobile','text','<p>Payment Method:</p>',3,''),(338789,19822,'120491','deals-mobile','text','<p>If undelivered please return to:</p>',3,''),(338791,19825,'120494','deals-mobile','text','<p>Thank you for your order</p>',3,''),(338792,19827,'120496','deals-mobile','text','<p>Phone:</p>',3,''),(338793,19829,'120498','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338794,19831,'120500','deals-mobile','text','<p>Email:</p>',3,''),(338795,19837,'120506','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338928,54257,'116269','furniture-mobile','logo','themes/furniture-mobile/img/payicons-1.png',3,''),(338929,55017,'116977','furniture-mobile','text','<p>If undelivered please return to:</p>',3,''),(338930,55018,'116978','furniture-mobile','text','<p>Thank you for your order</p>',3,''),(338932,55020,'116980','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338933,55022,'116982','furniture-mobile','text','<p>Email:</p>',3,''),(338934,55025,'116985','furniture-mobile','text','<p>Phone:</p>',3,''),(338936,55031,'116991','furniture-mobile','text','<p>Web:</p>',3,''),(338937,55034,'116994','furniture-mobile','text','<p>Phone:</p>',3,''),(338938,55037,'116997','furniture-mobile','text','<p>Email:</p>',3,''),(338939,55044,'117004','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338940,55049,'117009','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338941,55053,'117013','furniture-mobile','text','<p>CUSTOMER:</p>',3,''),(338942,55054,'117014','furniture-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338943,55057,'117017','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338944,55061,'117021','furniture-mobile','text','<p>Shipping via</p>',3,''),(338945,55063,'117023','furniture-mobile','text','<p>Shipping service</p>',3,''),(338946,55066,'117026','furniture-mobile','text','<p>Payment date:</p>',3,''),(338947,55101,'117055','furniture-mobile','logo','themes/furniture-mobile/img/logo-white-1.png',3,''),(338948,55150,'117107','furniture-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(338949,55155,'117112','furniture-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338950,55157,'117114','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338951,55158,'117115','furniture-mobile','text','<p>osCommerce</p>\n',3,''),(338952,55160,'117117','furniture-mobile','text','<p>Your code is:</p>',3,''),(338953,55164,'117121','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338954,55165,'117123','furniture-mobile','logo','themes/furniture-mobile/img/Logo-1.jpg',3,''),(338955,55166,'117124','furniture-mobile','text','<p>GIFT CARD</p>',3,''),(338956,55167,'117125','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(338957,55171,'117129','furniture-mobile','text','<p>Your code is:</p>',3,''),(338958,55175,'117133','furniture-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338959,55178,'117136','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338960,55179,'117137','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(338961,55180,'117138','furniture-mobile','text','<p>GIFT CARD</p>',3,''),(338962,55181,'117139','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338963,55192,'117150','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338964,55209,'117167','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338965,55221,'117180','furniture-mobile','text','<p>Your code is:</p>',3,''),(338966,55223,'117182','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338967,55225,'117185','furniture-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338968,55229,'117189','furniture-mobile','text','<p>GIFT CARD</p>',3,''),(338969,55230,'117190','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338970,55232,'117192','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(338971,55243,'117202','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338973,55258,'117218','furniture-mobile','logo','themes/furniture-mobile/img/header-img-1.png',3,''),(338974,55279,'117234','furniture-mobile','text','<p>Shipping via</p>',3,''),(338975,55281,'117236','furniture-mobile','text','<p>Shipping service</p>',3,''),(338976,55285,'117240','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338977,55289,'117243','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338978,55292,'117246','furniture-mobile','text','<p>CUSTOMER:</p>',3,''),(338979,55293,'117247','furniture-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338980,55296,'117250','furniture-mobile','text','<p>Payment Method:</p>',3,''),(338981,55297,'117251','furniture-mobile','text','<p>Payment date:</p>',3,''),(338982,55303,'117257','furniture-mobile','text','<p>If undelivered please return to:</p>',3,''),(338983,55304,'117258','furniture-mobile','text','<p>Thank you for your order</p>',3,''),(338984,55306,'117261','furniture-mobile','text','<p>Email:</p>',3,''),(338985,55309,'117264','furniture-mobile','text','<p>Phone:</p>',3,''),(338986,55311,'117266','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338987,55316,'117271','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338988,55320,'117275','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',3,''),(338989,55322,'117277','furniture-mobile','text','<p>Web:</p>',3,''),(338990,55325,'117280','furniture-mobile','text','<p>Email:</p>',3,''),(338991,55330,'117285','furniture-mobile','text','<p>Phone:</p>',3,''),(338992,55337,'117288','furniture-mobile','tab_1','RETURNING CUSTOMER',3,''),(338993,55337,'117288','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338994,55360,'117311','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338995,55360,'117311','furniture-mobile','tab_2','RETURNING CUSTOMER',3,''),(338996,55360,'117311','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338997,55376,'117327','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338998,55376,'117327','furniture-mobile','tab_2','RETURNING CUSTOMER',3,''),(338999,55376,'117327','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(339000,55393,'117344','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(339001,55393,'117344','furniture-mobile','tab_2','RETURNING CUSTOMER',3,''),(339002,55393,'117344','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(339003,55486,'117416','furniture-mobile','tab_1','RETURNING CUSTOMER',3,''),(339004,55486,'117416','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(339005,55663,'117536','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',3,''),(339006,55665,'117538','furniture-mobile','text','<p>Email:</p>',3,''),(339007,55668,'117541','furniture-mobile','text','<p>Phone:</p>',3,''),(339008,55673,'117546','furniture-mobile','text','<p>Web:</p>',3,''),(339009,55678,'117551','furniture-mobile','text','<p>If undelivered please return to:</p>',3,''),(339010,55683,'117556','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(339011,55685,'117558','furniture-mobile','text','<p>CUSTOMER:</p>',3,''),(339012,55688,'117561','furniture-mobile','text','<p>PHONE NUMBER:</p>',3,''),(339013,55690,'117563','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(339014,55694,'117567','furniture-mobile','text','<p>Shipping via</p>',3,''),(339015,55697,'117570','furniture-mobile','text','<p>Shipping service</p>',3,''),(339016,55726,'117596','furniture-mobile','logo','themes/furniture-mobile/img/oscommerce_logo-1.jpg',3,''),(339017,55727,'117597','furniture-mobile','text','osCommerce 4',3,''),(339018,55764,'117646','furniture-mobile','tab_1','Product Overview',3,''),(339019,55764,'117646','furniture-mobile','tab_2','Delivery and returns',3,''),(339020,55764,'117646','furniture-mobile','tab_3','Assembly',3,''),(339021,55882,'117702','furniture-mobile','text','<p>If undelivered please return to:</p>',3,''),(339022,55884,'117704','furniture-mobile','text','<p>Thank you for your order</p>',3,''),(339024,55887,'117707','furniture-mobile','text','<p>Email:</p>',3,''),(339025,55889,'117709','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(339026,55891,'117711','furniture-mobile','text','<p>Phone:</p>',3,''),(339028,55896,'117716','furniture-mobile','text','<p>Phone:</p>',3,''),(339029,55899,'117719','furniture-mobile','text','<p>Web:</p>',3,''),(339030,55904,'117724','furniture-mobile','text','<p>Email:</p>',3,''),(339031,55910,'117730','furniture-mobile','text','<p>ADDRESS:</p>\n',3,''),(339032,55913,'117733','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(339033,55916,'117736','furniture-mobile','text','<p>PHONE NUMBER:</p>',3,''),(339034,55917,'117737','furniture-mobile','text','<p>CUSTOMER:</p>',3,''),(339035,55919,'117739','furniture-mobile','text','<p>Order date:</p>\n',3,''),(339036,55924,'117744','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(339037,56056,'117816','furniture-mobile','logo','themes/furniture-mobile/img/Furntech-1.jpg',3,''),(339038,56314,'118011','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(339039,56318,'118015','furniture-mobile','text','<p>If undelivered please return to:</p>',3,''),(339040,56320,'118018','furniture-mobile','text','<p>Thank you for your order</p>',3,''),(339041,56321,'118019','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(339042,56323,'118021','furniture-mobile','text','<p>Email:</p>',3,''),(339043,56326,'118024','furniture-mobile','text','<p>Phone:</p>',3,''),(339044,56331,'118029','furniture-mobile','text','<p>Email:</p>',3,''),(339045,56334,'118032','furniture-mobile','text','<p>Web:</p>',3,''),(339046,56339,'118037','furniture-mobile','text','<p>Phone:</p>',3,''),(339047,56344,'118042','furniture-mobile','text','<p>Shipping via</p>',3,''),(339048,56347,'118045','furniture-mobile','text','<p>Shipping service</p>',3,''),(339049,56352,'118050','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(339050,56355,'118053','furniture-mobile','text','<p>PHONE NUMBER:</p>',3,''),(339051,56358,'118056','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(339052,56359,'118057','furniture-mobile','text','<p>CUSTOMER:</p>',3,''),(339053,56361,'118059','furniture-mobile','text','<p>Payment date:</p>',3,''),(339054,56362,'118060','furniture-mobile','text','<p>Payment Method:</p>',3,''),(339319,108868,'117051','splash','logo','themes/splash/img/oscommerce_logo_(2)-1.png',3,''),(339320,108918,'1661353032.672459','splash','logo','themes/splash/img/oscommerce_logo.jpg',3,''),(339321,108933,'1640168618.7708','splash','logo','themes/splash/img/oscommerce_logo (2).png',3,''),(339322,108936,'1640169872.1589','splash','img_link','furniture/',3,''),(339323,108936,'1640169872.1589','splash','logo','themes/splash/img/Splash_furniture_BGlogo.png',3,''),(339324,108936,'1640169872.1589','splash','target_blank','1',3,''),(339325,108937,'1640276640.1123','splash','text','<h1>osCommerce v4 Splash page</h1>\r\n\r\n<p>osCommerce supports multiple sales CHANNELS.</p>\r\n\r\n<p>Your installation of osCommerce comes with &nbsp;&quot;Furniture&quot;, &quot;Watch&quot;, &quot;B2B Supermarket&quot;, and &quot;Print shop&quot; Ecommerce sales channels and &quot;cms&quot; brochure website example.</p>\r\n\r\n<p>Each sales channel has its own URLs, design, and demo product sets.</p>\r\n\r\n<p>&quot;Admin&quot; is the back end of your osCommerce.</p>\r\n\r\n<p>Use osCommerce Wiki to learn how to manage sales channels, &nbsp;assign design themes, and content to the sales channels.<br />\r\nThank you for choosing &nbsp;osCommerce - the most powerful on-premise open source Ecommerce platform!</p>\r\n',3,''),(339326,108938,'1640170154.7803','splash','img_link','watch/',3,''),(339327,108938,'1640170154.7803','splash','logo','themes/splash/img/Splash_watch_BGlogo.png',3,''),(339328,108938,'1640170154.7803','splash','target_blank','1',3,''),(339329,108940,'1640170023.0001','splash','img_link','printshop/',3,''),(339330,108940,'1640170023.0001','splash','logo','themes/splash/img/print shop.jpg',3,''),(339331,108940,'1640170023.0001','splash','target_blank','1',3,''),(339332,108941,'1640170023.1491','splash','img_link','admin/',3,''),(339333,108941,'1640170023.1491','splash','logo','themes/splash/img/Splash_admin_BGlogo.png',3,''),(339334,108941,'1640170023.1491','splash','target_blank','1',3,''),(339335,108942,'1640170023','splash','img_link','b2b-supermarket/',3,''),(339336,108942,'1640170023','splash','logo','themes/splash/img/b2b supermarket.jpg',3,''),(339337,108942,'1640170023','splash','target_blank','1',3,''),(339338,108945,'1661353032.975845','splash','logo','themes/splash/img/oscommerce_logo-1.jpg',3,''),(339339,109001,'74702','splash','logo','themes/splash/img/oscommerce_logo.jpg',3,''),(339340,109002,'74703','splash','text','osCommerce 4',3,''),(339472,3158,'115992','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',4,''),(339473,3189,'113675','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',4,''),(339474,3888,'114358','watch-mobile','text','<p>Shipping via</p>',4,''),(339475,3892,'114362','watch-mobile','text','<p>Shipping service</p>',4,''),(339476,3896,'114366','watch-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(339477,3898,'114368','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339478,3901,'114371','watch-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339479,3902,'114372','watch-mobile','text','<p>CUSTOMER:</p>',4,''),(339480,3905,'114375','watch-mobile','text','<p>Payment date:</p>',4,''),(339481,3909,'114379','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339483,3917,'114387','watch-mobile','text','<p>Email:</p>',4,''),(339484,3920,'114390','watch-mobile','text','<p>Phone:</p>',4,''),(339485,3923,'114393','watch-mobile','text','<p>Web:</p>',4,''),(339486,3928,'114398','watch-mobile','text','<p>If undelivered please return to:</p>',4,''),(339487,3929,'114399','watch-mobile','text','<p>Thank you for your order</p>',4,''),(339489,3932,'114402','watch-mobile','text','<p>Phone:</p>',4,''),(339490,3935,'114405','watch-mobile','text','<p>Email:</p>',4,''),(339491,3937,'114407','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339492,3956,'75618','watch-mobile','logo','themes/watch-mobile/img/watchlogo-1-1.png',4,''),(339493,3959,'75621','watch-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',4,''),(339494,3970,'114422','watch-mobile','logo','themes/watch-mobile/img/logo-white-1.png',4,''),(339495,3991,'75629','watch-mobile','text','Account',4,''),(339496,3996,'75635','watch-mobile','text','Shop',4,''),(339497,3998,'75637','watch-mobile','text','Products',4,''),(339498,4002,'75642','watch-mobile','text','Contact Us',4,''),(339499,4014,'75655','watch-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339500,4017,'75658','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339501,4018,'75659','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339502,4019,'75660','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(339503,4020,'75661','watch-mobile','text','<p>GIFT CARD</p>',4,''),(339504,4022,'75663','watch-mobile','text','<p>Your code is:</p>',4,''),(339505,4026,'75667','watch-mobile','text','<p>HOLBI</p>',4,''),(339506,4028,'75669','watch-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(339507,4031,'114448','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(339508,4032,'114449','watch-mobile','text','<p>GIFT CARD</p>',4,''),(339509,4033,'114450','watch-mobile','logo','themes/watch-mobile/img/logo-1.png',4,''),(339510,4034,'114451','watch-mobile','logo','themes/watch-mobile/img/bestseller-1.png',4,''),(339511,4035,'114452','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339512,4039,'114456','watch-mobile','text','<p>Your code is:</p>',4,''),(339513,4041,'114458','watch-mobile','text','<p>HOLBI</p>',4,''),(339514,4042,'114459','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339515,4045,'114462','watch-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339516,4048,'114465','watch-mobile','text','<p>HOLBI</p>',4,''),(339517,4049,'114466','watch-mobile','text','<p>GIFT CARD</p>',4,''),(339518,4050,'114467','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339519,4052,'114469','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(339520,4053,'114470','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339521,4056,'114473','watch-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339522,4059,'114476','watch-mobile','text','<p>Your code is:</p>',4,''),(339523,4071,'114488','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339524,4088,'114505','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339525,4100,'114517','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(339526,4101,'114518','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339527,4103,'114520','watch-mobile','text','<p>GIFT CARD</p>',4,''),(339528,4105,'114522','watch-mobile','text','<p>HOLBI</p>',4,''),(339529,4109,'114526','watch-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339530,4110,'114527','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339531,4112,'114529','watch-mobile','text','<p>Your code is:</p>',4,''),(339532,4123,'114540','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339533,4130,'75671','watch-mobile','logo','themes/watch-mobile/img/oscommerce_logo.png',4,''),(339534,4144,'75693','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339535,4149,'75698','watch-mobile','logo','themes/watch-mobile/img/watchlogo-2-1.png',4,''),(339536,4151,'75700','watch-mobile','text','<p>Phone:</p>',4,''),(339537,4156,'75705','watch-mobile','text','<p>Web:</p>',4,''),(339538,4159,'75708','watch-mobile','text','<p>Email:</p>',4,''),(339539,4162,'75711','watch-mobile','text','<p>If undelivered please return to:</p>',4,''),(339540,4164,'75713','watch-mobile','text','<p>Thank you for your order</p>',4,''),(339542,4167,'75716','watch-mobile','text','<p>Email:</p>',4,''),(339543,4170,'75719','watch-mobile','text','<p>Phone:</p>',4,''),(339544,4172,'75721','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339545,4176,'75725','watch-mobile','text','<p>Shipping via</p>',4,''),(339546,4180,'75729','watch-mobile','text','<p>Shipping service</p>',4,''),(339547,4183,'75732','watch-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(339548,4187,'75736','watch-mobile','text','<p>CUSTOMER:</p>',4,''),(339549,4189,'75738','watch-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339550,4190,'75739','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339551,4196,'75745','watch-mobile','text','<p>Payment date:</p>',4,''),(339552,4197,'75746','watch-mobile','text','<p>Payment Method:</p>',4,''),(339553,4199,'94803','watch-mobile','tab_1','RETURNING CUSTOMER',4,''),(339554,4199,'94803','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(339555,4221,'114562','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(339556,4221,'114562','watch-mobile','tab_2','RETURNING CUSTOMER',4,''),(339557,4221,'114562','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(339558,4237,'114578','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(339559,4237,'114578','watch-mobile','tab_2','RETURNING CUSTOMER',4,''),(339560,4237,'114578','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(339561,4250,'114591','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(339562,4250,'114591','watch-mobile','tab_2','RETURNING CUSTOMER',4,''),(339563,4250,'114591','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(339564,4291,'75750','watch-mobile','tab_1','New products',4,''),(339565,4291,'75750','watch-mobile','tab_2','Specials products',4,''),(339566,4291,'75750','watch-mobile','tab_3','Featured',4,''),(339567,4324,'114653','watch-mobile','tab_1','RETURNING CUSTOMER',4,''),(339568,4324,'114653','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(339569,4446,'75764','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339570,4452,'75770','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339571,4453,'75771','watch-mobile','text','<p>CUSTOMER:</p>',4,''),(339572,4454,'75772','watch-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339573,4458,'75776','watch-mobile','text','<p>Shipping via</p>',4,''),(339574,4460,'75778','watch-mobile','text','<p>Shipping service</p>',4,''),(339575,4464,'75782','watch-mobile','text','<p>If undelivered please return to:</p>',4,''),(339576,4467,'75785','watch-mobile','logo','themes/watch-mobile/img/watchlogo-3.png',4,''),(339577,4471,'75789','watch-mobile','text','<p>Phone:</p>',4,''),(339578,4474,'75792','watch-mobile','text','<p>Web:</p>',4,''),(339579,4477,'75795','watch-mobile','text','<p>Email:</p>',4,''),(339581,4504,'75817','watch-mobile','text','osCommerce 4',4,''),(339582,4539,'75840','watch-mobile','tab_1','Description',4,''),(339583,4539,'75840','watch-mobile','tab_2','Reviews',4,''),(339584,4584,'114794','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339585,4589,'114799','watch-mobile','text','<p>ADDRESS:</p>\n',4,''),(339586,4592,'114802','watch-mobile','text','<p>CUSTOMER:</p>',4,''),(339587,4593,'114803','watch-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339588,4594,'114804','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339589,4598,'114808','watch-mobile','text','<p>Order date:</p>\n',4,''),(339591,4606,'114816','watch-mobile','text','<p>Email:</p>',4,''),(339592,4609,'114819','watch-mobile','text','<p>Web:</p>',4,''),(339593,4612,'114822','watch-mobile','text','<p>Phone:</p>',4,''),(339594,4616,'114826','watch-mobile','text','<p>If undelivered please return to:</p>',4,''),(339595,4617,'114827','watch-mobile','text','<p>Thank you for your order</p>',4,''),(339597,4620,'114830','watch-mobile','text','<p>Phone:</p>',4,''),(339598,4622,'114832','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339599,4624,'114834','watch-mobile','text','<p>Email:</p>',4,''),(339600,4664,'75868','watch-mobile','text','<h1>Quotations</h1>',4,''),(339601,4781,'114988','watch-mobile','logo','themes/watch-mobile/img/Furntech-1.jpg',4,''),(339602,4805,'75872','watch-mobile','text','<h1>Samples</h1>',4,''),(339603,4891,'75875','watch-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',4,''),(339604,4910,'115079','watch-mobile','text','<p>Phone:</p>',4,''),(339605,4913,'115082','watch-mobile','text','<p>Web:</p>',4,''),(339606,4916,'115085','watch-mobile','text','<p>Email:</p>',4,''),(339607,4921,'115090','watch-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(339608,4924,'115093','watch-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339609,4925,'115094','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339610,4926,'115095','watch-mobile','text','<p>CUSTOMER:</p>',4,''),(339611,4932,'115101','watch-mobile','text','<p>Shipping via</p>',4,''),(339612,4936,'115105','watch-mobile','text','<p>Shipping service</p>',4,''),(339613,4937,'115106','watch-mobile','text','<p>Payment date:</p>',4,''),(339614,4939,'115108','watch-mobile','text','<p>Payment Method:</p>',4,''),(339615,4944,'115113','watch-mobile','text','<p>If undelivered please return to:</p>',4,''),(339617,4947,'115116','watch-mobile','text','<p>Thank you for your order</p>',4,''),(339618,4949,'115118','watch-mobile','text','<p>Phone:</p>',4,''),(339619,4951,'115120','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339620,4953,'115122','watch-mobile','text','<p>Email:</p>',4,''),(339621,4959,'115128','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339750,13141,'118691','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',4,''),(339751,13172,'118722','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',4,''),(339752,13877,'119427','printshop-mobile','text','<p>Shipping via</p>',4,''),(339753,13881,'119431','printshop-mobile','text','<p>Shipping service</p>',4,''),(339754,13885,'119435','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(339755,13887,'119437','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339756,13890,'119440','printshop-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339757,13891,'119441','printshop-mobile','text','<p>CUSTOMER:</p>',4,''),(339758,13894,'119444','printshop-mobile','text','<p>Payment date:</p>',4,''),(339759,13898,'119448','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339761,13906,'119456','printshop-mobile','text','<p>Email:</p>',4,''),(339762,13909,'119459','printshop-mobile','text','<p>Phone:</p>',4,''),(339763,13912,'119462','printshop-mobile','text','<p>Web:</p>',4,''),(339764,13917,'119467','printshop-mobile','text','<p>If undelivered please return to:</p>',4,''),(339765,13918,'119468','printshop-mobile','text','<p>Thank you for your order</p>',4,''),(339767,13921,'119471','printshop-mobile','text','<p>Phone:</p>',4,''),(339768,13924,'119474','printshop-mobile','text','<p>Email:</p>',4,''),(339769,13926,'119476','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339770,13948,'119498','printshop-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',4,''),(339771,13959,'119509','printshop-mobile','logo','themes/printshop-mobile/img/logo-white-1.png',4,''),(339772,13980,'119530','printshop-mobile','text','Account',4,''),(339773,13985,'119535','printshop-mobile','text','Account',4,''),(339774,13987,'119537','printshop-mobile','text','Account',4,''),(339775,13991,'119541','printshop-mobile','text','Account',4,''),(339776,14003,'119553','printshop-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339777,14006,'119556','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339778,14007,'119557','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339779,14008,'119558','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(339780,14009,'119559','printshop-mobile','text','<p>GIFT CARD</p>',4,''),(339781,14011,'119561','printshop-mobile','text','<p>Your code is:</p>',4,''),(339782,14015,'119565','printshop-mobile','text','<p>HOLBI</p>',4,''),(339783,14017,'119567','printshop-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(339784,14020,'119570','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(339785,14021,'119571','printshop-mobile','text','<p>GIFT CARD</p>',4,''),(339786,14022,'119572','printshop-mobile','logo','themes/printshop-mobile/img/logo-1.png',4,''),(339787,14023,'119573','printshop-mobile','logo','themes/printshop-mobile/img/bestseller-1.png',4,''),(339788,14024,'119574','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339789,14028,'119578','printshop-mobile','text','<p>Your code is:</p>',4,''),(339790,14030,'119580','printshop-mobile','text','<p>HOLBI</p>',4,''),(339791,14031,'119581','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339792,14034,'119584','printshop-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339793,14037,'119587','printshop-mobile','text','<p>HOLBI</p>',4,''),(339794,14038,'119588','printshop-mobile','text','<p>GIFT CARD</p>',4,''),(339795,14039,'119589','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339796,14041,'119591','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(339797,14042,'119592','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339798,14045,'119595','printshop-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339799,14048,'119598','printshop-mobile','text','<p>Your code is:</p>',4,''),(339800,14060,'119610','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339801,14077,'119627','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339802,14089,'119639','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(339803,14090,'119640','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339804,14092,'119642','printshop-mobile','text','<p>GIFT CARD</p>',4,''),(339805,14094,'119644','printshop-mobile','text','<p>HOLBI</p>',4,''),(339806,14098,'119648','printshop-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339807,14099,'119649','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339808,14101,'119651','printshop-mobile','text','<p>Your code is:</p>',4,''),(339809,14112,'119662','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339810,14119,'119669','printshop-mobile','logo','themes/printshop-mobile/img/oscommerce_logo.png',4,''),(339811,14122,'119672','printshop-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',4,''),(339812,14124,'119674','printshop-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',4,''),(339813,14125,'119675','printshop-mobile','logo','themes/printshop-mobile/img/check-2.png',4,''),(339814,14141,'119691','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339816,14148,'119698','printshop-mobile','text','<p>Phone:</p>',4,''),(339817,14153,'119703','printshop-mobile','text','<p>Web:</p>',4,''),(339818,14156,'119706','printshop-mobile','text','<p>Email:</p>',4,''),(339819,14159,'119709','printshop-mobile','text','<p>If undelivered please return to:</p>',4,''),(339820,14161,'119711','printshop-mobile','text','<p>Thank you for your order</p>',4,''),(339822,14164,'119714','printshop-mobile','text','<p>Email:</p>',4,''),(339823,14167,'119717','printshop-mobile','text','<p>Phone:</p>',4,''),(339824,14169,'119719','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339825,14173,'119723','printshop-mobile','text','<p>Shipping via</p>',4,''),(339826,14177,'119727','printshop-mobile','text','<p>Shipping service</p>',4,''),(339827,14180,'119730','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(339828,14184,'119734','printshop-mobile','text','<p>CUSTOMER:</p>',4,''),(339829,14186,'119736','printshop-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339830,14187,'119737','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339831,14193,'119743','printshop-mobile','text','<p>Payment date:</p>',4,''),(339832,14194,'119744','printshop-mobile','text','<p>Payment Method:</p>',4,''),(339833,14196,'119746','printshop-mobile','tab_1','RETURNING CUSTOMER',4,''),(339834,14196,'119746','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(339835,14218,'119768','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(339836,14218,'119768','printshop-mobile','tab_2','RETURNING CUSTOMER',4,''),(339837,14218,'119768','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(339838,14234,'119784','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(339839,14234,'119784','printshop-mobile','tab_2','RETURNING CUSTOMER',4,''),(339840,14234,'119784','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(339841,14247,'119797','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(339842,14247,'119797','printshop-mobile','tab_2','RETURNING CUSTOMER',4,''),(339843,14247,'119797','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(339844,14288,'119838','printshop-mobile','tab_1','New products',4,''),(339845,14288,'119838','printshop-mobile','tab_2','Specials products',4,''),(339846,14288,'119838','printshop-mobile','tab_3','Featured',4,''),(339847,14321,'119871','printshop-mobile','tab_1','RETURNING CUSTOMER',4,''),(339848,14321,'119871','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(339849,14443,'119993','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339850,14449,'119999','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339851,14450,'120000','printshop-mobile','text','<p>CUSTOMER:</p>',4,''),(339852,14451,'120001','printshop-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339853,14455,'120005','printshop-mobile','text','<p>Shipping via</p>',4,''),(339854,14457,'120007','printshop-mobile','text','<p>Shipping service</p>',4,''),(339855,14461,'120011','printshop-mobile','text','<p>If undelivered please return to:</p>',4,''),(339857,14468,'120018','printshop-mobile','text','<p>Phone:</p>',4,''),(339858,14471,'120021','printshop-mobile','text','<p>Web:</p>',4,''),(339859,14474,'120024','printshop-mobile','text','<p>Email:</p>',4,''),(339861,14501,'120051','printshop-mobile','text','osCommerce 4',4,''),(339862,14536,'120086','printshop-mobile','tab_1','Description',4,''),(339863,14536,'120086','printshop-mobile','tab_2','Reviews',4,''),(339864,14581,'120131','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339865,14586,'120136','printshop-mobile','text','<p>ADDRESS:</p>\n',4,''),(339866,14589,'120139','printshop-mobile','text','<p>CUSTOMER:</p>',4,''),(339867,14590,'120140','printshop-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339868,14591,'120141','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339869,14595,'120145','printshop-mobile','text','<p>Order date:</p>\n',4,''),(339871,14603,'120153','printshop-mobile','text','<p>Email:</p>',4,''),(339872,14606,'120156','printshop-mobile','text','<p>Web:</p>',4,''),(339873,14609,'120159','printshop-mobile','text','<p>Phone:</p>',4,''),(339874,14613,'120163','printshop-mobile','text','<p>If undelivered please return to:</p>',4,''),(339875,14614,'120164','printshop-mobile','text','<p>Thank you for your order</p>',4,''),(339877,14617,'120167','printshop-mobile','text','<p>Phone:</p>',4,''),(339878,14619,'120169','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339879,14621,'120171','printshop-mobile','text','<p>Email:</p>',4,''),(339880,14661,'120211','printshop-mobile','text','<h1>Quotations</h1>',4,''),(339881,14778,'120328','printshop-mobile','logo','themes/printshop-mobile/img/Furntech-1.jpg',4,''),(339882,14802,'120352','printshop-mobile','text','<h1>Samples</h1>',4,''),(339883,14888,'120438','printshop-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',4,''),(339884,14907,'120457','printshop-mobile','text','<p>Phone:</p>',4,''),(339885,14910,'120460','printshop-mobile','text','<p>Web:</p>',4,''),(339886,14913,'120463','printshop-mobile','text','<p>Email:</p>',4,''),(339887,14918,'120468','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(339888,14921,'120471','printshop-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339889,14922,'120472','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339890,14923,'120473','printshop-mobile','text','<p>CUSTOMER:</p>',4,''),(339891,14929,'120479','printshop-mobile','text','<p>Shipping via</p>',4,''),(339892,14933,'120483','printshop-mobile','text','<p>Shipping service</p>',4,''),(339893,14934,'120484','printshop-mobile','text','<p>Payment date:</p>',4,''),(339894,14936,'120486','printshop-mobile','text','<p>Payment Method:</p>',4,''),(339895,14941,'120491','printshop-mobile','text','<p>If undelivered please return to:</p>',4,''),(339897,14944,'120494','printshop-mobile','text','<p>Thank you for your order</p>',4,''),(339898,14946,'120496','printshop-mobile','text','<p>Phone:</p>',4,''),(339899,14948,'120498','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339900,14950,'120500','printshop-mobile','text','<p>Email:</p>',4,''),(339901,14956,'120506','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340026,18022,'118691','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',4,''),(340027,18053,'118722','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',4,''),(340028,18758,'119427','deals-mobile','text','<p>Shipping via</p>',4,''),(340029,18762,'119431','deals-mobile','text','<p>Shipping service</p>',4,''),(340030,18766,'119435','deals-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(340031,18768,'119437','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340032,18771,'119440','deals-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340033,18772,'119441','deals-mobile','text','<p>CUSTOMER:</p>',4,''),(340034,18775,'119444','deals-mobile','text','<p>Payment date:</p>',4,''),(340035,18779,'119448','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340037,18787,'119456','deals-mobile','text','<p>Email:</p>',4,''),(340038,18790,'119459','deals-mobile','text','<p>Phone:</p>',4,''),(340039,18793,'119462','deals-mobile','text','<p>Web:</p>',4,''),(340040,18798,'119467','deals-mobile','text','<p>If undelivered please return to:</p>',4,''),(340041,18799,'119468','deals-mobile','text','<p>Thank you for your order</p>',4,''),(340043,18802,'119471','deals-mobile','text','<p>Phone:</p>',4,''),(340044,18805,'119474','deals-mobile','text','<p>Email:</p>',4,''),(340045,18807,'119476','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340046,18829,'119498','deals-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',4,''),(340047,18840,'119509','deals-mobile','logo','themes/deals-mobile/img/logo-white-1.png',4,''),(340048,18861,'119530','deals-mobile','text','Account',4,''),(340049,18866,'119535','deals-mobile','text','Account',4,''),(340050,18868,'119537','deals-mobile','text','Account',4,''),(340051,18872,'119541','deals-mobile','text','Account',4,''),(340052,18884,'119553','deals-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340053,18887,'119556','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340054,18888,'119557','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340055,18889,'119558','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(340056,18890,'119559','deals-mobile','text','<p>GIFT CARD</p>',4,''),(340057,18892,'119561','deals-mobile','text','<p>Your code is:</p>',4,''),(340058,18896,'119565','deals-mobile','text','<p>HOLBI</p>',4,''),(340059,18898,'119567','deals-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(340060,18901,'119570','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(340061,18902,'119571','deals-mobile','text','<p>GIFT CARD</p>',4,''),(340062,18903,'119572','deals-mobile','logo','themes/deals-mobile/img/logo-1.png',4,''),(340063,18904,'119573','deals-mobile','logo','themes/deals-mobile/img/bestseller-1.png',4,''),(340064,18905,'119574','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340065,18909,'119578','deals-mobile','text','<p>Your code is:</p>',4,''),(340066,18911,'119580','deals-mobile','text','<p>HOLBI</p>',4,''),(340067,18912,'119581','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340068,18915,'119584','deals-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340069,18918,'119587','deals-mobile','text','<p>HOLBI</p>',4,''),(340070,18919,'119588','deals-mobile','text','<p>GIFT CARD</p>',4,''),(340071,18920,'119589','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340072,18922,'119591','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(340073,18923,'119592','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340074,18926,'119595','deals-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340075,18929,'119598','deals-mobile','text','<p>Your code is:</p>',4,''),(340076,18941,'119610','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340077,18958,'119627','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340078,18970,'119639','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(340079,18971,'119640','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340080,18973,'119642','deals-mobile','text','<p>GIFT CARD</p>',4,''),(340081,18975,'119644','deals-mobile','text','<p>HOLBI</p>',4,''),(340082,18979,'119648','deals-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340083,18980,'119649','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340084,18982,'119651','deals-mobile','text','<p>Your code is:</p>',4,''),(340085,18993,'119662','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340086,19000,'119669','deals-mobile','logo','themes/deals-mobile/img/oscommerce_logo.png',4,''),(340087,19003,'119672','deals-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',4,''),(340088,19005,'119674','deals-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',4,''),(340089,19006,'119675','deals-mobile','logo','themes/deals-mobile/img/check-2.png',4,''),(340090,19022,'119691','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340092,19029,'119698','deals-mobile','text','<p>Phone:</p>',4,''),(340093,19034,'119703','deals-mobile','text','<p>Web:</p>',4,''),(340094,19037,'119706','deals-mobile','text','<p>Email:</p>',4,''),(340095,19040,'119709','deals-mobile','text','<p>If undelivered please return to:</p>',4,''),(340096,19042,'119711','deals-mobile','text','<p>Thank you for your order</p>',4,''),(340098,19045,'119714','deals-mobile','text','<p>Email:</p>',4,''),(340099,19048,'119717','deals-mobile','text','<p>Phone:</p>',4,''),(340100,19050,'119719','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340101,19054,'119723','deals-mobile','text','<p>Shipping via</p>',4,''),(340102,19058,'119727','deals-mobile','text','<p>Shipping service</p>',4,''),(340103,19061,'119730','deals-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(340104,19065,'119734','deals-mobile','text','<p>CUSTOMER:</p>',4,''),(340105,19067,'119736','deals-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340106,19068,'119737','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340107,19074,'119743','deals-mobile','text','<p>Payment date:</p>',4,''),(340108,19075,'119744','deals-mobile','text','<p>Payment Method:</p>',4,''),(340109,19077,'119746','deals-mobile','tab_1','RETURNING CUSTOMER',4,''),(340110,19077,'119746','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(340111,19099,'119768','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(340112,19099,'119768','deals-mobile','tab_2','RETURNING CUSTOMER',4,''),(340113,19099,'119768','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(340114,19115,'119784','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(340115,19115,'119784','deals-mobile','tab_2','RETURNING CUSTOMER',4,''),(340116,19115,'119784','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(340117,19128,'119797','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(340118,19128,'119797','deals-mobile','tab_2','RETURNING CUSTOMER',4,''),(340119,19128,'119797','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(340120,19169,'119838','deals-mobile','tab_1','New products',4,''),(340121,19169,'119838','deals-mobile','tab_2','Specials products',4,''),(340122,19169,'119838','deals-mobile','tab_3','Featured',4,''),(340123,19202,'119871','deals-mobile','tab_1','RETURNING CUSTOMER',4,''),(340124,19202,'119871','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(340125,19324,'119993','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340126,19330,'119999','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340127,19331,'120000','deals-mobile','text','<p>CUSTOMER:</p>',4,''),(340128,19332,'120001','deals-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340129,19336,'120005','deals-mobile','text','<p>Shipping via</p>',4,''),(340130,19338,'120007','deals-mobile','text','<p>Shipping service</p>',4,''),(340131,19342,'120011','deals-mobile','text','<p>If undelivered please return to:</p>',4,''),(340133,19349,'120018','deals-mobile','text','<p>Phone:</p>',4,''),(340134,19352,'120021','deals-mobile','text','<p>Web:</p>',4,''),(340135,19355,'120024','deals-mobile','text','<p>Email:</p>',4,''),(340137,19382,'120051','deals-mobile','text','osCommerce 4',4,''),(340138,19417,'120086','deals-mobile','tab_1','Description',4,''),(340139,19417,'120086','deals-mobile','tab_2','Reviews',4,''),(340140,19462,'120131','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340141,19467,'120136','deals-mobile','text','<p>ADDRESS:</p>\n',4,''),(340142,19470,'120139','deals-mobile','text','<p>CUSTOMER:</p>',4,''),(340143,19471,'120140','deals-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340144,19472,'120141','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340145,19476,'120145','deals-mobile','text','<p>Order date:</p>\n',4,''),(340147,19484,'120153','deals-mobile','text','<p>Email:</p>',4,''),(340148,19487,'120156','deals-mobile','text','<p>Web:</p>',4,''),(340149,19490,'120159','deals-mobile','text','<p>Phone:</p>',4,''),(340150,19494,'120163','deals-mobile','text','<p>If undelivered please return to:</p>',4,''),(340151,19495,'120164','deals-mobile','text','<p>Thank you for your order</p>',4,''),(340153,19498,'120167','deals-mobile','text','<p>Phone:</p>',4,''),(340154,19500,'120169','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340155,19502,'120171','deals-mobile','text','<p>Email:</p>',4,''),(340156,19542,'120211','deals-mobile','text','<h1>Quotations</h1>',4,''),(340157,19659,'120328','deals-mobile','logo','themes/deals-mobile/img/Furntech-1.jpg',4,''),(340158,19683,'120352','deals-mobile','text','<h1>Samples</h1>',4,''),(340159,19769,'120438','deals-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',4,''),(340160,19788,'120457','deals-mobile','text','<p>Phone:</p>',4,''),(340161,19791,'120460','deals-mobile','text','<p>Web:</p>',4,''),(340162,19794,'120463','deals-mobile','text','<p>Email:</p>',4,''),(340163,19799,'120468','deals-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(340164,19802,'120471','deals-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340165,19803,'120472','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340166,19804,'120473','deals-mobile','text','<p>CUSTOMER:</p>',4,''),(340167,19810,'120479','deals-mobile','text','<p>Shipping via</p>',4,''),(340168,19814,'120483','deals-mobile','text','<p>Shipping service</p>',4,''),(340169,19815,'120484','deals-mobile','text','<p>Payment date:</p>',4,''),(340170,19817,'120486','deals-mobile','text','<p>Payment Method:</p>',4,''),(340171,19822,'120491','deals-mobile','text','<p>If undelivered please return to:</p>',4,''),(340173,19825,'120494','deals-mobile','text','<p>Thank you for your order</p>',4,''),(340174,19827,'120496','deals-mobile','text','<p>Phone:</p>',4,''),(340175,19829,'120498','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340176,19831,'120500','deals-mobile','text','<p>Email:</p>',4,''),(340177,19837,'120506','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340310,54257,'116269','furniture-mobile','logo','themes/furniture-mobile/img/payicons-1.png',4,''),(340311,55017,'116977','furniture-mobile','text','<p>If undelivered please return to:</p>',4,''),(340312,55018,'116978','furniture-mobile','text','<p>Thank you for your order</p>',4,''),(340314,55020,'116980','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340315,55022,'116982','furniture-mobile','text','<p>Email:</p>',4,''),(340316,55025,'116985','furniture-mobile','text','<p>Phone:</p>',4,''),(340318,55031,'116991','furniture-mobile','text','<p>Web:</p>',4,''),(340319,55034,'116994','furniture-mobile','text','<p>Phone:</p>',4,''),(340320,55037,'116997','furniture-mobile','text','<p>Email:</p>',4,''),(340321,55044,'117004','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340322,55049,'117009','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(340323,55053,'117013','furniture-mobile','text','<p>CUSTOMER:</p>',4,''),(340324,55054,'117014','furniture-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340325,55057,'117017','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340326,55061,'117021','furniture-mobile','text','<p>Shipping via</p>',4,''),(340327,55063,'117023','furniture-mobile','text','<p>Shipping service</p>',4,''),(340328,55066,'117026','furniture-mobile','text','<p>Payment date:</p>',4,''),(340329,55101,'117055','furniture-mobile','logo','themes/furniture-mobile/img/logo-white-1.png',4,''),(340330,55150,'117107','furniture-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(340331,55155,'117112','furniture-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340332,55157,'117114','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340333,55158,'117115','furniture-mobile','text','<p>osCommerce</p>\n',4,''),(340334,55160,'117117','furniture-mobile','text','<p>Your code is:</p>',4,''),(340335,55164,'117121','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340336,55165,'117123','furniture-mobile','logo','themes/furniture-mobile/img/Logo-1.jpg',4,''),(340337,55166,'117124','furniture-mobile','text','<p>GIFT CARD</p>',4,''),(340338,55167,'117125','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(340339,55171,'117129','furniture-mobile','text','<p>Your code is:</p>',4,''),(340340,55175,'117133','furniture-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340341,55178,'117136','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340342,55179,'117137','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(340343,55180,'117138','furniture-mobile','text','<p>GIFT CARD</p>',4,''),(340344,55181,'117139','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340345,55192,'117150','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340346,55209,'117167','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340347,55221,'117180','furniture-mobile','text','<p>Your code is:</p>',4,''),(340348,55223,'117182','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340349,55225,'117185','furniture-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340350,55229,'117189','furniture-mobile','text','<p>GIFT CARD</p>',4,''),(340351,55230,'117190','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340352,55232,'117192','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(340353,55243,'117202','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340355,55258,'117218','furniture-mobile','logo','themes/furniture-mobile/img/header-img-1.png',4,''),(340356,55279,'117234','furniture-mobile','text','<p>Shipping via</p>',4,''),(340357,55281,'117236','furniture-mobile','text','<p>Shipping service</p>',4,''),(340358,55285,'117240','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(340359,55289,'117243','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340360,55292,'117246','furniture-mobile','text','<p>CUSTOMER:</p>',4,''),(340361,55293,'117247','furniture-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340362,55296,'117250','furniture-mobile','text','<p>Payment Method:</p>',4,''),(340363,55297,'117251','furniture-mobile','text','<p>Payment date:</p>',4,''),(340364,55303,'117257','furniture-mobile','text','<p>If undelivered please return to:</p>',4,''),(340365,55304,'117258','furniture-mobile','text','<p>Thank you for your order</p>',4,''),(340366,55306,'117261','furniture-mobile','text','<p>Email:</p>',4,''),(340367,55309,'117264','furniture-mobile','text','<p>Phone:</p>',4,''),(340368,55311,'117266','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340369,55316,'117271','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340370,55320,'117275','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',4,''),(340371,55322,'117277','furniture-mobile','text','<p>Web:</p>',4,''),(340372,55325,'117280','furniture-mobile','text','<p>Email:</p>',4,''),(340373,55330,'117285','furniture-mobile','text','<p>Phone:</p>',4,''),(340374,55337,'117288','furniture-mobile','tab_1','RETURNING CUSTOMER',4,''),(340375,55337,'117288','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(340376,55360,'117311','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(340377,55360,'117311','furniture-mobile','tab_2','RETURNING CUSTOMER',4,''),(340378,55360,'117311','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(340379,55376,'117327','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(340380,55376,'117327','furniture-mobile','tab_2','RETURNING CUSTOMER',4,''),(340381,55376,'117327','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(340382,55393,'117344','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(340383,55393,'117344','furniture-mobile','tab_2','RETURNING CUSTOMER',4,''),(340384,55393,'117344','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(340385,55486,'117416','furniture-mobile','tab_1','RETURNING CUSTOMER',4,''),(340386,55486,'117416','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(340387,55663,'117536','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',4,''),(340388,55665,'117538','furniture-mobile','text','<p>Email:</p>',4,''),(340389,55668,'117541','furniture-mobile','text','<p>Phone:</p>',4,''),(340390,55673,'117546','furniture-mobile','text','<p>Web:</p>',4,''),(340391,55678,'117551','furniture-mobile','text','<p>If undelivered please return to:</p>',4,''),(340392,55683,'117556','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340393,55685,'117558','furniture-mobile','text','<p>CUSTOMER:</p>',4,''),(340394,55688,'117561','furniture-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340395,55690,'117563','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340396,55694,'117567','furniture-mobile','text','<p>Shipping via</p>',4,''),(340397,55697,'117570','furniture-mobile','text','<p>Shipping service</p>',4,''),(340398,55726,'117596','furniture-mobile','logo','themes/furniture-mobile/img/oscommerce_logo-1.jpg',4,''),(340399,55727,'117597','furniture-mobile','text','osCommerce 4',4,''),(340400,55764,'117646','furniture-mobile','tab_1','Product Overview',4,''),(340401,55764,'117646','furniture-mobile','tab_2','Delivery and returns',4,''),(340402,55764,'117646','furniture-mobile','tab_3','Assembly',4,''),(340403,55882,'117702','furniture-mobile','text','<p>If undelivered please return to:</p>',4,''),(340404,55884,'117704','furniture-mobile','text','<p>Thank you for your order</p>',4,''),(340406,55887,'117707','furniture-mobile','text','<p>Email:</p>',4,''),(340407,55889,'117709','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340408,55891,'117711','furniture-mobile','text','<p>Phone:</p>',4,''),(340410,55896,'117716','furniture-mobile','text','<p>Phone:</p>',4,''),(340411,55899,'117719','furniture-mobile','text','<p>Web:</p>',4,''),(340412,55904,'117724','furniture-mobile','text','<p>Email:</p>',4,''),(340413,55910,'117730','furniture-mobile','text','<p>ADDRESS:</p>\n',4,''),(340414,55913,'117733','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340415,55916,'117736','furniture-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340416,55917,'117737','furniture-mobile','text','<p>CUSTOMER:</p>',4,''),(340417,55919,'117739','furniture-mobile','text','<p>Order date:</p>\n',4,''),(340418,55924,'117744','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340419,56056,'117816','furniture-mobile','logo','themes/furniture-mobile/img/Furntech-1.jpg',4,''),(340420,56314,'118011','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340421,56318,'118015','furniture-mobile','text','<p>If undelivered please return to:</p>',4,''),(340422,56320,'118018','furniture-mobile','text','<p>Thank you for your order</p>',4,''),(340423,56321,'118019','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340424,56323,'118021','furniture-mobile','text','<p>Email:</p>',4,''),(340425,56326,'118024','furniture-mobile','text','<p>Phone:</p>',4,''),(340426,56331,'118029','furniture-mobile','text','<p>Email:</p>',4,''),(340427,56334,'118032','furniture-mobile','text','<p>Web:</p>',4,''),(340428,56339,'118037','furniture-mobile','text','<p>Phone:</p>',4,''),(340429,56344,'118042','furniture-mobile','text','<p>Shipping via</p>',4,''),(340430,56347,'118045','furniture-mobile','text','<p>Shipping service</p>',4,''),(340431,56352,'118050','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(340432,56355,'118053','furniture-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340433,56358,'118056','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340434,56359,'118057','furniture-mobile','text','<p>CUSTOMER:</p>',4,''),(340435,56361,'118059','furniture-mobile','text','<p>Payment date:</p>',4,''),(340436,56362,'118060','furniture-mobile','text','<p>Payment Method:</p>',4,''),(340701,108868,'117051','splash','logo','themes/splash/img/oscommerce_logo_(2)-1.png',4,''),(340702,108918,'1661353032.672459','splash','logo','themes/splash/img/oscommerce_logo.jpg',4,''),(340703,108933,'1640168618.7708','splash','logo','themes/splash/img/oscommerce_logo (2).png',4,''),(340704,108936,'1640169872.1589','splash','img_link','furniture/',4,''),(340705,108936,'1640169872.1589','splash','logo','themes/splash/img/Splash_furniture_BGlogo.png',4,''),(340706,108936,'1640169872.1589','splash','target_blank','1',4,''),(340707,108937,'1640276640.1123','splash','text','<h1>osCommerce v4 Splash page</h1>\r\n\r\n<p>osCommerce supports multiple sales CHANNELS.</p>\r\n\r\n<p>Your installation of osCommerce comes with &nbsp;&quot;Furniture&quot;, &quot;Watch&quot;, &quot;B2B Supermarket&quot;, and &quot;Print shop&quot; Ecommerce sales channels and &quot;cms&quot; brochure website example.</p>\r\n\r\n<p>Each sales channel has its own URLs, design, and demo product sets.</p>\r\n\r\n<p>&quot;Admin&quot; is the back end of your osCommerce.</p>\r\n\r\n<p>Use osCommerce Wiki to learn how to manage sales channels, &nbsp;assign design themes, and content to the sales channels.<br />\r\nThank you for choosing &nbsp;osCommerce - the most powerful on-premise open source Ecommerce platform!</p>\r\n',4,''),(340708,108938,'1640170154.7803','splash','img_link','watch/',4,''),(340709,108938,'1640170154.7803','splash','logo','themes/splash/img/Splash_watch_BGlogo.png',4,''),(340710,108938,'1640170154.7803','splash','target_blank','1',4,''),(340711,108940,'1640170023.0001','splash','img_link','printshop/',4,''),(340712,108940,'1640170023.0001','splash','logo','themes/splash/img/print shop.jpg',4,''),(340713,108940,'1640170023.0001','splash','target_blank','1',4,''),(340714,108941,'1640170023.1491','splash','img_link','admin/',4,''),(340715,108941,'1640170023.1491','splash','logo','themes/splash/img/Splash_admin_BGlogo.png',4,''),(340716,108941,'1640170023.1491','splash','target_blank','1',4,''),(340717,108942,'1640170023','splash','img_link','b2b-supermarket/',4,''),(340718,108942,'1640170023','splash','logo','themes/splash/img/b2b supermarket.jpg',4,''),(340719,108942,'1640170023','splash','target_blank','1',4,''),(340720,108945,'1661353032.975845','splash','logo','themes/splash/img/oscommerce_logo-1.jpg',4,''),(340721,109001,'74702','splash','logo','themes/splash/img/oscommerce_logo.jpg',4,''),(340722,109002,'74703','splash','text','osCommerce 4',4,''),(340832,109007,'116005','furniture','text','##TEXT_PAGE_NOT_FOUND##',0,''),(340833,109007,'116005','furniture','text-align','center',0,''),(340834,109007,'116005','furniture','padding-top','100',0,''),(340835,109007,'116005','furniture','padding-bottom','100',0,''),(340836,109008,'116006','furniture','block_type','1',0,''),(340955,109024,'116022','furniture','block_type','1',0,''),(341074,109040,'116038','furniture','block_type','1',0,''),(341193,109056,'116054','furniture','block_type','1',0,''),(341312,109072,'116070','furniture','block_type','1',0,''),(341431,109088,'116086','furniture','block_type','1',0,''),(341550,109104,'116102','furniture','block_type','1',0,''),(341551,109104,'116102','furniture','style_class','account-index',0,''),(341788,109167,'116145','furniture','block_type','1',0,''),(341789,109167,'116145','furniture','style_class','account-edit-wrap',0,''),(341851,109191,'116150','furniture','block_type','1',0,''),(341852,109191,'116150','furniture','style_class','account-address-book',0,''),(341923,109216,'116156','furniture','block_type','1',0,''),(341924,109216,'116156','furniture','style_class','account-address-book-process',0,''),(341986,109240,'117906.000001','furniture','block_type','1',0,''),(341987,109240,'117906.000001','furniture','style_class','item-holder',0,''),(341988,109240,'117906.000001','furniture','padding-top','25',0,''),(341989,109240,'117906.000001','furniture','padding-bottom','25',0,''),(341990,109240,'117906.000001','furniture','text-align','left',0,''),(341991,109240,'117906.000001','furniture','border-top-width','1',0,''),(341992,109240,'117906.000001','furniture','border-top-color','$content-border-1',0,''),(341993,109241,'117907.000001','furniture','block_type','7',0,''),(341994,109241,'117907.000001','furniture','schema','7-2',0,'5140'),(341995,109242,'117908.000001','furniture','block_type','5',0,''),(341996,109242,'117908.000001','furniture','schema','5-2',0,'5140'),(341997,109243,'117909.000001','furniture','clear','none',0,''),(341998,109243,'117909.000001','furniture','padding-right','20',0,''),(341999,109244,'117910.000001','furniture','padding-right','20',0,''),(342000,109244,'117910.000001','furniture','max-width','300',0,'5140'),(342001,109244,'117910.000001','furniture','margin_left_measure','auto',0,'5140'),(342002,109244,'117910.000001','furniture','margin_right_measure','auto',0,'5140'),(342003,109245,'117914.000001','furniture','padding-right','20',0,''),(342004,109246,'117915.000001','furniture','description_characters','200',0,''),(342005,109246,'117915.000001','furniture','clear','none',0,''),(342006,109246,'117915.000001','furniture','padding-right','20',0,''),(342007,109247,'117916.000001','furniture','clear','none',0,''),(342008,109248,'117917.000001','furniture','margin-bottom','20',0,''),(342009,109250,'117918.000001','furniture','block_type','1',0,''),(342010,109250,'117918.000001','furniture','padding-left','40',0,''),(342011,109250,'117918.000001','furniture','style_class','right-aria',0,''),(342012,109250,'117918.000001','furniture','padding-left','0',0,'5140'),(342013,109251,'117911.000001','furniture','block_type','1',0,''),(342014,109251,'117911.000001','furniture','text-align','center',0,''),(342015,109252,'117912.000001','furniture','margin-top','4',0,''),(342016,109252,'117912.000001','furniture','margin-bottom','7',0,''),(342017,109253,'117913.000001','furniture','padding-top','6',0,''),(342018,109253,'117913.000001','furniture','padding-left','5',0,''),(342019,109254,'117919.000001','furniture','margin-bottom','15',0,''),(342020,109254,'117919.000001','furniture','text-align','right',0,''),(342021,109255,'117920.000001','furniture','margin-bottom','10',0,''),(342022,109255,'117920.000001','furniture','text-align','center',0,''),(342023,109256,'117922.000001','furniture','text-align','right',0,''),(342024,109256,'117922.000001','furniture','margin-bottom','15',0,''),(342025,109257,'117924.000001','furniture','text-align','center',0,''),(342026,109257,'117924.000001','furniture','margin-bottom','10',0,''),(342027,109258,'120924.000001','furniture','block_type','1',0,''),(342028,109258,'120924.000001','furniture','style_class','item-nav',0,''),(342029,109262,'116176','furniture','block_type','1',0,''),(342030,109262,'116176','furniture','style_class','item-holder',0,''),(342031,109262,'116176','furniture','padding-top','25',0,''),(342032,109262,'116176','furniture','padding-left','25',0,''),(342033,109262,'116176','furniture','padding-right','25',0,''),(342034,109262,'116176','furniture','padding-bottom','25',0,''),(342035,109262,'116176','furniture','text-align','left',0,''),(342036,109264,'116178','furniture','margin-bottom','7',0,''),(342037,109265,'116179','furniture','clear','both',0,''),(342038,109268,'116182','furniture','block_type','1',0,''),(342039,109268,'116182','furniture','style_class','item-holder',0,''),(342040,109268,'116182','furniture','padding-top','25',0,''),(342041,109268,'116182','furniture','padding-left','25',0,''),(342042,109268,'116182','furniture','padding-right','25',0,''),(342043,109268,'116182','furniture','padding-bottom','25',0,''),(342044,109268,'116182','furniture','text-align','left',0,''),(342045,109269,'116183','furniture','block_type','5',0,'');
INSERT INTO `design_boxes_settings` VALUES (342046,109272,'116186','furniture','margin-bottom','7',0,''),(342047,109273,'116187','furniture','clear','both',0,''),(342048,109274,'116188','furniture','block_type','1',0,''),(342049,109275,'116189','furniture','block_type','6',0,''),(342050,109275,'116189','furniture','font-weight','400',0,''),(342051,109275,'116189','furniture','schema','6-2',0,'5161'),(342052,109275,'116189','furniture','schema','6-2',0,'5140'),(342053,109276,'116190','furniture','font-weight','400',0,''),(342054,109276,'116190','furniture','padding-right','40',0,''),(342055,109276,'116190','furniture','padding-right','0',0,'5161'),(342056,109276,'116190','furniture','padding-right','0',0,'5140'),(342057,109277,'116191','furniture','block_type','5',0,''),(342058,109277,'116191','furniture','padding-top','10',0,''),(342059,109277,'116191','furniture','padding-bottom','10',0,''),(342060,109277,'116191','furniture','schema','5-2',0,'5161'),(342061,109277,'116191','furniture','border-top-color','$content-border-1',0,''),(342062,109277,'116191','furniture','border-top-width','1',0,''),(342063,109279,'116193','furniture','float','right',0,''),(342064,109281,'116195','furniture','col_in_row','3',0,''),(342065,109281,'116195','furniture','products_align','left',0,''),(342066,109281,'116195','furniture','font-weight','400',0,''),(342067,109281,'116195','furniture','show_qty_input','0',0,''),(342068,109281,'116195','furniture','listing_type','productListing',0,''),(342069,109281,'116195','furniture','listing_type_rows','no',0,''),(342070,109281,'116195','furniture','show_buy_button_b2b','on',0,''),(342071,109281,'116195','furniture','show_wishlist_button_b2b','1',0,''),(342072,109281,'116195','furniture','show_compare_b2b','1',0,''),(342073,109281,'116195','furniture','show_stock','0',0,''),(342074,109281,'116195','furniture','show_description','0',0,''),(342075,109281,'116195','furniture','show_model','0',0,''),(342076,109281,'116195','furniture','show_properties','0',0,''),(342077,109281,'116195','furniture','show_rating','0',0,''),(342078,109281,'116195','furniture','show_rating_counts','0',0,''),(342079,109281,'116195','furniture','show_price','0',0,''),(342080,109281,'116195','furniture','show_buy_button','0',0,''),(342081,109281,'116195','furniture','show_view_button','0',0,''),(342082,109281,'116195','furniture','show_wishlist_button','0',0,''),(342083,109281,'116195','furniture','show_compare','0',0,''),(342084,109281,'116195','furniture','show_name_rows','0',0,''),(342085,109281,'116195','furniture','show_image_rows','0',0,''),(342086,109281,'116195','furniture','show_stock_rows','0',0,''),(342087,109281,'116195','furniture','show_description_rows','0',0,''),(342088,109281,'116195','furniture','show_model_rows','0',0,''),(342089,109281,'116195','furniture','show_properties_rows','0',0,''),(342090,109281,'116195','furniture','show_rating_rows','0',0,''),(342091,109281,'116195','furniture','show_rating_counts_rows','0',0,''),(342092,109281,'116195','furniture','show_price_rows','0',0,''),(342093,109281,'116195','furniture','show_buy_button_rows','0',0,''),(342094,109281,'116195','furniture','show_qty_input_rows','0',0,''),(342095,109281,'116195','furniture','show_view_button_rows','0',0,''),(342096,109281,'116195','furniture','show_wishlist_button_rows','0',0,''),(342097,109281,'116195','furniture','show_compare_rows','0',0,''),(342098,109281,'116195','furniture','show_name_b2b','0',0,''),(342099,109281,'116195','furniture','show_image_b2b','0',0,''),(342100,109281,'116195','furniture','show_stock_b2b','0',0,''),(342101,109281,'116195','furniture','show_description_b2b','0',0,''),(342102,109281,'116195','furniture','show_model_b2b','0',0,''),(342103,109281,'116195','furniture','show_properties_b2b','0',0,''),(342104,109281,'116195','furniture','show_rating_b2b','0',0,''),(342105,109281,'116195','furniture','show_rating_counts_b2b','0',0,''),(342106,109281,'116195','furniture','show_price_b2b','0',0,''),(342107,109281,'116195','furniture','show_qty_input_b2b','0',0,''),(342108,109281,'116195','furniture','show_view_button_b2b','0',0,''),(342109,109281,'116195','furniture','show_attributes_b2b','0',0,''),(342110,109281,'116195','furniture','items_on_page','9',0,''),(342111,109281,'116195','furniture','col_in_row','2',0,'5140'),(342112,109281,'116195','furniture','col_in_row','1',0,'5161'),(342113,109281,'116195','furniture','product_names_teg','h2',0,''),(342114,109282,'116196','furniture','listing_type','productListing',0,''),(342115,109283,'116197','furniture','block_type','1',0,''),(342116,109283,'116197','furniture','padding-top','10',0,''),(342117,109283,'116197','furniture','padding-bottom','10',0,''),(342118,109283,'116197','furniture','border-bottom-width','1',0,''),(342119,109283,'116197','furniture','border-bottom-color','$content-border-1',0,''),(342120,109283,'116197','furniture','margin-left','0',0,''),(342121,109283,'116197','furniture','margin-right','0',0,''),(342122,109284,'116198','furniture','float','right',0,''),(342123,109284,'116198','furniture','display','none',0,'5161'),(342124,109285,'116199','furniture','margin-right','20',0,''),(342125,109285,'116199','furniture','float','right',0,''),(342126,109285,'116199','furniture','clear','none',0,''),(342127,109285,'116199','furniture','display','none',0,'5140'),(342128,109286,'116200','furniture','float','left',0,''),(342129,109286,'116200','furniture','clear','none',0,''),(342130,109286,'116200','furniture','margin-left','20',0,''),(342131,109286,'116200','furniture','display','none',0,'5161'),(342132,109287,'116201','furniture','float','left',0,''),(342133,109287,'116201','furniture','clear','none',0,''),(342134,109287,'116201','furniture','sort_pos_3','1',0,''),(342135,109287,'116201','furniture','sort_pos_4','2',0,''),(342136,109287,'116201','furniture','sort_pos_10','3',0,''),(342137,109287,'116201','furniture','sort_pos_9','4',0,''),(342138,109287,'116201','furniture','sort_pos_11','5',0,''),(342139,109287,'116201','furniture','sort_pos_12','6',0,''),(342140,109287,'116201','furniture','sort_pos_14','7',0,''),(342141,109287,'116201','furniture','sort_pos_13','8',0,''),(342142,109287,'116201','furniture','sort_pos_8','9',0,''),(342143,109287,'116201','furniture','sort_pos_7','10',0,''),(342144,109287,'116201','furniture','sort_pos_2','11',0,''),(342145,109287,'116201','furniture','sort_pos_1','12',0,''),(342146,109287,'116201','furniture','sort_pos_6','13',0,''),(342147,109287,'116201','furniture','sort_pos_5','14',0,''),(342148,109287,'116201','furniture','sort_pos_0','15',0,''),(342149,109287,'116201','furniture','sort_hide_10','1',0,''),(342150,109287,'116201','furniture','sort_hide_9','1',0,''),(342151,109287,'116201','furniture','hide_icons','1',0,''),(342152,109287,'116201','furniture','sort_hide_16','1',0,''),(342153,109287,'116201','furniture','sort_hide_15','1',0,''),(342154,109287,'116201','furniture','sort_hide_3','0',0,''),(342155,109287,'116201','furniture','sort_hide_4','0',0,''),(342156,109287,'116201','furniture','sort_hide_11','1',0,''),(342157,109287,'116201','furniture','sort_hide_12','1',0,''),(342158,109287,'116201','furniture','sort_hide_14','1',0,''),(342159,109287,'116201','furniture','sort_hide_13','1',0,''),(342160,109287,'116201','furniture','sort_hide_8','0',0,''),(342161,109287,'116201','furniture','sort_hide_7','0',0,''),(342162,109287,'116201','furniture','sort_hide_2','1',0,''),(342163,109287,'116201','furniture','sort_hide_1','1',0,''),(342164,109287,'116201','furniture','sort_hide_6','1',0,''),(342165,109287,'116201','furniture','sort_hide_5','1',0,''),(342166,109287,'116201','furniture','sort_hide_0','1',0,''),(342167,109290,'1683103176.926637','furniture','block_type','1',0,''),(342168,109290,'1683103176.926637','furniture','font-weight','normal',0,''),(342169,109290,'1683103176.926637','furniture','padding-top','20',0,''),(342170,109290,'1683103176.926637','furniture','background-color','$content-bg-2',0,''),(342171,109290,'1683103176.926637','furniture','style_class','shopping-cart-index',0,''),(342172,109291,'1683103176.947325','furniture','block_type','4',0,''),(342173,109291,'1683103176.947325','furniture','schema','4-1',0,'5145'),(342174,109291,'1683103176.947325','furniture','schema','4-2',0,'5140'),(342175,109292,'1683103176.971768','furniture','block_type','1',0,''),(342176,109292,'1683103176.971768','furniture','background-color','$content-bg-1',0,''),(342177,109292,'1683103176.971768','furniture','margin-bottom','25',0,''),(342178,109292,'1683103176.971768','furniture','padding-left','25',0,''),(342179,109292,'1683103176.971768','furniture','padding-right','25',0,''),(342180,109292,'1683103176.971768','furniture','padding-bottom','25',0,''),(342181,109293,'1683103176.974446','furniture','padding-top','20',0,''),(342182,109293,'1683103176.974446','furniture','padding-bottom','20',0,''),(342183,109294,'1683103176.975161','furniture','block_type','2',0,''),(342184,109294,'1683103176.975161','furniture','padding-bottom','20',0,''),(342185,109294,'1683103176.975161','furniture','padding-top','20',0,''),(342186,109294,'1683103176.975161','furniture','border-bottom-color','$content-border-1',0,''),(342187,109294,'1683103176.975161','furniture','border-bottom-width','1',0,''),(342188,109294,'1683103176.975161','furniture','schema','2-2',0,'5140'),(342189,109295,'1683103176.976938','furniture','float','left',0,''),(342190,109295,'1683103176.976938','furniture','float','none',0,'5140'),(342191,109296,'1683103176.977748','furniture','text-align','right',0,''),(342192,109296,'1683103176.977748','furniture','clear','none',0,''),(342193,109296,'1683103176.977748','furniture','float','right',0,''),(342194,109296,'1683103176.977748','furniture','padding-top','22',0,''),(342195,109296,'1683103176.977748','furniture','float','none',0,'5140'),(342196,109296,'1683103176.977748','furniture','text-align','left',0,'5140'),(342197,109297,'1683103176.9792','furniture','float','right',0,''),(342198,109297,'1683103176.9792','furniture','padding-top','26',0,''),(342199,109297,'1683103176.9792','furniture','float','none',0,'5140'),(342200,109297,'1683103176.9792','furniture','text-align','left',0,'5140'),(342201,109298,'1683103176.9841','furniture','block_type','3',0,''),(342202,109298,'1683103176.9841','furniture','font-weight','400',0,''),(342203,109298,'1683103176.9841','furniture','schema','2-2',0,'5131'),(342204,109298,'1683103176.9841','furniture','style_class','closeable-content',0,''),(342205,109298,'1683103176.9841','furniture','padding-top','10',0,''),(342206,109300,'1683103176.982975','furniture','padding-right','24',0,''),(342207,109300,'1683103176.982975','furniture','padding-right','0',0,'5131'),(342208,109300,'1683103176.982975','furniture','padding-bottom','20',0,'5131'),(342209,109301,'1683103176.983866','furniture','text-align','right',0,''),(342210,109302,'1683103176.985151','furniture','text','<div><span>##TEXT_YOUR_SHOPPING_CART##</span></div>',0,''),(342211,109302,'1683103176.985151','furniture','font-size','36',0,''),(342212,109302,'1683103176.985151','furniture','text-align','center',0,''),(342213,109302,'1683103176.985151','furniture','padding-top','20',0,''),(342214,109302,'1683103176.985151','furniture','margin-bottom','20',0,''),(342215,109302,'1683103176.985151','furniture','style_class','cartTitle',0,''),(342216,109302,'1683103176.985151','furniture','font-weight','600',0,''),(342217,109303,'1683103176.987818','furniture','block_type','1',0,''),(342218,109303,'1683103176.987818','furniture','padding-top','20',0,''),(342219,109303,'1683103176.987818','furniture','padding-bottom','20',0,''),(342220,109303,'1683103176.987818','furniture','padding-left','25',0,''),(342221,109303,'1683103176.987818','furniture','padding-right','25',0,''),(342222,109303,'1683103176.987818','furniture','background-color','$content-bg-1',0,''),(342223,109303,'1683103176.987818','furniture','margin-bottom','30',0,''),(342224,109304,'1683103176.989631','furniture','hide_parents','2',0,''),(342225,109305,'1683103176.99020','furniture','text','<div class=\"heading-3\">##TEXT_GA_PRODUCTS##</div>',0,''),(342226,109305,'1683103176.99020','furniture','style_class','shipping-ico',0,''),(342227,109306,'1683103176.992136','furniture','block_type','1',0,''),(342228,109306,'1683103176.992136','furniture','background-color','$content-bg-1',0,''),(342229,109306,'1683103176.992136','furniture','padding-top','20',0,''),(342230,109306,'1683103176.992136','furniture','padding-left','25',0,''),(342231,109306,'1683103176.992136','furniture','padding-right','25',0,''),(342232,109306,'1683103176.992136','furniture','padding-bottom','20',0,''),(342233,109306,'1683103176.992136','furniture','margin-bottom','30',0,''),(342234,109306,'1683103176.992136','furniture','style_class','closeable-box',0,''),(342235,109306,'1683103176.992136','furniture','display','none',0,'5140'),(342236,109307,'1683103176.99416','furniture','text','<div class=\"heading-3\">##TEXT_SHIPPING##</div>',0,''),(342237,109307,'1683103176.99416','furniture','style_class','shipping-ico',0,''),(342238,109308,'1683103176.995796','furniture','font-weight','normal',0,''),(342239,109308,'1683103176.995796','furniture','hide_parents','2',0,''),(342240,109309,'1683103176.996373','furniture','listing_type','productListing',0,''),(342241,109309,'1683103176.996373','furniture','col_in_row','4',0,''),(342242,109309,'1683103176.996373','furniture','show_popup','1',0,''),(342243,109309,'1683103176.996373','furniture','col_in_row','3',0,'5140'),(342244,109309,'1683103176.996373','furniture','col_in_row','2',0,'5131'),(342245,109309,'1683103176.996373','furniture','col_in_row','1',0,'5161'),(342246,109309,'1683103176.996373','furniture','padding-top','20',0,''),(342247,109309,'1683103176.996373','furniture','padding-left','25',0,''),(342248,109309,'1683103176.996373','furniture','padding-right','25',0,''),(342249,109309,'1683103176.996373','furniture','padding-bottom','20',0,''),(342250,109309,'1683103176.996373','furniture','background-color','$content-bg-1',0,''),(342251,109309,'1683103176.996373','furniture','margin-bottom','25',0,''),(342252,109310,'1683103176.999540','furniture','style_class','order-summary',0,''),(342253,109310,'1683103176.999540','furniture','block_type','1',0,''),(342254,109310,'1683103176.999540','furniture','margin-left','25',0,''),(342255,109310,'1683103176.999540','furniture','margin-left','0',0,'5140'),(342256,109310,'1683103176.999540','furniture','margin-bottom','30',0,'5140'),(342257,109310,'1683103176.999540','furniture','padding-left','10',0,''),(342258,109310,'1683103176.999540','furniture','padding-right','10',0,''),(342259,109310,'1683103176.999540','furniture','padding-bottom','10',0,''),(342260,109310,'1683103176.999540','furniture','background-color','$content-bg-1',0,''),(342261,109311,'1683103177.002177','furniture','block_type','1',0,''),(342262,109312,'1683103177.003296','furniture','font-weight','400',0,''),(342263,109312,'1683103177.003296','furniture','padding-right','0',0,'5131'),(342264,109312,'1683103177.003296','furniture','padding-bottom','20',0,'5131'),(342265,109313,'1683103177.016825','furniture','font-weight','400',0,''),(342266,109313,'1683103177.016825','furniture','box_align','4',0,''),(342267,109313,'1683103177.016825','furniture','text-align','center',0,'5131'),(342268,109313,'1683103177.016825','furniture','float','none',0,'5131'),(342269,109313,'1683103177.016825','furniture','width','100',0,'5131'),(342270,109313,'1683103177.016825','furniture','width_measure','%',0,'5131'),(342271,109314,'1683103177.018382','furniture','style_class','top-totals',0,''),(342272,109315,'1683103177.018993','furniture','style_class','bottom-totals',0,''),(342273,109316,'1683103177.019577','furniture','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(342278,109327,'116272','furniture','block_type','1',0,''),(342279,109328,'116273','furniture','block_type','6',0,''),(342280,109328,'116273','furniture','font-weight','400',0,''),(342281,109328,'116273','furniture','schema','6-2',0,'5161'),(342282,109328,'116273','furniture','schema','6-2',0,'5140'),(342283,109329,'116274','furniture','font-weight','400',0,''),(342284,109329,'116274','furniture','padding-right','40',0,''),(342285,109329,'116274','furniture','padding-right','0',0,'5161'),(342286,109329,'116274','furniture','padding-right','0',0,'5140'),(342287,109331,'116275','furniture','col_in_row','3',0,''),(342288,109331,'116275','furniture','products_align','left',0,''),(342289,109331,'116275','furniture','font-weight','400',0,''),(342290,109331,'116275','furniture','show_qty_input','0',0,''),(342291,109331,'116275','furniture','listing_type','productListing',0,''),(342292,109331,'116275','furniture','listing_type_rows','Rows',0,''),(342293,109331,'116275','furniture','show_buy_button_b2b','on',0,''),(342294,109331,'116275','furniture','show_wishlist_button_b2b','1',0,''),(342295,109331,'116275','furniture','show_compare_b2b','1',0,''),(342296,109331,'116275','furniture','show_stock','0',0,''),(342297,109331,'116275','furniture','show_description','0',0,''),(342298,109331,'116275','furniture','show_model','0',0,''),(342299,109331,'116275','furniture','show_properties','0',0,''),(342300,109331,'116275','furniture','show_rating','0',0,''),(342301,109331,'116275','furniture','show_rating_counts','0',0,''),(342302,109331,'116275','furniture','show_price','0',0,''),(342303,109331,'116275','furniture','show_buy_button','0',0,''),(342304,109331,'116275','furniture','show_view_button','0',0,''),(342305,109331,'116275','furniture','show_wishlist_button','0',0,''),(342306,109331,'116275','furniture','show_compare','0',0,''),(342307,109331,'116275','furniture','show_name_rows','0',0,''),(342308,109331,'116275','furniture','show_image_rows','0',0,''),(342309,109331,'116275','furniture','show_stock_rows','0',0,''),(342310,109331,'116275','furniture','show_description_rows','0',0,''),(342311,109331,'116275','furniture','show_model_rows','0',0,''),(342312,109331,'116275','furniture','show_properties_rows','0',0,''),(342313,109331,'116275','furniture','show_rating_rows','0',0,''),(342314,109331,'116275','furniture','show_rating_counts_rows','0',0,''),(342315,109331,'116275','furniture','show_price_rows','0',0,''),(342316,109331,'116275','furniture','show_buy_button_rows','0',0,''),(342317,109331,'116275','furniture','show_qty_input_rows','0',0,''),(342318,109331,'116275','furniture','show_view_button_rows','0',0,''),(342319,109331,'116275','furniture','show_wishlist_button_rows','0',0,''),(342320,109331,'116275','furniture','show_compare_rows','0',0,''),(342321,109331,'116275','furniture','show_name_b2b','0',0,''),(342322,109331,'116275','furniture','show_image_b2b','0',0,''),(342323,109331,'116275','furniture','show_stock_b2b','0',0,''),(342324,109331,'116275','furniture','show_description_b2b','0',0,''),(342325,109331,'116275','furniture','show_model_b2b','0',0,''),(342326,109331,'116275','furniture','show_properties_b2b','0',0,''),(342327,109331,'116275','furniture','show_rating_b2b','0',0,''),(342328,109331,'116275','furniture','show_rating_counts_b2b','0',0,''),(342329,109331,'116275','furniture','show_price_b2b','0',0,''),(342330,109331,'116275','furniture','show_qty_input_b2b','0',0,''),(342331,109331,'116275','furniture','show_view_button_b2b','0',0,''),(342332,109331,'116275','furniture','show_attributes_b2b','0',0,''),(342333,109331,'116275','furniture','items_on_page','9',0,''),(342334,109331,'116275','furniture','col_in_row','2',0,'5140'),(342335,109331,'116275','furniture','col_in_row','1',0,'5161'),(342336,109331,'116275','furniture','product_names_teg','h2',0,''),(342337,109333,'116277','furniture','block_type','5',0,''),(342338,109333,'116277','furniture','padding-top','10',0,''),(342339,109333,'116277','furniture','padding-bottom','10',0,''),(342340,109333,'116277','furniture','schema','5-2',0,'5161'),(342341,109333,'116277','furniture','border-top-color','$content-border-1',0,''),(342342,109333,'116277','furniture','border-top-width','1',0,''),(342343,109335,'116279','furniture','float','right',0,''),(342344,109336,'116280','furniture','listing_type','productListing',0,''),(342345,109338,'116282','furniture','block_type','1',0,''),(342346,109338,'116282','furniture','padding-top','10',0,''),(342347,109338,'116282','furniture','padding-bottom','10',0,''),(342348,109338,'116282','furniture','border-bottom-width','1',0,''),(342349,109338,'116282','furniture','border-bottom-color','$content-border-1',0,''),(342350,109338,'116282','furniture','margin-left','0',0,''),(342351,109338,'116282','furniture','margin-right','0',0,''),(342352,109339,'116283','furniture','float','right',0,''),(342353,109339,'116283','furniture','display','none',0,'5161'),(342354,109340,'116284','furniture','margin-right','20',0,''),(342355,109340,'116284','furniture','float','right',0,''),(342356,109340,'116284','furniture','clear','none',0,''),(342357,109340,'116284','furniture','display','none',0,'5140'),(342358,109341,'116285','furniture','float','left',0,''),(342359,109341,'116285','furniture','clear','none',0,''),(342360,109341,'116285','furniture','margin-left','20',0,''),(342361,109341,'116285','furniture','display','none',0,'5161'),(342362,109341,'116285','furniture','display','none',0,'5145'),(342363,109342,'116286','furniture','float','left',0,''),(342364,109342,'116286','furniture','clear','none',0,''),(342365,109342,'116286','furniture','sort_pos_3','2',0,''),(342366,109342,'116286','furniture','sort_pos_4','3',0,''),(342367,109342,'116286','furniture','sort_pos_10','11',0,''),(342368,109342,'116286','furniture','sort_pos_9','10',0,''),(342369,109342,'116286','furniture','sort_pos_11','12',0,''),(342370,109342,'116286','furniture','sort_pos_12','13',0,''),(342371,109342,'116286','furniture','sort_pos_14','15',0,''),(342372,109342,'116286','furniture','sort_pos_13','14',0,''),(342373,109342,'116286','furniture','sort_pos_8','4',0,''),(342374,109342,'116286','furniture','sort_pos_7','5',0,''),(342375,109342,'116286','furniture','sort_pos_2','7',0,''),(342376,109342,'116286','furniture','sort_pos_1','6',0,''),(342377,109342,'116286','furniture','sort_pos_6','9',0,''),(342378,109342,'116286','furniture','sort_pos_5','8',0,''),(342379,109342,'116286','furniture','sort_pos_0','1',0,''),(342380,109342,'116286','furniture','sort_hide_10','1',0,''),(342381,109342,'116286','furniture','sort_hide_9','1',0,''),(342382,109342,'116286','furniture','hide_icons','1',0,''),(342383,109342,'116286','furniture','sort_hide_16','1',0,''),(342384,109342,'116286','furniture','sort_hide_15','1',0,''),(342385,109342,'116286','furniture','sort_hide_3','0',0,''),(342386,109342,'116286','furniture','sort_hide_4','0',0,''),(342387,109342,'116286','furniture','sort_hide_11','1',0,''),(342388,109342,'116286','furniture','sort_hide_12','1',0,''),(342389,109342,'116286','furniture','sort_hide_14','1',0,''),(342390,109342,'116286','furniture','sort_hide_13','1',0,''),(342391,109342,'116286','furniture','sort_hide_8','0',0,''),(342392,109342,'116286','furniture','sort_hide_7','0',0,''),(342393,109342,'116286','furniture','sort_hide_2','1',0,''),(342394,109342,'116286','furniture','sort_hide_1','1',0,''),(342395,109342,'116286','furniture','sort_hide_6','1',0,''),(342396,109342,'116286','furniture','sort_hide_5','1',0,''),(342397,109342,'116286','furniture','sort_hide_0','0',0,''),(342398,109342,'116286','furniture','sort_pos_15','16',0,''),(342399,109342,'116286','furniture','sort_pos_16','17',0,''),(342400,109349,'116293','furniture','block_type','1',0,''),(342401,109351,'116295','furniture','block_type','6',0,''),(342402,109351,'116295','furniture','font-weight','400',0,''),(342403,109351,'116295','furniture','schema','6-2',0,'5161'),(342404,109351,'116295','furniture','schema','6-2',0,'5140'),(342405,109352,'116296','furniture','font-weight','400',0,''),(342406,109352,'116296','furniture','padding-right','40',0,''),(342407,109352,'116296','furniture','padding-right','0',0,'5161'),(342408,109352,'116296','furniture','padding-right','0',0,'5140'),(342409,109354,'116298','furniture','col_in_row','3',0,''),(342410,109354,'116298','furniture','products_align','left',0,''),(342411,109354,'116298','furniture','font-weight','400',0,''),(342412,109354,'116298','furniture','show_qty_input','0',0,''),(342413,109354,'116298','furniture','listing_type','productListing',0,''),(342414,109354,'116298','furniture','listing_type_rows','no',0,''),(342415,109354,'116298','furniture','show_buy_button_b2b','on',0,''),(342416,109354,'116298','furniture','show_wishlist_button_b2b','1',0,''),(342417,109354,'116298','furniture','show_compare_b2b','1',0,''),(342418,109354,'116298','furniture','show_stock','0',0,''),(342419,109354,'116298','furniture','show_description','0',0,''),(342420,109354,'116298','furniture','show_model','0',0,''),(342421,109354,'116298','furniture','show_properties','0',0,''),(342422,109354,'116298','furniture','show_rating','0',0,''),(342423,109354,'116298','furniture','show_rating_counts','0',0,''),(342424,109354,'116298','furniture','show_price','0',0,''),(342425,109354,'116298','furniture','show_buy_button','0',0,''),(342426,109354,'116298','furniture','show_view_button','0',0,''),(342427,109354,'116298','furniture','show_wishlist_button','0',0,''),(342428,109354,'116298','furniture','show_compare','0',0,''),(342429,109354,'116298','furniture','show_name_rows','0',0,''),(342430,109354,'116298','furniture','show_image_rows','0',0,''),(342431,109354,'116298','furniture','show_stock_rows','0',0,''),(342432,109354,'116298','furniture','show_description_rows','0',0,''),(342433,109354,'116298','furniture','show_model_rows','0',0,''),(342434,109354,'116298','furniture','show_properties_rows','0',0,''),(342435,109354,'116298','furniture','show_rating_rows','0',0,''),(342436,109354,'116298','furniture','show_rating_counts_rows','0',0,''),(342437,109354,'116298','furniture','show_price_rows','0',0,''),(342438,109354,'116298','furniture','show_buy_button_rows','0',0,''),(342439,109354,'116298','furniture','show_qty_input_rows','0',0,''),(342440,109354,'116298','furniture','show_view_button_rows','0',0,''),(342441,109354,'116298','furniture','show_wishlist_button_rows','0',0,''),(342442,109354,'116298','furniture','show_compare_rows','0',0,''),(342443,109354,'116298','furniture','show_name_b2b','0',0,''),(342444,109354,'116298','furniture','show_image_b2b','0',0,''),(342445,109354,'116298','furniture','show_stock_b2b','0',0,''),(342446,109354,'116298','furniture','show_description_b2b','0',0,''),(342447,109354,'116298','furniture','show_model_b2b','0',0,''),(342448,109354,'116298','furniture','show_properties_b2b','0',0,''),(342449,109354,'116298','furniture','show_rating_b2b','0',0,''),(342450,109354,'116298','furniture','show_rating_counts_b2b','0',0,''),(342451,109354,'116298','furniture','show_price_b2b','0',0,''),(342452,109354,'116298','furniture','show_qty_input_b2b','0',0,''),(342453,109354,'116298','furniture','show_view_button_b2b','0',0,''),(342454,109354,'116298','furniture','show_attributes_b2b','0',0,''),(342455,109354,'116298','furniture','items_on_page','9',0,''),(342456,109354,'116298','furniture','col_in_row','2',0,'5140'),(342457,109354,'116298','furniture','col_in_row','1',0,'5161'),(342458,109354,'116298','furniture','product_names_teg','h2',0,''),(342459,109355,'116299','furniture','block_type','1',0,''),(342460,109355,'116299','furniture','padding-top','10',0,''),(342461,109355,'116299','furniture','padding-bottom','10',0,''),(342462,109355,'116299','furniture','border-bottom-width','1',0,''),(342463,109355,'116299','furniture','border-bottom-color','$content-border-1',0,''),(342464,109355,'116299','furniture','margin-left','0',0,''),(342465,109355,'116299','furniture','margin-right','0',0,''),(342466,109356,'116300','furniture','float','left',0,''),(342467,109356,'116300','furniture','clear','none',0,''),(342468,109356,'116300','furniture','sort_pos_3','1',0,''),(342469,109356,'116300','furniture','sort_pos_4','2',0,''),(342470,109356,'116300','furniture','sort_pos_10','3',0,''),(342471,109356,'116300','furniture','sort_pos_9','4',0,''),(342472,109356,'116300','furniture','sort_pos_11','5',0,''),(342473,109356,'116300','furniture','sort_pos_12','6',0,''),(342474,109356,'116300','furniture','sort_pos_14','7',0,''),(342475,109356,'116300','furniture','sort_pos_13','8',0,''),(342476,109356,'116300','furniture','sort_pos_8','9',0,''),(342477,109356,'116300','furniture','sort_pos_7','10',0,''),(342478,109356,'116300','furniture','sort_pos_2','11',0,''),(342479,109356,'116300','furniture','sort_pos_1','12',0,''),(342480,109356,'116300','furniture','sort_pos_6','13',0,''),(342481,109356,'116300','furniture','sort_pos_5','14',0,''),(342482,109356,'116300','furniture','sort_pos_0','15',0,''),(342483,109356,'116300','furniture','sort_hide_10','1',0,''),(342484,109356,'116300','furniture','sort_hide_9','1',0,''),(342485,109356,'116300','furniture','hide_icons','1',0,''),(342486,109356,'116300','furniture','sort_hide_16','1',0,''),(342487,109356,'116300','furniture','sort_hide_15','1',0,''),(342488,109356,'116300','furniture','sort_hide_3','0',0,''),(342489,109356,'116300','furniture','sort_hide_4','0',0,''),(342490,109356,'116300','furniture','sort_hide_11','1',0,''),(342491,109356,'116300','furniture','sort_hide_12','1',0,''),(342492,109356,'116300','furniture','sort_hide_14','1',0,''),(342493,109356,'116300','furniture','sort_hide_13','1',0,''),(342494,109356,'116300','furniture','sort_hide_8','0',0,''),(342495,109356,'116300','furniture','sort_hide_7','0',0,''),(342496,109356,'116300','furniture','sort_hide_2','1',0,''),(342497,109356,'116300','furniture','sort_hide_1','1',0,''),(342498,109356,'116300','furniture','sort_hide_6','1',0,''),(342499,109356,'116300','furniture','sort_hide_5','1',0,''),(342500,109356,'116300','furniture','sort_hide_0','1',0,''),(342501,109357,'116301','furniture','float','left',0,''),(342502,109357,'116301','furniture','clear','none',0,''),(342503,109357,'116301','furniture','margin-left','20',0,''),(342504,109357,'116301','furniture','display','none',0,'5161'),(342505,109358,'116302','furniture','margin-right','20',0,''),(342506,109358,'116302','furniture','float','right',0,''),(342507,109358,'116302','furniture','clear','none',0,''),(342508,109358,'116302','furniture','display','none',0,'5140'),(342509,109359,'116303','furniture','float','right',0,''),(342510,109359,'116303','furniture','display','none',0,'5161'),(342511,109360,'116304','furniture','listing_type','productListing',0,''),(342512,109362,'116306','furniture','block_type','5',0,''),(342513,109362,'116306','furniture','padding-top','10',0,''),(342514,109362,'116306','furniture','padding-bottom','10',0,''),(342515,109362,'116306','furniture','schema','5-2',0,'5161'),(342516,109362,'116306','furniture','border-top-color','$content-border-1',0,''),(342517,109362,'116306','furniture','border-top-width','1',0,''),(342518,109364,'116308','furniture','float','right',0,''),(342519,109365,'116309','furniture','block_type','1',0,''),(342520,109368,'116312','furniture','block_type','1',0,''),(342521,109368,'116312','furniture','padding-top','10',0,''),(342522,109368,'116312','furniture','padding-bottom','10',0,''),(342523,109368,'116312','furniture','border-bottom-width','1',0,''),(342524,109368,'116312','furniture','border-bottom-color','$content-border-1',0,''),(342525,109368,'116312','furniture','margin-left','0',0,''),(342526,109368,'116312','furniture','margin-right','0',0,''),(342527,109369,'116313','furniture','float','left',0,''),(342528,109369,'116313','furniture','clear','none',0,''),(342529,109369,'116313','furniture','margin-left','20',0,''),(342530,109369,'116313','furniture','display','none',0,'5161'),(342531,109370,'116314','furniture','float','left',0,''),(342532,109370,'116314','furniture','clear','none',0,''),(342533,109370,'116314','furniture','sort_pos_3','2',0,''),(342534,109370,'116314','furniture','sort_pos_4','3',0,''),(342535,109370,'116314','furniture','sort_pos_10','11',0,''),(342536,109370,'116314','furniture','sort_pos_9','10',0,''),(342537,109370,'116314','furniture','sort_pos_11','12',0,''),(342538,109370,'116314','furniture','sort_pos_12','13',0,''),(342539,109370,'116314','furniture','sort_pos_14','15',0,''),(342540,109370,'116314','furniture','sort_pos_13','14',0,''),(342541,109370,'116314','furniture','sort_pos_8','4',0,''),(342542,109370,'116314','furniture','sort_pos_7','5',0,''),(342543,109370,'116314','furniture','sort_pos_2','7',0,''),(342544,109370,'116314','furniture','sort_pos_1','6',0,''),(342545,109370,'116314','furniture','sort_pos_6','9',0,''),(342546,109370,'116314','furniture','sort_pos_5','8',0,''),(342547,109370,'116314','furniture','sort_pos_0','1',0,''),(342548,109370,'116314','furniture','sort_hide_10','1',0,''),(342549,109370,'116314','furniture','sort_hide_9','1',0,''),(342550,109370,'116314','furniture','hide_icons','1',0,''),(342551,109370,'116314','furniture','sort_hide_16','1',0,''),(342552,109370,'116314','furniture','sort_hide_15','1',0,''),(342553,109370,'116314','furniture','sort_hide_3','0',0,''),(342554,109370,'116314','furniture','sort_hide_4','0',0,''),(342555,109370,'116314','furniture','sort_hide_11','1',0,''),(342556,109370,'116314','furniture','sort_hide_12','1',0,''),(342557,109370,'116314','furniture','sort_hide_14','1',0,''),(342558,109370,'116314','furniture','sort_hide_13','1',0,''),(342559,109370,'116314','furniture','sort_hide_8','0',0,''),(342560,109370,'116314','furniture','sort_hide_7','0',0,''),(342561,109370,'116314','furniture','sort_hide_2','1',0,''),(342562,109370,'116314','furniture','sort_hide_1','1',0,''),(342563,109370,'116314','furniture','sort_hide_6','1',0,''),(342564,109370,'116314','furniture','sort_hide_5','1',0,''),(342565,109370,'116314','furniture','sort_hide_0','0',0,''),(342566,109370,'116314','furniture','sort_pos_15','16',0,''),(342567,109370,'116314','furniture','sort_pos_16','17',0,''),(342568,109371,'116315','furniture','margin-right','20',0,''),(342569,109371,'116315','furniture','float','right',0,''),(342570,109371,'116315','furniture','clear','none',0,''),(342571,109371,'116315','furniture','display','none',0,'5140'),(342572,109372,'116316','furniture','float','right',0,''),(342573,109372,'116316','furniture','display','none',0,'5161'),(342574,109373,'116317','furniture','clear','none',0,''),(342575,109373,'116317','furniture','float','left',0,''),(342576,109373,'116317','furniture','padding-top','3',0,''),(342577,109373,'116317','furniture','padding-left','20',0,''),(342578,109374,'116318','furniture','block_type','5',0,''),(342579,109374,'116318','furniture','padding-top','10',0,''),(342580,109374,'116318','furniture','padding-bottom','10',0,''),(342581,109374,'116318','furniture','schema','5-2',0,'5161'),(342582,109374,'116318','furniture','border-top-color','$content-border-1',0,''),(342583,109374,'116318','furniture','border-top-width','1',0,''),(342584,109376,'116320','furniture','float','right',0,''),(342585,109377,'116321','furniture','col_in_row','4',0,''),(342586,109377,'116321','furniture','products_align','left',0,''),(342587,109377,'116321','furniture','font-weight','400',0,''),(342588,109377,'116321','furniture','show_qty_input','0',0,''),(342589,109377,'116321','furniture','listing_type','productListing',0,''),(342590,109377,'116321','furniture','listing_type_rows','Rows',0,''),(342591,109377,'116321','furniture','show_buy_button_b2b','on',0,''),(342592,109377,'116321','furniture','show_wishlist_button_b2b','1',0,''),(342593,109377,'116321','furniture','show_compare_b2b','1',0,''),(342594,109377,'116321','furniture','listing_type_b2b','b2b',0,''),(342595,109377,'116321','furniture','show_image','0',0,''),(342596,109377,'116321','furniture','show_stock','0',0,''),(342597,109377,'116321','furniture','show_description','0',0,''),(342598,109377,'116321','furniture','show_model','0',0,''),(342599,109377,'116321','furniture','show_properties','0',0,''),(342600,109377,'116321','furniture','show_rating','0',0,''),(342601,109377,'116321','furniture','show_rating_counts','0',0,''),(342602,109377,'116321','furniture','show_price','0',0,''),(342603,109377,'116321','furniture','show_buy_button','0',0,''),(342604,109377,'116321','furniture','show_view_button','0',0,''),(342605,109377,'116321','furniture','show_wishlist_button','0',0,''),(342606,109377,'116321','furniture','show_compare','0',0,''),(342607,109377,'116321','furniture','show_name_rows','0',0,''),(342608,109377,'116321','furniture','show_image_rows','0',0,''),(342609,109377,'116321','furniture','show_stock_rows','0',0,''),(342610,109377,'116321','furniture','show_description_rows','0',0,''),(342611,109377,'116321','furniture','show_model_rows','0',0,''),(342612,109377,'116321','furniture','show_properties_rows','0',0,''),(342613,109377,'116321','furniture','show_rating_rows','0',0,''),(342614,109377,'116321','furniture','show_rating_counts_rows','0',0,''),(342615,109377,'116321','furniture','show_price_rows','0',0,''),(342616,109377,'116321','furniture','show_buy_button_rows','0',0,''),(342617,109377,'116321','furniture','show_qty_input_rows','0',0,''),(342618,109377,'116321','furniture','show_view_button_rows','0',0,''),(342619,109377,'116321','furniture','show_wishlist_button_rows','0',0,''),(342620,109377,'116321','furniture','show_compare_rows','0',0,''),(342621,109377,'116321','furniture','show_name_b2b','0',0,''),(342622,109377,'116321','furniture','show_image_b2b','0',0,''),(342623,109377,'116321','furniture','show_stock_b2b','0',0,''),(342624,109377,'116321','furniture','show_description_b2b','0',0,''),(342625,109377,'116321','furniture','show_model_b2b','0',0,''),(342626,109377,'116321','furniture','show_properties_b2b','0',0,''),(342627,109377,'116321','furniture','show_rating_b2b','0',0,''),(342628,109377,'116321','furniture','show_rating_counts_b2b','0',0,''),(342629,109377,'116321','furniture','show_price_b2b','0',0,''),(342630,109377,'116321','furniture','show_qty_input_b2b','0',0,''),(342631,109377,'116321','furniture','show_view_button_b2b','0',0,''),(342632,109377,'116321','furniture','show_attributes_b2b','0',0,''),(342633,109377,'116321','furniture','items_on_page','12',0,''),(342634,109377,'116321','furniture','col_in_row','2',0,'5140'),(342635,109377,'116321','furniture','col_in_row','1',0,'5161'),(342636,109377,'116321','furniture','product_names_teg','h2',0,''),(342637,109380,'1693847444.869439','furniture','block_type','1',0,''),(342638,109380,'1693847444.869439','furniture','background-color','$content-bg-2',0,''),(342639,109380,'1693847444.869439','furniture','padding-top','30',0,''),(342640,109380,'1693847444.869439','furniture','padding-bottom','30',0,''),(342641,109380,'1693847444.869439','furniture','style_class','checkout-index-wrap',0,''),(342642,109380,'1693847444.869439','furniture','color','$content-color-2',0,''),(342643,109381,'1693847444.885847','furniture','block_type','7',0,''),(342644,109381,'1693847444.885847','furniture','schema','4-2',0,'5140'),(342645,109382,'1693847444.888529','furniture','block_type','1',0,''),(342646,109382,'1693847444.888529','furniture','padding-right','0',0,'5140'),(342647,109383,'1693847444.8951','furniture','block_type','1',0,''),(342648,109383,'1693847444.8951','furniture','background-color','$content-bg-1',0,''),(342649,109383,'1693847444.8951','furniture','padding-top','20',0,''),(342650,109383,'1693847444.8951','furniture','padding-left','30',0,''),(342651,109383,'1693847444.8951','furniture','padding-right','30',0,''),(342652,109383,'1693847444.8951','furniture','padding-bottom','14',0,''),(342653,109383,'1693847444.8951','furniture','margin-bottom','20',0,''),(342654,109383,'1693847444.8951','furniture','style_class','hiding-box closeable-box',0,''),(342655,109383,'1693847444.8951','furniture','color','$content-color-1',0,''),(342656,109384,'1693847444.891978','furniture','style_class','closeable-content',0,''),(342657,109384,'1693847444.891978','furniture','padding-bottom','20',0,''),(342658,109385,'1693847444.893451','furniture','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(342659,109385,'1693847444.893451','furniture','style_class','closeable-heading closeable-event closed',0,''),(342660,109386,'1693847444.898927','furniture','block_type','1',0,''),(342661,109386,'1693847444.898927','furniture','padding-top','30',0,''),(342662,109386,'1693847444.898927','furniture','padding-left','30',0,''),(342663,109386,'1693847444.898927','furniture','padding-right','30',0,''),(342664,109386,'1693847444.898927','furniture','padding-bottom','14',0,''),(342665,109386,'1693847444.898927','furniture','background-color','$content-bg-1',0,''),(342666,109386,'1693847444.898927','furniture','style_class','hiding-box closeable-box',0,''),(342667,109386,'1693847444.898927','furniture','margin-bottom','20',0,''),(342668,109386,'1693847444.898927','furniture','color','$content-color-1',0,''),(342669,109387,'1693847444.90129','furniture','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(342670,109387,'1693847444.90129','furniture','style_class','closeable-heading closeable-event closed',0,''),(342671,109388,'1693847444.902745','furniture','block_type','2',0,''),(342672,109388,'1693847444.902745','furniture','style_class','closeable-content',0,''),(342673,109388,'1693847444.902745','furniture','schema','2-2',0,'5140'),(342674,109389,'1693847444.904471','furniture','padding-right','20',0,''),(342675,109389,'1693847444.904471','furniture','padding-bottom','20',0,''),(342676,109389,'1693847444.904471','furniture','padding-right','0',0,'5140'),(342677,109390,'1693847444.906639','furniture','padding-left','20',0,''),(342678,109390,'1693847444.906639','furniture','padding-bottom','20',0,''),(342679,109390,'1693847444.906639','furniture','padding-left','0',0,'5140'),(342680,109391,'1693847444.908631','furniture','padding-left','20',0,''),(342681,109391,'1693847444.908631','furniture','padding-bottom','20',0,''),(342682,109391,'1693847444.908631','furniture','padding-left','0',0,'5140'),(342683,109392,'1693847444.910474','furniture','background-color','$content-bg-1',0,''),(342684,109392,'1693847444.910474','furniture','block_type','1',0,''),(342685,109392,'1693847444.910474','furniture','padding-top','30',0,''),(342686,109392,'1693847444.910474','furniture','padding-left','30',0,''),(342687,109392,'1693847444.910474','furniture','padding-right','30',0,''),(342688,109392,'1693847444.910474','furniture','padding-bottom','30',0,''),(342689,109392,'1693847444.910474','furniture','margin-bottom','20',0,''),(342690,109392,'1693847444.910474','furniture','style_class','hiding-box',0,''),(342691,109392,'1693847444.910474','furniture','color','$content-color-1',0,''),(342692,109393,'1693847444.912443','furniture','block_type','1',0,''),(342693,109393,'1693847444.912443','furniture','content','\\_',0,'3'),(342694,109393,'1693847444.912443','furniture','border-top-width','1',0,'3'),(342695,109393,'1693847444.912443','furniture','border-top-color','$content-border-2',0,'3'),(342696,109393,'1693847444.912443','furniture','display','block',0,'3'),(342697,109393,'1693847444.912443','furniture','position','absolute',0,'3'),(342698,109393,'1693847444.912443','furniture','top','19',0,'3'),(342699,109393,'1693847444.912443','furniture','left','0',0,'3'),(342700,109393,'1693847444.912443','furniture','right','0',0,'3'),(342701,109393,'1693847444.912443','furniture','margin-top','-2',0,'3'),(342702,109393,'1693847444.912443','furniture','position','relative',0,''),(342703,109394,'1693847444.914967','furniture','box_align','2',0,''),(342704,109394,'1693847444.914967','furniture','margin-bottom','10',0,''),(342705,109394,'1693847444.914967','furniture','background-color','$content-bg-1',0,''),(342706,109394,'1693847444.914967','furniture','position','relative',0,''),(342707,109395,'1693847444.921382','furniture','background-color','$content-bg-2',0,''),(342708,109395,'1693847444.921382','furniture','padding-top','10',0,''),(342709,109395,'1693847444.921382','furniture','padding-left','10',0,''),(342710,109395,'1693847444.921382','furniture','padding-right','10',0,''),(342711,109395,'1693847444.921382','furniture','padding-bottom','10',0,''),(342712,109395,'1693847444.921382','furniture','margin-top','10',0,''),(342713,109396,'1693847444.923161','furniture','block_type','2',0,''),(342714,109396,'1693847444.923161','furniture','schema','2-2',0,'5140'),(342715,109397,'1693847444.924488','furniture','block_type','1',0,''),(342716,109397,'1693847444.924488','furniture','padding-right','20',0,''),(342717,109397,'1693847444.924488','furniture','padding-left','0',0,'5140'),(342718,109397,'1693847444.924488','furniture','margin-bottom','20',0,'5140'),(342719,109397,'1693847444.924488','furniture','padding-right','0',0,'5140'),(342720,109398,'1693847444.926170','furniture','address_in','popup',0,''),(342721,109399,'1693847444.928743','furniture','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(342722,109402,'1693847444.934659','furniture','block_type','1',0,''),(342723,109402,'1693847444.934659','furniture','padding-left','20',0,''),(342724,109402,'1693847444.934659','furniture','padding-left','0',0,'5140'),(342725,109404,'1693847444.9487','furniture','border-top-width','1',0,''),(342726,109404,'1693847444.9487','furniture','border-top-color','$content-border-2',0,''),(342727,109404,'1693847444.9487','furniture','padding-top','13',0,''),(342728,109404,'1693847444.9487','furniture','padding-bottom','10',0,''),(342729,109405,'1693847444.942192','furniture','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(342730,109406,'1693847444.946113','furniture','show_day','next_day',0,''),(342731,109408,'1693847444.95160','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(342732,109409,'1693847444.954571','furniture','block_type','1',0,''),(342733,109409,'1693847444.954571','furniture','padding-left','30',0,''),(342734,109409,'1693847444.954571','furniture','padding-right','30',0,''),(342735,109409,'1693847444.954571','furniture','padding-bottom','30',0,''),(342736,109409,'1693847444.954571','furniture','margin-bottom','20',0,''),(342737,109409,'1693847444.954571','furniture','style_class','hiding-box',0,''),(342738,109409,'1693847444.954571','furniture','background-color','$content-bg-1',0,''),(342739,109409,'1693847444.954571','furniture','color','$content-color-1',0,''),(342740,109410,'1693847444.956524','furniture','margin-bottom','20',0,''),(342741,109411,'1693847444.960635','furniture','padding-top','10',0,''),(342742,109411,'1693847444.960635','furniture','padding-left','20',0,''),(342743,109411,'1693847444.960635','furniture','padding-right','20',0,''),(342744,109411,'1693847444.960635','furniture','margin-top','20',0,''),(342745,109411,'1693847444.960635','furniture','padding-bottom','8',0,''),(342746,109413,'1693847444.965195','furniture','block_type','1',0,''),(342747,109413,'1693847444.965195','furniture','padding-top','30',0,''),(342748,109413,'1693847444.965195','furniture','padding-left','30',0,''),(342749,109413,'1693847444.965195','furniture','padding-right','30',0,''),(342750,109413,'1693847444.965195','furniture','padding-bottom','23',0,''),(342751,109413,'1693847444.965195','furniture','margin-bottom','20',0,''),(342752,109413,'1693847444.965195','furniture','background-color','$content-bg-1',0,''),(342753,109413,'1693847444.965195','furniture','style_class','hiding-box',0,''),(342754,109414,'1693847444.967253','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(342755,109415,'1693847444.96852','furniture','block_type','2',0,''),(342756,109415,'1693847444.96852','furniture','schema','2-2',0,'5140'),(342757,109416,'1693847444.969566','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(342758,109417,'1693847444.97077','furniture','padding-right','20',0,''),(342759,109417,'1693847444.97077','furniture','padding-right','0',0,'5140'),(342760,109417,'1693847444.97077','furniture','padding-bottom','20',0,'5140'),(342761,109417,'1693847444.97077','furniture','address_in','popup',0,''),(342762,109418,'1693847444.97415','furniture','block_type','1',0,''),(342763,109418,'1693847444.97415','furniture','padding-left','20',0,''),(342764,109418,'1693847444.97415','furniture','padding-left','0',0,'5140'),(342765,109420,'1693847444.97623','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(342766,109421,'1693847444.977354','furniture','block_type','1',0,''),(342767,109421,'1693847444.977354','furniture','background-color','$content-bg-1',0,''),(342768,109421,'1693847444.977354','furniture','padding-top','20',0,''),(342769,109421,'1693847444.977354','furniture','padding-left','30',0,''),(342770,109421,'1693847444.977354','furniture','padding-right','30',0,''),(342771,109421,'1693847444.977354','furniture','padding-bottom','20',0,''),(342772,109421,'1693847444.977354','furniture','margin-bottom','20',0,''),(342773,109421,'1693847444.977354','furniture','color','$content-color-1',0,''),(342774,109423,'1693847444.979723','furniture','block_type','1',0,''),(342775,109423,'1693847444.979723','furniture','padding-top','10',0,''),(342776,109423,'1693847444.979723','furniture','padding-left','10',0,''),(342777,109423,'1693847444.979723','furniture','padding-right','10',0,''),(342778,109423,'1693847444.979723','furniture','padding-bottom','10',0,''),(342779,109423,'1693847444.979723','furniture','background-color','$content-bg-1',0,''),(342780,109423,'1693847444.979723','furniture','style_class','order-summary',0,''),(342781,109423,'1693847444.979723','furniture','margin-left','25',0,''),(342782,109423,'1693847444.979723','furniture','margin-left','0',0,'5140'),(342783,109423,'1693847444.979723','furniture','color','$content-color-1',0,''),(342784,109424,'1693847444.98495','furniture','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(342785,109424,'1693847444.98495','furniture','text-align','center',0,''),(342786,109424,'1693847444.98495','furniture','font-size','14',0,''),(342787,109424,'1693847444.98495','furniture','color','$content-color-1',0,''),(342788,109424,'1693847444.98495','furniture','padding-top','10',0,''),(342789,109425,'1693847444.986544','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(342790,109426,'1693847444.987613','furniture','hide_page','1',0,''),(342791,109426,'1693847444.987613','furniture','hide_continue_button','1',0,''),(342792,109427,'1693847444.988926','furniture','margin-bottom','10',0,''),(342793,109429,'116368','furniture','block_type','1',0,''),(342794,109431,'116370','furniture','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(342795,109432,'116371','furniture','link','products',0,''),(342796,109432,'116371','furniture','margin-top','-33',0,''),(342797,109432,'116371','furniture','float','right',0,''),(342798,109433,'116372','furniture','block_type','2',0,''),(342799,109433,'116372','furniture','margin-bottom','20',0,''),(342800,109433,'116372','furniture','schema','2-2',0,'5131'),(342801,109434,'116373','furniture','block_type','1',0,''),(342802,109434,'116373','furniture','padding-right','20',0,''),(342803,109434,'116373','furniture','padding-right','0',0,'5131'),(342804,109435,'116374','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(342805,109435,'116374','furniture','clear','none',0,''),(342806,109437,'116376','furniture','padding-left','20',0,''),(342807,109437,'116376','furniture','block_type','1',0,''),(342808,109437,'116376','furniture','padding-left','0',0,'5131'),(342809,109439,'116378','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(342810,109439,'116378','furniture','clear','none',0,''),(342811,109440,'116380','furniture','block_type','2',0,''),(342812,109440,'116380','furniture','margin-bottom','20',0,''),(342813,109440,'116380','furniture','schema','2-2',0,'5131'),(342814,109441,'116381','furniture','block_type','1',0,''),(342815,109441,'116381','furniture','padding-right','20',0,''),(342816,109441,'116381','furniture','padding-right','0',0,'5131'),(342817,109443,'116383','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(342818,109443,'116383','furniture','clear','none',0,''),(342819,109444,'116384','furniture','block_type','1',0,''),(342820,109444,'116384','furniture','padding-left','20',0,''),(342821,109444,'116384','furniture','padding-left','0',0,'5131'),(342822,109445,'116385','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(342823,109445,'116385','furniture','clear','none',0,''),(342824,109447,'116387','furniture','margin-bottom','20',0,''),(342825,109447,'116387','furniture','text-align','right',0,''),(342826,109449,'116379','furniture','text-align','right',0,''),(342827,109449,'116379','furniture','margin-bottom','20',0,''),(342828,109449,'116379','furniture','margin-top','20',0,''),(342829,109450,'116402','furniture','block_type','1',0,''),(342830,109451,'116403','furniture','text-align','right',0,''),(342831,109451,'116403','furniture','margin-bottom','20',0,''),(342832,109452,'116404','furniture','block_type','2',0,''),(342833,109452,'116404','furniture','margin-bottom','20',0,''),(342834,109452,'116404','furniture','schema','2-2',0,'5131'),(342835,109453,'116405','furniture','block_type','1',0,''),(342836,109453,'116405','furniture','padding-right','20',0,''),(342837,109453,'116405','furniture','padding-right','0',0,'5131'),(342838,109454,'116406','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(342839,109454,'116406','furniture','clear','none',0,''),(342840,109456,'116408','furniture','block_type','1',0,''),(342841,109456,'116408','furniture','padding-left','20',0,''),(342842,109456,'116408','furniture','padding-left','0',0,'5131'),(342843,109457,'116409','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(342844,109457,'116409','furniture','clear','none',0,''),(342845,109459,'116411','furniture','margin-bottom','20',0,''),(342846,109459,'116411','furniture','text-align','right',0,''),(342847,109462,'116414','furniture','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(342848,109463,'116389','furniture','block_type','1',0,''),(342849,109464,'116390','furniture','margin-bottom','20',0,''),(342850,109465,'116391','furniture','margin-bottom','20',0,''),(342851,109465,'116391','furniture','text-align','right',0,''),(342852,109466,'116392','furniture','text-align','right',0,''),(342853,109466,'116392','furniture','margin-bottom','20',0,''),(342854,109467,'116393','furniture','block_type','2',0,''),(342855,109467,'116393','furniture','margin-bottom','20',0,''),(342856,109467,'116393','furniture','schema','2-2',0,'5131'),(342857,109468,'116394','furniture','block_type','1',0,''),(342858,109468,'116394','furniture','padding-right','20',0,''),(342859,109468,'116394','furniture','padding-right','0',0,'5131'),(342860,109470,'116396','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(342861,109470,'116396','furniture','clear','none',0,''),(342862,109471,'116397','furniture','block_type','1',0,''),(342863,109471,'116397','furniture','padding-left','20',0,''),(342864,109471,'116397','furniture','padding-left','0',0,'5131'),(342865,109473,'116399','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(342866,109473,'116399','furniture','clear','none',0,''),(342867,109474,'116400','furniture','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(342868,109475,'116401','furniture','margin-bottom','20',0,''),(342869,109476,'116415','furniture','block_type','1',0,''),(342870,109477,'116416','furniture','block_type','2',0,''),(342871,109477,'116416','furniture','margin-bottom','20',0,''),(342872,109477,'116416','furniture','schema','2-2',0,'5131'),(342873,109478,'116417','furniture','block_type','1',0,''),(342874,109478,'116417','furniture','padding-right','20',0,''),(342875,109478,'116417','furniture','padding-right','0',0,'5131'),(342876,109480,'116419','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(342877,109480,'116419','furniture','clear','none',0,''),(342878,109481,'116420','furniture','block_type','1',0,''),(342879,109481,'116420','furniture','padding-left','20',0,''),(342880,109481,'116420','furniture','padding-left','0',0,'5131'),(342881,109483,'116422','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(342882,109483,'116422','furniture','clear','none',0,''),(342883,109484,'116423','furniture','margin-bottom','20',0,''),(342884,109485,'116424','furniture','margin-bottom','20',0,''),(342885,109486,'116425','furniture','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(342886,109487,'116426','furniture','link','products',0,''),(342887,109487,'116426','furniture','margin-top','-33',0,''),(342888,109487,'116426','furniture','float','right',0,''),(342889,109488,'116427','furniture','text-align','right',0,''),(342890,109488,'116427','furniture','margin-bottom','20',0,''),(342891,109489,'116428','furniture','margin-bottom','20',0,''),(342892,109489,'116428','furniture','text-align','right',0,''),(342893,109490,'116429','furniture','block_type','2',0,''),(342894,109490,'116429','furniture','margin-bottom','20',0,''),(342895,109490,'116429','furniture','schema','2-2',0,'5131'),(342896,109491,'116430','furniture','block_type','1',0,''),(342897,109491,'116430','furniture','padding-right','20',0,''),(342898,109491,'116430','furniture','padding-right','0',0,'5131'),(342899,109492,'116431','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(342900,109492,'116431','furniture','clear','none',0,''),(342901,109494,'116433','furniture','padding-left','20',0,''),(342902,109494,'116433','furniture','block_type','1',0,''),(342903,109494,'116433','furniture','padding-left','0',0,'5131'),(342904,109495,'116434','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(342905,109495,'116434','furniture','clear','none',0,''),(342906,109497,'116436','furniture','text','##TEXT_CONFIRMATION##',0,''),(342907,109498,'116437','furniture','text','##TEXT_CONFIRMATION##',0,''),(342908,109499,'116439','furniture','text','##TEXT_CONFIRMATION##',0,''),(342909,109500,'116438','furniture','text','##TEXT_CONFIRMATION##',0,''),(342910,109501,'116440','furniture','text','##TEXT_CONFIRMATION##',0,''),(342911,109502,'116441','furniture','text','##TEXT_CONFIRMATION##',0,''),(342912,109503,'116442','furniture','block_type','2',0,''),(342913,109504,'116443','furniture','block_type','1',0,''),(342914,109504,'116443','furniture','padding-right','20',0,''),(342915,109505,'116444','furniture','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(342916,109507,'116446','furniture','block_type','1',0,''),(342917,109507,'116446','furniture','padding-left','20',0,''),(342918,109507,'116446','furniture','padding-left','0',0,'5140'),(342919,109508,'116447','furniture','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(342920,109510,'116449','furniture','block_type','4',0,''),(342921,109510,'116449','furniture','schema','4-2',0,'5161'),(342922,109510,'116449','furniture','padding-top','20',0,''),(342923,109511,'116450','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(342924,109511,'116450','furniture','text-align','right',0,''),(342925,109511,'116450','furniture','padding-top','10',0,''),(342926,109511,'116450','furniture','font_size_measure','em',0,''),(342927,109511,'116450','furniture','font-size','1.2',0,''),(342928,109512,'116451','furniture','text-align','right',0,''),(342929,109513,'116452','furniture','block_type','2',0,''),(342930,109514,'116453','furniture','block_type','1',0,''),(342931,109514,'116453','furniture','padding-right','20',0,''),(342932,109514,'116453','furniture','padding-right','0',0,'5140'),(342933,109516,'116456','furniture','block_type','1',0,''),(342934,109516,'116456','furniture','padding-right','0',0,'5140'),(342935,109516,'116456','furniture','padding-left','20',0,''),(342936,109519,'116459','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(342937,109521,'116461','furniture','block_type','2',0,''),(342938,109522,'116462','furniture','block_type','1',0,''),(342939,109522,'116462','furniture','padding-right','20',0,''),(342940,109524,'116464','furniture','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(342941,109525,'116465','furniture','block_type','1',0,''),(342942,109525,'116465','furniture','padding-left','20',0,''),(342943,109525,'116465','furniture','padding-left','0',0,'5140'),(342944,109526,'116466','furniture','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(342945,109528,'116468','furniture','block_type','4',0,''),(342946,109528,'116468','furniture','schema','4-2',0,'5161'),(342947,109529,'116469','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(342948,109529,'116469','furniture','text-align','right',0,''),(342949,109529,'116469','furniture','padding-top','10',0,''),(342950,109529,'116469','furniture','font_size_measure','em',0,''),(342951,109529,'116469','furniture','font-size','1.2',0,''),(342952,109530,'116470','furniture','text-align','right',0,''),(342953,109531,'116471','furniture','block_type','2',0,''),(342954,109532,'116472','furniture','block_type','1',0,''),(342955,109532,'116472','furniture','padding-right','20',0,''),(342956,109532,'116472','furniture','padding-right','0',0,'5140'),(342957,109534,'116474','furniture','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(342958,109535,'116475','furniture','block_type','1',0,''),(342959,109535,'116475','furniture','padding-right','0',0,'5140'),(342960,109535,'116475','furniture','padding-left','20',0,''),(342961,109537,'116477','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(342962,109540,'116480','furniture','block_type','4',0,''),(342963,109540,'116480','furniture','schema','4-2',0,'5161'),(342964,109541,'116481','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(342965,109541,'116481','furniture','text-align','right',0,''),(342966,109541,'116481','furniture','padding-top','10',0,''),(342967,109541,'116481','furniture','font_size_measure','em',0,''),(342968,109541,'116481','furniture','font-size','1.2',0,''),(342969,109542,'116482','furniture','text-align','right',0,''),(342970,109543,'116483','furniture','block_type','2',0,''),(342971,109544,'116484','furniture','block_type','1',0,''),(342972,109544,'116484','furniture','padding-right','20',0,''),(342973,109546,'116486','furniture','block_type','1',0,''),(342974,109546,'116486','furniture','padding-left','20',0,''),(342975,109546,'116486','furniture','padding-left','0',0,'5140'),(342976,109547,'116487','furniture','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(342977,109549,'116489','furniture','block_type','4',0,''),(342978,109549,'116489','furniture','schema','4-2',0,'5161'),(342979,109550,'116490','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(342980,109550,'116490','furniture','text-align','right',0,''),(342981,109550,'116490','furniture','padding-top','10',0,''),(342982,109550,'116490','furniture','font_size_measure','em',0,''),(342983,109550,'116490','furniture','font-size','1.2',0,''),(342984,109551,'116491','furniture','text-align','right',0,''),(342985,109552,'116492','furniture','block_type','2',0,''),(342986,109553,'116493','furniture','block_type','1',0,''),(342987,109553,'116493','furniture','padding-right','20',0,''),(342988,109555,'116495','furniture','block_type','1',0,''),(342989,109555,'116495','furniture','padding-left','20',0,''),(342990,109555,'116495','furniture','padding-left','0',0,'5140'),(342991,109557,'116497','furniture','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(342992,109558,'116498','furniture','text','##DELIVERY_DETAILS##',0,''),(342993,109559,'116499','furniture','text','##DELIVERY_DETAILS##',0,''),(342994,109560,'116501','furniture','text','##CONTACT_INFORMATION##',0,''),(342995,109561,'116500','furniture','text','##CONTACT_INFORMATION##',0,''),(342996,109562,'116502','furniture','text','##DELIVERY_DETAILS##',0,''),(342997,109563,'116503','furniture','text','##DELIVERY_DETAILS##',0,''),(342998,109564,'116504','furniture','block_type','1',0,''),(342999,109564,'116504','furniture','background-color','$content-bg-2',0,''),(343000,109564,'116504','furniture','padding-top','30',0,''),(343001,109564,'116504','furniture','padding-bottom','30',0,''),(343002,109565,'116505','furniture','block_type','7',0,''),(343003,109565,'116505','furniture','schema','4-2',0,'5140'),(343004,109566,'116506','furniture','block_type','1',0,''),(343005,109566,'116506','furniture','padding-right','0',0,'5140'),(343006,109567,'116508','furniture','block_type','1',0,''),(343007,109567,'116508','furniture','background-color','$content-bg-1',0,''),(343008,109567,'116508','furniture','padding-top','30',0,''),(343009,109567,'116508','furniture','padding-left','30',0,''),(343010,109567,'116508','furniture','padding-right','30',0,''),(343011,109567,'116508','furniture','padding-bottom','30',0,''),(343012,109567,'116508','furniture','margin-bottom','20',0,''),(343013,109567,'116508','furniture','style_class','hiding-box',0,''),(343014,109568,'116509','furniture','margin-bottom','20',0,''),(343015,109569,'116510','furniture','padding-top','10',0,''),(343016,109569,'116510','furniture','padding-left','20',0,''),(343017,109569,'116510','furniture','padding-right','20',0,''),(343018,109569,'116510','furniture','margin-top','20',0,''),(343019,109569,'116510','furniture','background-color','$content-bg-2',0,''),(343020,109569,'116510','furniture','padding-bottom','8',0,''),(343021,109570,'116511','furniture','block_type','1',0,''),(343022,109570,'116511','furniture','background-color','$content-bg-1',0,''),(343023,109570,'116511','furniture','padding-top','30',0,''),(343024,109570,'116511','furniture','padding-left','30',0,''),(343025,109570,'116511','furniture','padding-right','30',0,''),(343026,109570,'116511','furniture','padding-bottom','14',0,''),(343027,109570,'116511','furniture','margin-bottom','20',0,''),(343028,109570,'116511','furniture','style_class','hiding-box closeable-box',0,''),(343029,109571,'116512','furniture','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(343030,109571,'116512','furniture','style_class','closeable-heading closeable-event closed',0,''),(343031,109572,'116513','furniture','style_class','closeable-content',0,''),(343032,109572,'116513','furniture','padding-bottom','20',0,''),(343033,109573,'116514','furniture','background-color','$content-bg-1',0,''),(343034,109573,'116514','furniture','block_type','1',0,''),(343035,109573,'116514','furniture','padding-top','30',0,''),(343036,109573,'116514','furniture','padding-left','30',0,''),(343037,109573,'116514','furniture','padding-right','30',0,''),(343038,109573,'116514','furniture','padding-bottom','30',0,''),(343039,109573,'116514','furniture','margin-bottom','20',0,''),(343040,109573,'116514','furniture','style_class','hiding-box',0,''),(343041,109574,'116515','furniture','block_type','1',0,''),(343042,109574,'116515','furniture','content','\\_',0,'3'),(343043,109574,'116515','furniture','border-top-width','1',0,'3'),(343044,109574,'116515','furniture','border-top-color','$content-border-1',0,'3'),(343045,109574,'116515','furniture','display','block',0,'3'),(343046,109574,'116515','furniture','position','absolute',0,'3'),(343047,109574,'116515','furniture','top','19',0,'3'),(343048,109574,'116515','furniture','left','0',0,'3'),(343049,109574,'116515','furniture','right','0',0,'3'),(343050,109574,'116515','furniture','margin-top','-2',0,'3'),(343051,109574,'116515','furniture','position','relative',0,''),(343052,109575,'116516','furniture','box_align','2',0,''),(343053,109575,'116516','furniture','margin-bottom','10',0,''),(343054,109575,'116516','furniture','background-color','$content-bg-1',0,''),(343055,109575,'116516','furniture','position','relative',0,''),(343056,109576,'116517','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(343057,109577,'116518','furniture','block_type','2',0,''),(343058,109577,'116518','furniture','schema','2-2',0,'5140'),(343059,109578,'116519','furniture','block_type','1',0,''),(343060,109578,'116519','furniture','padding-right','20',0,''),(343061,109578,'116519','furniture','padding-left','0',0,'5140'),(343062,109578,'116519','furniture','margin-bottom','20',0,'5140'),(343063,109578,'116519','furniture','padding-right','0',0,'5140'),(343064,109581,'116522','furniture','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(343065,109582,'116523','furniture','block_type','1',0,''),(343066,109582,'116523','furniture','padding-left','20',0,''),(343067,109582,'116523','furniture','padding-left','0',0,'5140'),(343068,109583,'116524','furniture','padding-bottom','10',0,''),(343069,109584,'116525','furniture','background-color','$content-bg-2',0,''),(343070,109584,'116525','furniture','padding-top','10',0,''),(343071,109584,'116525','furniture','padding-left','10',0,''),(343072,109584,'116525','furniture','padding-right','10',0,''),(343073,109584,'116525','furniture','padding-bottom','10',0,''),(343074,109584,'116525','furniture','margin-top','10',0,''),(343075,109585,'116526','furniture','block_type','1',0,''),(343076,109585,'116526','furniture','padding-top','10',0,''),(343077,109585,'116526','furniture','padding-left','10',0,''),(343078,109585,'116526','furniture','padding-right','10',0,''),(343079,109585,'116526','furniture','padding-bottom','10',0,''),(343080,109585,'116526','furniture','background-color','$content-bg-1',0,''),(343081,109585,'116526','furniture','style_class','order-summary',0,''),(343082,109585,'116526','furniture','margin-left','25',0,''),(343083,109585,'116526','furniture','margin-left','0',0,'5140'),(343084,109586,'116527','furniture','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(343085,109586,'116527','furniture','text-align','center',0,''),(343086,109586,'116527','furniture','font-size','14',0,''),(343087,109586,'116527','furniture','color','$fade-color-1',0,''),(343088,109586,'116527','furniture','padding-top','10',0,''),(343089,109589,'1638957135.2709','furniture','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(343090,109590,'116529','furniture','block_type','1',0,''),(343091,109590,'116529','furniture','background-color','$content-bg-2',0,''),(343092,109590,'116529','furniture','padding-top','30',0,''),(343093,109590,'116529','furniture','padding-bottom','30',0,''),(343094,109590,'116529','furniture','color','$content-color-2',0,''),(343095,109591,'116530','furniture','block_type','7',0,''),(343096,109592,'116531','furniture','block_type','1',0,''),(343097,109593,'116532','furniture','block_type','1',0,''),(343098,109593,'116532','furniture','background-color','$content-bg-1',0,''),(343099,109593,'116532','furniture','padding-top','30',0,''),(343100,109593,'116532','furniture','padding-left','30',0,''),(343101,109593,'116532','furniture','padding-right','30',0,''),(343102,109593,'116532','furniture','padding-bottom','30',0,''),(343103,109593,'116532','furniture','margin-bottom','20',0,''),(343104,109593,'116532','furniture','style_class','hiding-box',0,''),(343105,109593,'116532','furniture','color','$content-color-1',0,''),(343106,109594,'116533','furniture','padding-top','10',0,''),(343107,109594,'116533','furniture','padding-left','20',0,''),(343108,109594,'116533','furniture','padding-right','20',0,''),(343109,109594,'116533','furniture','margin-top','20',0,''),(343110,109594,'116533','furniture','background-color','$content-bg-2',0,''),(343111,109594,'116533','furniture','padding-bottom','8',0,''),(343112,109594,'116533','furniture','color','$content-color-2',0,''),(343113,109595,'116534','furniture','margin-bottom','20',0,''),(343114,109596,'116535','furniture','block_type','1',0,''),(343115,109596,'116535','furniture','padding-top','30',0,''),(343116,109596,'116535','furniture','padding-left','30',0,''),(343117,109596,'116535','furniture','padding-right','30',0,''),(343118,109596,'116535','furniture','padding-bottom','23',0,''),(343119,109596,'116535','furniture','margin-bottom','20',0,''),(343120,109596,'116535','furniture','background-color','$content-bg-1',0,''),(343121,109596,'116535','furniture','style_class','hiding-box',0,''),(343122,109596,'116535','furniture','color','$content-color-1',0,''),(343123,109597,'116536','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(343124,109598,'116537','furniture','block_type','2',0,''),(343125,109599,'116538','furniture','padding-right','20',0,''),(343126,109600,'116539','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343127,109601,'116540','furniture','block_type','1',0,''),(343128,109601,'116540','furniture','padding-left','20',0,''),(343129,109602,'116541','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343130,109604,'116543','furniture','block_type','1',0,''),(343131,109604,'116543','furniture','padding-top','30',0,''),(343132,109604,'116543','furniture','padding-left','30',0,''),(343133,109604,'116543','furniture','padding-right','30',0,''),(343134,109604,'116543','furniture','padding-bottom','14',0,''),(343135,109604,'116543','furniture','margin-bottom','20',0,''),(343136,109604,'116543','furniture','background-color','$content-bg-1',0,''),(343137,109604,'116543','furniture','style_class','hiding-box closeable-box',0,''),(343138,109604,'116543','furniture','color','$content-color-1',0,''),(343139,109605,'116544','furniture','block_type','2',0,''),(343140,109605,'116544','furniture','style_class','closeable-content',0,''),(343141,109606,'116545','furniture','padding-right','20',0,''),(343142,109606,'116545','furniture','padding-bottom','20',0,''),(343143,109607,'116546','furniture','padding-left','20',0,''),(343144,109607,'116546','furniture','padding-bottom','20',0,''),(343145,109608,'116547','furniture','padding-left','20',0,''),(343146,109608,'116547','furniture','padding-bottom','20',0,''),(343147,109609,'116548','furniture','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(343148,109609,'116548','furniture','style_class','closeable-heading closeable-event closed',0,''),(343149,109610,'116549','furniture','block_type','1',0,''),(343150,109610,'116549','furniture','background-color','$content-bg-1',0,''),(343151,109610,'116549','furniture','padding-top','30',0,''),(343152,109610,'116549','furniture','padding-left','30',0,''),(343153,109610,'116549','furniture','padding-right','30',0,''),(343154,109610,'116549','furniture','padding-bottom','14',0,''),(343155,109610,'116549','furniture','margin-bottom','20',0,''),(343156,109610,'116549','furniture','style_class','hiding-box closeable-box',0,''),(343157,109610,'116549','furniture','color','$content-color-1',0,''),(343158,109611,'116550','furniture','style_class','closeable-content',0,''),(343159,109611,'116550','furniture','padding-bottom','20',0,''),(343160,109612,'116551','furniture','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(343161,109612,'116551','furniture','style_class','closeable-heading closeable-event closed',0,''),(343162,109613,'116552','furniture','block_type','1',0,''),(343163,109613,'116552','furniture','padding-top','10',0,''),(343164,109613,'116552','furniture','padding-left','10',0,''),(343165,109613,'116552','furniture','padding-right','10',0,''),(343166,109613,'116552','furniture','padding-bottom','10',0,''),(343167,109613,'116552','furniture','background-color','$content-bg-1',0,''),(343168,109613,'116552','furniture','style_class','order-summary hiding-box',0,''),(343169,109613,'116552','furniture','margin-left','25',0,''),(343170,109613,'116552','furniture','color','$content-color-1',0,''),(343171,109614,'116553','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(343172,109615,'116554','furniture','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(343173,109615,'116554','furniture','text-align','center',0,''),(343174,109615,'116554','furniture','font-size','14',0,''),(343175,109615,'116554','furniture','color','$fade-color-1',0,''),(343176,109615,'116554','furniture','padding-top','10',0,''),(343177,109616,'116555','furniture','margin-bottom','10',0,''),(343178,109618,'116557','furniture','hide_page','1',0,''),(343179,109618,'116557','furniture','hide_continue_button','1',0,''),(343180,109619,'116558','furniture','block_type','1',0,''),(343181,109621,'116560','furniture','block_type','4',0,''),(343182,109621,'116560','furniture','schema','4-2',0,'5161'),(343183,109622,'116561','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(343184,109622,'116561','furniture','text-align','right',0,''),(343185,109622,'116561','furniture','padding-top','10',0,''),(343186,109622,'116561','furniture','font_size_measure','em',0,''),(343187,109622,'116561','furniture','font-size','1.2',0,''),(343188,109623,'116562','furniture','text-align','right',0,''),(343189,109624,'116563','furniture','block_type','2',0,''),(343190,109624,'116563','furniture','schema','2-2',0,'5140'),(343191,109625,'116564','furniture','block_type','1',0,''),(343192,109625,'116564','furniture','padding-right','20',0,''),(343193,109625,'116564','furniture','padding-right','0',0,'5140'),(343194,109627,'116566','furniture','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(343195,109628,'116567','furniture','block_type','1',0,''),(343196,109628,'116567','furniture','padding-left','20',0,''),(343197,109628,'116567','furniture','padding-left','0',0,'5140'),(343198,109630,'116569','furniture','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(343199,109631,'116570','furniture','block_type','2',0,''),(343200,109631,'116570','furniture','schema','2-2',0,'5140'),(343201,109632,'116571','furniture','block_type','1',0,''),(343202,109632,'116571','furniture','padding-right','20',0,''),(343203,109632,'116571','furniture','padding-right','0',0,'5140'),(343204,109633,'116572','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343205,109635,'116574','furniture','block_type','1',0,''),(343206,109635,'116574','furniture','padding-left','20',0,''),(343207,109635,'116574','furniture','padding-left','0',0,'5140'),(343208,109640,'116579','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343209,109641,'116580','furniture','margin-bottom','20',0,''),(343210,109642,'116581','furniture','block_type','1',0,''),(343211,109642,'116581','furniture','background-color','$content-bg-2',0,''),(343212,109642,'116581','furniture','padding-top','30',0,''),(343213,109642,'116581','furniture','padding-bottom','30',0,''),(343214,109643,'116582','furniture','block_type','7',0,''),(343215,109643,'116582','furniture','schema','4-2',0,'5140'),(343216,109643,'116582','furniture','margin-bottom','30',0,''),(343217,109644,'116583','furniture','block_type','1',0,''),(343218,109644,'116583','furniture','padding-right','0',0,'5140'),(343219,109645,'116585','furniture','block_type','1',0,''),(343220,109645,'116585','furniture','background-color','$content-bg-1',0,''),(343221,109645,'116585','furniture','padding-top','30',0,''),(343222,109645,'116585','furniture','padding-left','30',0,''),(343223,109645,'116585','furniture','padding-right','30',0,''),(343224,109645,'116585','furniture','padding-bottom','14',0,''),(343225,109645,'116585','furniture','margin-bottom','20',0,''),(343226,109645,'116585','furniture','style_class','hiding-box closeable-box',0,''),(343227,109646,'116586','furniture','style_class','closeable-content',0,''),(343228,109646,'116586','furniture','padding-bottom','20',0,''),(343229,109647,'116587','furniture','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(343230,109647,'116587','furniture','style_class','closeable-heading closeable-event closed',0,''),(343231,109648,'116588','furniture','block_type','1',0,''),(343232,109648,'116588','furniture','background-color','$content-bg-1',0,''),(343233,109648,'116588','furniture','padding-top','30',0,''),(343234,109648,'116588','furniture','padding-left','30',0,''),(343235,109648,'116588','furniture','padding-right','30',0,''),(343236,109648,'116588','furniture','padding-bottom','30',0,''),(343237,109648,'116588','furniture','margin-bottom','20',0,''),(343238,109648,'116588','furniture','style_class','hiding-box',0,''),(343239,109649,'116589','furniture','padding-top','10',0,''),(343240,109649,'116589','furniture','padding-left','20',0,''),(343241,109649,'116589','furniture','padding-right','20',0,''),(343242,109649,'116589','furniture','margin-top','20',0,''),(343243,109649,'116589','furniture','background-color','$content-bg-2',0,''),(343244,109649,'116589','furniture','padding-bottom','8',0,''),(343245,109650,'116590','furniture','margin-bottom','20',0,''),(343246,109651,'116591','furniture','block_type','1',0,''),(343247,109651,'116591','furniture','padding-top','30',0,''),(343248,109651,'116591','furniture','padding-left','30',0,''),(343249,109651,'116591','furniture','padding-right','30',0,''),(343250,109651,'116591','furniture','padding-bottom','23',0,''),(343251,109651,'116591','furniture','margin-bottom','20',0,''),(343252,109651,'116591','furniture','background-color','$content-bg-1',0,''),(343253,109651,'116591','furniture','style_class','hiding-box',0,''),(343254,109652,'116592','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(343255,109653,'116593','furniture','block_type','2',0,''),(343256,109653,'116593','furniture','schema','2-2',0,'5140'),(343257,109654,'116594','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343258,109655,'116595','furniture','padding-right','20',0,''),(343259,109655,'116595','furniture','padding-right','0',0,'5140'),(343260,109655,'116595','furniture','padding-bottom','20',0,'5140'),(343261,109656,'116596','furniture','block_type','1',0,''),(343262,109656,'116596','furniture','padding-left','20',0,''),(343263,109656,'116596','furniture','padding-left','0',0,'5140'),(343264,109658,'116598','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343265,109659,'116599','furniture','block_type','1',0,''),(343266,109659,'116599','furniture','padding-top','10',0,''),(343267,109659,'116599','furniture','padding-left','10',0,''),(343268,109659,'116599','furniture','padding-right','10',0,''),(343269,109659,'116599','furniture','padding-bottom','10',0,''),(343270,109659,'116599','furniture','background-color','$content-bg-1',0,''),(343271,109659,'116599','furniture','style_class','order-summary',0,''),(343272,109659,'116599','furniture','margin-left','25',0,''),(343273,109661,'116601','furniture','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(343274,109661,'116601','furniture','text-align','center',0,''),(343275,109661,'116601','furniture','font-size','14',0,''),(343276,109661,'116601','furniture','color','$fade-color-1',0,''),(343277,109661,'116601','furniture','padding-top','10',0,''),(343278,109662,'116602','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(343279,109663,'116603','furniture','margin-bottom','10',0,''),(343280,109665,'116604','furniture','block_type','2',0,''),(343281,109666,'116605','furniture','block_type','1',0,''),(343282,109666,'116605','furniture','padding-left','0',0,'5140'),(343283,109666,'116605','furniture','padding-right','20',0,''),(343284,109668,'116607','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343285,109669,'116608','furniture','block_type','1',0,''),(343286,109669,'116608','furniture','padding-left','20',0,''),(343287,109669,'116608','furniture','padding-left','0',0,'5140'),(343288,109674,'116613','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343289,109675,'116614','furniture','block_type','4',0,''),(343290,109675,'116614','furniture','schema','4-2',0,'5161'),(343291,109676,'116615','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(343292,109676,'116615','furniture','text-align','right',0,''),(343293,109676,'116615','furniture','padding-top','10',0,''),(343294,109676,'116615','furniture','font_size_measure','em',0,''),(343295,109676,'116615','furniture','font-size','1.2',0,''),(343296,109677,'116616','furniture','text-align','right',0,''),(343297,109678,'116617','furniture','block_type','2',0,''),(343298,109679,'116618','furniture','block_type','1',0,''),(343299,109679,'116618','furniture','padding-left','0',0,'5140'),(343300,109679,'116618','furniture','padding-right','20',0,''),(343301,109681,'116620','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343302,109682,'116621','furniture','block_type','1',0,''),(343303,109682,'116621','furniture','padding-left','20',0,''),(343304,109682,'116621','furniture','padding-left','0',0,'5140'),(343305,109684,'116623','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343306,109688,'116627','furniture','block_type','4',0,''),(343307,109688,'116627','furniture','schema','4-2',0,'5161'),(343308,109689,'116628','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(343309,109689,'116628','furniture','text-align','right',0,''),(343310,109689,'116628','furniture','padding-top','10',0,''),(343311,109689,'116628','furniture','font_size_measure','em',0,''),(343312,109689,'116628','furniture','font-size','1.2',0,''),(343313,109690,'116629','furniture','text-align','right',0,''),(343314,109691,'116630','furniture','block_type','4',0,''),(343315,109691,'116630','furniture','schema','4-2',0,'5161'),(343316,109692,'116631','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(343317,109692,'116631','furniture','text-align','right',0,''),(343318,109692,'116631','furniture','padding-top','10',0,''),(343319,109692,'116631','furniture','font_size_measure','em',0,''),(343320,109692,'116631','furniture','font-size','1.2',0,''),(343321,109693,'116632','furniture','text-align','right',0,''),(343322,109694,'116633','furniture','block_type','2',0,''),(343323,109695,'116634','furniture','block_type','1',0,''),(343324,109695,'116634','furniture','padding-left','0',0,'5140'),(343325,109695,'116634','furniture','padding-right','20',0,''),(343326,109696,'116635','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343327,109698,'116637','furniture','block_type','1',0,''),(343328,109698,'116637','furniture','padding-left','20',0,''),(343329,109698,'116637','furniture','padding-left','0',0,'5140'),(343330,109703,'116642','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343331,109704,'116643','furniture','block_type','4',0,''),(343332,109704,'116643','furniture','schema','4-2',0,'5161'),(343333,109705,'116644','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(343334,109705,'116644','furniture','text-align','right',0,''),(343335,109705,'116644','furniture','padding-top','10',0,''),(343336,109705,'116644','furniture','font_size_measure','em',0,''),(343337,109705,'116644','furniture','font-size','1.2',0,''),(343338,109706,'116645','furniture','text-align','right',0,''),(343339,109707,'116646','furniture','block_type','2',0,''),(343340,109708,'116647','furniture','block_type','1',0,''),(343341,109708,'116647','furniture','padding-left','0',0,'5140'),(343342,109708,'116647','furniture','padding-right','20',0,''),(343343,109710,'116649','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343344,109711,'116650','furniture','block_type','1',0,''),(343345,109711,'116650','furniture','padding-left','20',0,''),(343346,109711,'116650','furniture','padding-left','0',0,'5140'),(343347,109715,'116654','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343348,109717,'116656','furniture','text','##PAYMENT_DETAILS##',0,''),(343349,109718,'116657','furniture','text','##PAYMENT_DETAILS##',0,''),(343350,109719,'116658','furniture','text','##PAYMENT_DETAILS##',0,''),(343351,109720,'116659','furniture','text','##PAYMENT_DETAILS##',0,''),(343352,109721,'116660','furniture','text','##PAYMENT_DETAILS##',0,''),(343353,109722,'116661','furniture','text','##PAYMENT_DETAILS##',0,''),(343354,109723,'120947','furniture','block_type','1',0,''),(343355,109723,'120947','furniture','background-color','$content-bg-2',0,''),(343356,109723,'120947','furniture','padding-top','30',0,''),(343357,109723,'120947','furniture','padding-bottom','30',0,''),(343358,109724,'120948','furniture','block_type','7',0,''),(343359,109724,'120948','furniture','schema','4-2',0,'5140'),(343360,109725,'120949','furniture','block_type','1',0,''),(343361,109725,'120949','furniture','padding-right','0',0,'5140'),(343362,109726,'120950','furniture','block_type','1',0,''),(343363,109726,'120950','furniture','background-color','$content-bg-1',0,''),(343364,109726,'120950','furniture','padding-top','30',0,''),(343365,109726,'120950','furniture','padding-left','30',0,''),(343366,109726,'120950','furniture','padding-right','30',0,''),(343367,109726,'120950','furniture','padding-bottom','30',0,''),(343368,109726,'120950','furniture','margin-bottom','20',0,''),(343369,109726,'120950','furniture','style_class','hiding-box',0,''),(343370,109727,'120951','furniture','padding-top','10',0,''),(343371,109727,'120951','furniture','padding-left','20',0,''),(343372,109727,'120951','furniture','padding-right','20',0,''),(343373,109727,'120951','furniture','margin-top','20',0,''),(343374,109727,'120951','furniture','background-color','$content-bg-2',0,''),(343375,109727,'120951','furniture','padding-bottom','8',0,''),(343376,109728,'120952','furniture','margin-bottom','20',0,''),(343377,109729,'120953','furniture','background-color','$content-bg-1',0,''),(343378,109729,'120953','furniture','block_type','1',0,''),(343379,109729,'120953','furniture','padding-top','30',0,''),(343380,109729,'120953','furniture','padding-left','30',0,''),(343381,109729,'120953','furniture','padding-right','30',0,''),(343382,109729,'120953','furniture','padding-bottom','30',0,''),(343383,109729,'120953','furniture','margin-bottom','20',0,''),(343384,109729,'120953','furniture','style_class','hiding-box',0,''),(343385,109730,'120954','furniture','block_type','1',0,''),(343386,109730,'120954','furniture','content','\\_',0,'3'),(343387,109730,'120954','furniture','border-top-width','1',0,'3'),(343388,109730,'120954','furniture','border-top-color','$content-border-1',0,'3'),(343389,109730,'120954','furniture','display','block',0,'3'),(343390,109730,'120954','furniture','position','absolute',0,'3'),(343391,109730,'120954','furniture','top','19',0,'3'),(343392,109730,'120954','furniture','left','0',0,'3'),(343393,109730,'120954','furniture','right','0',0,'3'),(343394,109730,'120954','furniture','margin-top','-2',0,'3'),(343395,109730,'120954','furniture','position','relative',0,''),(343396,109731,'120955','furniture','box_align','2',0,''),(343397,109731,'120955','furniture','margin-bottom','10',0,''),(343398,109731,'120955','furniture','background-color','$content-bg-1',0,''),(343399,109731,'120955','furniture','position','relative',0,''),(343400,109732,'120956','furniture','background-color','$content-bg-2',0,''),(343401,109732,'120956','furniture','padding-top','10',0,''),(343402,109732,'120956','furniture','padding-left','10',0,''),(343403,109732,'120956','furniture','padding-right','10',0,''),(343404,109732,'120956','furniture','padding-bottom','10',0,''),(343405,109732,'120956','furniture','margin-top','10',0,''),(343406,109733,'120957','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(343407,109734,'120958','furniture','block_type','2',0,''),(343408,109734,'120958','furniture','schema','2-2',0,'5140'),(343409,109735,'120959','furniture','block_type','1',0,''),(343410,109735,'120959','furniture','padding-right','20',0,''),(343411,109735,'120959','furniture','padding-left','0',0,'5140'),(343412,109735,'120959','furniture','margin-bottom','20',0,'5140'),(343413,109735,'120959','furniture','padding-right','0',0,'5140'),(343414,109738,'120962','furniture','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(343415,109739,'120963','furniture','block_type','1',0,''),(343416,109739,'120963','furniture','padding-left','20',0,''),(343417,109739,'120963','furniture','padding-left','0',0,'5140'),(343418,109741,'120965','furniture','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(343419,109742,'120966','furniture','border-top-width','1',0,''),(343420,109742,'120966','furniture','border-top-color','$content-border-1',0,''),(343421,109742,'120966','furniture','padding-top','13',0,''),(343422,109742,'120966','furniture','padding-bottom','10',0,''),(343423,109743,'120967','furniture','block_type','1',0,''),(343424,109743,'120967','furniture','background-color','$content-bg-1',0,''),(343425,109743,'120967','furniture','padding-top','30',0,''),(343426,109743,'120967','furniture','padding-left','30',0,''),(343427,109743,'120967','furniture','padding-right','30',0,''),(343428,109743,'120967','furniture','padding-bottom','14',0,''),(343429,109743,'120967','furniture','margin-bottom','20',0,''),(343430,109743,'120967','furniture','style_class','hiding-box closeable-box',0,''),(343431,109744,'120968','furniture','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(343432,109744,'120968','furniture','style_class','closeable-heading closeable-event closed',0,''),(343433,109745,'120969','furniture','style_class','closeable-content',0,''),(343434,109745,'120969','furniture','padding-bottom','20',0,''),(343435,109746,'120970','furniture','block_type','1',0,''),(343436,109746,'120970','furniture','padding-top','30',0,''),(343437,109746,'120970','furniture','padding-left','30',0,''),(343438,109746,'120970','furniture','padding-right','30',0,''),(343439,109746,'120970','furniture','padding-bottom','23',0,''),(343440,109746,'120970','furniture','margin-bottom','20',0,''),(343441,109746,'120970','furniture','background-color','$content-bg-1',0,''),(343442,109746,'120970','furniture','style_class','hiding-box',0,''),(343443,109747,'120971','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(343444,109748,'120972','furniture','block_type','2',0,''),(343445,109748,'120972','furniture','schema','2-2',0,'5140'),(343446,109749,'120973','furniture','padding-right','20',0,''),(343447,109749,'120973','furniture','padding-right','0',0,'5140'),(343448,109749,'120973','furniture','padding-bottom','20',0,'5140'),(343449,109750,'120974','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343450,109751,'120975','furniture','block_type','1',0,''),(343451,109751,'120975','furniture','padding-left','20',0,''),(343452,109751,'120975','furniture','padding-left','0',0,'5140'),(343453,109753,'120977','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343454,109754,'120978','furniture','block_type','1',0,''),(343455,109754,'120978','furniture','padding-left','10',0,''),(343456,109754,'120978','furniture','padding-right','10',0,''),(343457,109754,'120978','furniture','padding-bottom','10',0,''),(343458,109754,'120978','furniture','background-color','$content-bg-1',0,''),(343459,109754,'120978','furniture','style_class','order-summary',0,''),(343460,109754,'120978','furniture','margin-left','25',0,''),(343461,109754,'120978','furniture','margin-left','0',0,'5140'),(343462,109755,'120979','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(343463,109756,'120980','furniture','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(343464,109756,'120980','furniture','text-align','center',0,''),(343465,109756,'120980','furniture','font-size','14',0,''),(343466,109756,'120980','furniture','color','$fade-color-1',0,''),(343467,109756,'120980','furniture','padding-top','10',0,''),(343468,109757,'120981','furniture','margin-bottom','10',0,''),(343469,109759,'120983','furniture','hide_continue_button','1',0,''),(343470,109760,'116699','furniture','block_type','1',0,''),(343471,109760,'116699','furniture','background-color','$content-bg-2',0,''),(343472,109760,'116699','furniture','padding-top','30',0,''),(343473,109760,'116699','furniture','padding-bottom','30',0,''),(343474,109761,'116700','furniture','block_type','7',0,''),(343475,109761,'116700','furniture','schema','7-2',0,'5140'),(343476,109762,'116701','furniture','block_type','1',0,''),(343477,109762,'116701','furniture','padding-right','0',0,'5140'),(343478,109763,'116703','furniture','block_type','1',0,''),(343479,109763,'116703','furniture','background-color','$content-bg-1',0,''),(343480,109763,'116703','furniture','padding-top','30',0,''),(343481,109763,'116703','furniture','padding-left','30',0,''),(343482,109763,'116703','furniture','padding-right','30',0,''),(343483,109763,'116703','furniture','padding-bottom','30',0,''),(343484,109763,'116703','furniture','margin-bottom','20',0,''),(343485,109763,'116703','furniture','style_class','hiding-box',0,''),(343486,109764,'116704','furniture','margin-bottom','20',0,''),(343487,109765,'116705','furniture','padding-top','10',0,''),(343488,109765,'116705','furniture','padding-left','20',0,''),(343489,109765,'116705','furniture','padding-right','20',0,''),(343490,109765,'116705','furniture','margin-top','20',0,''),(343491,109765,'116705','furniture','background-color','$content-bg-2',0,''),(343492,109765,'116705','furniture','padding-bottom','8',0,''),(343493,109766,'116706','furniture','background-color','$content-bg-1',0,''),(343494,109766,'116706','furniture','block_type','1',0,''),(343495,109766,'116706','furniture','padding-top','30',0,''),(343496,109766,'116706','furniture','padding-left','30',0,''),(343497,109766,'116706','furniture','padding-right','30',0,''),(343498,109766,'116706','furniture','padding-bottom','30',0,''),(343499,109766,'116706','furniture','margin-bottom','20',0,''),(343500,109766,'116706','furniture','style_class','hiding-box',0,''),(343501,109767,'116707','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(343502,109768,'116708','furniture','background-color','$content-bg-2',0,''),(343503,109768,'116708','furniture','padding-top','10',0,''),(343504,109768,'116708','furniture','padding-left','10',0,''),(343505,109768,'116708','furniture','padding-right','10',0,''),(343506,109768,'116708','furniture','padding-bottom','10',0,''),(343507,109768,'116708','furniture','margin-top','10',0,''),(343508,109769,'116709','furniture','block_type','1',0,''),(343509,109769,'116709','furniture','content','\\_',0,'3'),(343510,109769,'116709','furniture','border-top-width','1',0,'3'),(343511,109769,'116709','furniture','border-top-color','$content-border-1',0,'3'),(343512,109769,'116709','furniture','display','block',0,'3'),(343513,109769,'116709','furniture','position','absolute',0,'3'),(343514,109769,'116709','furniture','top','19',0,'3'),(343515,109769,'116709','furniture','left','0',0,'3'),(343516,109769,'116709','furniture','right','0',0,'3'),(343517,109769,'116709','furniture','margin-top','-2',0,'3'),(343518,109769,'116709','furniture','position','relative',0,''),(343519,109770,'116710','furniture','box_align','2',0,''),(343520,109770,'116710','furniture','margin-bottom','10',0,''),(343521,109770,'116710','furniture','background-color','$content-bg-1',0,''),(343522,109770,'116710','furniture','position','relative',0,''),(343523,109771,'116711','furniture','block_type','2',0,''),(343524,109771,'116711','furniture','schema','2-2',0,'5140'),(343525,109772,'116712','furniture','block_type','1',0,''),(343526,109772,'116712','furniture','padding-right','20',0,''),(343527,109772,'116712','furniture','padding-left','0',0,'5140'),(343528,109772,'116712','furniture','margin-bottom','20',0,'5140'),(343529,109772,'116712','furniture','padding-right','0',0,'5140'),(343530,109775,'116715','furniture','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(343531,109776,'116716','furniture','block_type','1',0,''),(343532,109776,'116716','furniture','padding-left','20',0,''),(343533,109776,'116716','furniture','padding-left','0',0,'5140'),(343534,109778,'116718','furniture','border-top-width','1',0,''),(343535,109778,'116718','furniture','border-top-color','$content-border-1',0,''),(343536,109778,'116718','furniture','padding-top','13',0,''),(343537,109778,'116718','furniture','padding-bottom','10',0,''),(343538,109779,'116719','furniture','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(343539,109780,'116720','furniture','block_type','1',0,''),(343540,109780,'116720','furniture','padding-top','30',0,''),(343541,109780,'116720','furniture','padding-left','30',0,''),(343542,109780,'116720','furniture','padding-right','30',0,''),(343543,109780,'116720','furniture','padding-bottom','23',0,''),(343544,109780,'116720','furniture','margin-bottom','20',0,''),(343545,109780,'116720','furniture','background-color','$content-bg-1',0,''),(343546,109780,'116720','furniture','style_class','hiding-box',0,''),(343547,109781,'116721','furniture','block_type','2',0,''),(343548,109781,'116721','furniture','schema','2-2',0,'5140'),(343549,109782,'116722','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343550,109783,'116723','furniture','padding-right','20',0,''),(343551,109783,'116723','furniture','padding-right','0',0,'5140'),(343552,109783,'116723','furniture','padding-bottom','20',0,'5140'),(343553,109784,'116724','furniture','block_type','1',0,''),(343554,109784,'116724','furniture','padding-left','20',0,''),(343555,109784,'116724','furniture','padding-left','0',0,'5140'),(343556,109785,'116725','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343557,109787,'116727','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(343558,109788,'116728','furniture','block_type','1',0,''),(343559,109788,'116728','furniture','background-color','$content-bg-1',0,''),(343560,109788,'116728','furniture','padding-top','30',0,''),(343561,109788,'116728','furniture','padding-left','30',0,''),(343562,109788,'116728','furniture','padding-right','30',0,''),(343563,109788,'116728','furniture','padding-bottom','14',0,''),(343564,109788,'116728','furniture','margin-bottom','20',0,''),(343565,109788,'116728','furniture','style_class','hiding-box closeable-box',0,''),(343566,109789,'116729','furniture','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(343567,109789,'116729','furniture','style_class','closeable-heading closeable-event closed',0,''),(343568,109790,'116730','furniture','style_class','closeable-content',0,''),(343569,109790,'116730','furniture','padding-bottom','20',0,''),(343570,109791,'116731','furniture','block_type','1',0,''),(343571,109791,'116731','furniture','padding-top','30',0,''),(343572,109791,'116731','furniture','padding-left','30',0,''),(343573,109791,'116731','furniture','padding-right','30',0,''),(343574,109791,'116731','furniture','padding-bottom','14',0,''),(343575,109791,'116731','furniture','margin-bottom','20',0,''),(343576,109791,'116731','furniture','background-color','$content-bg-1',0,''),(343577,109791,'116731','furniture','style_class','hiding-box closeable-box',0,''),(343578,109792,'116732','furniture','block_type','2',0,''),(343579,109792,'116732','furniture','style_class','closeable-content',0,''),(343580,109792,'116732','furniture','schema','2-2',0,'5140'),(343581,109793,'116733','furniture','padding-right','20',0,''),(343582,109793,'116733','furniture','padding-bottom','20',0,''),(343583,109793,'116733','furniture','padding-right','0',0,'5140'),(343584,109794,'116734','furniture','padding-left','20',0,''),(343585,109794,'116734','furniture','padding-bottom','20',0,''),(343586,109794,'116734','furniture','padding-left','0',0,'5140'),(343587,109795,'116735','furniture','padding-left','20',0,''),(343588,109795,'116735','furniture','padding-bottom','20',0,''),(343589,109795,'116735','furniture','padding-left','0',0,'5140'),(343590,109796,'116736','furniture','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(343591,109796,'116736','furniture','style_class','closeable-heading closeable-event closed',0,''),(343592,109797,'116737','furniture','block_type','1',0,''),(343593,109797,'116737','furniture','padding-top','20',0,''),(343594,109797,'116737','furniture','padding-left','20',0,''),(343595,109797,'116737','furniture','padding-right','20',0,''),(343596,109797,'116737','furniture','padding-bottom','20',0,''),(343597,109797,'116737','furniture','background-color','$content-bg-1',0,''),(343598,109797,'116737','furniture','style_class','order-summary',0,''),(343599,109797,'116737','furniture','margin-left','25',0,''),(343600,109797,'116737','furniture','padding-left','0',0,'5140'),(343601,109798,'116738','furniture','margin-bottom','10',0,''),(343602,109799,'116739','furniture','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(343603,109799,'116739','furniture','text-align','center',0,''),(343604,109799,'116739','furniture','font-size','14',0,''),(343605,109799,'116739','furniture','color','$fade-color-1',0,''),(343606,109799,'116739','furniture','padding-top','10',0,''),(343607,109800,'116740','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(343608,109802,'120986','furniture','hide_continue_button','1',0,''),(343609,109803,'116742','furniture','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(343610,109808,'116747','furniture','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(343611,109809,'116749','furniture','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(343612,109810,'116750','furniture','style_class','order-summary',0,''),(343613,109810,'116750','furniture','box_align','3',0,''),(343614,109810,'116750','furniture','width','400',0,''),(343615,109812,'116748','furniture','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(343616,109815,'116754','furniture','block_type','1',0,''),(343617,109816,'116755','furniture','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(343618,109817,'116756','furniture','float','right',0,''),(343619,109817,'116756','furniture','position','relative',0,''),(343620,109817,'116756','furniture','z-index','1',0,''),(343621,109817,'116756','furniture','top','30',0,''),(343622,109817,'116756','furniture','margin-bottom','-10',0,''),(343623,109818,'116757','furniture','margin-bottom','30',0,''),(343624,109819,'116758','furniture','block_type','1',0,''),(343625,109820,'116759','furniture','listing_type','CompareProduct',0,''),(343626,109821,'117665.000001','furniture','block_type','1',0,''),(343627,109821,'117665.000001','furniture','style_class','item-holder',0,''),(343628,109821,'117665.000001','furniture','padding-top','25',0,''),(343629,109821,'117665.000001','furniture','padding-left','25',0,''),(343630,109821,'117665.000001','furniture','padding-right','25',0,''),(343631,109821,'117665.000001','furniture','padding-bottom','25',0,''),(343632,109821,'117665.000001','furniture','text-align','left',0,''),(343633,109822,'120921.000001','furniture','block_type','1',0,''),(343634,109822,'120921.000001','furniture','style_class','item-wrapper',0,''),(343635,109823,'120919.000001','furniture','block_type','1',0,''),(343636,109823,'120919.000001','furniture','style_class','item-content',0,''),(343637,109824,'1638872990.9609','furniture','block_type','5',0,''),(343638,109826,'117677.000001','furniture','float','right',0,''),(343639,109827,'117675.000001','furniture','clear','none',0,''),(343640,109828,'117676.000001','furniture','margin-bottom','10',0,''),(343641,109829,'1638873112.0384','furniture','block_type','2',0,''),(343642,109831,'117673.000001','furniture','margin-bottom','7',0,''),(343643,109831,'117673.000001','furniture','text-align','right',0,''),(343644,109832,'116760','furniture','block_type','1',0,''),(343645,109832,'116760','furniture','style_class','item-holder',0,''),(343646,109832,'116760','furniture','padding-top','10',0,''),(343647,109832,'116760','furniture','padding-left','20',0,''),(343648,109832,'116760','furniture','padding-right','20',0,''),(343649,109832,'116760','furniture','padding-bottom','10',0,''),(343650,109832,'116760','furniture','text-align','left',0,''),(343651,109835,'116763','furniture','margin-bottom','10',0,''),(343652,109836,'116764','furniture','block_type','5',0,''),(343653,109838,'116766','furniture','clear','both',0,''),(343654,109839,'116767','furniture','block_type','2',0,''),(343655,109840,'116768','furniture','margin-bottom','7',0,''),(343656,109841,'116769','furniture','text-align','right',0,''),(343657,109841,'116769','furniture','margin-bottom','10',0,''),(343658,109841,'116769','furniture','float','right',0,''),(343659,109842,'116770','furniture','block_type','1',0,''),(343660,109842,'116770','furniture','background-color','$content-bg-2',0,''),(343661,109842,'116770','furniture','padding-bottom','30',0,''),(343662,109842,'116770','furniture','style_class','checkout-order-confirmation',0,''),(343663,109842,'116770','furniture','color','$content-color-2',0,''),(343664,109843,'116771','furniture','block_type','4',0,''),(343665,109843,'116771','furniture','schema','4-2',0,'5140'),(343666,109844,'116772','furniture','block_type','1',0,''),(343667,109844,'116772','furniture','padding-right','40',0,''),(343668,109844,'116772','furniture','padding-right','0',0,'5140'),(343669,109845,'116773','furniture','block_type','1',0,''),(343670,109845,'116773','furniture','padding-right','30',0,''),(343671,109845,'116773','furniture','background-color','$content-bg-1',0,''),(343672,109845,'116773','furniture','padding-top','20',0,''),(343673,109845,'116773','furniture','padding-left','30',0,''),(343674,109845,'116773','furniture','padding-bottom','20',0,''),(343675,109845,'116773','furniture','padding-left','20',0,'5140'),(343676,109845,'116773','furniture','padding-right','20',0,'5140'),(343677,109845,'116773','furniture','color','$content-color-1',0,''),(343678,109846,'116774','furniture','link','products',0,''),(343679,109846,'116774','furniture','float','right',0,''),(343680,109846,'116774','furniture','margin-top','-37',0,''),(343681,109848,'116776','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(343682,109849,'116777','furniture','block_type','1',0,''),(343683,109849,'116777','furniture','background-color','$content-bg-1',0,''),(343684,109849,'116777','furniture','padding-top','20',0,''),(343685,109849,'116777','furniture','padding-bottom','20',0,''),(343686,109849,'116777','furniture','padding-left','30',0,''),(343687,109849,'116777','furniture','padding-right','30',0,''),(343688,109849,'116777','furniture','margin-bottom','20',0,''),(343689,109849,'116777','furniture','color','$content-color-1',0,''),(343690,109850,'116778','furniture','float','right',0,''),(343691,109850,'116778','furniture','margin-top','-37',0,''),(343692,109850,'116778','furniture','link','comments',0,''),(343693,109851,'116779','furniture','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(343694,109852,'116780','furniture','hide_parents','2',0,''),(343695,109853,'116781','furniture','block_type','2',0,''),(343696,109853,'116781','furniture','margin-bottom','20',0,''),(343697,109853,'116781','furniture','schema','2-2',0,'5131'),(343698,109853,'116781','furniture','background-color','$content-bg-1',0,''),(343699,109853,'116781','furniture','color','$content-color-1',0,''),(343700,109854,'116782','furniture','block_type','1',0,''),(343701,109854,'116782','furniture','border-right-width','20',0,''),(343702,109854,'116782','furniture','border-right-color','$content-bg-2',0,''),(343703,109854,'116782','furniture','margin-right','-10',0,''),(343704,109854,'116782','furniture','padding-right','30',0,''),(343705,109854,'116782','furniture','padding-top','20',0,''),(343706,109854,'116782','furniture','padding-left','30',0,''),(343707,109854,'116782','furniture','padding-bottom','20',0,''),(343708,109854,'116782','furniture','border-right-width','0',0,'5140'),(343709,109854,'116782','furniture','margin-right','0',0,'5140'),(343710,109854,'116782','furniture','margin-bottom','20',0,'5140'),(343711,109854,'116782','furniture','padding-left','20',0,'5140'),(343712,109854,'116782','furniture','padding-right','20',0,'5140'),(343713,109855,'116783','furniture','link','shipping_method',0,''),(343714,109855,'116783','furniture','float','right',0,''),(343715,109855,'116783','furniture','margin-top','-31',0,''),(343716,109857,'116785','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(343717,109857,'116785','furniture','padding-top','20',0,''),(343718,109858,'116786','furniture','link','contact_information',0,''),(343719,109858,'116786','furniture','margin-top','-31',0,''),(343720,109858,'116786','furniture','float','right',0,''),(343721,109859,'116787','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(343722,109859,'116787','furniture','clear','none',0,''),(343723,109861,'116789','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(343724,109862,'116790','furniture','link','shipping_address',0,''),(343725,109862,'116790','furniture','float','right',0,''),(343726,109862,'116790','furniture','margin-top','-31',0,''),(343727,109864,'116792','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(343728,109864,'116792','furniture','clear','none',0,''),(343729,109865,'116793','furniture','margin-bottom','20',0,''),(343730,109866,'116794','furniture','block_type','1',0,''),(343731,109866,'116794','furniture','padding-left','30',0,''),(343732,109866,'116794','furniture','border-left-width','20',0,''),(343733,109866,'116794','furniture','border-left-color','$content-bg-2',0,''),(343734,109866,'116794','furniture','margin-left','-10',0,''),(343735,109866,'116794','furniture','padding-right','30',0,''),(343736,109866,'116794','furniture','padding-top','20',0,''),(343737,109866,'116794','furniture','padding-bottom','20',0,''),(343738,109866,'116794','furniture','border-left-width','0',0,'5140'),(343739,109867,'116795','furniture','link','payment_method',0,''),(343740,109867,'116795','furniture','float','right',0,''),(343741,109867,'116795','furniture','margin-top','-31',0,''),(343742,109868,'116796','furniture','link','billing_address',0,''),(343743,109868,'116796','furniture','float','right',0,''),(343744,109868,'116796','furniture','margin-top','-31',0,''),(343745,109870,'116798','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343746,109870,'116798','furniture','clear','none',0,''),(343747,109871,'116799','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(343748,109872,'116800','furniture','margin-bottom','20',0,''),(343749,109873,'116801','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343750,109873,'116801','furniture','clear','none',0,''),(343751,109875,'116803','furniture','block_type','1',0,''),(343752,109875,'116803','furniture','padding-top','20',0,''),(343753,109875,'116803','furniture','padding-left','20',0,''),(343754,109875,'116803','furniture','padding-right','20',0,''),(343755,109875,'116803','furniture','padding-bottom','20',0,''),(343756,109875,'116803','furniture','background-color','$content-bg-1',0,''),(343757,109875,'116803','furniture','style_class','order-summary2 hiding-box',0,''),(343758,109875,'116803','furniture','color','$content-color-1',0,''),(343759,109876,'116804','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(343760,109877,'116805','furniture','margin-bottom','20',0,''),(343761,109877,'116805','furniture','text-align','right',0,''),(343762,109879,'116807','furniture','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(343763,109880,'116808','furniture','block_type','1',0,''),(343764,109880,'116808','furniture','background-color','$content-bg-2',0,''),(343765,109880,'116808','furniture','padding-bottom','30',0,''),(343766,109881,'116809','furniture','block_type','4',0,''),(343767,109881,'116809','furniture','schema','4-2',0,'5140'),(343768,109882,'116810','furniture','block_type','1',0,''),(343769,109882,'116810','furniture','padding-right','40',0,''),(343770,109882,'116810','furniture','padding-right','0',0,'5140'),(343771,109883,'116811','furniture','block_type','1',0,''),(343772,109883,'116811','furniture','background-color','$content-bg-1',0,''),(343773,109883,'116811','furniture','padding-top','20',0,''),(343774,109883,'116811','furniture','padding-bottom','20',0,''),(343775,109883,'116811','furniture','padding-left','30',0,''),(343776,109883,'116811','furniture','padding-right','30',0,''),(343777,109883,'116811','furniture','margin-bottom','20',0,''),(343778,109884,'116812','furniture','hide_parents','2',0,''),(343779,109885,'116813','furniture','float','right',0,''),(343780,109885,'116813','furniture','margin-top','-37',0,''),(343781,109885,'116813','furniture','link','comments',0,''),(343782,109886,'116814','furniture','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(343783,109887,'116815','furniture','block_type','1',0,''),(343784,109887,'116815','furniture','padding-right','30',0,''),(343785,109887,'116815','furniture','background-color','$content-bg-1',0,''),(343786,109887,'116815','furniture','padding-top','20',0,''),(343787,109887,'116815','furniture','padding-left','30',0,''),(343788,109887,'116815','furniture','padding-bottom','20',0,''),(343789,109887,'116815','furniture','padding-left','20',0,'5140'),(343790,109887,'116815','furniture','padding-right','20',0,'5140'),(343791,109888,'116816','furniture','link','products',0,''),(343792,109888,'116816','furniture','float','right',0,''),(343793,109888,'116816','furniture','margin-top','-37',0,''),(343794,109889,'116817','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(343795,109891,'116819','furniture','block_type','2',0,''),(343796,109891,'116819','furniture','margin-bottom','20',0,''),(343797,109891,'116819','furniture','schema','2-2',0,'5131'),(343798,109891,'116819','furniture','background-color','$content-bg-1',0,''),(343799,109892,'116820','furniture','block_type','1',0,''),(343800,109892,'116820','furniture','border-right-width','20',0,''),(343801,109892,'116820','furniture','border-right-color','$content-border-1',0,''),(343802,109892,'116820','furniture','margin-right','-10',0,''),(343803,109892,'116820','furniture','padding-right','30',0,''),(343804,109892,'116820','furniture','padding-top','20',0,''),(343805,109892,'116820','furniture','padding-left','30',0,''),(343806,109892,'116820','furniture','padding-bottom','20',0,''),(343807,109892,'116820','furniture','border-right-width','0',0,'5140'),(343808,109892,'116820','furniture','margin-right','0',0,'5140'),(343809,109892,'116820','furniture','margin-bottom','20',0,'5140'),(343810,109892,'116820','furniture','padding-left','20',0,'5140'),(343811,109892,'116820','furniture','padding-right','20',0,'5140'),(343812,109893,'116821','furniture','link','shipping_address',0,''),(343813,109893,'116821','furniture','float','right',0,''),(343814,109893,'116821','furniture','margin-top','-31',0,''),(343815,109895,'116823','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(343816,109895,'116823','furniture','clear','none',0,''),(343817,109896,'116824','furniture','link','shipping_method',0,''),(343818,109896,'116824','furniture','float','right',0,''),(343819,109896,'116824','furniture','margin-top','-31',0,''),(343820,109897,'116825','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(343821,109897,'116825','furniture','clear','none',0,''),(343822,109898,'116826','furniture','margin-bottom','20',0,''),(343823,109899,'116827','furniture','block_type','1',0,''),(343824,109899,'116827','furniture','padding-left','30',0,''),(343825,109899,'116827','furniture','border-left-width','20',0,''),(343826,109899,'116827','furniture','border-left-color','$content-border-1',0,''),(343827,109899,'116827','furniture','margin-left','-10',0,''),(343828,109899,'116827','furniture','padding-right','30',0,''),(343829,109899,'116827','furniture','padding-top','20',0,''),(343830,109899,'116827','furniture','padding-bottom','20',0,''),(343831,109899,'116827','furniture','border-left-width','0',0,'5140'),(343832,109902,'116830','furniture','link','contact_information',0,''),(343833,109902,'116830','furniture','margin-top','-31',0,''),(343834,109902,'116830','furniture','float','right',0,''),(343835,109903,'116831','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(343836,109904,'116832','furniture','block_type','1',0,''),(343837,109904,'116832','furniture','padding-top','20',0,''),(343838,109904,'116832','furniture','padding-left','20',0,''),(343839,109904,'116832','furniture','padding-right','20',0,''),(343840,109904,'116832','furniture','padding-bottom','20',0,''),(343841,109904,'116832','furniture','background-color','$content-bg-1',0,''),(343842,109904,'116832','furniture','style_class','order-summary',0,''),(343843,109905,'116833','furniture','margin-bottom','20',0,''),(343844,109905,'116833','furniture','text-align','right',0,''),(343845,109906,'116834','furniture','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(343846,109907,'116835','furniture','block_type','1',0,''),(343847,109907,'116835','furniture','background-color','$content-bg-2',0,''),(343848,109907,'116835','furniture','padding-bottom','30',0,''),(343849,109907,'116835','furniture','color','$content-color-2',0,''),(343850,109908,'116836','furniture','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(343851,109909,'116837','furniture','block_type','4',0,''),(343852,109910,'116838','furniture','block_type','1',0,''),(343853,109910,'116838','furniture','padding-right','40',0,''),(343854,109911,'116839','furniture','block_type','2',0,''),(343855,109911,'116839','furniture','margin-bottom','20',0,''),(343856,109911,'116839','furniture','schema','2-2',0,'5131'),(343857,109911,'116839','furniture','background-color','$content-bg-1',0,''),(343858,109911,'116839','furniture','color','$content-color-1',0,''),(343859,109912,'116840','furniture','block_type','1',0,''),(343860,109912,'116840','furniture','padding-right','0',0,'5131'),(343861,109912,'116840','furniture','border-right-width','20',0,''),(343862,109912,'116840','furniture','border-right-color','$content-bg-2',0,''),(343863,109912,'116840','furniture','margin-right','-10',0,''),(343864,109912,'116840','furniture','padding-right','30',0,''),(343865,109912,'116840','furniture','padding-top','20',0,''),(343866,109912,'116840','furniture','padding-left','30',0,''),(343867,109912,'116840','furniture','padding-bottom','20',0,''),(343868,109913,'116841','furniture','link','contact_information',0,''),(343869,109913,'116841','furniture','float','right',0,''),(343870,109914,'116842','furniture','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(343871,109916,'116844','furniture','block_type','1',0,''),(343872,109916,'116844','furniture','padding-left','30',0,''),(343873,109916,'116844','furniture','padding-left','0',0,'5131'),(343874,109916,'116844','furniture','border-left-width','20',0,''),(343875,109916,'116844','furniture','border-left-color','$content-bg-2',0,''),(343876,109916,'116844','furniture','margin-left','-10',0,''),(343877,109916,'116844','furniture','padding-right','30',0,''),(343878,109916,'116844','furniture','padding-top','20',0,''),(343879,109916,'116844','furniture','padding-bottom','20',0,''),(343880,109918,'116846','furniture','link','payment_method',0,''),(343881,109918,'116846','furniture','float','right',0,''),(343882,109918,'116846','furniture','margin-top','-31',0,''),(343883,109919,'116847','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343884,109919,'116847','furniture','clear','none',0,''),(343885,109920,'116848','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(343886,109921,'116849','furniture','link','billing_address',0,''),(343887,109921,'116849','furniture','float','right',0,''),(343888,109921,'116849','furniture','margin-top','-31',0,''),(343889,109922,'116850','furniture','margin-bottom','20',0,''),(343890,109923,'116851','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343891,109923,'116851','furniture','clear','none',0,''),(343892,109924,'116852','furniture','block_type','1',0,''),(343893,109924,'116852','furniture','background-color','$content-bg-1',0,''),(343894,109924,'116852','furniture','padding-top','20',0,''),(343895,109924,'116852','furniture','padding-bottom','20',0,''),(343896,109924,'116852','furniture','padding-left','30',0,''),(343897,109924,'116852','furniture','padding-right','30',0,''),(343898,109924,'116852','furniture','margin-bottom','20',0,''),(343899,109924,'116852','furniture','color','$content-color-1',0,''),(343900,109925,'116853','furniture','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(343901,109926,'116854','furniture','hide_parents','2',0,''),(343902,109927,'116855','furniture','float','right',0,''),(343903,109927,'116855','furniture','margin-top','-37',0,''),(343904,109927,'116855','furniture','link','comments',0,''),(343905,109928,'116856','furniture','block_type','1',0,''),(343906,109928,'116856','furniture','padding-right','30',0,''),(343907,109928,'116856','furniture','padding-right','0',0,'5131'),(343908,109928,'116856','furniture','background-color','$content-bg-1',0,''),(343909,109928,'116856','furniture','padding-top','20',0,''),(343910,109928,'116856','furniture','padding-left','30',0,''),(343911,109928,'116856','furniture','padding-bottom','20',0,''),(343912,109928,'116856','furniture','color','$content-color-1',0,''),(343913,109929,'116857','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(343914,109930,'116858','furniture','link','products',0,''),(343915,109930,'116858','furniture','float','right',0,''),(343916,109930,'116858','furniture','margin-top','-37',0,''),(343917,109932,'116860','furniture','block_type','1',0,''),(343918,109932,'116860','furniture','padding-top','20',0,''),(343919,109932,'116860','furniture','padding-left','20',0,''),(343920,109932,'116860','furniture','padding-right','20',0,''),(343921,109932,'116860','furniture','padding-bottom','20',0,''),(343922,109932,'116860','furniture','background-color','$content-bg-1',0,''),(343923,109932,'116860','furniture','style_class','order-summary2 hiding-box',0,''),(343924,109932,'116860','furniture','color','$content-color-1',0,''),(343925,109933,'116861','furniture','margin-bottom','20',0,''),(343926,109933,'116861','furniture','text-align','right',0,''),(343927,109934,'116862','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(343928,109936,'116864','furniture','block_type','1',0,''),(343929,109936,'116864','furniture','background-color','$content-bg-2',0,''),(343930,109936,'116864','furniture','padding-bottom','30',0,''),(343931,109937,'116865','furniture','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(343932,109938,'116866','furniture','block_type','4',0,''),(343933,109938,'116866','furniture','schema','4-2',0,'5140'),(343934,109939,'116867','furniture','block_type','1',0,''),(343935,109939,'116867','furniture','padding-right','40',0,''),(343936,109939,'116867','furniture','padding-right','0',0,'5140'),(343937,109940,'116868','furniture','block_type','1',0,''),(343938,109940,'116868','furniture','background-color','$content-bg-1',0,''),(343939,109940,'116868','furniture','padding-top','20',0,''),(343940,109940,'116868','furniture','padding-bottom','20',0,''),(343941,109940,'116868','furniture','padding-left','30',0,''),(343942,109940,'116868','furniture','padding-right','30',0,''),(343943,109940,'116868','furniture','margin-bottom','20',0,''),(343944,109941,'116869','furniture','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(343945,109942,'116870','furniture','hide_parents','2',0,''),(343946,109943,'116871','furniture','float','right',0,''),(343947,109943,'116871','furniture','margin-top','-37',0,''),(343948,109943,'116871','furniture','link','comments',0,''),(343949,109944,'116872','furniture','block_type','2',0,''),(343950,109944,'116872','furniture','margin-bottom','20',0,''),(343951,109944,'116872','furniture','schema','2-2',0,'5131'),(343952,109944,'116872','furniture','background-color','$content-bg-1',0,''),(343953,109945,'116873','furniture','block_type','1',0,''),(343954,109945,'116873','furniture','border-right-width','20',0,''),(343955,109945,'116873','furniture','border-right-color','$content-border-1',0,''),(343956,109945,'116873','furniture','margin-right','-10',0,''),(343957,109945,'116873','furniture','padding-right','30',0,''),(343958,109945,'116873','furniture','padding-top','20',0,''),(343959,109945,'116873','furniture','padding-left','30',0,''),(343960,109945,'116873','furniture','padding-bottom','20',0,''),(343961,109945,'116873','furniture','border-right-width','0',0,'5140'),(343962,109945,'116873','furniture','margin-right','0',0,'5140'),(343963,109945,'116873','furniture','margin-bottom','20',0,'5140'),(343964,109945,'116873','furniture','padding-left','20',0,'5140'),(343965,109945,'116873','furniture','padding-right','20',0,'5140'),(343966,109946,'116874','furniture','link','contact_information',0,''),(343967,109946,'116874','furniture','margin-top','-31',0,''),(343968,109946,'116874','furniture','float','right',0,''),(343969,109949,'116877','furniture','link','payment_method',0,''),(343970,109949,'116877','furniture','float','right',0,''),(343971,109949,'116877','furniture','margin-top','-31',0,''),(343972,109950,'116878','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(343973,109950,'116878','furniture','padding-top','20',0,''),(343974,109951,'116879','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343975,109951,'116879','furniture','clear','none',0,''),(343976,109952,'116880','furniture','block_type','1',0,''),(343977,109952,'116880','furniture','padding-left','30',0,''),(343978,109952,'116880','furniture','border-left-width','20',0,''),(343979,109952,'116880','furniture','border-left-color','$content-border-1',0,''),(343980,109952,'116880','furniture','margin-left','-10',0,''),(343981,109952,'116880','furniture','padding-right','30',0,''),(343982,109952,'116880','furniture','padding-top','20',0,''),(343983,109952,'116880','furniture','padding-bottom','20',0,''),(343984,109952,'116880','furniture','border-left-width','0',0,'5140'),(343985,109953,'116881','furniture','margin-bottom','20',0,''),(343986,109954,'116882','furniture','link','billing_address',0,''),(343987,109954,'116882','furniture','float','right',0,''),(343988,109954,'116882','furniture','margin-top','-31',0,''),(343989,109955,'116883','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343990,109955,'116883','furniture','clear','none',0,''),(343991,109956,'116884','furniture','block_type','1',0,''),(343992,109956,'116884','furniture','padding-right','30',0,''),(343993,109956,'116884','furniture','background-color','$content-bg-1',0,''),(343994,109956,'116884','furniture','padding-top','20',0,''),(343995,109956,'116884','furniture','padding-left','30',0,''),(343996,109956,'116884','furniture','padding-bottom','20',0,''),(343997,109956,'116884','furniture','padding-left','20',0,'5140'),(343998,109956,'116884','furniture','padding-right','20',0,'5140'),(343999,109957,'116885','furniture','link','products',0,''),(344000,109957,'116885','furniture','float','right',0,''),(344001,109957,'116885','furniture','margin-top','-37',0,''),(344002,109958,'116886','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(344003,109959,'116887','furniture','margin-bottom','20',0,''),(344004,109960,'116888','furniture','block_type','1',0,''),(344005,109960,'116888','furniture','padding-top','20',0,''),(344006,109960,'116888','furniture','padding-left','20',0,''),(344007,109960,'116888','furniture','padding-right','20',0,''),(344008,109960,'116888','furniture','padding-bottom','20',0,''),(344009,109960,'116888','furniture','background-color','$content-bg-1',0,''),(344010,109960,'116888','furniture','style_class','order-summary',0,''),(344011,109961,'116889','furniture','margin-bottom','20',0,''),(344012,109961,'116889','furniture','text-align','right',0,''),(344013,109963,'116891','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(344014,109964,'116892','furniture','block_type','1',0,''),(344015,109964,'116892','furniture','background-color','$content-bg-2',0,''),(344016,109964,'116892','furniture','padding-bottom','30',0,''),(344017,109965,'116893','furniture','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(344018,109966,'116894','furniture','block_type','4',0,''),(344019,109966,'116894','furniture','schema','4-2',0,'5140'),(344020,109967,'116895','furniture','block_type','1',0,''),(344021,109967,'116895','furniture','padding-right','40',0,''),(344022,109967,'116895','furniture','padding-right','0',0,'5140'),(344023,109968,'116896','furniture','block_type','1',0,''),(344024,109968,'116896','furniture','padding-right','30',0,''),(344025,109968,'116896','furniture','background-color','$content-bg-1',0,''),(344026,109968,'116896','furniture','padding-top','20',0,''),(344027,109968,'116896','furniture','padding-left','30',0,''),(344028,109968,'116896','furniture','padding-bottom','20',0,''),(344029,109968,'116896','furniture','padding-left','20',0,'5140'),(344030,109968,'116896','furniture','padding-right','20',0,'5140'),(344031,109970,'116898','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(344032,109971,'116899','furniture','link','products',0,''),(344033,109971,'116899','furniture','float','right',0,''),(344034,109971,'116899','furniture','margin-top','-37',0,''),(344035,109972,'116900','furniture','block_type','2',0,''),(344036,109972,'116900','furniture','margin-bottom','20',0,''),(344037,109972,'116900','furniture','schema','2-2',0,'5131'),(344038,109972,'116900','furniture','background-color','$content-bg-1',0,''),(344039,109973,'116901','furniture','block_type','1',0,''),(344040,109973,'116901','furniture','border-right-width','20',0,''),(344041,109973,'116901','furniture','border-right-color','$content-border-1',0,''),(344042,109973,'116901','furniture','margin-right','-10',0,''),(344043,109973,'116901','furniture','padding-right','30',0,''),(344044,109973,'116901','furniture','padding-top','20',0,''),(344045,109973,'116901','furniture','padding-left','30',0,''),(344046,109973,'116901','furniture','padding-bottom','20',0,''),(344047,109973,'116901','furniture','border-right-width','0',0,'5140'),(344048,109973,'116901','furniture','margin-right','0',0,'5140'),(344049,109973,'116901','furniture','margin-bottom','20',0,'5140'),(344050,109973,'116901','furniture','padding-left','20',0,'5140'),(344051,109973,'116901','furniture','padding-right','20',0,'5140'),(344052,109974,'116902','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(344053,109975,'116903','furniture','link','contact_information',0,''),(344054,109975,'116903','furniture','margin-top','-31',0,''),(344055,109975,'116903','furniture','float','right',0,''),(344056,109976,'116904','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(344057,109976,'116904','furniture','clear','none',0,''),(344058,109978,'116906','furniture','margin-bottom','20',0,''),(344059,109980,'116908','furniture','link','shipping_address',0,''),(344060,109980,'116908','furniture','float','right',0,''),(344061,109980,'116908','furniture','margin-top','-31',0,''),(344062,109982,'116910','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(344063,109982,'116910','furniture','padding-top','20',0,''),(344064,109983,'116911','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(344065,109983,'116911','furniture','clear','none',0,''),(344066,109984,'116912','furniture','link','shipping_method',0,''),(344067,109984,'116912','furniture','float','right',0,''),(344068,109984,'116912','furniture','margin-top','-31',0,''),(344069,109985,'116913','furniture','block_type','1',0,''),(344070,109985,'116913','furniture','padding-left','30',0,''),(344071,109985,'116913','furniture','border-left-width','20',0,''),(344072,109985,'116913','furniture','border-left-color','$content-border-1',0,''),(344073,109985,'116913','furniture','margin-left','-10',0,''),(344074,109985,'116913','furniture','padding-right','30',0,''),(344075,109985,'116913','furniture','padding-top','20',0,''),(344076,109985,'116913','furniture','padding-bottom','20',0,''),(344077,109985,'116913','furniture','border-left-width','0',0,'5140'),(344078,109986,'116914','furniture','link','billing_address',0,''),(344079,109986,'116914','furniture','float','right',0,''),(344080,109986,'116914','furniture','margin-top','-31',0,''),(344081,109987,'116915','furniture','margin-bottom','20',0,''),(344082,109989,'116917','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(344083,109990,'116918','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(344084,109990,'116918','furniture','clear','none',0,''),(344085,109991,'116919','furniture','link','payment_method',0,''),(344086,109991,'116919','furniture','float','right',0,''),(344087,109991,'116919','furniture','margin-top','-31',0,''),(344088,109992,'116920','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(344089,109992,'116920','furniture','clear','none',0,''),(344090,109993,'116921','furniture','block_type','1',0,''),(344091,109993,'116921','furniture','background-color','$content-bg-1',0,''),(344092,109993,'116921','furniture','padding-top','20',0,''),(344093,109993,'116921','furniture','padding-bottom','20',0,''),(344094,109993,'116921','furniture','padding-left','30',0,''),(344095,109993,'116921','furniture','padding-right','30',0,''),(344096,109993,'116921','furniture','margin-bottom','20',0,''),(344097,109994,'116922','furniture','hide_parents','2',0,''),(344098,109995,'116923','furniture','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(344099,109996,'116924','furniture','float','right',0,''),(344100,109996,'116924','furniture','margin-top','-37',0,''),(344101,109996,'116924','furniture','link','comments',0,''),(344102,109997,'116925','furniture','block_type','1',0,''),(344103,109997,'116925','furniture','padding-top','20',0,''),(344104,109997,'116925','furniture','padding-left','20',0,''),(344105,109997,'116925','furniture','padding-right','20',0,''),(344106,109997,'116925','furniture','padding-bottom','20',0,''),(344107,109997,'116925','furniture','background-color','$content-bg-1',0,''),(344108,109997,'116925','furniture','style_class','order-summary',0,''),(344109,109998,'116926','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(344110,110000,'116928','furniture','margin-bottom','20',0,''),(344111,110000,'116928','furniture','text-align','right',0,''),(344112,110001,'116929','furniture','block_type','1',0,''),(344113,110001,'116929','furniture','background-color','$content-bg-2',0,''),(344114,110001,'116929','furniture','padding-bottom','30',0,''),(344115,110002,'116930','furniture','block_type','4',0,''),(344116,110002,'116930','furniture','schema','4-2',0,'5140'),(344117,110003,'116931','furniture','block_type','1',0,''),(344118,110003,'116931','furniture','padding-right','40',0,''),(344119,110003,'116931','furniture','padding-right','0',0,'5140'),(344120,110004,'116932','furniture','block_type','2',0,''),(344121,110004,'116932','furniture','margin-bottom','20',0,''),(344122,110004,'116932','furniture','schema','2-2',0,'5131'),(344123,110004,'116932','furniture','background-color','$content-bg-1',0,''),(344124,110005,'116933','furniture','block_type','1',0,''),(344125,110005,'116933','furniture','border-right-width','20',0,''),(344126,110005,'116933','furniture','border-right-color','$content-border-1',0,''),(344127,110005,'116933','furniture','margin-right','-10',0,''),(344128,110005,'116933','furniture','padding-right','30',0,''),(344129,110005,'116933','furniture','padding-top','20',0,''),(344130,110005,'116933','furniture','padding-left','30',0,''),(344131,110005,'116933','furniture','padding-bottom','20',0,''),(344132,110005,'116933','furniture','border-right-width','0',0,'5140'),(344133,110005,'116933','furniture','margin-right','0',0,'5140'),(344134,110005,'116933','furniture','margin-bottom','20',0,'5140'),(344135,110005,'116933','furniture','padding-left','20',0,'5140'),(344136,110005,'116933','furniture','padding-right','20',0,'5140'),(344137,110006,'116934','furniture','margin-bottom','20',0,''),(344138,110007,'116935','furniture','link','shipping_address',0,''),(344139,110007,'116935','furniture','float','right',0,''),(344140,110007,'116935','furniture','margin-top','-31',0,''),(344141,110008,'116936','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(344142,110008,'116936','furniture','clear','none',0,''),(344143,110011,'116939','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(344144,110012,'116940','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(344145,110012,'116940','furniture','clear','none',0,''),(344146,110013,'116941','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(344147,110013,'116941','furniture','padding-top','20',0,''),(344148,110015,'116943','furniture','link','shipping_method',0,''),(344149,110015,'116943','furniture','float','right',0,''),(344150,110015,'116943','furniture','margin-top','-31',0,''),(344151,110016,'116944','furniture','link','contact_information',0,''),(344152,110016,'116944','furniture','margin-top','-31',0,''),(344153,110016,'116944','furniture','float','right',0,''),(344154,110017,'116945','furniture','block_type','1',0,''),(344155,110017,'116945','furniture','padding-left','30',0,''),(344156,110017,'116945','furniture','border-left-width','20',0,''),(344157,110017,'116945','furniture','border-left-color','$content-border-1',0,''),(344158,110017,'116945','furniture','margin-left','-10',0,''),(344159,110017,'116945','furniture','padding-right','30',0,''),(344160,110017,'116945','furniture','padding-top','20',0,''),(344161,110017,'116945','furniture','padding-bottom','20',0,''),(344162,110017,'116945','furniture','border-left-width','0',0,'5140'),(344163,110018,'116946','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(344164,110018,'116946','furniture','clear','none',0,''),(344165,110019,'116947','furniture','margin-bottom','20',0,''),(344166,110020,'116948','furniture','link','billing_address',0,''),(344167,110020,'116948','furniture','float','right',0,''),(344168,110020,'116948','furniture','margin-top','-31',0,''),(344169,110022,'116950','furniture','link','payment_method',0,''),(344170,110022,'116950','furniture','float','right',0,''),(344171,110022,'116950','furniture','margin-top','-31',0,''),(344172,110023,'116951','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(344173,110024,'116952','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(344174,110024,'116952','furniture','clear','none',0,''),(344175,110025,'116953','furniture','block_type','1',0,''),(344176,110025,'116953','furniture','padding-right','30',0,''),(344177,110025,'116953','furniture','background-color','$content-bg-1',0,''),(344178,110025,'116953','furniture','padding-top','20',0,''),(344179,110025,'116953','furniture','padding-left','30',0,''),(344180,110025,'116953','furniture','padding-bottom','20',0,''),(344181,110025,'116953','furniture','padding-left','20',0,'5140'),(344182,110025,'116953','furniture','padding-right','20',0,'5140'),(344183,110026,'116954','furniture','link','products',0,''),(344184,110026,'116954','furniture','float','right',0,''),(344185,110026,'116954','furniture','margin-top','-37',0,''),(344186,110027,'116955','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(344187,110029,'116957','furniture','block_type','1',0,''),(344188,110029,'116957','furniture','background-color','$content-bg-1',0,''),(344189,110029,'116957','furniture','padding-top','20',0,''),(344190,110029,'116957','furniture','padding-bottom','20',0,''),(344191,110029,'116957','furniture','padding-left','30',0,''),(344192,110029,'116957','furniture','padding-right','30',0,''),(344193,110029,'116957','furniture','margin-bottom','20',0,''),(344194,110030,'116958','furniture','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(344195,110031,'116959','furniture','float','right',0,''),(344196,110031,'116959','furniture','margin-top','-37',0,''),(344197,110031,'116959','furniture','link','comments',0,''),(344198,110032,'116960','furniture','hide_parents','2',0,''),(344199,110033,'116961','furniture','block_type','1',0,''),(344200,110033,'116961','furniture','padding-top','20',0,''),(344201,110033,'116961','furniture','padding-left','20',0,''),(344202,110033,'116961','furniture','padding-right','20',0,''),(344203,110033,'116961','furniture','padding-bottom','20',0,''),(344204,110033,'116961','furniture','background-color','$content-bg-1',0,''),(344205,110033,'116961','furniture','style_class','order-summary',0,''),(344206,110035,'116963','furniture','margin-bottom','20',0,''),(344207,110035,'116963','furniture','text-align','right',0,''),(344208,110036,'116964','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(344209,110037,'116965','furniture','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(344210,110038,'116966','furniture','block_type','1',0,''),(344211,110040,'116968','furniture','block_type','2',0,''),(344212,110040,'116968','furniture','font-weight','400',0,''),(344213,110040,'116968','furniture','padding-bottom','20',0,''),(344214,110040,'116968','furniture','schema','2-2',0,'5140'),(344215,110041,'116969','furniture','show_captcha','on',0,''),(344216,110042,'116970','furniture','font-weight','400',0,''),(344217,110042,'116970','furniture','padding-left','40',0,''),(344218,110042,'116970','furniture','time_format','24',0,''),(344219,110042,'116970','furniture','show_icons','on',0,''),(344220,110042,'116970','furniture','padding-left','0',0,'5140'),(344221,110043,'116971','furniture','block_type','1',0,''),(344222,110044,'116972','furniture','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(344223,110045,'116973','furniture','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(344224,110045,'116973','furniture','margin-bottom','40',0,''),(344225,110046,'116102.000001','furniture','block_type','1',0,''),(344226,110047,'116103.000001','furniture','block_type','6',0,''),(344227,110047,'116103.000001','furniture','schema','6-3',0,'5140'),(344228,110048,'116104.000001','furniture','aria_name','account-menu',0,''),(344286,110068,'116109.000001','furniture','text','<h1>##CREDIT_AMOUNT_HISTORY##</h1>',0,''),(344287,110069,'1638895944.9672','furniture','margin-bottom','20',0,''),(344288,110070,'116974','furniture','width','680',0,''),(344289,110070,'116974','furniture','font-weight','normal',0,''),(344290,110070,'116974','furniture','font-size','12',0,''),(344291,110070,'116974','furniture','padding-top','20',0,''),(344292,110070,'116974','furniture','padding-bottom','20',0,''),(344293,110070,'116974','furniture','color','$content-color-1',0,''),(344294,110071,'116975','furniture','block_type','3',0,''),(344295,110071,'116975','furniture','font-weight','normal',0,''),(344296,110071,'116975','furniture','padding-top','20',0,''),(344297,110072,'116976','furniture','font-size','12',0,''),(344298,110073,'116977','furniture','text','<p>If undelivered please return to:</p>',1,''),(344299,110073,'116977','furniture','font-size','12',0,''),(344300,110073,'116977','furniture','font-weight','bold',0,''),(344301,110073,'116977','furniture','text','<p>If undelivered please return to:</p>',2,''),(344302,110073,'116977','furniture','text','<p>If undelivered please return to:</p>',3,''),(344303,110073,'116977','furniture','text','<p>If undelivered please return to:</p>',4,''),(344304,110074,'116978','furniture','text','<p>Thank you for your order</p>',1,''),(344305,110074,'116978','furniture','color','$content-color-1',0,''),(344306,110074,'116978','furniture','font-size','13',0,''),(344307,110074,'116978','furniture','font-weight','bold',0,''),(344308,110074,'116978','furniture','padding-top','5',0,''),(344309,110074,'116978','furniture','text-align','center',0,''),(344310,110074,'116978','furniture','text','<p>Thank you for your order</p>',2,''),(344311,110074,'116978','furniture','text','<p>Thank you for your order</p>',3,''),(344312,110074,'116978','furniture','text','<p>Thank you for your order</p>',4,''),(344313,110075,'116979','furniture','font-weight','400',0,''),(344314,110075,'116979','furniture','text-align','center',0,''),(344315,110075,'116979','furniture','padding-top','0',0,''),(344317,110075,'116979','furniture','padding-left','20',0,''),(344318,110075,'116979','furniture','padding-right','20',0,''),(344322,110076,'116980','furniture','text','<p>If something has gone wrong please contact us at:</p>',1,''),(344323,110076,'116980','furniture','font-size','12',0,''),(344324,110076,'116980','furniture','font-weight','bold',0,''),(344325,110076,'116980','furniture','text-align','right',0,''),(344326,110076,'116980','furniture','text','<p>If something has gone wrong please contact us at:</p>',2,''),(344327,110076,'116980','furniture','text','<p>If something has gone wrong please contact us at:</p>',3,''),(344328,110076,'116980','furniture','text','<p>If something has gone wrong please contact us at:</p>',4,''),(344329,110077,'116981','furniture','block_type','6',0,''),(344330,110077,'116981','furniture','font-weight','normal',0,''),(344331,110077,'116981','furniture','font-size','16',0,''),(344332,110078,'116982','furniture','text','<p>Email:</p>',1,''),(344333,110078,'116982','furniture','font-weight','normal',0,''),(344334,110078,'116982','furniture','text-align','right',0,''),(344335,110078,'116982','furniture','font-size','12',0,''),(344336,110078,'116982','furniture','text','<p>Email:</p>',2,''),(344337,110078,'116982','furniture','text','<p>Email:</p>',3,''),(344338,110078,'116982','furniture','text','<p>Email:</p>',4,''),(344339,110079,'116983','furniture','font-weight','normal',0,''),(344340,110079,'116983','furniture','text-align','right',0,''),(344341,110079,'116983','furniture','font-size','12',0,''),(344342,110080,'116984','furniture','block_type','6',0,''),(344343,110080,'116984','furniture','font-weight','normal',0,''),(344344,110080,'116984','furniture','font-size','16',0,''),(344345,110081,'116985','furniture','text','<p>Phone:</p>',1,''),(344346,110081,'116985','furniture','font-weight','normal',0,''),(344347,110081,'116985','furniture','text-align','right',0,''),(344348,110081,'116985','furniture','font-size','12',0,''),(344349,110081,'116985','furniture','text','<p>Phone:</p>',2,''),(344350,110081,'116985','furniture','text','<p>Phone:</p>',3,''),(344351,110081,'116985','furniture','text','<p>Phone:</p>',4,''),(344352,110082,'116986','furniture','font-weight','normal',0,''),(344353,110082,'116986','furniture','text-align','right',0,''),(344354,110082,'116986','furniture','font-size','12',0,''),(344355,110083,'116987','furniture','font-weight','400',0,''),(344356,110083,'116987','furniture','padding-top','20',0,''),(344357,110083,'116987','furniture','padding-bottom','0',0,''),(344358,110083,'116987','furniture','font-size','12',0,''),(344359,110084,'116988','furniture','block_type','2',0,''),(344360,110084,'116988','furniture','font-weight','normal',0,''),(344361,110084,'116988','furniture','padding-bottom','20',0,''),(344362,110085,'116989','furniture','font-weight','400',0,''),(344363,110085,'116989','furniture','padding-top','20',0,''),(344368,110086,'116990','furniture','block_type','11',0,''),(344369,110086,'116990','furniture','font-weight','normal',0,''),(344370,110087,'116991','furniture','text','<p>Web:</p>',1,''),(344371,110087,'116991','furniture','font-weight','normal',0,''),(344372,110087,'116991','furniture','text-align','right',0,''),(344373,110087,'116991','furniture','text','<p>Web:</p>',2,''),(344374,110087,'116991','furniture','text','<p>Web:</p>',3,''),(344375,110087,'116991','furniture','text','<p>Web:</p>',4,''),(344376,110088,'116992','furniture','font-weight','normal',0,''),(344377,110088,'116992','furniture','text-align','right',0,''),(344378,110089,'116993','furniture','block_type','11',0,''),(344379,110089,'116993','furniture','font-weight','normal',0,''),(344380,110090,'116994','furniture','text','<p>Phone:</p>',1,''),(344381,110090,'116994','furniture','font-weight','normal',0,''),(344382,110090,'116994','furniture','text-align','right',0,''),(344383,110090,'116994','furniture','text','<p>Phone:</p>',2,''),(344384,110090,'116994','furniture','text','<p>Phone:</p>',3,''),(344385,110090,'116994','furniture','text','<p>Phone:</p>',4,''),(344386,110091,'116995','furniture','font-weight','normal',0,''),(344387,110091,'116995','furniture','text-align','right',0,''),(344388,110092,'116996','furniture','block_type','11',0,''),(344389,110092,'116996','furniture','font-weight','normal',0,''),(344390,110093,'116997','furniture','text','<p>Email:</p>',1,''),(344391,110093,'116997','furniture','font-weight','normal',0,''),(344392,110093,'116997','furniture','text-align','right',0,''),(344393,110093,'116997','furniture','text','<p>Email:</p>',2,''),(344394,110093,'116997','furniture','text','<p>Email:</p>',3,''),(344395,110093,'116997','furniture','text','<p>Email:</p>',4,''),(344396,110094,'116998','furniture','font-weight','normal',0,''),(344397,110094,'116998','furniture','text-align','right',0,''),(344398,110095,'116999','furniture','block_type','1',0,''),(344399,110096,'117000','furniture','font-weight','normal',0,''),(344400,110096,'117000','furniture','text-align','right',0,''),(344401,110096,'117000','furniture','padding-bottom','10',0,''),(344402,110096,'117000','furniture','address_spacer',',',0,''),(344403,110096,'117000','furniture','font-size','12',0,''),(344404,110097,'117001','furniture','block_type','5',0,''),(344405,110097,'117001','furniture','font-weight','normal',0,''),(344406,110097,'117001','furniture','border-bottom-width','1',0,''),(344407,110097,'117001','furniture','border-bottom-color','$content-border-1',0,''),(344408,110097,'117001','furniture','border-top-width','1',0,''),(344409,110097,'117001','furniture','border-top-color','$content-border-1',0,''),(344410,110097,'117001','furniture','border-left-color','$content-border-1',0,''),(344411,110097,'117001','furniture','border-left-width','1',0,''),(344412,110098,'117002','furniture','block_type','1',0,''),(344413,110098,'117002','furniture','font-weight','normal',0,''),(344414,110098,'117002','furniture','padding-top','10',0,''),(344415,110098,'117002','furniture','padding-left','10',0,''),(344416,110098,'117002','furniture','padding-right','10',0,''),(344417,110099,'117003','furniture','font-weight','400',0,''),(344418,110099,'117003','furniture','line-height','120',0,''),(344419,110099,'117003','furniture','line_height_measure','%',0,''),(344420,110099,'117003','furniture','font-size','12',0,''),(344421,110100,'117004','furniture','text','<p>SHIPPING ADDRESS:</p>',1,''),(344422,110100,'117004','furniture','font-size','14',0,''),(344423,110100,'117004','furniture','font-weight','bold',0,''),(344424,110100,'117004','furniture','padding-bottom','10',0,''),(344425,110100,'117004','furniture','text','<p>SHIPPING ADDRESS:</p>',2,''),(344426,110100,'117004','furniture','text','<p>SHIPPING ADDRESS:</p>',3,''),(344427,110100,'117004','furniture','text','<p>SHIPPING ADDRESS:</p>',4,''),(344428,110101,'117005','furniture','block_type','1',0,''),(344429,110101,'117005','furniture','background-color','$content-bg-2',0,''),(344430,110101,'117005','furniture','padding-top','20',0,''),(344431,110101,'117005','furniture','padding-left','10',0,''),(344432,110101,'117005','furniture','padding-right','10',0,''),(344433,110101,'117005','furniture','padding-bottom','20',0,''),(344434,110101,'117005','furniture','font-size','14',0,''),(344435,110102,'117006','furniture','block_type','4',0,''),(344436,110102,'117006','furniture','font-weight','normal',0,''),(344437,110102,'117006','furniture','border-top-width','1',0,''),(344438,110102,'117006','furniture','border-top-color','$content-border-1',0,''),(344439,110102,'117006','furniture','border-left-width','1',0,''),(344440,110102,'117006','furniture','border-left-color','$content-border-1',0,''),(344441,110102,'117006','furniture','border-right-width','1',0,''),(344442,110102,'117006','furniture','border-right-color','$content-border-1',0,''),(344443,110102,'117006','furniture','border-bottom-width','1',0,''),(344444,110102,'117006','furniture','border-bottom-color','$content-border-1',0,''),(344445,110103,'117007','furniture','block_type','2',0,''),(344446,110103,'117007','furniture','font-weight','normal',0,''),(344447,110103,'117007','furniture','border-right-width','1',0,''),(344448,110103,'117007','furniture','border-right-color','$content-border-1',0,''),(344449,110104,'117008','furniture','block_type','1',0,''),(344450,110104,'117008','furniture','font-weight','400',0,''),(344451,110104,'117008','furniture','background-color','$content-bg-2',0,''),(344452,110104,'117008','furniture','padding-top','10',0,''),(344453,110104,'117008','furniture','padding-left','10',0,''),(344454,110104,'117008','furniture','padding-right','10',0,''),(344455,110104,'117008','furniture','padding-bottom','30',0,''),(344456,110105,'117009','furniture','text','<p>INVOICE ADDRESS:</p>',1,''),(344457,110105,'117009','furniture','font-size','14',0,''),(344458,110105,'117009','furniture','font-weight','bold',0,''),(344459,110105,'117009','furniture','text','<p>INVOICE ADDRESS:</p>',2,''),(344460,110105,'117009','furniture','text','<p>INVOICE ADDRESS:</p>',3,''),(344461,110105,'117009','furniture','text','<p>INVOICE ADDRESS:</p>',4,''),(344462,110106,'117010','furniture','font-size','12',0,''),(344463,110107,'117011','furniture','block_type','1',0,''),(344464,110107,'117011','furniture','font-weight','normal',0,''),(344465,110107,'117011','furniture','padding-top','10',0,''),(344466,110107,'117011','furniture','padding-left','10',0,''),(344467,110107,'117011','furniture','padding-right','10',0,''),(344468,110107,'117011','furniture','padding-bottom','10',0,''),(344469,110108,'117012','furniture','font-weight','normal',0,''),(344470,110109,'117013','furniture','text','<p>CUSTOMER:</p>',1,''),(344471,110109,'117013','furniture','font-size','13',0,''),(344472,110109,'117013','furniture','font-weight','bold',0,''),(344473,110109,'117013','furniture','text','<p>CUSTOMER:</p>',2,''),(344474,110109,'117013','furniture','text','<p>CUSTOMER:</p>',3,''),(344475,110109,'117013','furniture','text','<p>CUSTOMER:</p>',4,''),(344476,110110,'117014','furniture','text','<p>PHONE NUMBER:</p>',1,''),(344477,110110,'117014','furniture','font-size','14',0,''),(344478,110110,'117014','furniture','font-weight','bold',0,''),(344479,110110,'117014','furniture','padding-top','10',0,''),(344480,110110,'117014','furniture','text','<p>PHONE NUMBER:</p>',2,''),(344481,110110,'117014','furniture','text','<p>PHONE NUMBER:</p>',3,''),(344482,110110,'117014','furniture','text','<p>PHONE NUMBER:</p>',4,''),(344483,110111,'117015','furniture','font-weight','normal',0,''),(344484,110113,'117017','furniture','text','<p>E-MAIL ADDRESS:</p>',1,''),(344485,110113,'117017','furniture','font-weight','bold',0,''),(344486,110113,'117017','furniture','font-size','14',0,''),(344487,110113,'117017','furniture','padding-top','10',0,''),(344488,110113,'117017','furniture','text','<p>E-MAIL ADDRESS:</p>',2,''),(344489,110113,'117017','furniture','text','<p>E-MAIL ADDRESS:</p>',3,''),(344490,110113,'117017','furniture','text','<p>E-MAIL ADDRESS:</p>',4,''),(344491,110114,'117018','furniture','block_type','2',0,''),(344492,110114,'117018','furniture','font-weight','normal',0,''),(344493,110114,'117018','furniture','border-top-width','1',0,''),(344494,110114,'117018','furniture','border-top-color','$content-border-1',0,''),(344495,110114,'117018','furniture','border-right-width','1',0,''),(344496,110114,'117018','furniture','border-right-color','$content-border-1',0,''),(344497,110115,'117019','furniture','block_type','1',0,''),(344498,110115,'117019','furniture','font-weight','normal',0,''),(344499,110115,'117019','furniture','padding-top','10',0,''),(344500,110115,'117019','furniture','padding-left','10',0,''),(344501,110115,'117019','furniture','padding-right','10',0,''),(344502,110115,'117019','furniture','padding-bottom','10',0,''),(344503,110115,'117019','furniture','border-right-width','1',0,''),(344504,110115,'117019','furniture','border-right-color','$content-border-1',0,''),(344505,110117,'117021','furniture','text','<p>Shipping via</p>',1,''),(344506,110117,'117021','furniture','font-weight','bold',0,''),(344507,110117,'117021','furniture','font-size','14',0,''),(344508,110117,'117021','furniture','text','<p>Shipping via</p>',2,''),(344509,110117,'117021','furniture','text','<p>Shipping via</p>',3,''),(344510,110117,'117021','furniture','text','<p>Shipping via</p>',4,''),(344511,110118,'117022','furniture','block_type','1',0,''),(344512,110118,'117022','furniture','font-weight','normal',0,''),(344513,110118,'117022','furniture','padding-top','10',0,''),(344514,110118,'117022','furniture','padding-left','10',0,''),(344515,110118,'117022','furniture','padding-right','10',0,''),(344516,110118,'117022','furniture','padding-bottom','10',0,''),(344517,110119,'117023','furniture','text','<p>Shipping service</p>',1,''),(344518,110119,'117023','furniture','font-weight','bold',0,''),(344519,110119,'117023','furniture','font-size','14',0,''),(344520,110119,'117023','furniture','text','<p>Shipping service</p>',2,''),(344521,110119,'117023','furniture','text','<p>Shipping service</p>',3,''),(344522,110119,'117023','furniture','text','<p>Shipping service</p>',4,''),(344523,110121,'117025','furniture','font-size','14',0,''),(344524,110121,'117025','furniture','font-weight','bold',0,''),(344525,110121,'117025','furniture','text-align','center',0,''),(344526,110121,'117025','furniture','padding-bottom','10',0,''),(344527,110121,'117025','furniture','padding-top','10',0,''),(344528,110122,'117026','furniture','text','<p>Payment date:</p>',1,''),(344529,110122,'117026','furniture','font-weight','bold',0,''),(344530,110122,'117026','furniture','text-align','center',0,''),(344531,110122,'117026','furniture','font-size','12',0,''),(344532,110122,'117026','furniture','text','<p>Payment date:</p>',2,''),(344533,110122,'117026','furniture','text','<p>Payment date:</p>',3,''),(344534,110122,'117026','furniture','text','<p>Payment date:</p>',4,''),(344535,110123,'117027','furniture','font-weight','normal',0,''),(344536,110123,'117027','furniture','text-align','center',0,''),(344537,110123,'117027','furniture','padding-bottom','10',0,''),(344538,110124,'117034','furniture','text-align','center',0,''),(344539,110124,'117034','furniture','padding-top','10',0,''),(344540,110125,'1639155816.3893','furniture','block_type','1',0,''),(344541,110126,'117028','furniture','padding-top','30',0,''),(344542,110126,'117028','furniture','padding-bottom','30',0,''),(344543,110130,'117032','furniture','col_in_row','4',0,''),(344544,110130,'117032','furniture','listing_type','productListing',0,''),(344545,110130,'117032','furniture','view_as','carousel',0,''),(344546,110130,'117032','furniture','col_in_row','3',0,'5140'),(344547,110130,'117032','furniture','col_in_row','2',0,'5131'),(344548,110130,'117032','furniture','col_in_row','1',0,'5161'),(344549,110132,'1639485067.5512','furniture','padding-top','30',0,''),(344550,110132,'1639485067.5512','furniture','padding-bottom','30',0,''),(344551,110134,'1639154415.2739','furniture','block_type','1',0,''),(344552,110136,'117036','furniture','heading_type','h1',0,''),(344553,110137,'1639419797.9718','furniture','page_id','4',0,''),(344554,110137,'1639419797.9718','furniture','padding-top','30',0,''),(344555,110137,'1639419797.9718','furniture','padding-bottom','30',0,''),(344556,110140,'117039','furniture','text-align','center',0,''),(344557,110140,'117039','furniture','padding-top','10',0,''),(344558,110145,'117044','furniture','block_type','1',0,''),(344559,110146,'117045','furniture','block_type','1',0,''),(344560,110146,'117045','furniture','max-width','800',0,''),(344561,110146,'117045','furniture','margin','0 auto',0,''),(344562,110146,'117045','furniture','background-color','$content-bg-1',0,''),(344563,110147,'117046','furniture','color','$content-color-1',0,''),(344564,110147,'117046','furniture','font-size','12',0,''),(344565,110147,'117046','furniture','padding-top','20',0,''),(344566,110147,'117046','furniture','padding-bottom','20',0,''),(344567,110147,'117046','furniture','border-top-width','1',0,''),(344568,110147,'117046','furniture','border-top-color','$content-border-1',0,''),(344569,110148,'117047','furniture','font-weight','normal',0,''),(344570,110148,'117047','furniture','padding-top','20',0,''),(344571,110148,'117047','furniture','padding-left','10',0,''),(344572,110148,'117047','furniture','padding-right','10',0,''),(344573,110148,'117047','furniture','padding-bottom','20',0,''),(344574,110148,'117047','furniture','color','$content-color-1',0,''),(344575,110148,'117047','furniture','font-size','14',0,''),(344576,110149,'117048','furniture','block_type','7',0,''),(344577,110149,'117048','furniture','font-weight','normal',0,''),(344578,110149,'117048','furniture','background-color','$header-menu-bg-1',0,''),(344579,110149,'117048','furniture','padding-top','5',0,''),(344580,110149,'117048','furniture','padding-left','10',0,''),(344581,110149,'117048','furniture','padding-right','10',0,''),(344582,110149,'117048','furniture','padding-bottom','5',0,''),(344583,110150,'117049','furniture','color','$highlight-box-color-2',0,''),(344584,110150,'117049','furniture','font-size','14',0,''),(344585,110150,'117049','furniture','font-weight','normal',0,''),(344586,110151,'117050','furniture','font-weight','normal',0,''),(344587,110151,'117050','furniture','text-align','right',0,''),(344588,110151,'117050','furniture','color','$highlight-box-color-2',0,''),(344589,110151,'117050','furniture','font-size','12',0,''),(344590,110152,'117051','furniture','font-weight','normal',0,''),(344591,110152,'117051','furniture','padding-bottom','10',0,''),(344592,110152,'117051','furniture','padding-top','10',0,''),(344593,110152,'117051','furniture','logo_from','theme',0,''),(344594,110152,'117051','furniture','padding-left','20',0,''),(344595,110152,'117051','furniture','background-color','$header-bg-1',0,''),(344596,110153,'117052','furniture','block_type','1',0,''),(344597,110154,'117053','furniture','block_type','1',0,''),(344598,110154,'117053','furniture','max-width','800',0,''),(344599,110154,'117053','furniture','margin','0 auto',0,''),(344600,110154,'117053','furniture','background-color','$content-bg-1',0,''),(344601,110155,'117054','furniture','color','$content-color-1',0,''),(344602,110155,'117054','furniture','font-size','12',0,''),(344603,110155,'117054','furniture','padding-top','20',0,''),(344604,110155,'117054','furniture','padding-bottom','20',0,''),(344605,110155,'117054','furniture','border-top-width','1',0,''),(344606,110155,'117054','furniture','border-top-color','$content-border-1',0,''),(344607,110156,'117055','furniture','font-weight','normal',0,''),(344608,110156,'117055','furniture','padding-bottom','10',0,''),(344609,110156,'117055','furniture','background-color','$highlight-box-bg-2',0,''),(344611,110156,'117055','furniture','padding-left','20',0,''),(344612,110156,'117055','furniture','padding-top','10',0,''),(344616,110157,'117056','furniture','font-weight','normal',0,''),(344617,110157,'117056','furniture','padding-top','20',0,''),(344618,110157,'117056','furniture','padding-left','10',0,''),(344619,110157,'117056','furniture','padding-right','10',0,''),(344620,110157,'117056','furniture','padding-bottom','20',0,''),(344621,110157,'117056','furniture','color','$content-color-1',0,''),(344622,110157,'117056','furniture','font-size','14',0,''),(344623,110158,'117057','furniture','block_type','7',0,''),(344624,110158,'117057','furniture','font-weight','normal',0,''),(344625,110158,'117057','furniture','background-color','$highlight-box-bg-2',0,''),(344626,110158,'117057','furniture','padding-top','5',0,''),(344627,110158,'117057','furniture','padding-left','10',0,''),(344628,110158,'117057','furniture','padding-right','10',0,''),(344629,110158,'117057','furniture','padding-bottom','5',0,''),(344630,110159,'117058','furniture','color','$highlight-box-color-2',0,''),(344631,110159,'117058','furniture','font-size','15',0,''),(344632,110159,'117058','furniture','font-weight','700',0,''),(344633,110160,'117059','furniture','font-weight','normal',0,''),(344634,110160,'117059','furniture','text-align','right',0,''),(344635,110160,'117059','furniture','color','$fade-color-1',0,''),(344636,110160,'117059','furniture','font-size','12',0,''),(344637,110161,'117060','furniture','block_type','1',0,''),(344638,110161,'117060','furniture','background-color','$content-bg-2',0,''),(344639,110162,'117061','furniture','block_type','1',0,''),(344640,110162,'117061','furniture','max-width','800',0,''),(344641,110162,'117061','furniture','margin','0 auto',0,''),(344642,110163,'117062','furniture','block_type','1',0,''),(344643,110163,'117062','furniture','background-color','$content-bg-1',0,''),(344644,110163,'117062','furniture','padding-top','20',0,''),(344645,110163,'117062','furniture','padding-left','20',0,''),(344646,110163,'117062','furniture','padding-right','20',0,''),(344647,110163,'117062','furniture','padding-bottom','20',0,''),(344648,110164,'117063','furniture','font-weight','normal',0,''),(344649,110164,'117063','furniture','padding-top','20',0,''),(344650,110164,'117063','furniture','padding-bottom','20',0,''),(344651,110164,'117063','furniture','color','$content-color-1',0,''),(344652,110164,'117063','furniture','font-size','14',0,''),(344653,110165,'117064','furniture','block_type','7',0,''),(344654,110165,'117064','furniture','font-weight','normal',0,''),(344655,110165,'117064','furniture','padding-left','10',0,''),(344656,110165,'117064','furniture','padding-right','10',0,''),(344657,110165,'117064','furniture','padding-bottom','15',0,''),(344658,110165,'117064','furniture','border-bottom-width','1',0,''),(344659,110165,'117064','furniture','border-bottom-color','$content-border-1',0,''),(344660,110166,'117065','furniture','color','$content-color-1',0,''),(344661,110166,'117065','furniture','font-size','14',0,''),(344662,110166,'117065','furniture','font-weight','700',0,''),(344663,110167,'117066','furniture','font-weight','normal',0,''),(344664,110167,'117066','furniture','text-align','right',0,''),(344665,110167,'117066','furniture','color','$fade-color-1',0,''),(344666,110167,'117066','furniture','font-size','11',0,''),(344667,110167,'117066','furniture','text-transform','uppercase',0,''),(344668,110168,'117067','furniture','color','$fade-color-1',0,''),(344669,110168,'117067','furniture','font-size','12',0,''),(344670,110168,'117067','furniture','padding-top','20',0,''),(344671,110168,'117067','furniture','padding-bottom','20',0,''),(344672,110168,'117067','furniture','text-align','center',0,''),(344673,110169,'117068','furniture','font-weight','normal',0,''),(344674,110169,'117068','furniture','padding-bottom','10',0,''),(344675,110169,'117068','furniture','padding-top','10',0,''),(344676,110169,'117068','furniture','text-align','center',0,''),(344677,110169,'117068','furniture','logo_from','theme',0,''),(344678,110170,'117069','furniture','block_type','1',0,''),(344679,110170,'117069','furniture','background-color','$content-bg-2',0,''),(344680,110170,'117069','furniture','padding-top','20',0,''),(344681,110170,'117069','furniture','padding-bottom','20',0,''),(344682,110171,'117070','furniture','block_type','1',0,''),(344683,110171,'117070','furniture','max-width','800',0,''),(344684,110171,'117070','furniture','margin','0 auto',0,''),(344685,110172,'117071','furniture','color','$fade-color-1',0,''),(344686,110172,'117071','furniture','font-size','12',0,''),(344687,110172,'117071','furniture','padding-top','20',0,''),(344688,110172,'117071','furniture','padding-bottom','20',0,''),(344689,110172,'117071','furniture','text-align','left',0,''),(344690,110173,'117072','furniture','block_type','1',0,''),(344691,110173,'117072','furniture','background-color','$content-bg-1',0,''),(344692,110173,'117072','furniture','padding-top','20',0,''),(344693,110173,'117072','furniture','padding-left','20',0,''),(344694,110173,'117072','furniture','padding-right','20',0,''),(344695,110173,'117072','furniture','padding-bottom','20',0,''),(344696,110173,'117072','furniture','border-top-width','1',0,''),(344697,110173,'117072','furniture','border-left-width','1',0,''),(344698,110173,'117072','furniture','border-right-width','1',0,''),(344699,110173,'117072','furniture','border-bottom-width','1',0,''),(344700,110173,'117072','furniture','border-top-color','$content-border-1',0,''),(344701,110173,'117072','furniture','border-left-color','$content-border-1',0,''),(344702,110173,'117072','furniture','border-bottom-color','$content-border-1',0,''),(344703,110173,'117072','furniture','border-right-color','$content-border-1',0,''),(344704,110174,'117073','furniture','block_type','2',0,''),(344705,110175,'117074','furniture','font-weight','normal',0,''),(344706,110175,'117074','furniture','padding-bottom','10',0,''),(344707,110175,'117074','furniture','padding-top','10',0,''),(344708,110175,'117074','furniture','logo_from','theme',0,''),(344709,110176,'117075','furniture','font-weight','normal',0,''),(344710,110176,'117075','furniture','text-align','right',0,''),(344711,110176,'117075','furniture','color','$fade-color-1',0,''),(344712,110176,'117075','furniture','font-size','11',0,''),(344713,110176,'117075','furniture','text-transform','uppercase',0,''),(344714,110177,'117076','furniture','color','$content-color-1',0,''),(344715,110177,'117076','furniture','font-size','14',0,''),(344716,110177,'117076','furniture','font-weight','700',0,''),(344717,110177,'117076','furniture','text-align','right',0,''),(344718,110178,'117077','furniture','font-weight','normal',0,''),(344719,110178,'117077','furniture','padding-top','20',0,''),(344720,110178,'117077','furniture','padding-bottom','20',0,''),(344721,110178,'117077','furniture','color','$content-color-1',0,''),(344722,110178,'117077','furniture','font-size','14',0,''),(344723,110179,'121029','furniture','block_type','1',0,''),(344724,110182,'121032','furniture','margin-bottom','30',0,''),(344725,110183,'121025','furniture','block_type','1',0,''),(344726,110184,'121026','furniture','text','<h1>CATALOGUE</h1>',0,''),(344727,110186,'117078','furniture','block_type','1',0,''),(344728,110186,'117078','furniture','font-weight','normal',0,''),(344729,110186,'117078','furniture','padding-top','20',0,''),(344730,110186,'117078','furniture','background-color','$footer-bg-1',0,''),(344731,110186,'117078','furniture','style_class','preFooter',0,''),(344732,110186,'117078','furniture','padding-bottom','25',0,''),(344733,110186,'117078','furniture','color','$footer-color-1',0,''),(344734,110187,'120866','furniture','block_type','6',0,''),(344735,110187,'120866','furniture','schema','6-3',0,'5131'),(344736,110188,'117091','furniture','view_item','address',0,''),(344737,110188,'117091','furniture','address_spacer',',<br>',0,''),(344738,110188,'117091','furniture','data_format_content','<div>##TITLE##</div><div>Location: ##POST_ADDRESS##</div><div>Phone number: ##TELEPHONE##</div>\n',0,''),(344739,110188,'117091','furniture','margin-top','20',0,'5131'),(344740,110189,'120868','furniture','logo_from','theme',0,''),(344741,110189,'120868','furniture','margin-bottom','25',0,''),(344742,110189,'120868','furniture','padding-right','20',0,''),(344743,110189,'120868','furniture','display_none','1',0,'5131'),(344744,110190,'120871','furniture','block_type','1',0,''),(344745,110190,'120871','furniture','padding-left','15',0,''),(344746,110190,'120871','furniture','padding-right','15',0,''),(344747,110190,'120871','furniture','border-left-width','1',0,''),(344748,110190,'120871','furniture','border-right-width','1',0,''),(344749,110190,'120871','furniture','border-left-color','$footer-border-1',0,''),(344750,110190,'120871','furniture','border-right-color','$footer-border-1',0,''),(344751,110190,'120871','furniture','padding-left','0',0,'5131'),(344752,110190,'120871','furniture','padding-right','0',0,'5131'),(344753,110190,'120871','furniture','border-left-width','0',0,'5131'),(344754,110190,'120871','furniture','border-right-width','0',0,'5131'),(344755,110191,'117085','furniture','class','menu-style-2',0,''),(344756,110191,'117085','furniture','type','builder',0,''),(344757,110191,'117085','furniture','lev2_vis','click',0,'5140'),(344758,110191,'117085','furniture','style_class','footer-menu',0,''),(344759,110191,'117085','furniture','style','3',0,''),(344760,110192,'120869','furniture','block_type','1',0,''),(344761,110192,'120869','furniture','padding-top','30',0,''),(344762,110192,'120869','furniture','margin-top','24',0,''),(344763,110192,'120869','furniture','border-top-width','1',0,''),(344764,110192,'120869','furniture','border-top-color','$footer-border-1',0,''),(344765,110192,'120869','furniture','border-top-width','0',0,'5140'),(344766,110192,'120869','furniture','padding-top','0',0,'5140'),(344767,110193,'120870','furniture','logo','themes/furniture/img/geotrust.png',1,''),(344768,110193,'120870','furniture','float','left',0,''),(344769,110193,'120870','furniture','clear','none',0,''),(344773,110194,'120872','furniture','banners_group','payment',0,''),(344774,110194,'120872','furniture','float','right',0,''),(344775,110194,'120872','furniture','padding-top','15',0,''),(344776,110194,'120872','furniture','clear','none',0,''),(344777,110194,'120872','furniture','margin-bottom','20',0,''),(344778,110194,'120872','furniture','template','1',0,''),(344779,110195,'120873','furniture','text','<span>Payment types we accept</span>',0,''),(344780,110195,'120873','furniture','style_class','payment-text',0,''),(344781,110195,'120873','furniture','font-size','24',0,''),(344782,110195,'120873','furniture','font-weight','bold',0,''),(344783,110195,'120873','furniture','float','right',0,''),(344784,110195,'120873','furniture','padding-top','15',0,''),(344785,110195,'120873','furniture','clear','none',0,''),(344786,110195,'120873','furniture','padding-right','20',0,''),(344787,110195,'120873','furniture','font-size','18',0,'5145'),(344788,110195,'120873','furniture','display_none','1',0,'5140'),(344789,110196,'117093','furniture','block_type','1',0,''),(344790,110196,'117093','furniture','font-weight','400',0,''),(344791,110196,'117093','furniture','padding-top','20',0,''),(344792,110196,'117093','furniture','padding-bottom','20',0,''),(344793,110196,'117093','furniture','schema','2-2',0,''),(344794,110196,'117093','furniture','schema','2-3',0,'5140'),(344795,110196,'117093','furniture','background-color','$footer-bg-1',0,''),(344796,110196,'117093','furniture','color','$footer-color-1',0,''),(344797,110197,'117094','furniture','text-align','center',0,''),(344798,110197,'117094','furniture','font-size','14',0,''),(344799,110198,'117096','furniture','block_type','5',0,''),(344800,110199,'117097','furniture','text','##TEXT_LANGUAGE##',0,''),(344801,110201,'117099','furniture','block_type','5',0,''),(344802,110202,'117100','furniture','text','##TEXT_CURRENCY##',0,''),(344803,110204,'117102','furniture','block_type','1',0,''),(344804,110204,'117102','furniture','font-weight','normal',0,''),(344805,110205,'117103','furniture','block_type','2',0,''),(344806,110205,'117103','furniture','font-weight','normal',0,''),(344807,110205,'117103','furniture','padding-bottom','20',0,''),(344808,110206,'117104','furniture','block_type','1',0,''),(344809,110206,'117104','furniture','margin-right','20',0,''),(344810,110209,'117107','furniture','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(344811,110209,'117107','furniture','font-weight','normal',0,''),(344812,110209,'117107','furniture','padding-bottom','20',0,''),(344813,110209,'117107','furniture','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(344814,110209,'117107','furniture','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(344815,110209,'117107','furniture','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(344816,110211,'117109','furniture','block_type','1',0,''),(344817,110211,'117109','furniture','font-weight','normal',0,''),(344818,110211,'117109','furniture','style_class','gift-card-view',0,''),(344819,110211,'117109','furniture','text-align','center',0,''),(344820,110211,'117109','furniture','padding-bottom','20',0,''),(344821,110211,'117109','furniture','background-color','$highlight-box-bg-2',0,''),(344822,110211,'117109','furniture','padding-left','20',0,''),(344823,110211,'117109','furniture','padding-right','20',0,''),(344824,110211,'117109','furniture','color','$fade-color-1',0,''),(344825,110212,'117110','furniture','block_type','1',0,''),(344826,110212,'117110','furniture','font-weight','normal',0,''),(344827,110212,'117110','furniture','padding-top','10',0,''),(344828,110213,'117111','furniture','font-size','12',0,''),(344829,110213,'117111','furniture','font-weight','bold',0,''),(344830,110213,'117111','furniture','text-align','center',0,''),(344831,110213,'117111','furniture','style_class','email',0,''),(344832,110214,'117112','furniture','text','<p>If you require further assistance please contact us</p>',1,''),(344833,110214,'117112','furniture','font-weight','normal',0,''),(344834,110214,'117112','furniture','text-align','center',0,''),(344835,110214,'117112','furniture','font-size','12',0,''),(344836,110214,'117112','furniture','padding-top','10',0,''),(344837,110214,'117112','furniture','padding-bottom','5',0,''),(344838,110214,'117112','furniture','border-top-width','1',0,''),(344839,110214,'117112','furniture','border-top-color','$highlight-box-border-1',0,''),(344840,110214,'117112','furniture','text','<p>If you require further assistance please contact us</p>',2,''),(344841,110214,'117112','furniture','text','<p>If you require further assistance please contact us</p>',3,''),(344842,110214,'117112','furniture','text','<p>If you require further assistance please contact us</p>',4,''),(344843,110215,'117113','furniture','font-size','12',0,''),(344844,110215,'117113','furniture','font-weight','bold',0,''),(344845,110215,'117113','furniture','text-align','center',0,''),(344846,110215,'117113','furniture','style_class','phone',0,''),(344847,110215,'117113','furniture','padding-bottom','5',0,''),(344848,110216,'117114','furniture','text','<p>WHAT TO DO NEXT:</p>',1,''),(344849,110216,'117114','furniture','font-weight','normal',0,''),(344850,110216,'117114','furniture','text-align','center',0,''),(344851,110216,'117114','furniture','padding-top','20',0,''),(344852,110216,'117114','furniture','padding-bottom','10',0,''),(344853,110216,'117114','furniture','style_class','question-ico',0,''),(344854,110216,'117114','furniture','border-top-width','1',0,''),(344855,110216,'117114','furniture','border-top-color','$highlight-box-border-1',0,''),(344856,110216,'117114','furniture','font-size','18',0,''),(344857,110216,'117114','furniture','text','<p>WHAT TO DO NEXT:</p>',2,''),(344858,110216,'117114','furniture','text','<p>WHAT TO DO NEXT:</p>',3,''),(344859,110216,'117114','furniture','text','<p>WHAT TO DO NEXT:</p>',4,''),(344860,110217,'117115','furniture','text','<p>osCommerce</p>\n',1,''),(344861,110217,'117115','furniture','font-family','$font-1',0,''),(344862,110217,'117115','furniture','font-size','24',0,''),(344863,110217,'117115','furniture','font-weight','normal',0,''),(344864,110217,'117115','furniture','text-align','center',0,''),(344865,110217,'117115','furniture','padding-top','10',0,''),(344866,110217,'117115','furniture','padding-bottom','20',0,''),(344867,110217,'117115','furniture','text','<p>osCommerce</p>\n',2,''),(344868,110217,'117115','furniture','text','<p>osCommerce</p>\n',3,''),(344869,110217,'117115','furniture','text','<p>osCommerce</p>\n',4,''),(344870,110218,'117116','furniture','block_type','4',0,''),(344871,110218,'117116','furniture','color','$highlight-box-color-1',0,''),(344872,110218,'117116','furniture','font-size','30',0,''),(344873,110218,'117116','furniture','font-weight','normal',0,''),(344874,110218,'117116','furniture','background-color','$highlight-box-bg-1',0,''),(344875,110218,'117116','furniture','padding-top','5',0,''),(344876,110218,'117116','furniture','padding-left','10',0,''),(344877,110218,'117116','furniture','padding-right','10',0,''),(344878,110218,'117116','furniture','padding-bottom','5',0,''),(344879,110219,'117117','furniture','text','<p>Your code is:</p>',1,''),(344880,110219,'117117','furniture','font-weight','normal',0,''),(344881,110219,'117117','furniture','text','<p>Your code is:</p>',2,''),(344882,110219,'117117','furniture','text','<p>Your code is:</p>',3,''),(344883,110219,'117117','furniture','text','<p>Your code is:</p>',4,''),(344884,110221,'117119','furniture','font-weight','normal',0,''),(344885,110221,'117119','furniture','text-align','center',0,''),(344886,110221,'117119','furniture','padding-bottom','20',0,''),(344887,110222,'117120','furniture','font-size','60',0,''),(344888,110222,'117120','furniture','font-weight','bold',0,''),(344889,110222,'117120','furniture','text-align','center',0,''),(344890,110222,'117120','furniture','line-height','100',0,''),(344891,110222,'117120','furniture','padding-bottom','20',0,''),(344892,110222,'117120','furniture','line_height_measure','px',0,''),(344893,110223,'117121','furniture','text','<p>PERSONAL MESSAGE</p>',1,''),(344894,110223,'117121','furniture','font-size','18',0,''),(344895,110223,'117121','furniture','font-weight','normal',0,''),(344896,110223,'117121','furniture','text-align','center',0,''),(344897,110223,'117121','furniture','padding-top','20',0,''),(344898,110223,'117121','furniture','padding-bottom','10',0,''),(344899,110223,'117121','furniture','border-top-width','1',0,''),(344900,110223,'117121','furniture','border-top-color','$highlight-box-border-1',0,''),(344901,110223,'117121','furniture','text','<p>PERSONAL MESSAGE</p>',2,''),(344902,110223,'117121','furniture','text','<p>PERSONAL MESSAGE</p>',3,''),(344903,110223,'117121','furniture','text','<p>PERSONAL MESSAGE</p>',4,''),(344905,110224,'117123','furniture','logo_from','theme',0,''),(344906,110224,'117123','furniture','padding-top','20',0,''),(344907,110224,'117123','furniture','text-align','center',0,''),(344911,110225,'117124','furniture','text','<p>GIFT CARD</p>',1,''),(344912,110225,'117124','furniture','font-size','30',0,''),(344913,110225,'117124','furniture','font-weight','normal',0,''),(344914,110225,'117124','furniture','border-top-width','1',0,''),(344915,110225,'117124','furniture','border-top-color','$highlight-box-border-1',0,''),(344916,110225,'117124','furniture','style_class','gift-ico',0,''),(344917,110225,'117124','furniture','text-align','center',0,''),(344918,110225,'117124','furniture','padding-top','15',0,''),(344919,110225,'117124','furniture','text','<p>GIFT CARD</p>',2,''),(344920,110225,'117124','furniture','text','<p>GIFT CARD</p>',3,''),(344921,110225,'117124','furniture','text','<p>GIFT CARD</p>',4,''),(344922,110226,'117125','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(344923,110226,'117125','furniture','font-weight','normal',0,''),(344924,110226,'117125','furniture','text-align','center',0,''),(344925,110226,'117125','furniture','padding-bottom','10',0,''),(344926,110226,'117125','furniture','font-size','14',0,''),(344927,110226,'117125','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(344928,110226,'117125','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(344929,110226,'117125','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(344930,110227,'117126','furniture','block_type','1',0,''),(344931,110227,'117126','furniture','font-weight','normal',0,''),(344932,110227,'117126','furniture','style_class','gift-card-view',0,''),(344933,110227,'117126','furniture','text-align','center',0,''),(344934,110227,'117126','furniture','padding-bottom','20',0,''),(344935,110227,'117126','furniture','background-color','$content-bg-2',0,''),(344936,110227,'117126','furniture','padding-left','20',0,''),(344937,110227,'117126','furniture','padding-right','20',0,''),(344938,110227,'117126','furniture','color','$fade-color-1',0,''),(344939,110228,'117127','furniture','font-size','60',0,''),(344940,110228,'117127','furniture','font-weight','bold',0,''),(344941,110228,'117127','furniture','text-align','center',0,''),(344942,110228,'117127','furniture','line-height','100',0,''),(344943,110228,'117127','furniture','padding-bottom','20',0,''),(344944,110228,'117127','furniture','line_height_measure','px',0,''),(344945,110229,'117128','furniture','block_type','4',0,''),(344946,110229,'117128','furniture','color','$highlight-box-color-2',0,''),(344947,110229,'117128','furniture','font-size','30',0,''),(344948,110229,'117128','furniture','font-weight','normal',0,''),(344949,110229,'117128','furniture','background-color','$highlight-box-bg-4',0,''),(344950,110229,'117128','furniture','padding-top','5',0,''),(344951,110229,'117128','furniture','padding-left','10',0,''),(344952,110229,'117128','furniture','padding-right','10',0,''),(344953,110229,'117128','furniture','padding-bottom','5',0,''),(344954,110230,'117129','furniture','text','<p>Your code is:</p>',1,''),(344955,110230,'117129','furniture','font-weight','normal',0,''),(344956,110230,'117129','furniture','text','<p>Your code is:</p>',2,''),(344957,110230,'117129','furniture','text','<p>Your code is:</p>',3,''),(344958,110230,'117129','furniture','text','<p>Your code is:</p>',4,''),(344959,110232,'117131','furniture','block_type','1',0,''),(344960,110232,'117131','furniture','font-weight','normal',0,''),(344961,110232,'117131','furniture','padding-top','10',0,''),(344962,110233,'117132','furniture','font-size','12',0,''),(344963,110233,'117132','furniture','font-weight','bold',0,''),(344964,110233,'117132','furniture','text-align','center',0,''),(344965,110233,'117132','furniture','style_class','email',0,''),(344966,110234,'117133','furniture','text','<p>If you require further assistance please contact us</p>',1,''),(344967,110234,'117133','furniture','font-weight','normal',0,''),(344968,110234,'117133','furniture','text-align','center',0,''),(344969,110234,'117133','furniture','font-size','12',0,''),(344970,110234,'117133','furniture','padding-top','10',0,''),(344971,110234,'117133','furniture','padding-bottom','5',0,''),(344972,110234,'117133','furniture','border-top-width','1',0,''),(344973,110234,'117133','furniture','border-top-color','$highlight-box-border-1',0,''),(344974,110234,'117133','furniture','text','<p>If you require further assistance please contact us</p>',2,''),(344975,110234,'117133','furniture','text','<p>If you require further assistance please contact us</p>',3,''),(344976,110234,'117133','furniture','text','<p>If you require further assistance please contact us</p>',4,''),(344977,110235,'117134','furniture','font-size','12',0,''),(344978,110235,'117134','furniture','font-weight','bold',0,''),(344979,110235,'117134','furniture','text-align','center',0,''),(344980,110235,'117134','furniture','style_class','phone',0,''),(344981,110235,'117134','furniture','padding-bottom','5',0,''),(344982,110236,'117135','furniture','font-weight','normal',0,''),(344983,110236,'117135','furniture','text-align','center',0,''),(344984,110236,'117135','furniture','padding-bottom','20',0,''),(344985,110237,'117136','furniture','text','<p>PERSONAL MESSAGE</p>',1,''),(344986,110237,'117136','furniture','font-size','18',0,''),(344987,110237,'117136','furniture','font-weight','normal',0,''),(344988,110237,'117136','furniture','text-align','center',0,''),(344989,110237,'117136','furniture','padding-top','20',0,''),(344990,110237,'117136','furniture','padding-bottom','10',0,''),(344991,110237,'117136','furniture','border-top-width','1',0,''),(344992,110237,'117136','furniture','border-top-color','$highlight-box-border-1',0,''),(344993,110237,'117136','furniture','text','<p>PERSONAL MESSAGE</p>',2,''),(344994,110237,'117136','furniture','text','<p>PERSONAL MESSAGE</p>',3,''),(344995,110237,'117136','furniture','text','<p>PERSONAL MESSAGE</p>',4,''),(344996,110238,'117137','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(344997,110238,'117137','furniture','font-weight','normal',0,''),(344998,110238,'117137','furniture','text-align','center',0,''),(344999,110238,'117137','furniture','padding-bottom','10',0,''),(345000,110238,'117137','furniture','font-size','14',0,''),(345001,110238,'117137','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(345002,110238,'117137','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(345003,110238,'117137','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(345004,110239,'117138','furniture','text','<p>GIFT CARD</p>',1,''),(345005,110239,'117138','furniture','font-size','30',0,''),(345006,110239,'117138','furniture','font-weight','normal',0,''),(345007,110239,'117138','furniture','border-top-width','1',0,''),(345008,110239,'117138','furniture','border-top-color','$highlight-box-border-1',0,''),(345009,110239,'117138','furniture','style_class','gift-ico',0,''),(345010,110239,'117138','furniture','text-align','center',0,''),(345011,110239,'117138','furniture','padding-top','15',0,''),(345012,110239,'117138','furniture','text','<p>GIFT CARD</p>',2,''),(345013,110239,'117138','furniture','text','<p>GIFT CARD</p>',3,''),(345014,110239,'117138','furniture','text','<p>GIFT CARD</p>',4,''),(345015,110240,'117139','furniture','text','<p>WHAT TO DO NEXT:</p>',1,''),(345016,110240,'117139','furniture','font-weight','normal',0,''),(345017,110240,'117139','furniture','text-align','center',0,''),(345018,110240,'117139','furniture','padding-top','20',0,''),(345019,110240,'117139','furniture','padding-bottom','10',0,''),(345020,110240,'117139','furniture','style_class','question-ico',0,''),(345021,110240,'117139','furniture','border-top-width','1',0,''),(345022,110240,'117139','furniture','border-top-color','$highlight-box-border-1',0,''),(345023,110240,'117139','furniture','font-size','18',0,''),(345024,110240,'117139','furniture','text','<p>WHAT TO DO NEXT:</p>',2,''),(345025,110240,'117139','furniture','text','<p>WHAT TO DO NEXT:</p>',3,''),(345026,110240,'117139','furniture','text','<p>WHAT TO DO NEXT:</p>',4,''),(345027,110241,'1638804282.8587','furniture','logo_from','theme',0,''),(345028,110241,'1638804282.8587','furniture','padding-top','20',0,''),(345029,110241,'1638804282.8587','furniture','text-align','center',0,''),(345030,110241,'1638804282.8587','furniture','padding-bottom','20',0,''),(345031,110242,'117141','furniture','block_type','1',0,''),(345032,110242,'117141','furniture','font-weight','normal',0,''),(345033,110242,'117141','furniture','style_class','gift-card-view',0,''),(345034,110242,'117141','furniture','text-align','center',0,''),(345035,110242,'117141','furniture','padding-bottom','20',0,''),(345036,110242,'117141','furniture','background-color','$content-bg-2',0,''),(345037,110242,'117141','furniture','padding-left','20',0,''),(345038,110242,'117141','furniture','padding-right','20',0,''),(345039,110242,'117141','furniture','color','$fade-color-1',0,''),(345040,110243,'117142','furniture','block_type','1',0,''),(345041,110243,'117142','furniture','font-weight','normal',0,''),(345042,110243,'117142','furniture','padding-top','10',0,''),(345043,110244,'117143','furniture','font-size','12',0,''),(345044,110244,'117143','furniture','font-weight','bold',0,''),(345045,110244,'117143','furniture','text-align','center',0,''),(345046,110244,'117143','furniture','style_class','email',0,''),(345047,110244,'117143','furniture','color','$highlight-box-color-2',0,''),(345048,110245,'117144','furniture','font-size','12',0,''),(345049,110245,'117144','furniture','font-weight','bold',0,''),(345050,110245,'117144','furniture','text-align','center',0,''),(345051,110245,'117144','furniture','style_class','phone',0,''),(345052,110245,'117144','furniture','padding-bottom','5',0,''),(345053,110245,'117144','furniture','color','$highlight-box-color-2',0,''),(345054,110246,'117145','furniture','text','If you require further assistance please contact us',0,''),(345055,110246,'117145','furniture','font-size','12',0,''),(345056,110246,'117145','furniture','color','$highlight-box-color-2',0,''),(345057,110246,'117145','furniture','text-align','center',0,''),(345058,110246,'117145','furniture','padding-top','10',0,''),(345059,110247,'117146','furniture','block_type','4',0,''),(345060,110247,'117146','furniture','color','$highlight-box-color-2',0,''),(345061,110247,'117146','furniture','font-size','30',0,''),(345062,110247,'117146','furniture','font-weight','normal',0,''),(345063,110247,'117146','furniture','background-color','$highlight-box-bg-4',0,''),(345064,110247,'117146','furniture','padding-top','5',0,''),(345065,110247,'117146','furniture','padding-left','10',0,''),(345066,110247,'117146','furniture','padding-right','10',0,''),(345067,110247,'117146','furniture','padding-bottom','5',0,''),(345068,110248,'117147','furniture','text','Your code is:',0,''),(345069,110248,'117147','furniture','font-size','30',0,''),(345070,110248,'117147','furniture','color','$highlight-box-color-2',0,''),(345071,110249,'117148','furniture','color','$highlight-box-color-2',0,''),(345072,110249,'117148','furniture','font-size','30',0,''),(345073,110250,'117149','furniture','block_type','1',0,''),(345074,110251,'117150','furniture','text','<p>PERSONAL MESSAGE</p>',1,''),(345075,110251,'117150','furniture','font-size','18',0,''),(345076,110251,'117150','furniture','font-weight','normal',0,''),(345077,110251,'117150','furniture','text-align','center',0,''),(345078,110251,'117150','furniture','padding-top','20',0,''),(345079,110251,'117150','furniture','padding-bottom','10',0,''),(345080,110251,'117150','furniture','border-top-width','1',0,''),(345081,110251,'117150','furniture','border-top-color','$highlight-box-border-1',0,''),(345082,110251,'117150','furniture','text','<p>PERSONAL MESSAGE</p>',2,''),(345083,110251,'117150','furniture','text','<p>PERSONAL MESSAGE</p>',3,''),(345084,110251,'117150','furniture','text','<p>PERSONAL MESSAGE</p>',4,''),(345085,110252,'117151','furniture','text','HOLBI',0,''),(345086,110252,'117151','furniture','color','$highlight-box-color-2',0,''),(345087,110252,'117151','furniture','font-size','24',0,''),(345088,110252,'117151','furniture','padding-top','20',0,''),(345089,110252,'117151','furniture','text-align','center',0,''),(345090,110252,'117151','furniture','padding-bottom','20',0,''),(345091,110253,'117152','furniture','border-top-color','$highlight-box-border-1',0,''),(345092,110253,'117152','furniture','border-top-width','1',0,''),(345093,110253,'117152','furniture','padding-top','20',0,''),(345094,110253,'117152','furniture','font-size','30',0,''),(345095,110253,'117152','furniture','text-align','center',0,''),(345096,110253,'117152','furniture','color','$highlight-box-color-2',0,''),(345097,110253,'117152','furniture','text','GIFT CARD',0,''),(345098,110254,'117153','furniture','text-align','center',0,''),(345099,110254,'117153','furniture','font-weight','bold',0,''),(345100,110254,'117153','furniture','font-size','60',0,''),(345101,110254,'117153','furniture','color','$highlight-box-color-2',0,''),(345102,110255,'117154','furniture','font-size','20',0,''),(345103,110255,'117154','furniture','text-align','center',0,''),(345104,110255,'117154','furniture','color','$highlight-box-color-2',0,''),(345105,110255,'117154','furniture','padding-top','20',0,''),(345106,110255,'117154','furniture','padding-bottom','20',0,''),(345107,110256,'117155','furniture','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(345108,110256,'117155','furniture','text-align','center',0,''),(345109,110256,'117155','furniture','color','$highlight-box-color-2',0,''),(345110,110256,'117155','furniture','font-size','14',0,''),(345111,110256,'117155','furniture','padding-bottom','20',0,''),(345112,110257,'117156','furniture','text','WHAT TO DO NEXT:',0,''),(345113,110257,'117156','furniture','font-size','18',0,''),(345114,110257,'117156','furniture','text-align','center',0,''),(345115,110257,'117156','furniture','color','$highlight-box-color-2',0,''),(345116,110257,'117156','furniture','padding-top','20',0,''),(345117,110257,'117156','furniture','padding-bottom','10',0,''),(345118,110257,'117156','furniture','border-top-width','1',0,''),(345119,110257,'117156','furniture','border-top-color','$highlight-box-border-1',0,''),(345120,110259,'117158','furniture','block_type','1',0,''),(345121,110259,'117158','furniture','font-weight','normal',0,''),(345122,110259,'117158','furniture','style_class','gift-card-view',0,''),(345123,110259,'117158','furniture','text-align','center',0,''),(345124,110259,'117158','furniture','padding-bottom','20',0,''),(345125,110259,'117158','furniture','background-color','$highlight-box-bg-2',0,''),(345126,110259,'117158','furniture','padding-left','20',0,''),(345127,110259,'117158','furniture','padding-right','20',0,''),(345128,110259,'117158','furniture','color','$fade-color-1',0,''),(345129,110260,'117159','furniture','block_type','1',0,''),(345130,110260,'117159','furniture','font-weight','normal',0,''),(345131,110260,'117159','furniture','padding-top','10',0,''),(345132,110261,'117160','furniture','font-size','12',0,''),(345133,110261,'117160','furniture','font-weight','bold',0,''),(345134,110261,'117160','furniture','text-align','center',0,''),(345135,110261,'117160','furniture','style_class','email',0,''),(345136,110261,'117160','furniture','color','$highlight-box-color-2',0,''),(345137,110262,'117161','furniture','font-size','12',0,''),(345138,110262,'117161','furniture','font-weight','bold',0,''),(345139,110262,'117161','furniture','text-align','center',0,''),(345140,110262,'117161','furniture','style_class','phone',0,''),(345141,110262,'117161','furniture','padding-bottom','5',0,''),(345142,110262,'117161','furniture','color','$highlight-box-color-2',0,''),(345143,110263,'117162','furniture','text','If you require further assistance please contact us',0,''),(345144,110263,'117162','furniture','font-size','12',0,''),(345145,110263,'117162','furniture','color','$highlight-box-color-2',0,''),(345146,110263,'117162','furniture','text-align','center',0,''),(345147,110263,'117162','furniture','padding-top','10',0,''),(345148,110264,'117163','furniture','block_type','2',0,''),(345149,110264,'117163','furniture','color','$highlight-box-color-2',0,''),(345150,110264,'117163','furniture','font-size','30',0,''),(345151,110264,'117163','furniture','font-weight','normal',0,''),(345152,110264,'117163','furniture','background-color','$highlight-box-bg-4',0,''),(345153,110264,'117163','furniture','padding-top','5',0,''),(345154,110264,'117163','furniture','padding-left','10',0,''),(345155,110264,'117163','furniture','padding-right','10',0,''),(345156,110264,'117163','furniture','padding-bottom','5',0,''),(345157,110265,'117164','furniture','text','Your code is:',0,''),(345158,110265,'117164','furniture','font-size','30',0,''),(345159,110265,'117164','furniture','color','$highlight-box-color-2',0,''),(345160,110266,'117165','furniture','color','$highlight-box-color-2',0,''),(345161,110266,'117165','furniture','font-size','30',0,''),(345162,110267,'117166','furniture','block_type','1',0,''),(345163,110268,'117167','furniture','text','<p>PERSONAL MESSAGE</p>',1,''),(345164,110268,'117167','furniture','font-size','18',0,''),(345165,110268,'117167','furniture','font-weight','normal',0,''),(345166,110268,'117167','furniture','text-align','center',0,''),(345167,110268,'117167','furniture','padding-top','20',0,''),(345168,110268,'117167','furniture','padding-bottom','10',0,''),(345169,110268,'117167','furniture','border-top-width','1',0,''),(345170,110268,'117167','furniture','border-top-color','$highlight-box-border-1',0,''),(345171,110268,'117167','furniture','text','<p>PERSONAL MESSAGE</p>',2,''),(345172,110268,'117167','furniture','text','<p>PERSONAL MESSAGE</p>',3,''),(345173,110268,'117167','furniture','text','<p>PERSONAL MESSAGE</p>',4,''),(345174,110269,'117169','furniture','border-top-color','$highlight-box-border-1',0,''),(345175,110269,'117169','furniture','border-top-width','1',0,''),(345176,110269,'117169','furniture','padding-top','20',0,''),(345177,110269,'117169','furniture','font-size','30',0,''),(345178,110269,'117169','furniture','text-align','center',0,''),(345179,110269,'117169','furniture','color','$highlight-box-color-2',0,''),(345180,110269,'117169','furniture','text','GIFT CARD',0,''),(345181,110270,'117170','furniture','text-align','center',0,''),(345182,110270,'117170','furniture','font-weight','bold',0,''),(345183,110270,'117170','furniture','font-size','60',0,''),(345184,110270,'117170','furniture','color','$highlight-box-color-2',0,''),(345185,110271,'117171','furniture','font-size','20',0,''),(345186,110271,'117171','furniture','text-align','center',0,''),(345187,110271,'117171','furniture','color','$highlight-box-color-2',0,''),(345188,110271,'117171','furniture','padding-top','20',0,''),(345189,110271,'117171','furniture','padding-bottom','20',0,''),(345190,110272,'117172','furniture','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(345191,110272,'117172','furniture','text-align','center',0,''),(345192,110272,'117172','furniture','color','$highlight-box-color-2',0,''),(345193,110272,'117172','furniture','font-size','14',0,''),(345194,110272,'117172','furniture','padding-bottom','20',0,''),(345195,110273,'117173','furniture','text','WHAT TO DO NEXT:',0,''),(345196,110273,'117173','furniture','font-size','18',0,''),(345197,110273,'117173','furniture','text-align','center',0,''),(345198,110273,'117173','furniture','color','$highlight-box-color-2',0,''),(345199,110273,'117173','furniture','padding-top','20',0,''),(345200,110273,'117173','furniture','padding-bottom','10',0,''),(345201,110273,'117173','furniture','border-top-width','1',0,''),(345202,110273,'117173','furniture','border-top-color','$highlight-box-border-1',0,''),(345203,110274,'1638978695.8384','furniture','logo_from','theme',0,''),(345204,110274,'1638978695.8384','furniture','text-align','center',0,''),(345205,110274,'1638978695.8384','furniture','padding-top','20',0,''),(345206,110274,'1638978695.8384','furniture','padding-bottom','20',0,''),(345207,110275,'117175','furniture','block_type','1',0,''),(345208,110275,'117175','furniture','padding-left','20',0,''),(345209,110275,'117175','furniture','padding-right','20',0,''),(345210,110275,'117175','furniture','padding-bottom','20',0,''),(345211,110277,'117177','furniture','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(345212,110277,'117177','furniture','text-align','center',0,''),(345213,110278,'117178','furniture','block_type','1',0,''),(345214,110278,'117178','furniture','font-weight','normal',0,''),(345215,110278,'117178','furniture','style_class','gift-card-view',0,''),(345216,110278,'117178','furniture','text-align','center',0,''),(345217,110278,'117178','furniture','padding-bottom','20',0,''),(345218,110278,'117178','furniture','background-color','$highlight-box-bg-3',0,''),(345219,110278,'117178','furniture','padding-left','20',0,''),(345220,110278,'117178','furniture','padding-right','20',0,''),(345221,110278,'117178','furniture','color','$fade-color-1',0,''),(345222,110279,'117179','furniture','block_type','4',0,''),(345223,110279,'117179','furniture','color','$highlight-box-color-2',0,''),(345224,110279,'117179','furniture','font-size','30',0,''),(345225,110279,'117179','furniture','font-weight','normal',0,''),(345226,110279,'117179','furniture','background-color','$highlight-box-bg-4',0,''),(345227,110279,'117179','furniture','padding-top','5',0,''),(345228,110279,'117179','furniture','padding-left','10',0,''),(345229,110279,'117179','furniture','padding-right','10',0,''),(345230,110279,'117179','furniture','padding-bottom','5',0,''),(345231,110280,'117180','furniture','text','<p>Your code is:</p>',1,''),(345232,110280,'117180','furniture','font-weight','normal',0,''),(345233,110280,'117180','furniture','text','<p>Your code is:</p>',2,''),(345234,110280,'117180','furniture','text','<p>Your code is:</p>',3,''),(345235,110280,'117180','furniture','text','<p>Your code is:</p>',4,''),(345236,110282,'117182','furniture','text','<p>WHAT TO DO NEXT:</p>',1,''),(345237,110282,'117182','furniture','font-weight','normal',0,''),(345238,110282,'117182','furniture','text-align','center',0,''),(345239,110282,'117182','furniture','padding-top','20',0,''),(345240,110282,'117182','furniture','padding-bottom','10',0,''),(345241,110282,'117182','furniture','style_class','question-ico',0,''),(345242,110282,'117182','furniture','border-top-width','1',0,''),(345243,110282,'117182','furniture','border-top-color','$highlight-box-border-1',0,''),(345244,110282,'117182','furniture','font-size','18',0,''),(345245,110282,'117182','furniture','text','<p>WHAT TO DO NEXT:</p>',2,''),(345246,110282,'117182','furniture','text','<p>WHAT TO DO NEXT:</p>',3,''),(345247,110282,'117182','furniture','text','<p>WHAT TO DO NEXT:</p>',4,''),(345248,110283,'117184','furniture','block_type','1',0,''),(345249,110283,'117184','furniture','font-weight','normal',0,''),(345250,110283,'117184','furniture','padding-top','10',0,''),(345251,110284,'117185','furniture','text','<p>If you require further assistance please contact us</p>',1,''),(345252,110284,'117185','furniture','font-weight','normal',0,''),(345253,110284,'117185','furniture','text-align','center',0,''),(345254,110284,'117185','furniture','font-size','12',0,''),(345255,110284,'117185','furniture','padding-top','10',0,''),(345256,110284,'117185','furniture','padding-bottom','5',0,''),(345257,110284,'117185','furniture','border-top-width','1',0,''),(345258,110284,'117185','furniture','border-top-color','$highlight-box-border-1',0,''),(345259,110284,'117185','furniture','text','<p>If you require further assistance please contact us</p>',2,''),(345260,110284,'117185','furniture','text','<p>If you require further assistance please contact us</p>',3,''),(345261,110284,'117185','furniture','text','<p>If you require further assistance please contact us</p>',4,''),(345262,110285,'117186','furniture','font-size','12',0,''),(345263,110285,'117186','furniture','font-weight','bold',0,''),(345264,110285,'117186','furniture','text-align','center',0,''),(345265,110285,'117186','furniture','style_class','email',0,''),(345266,110286,'117187','furniture','font-size','12',0,''),(345267,110286,'117187','furniture','font-weight','bold',0,''),(345268,110286,'117187','furniture','text-align','center',0,''),(345269,110286,'117187','furniture','style_class','phone',0,''),(345270,110286,'117187','furniture','padding-bottom','5',0,''),(345271,110287,'117188','furniture','font-weight','normal',0,''),(345272,110287,'117188','furniture','text-align','center',0,''),(345273,110287,'117188','furniture','padding-bottom','20',0,''),(345274,110288,'117189','furniture','text','<p>GIFT CARD</p>',1,''),(345275,110288,'117189','furniture','font-size','30',0,''),(345276,110288,'117189','furniture','font-weight','normal',0,''),(345277,110288,'117189','furniture','border-top-width','1',0,''),(345278,110288,'117189','furniture','border-top-color','$highlight-box-border-1',0,''),(345279,110288,'117189','furniture','style_class','gift-ico',0,''),(345280,110288,'117189','furniture','text-align','center',0,''),(345281,110288,'117189','furniture','padding-top','15',0,''),(345282,110288,'117189','furniture','text','<p>GIFT CARD</p>',2,''),(345283,110288,'117189','furniture','text','<p>GIFT CARD</p>',3,''),(345284,110288,'117189','furniture','text','<p>GIFT CARD</p>',4,''),(345285,110289,'117190','furniture','text','<p>PERSONAL MESSAGE</p>',1,''),(345286,110289,'117190','furniture','font-size','18',0,''),(345287,110289,'117190','furniture','font-weight','normal',0,''),(345288,110289,'117190','furniture','text-align','center',0,''),(345289,110289,'117190','furniture','padding-top','20',0,''),(345290,110289,'117190','furniture','padding-bottom','10',0,''),(345291,110289,'117190','furniture','border-top-width','1',0,''),(345292,110289,'117190','furniture','border-top-color','$highlight-box-border-1',0,''),(345293,110289,'117190','furniture','text','<p>PERSONAL MESSAGE</p>',2,''),(345294,110289,'117190','furniture','text','<p>PERSONAL MESSAGE</p>',3,''),(345295,110289,'117190','furniture','text','<p>PERSONAL MESSAGE</p>',4,''),(345296,110290,'117191','furniture','font-size','60',0,''),(345297,110290,'117191','furniture','font-weight','bold',0,''),(345298,110290,'117191','furniture','text-align','center',0,''),(345299,110290,'117191','furniture','line-height','100',0,''),(345300,110290,'117191','furniture','padding-bottom','20',0,''),(345301,110290,'117191','furniture','line_height_measure','px',0,''),(345302,110291,'117192','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(345303,110291,'117192','furniture','font-weight','normal',0,''),(345304,110291,'117192','furniture','text-align','center',0,''),(345305,110291,'117192','furniture','padding-bottom','10',0,''),(345306,110291,'117192','furniture','font-size','14',0,''),(345307,110291,'117192','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(345308,110291,'117192','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(345309,110291,'117192','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(345310,110292,'1638804328.7281','furniture','logo_from','theme',0,''),(345311,110292,'1638804328.7281','furniture','padding-top','20',0,''),(345312,110292,'1638804328.7281','furniture','text-align','center',0,''),(345313,110292,'1638804328.7281','furniture','padding-bottom','20',0,''),(345314,110293,'117193','furniture','block_type','1',0,''),(345315,110293,'117193','furniture','font-weight','normal',0,''),(345316,110293,'117193','furniture','style_class','gift-card-view',0,''),(345317,110293,'117193','furniture','text-align','center',0,''),(345318,110293,'117193','furniture','padding-bottom','20',0,''),(345319,110293,'117193','furniture','background-color','$highlight-box-bg-3',0,''),(345320,110293,'117193','furniture','padding-left','20',0,''),(345321,110293,'117193','furniture','padding-right','20',0,''),(345322,110293,'117193','furniture','color','$fade-color-1',0,''),(345323,110294,'117194','furniture','block_type','1',0,''),(345324,110294,'117194','furniture','font-weight','normal',0,''),(345325,110294,'117194','furniture','padding-top','10',0,''),(345326,110295,'117195','furniture','font-size','12',0,''),(345327,110295,'117195','furniture','font-weight','bold',0,''),(345328,110295,'117195','furniture','text-align','center',0,''),(345329,110295,'117195','furniture','style_class','email',0,''),(345330,110295,'117195','furniture','color','$highlight-box-color-2',0,''),(345331,110296,'117196','furniture','font-size','12',0,''),(345332,110296,'117196','furniture','font-weight','bold',0,''),(345333,110296,'117196','furniture','text-align','center',0,''),(345334,110296,'117196','furniture','style_class','phone',0,''),(345335,110296,'117196','furniture','padding-bottom','5',0,''),(345336,110296,'117196','furniture','color','$highlight-box-color-2',0,''),(345337,110297,'117197','furniture','text','If you require further assistance please contact us',0,''),(345338,110297,'117197','furniture','font-size','12',0,''),(345339,110297,'117197','furniture','color','$highlight-box-color-2',0,''),(345340,110297,'117197','furniture','text-align','center',0,''),(345341,110297,'117197','furniture','padding-top','10',0,''),(345342,110298,'117198','furniture','block_type','4',0,''),(345343,110298,'117198','furniture','color','$highlight-box-color-2',0,''),(345344,110298,'117198','furniture','font-size','30',0,''),(345345,110298,'117198','furniture','font-weight','normal',0,''),(345346,110298,'117198','furniture','background-color','$highlight-box-bg-4',0,''),(345347,110298,'117198','furniture','padding-top','5',0,''),(345348,110298,'117198','furniture','padding-left','10',0,''),(345349,110298,'117198','furniture','padding-right','10',0,''),(345350,110298,'117198','furniture','padding-bottom','5',0,''),(345351,110299,'117199','furniture','text','Your code is:',0,''),(345352,110299,'117199','furniture','font-size','30',0,''),(345353,110299,'117199','furniture','color','$highlight-box-color-2',0,''),(345354,110300,'117200','furniture','color','$highlight-box-color-2',0,''),(345355,110300,'117200','furniture','font-size','30',0,''),(345356,110301,'117201','furniture','block_type','1',0,''),(345357,110302,'117202','furniture','text','<p>PERSONAL MESSAGE</p>',1,''),(345358,110302,'117202','furniture','font-size','18',0,''),(345359,110302,'117202','furniture','font-weight','normal',0,''),(345360,110302,'117202','furniture','text-align','center',0,''),(345361,110302,'117202','furniture','padding-top','20',0,''),(345362,110302,'117202','furniture','padding-bottom','10',0,''),(345363,110302,'117202','furniture','border-top-width','1',0,''),(345364,110302,'117202','furniture','border-top-color','$highlight-box-border-1',0,''),(345365,110302,'117202','furniture','text','<p>PERSONAL MESSAGE</p>',2,''),(345366,110302,'117202','furniture','text','<p>PERSONAL MESSAGE</p>',3,''),(345367,110302,'117202','furniture','text','<p>PERSONAL MESSAGE</p>',4,''),(345368,110303,'117203','furniture','text','HOLBI',0,''),(345369,110303,'117203','furniture','color','$highlight-box-color-2',0,''),(345370,110303,'117203','furniture','font-size','24',0,''),(345371,110303,'117203','furniture','padding-top','20',0,''),(345372,110303,'117203','furniture','text-align','center',0,''),(345373,110303,'117203','furniture','padding-bottom','20',0,''),(345374,110304,'117204','furniture','border-top-color','$highlight-box-border-1',0,''),(345375,110304,'117204','furniture','border-top-width','1',0,''),(345376,110304,'117204','furniture','padding-top','20',0,''),(345377,110304,'117204','furniture','font-size','30',0,''),(345378,110304,'117204','furniture','text-align','center',0,''),(345379,110304,'117204','furniture','color','$highlight-box-color-2',0,''),(345380,110304,'117204','furniture','text','GIFT CARD',0,''),(345381,110305,'117205','furniture','text-align','center',0,''),(345382,110305,'117205','furniture','font-weight','bold',0,''),(345383,110305,'117205','furniture','font-size','60',0,''),(345384,110305,'117205','furniture','color','$highlight-box-color-2',0,''),(345385,110306,'117206','furniture','font-size','20',0,''),(345386,110306,'117206','furniture','text-align','center',0,''),(345387,110306,'117206','furniture','color','$highlight-box-color-2',0,''),(345388,110306,'117206','furniture','padding-top','20',0,''),(345389,110306,'117206','furniture','padding-bottom','20',0,''),(345390,110307,'117207','furniture','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(345391,110307,'117207','furniture','text-align','center',0,''),(345392,110307,'117207','furniture','color','$highlight-box-color-2',0,''),(345393,110307,'117207','furniture','font-size','14',0,''),(345394,110307,'117207','furniture','padding-bottom','20',0,''),(345395,110308,'117208','furniture','text','WHAT TO DO NEXT:',0,''),(345396,110308,'117208','furniture','font-size','18',0,''),(345397,110308,'117208','furniture','text-align','center',0,''),(345398,110308,'117208','furniture','color','$highlight-box-color-2',0,''),(345399,110308,'117208','furniture','padding-top','20',0,''),(345400,110308,'117208','furniture','padding-bottom','10',0,''),(345401,110308,'117208','furniture','border-top-width','1',0,''),(345402,110308,'117208','furniture','border-top-color','$highlight-box-border-1',0,''),(345530,110328,'117224','furniture','block_type','1',0,''),(345531,110334,'117229','furniture','width','680',0,''),(345532,110334,'117229','furniture','font-weight','normal',0,''),(345533,110334,'117229','furniture','font-size','12',0,''),(345534,110334,'117229','furniture','padding-top','20',0,''),(345535,110334,'117229','furniture','padding-bottom','20',0,''),(345536,110334,'117229','furniture','color','$content-color-1',0,''),(345537,110335,'117230','furniture','block_type','4',0,''),(345538,110335,'117230','furniture','font-weight','normal',0,''),(345539,110335,'117230','furniture','border-top-width','1',0,''),(345540,110335,'117230','furniture','border-top-color','$content-border-1',0,''),(345541,110335,'117230','furniture','border-left-width','1',0,''),(345542,110335,'117230','furniture','border-left-color','$content-border-1',0,''),(345543,110335,'117230','furniture','border-right-width','1',0,''),(345544,110335,'117230','furniture','border-right-color','$content-border-1',0,''),(345545,110335,'117230','furniture','border-bottom-width','1',0,''),(345546,110335,'117230','furniture','border-bottom-color','$content-border-1',0,''),(345547,110336,'117231','furniture','block_type','2',0,''),(345548,110336,'117231','furniture','font-weight','normal',0,''),(345549,110336,'117231','furniture','border-top-width','1',0,''),(345550,110336,'117231','furniture','border-top-color','$content-border-1',0,''),(345551,110336,'117231','furniture','border-right-width','1',0,''),(345552,110336,'117231','furniture','border-right-color','$content-border-1',0,''),(345553,110337,'117232','furniture','block_type','1',0,''),(345554,110337,'117232','furniture','font-weight','normal',0,''),(345555,110337,'117232','furniture','padding-top','10',0,''),(345556,110337,'117232','furniture','padding-left','10',0,''),(345557,110337,'117232','furniture','padding-right','10',0,''),(345558,110337,'117232','furniture','padding-bottom','10',0,''),(345559,110337,'117232','furniture','border-right-width','1',0,''),(345560,110337,'117232','furniture','border-right-color','$content-border-1',0,''),(345561,110339,'117234','furniture','text','<p>Shipping via</p>',1,''),(345562,110339,'117234','furniture','font-weight','bold',0,''),(345563,110339,'117234','furniture','font-size','14',0,''),(345564,110339,'117234','furniture','text','<p>Shipping via</p>',2,''),(345565,110339,'117234','furniture','text','<p>Shipping via</p>',3,''),(345566,110339,'117234','furniture','text','<p>Shipping via</p>',4,''),(345567,110340,'117235','furniture','block_type','1',0,''),(345568,110340,'117235','furniture','font-weight','normal',0,''),(345569,110340,'117235','furniture','padding-top','10',0,''),(345570,110340,'117235','furniture','padding-left','10',0,''),(345571,110340,'117235','furniture','padding-right','10',0,''),(345572,110340,'117235','furniture','padding-bottom','10',0,''),(345573,110341,'117236','furniture','text','<p>Shipping service</p>',1,''),(345574,110341,'117236','furniture','font-weight','bold',0,''),(345575,110341,'117236','furniture','font-size','14',0,''),(345576,110341,'117236','furniture','text','<p>Shipping service</p>',2,''),(345577,110341,'117236','furniture','text','<p>Shipping service</p>',3,''),(345578,110341,'117236','furniture','text','<p>Shipping service</p>',4,''),(345579,110343,'117238','furniture','block_type','2',0,''),(345580,110343,'117238','furniture','font-weight','normal',0,''),(345581,110343,'117238','furniture','border-right-width','1',0,''),(345582,110343,'117238','furniture','border-right-color','$content-border-1',0,''),(345583,110344,'117239','furniture','block_type','1',0,''),(345584,110344,'117239','furniture','font-weight','400',0,''),(345585,110344,'117239','furniture','background-color','$content-bg-2',0,''),(345586,110344,'117239','furniture','padding-top','10',0,''),(345587,110344,'117239','furniture','padding-left','10',0,''),(345588,110344,'117239','furniture','padding-right','10',0,''),(345589,110344,'117239','furniture','padding-bottom','30',0,''),(345590,110345,'117240','furniture','text','<p>INVOICE ADDRESS:</p>',1,''),(345591,110345,'117240','furniture','font-size','14',0,''),(345592,110345,'117240','furniture','font-weight','bold',0,''),(345593,110345,'117240','furniture','text','<p>INVOICE ADDRESS:</p>',2,''),(345594,110345,'117240','furniture','text','<p>INVOICE ADDRESS:</p>',3,''),(345595,110345,'117240','furniture','text','<p>INVOICE ADDRESS:</p>',4,''),(345596,110346,'117241','furniture','font-size','12',0,''),(345597,110348,'117242','furniture','block_type','1',0,''),(345598,110348,'117242','furniture','font-weight','normal',0,''),(345599,110348,'117242','furniture','padding-top','10',0,''),(345600,110348,'117242','furniture','padding-left','10',0,''),(345601,110348,'117242','furniture','padding-right','10',0,''),(345602,110348,'117242','furniture','padding-bottom','10',0,''),(345603,110349,'117243','furniture','text','<p>E-MAIL ADDRESS:</p>',1,''),(345604,110349,'117243','furniture','font-weight','bold',0,''),(345605,110349,'117243','furniture','font-size','14',0,''),(345606,110349,'117243','furniture','padding-top','10',0,''),(345607,110349,'117243','furniture','text','<p>E-MAIL ADDRESS:</p>',2,''),(345608,110349,'117243','furniture','text','<p>E-MAIL ADDRESS:</p>',3,''),(345609,110349,'117243','furniture','text','<p>E-MAIL ADDRESS:</p>',4,''),(345610,110350,'117244','furniture','font-weight','normal',0,''),(345611,110351,'117245','furniture','font-weight','normal',0,''),(345612,110352,'117246','furniture','text','<p>CUSTOMER:</p>',1,''),(345613,110352,'117246','furniture','font-size','13',0,''),(345614,110352,'117246','furniture','font-weight','bold',0,''),(345615,110352,'117246','furniture','text','<p>CUSTOMER:</p>',2,''),(345616,110352,'117246','furniture','text','<p>CUSTOMER:</p>',3,''),(345617,110352,'117246','furniture','text','<p>CUSTOMER:</p>',4,''),(345618,110353,'117247','furniture','text','<p>PHONE NUMBER:</p>',1,''),(345619,110353,'117247','furniture','font-size','14',0,''),(345620,110353,'117247','furniture','font-weight','bold',0,''),(345621,110353,'117247','furniture','padding-top','10',0,''),(345622,110353,'117247','furniture','text','<p>PHONE NUMBER:</p>',2,''),(345623,110353,'117247','furniture','text','<p>PHONE NUMBER:</p>',3,''),(345624,110353,'117247','furniture','text','<p>PHONE NUMBER:</p>',4,''),(345625,110355,'117249','furniture','font-weight','normal',0,''),(345626,110355,'117249','furniture','text-align','center',0,''),(345627,110355,'117249','furniture','padding-bottom','20',0,''),(345628,110356,'117250','furniture','text','<p>Payment Method:</p>',1,''),(345629,110356,'117250','furniture','font-weight','bold',0,''),(345630,110356,'117250','furniture','text-align','center',0,''),(345631,110356,'117250','furniture','text','<p>Payment Method:</p>',2,''),(345632,110356,'117250','furniture','text','<p>Payment Method:</p>',3,''),(345633,110356,'117250','furniture','text','<p>Payment Method:</p>',4,''),(345634,110357,'117251','furniture','text','<p>Payment date:</p>',1,''),(345635,110357,'117251','furniture','font-weight','bold',0,''),(345636,110357,'117251','furniture','text-align','center',0,''),(345637,110357,'117251','furniture','font-size','12',0,''),(345638,110357,'117251','furniture','text','<p>Payment date:</p>',2,''),(345639,110357,'117251','furniture','text','<p>Payment date:</p>',3,''),(345640,110357,'117251','furniture','text','<p>Payment date:</p>',4,''),(345641,110358,'117252','furniture','font-size','14',0,''),(345642,110358,'117252','furniture','font-weight','bold',0,''),(345643,110358,'117252','furniture','text-align','center',0,''),(345644,110358,'117252','furniture','padding-bottom','10',0,''),(345645,110358,'117252','furniture','padding-top','10',0,''),(345646,110359,'117253','furniture','font-weight','normal',0,''),(345647,110359,'117253','furniture','text-align','center',0,''),(345648,110359,'117253','furniture','padding-bottom','10',0,''),(345649,110360,'117254','furniture','font-weight','normal',0,''),(345650,110360,'117254','furniture','text-align','center',0,''),(345651,110361,'117255','furniture','block_type','3',0,''),(345652,110361,'117255','furniture','font-weight','normal',0,''),(345653,110361,'117255','furniture','padding-top','20',0,''),(345654,110362,'117256','furniture','font-size','12',0,''),(345655,110363,'117257','furniture','text','<p>If undelivered please return to:</p>',1,''),(345656,110363,'117257','furniture','font-size','12',0,''),(345657,110363,'117257','furniture','font-weight','bold',0,''),(345658,110363,'117257','furniture','text','<p>If undelivered please return to:</p>',2,''),(345659,110363,'117257','furniture','text','<p>If undelivered please return to:</p>',3,''),(345660,110363,'117257','furniture','text','<p>If undelivered please return to:</p>',4,''),(345661,110364,'117258','furniture','text','<p>Thank you for your order</p>',1,''),(345662,110364,'117258','furniture','color','$content-color-1',0,''),(345663,110364,'117258','furniture','font-size','13',0,''),(345664,110364,'117258','furniture','font-weight','bold',0,''),(345665,110364,'117258','furniture','padding-top','5',0,''),(345666,110364,'117258','furniture','text-align','center',0,''),(345667,110364,'117258','furniture','text','<p>Thank you for your order</p>',2,''),(345668,110364,'117258','furniture','text','<p>Thank you for your order</p>',3,''),(345669,110364,'117258','furniture','text','<p>Thank you for your order</p>',4,''),(345670,110365,'117260','furniture','block_type','6',0,''),(345671,110365,'117260','furniture','font-weight','normal',0,''),(345672,110365,'117260','furniture','font-size','16',0,''),(345673,110366,'117261','furniture','text','<p>Email:</p>',1,''),(345674,110366,'117261','furniture','font-weight','normal',0,''),(345675,110366,'117261','furniture','text-align','right',0,''),(345676,110366,'117261','furniture','font-size','12',0,''),(345677,110366,'117261','furniture','text','<p>Email:</p>',2,''),(345678,110366,'117261','furniture','text','<p>Email:</p>',3,''),(345679,110366,'117261','furniture','text','<p>Email:</p>',4,''),(345680,110367,'117262','furniture','font-weight','normal',0,''),(345681,110367,'117262','furniture','text-align','right',0,''),(345682,110367,'117262','furniture','font-size','12',0,''),(345683,110368,'117263','furniture','block_type','6',0,''),(345684,110368,'117263','furniture','font-weight','normal',0,''),(345685,110368,'117263','furniture','font-size','16',0,''),(345686,110369,'117264','furniture','text','<p>Phone:</p>',1,''),(345687,110369,'117264','furniture','font-weight','normal',0,''),(345688,110369,'117264','furniture','text-align','right',0,''),(345689,110369,'117264','furniture','font-size','12',0,''),(345690,110369,'117264','furniture','text','<p>Phone:</p>',2,''),(345691,110369,'117264','furniture','text','<p>Phone:</p>',3,''),(345692,110369,'117264','furniture','text','<p>Phone:</p>',4,''),(345693,110370,'117265','furniture','font-weight','normal',0,''),(345694,110370,'117265','furniture','text-align','right',0,''),(345695,110370,'117265','furniture','font-size','12',0,''),(345696,110371,'117266','furniture','text','<p>If something has gone wrong please contact us at:</p>',1,''),(345697,110371,'117266','furniture','font-size','12',0,''),(345698,110371,'117266','furniture','font-weight','bold',0,''),(345699,110371,'117266','furniture','text-align','right',0,''),(345700,110371,'117266','furniture','text','<p>If something has gone wrong please contact us at:</p>',2,''),(345701,110371,'117266','furniture','text','<p>If something has gone wrong please contact us at:</p>',3,''),(345702,110371,'117266','furniture','text','<p>If something has gone wrong please contact us at:</p>',4,''),(345703,110372,'117267','furniture','font-weight','400',0,''),(345704,110372,'117267','furniture','padding-top','20',0,''),(345705,110372,'117267','furniture','padding-bottom','0',0,''),(345706,110372,'117267','furniture','font-size','12',0,''),(345707,110373,'117268','furniture','block_type','5',0,''),(345708,110373,'117268','furniture','font-weight','normal',0,''),(345709,110373,'117268','furniture','border-bottom-width','1',0,''),(345710,110373,'117268','furniture','border-bottom-color','$content-border-1',0,''),(345711,110373,'117268','furniture','border-top-width','1',0,''),(345712,110373,'117268','furniture','border-top-color','$content-border-1',0,''),(345713,110373,'117268','furniture','border-left-color','$content-border-1',0,''),(345714,110373,'117268','furniture','border-left-width','1',0,''),(345715,110374,'117269','furniture','block_type','1',0,''),(345716,110374,'117269','furniture','font-weight','normal',0,''),(345717,110374,'117269','furniture','padding-top','10',0,''),(345718,110374,'117269','furniture','padding-left','10',0,''),(345719,110374,'117269','furniture','padding-right','10',0,''),(345720,110375,'117270','furniture','font-weight','400',0,''),(345721,110375,'117270','furniture','line-height','120',0,''),(345722,110375,'117270','furniture','line_height_measure','%',0,''),(345723,110375,'117270','furniture','font-size','12',0,''),(345724,110376,'117271','furniture','text','<p>SHIPPING ADDRESS:</p>',1,''),(345725,110376,'117271','furniture','font-size','14',0,''),(345726,110376,'117271','furniture','font-weight','bold',0,''),(345727,110376,'117271','furniture','padding-bottom','10',0,''),(345728,110376,'117271','furniture','text','<p>SHIPPING ADDRESS:</p>',2,''),(345729,110376,'117271','furniture','text','<p>SHIPPING ADDRESS:</p>',3,''),(345730,110376,'117271','furniture','text','<p>SHIPPING ADDRESS:</p>',4,''),(345731,110377,'117272','furniture','block_type','1',0,''),(345732,110377,'117272','furniture','background-color','$content-bg-2',0,''),(345733,110377,'117272','furniture','padding-top','20',0,''),(345734,110377,'117272','furniture','padding-left','10',0,''),(345735,110377,'117272','furniture','padding-right','10',0,''),(345736,110377,'117272','furniture','padding-bottom','20',0,''),(345737,110377,'117272','furniture','font-size','14',0,''),(345738,110378,'117273','furniture','font-weight','normal',0,''),(345739,110378,'117273','furniture','text-align','right',0,''),(345740,110378,'117273','furniture','font-size','14',0,''),(345741,110378,'117273','furniture','box_align','3',0,''),(345742,110379,'117274','furniture','block_type','2',0,''),(345743,110379,'117274','furniture','font-weight','normal',0,''),(345744,110379,'117274','furniture','padding-bottom','20',0,''),(345745,110380,'117275','furniture','font-weight','400',0,''),(345746,110380,'117275','furniture','padding-top','10',0,''),(345748,110380,'117275','furniture','padding-bottom','10',0,''),(345752,110381,'117276','furniture','block_type','11',0,''),(345753,110381,'117276','furniture','font-weight','normal',0,''),(345754,110382,'117277','furniture','text','<p>Web:</p>',1,''),(345755,110382,'117277','furniture','font-weight','normal',0,''),(345756,110382,'117277','furniture','text-align','right',0,''),(345757,110382,'117277','furniture','text','<p>Web:</p>',2,''),(345758,110382,'117277','furniture','text','<p>Web:</p>',3,''),(345759,110382,'117277','furniture','text','<p>Web:</p>',4,''),(345760,110383,'117278','furniture','font-weight','normal',0,''),(345761,110383,'117278','furniture','text-align','right',0,''),(345762,110384,'117279','furniture','block_type','11',0,''),(345763,110384,'117279','furniture','font-weight','normal',0,''),(345764,110385,'117280','furniture','text','<p>Email:</p>',1,''),(345765,110385,'117280','furniture','font-weight','normal',0,''),(345766,110385,'117280','furniture','text-align','right',0,''),(345767,110385,'117280','furniture','text','<p>Email:</p>',2,''),(345768,110385,'117280','furniture','text','<p>Email:</p>',3,''),(345769,110385,'117280','furniture','text','<p>Email:</p>',4,''),(345770,110386,'117281','furniture','font-weight','normal',0,''),(345771,110386,'117281','furniture','text-align','right',0,''),(345772,110387,'117282','furniture','block_type','1',0,''),(345773,110388,'117283','furniture','font-weight','normal',0,''),(345774,110388,'117283','furniture','text-align','right',0,''),(345775,110388,'117283','furniture','padding-bottom','10',0,''),(345776,110388,'117283','furniture','address_spacer',',',0,''),(345777,110388,'117283','furniture','font-size','12',0,''),(345778,110389,'117284','furniture','block_type','11',0,''),(345779,110389,'117284','furniture','font-weight','normal',0,''),(345780,110390,'117285','furniture','text','<p>Phone:</p>',1,''),(345781,110390,'117285','furniture','font-weight','normal',0,''),(345782,110390,'117285','furniture','text-align','right',0,''),(345783,110390,'117285','furniture','text','<p>Phone:</p>',2,''),(345784,110390,'117285','furniture','text','<p>Phone:</p>',3,''),(345785,110390,'117285','furniture','text','<p>Phone:</p>',4,''),(345786,110391,'117286','furniture','font-weight','normal',0,''),(345787,110391,'117286','furniture','text-align','right',0,''),(345788,110392,'1640103567.8175','furniture','column_qty','1',0,''),(345789,110392,'1640103567.8175','furniture','column_name','1',0,''),(345790,110392,'1640103567.8175','furniture','column_model','1',0,''),(345791,110393,'117287','furniture','block_type','1',0,''),(345792,110393,'117287','furniture','padding-top','20',0,''),(345793,110394,'117288','furniture','tab_1','RETURNING CUSTOMER',1,''),(345794,110394,'117288','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(345795,110394,'117288','furniture','tab_1','RETURNING CUSTOMER',2,''),(345796,110394,'117288','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(345797,110394,'117288','furniture','tab_1','RETURNING CUSTOMER',3,''),(345798,110394,'117288','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(345799,110394,'117288','furniture','tab_1','RETURNING CUSTOMER',4,''),(345800,110394,'117288','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(345801,110395,'117289','furniture','max-width','600',0,''),(345802,110395,'117289','furniture','margin_left_measure','auto',0,''),(345803,110395,'117289','furniture','margin_right_measure','auto',0,''),(345804,110396,'117290','furniture','block_type','8',0,''),(345805,110396,'117290','furniture','schema','8-6',0,'5140'),(345806,110397,'117291','furniture','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(345807,110398,'117292','furniture','block_type','1',0,''),(345808,110398,'117292','furniture','padding-left','20',0,''),(345809,110398,'117292','furniture','padding-right','20',0,''),(345810,110399,'117293','furniture','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(345811,110401,'117295','furniture','block_type','1',0,''),(345812,110402,'117296','furniture','text','##TEXT_OR##',0,''),(345813,110402,'117296','furniture','font-size','18',0,''),(345814,110402,'117296','furniture','font-weight','700',0,''),(345815,110402,'117296','furniture','padding-top','15',0,''),(345816,110402,'117296','furniture','text-align','center',0,''),(345817,110402,'117296','furniture','content','\\_',0,'3'),(345818,110402,'117296','furniture','height','5',0,'3'),(345819,110402,'117296','furniture','width','70',0,'3'),(345820,110402,'117296','furniture','display','inline-block',0,'3'),(345821,110402,'117296','furniture','border-top-width','1',0,'3'),(345822,110402,'117296','furniture','border-top-color','$content-border-1',0,'3'),(345823,110402,'117296','furniture','margin-left','10',0,'3'),(345824,110402,'117296','furniture','margin-right','10',0,'3'),(345825,110402,'117296','furniture','content','\\_',0,'4'),(345826,110402,'117296','furniture','display','inline-block',0,'4'),(345827,110402,'117296','furniture','width','70',0,'4'),(345828,110402,'117296','furniture','height','5',0,'4'),(345829,110402,'117296','furniture','border-top-width','1',0,'4'),(345830,110402,'117296','furniture','border-top-color','$content-border-1',0,'4'),(345831,110402,'117296','furniture','margin-left','10',0,'4'),(345832,110402,'117296','furniture','margin-right','10',0,'4'),(345833,110402,'117296','furniture','position','relative',0,''),(345834,110402,'117296','furniture','top','-10',0,''),(345835,110403,'117297','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(345836,110403,'117297','furniture','font-size','26',0,''),(345837,110403,'117297','furniture','font-family','$font-1',0,''),(345838,110403,'117297','furniture','padding-top','15',0,''),(345839,110403,'117297','furniture','padding-bottom','15',0,''),(345840,110403,'117297','furniture','text-align','center',0,''),(345841,110404,'117298','furniture','text-align','center',0,''),(345842,110404,'117298','furniture','hide_parents','2',0,''),(345843,110405,'117299','furniture','block_type','1',0,''),(345844,110405,'117299','furniture','padding-top','40',0,''),(345845,110405,'117299','furniture','background-color','$content-bg-2',0,''),(345846,110405,'117299','furniture','padding-bottom','40',0,''),(345847,110405,'117299','furniture','style_class','checkout-login-wrap',0,''),(345848,110405,'117299','furniture','color','$content-color-2',0,''),(345849,110406,'117300','furniture','block_type','2',0,''),(345850,110406,'117300','furniture','background-color','$content-bg-1',0,''),(345851,110406,'117300','furniture','max-width','830',0,''),(345852,110406,'117300','furniture','margin_left_measure','auto',0,''),(345853,110406,'117300','furniture','margin_right_measure','auto',0,''),(345854,110406,'117300','furniture','padding-top','40',0,''),(345855,110406,'117300','furniture','padding-bottom','40',0,''),(345856,110406,'117300','furniture','schema','2-3',0,'5140'),(345857,110406,'117300','furniture','color','$content-color-1',0,''),(345858,110407,'117301','furniture','text-align','center',0,''),(345859,110407,'117301','furniture','margin-bottom','40',0,''),(345860,110408,'117302','furniture','text-align','center',0,''),(345861,110409,'117303','furniture','text','##TEXT_OR##',0,''),(345862,110409,'117303','furniture','font-size','18',0,''),(345863,110409,'117303','furniture','font-weight','700',0,''),(345864,110409,'117303','furniture','text-align','center',0,''),(345865,110409,'117303','furniture','content','\\_',0,'3'),(345866,110409,'117303','furniture','height','5',0,'3'),(345867,110409,'117303','furniture','width','70',0,'3'),(345868,110409,'117303','furniture','display','inline-block',0,'3'),(345869,110409,'117303','furniture','border-top-width','1',0,'3'),(345870,110409,'117303','furniture','border-top-color','$content-border-1',0,'3'),(345871,110409,'117303','furniture','margin-left','10',0,'3'),(345872,110409,'117303','furniture','margin-right','10',0,'3'),(345873,110409,'117303','furniture','content','\\_',0,'4'),(345874,110409,'117303','furniture','display','inline-block',0,'4'),(345875,110409,'117303','furniture','width','70',0,'4'),(345876,110409,'117303','furniture','height','5',0,'4'),(345877,110409,'117303','furniture','border-top-width','1',0,'4'),(345878,110409,'117303','furniture','border-top-color','$content-border-1',0,'4'),(345879,110409,'117303','furniture','margin-left','10',0,'4'),(345880,110409,'117303','furniture','margin-right','10',0,'4'),(345881,110409,'117303','furniture','position','relative',0,''),(345882,110409,'117303','furniture','padding-top','10',0,''),(345883,110409,'117303','furniture','padding-bottom','10',0,''),(345884,110410,'117304','furniture','block_type','1',0,''),(345885,110411,'117305','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(345886,110411,'117305','furniture','font-size','18',0,''),(345887,110411,'117305','furniture','font-family','$font-1',0,''),(345888,110411,'117305','furniture','padding-top','15',0,''),(345889,110411,'117305','furniture','padding-bottom','15',0,''),(345890,110411,'117305','furniture','text-align','center',0,''),(345891,110411,'117305','furniture','text-transform','uppercase',0,''),(345892,110412,'117306','furniture','text-align','center',0,''),(345893,110412,'117306','furniture','hide_parents','2',0,''),(345894,110413,'117307','furniture','text','##NEW_CUSTOMER##',0,''),(345895,110413,'117307','furniture','font-size','18',0,''),(345896,110413,'117307','furniture','font-family','$font-1',0,''),(345897,110413,'117307','furniture','text-align','center',0,''),(345898,110413,'117307','furniture','text-transform','uppercase',0,''),(345899,110413,'117307','furniture','margin-bottom','10',0,''),(345900,110414,'117308','furniture','max-width','230',0,''),(345901,110414,'117308','furniture','margin_left_measure','auto',0,''),(345902,110414,'117308','furniture','margin_right_measure','auto',0,''),(345903,110415,'117309','furniture','text','##RETURNING_CUSTOMER##',0,''),(345904,110415,'117309','furniture','font-size','18',0,''),(345905,110415,'117309','furniture','font-family','$font-1',0,''),(345906,110415,'117309','furniture','text-transform','uppercase',0,''),(345907,110415,'117309','furniture','text-align','center',0,''),(345908,110416,'117310','furniture','block_type','1',0,''),(345909,110416,'117310','furniture','padding-top','20',0,''),(345910,110417,'117311','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(345911,110417,'117311','furniture','tab_2','RETURNING CUSTOMER',1,''),(345912,110417,'117311','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(345913,110417,'117311','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(345914,110417,'117311','furniture','tab_2','RETURNING CUSTOMER',2,''),(345915,110417,'117311','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(345916,110417,'117311','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(345917,110417,'117311','furniture','tab_2','RETURNING CUSTOMER',3,''),(345918,110417,'117311','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(345919,110417,'117311','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(345920,110417,'117311','furniture','tab_2','RETURNING CUSTOMER',4,''),(345921,110417,'117311','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(345922,110418,'117312','furniture','block_type','8',0,''),(345923,110419,'117313','furniture','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(345924,110420,'117314','furniture','block_type','1',0,''),(345925,110420,'117314','furniture','padding-left','20',0,''),(345926,110420,'117314','furniture','padding-right','20',0,''),(345927,110422,'117316','furniture','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(345928,110422,'117316','furniture','border-top-width','1',0,''),(345929,110422,'117316','furniture','border-top-color','$content-border-1',0,''),(345930,110424,'117318','furniture','block_type','8',0,''),(345931,110425,'117319','furniture','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(345932,110426,'117320','furniture','block_type','1',0,''),(345933,110426,'117320','furniture','padding-left','20',0,''),(345934,110426,'117320','furniture','padding-right','20',0,''),(345935,110427,'117321','furniture','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(345936,110429,'117323','furniture','text-align','center',0,''),(345937,110430,'117324','furniture','text','##TEXT_OR##',0,''),(345938,110430,'117324','furniture','font-size','18',0,''),(345939,110430,'117324','furniture','font-weight','700',0,''),(345940,110430,'117324','furniture','padding-top','15',0,''),(345941,110430,'117324','furniture','text-align','center',0,''),(345942,110430,'117324','furniture','content','\\_',0,'3'),(345943,110430,'117324','furniture','height','5',0,'3'),(345944,110430,'117324','furniture','width','70',0,'3'),(345945,110430,'117324','furniture','display','inline-block',0,'3'),(345946,110430,'117324','furniture','border-top-width','1',0,'3'),(345947,110430,'117324','furniture','border-top-color','$content-border-1',0,'3'),(345948,110430,'117324','furniture','margin-left','10',0,'3'),(345949,110430,'117324','furniture','margin-right','10',0,'3'),(345950,110430,'117324','furniture','content','\\_',0,'4'),(345951,110430,'117324','furniture','display','inline-block',0,'4'),(345952,110430,'117324','furniture','width','70',0,'4'),(345953,110430,'117324','furniture','height','5',0,'4'),(345954,110430,'117324','furniture','border-top-width','1',0,'4'),(345955,110430,'117324','furniture','border-top-color','$content-border-1',0,'4'),(345956,110430,'117324','furniture','margin-left','10',0,'4'),(345957,110430,'117324','furniture','margin-right','10',0,'4'),(345958,110430,'117324','furniture','position','relative',0,''),(345959,110430,'117324','furniture','top','-10',0,''),(345960,110431,'117325','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(345961,110431,'117325','furniture','font-size','26',0,''),(345962,110431,'117325','furniture','font-family','$font-1',0,''),(345963,110431,'117325','furniture','padding-top','15',0,''),(345964,110431,'117325','furniture','padding-bottom','15',0,''),(345965,110431,'117325','furniture','text-align','center',0,''),(345966,110432,'117326','furniture','block_type','1',0,''),(345967,110432,'117326','furniture','padding-top','20',0,''),(345968,110433,'117327','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(345969,110433,'117327','furniture','tab_2','RETURNING CUSTOMER',1,''),(345970,110433,'117327','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(345971,110433,'117327','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(345972,110433,'117327','furniture','tab_2','RETURNING CUSTOMER',2,''),(345973,110433,'117327','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(345974,110433,'117327','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(345975,110433,'117327','furniture','tab_2','RETURNING CUSTOMER',3,''),(345976,110433,'117327','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(345977,110433,'117327','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(345978,110433,'117327','furniture','tab_2','RETURNING CUSTOMER',4,''),(345979,110433,'117327','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(345980,110434,'117328','furniture','block_type','8',0,''),(345981,110435,'117329','furniture','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(345982,110438,'117332','furniture','block_type','8',0,''),(345983,110439,'117333','furniture','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(345984,110441,'117335','furniture','block_type','1',0,''),(345985,110441,'117335','furniture','padding-left','20',0,''),(345986,110441,'117335','furniture','padding-right','20',0,''),(345987,110443,'117337','furniture','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(345988,110444,'117338','furniture','text','##TEXT_OR##',0,''),(345989,110444,'117338','furniture','font-size','18',0,''),(345990,110444,'117338','furniture','font-weight','700',0,''),(345991,110444,'117338','furniture','padding-top','15',0,''),(345992,110444,'117338','furniture','text-align','center',0,''),(345993,110444,'117338','furniture','content','\\_',0,'3'),(345994,110444,'117338','furniture','height','5',0,'3'),(345995,110444,'117338','furniture','width','70',0,'3'),(345996,110444,'117338','furniture','display','inline-block',0,'3'),(345997,110444,'117338','furniture','border-top-width','1',0,'3'),(345998,110444,'117338','furniture','border-top-color','$content-border-1',0,'3'),(345999,110444,'117338','furniture','margin-left','10',0,'3'),(346000,110444,'117338','furniture','margin-right','10',0,'3'),(346001,110444,'117338','furniture','content','\\_',0,'4'),(346002,110444,'117338','furniture','display','inline-block',0,'4'),(346003,110444,'117338','furniture','width','70',0,'4'),(346004,110444,'117338','furniture','height','5',0,'4'),(346005,110444,'117338','furniture','border-top-width','1',0,'4'),(346006,110444,'117338','furniture','border-top-color','$content-border-1',0,'4'),(346007,110444,'117338','furniture','margin-left','10',0,'4'),(346008,110444,'117338','furniture','margin-right','10',0,'4'),(346009,110444,'117338','furniture','position','relative',0,''),(346010,110444,'117338','furniture','top','-10',0,''),(346011,110445,'117339','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(346012,110445,'117339','furniture','font-size','26',0,''),(346013,110445,'117339','furniture','font-family','$font-1',0,''),(346014,110445,'117339','furniture','padding-top','15',0,''),(346015,110445,'117339','furniture','padding-bottom','15',0,''),(346016,110445,'117339','furniture','text-align','center',0,''),(346017,110446,'117340','furniture','text-align','center',0,''),(346018,110447,'117341','furniture','block_type','1',0,''),(346019,110447,'117341','furniture','padding-top','20',0,''),(346020,110448,'117342','furniture','text-align','center',0,''),(346021,110449,'117343','furniture','text','##TEXT_OR##',0,''),(346022,110449,'117343','furniture','font-size','18',0,''),(346023,110449,'117343','furniture','font-weight','700',0,''),(346024,110449,'117343','furniture','padding-top','15',0,''),(346025,110449,'117343','furniture','text-align','center',0,''),(346026,110449,'117343','furniture','content','\\_',0,'3'),(346027,110449,'117343','furniture','height','5',0,'3'),(346028,110449,'117343','furniture','width','70',0,'3'),(346029,110449,'117343','furniture','display','inline-block',0,'3'),(346030,110449,'117343','furniture','border-top-width','1',0,'3'),(346031,110449,'117343','furniture','border-top-color','$content-border-1',0,'3'),(346032,110449,'117343','furniture','margin-left','10',0,'3'),(346033,110449,'117343','furniture','margin-right','10',0,'3'),(346034,110449,'117343','furniture','content','\\_',0,'4'),(346035,110449,'117343','furniture','display','inline-block',0,'4'),(346036,110449,'117343','furniture','width','70',0,'4'),(346037,110449,'117343','furniture','height','5',0,'4'),(346038,110449,'117343','furniture','border-top-width','1',0,'4'),(346039,110449,'117343','furniture','border-top-color','$content-border-1',0,'4'),(346040,110449,'117343','furniture','margin-left','10',0,'4'),(346041,110449,'117343','furniture','margin-right','10',0,'4'),(346042,110449,'117343','furniture','position','relative',0,''),(346043,110449,'117343','furniture','top','-10',0,''),(346044,110450,'117344','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(346045,110450,'117344','furniture','tab_2','RETURNING CUSTOMER',1,''),(346046,110450,'117344','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(346047,110450,'117344','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(346048,110450,'117344','furniture','tab_2','RETURNING CUSTOMER',2,''),(346049,110450,'117344','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(346050,110450,'117344','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(346051,110450,'117344','furniture','tab_2','RETURNING CUSTOMER',3,''),(346052,110450,'117344','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(346053,110450,'117344','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(346054,110450,'117344','furniture','tab_2','RETURNING CUSTOMER',4,''),(346055,110450,'117344','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(346056,110451,'117345','furniture','block_type','8',0,''),(346057,110452,'117346','furniture','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(346058,110455,'117349','furniture','block_type','8',0,''),(346059,110456,'117350','furniture','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(346060,110457,'117351','furniture','block_type','1',0,''),(346061,110457,'117351','furniture','padding-left','20',0,''),(346062,110457,'117351','furniture','padding-right','20',0,''),(346063,110459,'117353','furniture','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(346064,110460,'117354','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(346065,110460,'117354','furniture','font-size','26',0,''),(346066,110460,'117354','furniture','font-family','$font-1',0,''),(346067,110460,'117354','furniture','padding-top','15',0,''),(346068,110460,'117354','furniture','padding-bottom','15',0,''),(346069,110460,'117354','furniture','text-align','center',0,''),(346070,110461,'117355','furniture','block_type','1',0,''),(346071,110461,'117355','furniture','padding-top','40',0,''),(346072,110461,'117355','furniture','background-color','$content-bg-2',0,''),(346073,110461,'117355','furniture','padding-bottom','40',0,''),(346074,110462,'117356','furniture','block_type','2',0,''),(346075,110462,'117356','furniture','background-color','$content-bg-1',0,''),(346076,110462,'117356','furniture','max-width','830',0,''),(346077,110462,'117356','furniture','margin_left_measure','auto',0,''),(346078,110462,'117356','furniture','margin_right_measure','auto',0,''),(346079,110462,'117356','furniture','padding-top','40',0,''),(346080,110462,'117356','furniture','padding-bottom','40',0,''),(346081,110462,'117356','furniture','schema','2-3',0,'5140'),(346082,110463,'117357','furniture','block_type','1',0,''),(346083,110464,'117358','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(346084,110464,'117358','furniture','font-size','18',0,''),(346085,110464,'117358','furniture','font-family','$font-1',0,''),(346086,110464,'117358','furniture','padding-top','15',0,''),(346087,110464,'117358','furniture','padding-bottom','15',0,''),(346088,110464,'117358','furniture','text-align','center',0,''),(346089,110464,'117358','furniture','text-transform','uppercase',0,''),(346090,110465,'117359','furniture','text-align','center',0,''),(346091,110465,'117359','furniture','hide_parents','2',0,''),(346092,110466,'117360','furniture','text-align','center',0,''),(346093,110467,'117361','furniture','text-align','center',0,''),(346094,110467,'117361','furniture','margin-bottom','40',0,''),(346095,110468,'117362','furniture','text','##TEXT_OR##',0,''),(346096,110468,'117362','furniture','font-size','18',0,''),(346097,110468,'117362','furniture','font-weight','700',0,''),(346098,110468,'117362','furniture','text-align','center',0,''),(346099,110468,'117362','furniture','content','\\_',0,'3'),(346100,110468,'117362','furniture','height','5',0,'3'),(346101,110468,'117362','furniture','width','70',0,'3'),(346102,110468,'117362','furniture','display','inline-block',0,'3'),(346103,110468,'117362','furniture','border-top-width','1',0,'3'),(346104,110468,'117362','furniture','border-top-color','$content-border-1',0,'3'),(346105,110468,'117362','furniture','margin-left','10',0,'3'),(346106,110468,'117362','furniture','margin-right','10',0,'3'),(346107,110468,'117362','furniture','content','\\_',0,'4'),(346108,110468,'117362','furniture','display','inline-block',0,'4'),(346109,110468,'117362','furniture','width','70',0,'4'),(346110,110468,'117362','furniture','height','5',0,'4'),(346111,110468,'117362','furniture','border-top-width','1',0,'4'),(346112,110468,'117362','furniture','border-top-color','$content-border-1',0,'4'),(346113,110468,'117362','furniture','margin-left','10',0,'4'),(346114,110468,'117362','furniture','margin-right','10',0,'4'),(346115,110468,'117362','furniture','position','relative',0,''),(346116,110468,'117362','furniture','padding-top','10',0,''),(346117,110468,'117362','furniture','padding-bottom','10',0,''),(346118,110469,'117363','furniture','text','##NEW_CUSTOMER##',0,''),(346119,110469,'117363','furniture','font-size','18',0,''),(346120,110469,'117363','furniture','font-family','$font-1',0,''),(346121,110469,'117363','furniture','text-align','center',0,''),(346122,110469,'117363','furniture','text-transform','uppercase',0,''),(346123,110469,'117363','furniture','margin-bottom','10',0,''),(346124,110470,'117364','furniture','text','##RETURNING_CUSTOMER##',0,''),(346125,110470,'117364','furniture','font-size','18',0,''),(346126,110470,'117364','furniture','font-family','$font-1',0,''),(346127,110470,'117364','furniture','text-transform','uppercase',0,''),(346128,110470,'117364','furniture','text-align','center',0,''),(346129,110471,'117365','furniture','max-width','230',0,''),(346130,110471,'117365','furniture','margin_left_measure','auto',0,''),(346131,110471,'117365','furniture','margin_right_measure','auto',0,''),(346132,110472,'117366','furniture','block_type','1',0,''),(346133,110472,'117366','furniture','padding-top','40',0,''),(346134,110472,'117366','furniture','background-color','$content-bg-2',0,''),(346135,110472,'117366','furniture','padding-bottom','40',0,''),(346136,110473,'117367','furniture','block_type','2',0,''),(346137,110473,'117367','furniture','background-color','$content-bg-1',0,''),(346138,110473,'117367','furniture','max-width','830',0,''),(346139,110473,'117367','furniture','margin_left_measure','auto',0,''),(346140,110473,'117367','furniture','margin_right_measure','auto',0,''),(346141,110473,'117367','furniture','padding-top','40',0,''),(346142,110473,'117367','furniture','padding-bottom','40',0,''),(346143,110473,'117367','furniture','schema','2-3',0,'5140'),(346144,110474,'117368','furniture','text','##NEW_CUSTOMER##',0,''),(346145,110474,'117368','furniture','font-size','18',0,''),(346146,110474,'117368','furniture','font-family','$font-1',0,''),(346147,110474,'117368','furniture','text-align','center',0,''),(346148,110474,'117368','furniture','text-transform','uppercase',0,''),(346149,110474,'117368','furniture','margin-bottom','10',0,''),(346150,110475,'117369','furniture','text-align','center',0,''),(346151,110476,'117370','furniture','text-align','center',0,''),(346152,110476,'117370','furniture','margin-bottom','40',0,''),(346153,110477,'117371','furniture','text','##TEXT_OR##',0,''),(346154,110477,'117371','furniture','font-size','18',0,''),(346155,110477,'117371','furniture','font-weight','700',0,''),(346156,110477,'117371','furniture','text-align','center',0,''),(346157,110477,'117371','furniture','content','\\_',0,'3'),(346158,110477,'117371','furniture','height','5',0,'3'),(346159,110477,'117371','furniture','width','70',0,'3'),(346160,110477,'117371','furniture','display','inline-block',0,'3'),(346161,110477,'117371','furniture','border-top-width','1',0,'3'),(346162,110477,'117371','furniture','border-top-color','$content-border-1',0,'3'),(346163,110477,'117371','furniture','margin-left','10',0,'3'),(346164,110477,'117371','furniture','margin-right','10',0,'3'),(346165,110477,'117371','furniture','content','\\_',0,'4'),(346166,110477,'117371','furniture','display','inline-block',0,'4'),(346167,110477,'117371','furniture','width','70',0,'4'),(346168,110477,'117371','furniture','height','5',0,'4'),(346169,110477,'117371','furniture','border-top-width','1',0,'4'),(346170,110477,'117371','furniture','border-top-color','$content-border-1',0,'4'),(346171,110477,'117371','furniture','margin-left','10',0,'4'),(346172,110477,'117371','furniture','margin-right','10',0,'4'),(346173,110477,'117371','furniture','position','relative',0,''),(346174,110477,'117371','furniture','padding-top','10',0,''),(346175,110477,'117371','furniture','padding-bottom','10',0,''),(346176,110478,'117372','furniture','block_type','1',0,''),(346177,110479,'117373','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(346178,110479,'117373','furniture','font-size','18',0,''),(346179,110479,'117373','furniture','font-family','$font-1',0,''),(346180,110479,'117373','furniture','padding-top','15',0,''),(346181,110479,'117373','furniture','padding-bottom','15',0,''),(346182,110479,'117373','furniture','text-align','center',0,''),(346183,110479,'117373','furniture','text-transform','uppercase',0,''),(346184,110480,'117374','furniture','text-align','center',0,''),(346185,110480,'117374','furniture','hide_parents','2',0,''),(346186,110481,'117375','furniture','text','##RETURNING_CUSTOMER##',0,''),(346187,110481,'117375','furniture','font-size','18',0,''),(346188,110481,'117375','furniture','font-family','$font-1',0,''),(346189,110481,'117375','furniture','text-transform','uppercase',0,''),(346190,110481,'117375','furniture','text-align','center',0,''),(346191,110482,'117376','furniture','max-width','230',0,''),(346192,110482,'117376','furniture','margin_left_measure','auto',0,''),(346193,110482,'117376','furniture','margin_right_measure','auto',0,''),(346194,110483,'117377','furniture','block_type','1',0,''),(346195,110484,'117378','furniture','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(346196,110484,'117378','furniture','margin-bottom','30',0,''),(346197,110485,'117379','furniture','block_type','1',0,''),(346198,110486,'117380','furniture','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(346199,110486,'117380','furniture','margin-bottom','30',0,''),(346200,110487,'1683019393.8433','furniture','block_type','1',0,''),(346201,110487,'1683019393.8433','furniture','style_class','mainBanner',0,''),(346202,110488,'1683018455.4659','furniture','banners_type','single',0,''),(346203,110488,'1683018455.4659','furniture','banners_group','3',0,''),(346204,110488,'1683018455.4659','furniture','ban_id','136',0,''),(346205,110490,'1705058746.79624','furniture','block_type','1',0,''),(346206,110490,'1705058746.79624','furniture','font-weight','normal',0,''),(346207,110491,'1705058746.808883','furniture','block_type','1',0,''),(346208,110491,'1705058746.808883','furniture','style_class','lowestPricedBox',0,''),(346209,110492,'1705058746.898727','furniture','banners_group','21',0,''),(346210,110492,'1705058746.898727','furniture','banners_type','banner',0,''),(346211,110492,'1705058746.898727','furniture','template','1',0,''),(346212,110493,'1705058747.047682','furniture','block_type','3',0,''),(346213,110493,'1705058747.047682','furniture','style_class','tripleBanner',0,''),(346214,110494,'1705058747.07661','furniture','text','<div>Returns and Exchanges</div>\n<div>30 Day Satisfaction Guarantee</div>\n',0,''),(346215,110494,'1705058747.07661','furniture','style_class','returns',0,''),(346216,110495,'1705058747.089734','furniture','text','<div>Warranty</div>\n<div>Min 12 months manufacturer’s warranty</div>',0,''),(346217,110495,'1705058747.089734','furniture','style_class','warranty',0,''),(346218,110496,'1705058747.092420','furniture','text','<div>Track your order</div>\n<div>Check the current status of your order</div>',0,''),(346219,110496,'1705058747.092420','furniture','style_class','track',0,''),(346220,110497,'1705058747.094689','furniture','block_type','1',0,''),(346221,110498,'1705058747.096170','furniture','col_in_row','4',0,''),(346222,110498,'1705058747.096170','furniture','view_as','carousel',0,''),(346223,110498,'1705058747.096170','furniture','show_attributes','1',0,''),(346224,110498,'1705058747.096170','furniture','col_in_row','3',0,'5140'),(346225,110498,'1705058747.096170','furniture','col_in_row','2',0,'5131'),(346226,110498,'1705058747.096170','furniture','col_in_row','1',0,'5161'),(346227,110498,'1705058747.096170','furniture','listing_type','productListing',0,''),(346228,110498,'1705058747.096170','furniture','show_qty_input','1',0,''),(346229,110498,'1705058747.096170','furniture','show_compare','1',0,''),(346230,110498,'1705058747.096170','furniture','lazy_load','1',0,''),(346231,110498,'1705058747.096170','furniture','show_model','1',0,''),(346232,110498,'1705058747.096170','furniture','show_properties','1',0,''),(346233,110498,'1705058747.096170','furniture','show_bonus_points','1',0,''),(346234,110498,'1705058747.096170','furniture','show_buy_button','1',0,''),(346235,110498,'1705058747.096170','furniture','show_view_button','1',0,''),(346236,110498,'1705058747.096170','furniture','show_wishlist_button','1',0,''),(346237,110498,'1705058747.096170','furniture','hide_parents','2',0,''),(346238,110499,'1705058747.101394','furniture','text','<h2>Furniture deals</h2>',0,''),(346239,110500,'1705058747.103997','furniture','block_type','1',0,''),(346240,110500,'1705058747.103997','furniture','style_class','shopByCollectionBox',0,''),(346241,110500,'1705058747.103997','furniture','padding-bottom','30',0,''),(346242,110501,'1705058747.131252','furniture','banners_group','11',0,''),(346243,110501,'1705058747.131252','furniture','banners_type','banner',0,''),(346244,110501,'1705058747.131252','furniture','template','1',0,''),(346245,110502,'1705058747.202374','furniture','text','<h2>Shop by collection</h2> ',0,''),(346246,110504,'117394','furniture','block_type','1',0,''),(346247,110505,'117395','furniture','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(346248,110507,'117397','furniture','block_type','1',0,''),(346249,110507,'117397','furniture','padding-top','40',0,''),(346250,110507,'117397','furniture','padding-bottom','80',0,''),(346251,110508,'117398','furniture','block_type','6',0,''),(346252,110509,'117399','furniture','block_type','1',0,''),(346253,110509,'117399','furniture','padding-top','20',0,''),(346254,110509,'117399','furniture','padding-left','20',0,''),(346255,110509,'117399','furniture','padding-right','20',0,''),(346256,110509,'117399','furniture','padding-bottom','20',0,''),(346257,110509,'117399','furniture','border-top-width','1',0,''),(346258,110509,'117399','furniture','border-left-width','1',0,''),(346259,110509,'117399','furniture','border-right-width','1',0,''),(346260,110509,'117399','furniture','border-bottom-width','1',0,''),(346261,110509,'117399','furniture','border-top-color','$content-border-1',0,''),(346262,110509,'117399','furniture','border-left-color','$content-border-1',0,''),(346263,110509,'117399','furniture','border-right-color','$content-border-1',0,''),(346264,110509,'117399','furniture','border-bottom-color','$content-border-1',0,''),(346265,110509,'117399','furniture','margin-right','20',0,''),(346266,110512,'117402','furniture','block_type','1',0,''),(346267,110512,'117402','furniture','padding-top','20',0,''),(346268,110513,'117403','furniture','block_type','6',0,''),(346269,110514,'117404','furniture','padding-right','20',0,''),(346270,110516,'117406','furniture','block_type','1',0,''),(346271,110516,'117406','furniture','padding-top','20',0,''),(346272,110517,'117407','furniture','block_type','6',0,''),(346273,110518,'117408','furniture','padding-right','20',0,''),(346274,110520,'117410','furniture','block_type','1',0,''),(346275,110520,'117410','furniture','style_class','account-password-wrap',0,''),(346276,110521,'117411','furniture','block_type','6',0,''),(346277,110521,'117411','furniture','schema','6-3',0,'5140'),(346278,110522,'117412','furniture','aria_name','account-menu',0,''),(346336,110543,'117414','furniture','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(346337,110544,'117415','furniture','block_type','1',0,''),(346338,110544,'117415','furniture','padding-top','20',0,''),(346339,110545,'117416','furniture','tab_1','RETURNING CUSTOMER',1,''),(346340,110545,'117416','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(346341,110545,'117416','furniture','tab_1','RETURNING CUSTOMER',2,''),(346342,110545,'117416','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(346343,110545,'117416','furniture','tab_1','RETURNING CUSTOMER',3,''),(346344,110545,'117416','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(346345,110545,'117416','furniture','tab_1','RETURNING CUSTOMER',4,''),(346346,110545,'117416','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(346347,110546,'117417','furniture','max-width','800',0,''),(346348,110546,'117417','furniture','margin_left_measure','auto',0,''),(346349,110546,'117417','furniture','margin_right_measure','auto',0,''),(346350,110547,'117418','furniture','block_type','8',0,''),(346351,110548,'117419','furniture','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(346352,110549,'117420','furniture','block_type','1',0,''),(346353,110549,'117420','furniture','padding-left','20',0,''),(346354,110549,'117420','furniture','padding-right','20',0,''),(346355,110551,'117422','furniture','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(346356,110552,'117423','furniture','block_type','1',0,''),(346357,110553,'117424','furniture','block_type','1',0,''),(346358,110554,'117425','furniture','margin-left','0',0,''),(346359,110554,'117425','furniture','margin-right','0',0,''),(346360,110554,'117425','furniture','margin-bottom','20',0,''),(346361,110555,'117426','furniture','margin-bottom','30',0,''),(346362,110556,'117427','furniture','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(346363,110557,'117428','furniture','block_type','1',0,''),(346364,110559,'117430','furniture','block_type','6',0,''),(346365,110559,'117430','furniture','font-weight','400',0,''),(346366,110559,'117430','furniture','schema','6-2',0,'5161'),(346367,110559,'117430','furniture','schema','6-2',0,'5140'),(346368,110560,'117431','furniture','font-weight','400',0,''),(346369,110560,'117431','furniture','padding-right','40',0,''),(346370,110560,'117431','furniture','padding-right','0',0,'5161'),(346371,110560,'117431','furniture','padding-right','0',0,'5140'),(346372,110561,'117432','furniture','col_in_row','3',0,''),(346373,110561,'117432','furniture','products_align','left',0,''),(346374,110561,'117432','furniture','font-weight','400',0,''),(346375,110561,'117432','furniture','show_qty_input','0',0,''),(346376,110561,'117432','furniture','listing_type','productListing',0,''),(346377,110561,'117432','furniture','listing_type_rows','no',0,''),(346378,110561,'117432','furniture','show_buy_button_b2b','on',0,''),(346379,110561,'117432','furniture','show_wishlist_button_b2b','1',0,''),(346380,110561,'117432','furniture','show_compare_b2b','1',0,''),(346381,110561,'117432','furniture','show_stock','0',0,''),(346382,110561,'117432','furniture','show_description','0',0,''),(346383,110561,'117432','furniture','show_model','0',0,''),(346384,110561,'117432','furniture','show_properties','0',0,''),(346385,110561,'117432','furniture','show_rating','0',0,''),(346386,110561,'117432','furniture','show_rating_counts','0',0,''),(346387,110561,'117432','furniture','show_price','0',0,''),(346388,110561,'117432','furniture','show_buy_button','0',0,''),(346389,110561,'117432','furniture','show_view_button','0',0,''),(346390,110561,'117432','furniture','show_wishlist_button','0',0,''),(346391,110561,'117432','furniture','show_compare','0',0,''),(346392,110561,'117432','furniture','show_name_rows','0',0,''),(346393,110561,'117432','furniture','show_image_rows','0',0,''),(346394,110561,'117432','furniture','show_stock_rows','0',0,''),(346395,110561,'117432','furniture','show_description_rows','0',0,''),(346396,110561,'117432','furniture','show_model_rows','0',0,''),(346397,110561,'117432','furniture','show_properties_rows','0',0,''),(346398,110561,'117432','furniture','show_rating_rows','0',0,''),(346399,110561,'117432','furniture','show_rating_counts_rows','0',0,''),(346400,110561,'117432','furniture','show_price_rows','0',0,''),(346401,110561,'117432','furniture','show_buy_button_rows','0',0,''),(346402,110561,'117432','furniture','show_qty_input_rows','0',0,''),(346403,110561,'117432','furniture','show_view_button_rows','0',0,''),(346404,110561,'117432','furniture','show_wishlist_button_rows','0',0,''),(346405,110561,'117432','furniture','show_compare_rows','0',0,''),(346406,110561,'117432','furniture','show_name_b2b','0',0,''),(346407,110561,'117432','furniture','show_image_b2b','0',0,''),(346408,110561,'117432','furniture','show_stock_b2b','0',0,''),(346409,110561,'117432','furniture','show_description_b2b','0',0,''),(346410,110561,'117432','furniture','show_model_b2b','0',0,''),(346411,110561,'117432','furniture','show_properties_b2b','0',0,''),(346412,110561,'117432','furniture','show_rating_b2b','0',0,''),(346413,110561,'117432','furniture','show_rating_counts_b2b','0',0,''),(346414,110561,'117432','furniture','show_price_b2b','0',0,''),(346415,110561,'117432','furniture','show_qty_input_b2b','0',0,''),(346416,110561,'117432','furniture','show_view_button_b2b','0',0,''),(346417,110561,'117432','furniture','show_attributes_b2b','0',0,''),(346418,110561,'117432','furniture','items_on_page','9',0,''),(346419,110561,'117432','furniture','col_in_row','2',0,'5140'),(346420,110561,'117432','furniture','col_in_row','1',0,'5161'),(346421,110561,'117432','furniture','product_names_teg','h2',0,''),(346422,110563,'117434','furniture','block_type','5',0,''),(346423,110563,'117434','furniture','padding-top','10',0,''),(346424,110563,'117434','furniture','padding-bottom','10',0,''),(346425,110563,'117434','furniture','schema','5-2',0,'5161'),(346426,110563,'117434','furniture','border-top-color','$content-border-1',0,''),(346427,110563,'117434','furniture','border-top-width','1',0,''),(346428,110565,'117436','furniture','float','right',0,''),(346429,110566,'117437','furniture','listing_type','productListing',0,''),(346430,110568,'117439','furniture','block_type','1',0,''),(346431,110568,'117439','furniture','padding-top','10',0,''),(346432,110568,'117439','furniture','padding-bottom','10',0,''),(346433,110568,'117439','furniture','border-bottom-width','1',0,''),(346434,110568,'117439','furniture','border-bottom-color','$content-border-1',0,''),(346435,110568,'117439','furniture','margin-left','0',0,''),(346436,110568,'117439','furniture','margin-right','0',0,''),(346437,110569,'117440','furniture','float','right',0,''),(346438,110569,'117440','furniture','display','none',0,'5161'),(346439,110570,'117441','furniture','float','left',0,''),(346440,110570,'117441','furniture','clear','none',0,''),(346441,110570,'117441','furniture','margin-left','20',0,''),(346442,110570,'117441','furniture','display','none',0,'5161'),(346443,110571,'117442','furniture','margin-right','20',0,''),(346444,110571,'117442','furniture','float','right',0,''),(346445,110571,'117442','furniture','clear','none',0,''),(346446,110571,'117442','furniture','display','none',0,'5140'),(346447,110572,'117443','furniture','float','left',0,''),(346448,110572,'117443','furniture','clear','none',0,''),(346449,110572,'117443','furniture','sort_pos_3','1',0,''),(346450,110572,'117443','furniture','sort_pos_4','2',0,''),(346451,110572,'117443','furniture','sort_pos_10','3',0,''),(346452,110572,'117443','furniture','sort_pos_9','4',0,''),(346453,110572,'117443','furniture','sort_pos_11','5',0,''),(346454,110572,'117443','furniture','sort_pos_12','6',0,''),(346455,110572,'117443','furniture','sort_pos_14','7',0,''),(346456,110572,'117443','furniture','sort_pos_13','8',0,''),(346457,110572,'117443','furniture','sort_pos_8','9',0,''),(346458,110572,'117443','furniture','sort_pos_7','10',0,''),(346459,110572,'117443','furniture','sort_pos_2','11',0,''),(346460,110572,'117443','furniture','sort_pos_1','12',0,''),(346461,110572,'117443','furniture','sort_pos_6','13',0,''),(346462,110572,'117443','furniture','sort_pos_5','14',0,''),(346463,110572,'117443','furniture','sort_pos_0','15',0,''),(346464,110572,'117443','furniture','sort_hide_10','1',0,''),(346465,110572,'117443','furniture','sort_hide_9','1',0,''),(346466,110572,'117443','furniture','hide_icons','1',0,''),(346467,110572,'117443','furniture','sort_hide_16','1',0,''),(346468,110572,'117443','furniture','sort_hide_15','1',0,''),(346469,110572,'117443','furniture','sort_hide_3','0',0,''),(346470,110572,'117443','furniture','sort_hide_4','0',0,''),(346471,110572,'117443','furniture','sort_hide_11','1',0,''),(346472,110572,'117443','furniture','sort_hide_12','1',0,''),(346473,110572,'117443','furniture','sort_hide_14','1',0,''),(346474,110572,'117443','furniture','sort_hide_13','1',0,''),(346475,110572,'117443','furniture','sort_hide_8','0',0,''),(346476,110572,'117443','furniture','sort_hide_7','0',0,''),(346477,110572,'117443','furniture','sort_hide_2','1',0,''),(346478,110572,'117443','furniture','sort_hide_1','1',0,''),(346479,110572,'117443','furniture','sort_hide_6','1',0,''),(346480,110572,'117443','furniture','sort_hide_5','1',0,''),(346481,110572,'117443','furniture','sort_hide_0','1',0,''),(346482,110573,'117444','furniture','block_type','1',0,''),(346483,110574,'117445','furniture','margin-bottom','30',0,''),(346484,110575,'117446','furniture','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(346485,110576,'117447','furniture','block_type','1',0,''),(346486,110577,'117448','furniture','block_type','5',0,''),(346487,110577,'117448','furniture','padding-top','10',0,''),(346488,110577,'117448','furniture','padding-bottom','10',0,''),(346489,110577,'117448','furniture','schema','5-2',0,'5161'),(346490,110577,'117448','furniture','border-top-color','$content-border-1',0,''),(346491,110577,'117448','furniture','border-top-width','1',0,''),(346492,110578,'117449','furniture','padding-top','3',0,''),(346493,110579,'117450','furniture','float','right',0,''),(346494,110579,'117450','furniture','height','31',0,''),(346495,110580,'117451','furniture','col_in_row','4',0,''),(346496,110580,'117451','furniture','products_align','left',0,''),(346497,110580,'117451','furniture','font-weight','400',0,''),(346498,110580,'117451','furniture','listing_type','productListing',0,''),(346499,110580,'117451','furniture','listing_type_rows','Rows',0,''),(346500,110580,'117451','furniture','show_buy_button_b2b','on',0,''),(346501,110580,'117451','furniture','show_wishlist_button_b2b','1',0,''),(346502,110580,'117451','furniture','show_compare_b2b','1',0,''),(346503,110580,'117451','furniture','listing_type_b2b','b2b',0,''),(346504,110580,'117451','furniture','show_image','0',0,''),(346505,110580,'117451','furniture','show_stock','0',0,''),(346506,110580,'117451','furniture','show_description','0',0,''),(346507,110580,'117451','furniture','show_model','0',0,''),(346508,110580,'117451','furniture','show_properties','0',0,''),(346509,110580,'117451','furniture','show_rating','0',0,''),(346510,110580,'117451','furniture','show_rating_counts','0',0,''),(346511,110580,'117451','furniture','show_price','0',0,''),(346512,110580,'117451','furniture','show_buy_button','0',0,''),(346513,110580,'117451','furniture','show_view_button','0',0,''),(346514,110580,'117451','furniture','show_wishlist_button','0',0,''),(346515,110580,'117451','furniture','show_compare','0',0,''),(346516,110580,'117451','furniture','show_name_rows','0',0,''),(346517,110580,'117451','furniture','show_image_rows','0',0,''),(346518,110580,'117451','furniture','show_stock_rows','0',0,''),(346519,110580,'117451','furniture','show_description_rows','0',0,''),(346520,110580,'117451','furniture','show_model_rows','0',0,''),(346521,110580,'117451','furniture','show_properties_rows','0',0,''),(346522,110580,'117451','furniture','show_rating_rows','0',0,''),(346523,110580,'117451','furniture','show_rating_counts_rows','0',0,''),(346524,110580,'117451','furniture','show_price_rows','0',0,''),(346525,110580,'117451','furniture','show_buy_button_rows','0',0,''),(346526,110580,'117451','furniture','show_qty_input_rows','0',0,''),(346527,110580,'117451','furniture','show_view_button_rows','0',0,''),(346528,110580,'117451','furniture','show_wishlist_button_rows','0',0,''),(346529,110580,'117451','furniture','show_compare_rows','0',0,''),(346530,110580,'117451','furniture','show_name_b2b','0',0,''),(346531,110580,'117451','furniture','show_image_b2b','0',0,''),(346532,110580,'117451','furniture','show_stock_b2b','0',0,''),(346533,110580,'117451','furniture','show_description_b2b','0',0,''),(346534,110580,'117451','furniture','show_model_b2b','0',0,''),(346535,110580,'117451','furniture','show_properties_b2b','0',0,''),(346536,110580,'117451','furniture','show_rating_b2b','0',0,''),(346537,110580,'117451','furniture','show_rating_counts_b2b','0',0,''),(346538,110580,'117451','furniture','show_price_b2b','0',0,''),(346539,110580,'117451','furniture','show_qty_input_b2b','0',0,''),(346540,110580,'117451','furniture','show_view_button_b2b','0',0,''),(346541,110580,'117451','furniture','show_attributes_b2b','0',0,''),(346542,110580,'117451','furniture','items_on_page','12',0,''),(346543,110580,'117451','furniture','col_in_row','2',0,'5140'),(346544,110580,'117451','furniture','col_in_row','1',0,'5161'),(346545,110580,'117451','furniture','product_names_teg','h2',0,''),(346546,110583,'117454','furniture','block_type','1',0,''),(346547,110584,'117455','furniture','block_type','1',0,''),(346548,110584,'117455','furniture','padding-top','10',0,''),(346549,110584,'117455','furniture','padding-bottom','10',0,''),(346550,110584,'117455','furniture','border-bottom-width','1',0,''),(346551,110584,'117455','furniture','border-bottom-color','$content-border-1',0,''),(346552,110584,'117455','furniture','margin-left','0',0,''),(346553,110584,'117455','furniture','margin-right','0',0,''),(346554,110585,'117456','furniture','clear','none',0,''),(346555,110585,'117456','furniture','float','left',0,''),(346556,110585,'117456','furniture','padding-top','3',0,''),(346557,110585,'117456','furniture','margin-left','20',0,''),(346558,110586,'117457','furniture','float','right',0,''),(346559,110586,'117457','furniture','display','none',0,'5161'),(346560,110587,'117458','furniture','margin-right','20',0,''),(346561,110587,'117458','furniture','float','right',0,''),(346562,110587,'117458','furniture','clear','none',0,''),(346563,110587,'117458','furniture','display','none',0,'5140'),(346564,110588,'117459','furniture','float','left',0,''),(346565,110588,'117459','furniture','clear','none',0,''),(346566,110588,'117459','furniture','margin-left','20',0,''),(346567,110588,'117459','furniture','display','none',0,'5161'),(346568,110589,'117460','furniture','float','left',0,''),(346569,110589,'117460','furniture','clear','none',0,''),(346570,110589,'117460','furniture','sort_pos_3','2',0,''),(346571,110589,'117460','furniture','sort_pos_4','3',0,''),(346572,110589,'117460','furniture','sort_pos_10','11',0,''),(346573,110589,'117460','furniture','sort_pos_9','10',0,''),(346574,110589,'117460','furniture','sort_pos_11','12',0,''),(346575,110589,'117460','furniture','sort_pos_12','13',0,''),(346576,110589,'117460','furniture','sort_pos_14','15',0,''),(346577,110589,'117460','furniture','sort_pos_13','14',0,''),(346578,110589,'117460','furniture','sort_pos_8','4',0,''),(346579,110589,'117460','furniture','sort_pos_7','5',0,''),(346580,110589,'117460','furniture','sort_pos_2','7',0,''),(346581,110589,'117460','furniture','sort_pos_1','6',0,''),(346582,110589,'117460','furniture','sort_pos_6','9',0,''),(346583,110589,'117460','furniture','sort_pos_5','8',0,''),(346584,110589,'117460','furniture','sort_pos_0','1',0,''),(346585,110589,'117460','furniture','sort_hide_10','1',0,''),(346586,110589,'117460','furniture','sort_hide_9','1',0,''),(346587,110589,'117460','furniture','sort_pos_15','16',0,''),(346588,110589,'117460','furniture','sort_pos_16','17',0,''),(346589,110589,'117460','furniture','sort_hide_4','0',0,''),(346590,110589,'117460','furniture','sort_hide_3','0',0,''),(346591,110589,'117460','furniture','sort_hide_16','1',0,''),(346592,110589,'117460','furniture','sort_hide_15','1',0,''),(346593,110589,'117460','furniture','sort_hide_11','1',0,''),(346594,110589,'117460','furniture','sort_hide_12','1',0,''),(346595,110589,'117460','furniture','sort_hide_14','1',0,''),(346596,110589,'117460','furniture','sort_hide_13','1',0,''),(346597,110589,'117460','furniture','sort_hide_8','0',0,''),(346598,110589,'117460','furniture','sort_hide_7','0',0,''),(346599,110589,'117460','furniture','sort_hide_2','1',0,''),(346600,110589,'117460','furniture','sort_hide_1','1',0,''),(346601,110589,'117460','furniture','sort_hide_6','1',0,''),(346602,110589,'117460','furniture','sort_hide_5','1',0,''),(346603,110589,'117460','furniture','sort_hide_0','0',0,''),(346604,110589,'117460','furniture','hide_icons','1',0,''),(346605,110590,'117461','furniture','margin-bottom','20',0,''),(346606,110591,'117462','furniture','block_type','1',0,''),(346607,110591,'117462','furniture','style_class','account-order-history',0,''),(346674,110615,'117467','furniture','block_type','1',0,''),(346675,110615,'117467','furniture','style_class','account-order-history-info',0,''),(346806,110674,'117507','furniture','block_type','1',0,''),(346807,110674,'117507','furniture','style_class','account-order-pay',0,''),(346808,110675,'117508','furniture','block_type','6',0,''),(346809,110675,'117508','furniture','schema','6-3',0,'5140'),(346810,110676,'117509','furniture','aria_name','account-menu',0,''),(346868,110697,'117511','furniture','block_type','3',0,''),(346869,110698,'117512','furniture','block_type','1',0,''),(346870,110698,'117512','furniture','padding-right','20',0,''),(346871,110698,'117512','furniture','padding-bottom','20',0,''),(346872,110699,'117513','furniture','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(346873,110700,'117514','furniture','orders_data','name',0,''),(346874,110700,'117514','furniture','padding-left','30',0,''),(346875,110701,'117515','furniture','block_type','1',0,''),(346876,110702,'117516','furniture','padding-left','30',0,''),(346877,110703,'117517','furniture','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(346878,110704,'117518','furniture','block_type','1',0,''),(346879,110704,'117518','furniture','padding-right','20',0,''),(346880,110704,'117518','furniture','padding-bottom','20',0,''),(346881,110705,'117519','furniture','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(346882,110706,'117520','furniture','orders_data','delivery_address',0,''),(346883,110706,'117520','furniture','padding-left','30',0,''),(346884,110707,'117521','furniture','block_type','1',0,''),(346885,110707,'117521','furniture','padding-right','20',0,''),(346886,110708,'117522','furniture','orders_data','shipping_method',0,''),(346887,110708,'117522','furniture','padding-left','30',0,''),(346888,110709,'117523','furniture','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(346889,110710,'117524','furniture','block_type','1',0,''),(346890,110711,'117525','furniture','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(346891,110712,'117526','furniture','orders_data','payment_method',0,''),(346892,110712,'117526','furniture','padding-left','30',0,''),(346893,110713,'117527','furniture','block_type','1',0,''),(346894,110713,'117527','furniture','padding-bottom','20',0,''),(346895,110714,'117528','furniture','orders_data','billing_address',0,''),(346896,110714,'117528','furniture','padding-left','30',0,''),(346897,110715,'117529','furniture','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(346898,110716,'117530','furniture','margin-bottom','20',0,''),(346899,110716,'117530','furniture','orders_data','name',0,''),(346900,110717,'117531','furniture','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(346901,110720,'117534','furniture','width','680',0,''),(346902,110720,'117534','furniture','font-weight','400',0,''),(346903,110720,'117534','furniture','font-size','12',0,''),(346904,110720,'117534','furniture','padding-top','20',0,''),(346905,110720,'117534','furniture','padding-bottom','20',0,''),(346906,110721,'117535','furniture','block_type','2',0,''),(346907,110721,'117535','furniture','font-weight','normal',0,''),(346908,110721,'117535','furniture','padding-bottom','20',0,''),(346909,110722,'117536','furniture','font-weight','400',0,''),(346910,110722,'117536','furniture','text-align','center',0,''),(346911,110722,'117536','furniture','padding-top','10',0,''),(346916,110723,'117537','furniture','block_type','11',0,''),(346917,110723,'117537','furniture','font-weight','normal',0,''),(346918,110724,'117538','furniture','text','<p>Email:</p>',1,''),(346919,110724,'117538','furniture','font-weight','normal',0,''),(346920,110724,'117538','furniture','text-align','right',0,''),(346921,110724,'117538','furniture','text','<p>Email:</p>',2,''),(346922,110724,'117538','furniture','text','<p>Email:</p>',3,''),(346923,110724,'117538','furniture','text','<p>Email:</p>',4,''),(346924,110725,'117539','furniture','font-weight','normal',0,''),(346925,110725,'117539','furniture','text-align','right',0,''),(346926,110726,'117540','furniture','block_type','11',0,''),(346927,110726,'117540','furniture','font-weight','normal',0,''),(346928,110727,'117541','furniture','text','<p>Phone:</p>',1,''),(346929,110727,'117541','furniture','font-weight','normal',0,''),(346930,110727,'117541','furniture','text-align','right',0,''),(346931,110727,'117541','furniture','text','<p>Phone:</p>',2,''),(346932,110727,'117541','furniture','text','<p>Phone:</p>',3,''),(346933,110727,'117541','furniture','text','<p>Phone:</p>',4,''),(346934,110728,'117542','furniture','font-weight','normal',0,''),(346935,110728,'117542','furniture','text-align','right',0,''),(346936,110729,'117543','furniture','block_type','1',0,''),(346937,110730,'117544','furniture','font-weight','400',0,''),(346938,110730,'117544','furniture','text-align','right',0,''),(346939,110730,'117544','furniture','padding-bottom','10',0,''),(346940,110730,'117544','furniture','address_spacer',',',0,''),(346941,110730,'117544','furniture','font-size','12',0,''),(346942,110731,'117545','furniture','block_type','11',0,''),(346943,110731,'117545','furniture','font-weight','400',0,''),(346944,110732,'117546','furniture','text','<p>Web:</p>',1,''),(346945,110732,'117546','furniture','font-weight','400',0,''),(346946,110732,'117546','furniture','text-align','right',0,''),(346947,110732,'117546','furniture','text','<p>Web:</p>',2,''),(346948,110732,'117546','furniture','text','<p>Web:</p>',3,''),(346949,110732,'117546','furniture','text','<p>Web:</p>',4,''),(346950,110733,'117547','furniture','font-weight','normal',0,''),(346951,110733,'117547','furniture','text-align','right',0,''),(346952,110734,'117548','furniture','font-weight','normal',0,''),(346953,110734,'117548','furniture','padding-top','20',0,''),(346954,110734,'117548','furniture','font-size','12',0,''),(346955,110735,'117549','furniture','block_type','1',0,''),(346956,110735,'117549','furniture','font-weight','normal',0,''),(346957,110735,'117549','furniture','padding-top','10',0,''),(346958,110735,'117549','furniture','padding-bottom','10',0,''),(346959,110737,'117551','furniture','text','<p>If undelivered please return to:</p>',1,''),(346960,110737,'117551','furniture','font-weight','bold',0,''),(346961,110737,'117551','furniture','text','<p>If undelivered please return to:</p>',2,''),(346962,110737,'117551','furniture','text','<p>If undelivered please return to:</p>',3,''),(346963,110737,'117551','furniture','text','<p>If undelivered please return to:</p>',4,''),(346964,110738,'117552','furniture','block_type','4',0,''),(346965,110738,'117552','furniture','font-weight','400',0,''),(346966,110738,'117552','furniture','border-top-width','1',0,''),(346967,110738,'117552','furniture','border-top-color','$content-border-1',0,''),(346968,110738,'117552','furniture','border-left-width','1',0,''),(346969,110738,'117552','furniture','border-left-color','$content-border-1',0,''),(346970,110738,'117552','furniture','border-right-width','1',0,''),(346971,110738,'117552','furniture','border-right-color','$content-border-1',0,''),(346972,110738,'117552','furniture','border-bottom-width','1',0,''),(346973,110738,'117552','furniture','border-bottom-color','$content-border-1',0,''),(346974,110739,'117553','furniture','block_type','2',0,''),(346975,110739,'117553','furniture','font-weight','normal',0,''),(346976,110739,'117553','furniture','border-right-width','1',0,''),(346977,110739,'117553','furniture','border-right-color','$content-border-1',0,''),(346978,110740,'117554','furniture','block_type','1',0,''),(346979,110740,'117554','furniture','font-weight','normal',0,''),(346980,110740,'117554','furniture','border-right-width','1',0,''),(346981,110740,'117554','furniture','border-right-color','$content-border-1',0,''),(346982,110740,'117554','furniture','background-color','$content-bg-2',0,''),(346983,110740,'117554','furniture','padding-top','10',0,''),(346984,110740,'117554','furniture','padding-left','10',0,''),(346985,110740,'117554','furniture','padding-right','10',0,''),(346986,110740,'117554','furniture','padding-bottom','10',0,''),(346987,110741,'117555','furniture','font-size','12',0,''),(346988,110741,'117555','furniture','font-weight','normal',0,''),(346989,110742,'117556','furniture','text','<p>SHIPPING ADDRESS:</p>',1,''),(346990,110742,'117556','furniture','font-size','13',0,''),(346991,110742,'117556','furniture','font-weight','bold',0,''),(346992,110742,'117556','furniture','padding-bottom','10',0,''),(346993,110742,'117556','furniture','text','<p>SHIPPING ADDRESS:</p>',2,''),(346994,110742,'117556','furniture','text','<p>SHIPPING ADDRESS:</p>',3,''),(346995,110742,'117556','furniture','text','<p>SHIPPING ADDRESS:</p>',4,''),(346996,110743,'117557','furniture','block_type','1',0,''),(346997,110743,'117557','furniture','font-weight','normal',0,''),(346998,110743,'117557','furniture','padding-top','10',0,''),(346999,110743,'117557','furniture','padding-left','10',0,''),(347000,110743,'117557','furniture','padding-right','10',0,''),(347001,110743,'117557','furniture','padding-bottom','10',0,''),(347002,110744,'117558','furniture','text','<p>CUSTOMER:</p>',1,''),(347003,110744,'117558','furniture','font-size','13',0,''),(347004,110744,'117558','furniture','font-weight','bold',0,''),(347005,110744,'117558','furniture','text','<p>CUSTOMER:</p>',2,''),(347006,110744,'117558','furniture','text','<p>CUSTOMER:</p>',3,''),(347007,110744,'117558','furniture','text','<p>CUSTOMER:</p>',4,''),(347008,110745,'117559','furniture','font-size','12',0,''),(347009,110747,'117561','furniture','text','<p>PHONE NUMBER:</p>',1,''),(347010,110747,'117561','furniture','font-size','13',0,''),(347011,110747,'117561','furniture','font-weight','bold',0,''),(347012,110747,'117561','furniture','padding-top','10',0,''),(347013,110747,'117561','furniture','text','<p>PHONE NUMBER:</p>',2,''),(347014,110747,'117561','furniture','text','<p>PHONE NUMBER:</p>',3,''),(347015,110747,'117561','furniture','text','<p>PHONE NUMBER:</p>',4,''),(347016,110748,'117562','furniture','font-size','12',0,''),(347017,110749,'117563','furniture','text','<p>E-MAIL ADDRESS:</p>',1,''),(347018,110749,'117563','furniture','font-size','13',0,''),(347019,110749,'117563','furniture','font-weight','bold',0,''),(347020,110749,'117563','furniture','padding-top','10',0,''),(347021,110749,'117563','furniture','text','<p>E-MAIL ADDRESS:</p>',2,''),(347022,110749,'117563','furniture','text','<p>E-MAIL ADDRESS:</p>',3,''),(347023,110749,'117563','furniture','text','<p>E-MAIL ADDRESS:</p>',4,''),(347024,110750,'117564','furniture','block_type','2',0,''),(347025,110750,'117564','furniture','font-weight','normal',0,''),(347026,110750,'117564','furniture','border-right-width','1',0,''),(347027,110750,'117564','furniture','border-right-color','$content-border-1',0,''),(347028,110750,'117564','furniture','border-top-width','1',0,''),(347029,110750,'117564','furniture','border-top-color','$content-border-1',0,''),(347030,110751,'117565','furniture','block_type','1',0,''),(347031,110751,'117565','furniture','font-weight','normal',0,''),(347032,110751,'117565','furniture','padding-top','10',0,''),(347033,110751,'117565','furniture','padding-left','10',0,''),(347034,110751,'117565','furniture','padding-right','10',0,''),(347035,110751,'117565','furniture','padding-bottom','10',0,''),(347036,110751,'117565','furniture','border-right-width','1',0,''),(347037,110751,'117565','furniture','border-right-color','$content-border-1',0,''),(347038,110753,'117567','furniture','text','<p>Shipping via</p>',1,''),(347039,110753,'117567','furniture','font-weight','bold',0,''),(347040,110753,'117567','furniture','text','<p>Shipping via</p>',2,''),(347041,110753,'117567','furniture','text','<p>Shipping via</p>',3,''),(347042,110753,'117567','furniture','text','<p>Shipping via</p>',4,''),(347043,110754,'117568','furniture','block_type','1',0,''),(347044,110754,'117568','furniture','font-weight','normal',0,''),(347045,110754,'117568','furniture','padding-top','10',0,''),(347046,110754,'117568','furniture','padding-left','10',0,''),(347047,110754,'117568','furniture','padding-right','10',0,''),(347048,110754,'117568','furniture','padding-bottom','10',0,''),(347049,110756,'117570','furniture','text','<p>Shipping service</p>',1,''),(347050,110756,'117570','furniture','font-weight','bold',0,''),(347051,110756,'117570','furniture','text','<p>Shipping service</p>',2,''),(347052,110756,'117570','furniture','text','<p>Shipping service</p>',3,''),(347053,110756,'117570','furniture','text','<p>Shipping service</p>',4,''),(347054,110757,'117571','furniture','font-weight','normal',0,''),(347055,110757,'117571','furniture','text-align','center',0,''),(347056,110757,'117571','furniture','padding-top','40',0,''),(347057,110759,'1639661081.5616','furniture','padding-top','15',0,''),(347058,110760,'117572','furniture','block_type','1',0,''),(347059,110761,'117573','furniture','block_type','8',0,''),(347060,110762,'1638807246.6206','furniture','text','<span></span>',0,''),(347061,110763,'117574','furniture','text','##TEXT_MAIN##',0,''),(347062,110763,'117574','furniture','margin-bottom','20',0,''),(347063,110763,'117574','furniture','text-align','center',0,''),(347064,110764,'117575','furniture','margin-bottom','20',0,''),(347065,110765,'117576','furniture','text','<h1>##HEADING_TITLE##</h1>',0,''),(347066,110767,'117578','furniture','block_type','2',0,''),(347067,110768,'117579','furniture','block_type','1',0,''),(347068,110768,'117579','furniture','style_class','product',0,''),(347069,110768,'117579','furniture','padding-right','10',0,''),(347070,110768,'117579','furniture','padding-bottom','20',0,''),(347071,110769,'117580','furniture','block_type','1',0,''),(347072,110770,'117581','furniture','product_element','products_name',0,''),(347073,110770,'117581','furniture','font-family','$font-1',0,''),(347074,110770,'117581','furniture','padding-bottom','10',0,''),(347075,110770,'117581','furniture','font-size','16',0,''),(347076,110771,'117582','furniture','block_type','2',0,''),(347077,110772,'117583','furniture','product_element','image',0,''),(347078,110772,'117583','furniture','padding-right','10',0,''),(347079,110773,'117584','furniture','product_element','products_price_old',0,''),(347080,110773,'117584','furniture','font-family','$font-1',0,''),(347081,110773,'117584','furniture','font-size','14',0,''),(347082,110773,'117584','furniture','text-decoration','line-through',0,''),(347083,110774,'117585','furniture','product_element','products_price',0,''),(347084,110774,'117585','furniture','font-family','$font-1',0,''),(347085,110774,'117585','furniture','font-size','20',0,''),(347086,110774,'117585','furniture','padding-top','20',0,''),(347087,110775,'117586','furniture','block_type','1',0,''),(347088,110775,'117586','furniture','style_class','product',0,''),(347089,110775,'117586','furniture','padding-left','10',0,''),(347090,110775,'117586','furniture','padding-bottom','20',0,''),(347091,110776,'117587','furniture','block_type','2',0,''),(347092,110777,'117588','furniture','product_element','image',0,''),(347093,110777,'117588','furniture','padding-right','10',0,''),(347094,110778,'117589','furniture','font-size','14',0,''),(347095,110778,'117589','furniture','font-family','$font-1',0,''),(347096,110778,'117589','furniture','text-decoration','line-through',0,''),(347097,110778,'117589','furniture','product_element','products_price_old',0,''),(347098,110779,'117590','furniture','product_element','products_price',0,''),(347099,110779,'117590','furniture','font-family','$font-1',0,''),(347100,110779,'117590','furniture','font-size','20',0,''),(347101,110779,'117590','furniture','padding-top','20',0,''),(347102,110780,'117591','furniture','block_type','1',0,''),(347103,110781,'117592','furniture','product_element','products_name',0,''),(347104,110781,'117592','furniture','font-family','$font-1',0,''),(347105,110781,'117592','furniture','font-size','16',0,''),(347106,110781,'117592','furniture','padding-bottom','10',0,''),(347107,110782,'117593','furniture','font-size','30',0,''),(347108,110782,'117593','furniture','font-family','$font-1',0,''),(347109,110782,'117593','furniture','text-align','center',0,''),(347110,110782,'117593','furniture','padding-bottom','50',0,''),(347111,110783,'117594','furniture','padding-bottom','20',0,''),(347112,110783,'117594','furniture','text-align','center',0,''),(347113,110784,'117595','furniture','width','680',0,''),(347114,110785,'117596','furniture','padding-top','200',0,''),(347115,110785,'117596','furniture','padding-left','200',0,''),(347120,110786,'117597','furniture','text','osCommerce 4',1,''),(347121,110786,'117597','furniture','font-family','$font-1',0,''),(347122,110786,'117597','furniture','font-size','40',0,''),(347123,110786,'117597','furniture','padding-top','50',0,''),(347124,110786,'117597','furniture','text-align','center',0,''),(347125,110786,'117597','furniture','text','osCommerce 4',2,''),(347126,110786,'117597','furniture','text','osCommerce 4',3,''),(347127,110786,'117597','furniture','text','osCommerce 4',4,''),(347128,110787,'117598','furniture','block_type','2',0,''),(347129,110787,'117598','furniture','border-top-width','1',0,''),(347130,110787,'117598','furniture','border-top-color','$content-border-1',0,''),(347131,110788,'117599','furniture','text-align','right',0,''),(347132,110788,'117599','furniture','padding-top','15',0,''),(347133,110788,'117599','furniture','padding-bottom','15',0,''),(347134,110788,'117599','furniture','font-size','14',0,''),(347135,110789,'117600','furniture','font-family','$font-1',0,''),(347136,110789,'117600','furniture','text-align','center',0,''),(347137,110789,'117600','furniture','font-size','20',0,''),(347138,110789,'117600','furniture','color','$content-color-1',0,''),(347139,110789,'117600','furniture','border-bottom-width','1',0,''),(347140,110789,'117600','furniture','border-bottom-color','$content-border-1',0,''),(347141,110789,'117600','furniture','padding-top','10',0,''),(347142,110789,'117600','furniture','padding-bottom','10',0,''),(347143,110790,'117601','furniture','block_type','1',0,''),(347144,110791,'117602','furniture','block_type','6',0,''),(347145,110791,'117602','furniture','schema','6-3',0,'5140'),(347146,110792,'117603','furniture','aria_name','account-menu',0,''),(347204,110812,'117604','furniture','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(347205,110813,'117606','furniture','max_items','10',0,''),(347206,110813,'117606','furniture','padding-bottom','20',0,''),(347207,110814,'117607','furniture','block_type','1',0,''),(347208,110814,'117607','furniture','padding-top','20',0,''),(347209,110814,'117607','furniture','padding-left','20',0,''),(347210,110814,'117607','furniture','padding-right','20',0,''),(347211,110814,'117607','furniture','padding-bottom','20',0,''),(347212,110815,'117608','furniture','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(347213,110817,'117610','furniture','block_type','1',0,''),(347214,110818,'117611','furniture','margin_left_measure','auto',0,''),(347215,110818,'117611','furniture','margin_right_measure','auto',0,''),(347216,110818,'117611','furniture','max-width','560',0,''),(347217,110819,'117612','furniture','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(347218,110820,'117613','furniture','margin-bottom','30',0,''),(347219,110821,'1683109599.245213','furniture','block_type','1',0,''),(347220,110822,'1683109599.255978','furniture','block_type','2',0,''),(347221,110822,'1683109599.255978','furniture','font-weight','400',0,''),(347222,110822,'1683109599.255978','furniture','padding-bottom','20',0,''),(347223,110822,'1683109599.255978','furniture','schema','2-2',0,'5161'),(347224,110822,'1683109599.255978','furniture','schema','2-2',0,'5140'),(347225,110823,'1683109599.25889','furniture','block_type','1',0,''),(347226,110824,'1683109599.25915','furniture','font-weight','400',0,''),(347227,110824,'1683109599.25915','furniture','padding-top','20',0,''),(347228,110824,'1683109599.25915','furniture','box_align','4',0,''),(347229,110824,'1683109599.25915','furniture','margin-bottom','50',0,''),(347230,110824,'1683109599.25915','furniture','align_position','horizontal',0,''),(347231,110824,'1683109599.25915','furniture','padding-right','0',0,'5140'),(347232,110824,'1683109599.25915','furniture','padding-right','20',0,''),(347233,110826,'1683109599.261153','furniture','padding-bottom','20',0,''),(347234,110830,'1683109599.263173','furniture','block_type','2',0,''),(347235,110830,'1683109599.263173','furniture','schema','2-2',0,'5145'),(347236,110831,'1683109599.264430','furniture','block_type','1',0,''),(347237,110831,'1683109599.264430','furniture','padding-right','9',0,''),(347238,110831,'1683109599.264430','furniture','padding-right','0',0,'5145'),(347239,110832,'1683109599.26556','furniture','cat_description','on',0,''),(347240,110832,'1683109599.26556','furniture','length_description','250',0,''),(347241,110832,'1683109599.26556','furniture','padding-bottom','7',0,''),(347242,110832,'1683109599.26556','furniture','link_description','1',0,''),(347243,110832,'1683109599.26556','furniture','border-bottom-width','1',0,''),(347244,110832,'1683109599.26556','furniture','border-bottom-color','$content-border-1',0,''),(347245,110833,'1683109599.26782','furniture','margin-bottom','7',0,''),(347246,110833,'1683109599.26782','furniture','border-bottom-width','1',0,''),(347247,110833,'1683109599.26782','furniture','border-bottom-color','$content-border-1',0,''),(347248,110834,'1683109599.267742','furniture','text','<div class=\"warranty\">\n <div class=\"title\">##TITLE_WARRANTY_PRODUCT##</div>\n <div class=\"seeDetails\"><a href=\"warranty\">##TITLE_SEE_DETAILS_PRODUCT##</a></div>\n</div>\n<div class=\"delivery\">\n <div class=\"title\">##TITLE_DELIVERY_PRODUCT##</div>\n <div class=\"seeDetails\"><a href=\"shipping\">##TITLE_SEE_DETAILS_PRODUCT##</a></div>\n</div>',0,''),(347249,110834,'1683109599.267742','furniture','style_class','warrantyProduct',0,''),(347250,110834,'1683109599.267742','furniture','margin-bottom','20',0,''),(347251,110835,'1683109599.27259','furniture','show_prices','1',0,''),(347252,110835,'1683109599.27259','furniture','show_images','swatches',0,''),(347253,110836,'1683109599.272734','furniture','block_type','1',0,''),(347254,110838,'1683109599.292170','furniture','block_type','1',0,''),(347255,110838,'1683109599.292170','furniture','padding-left','9',0,''),(347256,110838,'1683109599.292170','furniture','margin-top','20',0,'5145'),(347257,110838,'1683109599.292170','furniture','padding-left','0',0,'5145'),(347258,110839,'1683109599.294458','furniture','block_type','1',0,''),(347259,110839,'1683109599.294458','furniture','style_class','productNavigation',0,''),(347260,110839,'1683109599.294458','furniture','border-top-width','1',0,''),(347261,110839,'1683109599.294458','furniture','border-left-width','1',0,''),(347262,110839,'1683109599.294458','furniture','border-right-width','1',0,''),(347263,110839,'1683109599.294458','furniture','border-bottom-width','1',0,''),(347264,110839,'1683109599.294458','furniture','border-top-color','$content-border-1',0,''),(347265,110839,'1683109599.294458','furniture','border-left-color','$content-border-1',0,''),(347266,110839,'1683109599.294458','furniture','border-right-color','$content-border-1',0,''),(347267,110839,'1683109599.294458','furniture','border-bottom-color','$content-border-1',0,''),(347268,110840,'1683109599.297231','furniture','padding-top','15',0,''),(347269,110840,'1683109599.297231','furniture','padding-left','20',0,''),(347270,110840,'1683109599.297231','furniture','padding-right','20',0,''),(347271,110840,'1683109599.297231','furniture','padding-bottom','20',0,''),(347272,110840,'1683109599.297231','furniture','border-bottom-width','1',0,''),(347273,110840,'1683109599.297231','furniture','border-bottom-color','$content-border-1',0,''),(347274,110841,'1683109599.30758','furniture','block_type','1',0,''),(347275,110841,'1683109599.30758','furniture','padding-top','20',0,''),(347276,110841,'1683109599.30758','furniture','padding-left','20',0,''),(347277,110841,'1683109599.30758','furniture','padding-right','20',0,''),(347278,110841,'1683109599.30758','furniture','padding-bottom','20',0,''),(347279,110842,'1683109599.30990','furniture','margin-bottom','20',0,''),(347280,110843,'1683109599.310437','furniture','text-align','center',0,''),(347281,110843,'1683109599.310437','furniture','padding-bottom','10',0,''),(347282,110843,'1683109599.310437','furniture','border-bottom-color','$content-border-1',0,''),(347283,110843,'1683109599.310437','furniture','border-bottom-width','1',0,''),(347284,110843,'1683109599.310437','furniture','margin-bottom','10',0,''),(347285,110843,'1683109599.310437','furniture','padding-top','10',0,''),(347286,110843,'1683109599.310437','furniture','margin-top','10',0,''),(347287,110843,'1683109599.310437','furniture','border-top-color','$content-border-1',0,''),(347288,110843,'1683109599.310437','furniture','border-top-width','1',0,''),(347289,110844,'1683109599.313121','furniture','font-size','38',0,''),(347290,110844,'1683109599.313121','furniture','font-weight','400',0,''),(347291,110844,'1683109599.313121','furniture','line-height','35',0,''),(347292,110844,'1683109599.313121','furniture','font-family','$font-1',0,''),(347293,110844,'1683109599.313121','furniture','line_height_measure','px',0,''),(347294,110844,'1683109599.313121','furniture','padding-top','5',0,''),(347295,110844,'1683109599.313121','furniture','text-align','center',0,''),(347296,110844,'1683109599.313121','furniture','padding-bottom','15',0,''),(347297,110845,'1683109599.315738','furniture','box_align','2',0,''),(347298,110845,'1683109599.315738','furniture','margin-bottom','15',0,'5140'),(347299,110845,'1683109599.315738','furniture','text-align','right',0,'5140'),(347300,110845,'1683109599.315738','furniture','padding-top','5',0,''),(347301,110845,'1683109599.315738','furniture','text-align','center',0,''),(347302,110845,'1683109599.315738','furniture','margin-bottom','25',0,''),(347303,110846,'1683109599.322597','furniture','text-align','center',0,''),(347304,110846,'1683109599.322597','furniture','width','100',0,'5131'),(347305,110846,'1683109599.322597','furniture','width_measure','%',0,'5131'),(347306,110846,'1683109599.322597','furniture','float','none',0,'5131'),(347307,110846,'1683109599.322597','furniture','hide_additional_buttons','1',0,''),(347308,110846,'1683109599.322597','furniture','margin-bottom','15',0,''),(347309,110847,'1683109599.325422','furniture','text-align','center',0,''),(347310,110848,'1683109599.326754','furniture','text-align','center',0,''),(347311,110849,'1683109599.329949','furniture','text-align','center',0,''),(347312,110850,'1683109599.331551','furniture','margin-bottom','10',0,''),(347313,110851,'1683109599.334184','furniture','block_type','2',0,''),(347314,110852,'1683109599.335484','furniture','margin-bottom','15',0,''),(347315,110852,'1683109599.335484','furniture','padding-top','15',0,''),(347316,110853,'1683109599.33824','furniture','font-weight','400',0,''),(347317,110854,'1683109599.338931','furniture','font-weight','normal',0,''),(347318,110854,'1683109599.338931','furniture','padding-top','10',0,''),(347319,110854,'1683109599.338931','furniture','padding-bottom','10',0,''),(347320,110854,'1683109599.338931','furniture','box_align','4',0,''),(347321,110855,'1683109599.343489','furniture','block_type','1',0,''),(347322,110855,'1683109599.343489','furniture','padding-bottom','30',0,''),(347323,110856,'1683109599.345520','furniture','reviews_count','right',0,''),(347324,110856,'1683109599.345520','furniture','display','inline-block',0,''),(347325,110856,'1683109599.345520','furniture','padding-right','12',0,''),(347326,110856,'1683109599.345520','furniture','border-right-width','1',0,''),(347327,110856,'1683109599.345520','furniture','border-right-color','$content-border-2',0,''),(347328,110856,'1683109599.345520','furniture','line-height','1',0,''),(347329,110857,'1683109599.348715','furniture','text','##TEXT_WRITE_REVIEW##',0,''),(347330,110857,'1683109599.348715','furniture','style_class','writeReview',0,''),(347331,110857,'1683109599.348715','furniture','display','inline-block',0,''),(347332,110857,'1683109599.348715','furniture','padding-left','12',0,''),(347333,110857,'1683109599.348715','furniture','line-height','1',0,''),(347334,110857,'1683109599.348715','furniture','font-size','14',0,''),(347335,110858,'1683109648.23241','furniture','block_type','1',0,''),(347336,110859,'1683109648.239129','furniture','font-weight','normal',0,''),(347337,110859,'1683109648.239129','furniture','padding-bottom','20',0,''),(347338,110861,'1683109666.978945','furniture','block_type','1',0,''),(347339,110861,'1683109666.978945','furniture','padding-top','25',0,''),(347340,110861,'1683109666.978945','furniture','padding-bottom','25',0,''),(347341,110861,'1683109666.978945','furniture','style_class','catalog-product-wrap',0,''),(347342,110862,'1683109666.985380','furniture','block_type','1',0,''),(347343,110863,'1683109666.986680','furniture','tab_1','##TEXT_PRODUCT_OVERVIEW##',1,''),(347344,110863,'1683109666.986680','furniture','tab_2','##TEXT_DELIVERY_AND_RETURNS##',1,''),(347345,110863,'1683109666.986680','furniture','font-weight','400',0,''),(347346,110863,'1683109666.986680','furniture','tab_3','##TEXT_ASSEMBLY##',1,''),(347347,110863,'1683109666.986680','furniture','tab_1','##TEXT_PRODUCT_OVERVIEW##',2,''),(347348,110863,'1683109666.986680','furniture','tab_2','##TEXT_DELIVERY_AND_RETURNS##',2,''),(347349,110863,'1683109666.986680','furniture','tab_3','##TEXT_ASSEMBLY##',2,''),(347350,110863,'1683109666.986680','furniture','tab_1','##TEXT_PRODUCT_OVERVIEW##',3,''),(347351,110863,'1683109666.986680','furniture','tab_2','##TEXT_DELIVERY_AND_RETURNS##',3,''),(347352,110863,'1683109666.986680','furniture','tab_3','##TEXT_ASSEMBLY##',3,''),(347353,110863,'1683109666.986680','furniture','tab_1','##TEXT_PRODUCT_OVERVIEW##',4,''),(347354,110863,'1683109666.986680','furniture','tab_2','##TEXT_DELIVERY_AND_RETURNS##',4,''),(347355,110863,'1683109666.986680','furniture','tab_3','##TEXT_ASSEMBLY##',4,''),(347356,110864,'1683109666.994221','furniture','hTagsInline','block',0,''),(347357,110865,'1683109666.99570','furniture','margin-bottom','20',0,''),(347358,110865,'1683109666.99570','furniture','max-width','500',0,''),(347359,110866,'1683109666.999888','furniture','info_page','42',0,''),(347360,110867,'1683109667.001793','furniture','tab_1','##TEXT_CUSTOMER_ALSO_BOUGHT##',0,''),(347361,110867,'1683109667.001793','furniture','tab_2','##TEXT_YOU_RECENTLY_VIEWED##',0,''),(347362,110867,'1683109667.001793','furniture','margin-bottom','20',0,''),(347363,110868,'1683109667.003150','furniture','font-weight','400',0,''),(347364,110868,'1683109667.003150','furniture','padding-bottom','20',0,''),(347365,110868,'1683109667.003150','furniture','show_qty_input','1',0,''),(347366,110868,'1683109667.003150','furniture','show_compare','1',0,''),(347367,110868,'1683109667.003150','furniture','listing_type','productListing',0,''),(347368,110868,'1683109667.003150','furniture','view_as','carousel',0,''),(347369,110868,'1683109667.003150','furniture','show_name','0',0,''),(347370,110868,'1683109667.003150','furniture','show_image','0',0,''),(347371,110868,'1683109667.003150','furniture','show_stock','0',0,''),(347372,110868,'1683109667.003150','furniture','show_description','0',0,''),(347373,110868,'1683109667.003150','furniture','show_model','1',0,''),(347374,110868,'1683109667.003150','furniture','show_properties','1',0,''),(347375,110868,'1683109667.003150','furniture','show_rating','0',0,''),(347376,110868,'1683109667.003150','furniture','show_rating_counts','0',0,''),(347377,110868,'1683109667.003150','furniture','show_price','0',0,''),(347378,110868,'1683109667.003150','furniture','show_buy_button','1',0,''),(347379,110868,'1683109667.003150','furniture','show_view_button','1',0,''),(347380,110868,'1683109667.003150','furniture','show_wishlist_button','1',0,''),(347381,110868,'1683109667.003150','furniture','display','none',0,'5140'),(347382,110868,'1683109667.003150','furniture','product_names_teg','h2',0,''),(347383,110868,'1683109667.003150','furniture','show_attributes','1',0,''),(347384,110868,'1683109667.003150','furniture','col_in_row','4',0,''),(347385,110868,'1683109667.003150','furniture','show_bonus_points','1',0,''),(347386,110869,'1683109667.007130','furniture','font-weight','400',0,''),(347387,110869,'1683109667.007130','furniture','padding-bottom','20',0,''),(347388,110869,'1683109667.007130','furniture','show_compare','1',0,''),(347389,110869,'1683109667.007130','furniture','show_name','0',0,''),(347390,110869,'1683109667.007130','furniture','show_image','0',0,''),(347391,110869,'1683109667.007130','furniture','show_stock','0',0,''),(347392,110869,'1683109667.007130','furniture','show_description','0',0,''),(347393,110869,'1683109667.007130','furniture','show_model','1',0,''),(347394,110869,'1683109667.007130','furniture','show_properties','1',0,''),(347395,110869,'1683109667.007130','furniture','show_rating','0',0,''),(347396,110869,'1683109667.007130','furniture','show_rating_counts','0',0,''),(347397,110869,'1683109667.007130','furniture','show_price','0',0,''),(347398,110869,'1683109667.007130','furniture','show_buy_button','1',0,''),(347399,110869,'1683109667.007130','furniture','show_view_button','1',0,''),(347400,110869,'1683109667.007130','furniture','show_wishlist_button','1',0,''),(347401,110869,'1683109667.007130','furniture','listing_type','productListing',0,''),(347402,110869,'1683109667.007130','furniture','col_in_row','2',0,'5140'),(347403,110869,'1683109667.007130','furniture','col_in_row','1',0,'5161'),(347404,110869,'1683109667.007130','furniture','col_in_row','4',0,''),(347405,110869,'1683109667.007130','furniture','view_as','carousel',0,''),(347406,110869,'1683109667.007130','furniture','show_bonus_points','1',0,''),(347407,110869,'1683109667.007130','furniture','show_qty_input','1',0,''),(347408,110869,'1683109667.007130','furniture','show_attributes','1',0,''),(347409,110870,'1683109667.010748','furniture','block_type','3',0,''),(347410,110870,'1683109667.010748','furniture','style_class','tripleBanner',0,''),(347411,110871,'1683109667.01353','furniture','text','<div>##TEXT_RETURN_AND_EXCHANGES##</div>\n<div>##TEXT_SATISFACTION_GUARANTEE##</div>\n',0,''),(347412,110871,'1683109667.01353','furniture','style_class','returns',0,''),(347413,110872,'1683109667.014986','furniture','text','<div>##TEXT_WARRANTY##</div>\n<div>##TEXT_PERIOD_MANUFACTURER_WARRANTY##</div>',0,''),(347414,110872,'1683109667.014986','furniture','style_class','warranty',0,''),(347415,110873,'1683109667.016871','furniture','text','<div>##TEXT_TRACK_YOUR_ORDER##</div>\n<div>##TEXT_CHECK_CURRENT_STATUS##</div>',0,''),(347416,110873,'1683109667.016871','furniture','style_class','track',0,''),(347417,110874,'1683109667.01857','furniture','block_type','1',0,''),(347418,110875,'1683109667.019642','furniture','padding-bottom','10',0,''),(347419,110875,'1683109667.019642','furniture','padding-top','5',0,''),(347420,110876,'1707919218.1062','furniture','listing_type','b2b',0,''),(347421,110876,'1707919218.1062','furniture','platform','8',0,''),(347422,110876,'1707919218.1062','furniture','xsell_type_id','1',0,''),(347423,110887,'117665','furniture','block_type','1',0,''),(347424,110887,'117665','furniture','style_class','item-holder',0,''),(347425,110887,'117665','furniture','padding-top','25',0,''),(347426,110887,'117665','furniture','padding-left','25',0,''),(347427,110887,'117665','furniture','padding-right','25',0,''),(347428,110887,'117665','furniture','padding-bottom','25',0,''),(347429,110887,'117665','furniture','text-align','left',0,''),(347430,110888,'120921','furniture','block_type','1',0,''),(347431,110888,'120921','furniture','style_class','item-wrapper',0,''),(347432,110889,'120896','furniture','block_type','1',0,''),(347433,110889,'120896','furniture','style_class','item-nav',0,''),(347434,110893,'120919','furniture','block_type','1',0,''),(347435,110893,'120919','furniture','style_class','item-content',0,''),(347436,110895,'117668','furniture','description_characters','90',0,''),(347437,110898,'117673','furniture','margin-bottom','7',0,''),(347438,110899,'117675','furniture','clear','both',0,''),(347439,110900,'117676','furniture','margin-bottom','10',0,''),(347440,110903,'117678','furniture','block_type','1',0,''),(347441,110903,'117678','furniture','padding-bottom','30',0,''),(347442,110904,'117679','furniture','block_type','6',0,''),(347443,110904,'117679','furniture','font-weight','400',0,''),(347444,110904,'117679','furniture','schema','6-2',0,'5161'),(347445,110904,'117679','furniture','schema','6-2',0,'5140'),(347446,110905,'117680','furniture','font-weight','400',0,''),(347447,110905,'117680','furniture','padding-right','40',0,''),(347448,110905,'117680','furniture','padding-right','0',0,'5161'),(347449,110905,'117680','furniture','padding-right','0',0,'5140'),(347450,110905,'117680','furniture','margin-bottom','20',0,''),(347451,110906,'117681','furniture','margin-bottom','20',0,''),(347452,110907,'120916','furniture','block_type','1',0,''),(347453,110907,'120916','furniture','padding-right','40',0,''),(347454,110907,'120916','furniture','style_class','leftCategories',0,''),(347455,110907,'120916','furniture','padding-bottom','25',0,''),(347456,110907,'120916','furniture','padding-right','0',0,'5140'),(347457,110908,'120918','furniture','block_type','1',0,''),(347458,110908,'120918','furniture','background-color','$content-bg-2',0,''),(347459,110909,'120884','furniture','type','default',0,''),(347460,110909,'120884','furniture','class','menu-simple',0,''),(347461,110909,'120884','furniture','style_class','LeftCategories',0,''),(347462,110910,'120917','furniture','text','##TEXT_CATEGORIES##',0,''),(347463,110910,'120917','furniture','padding-top','22',0,''),(347464,110910,'120917','furniture','padding-left','25',0,''),(347465,110910,'120917','furniture','padding-right','25',0,''),(347466,110910,'120917','furniture','padding-bottom','10',0,''),(347467,110910,'120917','furniture','color','$content-color-1',0,''),(347468,110910,'120917','furniture','font-size','24',0,''),(347469,110910,'120917','furniture','font-weight','bold',0,''),(347470,110912,'117683','furniture','block_type','1',0,''),(347471,110912,'117683','furniture','padding-top','10',0,''),(347472,110912,'117683','furniture','padding-bottom','10',0,''),(347473,110912,'117683','furniture','border-bottom-width','1',0,''),(347474,110912,'117683','furniture','border-bottom-color','$content-border-1',0,''),(347475,110912,'117683','furniture','margin-left','0',0,''),(347476,110912,'117683','furniture','margin-right','0',0,''),(347477,110913,'117684','furniture','float','left',0,''),(347478,110913,'117684','furniture','clear','none',0,''),(347479,110913,'117684','furniture','sort_pos_3','2',0,''),(347480,110913,'117684','furniture','sort_pos_4','3',0,''),(347481,110913,'117684','furniture','sort_pos_10','11',0,''),(347482,110913,'117684','furniture','sort_pos_9','10',0,''),(347483,110913,'117684','furniture','sort_pos_11','12',0,''),(347484,110913,'117684','furniture','sort_pos_12','13',0,''),(347485,110913,'117684','furniture','sort_pos_14','15',0,''),(347486,110913,'117684','furniture','sort_pos_13','14',0,''),(347487,110913,'117684','furniture','sort_pos_8','4',0,''),(347488,110913,'117684','furniture','sort_pos_7','5',0,''),(347489,110913,'117684','furniture','sort_pos_2','7',0,''),(347490,110913,'117684','furniture','sort_pos_1','6',0,''),(347491,110913,'117684','furniture','sort_pos_6','9',0,''),(347492,110913,'117684','furniture','sort_pos_5','8',0,''),(347493,110913,'117684','furniture','sort_pos_0','1',0,''),(347494,110913,'117684','furniture','sort_hide_10','1',0,''),(347495,110913,'117684','furniture','sort_hide_9','1',0,''),(347496,110913,'117684','furniture','sort_pos_15','16',0,''),(347497,110913,'117684','furniture','sort_pos_16','17',0,''),(347498,110913,'117684','furniture','sort_hide_4','0',0,''),(347499,110913,'117684','furniture','sort_hide_3','0',0,''),(347500,110913,'117684','furniture','sort_hide_16','1',0,''),(347501,110913,'117684','furniture','sort_hide_15','1',0,''),(347502,110913,'117684','furniture','sort_hide_11','1',0,''),(347503,110913,'117684','furniture','sort_hide_12','1',0,''),(347504,110913,'117684','furniture','sort_hide_14','1',0,''),(347505,110913,'117684','furniture','sort_hide_13','1',0,''),(347506,110913,'117684','furniture','sort_hide_8','0',0,''),(347507,110913,'117684','furniture','sort_hide_7','0',0,''),(347508,110913,'117684','furniture','sort_hide_2','1',0,''),(347509,110913,'117684','furniture','sort_hide_1','1',0,''),(347510,110913,'117684','furniture','sort_hide_6','1',0,''),(347511,110913,'117684','furniture','sort_hide_5','1',0,''),(347512,110913,'117684','furniture','sort_hide_0','0',0,''),(347513,110913,'117684','furniture','hide_icons','1',0,''),(347514,110914,'117685','furniture','float','right',0,''),(347515,110914,'117685','furniture','display','none',0,'5161'),(347516,110915,'117686','furniture','float','left',0,''),(347517,110915,'117686','furniture','clear','none',0,''),(347518,110915,'117686','furniture','margin-left','20',0,''),(347519,110915,'117686','furniture','display','none',0,'5161'),(347520,110915,'117686','furniture','display','none',0,'5145'),(347521,110916,'117687','furniture','margin-right','20',0,''),(347522,110916,'117687','furniture','float','right',0,''),(347523,110916,'117687','furniture','clear','none',0,''),(347524,110916,'117687','furniture','display','none',0,'5140'),(347525,110917,'117688','furniture','block_type','5',0,''),(347526,110917,'117688','furniture','padding-top','10',0,''),(347527,110917,'117688','furniture','padding-bottom','10',0,''),(347528,110917,'117688','furniture','schema','5-2',0,'5161'),(347529,110917,'117688','furniture','border-top-color','$content-border-1',0,''),(347530,110917,'117688','furniture','border-top-width','1',0,''),(347531,110918,'117689','furniture','padding-top','3',0,''),(347532,110919,'117690','furniture','float','right',0,''),(347533,110919,'117690','furniture','height','31',0,''),(347534,110920,'117691','furniture','col_in_row','3',0,''),(347535,110920,'117691','furniture','products_align','left',0,''),(347536,110920,'117691','furniture','font-weight','400',0,''),(347537,110920,'117691','furniture','listing_type','productListing',0,''),(347538,110920,'117691','furniture','listing_type_rows','Rows',0,''),(347539,110920,'117691','furniture','show_buy_button_b2b','on',0,''),(347540,110920,'117691','furniture','show_wishlist_button_b2b','1',0,''),(347541,110920,'117691','furniture','show_compare_b2b','1',0,''),(347542,110920,'117691','furniture','show_image','0',0,''),(347543,110920,'117691','furniture','show_stock','0',0,''),(347544,110920,'117691','furniture','show_description','0',0,''),(347545,110920,'117691','furniture','show_rating','0',0,''),(347546,110920,'117691','furniture','show_rating_counts','0',0,''),(347547,110920,'117691','furniture','show_price','0',0,''),(347548,110920,'117691','furniture','show_view_button','0',0,''),(347549,110920,'117691','furniture','show_wishlist_button','0',0,''),(347550,110920,'117691','furniture','show_compare','0',0,''),(347551,110920,'117691','furniture','show_name_rows','0',0,''),(347552,110920,'117691','furniture','show_image_rows','0',0,''),(347553,110920,'117691','furniture','show_stock_rows','0',0,''),(347554,110920,'117691','furniture','show_description_rows','0',0,''),(347555,110920,'117691','furniture','show_model_rows','0',0,''),(347556,110920,'117691','furniture','show_properties_rows','0',0,''),(347557,110920,'117691','furniture','show_rating_rows','0',0,''),(347558,110920,'117691','furniture','show_rating_counts_rows','0',0,''),(347559,110920,'117691','furniture','show_price_rows','0',0,''),(347560,110920,'117691','furniture','show_buy_button_rows','0',0,''),(347561,110920,'117691','furniture','show_qty_input_rows','0',0,''),(347562,110920,'117691','furniture','show_view_button_rows','0',0,''),(347563,110920,'117691','furniture','show_wishlist_button_rows','0',0,''),(347564,110920,'117691','furniture','show_compare_rows','0',0,''),(347565,110920,'117691','furniture','show_name_b2b','0',0,''),(347566,110920,'117691','furniture','show_image_b2b','0',0,''),(347567,110920,'117691','furniture','show_stock_b2b','0',0,''),(347568,110920,'117691','furniture','show_description_b2b','0',0,''),(347569,110920,'117691','furniture','show_model_b2b','0',0,''),(347570,110920,'117691','furniture','show_properties_b2b','0',0,''),(347571,110920,'117691','furniture','show_rating_b2b','0',0,''),(347572,110920,'117691','furniture','show_rating_counts_b2b','0',0,''),(347573,110920,'117691','furniture','show_price_b2b','0',0,''),(347574,110920,'117691','furniture','show_qty_input_b2b','0',0,''),(347575,110920,'117691','furniture','show_view_button_b2b','0',0,''),(347576,110920,'117691','furniture','show_attributes_b2b','0',0,''),(347577,110920,'117691','furniture','items_on_page','9',0,''),(347578,110920,'117691','furniture','col_in_row','2',0,'5140'),(347579,110920,'117691','furniture','col_in_row','1',0,'5161'),(347580,110920,'117691','furniture','product_names_teg','h2',0,''),(347581,110920,'117691','furniture','padding-top','20',0,''),(347582,110920,'117691','furniture','padding-bottom','20',0,''),(347583,110920,'117691','furniture','col_in_row','2',0,'5145'),(347584,110921,'120912','furniture','block_type','5',0,''),(347585,110921,'120912','furniture','padding-top','10',0,''),(347586,110921,'120912','furniture','schema','5-2',0,'5161'),(347587,110922,'120913','furniture','padding-top','3',0,''),(347588,110923,'120914','furniture','float','right',0,''),(347589,110923,'120914','furniture','height','31',0,''),(347590,110924,'1639760443.0645','furniture','carousel','1',0,''),(347591,110924,'1639760443.0645','furniture','col_in_row','4',0,''),(347592,110924,'1639760443.0645','furniture','fancibox','1',0,''),(347593,110926,'117693','furniture','block_type','1',0,''),(347594,110927,'117694','furniture','margin-bottom','20',0,''),(347595,110931,'117696','furniture','block_type','1',0,''),(347596,110933,'117698','furniture','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(347597,110934,'117699','furniture','width','680',0,''),(347598,110934,'117699','furniture','font-weight','normal',0,''),(347599,110934,'117699','furniture','font-size','12',0,''),(347600,110934,'117699','furniture','padding-top','20',0,''),(347601,110934,'117699','furniture','padding-bottom','20',0,''),(347602,110934,'117699','furniture','color','$content-color-1',0,''),(347603,110935,'117700','furniture','font-weight','400',0,''),(347604,110935,'117700','furniture','padding-top','20',0,''),(347605,110935,'117700','furniture','padding-bottom','0',0,''),(347606,110935,'117700','furniture','font-size','12',0,''),(347607,110936,'117701','furniture','block_type','3',0,''),(347608,110936,'117701','furniture','font-weight','normal',0,''),(347609,110936,'117701','furniture','padding-top','20',0,''),(347610,110937,'117702','furniture','text','<p>If undelivered please return to:</p>',1,''),(347611,110937,'117702','furniture','font-size','12',0,''),(347612,110937,'117702','furniture','font-weight','bold',0,''),(347613,110937,'117702','furniture','text','<p>If undelivered please return to:</p>',2,''),(347614,110937,'117702','furniture','text','<p>If undelivered please return to:</p>',3,''),(347615,110937,'117702','furniture','text','<p>If undelivered please return to:</p>',4,''),(347616,110938,'117703','furniture','font-size','12',0,''),(347617,110939,'117704','furniture','text','<p>Thank you for your order</p>',1,''),(347618,110939,'117704','furniture','color','$content-color-1',0,''),(347619,110939,'117704','furniture','font-size','13',0,''),(347620,110939,'117704','furniture','font-weight','bold',0,''),(347621,110939,'117704','furniture','padding-top','5',0,''),(347622,110939,'117704','furniture','text-align','center',0,''),(347623,110939,'117704','furniture','text','<p>Thank you for your order</p>',2,''),(347624,110939,'117704','furniture','text','<p>Thank you for your order</p>',3,''),(347625,110939,'117704','furniture','text','<p>Thank you for your order</p>',4,''),(347626,110940,'117705','furniture','font-weight','400',0,''),(347627,110940,'117705','furniture','text-align','center',0,''),(347628,110940,'117705','furniture','padding-top','0',0,''),(347630,110940,'117705','furniture','padding-left','20',0,''),(347631,110940,'117705','furniture','padding-right','20',0,''),(347635,110941,'117706','furniture','block_type','6',0,''),(347636,110941,'117706','furniture','font-weight','normal',0,''),(347637,110941,'117706','furniture','font-size','16',0,''),(347638,110942,'117707','furniture','text','<p>Email:</p>',1,''),(347639,110942,'117707','furniture','font-weight','normal',0,''),(347640,110942,'117707','furniture','text-align','right',0,''),(347641,110942,'117707','furniture','font-size','12',0,''),(347642,110942,'117707','furniture','text','<p>Email:</p>',2,''),(347643,110942,'117707','furniture','text','<p>Email:</p>',3,''),(347644,110942,'117707','furniture','text','<p>Email:</p>',4,''),(347645,110943,'117708','furniture','font-weight','normal',0,''),(347646,110943,'117708','furniture','text-align','right',0,''),(347647,110943,'117708','furniture','font-size','12',0,''),(347648,110944,'117709','furniture','text','<p>If something has gone wrong please contact us at:</p>',1,''),(347649,110944,'117709','furniture','font-size','12',0,''),(347650,110944,'117709','furniture','font-weight','bold',0,''),(347651,110944,'117709','furniture','text-align','right',0,''),(347652,110944,'117709','furniture','text','<p>If something has gone wrong please contact us at:</p>',2,''),(347653,110944,'117709','furniture','text','<p>If something has gone wrong please contact us at:</p>',3,''),(347654,110944,'117709','furniture','text','<p>If something has gone wrong please contact us at:</p>',4,''),(347655,110945,'117710','furniture','block_type','6',0,''),(347656,110945,'117710','furniture','font-weight','normal',0,''),(347657,110945,'117710','furniture','font-size','16',0,''),(347658,110946,'117711','furniture','text','<p>Phone:</p>',1,''),(347659,110946,'117711','furniture','font-weight','normal',0,''),(347660,110946,'117711','furniture','text-align','right',0,''),(347661,110946,'117711','furniture','font-size','12',0,''),(347662,110946,'117711','furniture','text','<p>Phone:</p>',2,''),(347663,110946,'117711','furniture','text','<p>Phone:</p>',3,''),(347664,110946,'117711','furniture','text','<p>Phone:</p>',4,''),(347665,110947,'117712','furniture','font-weight','normal',0,''),(347666,110947,'117712','furniture','text-align','right',0,''),(347667,110947,'117712','furniture','font-size','12',0,''),(347668,110948,'117713','furniture','block_type','2',0,''),(347669,110948,'117713','furniture','font-weight','normal',0,''),(347670,110948,'117713','furniture','padding-bottom','20',0,''),(347671,110949,'117714','furniture','font-weight','400',0,''),(347672,110949,'117714','furniture','padding-top','20',0,''),(347677,110950,'117715','furniture','block_type','11',0,''),(347678,110950,'117715','furniture','font-weight','normal',0,''),(347679,110951,'117716','furniture','text','<p>Phone:</p>',1,''),(347680,110951,'117716','furniture','font-weight','normal',0,''),(347681,110951,'117716','furniture','text-align','right',0,''),(347682,110951,'117716','furniture','text','<p>Phone:</p>',2,''),(347683,110951,'117716','furniture','text','<p>Phone:</p>',3,''),(347684,110951,'117716','furniture','text','<p>Phone:</p>',4,''),(347685,110952,'117717','furniture','font-weight','normal',0,''),(347686,110952,'117717','furniture','text-align','right',0,''),(347687,110953,'117718','furniture','block_type','11',0,''),(347688,110953,'117718','furniture','font-weight','normal',0,''),(347689,110954,'117719','furniture','text','<p>Web:</p>',1,''),(347690,110954,'117719','furniture','font-weight','normal',0,''),(347691,110954,'117719','furniture','text-align','right',0,''),(347692,110954,'117719','furniture','text','<p>Web:</p>',2,''),(347693,110954,'117719','furniture','text','<p>Web:</p>',3,''),(347694,110954,'117719','furniture','text','<p>Web:</p>',4,''),(347695,110955,'117720','furniture','font-weight','normal',0,''),(347696,110955,'117720','furniture','text-align','right',0,''),(347697,110956,'117721','furniture','block_type','1',0,''),(347698,110957,'117722','furniture','font-weight','normal',0,''),(347699,110957,'117722','furniture','text-align','right',0,''),(347700,110957,'117722','furniture','padding-bottom','10',0,''),(347701,110957,'117722','furniture','address_spacer',',',0,''),(347702,110957,'117722','furniture','font-size','12',0,''),(347703,110958,'117723','furniture','block_type','11',0,''),(347704,110958,'117723','furniture','font-weight','normal',0,''),(347705,110959,'117724','furniture','text','<p>Email:</p>',1,''),(347706,110959,'117724','furniture','font-weight','normal',0,''),(347707,110959,'117724','furniture','text-align','right',0,''),(347708,110959,'117724','furniture','text','<p>Email:</p>',2,''),(347709,110959,'117724','furniture','text','<p>Email:</p>',3,''),(347710,110959,'117724','furniture','text','<p>Email:</p>',4,''),(347711,110960,'117725','furniture','font-weight','normal',0,''),(347712,110960,'117725','furniture','text-align','right',0,''),(347713,110961,'117726','furniture','block_type','4',0,''),(347714,110961,'117726','furniture','font-weight','normal',0,''),(347715,110961,'117726','furniture','border-top-width','1',0,''),(347716,110961,'117726','furniture','border-top-color','$content-border-1',0,''),(347717,110961,'117726','furniture','border-left-width','1',0,''),(347718,110961,'117726','furniture','border-left-color','$content-border-1',0,''),(347719,110961,'117726','furniture','border-right-width','1',0,''),(347720,110961,'117726','furniture','border-right-color','$content-border-1',0,''),(347721,110961,'117726','furniture','border-bottom-width','1',0,''),(347722,110961,'117726','furniture','border-bottom-color','$content-border-1',0,''),(347723,110962,'117727','furniture','block_type','2',0,''),(347724,110962,'117727','furniture','font-weight','normal',0,''),(347725,110962,'117727','furniture','border-right-width','1',0,''),(347726,110962,'117727','furniture','border-right-color','$content-border-1',0,''),(347727,110963,'117728','furniture','block_type','1',0,''),(347728,110963,'117728','furniture','font-weight','400',0,''),(347729,110963,'117728','furniture','background-color','$content-bg-2',0,''),(347730,110963,'117728','furniture','padding-top','10',0,''),(347731,110963,'117728','furniture','padding-left','10',0,''),(347732,110963,'117728','furniture','padding-right','10',0,''),(347733,110963,'117728','furniture','padding-bottom','30',0,''),(347734,110964,'117729','furniture','font-size','12',0,''),(347735,110965,'117730','furniture','text','<p>ADDRESS:</p>\n',1,''),(347736,110965,'117730','furniture','font-size','14',0,''),(347737,110965,'117730','furniture','font-weight','bold',0,''),(347738,110965,'117730','furniture','text','<p>ADDRESS:</p>\n',2,''),(347739,110965,'117730','furniture','text','<p>ADDRESS:</p>\n',3,''),(347740,110965,'117730','furniture','text','<p>ADDRESS:</p>\n',4,''),(347741,110966,'117731','furniture','block_type','1',0,''),(347742,110966,'117731','furniture','font-weight','normal',0,''),(347743,110966,'117731','furniture','padding-top','10',0,''),(347744,110966,'117731','furniture','padding-left','10',0,''),(347745,110966,'117731','furniture','padding-right','10',0,''),(347746,110966,'117731','furniture','padding-bottom','10',0,''),(347747,110968,'117733','furniture','text','<p>E-MAIL ADDRESS:</p>',1,''),(347748,110968,'117733','furniture','font-weight','bold',0,''),(347749,110968,'117733','furniture','font-size','14',0,''),(347750,110968,'117733','furniture','padding-top','10',0,''),(347751,110968,'117733','furniture','text','<p>E-MAIL ADDRESS:</p>',2,''),(347752,110968,'117733','furniture','text','<p>E-MAIL ADDRESS:</p>',3,''),(347753,110968,'117733','furniture','text','<p>E-MAIL ADDRESS:</p>',4,''),(347754,110969,'117734','furniture','font-weight','normal',0,''),(347755,110970,'117735','furniture','font-weight','normal',0,''),(347756,110971,'117736','furniture','text','<p>PHONE NUMBER:</p>',1,''),(347757,110971,'117736','furniture','font-size','14',0,''),(347758,110971,'117736','furniture','font-weight','bold',0,''),(347759,110971,'117736','furniture','padding-top','10',0,''),(347760,110971,'117736','furniture','text','<p>PHONE NUMBER:</p>',2,''),(347761,110971,'117736','furniture','text','<p>PHONE NUMBER:</p>',3,''),(347762,110971,'117736','furniture','text','<p>PHONE NUMBER:</p>',4,''),(347763,110972,'117737','furniture','text','<p>CUSTOMER:</p>',1,''),(347764,110972,'117737','furniture','font-size','13',0,''),(347765,110972,'117737','furniture','font-weight','bold',0,''),(347766,110972,'117737','furniture','text','<p>CUSTOMER:</p>',2,''),(347767,110972,'117737','furniture','text','<p>CUSTOMER:</p>',3,''),(347768,110972,'117737','furniture','text','<p>CUSTOMER:</p>',4,''),(347769,110973,'117738','furniture','font-size','14',0,''),(347770,110973,'117738','furniture','font-weight','bold',0,''),(347771,110973,'117738','furniture','text-align','center',0,''),(347772,110973,'117738','furniture','padding-bottom','10',0,''),(347773,110973,'117738','furniture','padding-top','10',0,''),(347774,110974,'117739','furniture','text','<p>Order date:</p>\n',1,''),(347775,110974,'117739','furniture','font-weight','bold',0,''),(347776,110974,'117739','furniture','text-align','center',0,''),(347777,110974,'117739','furniture','font-size','12',0,''),(347778,110974,'117739','furniture','text','<p>Order date:</p>\n',2,''),(347779,110974,'117739','furniture','text','<p>Order date:</p>\n',3,''),(347780,110974,'117739','furniture','text','<p>Order date:</p>\n',4,''),(347781,110975,'117740','furniture','font-weight','normal',0,''),(347782,110975,'117740','furniture','text-align','center',0,''),(347783,110975,'117740','furniture','padding-bottom','10',0,''),(347784,110976,'117741','furniture','block_type','5',0,''),(347785,110976,'117741','furniture','font-weight','normal',0,''),(347786,110976,'117741','furniture','border-bottom-width','1',0,''),(347787,110976,'117741','furniture','border-bottom-color','$content-border-1',0,''),(347788,110976,'117741','furniture','border-top-width','1',0,''),(347789,110976,'117741','furniture','border-top-color','$content-border-1',0,''),(347790,110976,'117741','furniture','border-left-color','$content-border-1',0,''),(347791,110976,'117741','furniture','border-left-width','1',0,''),(347792,110977,'117742','furniture','block_type','1',0,''),(347793,110977,'117742','furniture','font-weight','normal',0,''),(347794,110977,'117742','furniture','padding-top','10',0,''),(347795,110977,'117742','furniture','padding-left','10',0,''),(347796,110977,'117742','furniture','padding-right','10',0,''),(347797,110978,'117743','furniture','font-weight','400',0,''),(347798,110978,'117743','furniture','line-height','120',0,''),(347799,110978,'117743','furniture','line_height_measure','%',0,''),(347800,110978,'117743','furniture','font-size','12',0,''),(347801,110979,'117744','furniture','text','<p>SHIPPING ADDRESS:</p>',1,''),(347802,110979,'117744','furniture','font-size','14',0,''),(347803,110979,'117744','furniture','font-weight','bold',0,''),(347804,110979,'117744','furniture','padding-bottom','10',0,''),(347805,110979,'117744','furniture','text','<p>SHIPPING ADDRESS:</p>',2,''),(347806,110979,'117744','furniture','text','<p>SHIPPING ADDRESS:</p>',3,''),(347807,110979,'117744','furniture','text','<p>SHIPPING ADDRESS:</p>',4,''),(347810,110983,'117745','furniture','block_type','1',0,''),(347811,110984,'117746','furniture','block_type','6',0,''),(347812,110984,'117746','furniture','schema','6-3',0,'5140'),(347813,110985,'117747','furniture','aria_name','account-menu',0,''),(347871,111005,'117748','furniture','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(347872,111006,'117749','furniture','link','Quotation Info',0,''),(347873,111006,'117749','furniture','margin-bottom','20',0,''),(347874,111007,'117750','furniture','block_type','1',0,''),(347875,111008,'117751','furniture','block_type','6',0,''),(347876,111008,'117751','furniture','schema','6-3',0,'5140'),(347877,111009,'117752','furniture','aria_name','account-menu',0,''),(347935,111029,'117753','furniture','block_type','3',0,''),(347936,111030,'117754','furniture','block_type','1',0,''),(347937,111030,'117754','furniture','padding-right','20',0,''),(347938,111030,'117754','furniture','padding-bottom','20',0,''),(347939,111031,'117755','furniture','orders_data','name',0,''),(347940,111032,'117756','furniture','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(347941,111033,'117757','furniture','block_type','1',0,''),(347942,111033,'117757','furniture','padding-right','20',0,''),(347943,111033,'117757','furniture','padding-bottom','20',0,''),(347944,111034,'117758','furniture','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(347945,111035,'117759','furniture','orders_data','telephone',0,''),(347946,111036,'117760','furniture','block_type','1',0,''),(347947,111036,'117760','furniture','padding-right','20',0,''),(347948,111037,'117761','furniture','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(347949,111038,'117762','furniture','orders_data','shipping_method',0,''),(347950,111039,'117763','furniture','block_type','1',0,''),(347951,111039,'117763','furniture','padding-right','20',0,''),(347952,111039,'117763','furniture','padding-bottom','20',0,''),(347953,111040,'117764','furniture','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(347954,111041,'117765','furniture','orders_data','delivery_address',0,''),(347955,111042,'117766','furniture','block_type','1',0,''),(347956,111042,'117766','furniture','padding-bottom','20',0,''),(347957,111043,'117767','furniture','orders_data','billing_address',0,''),(347958,111044,'117768','furniture','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(347959,111045,'117769','furniture','block_type','1',0,''),(347960,111046,'117770','furniture','orders_data','payment_method',0,''),(347961,111047,'117771','furniture','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(347962,111048,'117772','furniture','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(347963,111050,'117774','furniture','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(347964,111053,'117777','furniture','block_type','2',0,''),(347965,111053,'117777','furniture','padding-top','20',0,''),(347966,111053,'117777','furniture','margin-bottom','20',0,''),(347967,111054,'117778','furniture','like_button','1',0,''),(347968,111054,'117778','furniture','text','IMAGE_BUTTON_BACK',0,''),(347969,111054,'117778','furniture','link','Quotations',0,''),(347970,111055,'117779','furniture','text','<h1>##HEADING_TITLE##</h1>',0,''),(347971,111056,'117780','furniture','padding-top','20',0,''),(347972,111056,'117780','furniture','padding-bottom','20',0,''),(347973,111056,'117780','furniture','block_type','1',0,''),(347974,111056,'117780','furniture','background-color','$content-bg-2',0,''),(347975,111058,'117782','furniture','block_type','4',0,''),(347976,111058,'117782','furniture','schema','4-2',0,'5140'),(347977,111058,'117782','furniture','schema','4-2',0,'5131'),(347978,111059,'117783','furniture','background-color','$content-bg-1',0,''),(347979,111060,'117784','furniture','block_type','1',0,''),(347980,111060,'117784','furniture','style_class','order-summary',0,''),(347981,111060,'117784','furniture','margin-left','30',0,''),(347982,111060,'117784','furniture','margin-left','0',0,'5140'),(347983,111061,'117785','furniture','block_type','1',0,''),(347984,111061,'117785','furniture','padding-left','20',0,''),(347985,111061,'117785','furniture','padding-right','20',0,''),(347986,111061,'117785','furniture','padding-bottom','30',0,''),(347987,111062,'117786','furniture','max-width','300',0,'5140'),(347988,111062,'117786','furniture','margin_left_measure','auto',0,'5140'),(347989,111062,'117786','furniture','margin_right_measure','auto',0,'5140'),(347990,111062,'117786','furniture','margin-bottom','0',0,''),(347991,111064,'117788','furniture','block_type','1',0,''),(348054,111088,'117793','furniture','block_type','1',0,''),(348055,111090,'117795','furniture','pagination','bottom',0,''),(348056,111091,'117796','furniture','width','800',0,''),(348057,111092,'117797','furniture','block_type','11',0,''),(348058,111092,'117797','furniture','border-top-width','1',0,''),(348059,111092,'117797','furniture','border-left-width','1',0,''),(348060,111092,'117797','furniture','border-right-width','1',0,''),(348061,111092,'117797','furniture','border-bottom-width','1',0,''),(348062,111092,'117797','furniture','border-top-color','$content-border-2',0,''),(348063,111092,'117797','furniture','border-left-color','$content-border-2',0,''),(348064,111092,'117797','furniture','border-right-color','$content-border-2',0,''),(348065,111092,'117797','furniture','border-bottom-color','$content-border-2',0,''),(348066,111093,'117798','furniture','block_type','1',0,''),(348067,111093,'117798','furniture','border-right-width','1',0,''),(348068,111093,'117798','furniture','border-right-color','$content-border-2',0,''),(348069,111093,'117798','furniture','padding-top','10',0,''),(348070,111093,'117798','furniture','padding-right','10',0,''),(348071,111093,'117798','furniture','padding-bottom','10',0,''),(348072,111094,'117799','furniture','block_type','9',0,''),(348073,111095,'117800','furniture','text','1.',0,''),(348074,111095,'117800','furniture','font-size','12',0,''),(348075,111095,'117800','furniture','text-align','right',0,''),(348076,111095,'117800','furniture','padding-right','5',0,''),(348077,111096,'117801','furniture','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(348078,111096,'117801','furniture','font-size','12',0,''),(348079,111096,'117801','furniture','padding-bottom','5',0,''),(348080,111097,'117802','furniture','block_type','9',0,''),(348081,111098,'117803','furniture','text','4.',0,''),(348082,111098,'117803','furniture','font-size','12',0,''),(348083,111098,'117803','furniture','text-align','right',0,''),(348084,111098,'117803','furniture','margin-right','5',0,''),(348085,111099,'117804','furniture','text','Our Replacement Department will process your request.',0,''),(348086,111099,'117804','furniture','font-size','12',0,''),(348087,111099,'117804','furniture','padding-bottom','5',0,''),(348088,111100,'117805','furniture','block_type','9',0,''),(348089,111101,'117806','furniture','text','3.',0,''),(348090,111101,'117806','furniture','font-size','12',0,''),(348091,111101,'117806','furniture','text-align','right',0,''),(348092,111101,'117806','furniture','margin-right','5',0,''),(348093,111102,'117807','furniture','text','Return the authorized item(s) per shipping instructions.',0,''),(348094,111102,'117807','furniture','font-size','12',0,''),(348095,111102,'117807','furniture','padding-bottom','5',0,''),(348096,111103,'117808','furniture','block_type','9',0,''),(348097,111104,'117809','furniture','text','2.',0,''),(348098,111104,'117809','furniture','font-size','12',0,''),(348099,111104,'117809','furniture','text-align','right',0,''),(348100,111104,'117809','furniture','margin-right','5',0,''),(348101,111105,'117810','furniture','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(348102,111105,'117810','furniture','font-size','12',0,''),(348103,111105,'117810','furniture','padding-bottom','5',0,''),(348104,111106,'117811','furniture','block_type','1',0,''),(348105,111106,'117811','furniture','padding-left','15',0,''),(348106,111107,'117812','furniture','text','Replacement Policy:',0,''),(348107,111107,'117812','furniture','font-size','14',0,''),(348108,111107,'117812','furniture','padding-bottom','5',0,''),(348109,111107,'117812','furniture','font-weight','bold',0,''),(348110,111108,'117813','furniture','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(348111,111108,'117813','furniture','font-size','11',0,''),(348112,111108,'117813','furniture','font-style','italic',0,''),(348113,111108,'117813','furniture','padding-bottom','5',0,''),(348114,111109,'117814','furniture','block_type','1',0,''),(348115,111109,'117814','furniture','border-bottom-width','1',0,''),(348116,111109,'117814','furniture','border-bottom-color','$content-border-2',0,''),(348117,111110,'117815','furniture','text','Return Material Authorization (RMA) Form',0,''),(348118,111110,'117815','furniture','text-align','center',0,''),(348119,111110,'117815','furniture','font-size','16',0,''),(348120,111110,'117815','furniture','font-weight','bold',0,''),(348121,111111,'117816','furniture','text-align','center',0,''),(348123,111111,'117816','furniture','padding-top','10',0,''),(348124,111111,'117816','furniture','padding-bottom','10',0,''),(348128,111112,'117817','furniture','block_type','1',0,''),(348129,111112,'117817','furniture','padding-top','10',0,''),(348130,111112,'117817','furniture','padding-left','10',0,''),(348131,111112,'117817','furniture','padding-right','10',0,''),(348132,111112,'117817','furniture','padding-bottom','20',0,''),(348133,111113,'117818','furniture','block_type','2',0,''),(348134,111113,'117818','furniture','padding-top','5',0,''),(348135,111114,'117819','furniture','block_type','11',0,''),(348136,111115,'117820','furniture','text','Email:',0,''),(348137,111115,'117820','furniture','font-size','12',0,''),(348138,111116,'117821','furniture','data','rrDelivery_email_address',0,''),(348139,111116,'117821','furniture','font-size','12',0,''),(348140,111117,'117822','furniture','block_type','11',0,''),(348141,111118,'117823','furniture','text','Phone:',0,''),(348142,111118,'117823','furniture','font-size','12',0,''),(348143,111119,'117824','furniture','data','rrDelivery_telephone',0,''),(348144,111119,'117824','furniture','font-size','12',0,''),(348145,111120,'117825','furniture','block_type','2',0,''),(348146,111120,'117825','furniture','padding-top','5',0,''),(348147,111121,'117826','furniture','block_type','11',0,''),(348148,111122,'117827','furniture','text','Country:',0,''),(348149,111122,'117827','furniture','font-size','12',0,''),(348150,111123,'117828','furniture','data','rrDelivery_country',0,''),(348151,111123,'117828','furniture','font-size','12',0,''),(348152,111124,'117829','furniture','block_type','11',0,''),(348153,111125,'117830','furniture','text','Postcode:',0,''),(348154,111125,'117830','furniture','font-size','12',0,''),(348155,111126,'117831','furniture','data','rrDelivery_postcode',0,''),(348156,111126,'117831','furniture','font-size','12',0,''),(348157,111127,'117832','furniture','block_type','2',0,''),(348158,111127,'117832','furniture','padding-top','5',0,''),(348159,111128,'117833','furniture','block_type','11',0,''),(348160,111129,'117834','furniture','text','City:',0,''),(348161,111129,'117834','furniture','font-size','12',0,''),(348162,111130,'117835','furniture','data','rrDelivery_city',0,''),(348163,111130,'117835','furniture','font-size','12',0,''),(348164,111131,'117836','furniture','block_type','11',0,''),(348165,111132,'117837','furniture','text','State:',0,''),(348166,111132,'117837','furniture','font-size','12',0,''),(348167,111133,'117838','furniture','data','rrDelivery_state',0,''),(348168,111133,'117838','furniture','font-size','12',0,''),(348169,111134,'117839','furniture','block_type','9',0,''),(348170,111134,'117839','furniture','padding-top','5',0,''),(348171,111135,'117840','furniture','text','Address:',0,''),(348172,111135,'117840','furniture','font-size','12',0,''),(348173,111136,'117841','furniture','data','rrDelivery_street_address',0,''),(348174,111136,'117841','furniture','font-size','12',0,''),(348175,111137,'117842','furniture','block_type','2',0,''),(348176,111138,'117843','furniture','block_type','11',0,''),(348177,111139,'117844','furniture','text','Company:',0,''),(348178,111139,'117844','furniture','font-size','12',0,''),(348179,111140,'117845','furniture','data','rrDelivery_company',0,''),(348180,111140,'117845','furniture','font-size','12',0,''),(348181,111141,'117846','furniture','block_type','2',0,''),(348182,111142,'117847','furniture','text','Contact Name:',0,''),(348183,111142,'117847','furniture','font-size','12',0,''),(348184,111143,'117848','furniture','data','rrDelivery_name',0,''),(348185,111143,'117848','furniture','font-size','12',0,''),(348186,111144,'117849','furniture','block_type','2',0,''),(348187,111144,'117849','furniture','padding-left','10',0,''),(348188,111144,'117849','furniture','padding-top','20',0,''),(348189,111144,'117849','furniture','padding-right','10',0,''),(348190,111145,'117850','furniture','block_type','5',0,''),(348191,111146,'117851','furniture','text','RMA No:',0,''),(348192,111146,'117851','furniture','font-size','12',0,''),(348193,111146,'117851','furniture','font-weight','bold',0,''),(348194,111147,'117852','furniture','data','rrNumber',0,''),(348195,111147,'117852','furniture','font-size','12',0,''),(348196,111147,'117852','furniture','font-weight','bold',0,''),(348197,111148,'117853','furniture','block_type','2',0,''),(348198,111149,'117854','furniture','text','Date Issued:',0,''),(348199,111149,'117854','furniture','font-size','12',0,''),(348200,111149,'117854','furniture','font-weight','bold',0,''),(348201,111150,'117855','furniture','data','rrDateCreate',0,''),(348202,111150,'117855','furniture','font-size','12',0,''),(348203,111150,'117855','furniture','font-weight','bold',0,''),(348204,111151,'117856','furniture','block_type','1',0,''),(348205,111152,'117857','furniture','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(348206,111152,'117857','furniture','font-size','12',0,''),(348207,111152,'117857','furniture','font-style','italic',0,''),(348208,111152,'117857','furniture','padding-bottom','20',0,''),(348209,111154,'117859','furniture','block_type','1',0,''),(348210,111154,'117859','furniture','border-top-width','1',0,''),(348211,111154,'117859','furniture','border-left-width','1',0,''),(348212,111154,'117859','furniture','border-right-width','1',0,''),(348213,111154,'117859','furniture','border-bottom-width','1',0,''),(348214,111154,'117859','furniture','border-top-color','$content-border-2',0,''),(348215,111154,'117859','furniture','border-left-color','$content-border-2',0,''),(348216,111154,'117859','furniture','border-right-color','$content-border-2',0,''),(348217,111154,'117859','furniture','border-bottom-color','$content-border-2',0,''),(348218,111155,'117860','furniture','block_type','11',0,''),(348219,111156,'117861','furniture','block_type','1',0,''),(348220,111156,'117861','furniture','padding-top','10',0,''),(348221,111156,'117861','furniture','padding-right','10',0,''),(348222,111156,'117861','furniture','padding-bottom','10',0,''),(348223,111156,'117861','furniture','border-right-width','1',0,''),(348224,111156,'117861','furniture','border-right-color','$content-border-2',0,''),(348225,111157,'117862','furniture','block_type','9',0,''),(348226,111158,'117863','furniture','text','4.',0,''),(348227,111158,'117863','furniture','font-size','12',0,''),(348228,111158,'117863','furniture','text-align','right',0,''),(348229,111158,'117863','furniture','padding-right','5',0,''),(348230,111159,'117864','furniture','font-size','11',0,''),(348231,111159,'117864','furniture','font-style','italic',0,''),(348232,111159,'117864','furniture','padding-bottom','5',0,''),(348233,111160,'117865','furniture','text','Ship returned items to:',0,''),(348234,111160,'117865','furniture','font-size','12',0,''),(348235,111160,'117865','furniture','padding-bottom','5',0,''),(348236,111161,'117866','furniture','block_type','9',0,''),(348237,111162,'117867','furniture','text','3.',0,''),(348238,111162,'117867','furniture','font-size','12',0,''),(348239,111162,'117867','furniture','text-align','right',0,''),(348240,111162,'117867','furniture','padding-right','5',0,''),(348241,111163,'117868','furniture','text','Ship only the items that are authorized.',0,''),(348242,111163,'117868','furniture','font-size','12',0,''),(348243,111163,'117868','furniture','padding-bottom','10',0,''),(348244,111164,'117869','furniture','block_type','9',0,''),(348245,111165,'117870','furniture','text','1.',0,''),(348246,111165,'117870','furniture','font-size','12',0,''),(348247,111165,'117870','furniture','text-align','right',0,''),(348248,111165,'117870','furniture','padding-right','5',0,''),(348249,111166,'117871','furniture','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(348250,111166,'117871','furniture','font-size','12',0,''),(348251,111166,'117871','furniture','padding-bottom','10',0,''),(348252,111167,'117872','furniture','block_type','1',0,''),(348253,111168,'117873','furniture','text','Shipping Instructions:',0,''),(348254,111168,'117873','furniture','font-weight','bold',0,''),(348255,111168,'117873','furniture','font-size','14',0,''),(348256,111168,'117873','furniture','padding-bottom','5',0,''),(348257,111168,'117873','furniture','padding-left','10',0,''),(348258,111169,'117874','furniture','block_type','9',0,''),(348259,111170,'117875','furniture','text','2.',0,''),(348260,111170,'117875','furniture','font-size','12',0,''),(348261,111170,'117875','furniture','text-align','right',0,''),(348262,111170,'117875','furniture','padding-right','5',0,''),(348263,111171,'117876','furniture','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(348264,111171,'117876','furniture','font-size','12',0,''),(348265,111171,'117876','furniture','padding-bottom','10',0,''),(348266,111172,'117877','furniture','block_type','1',0,''),(348267,111172,'117877','furniture','padding-left','10',0,''),(348268,111172,'117877','furniture','padding-right','10',0,''),(348269,111172,'117877','furniture','padding-bottom','10',0,''),(348270,111173,'117878','furniture','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(348271,111173,'117878','furniture','font-size','11',0,''),(348272,111173,'117878','furniture','font-style','italic',0,''),(348273,111174,'117879','furniture','block_type','1',0,''),(348274,111174,'117879','furniture','padding-top','10',0,''),(348275,111174,'117879','furniture','padding-left','40',0,''),(348276,111174,'117879','furniture','padding-right','40',0,''),(348277,111174,'117879','furniture','padding-bottom','10',0,''),(348278,111175,'117880','furniture','block_type','1',0,''),(348279,111175,'117880','furniture','padding-top','10',0,''),(348280,111175,'117880','furniture','padding-left','10',0,''),(348281,111175,'117880','furniture','padding-right','10',0,''),(348282,111175,'117880','furniture','padding-bottom','10',0,''),(348283,111175,'117880','furniture','border-top-width','1',0,''),(348284,111175,'117880','furniture','border-left-width','1',0,''),(348285,111175,'117880','furniture','border-right-width','1',0,''),(348286,111175,'117880','furniture','border-bottom-width','1',0,''),(348287,111175,'117880','furniture','border-top-color','$content-border-2',0,''),(348288,111175,'117880','furniture','border-left-color','$content-border-2',0,''),(348289,111175,'117880','furniture','border-right-color','$content-border-2',0,''),(348290,111175,'117880','furniture','border-bottom-color','$content-border-2',0,''),(348291,111176,'117881','furniture','block_type','3',0,''),(348292,111177,'117882','furniture','data','rrDelivery_name',0,''),(348293,111177,'117882','furniture','font-size','9',0,''),(348294,111178,'117883','furniture','block_type','2',0,''),(348295,111179,'117884','furniture','text','RMA#:',0,''),(348296,111179,'117884','furniture','font-size','10',0,''),(348297,111180,'117885','furniture','data','rrNumber',0,''),(348298,111180,'117885','furniture','font-size','9',0,''),(348299,111181,'117886','furniture','block_type','5',0,''),(348300,111182,'117887','furniture','font-size','9',0,''),(348301,111183,'117888','furniture','block_type','1',0,''),(348302,111183,'117888','furniture','padding-left','10',0,''),(348303,111183,'117888','furniture','padding-right','10',0,''),(348304,111183,'117888','furniture','padding-bottom','10',0,''),(348305,111184,'117889','furniture','text','Use this space for additional Comments:',0,''),(348306,111184,'117889','furniture','font-size','11',0,''),(348307,111184,'117889','furniture','font-style','italic',0,''),(348308,111185,'117890','furniture','text','&nbsp;',0,''),(348309,111185,'117890','furniture','border-bottom-width','1',0,''),(348310,111185,'117890','furniture','border-bottom-color','$content-border-2',0,''),(348311,111186,'117891','furniture','text','&nbsp;',0,''),(348312,111186,'117891','furniture','border-bottom-width','1',0,''),(348313,111186,'117891','furniture','border-bottom-color','$content-border-2',0,''),(348314,111186,'117891','furniture','padding-top','5',0,''),(348315,111187,'117892','furniture','text','&nbsp;',0,''),(348316,111187,'117892','furniture','border-bottom-width','1',0,''),(348317,111187,'117892','furniture','border-bottom-color','$content-border-2',0,''),(348318,111187,'117892','furniture','padding-top','5',0,''),(348319,111188,'117893','furniture','text','&nbsp;',0,''),(348320,111188,'117893','furniture','border-bottom-width','1',0,''),(348321,111188,'117893','furniture','border-bottom-color','$content-border-2',0,''),(348322,111188,'117893','furniture','padding-top','5',0,''),(348323,111189,'117894','furniture','block_type','3',0,''),(348324,111189,'117894','furniture','padding-top','10',0,''),(348325,111189,'117894','furniture','padding-bottom','10',0,''),(348326,111189,'117894','furniture','padding-right','10',0,''),(348327,111190,'117895','furniture','font-size','11',0,''),(348328,111190,'117895','furniture','font-weight','bold',0,''),(348329,111190,'117895','furniture','text','Return Approval:',0,''),(348330,111190,'117895','furniture','padding-top','5',0,''),(348331,111190,'117895','furniture','padding-left','10',0,''),(348332,111191,'117896','furniture','border-bottom-width','1',0,''),(348333,111191,'117896','furniture','border-bottom-color','$content-border-2',0,''),(348334,111191,'117896','furniture','text','&nbsp;',0,''),(348335,111192,'117897','furniture','block_type','5',0,''),(348336,111193,'117898','furniture','text','Date:',0,''),(348337,111193,'117898','furniture','padding-top','5',0,''),(348338,111193,'117898','furniture','font-size','11',0,''),(348339,111193,'117898','furniture','font-weight','bold',0,''),(348340,111193,'117898','furniture','padding-left','5',0,''),(348341,111194,'117899','furniture','text','&nbsp;',0,''),(348342,111194,'117899','furniture','border-bottom-width','1',0,''),(348343,111194,'117899','furniture','border-bottom-color','$content-border-2',0,''),(348344,111195,'117900','furniture','block_type','3',0,''),(348345,111195,'117900','furniture','padding-right','10',0,''),(348346,111196,'117901','furniture','text','Customer Signature:',0,''),(348347,111196,'117901','furniture','font-weight','bold',0,''),(348348,111196,'117901','furniture','font-size','11',0,''),(348349,111196,'117901','furniture','padding-top','5',0,''),(348350,111196,'117901','furniture','padding-left','10',0,''),(348351,111197,'117902','furniture','text','&nbsp;',0,''),(348352,111197,'117902','furniture','border-bottom-width','1',0,''),(348353,111197,'117902','furniture','border-bottom-color','$content-border-2',0,''),(348354,111198,'117903','furniture','block_type','5',0,''),(348355,111199,'117904','furniture','text','Date:',0,''),(348356,111199,'117904','furniture','padding-top','5',0,''),(348357,111199,'117904','furniture','font-size','11',0,''),(348358,111199,'117904','furniture','font-weight','bold',0,''),(348359,111199,'117904','furniture','padding-left','5',0,''),(348360,111200,'117905','furniture','text','&nbsp;',0,''),(348361,111200,'117905','furniture','border-bottom-width','1',0,''),(348362,111200,'117905','furniture','border-bottom-color','$content-border-2',0,''),(348363,111201,'117906','furniture','block_type','1',0,''),(348364,111201,'117906','furniture','style_class','item-holder',0,''),(348365,111201,'117906','furniture','padding-top','25',0,''),(348366,111201,'117906','furniture','padding-bottom','25',0,''),(348367,111201,'117906','furniture','text-align','left',0,''),(348368,111201,'117906','furniture','border-top-width','1',0,''),(348369,111201,'117906','furniture','border-top-color','$content-border-1',0,''),(348370,111202,'117907','furniture','block_type','7',0,''),(348371,111202,'117907','furniture','schema','7-2',0,'5140'),(348372,111203,'117908','furniture','block_type','5',0,''),(348373,111203,'117908','furniture','schema','5-2',0,'5140'),(348374,111204,'117909','furniture','clear','none',0,''),(348375,111204,'117909','furniture','padding-right','20',0,''),(348376,111205,'117910','furniture','padding-right','20',0,''),(348377,111205,'117910','furniture','max-width','300',0,'5140'),(348378,111205,'117910','furniture','margin_left_measure','auto',0,'5140'),(348379,111205,'117910','furniture','margin_right_measure','auto',0,'5140'),(348380,111206,'117914','furniture','padding-right','20',0,''),(348381,111207,'117915','furniture','description_characters','200',0,''),(348382,111207,'117915','furniture','clear','none',0,''),(348383,111207,'117915','furniture','padding-right','20',0,''),(348384,111208,'117916','furniture','clear','none',0,''),(348385,111209,'117917','furniture','margin-bottom','20',0,''),(348386,111212,'117918','furniture','block_type','1',0,''),(348387,111212,'117918','furniture','padding-left','40',0,''),(348388,111212,'117918','furniture','style_class','right-aria',0,''),(348389,111212,'117918','furniture','padding-left','0',0,'5140'),(348390,111213,'117911','furniture','block_type','1',0,''),(348391,111213,'117911','furniture','text-align','center',0,''),(348392,111214,'117912','furniture','margin-top','4',0,''),(348393,111214,'117912','furniture','margin-bottom','7',0,''),(348394,111215,'117913','furniture','padding-top','6',0,''),(348395,111215,'117913','furniture','padding-left','5',0,''),(348396,111216,'117919','furniture','margin-bottom','15',0,''),(348397,111216,'117919','furniture','text-align','right',0,''),(348398,111217,'117920','furniture','margin-bottom','10',0,''),(348399,111217,'117920','furniture','text-align','center',0,''),(348400,111218,'117922','furniture','text-align','right',0,''),(348401,111218,'117922','furniture','margin-bottom','15',0,''),(348402,111219,'117924','furniture','text-align','center',0,''),(348403,111219,'117924','furniture','margin-bottom','10',0,''),(348404,111220,'120924','furniture','block_type','1',0,''),(348405,111220,'120924','furniture','style_class','item-nav',0,''),(348406,111224,'117925','furniture','block_type','1',0,''),(348407,111224,'117925','furniture','padding-top','20',0,''),(348408,111224,'117925','furniture','padding-bottom','20',0,''),(348409,111224,'117925','furniture','background-color','$content-bg-2',0,''),(348410,111226,'117927','furniture','block_type','7',0,''),(348411,111226,'117927','furniture','schema','4-2',0,'5140'),(348412,111227,'117928','furniture','padding-bottom','20',0,''),(348413,111227,'117928','furniture','background-color','$content-bg-1',0,''),(348414,111228,'117929','furniture','style_class','order-summary',0,''),(348415,111228,'117929','furniture','padding-left','25',0,''),(348416,111228,'117929','furniture','block_type','1',0,''),(348417,111228,'117929','furniture','padding-left','0',0,'5140'),(348418,111228,'117929','furniture','margin-top','30',0,'5140'),(348419,111229,'117930','furniture','block_type','1',0,''),(348420,111229,'117930','furniture','padding-left','20',0,''),(348421,111229,'117930','furniture','padding-right','20',0,''),(348422,111229,'117930','furniture','padding-bottom','20',0,''),(348423,111229,'117930','furniture','padding-top','20',0,''),(348424,111230,'117931','furniture','max-width','300',0,'5140'),(348425,111230,'117931','furniture','margin_left_measure','auto',0,'5140'),(348426,111230,'117931','furniture','margin_right_measure','auto',0,'5140'),(348427,111231,'117932','furniture','block_type','1',0,''),(348428,111231,'117932','furniture','style_class','account-samples',0,''),(348429,111232,'117933','furniture','block_type','6',0,''),(348430,111232,'117933','furniture','schema','6-3',0,'5140'),(348431,111233,'117934','furniture','aria_name','account-menu',0,''),(348489,111253,'117935','furniture','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(348490,111254,'117936','furniture','show_pagenation','1',0,''),(348491,111254,'117936','furniture','link','Sample Info',0,''),(348492,111254,'117936','furniture','margin-bottom','20',0,''),(348493,111255,'117937','furniture','block_type','1',0,''),(348494,111255,'117937','furniture','style_class','account-sample-info',0,''),(348495,111256,'117938','furniture','block_type','6',0,''),(348496,111256,'117938','furniture','schema','6-3',0,'5140'),(348497,111257,'117939','furniture','aria_name','account-menu',0,''),(348555,111277,'117940','furniture','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(348556,111278,'117941','furniture','block_type','2',0,''),(348557,111278,'117941','furniture','padding-top','20',0,''),(348558,111278,'117941','furniture','margin-bottom','20',0,''),(348559,111279,'117942','furniture','like_button','1',0,''),(348560,111279,'117942','furniture','text','IMAGE_BUTTON_BACK',0,''),(348561,111279,'117942','furniture','link','Samples',0,''),(348562,111281,'117944','furniture','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(348563,111284,'117947','furniture','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(348564,111285,'117948','furniture','block_type','3',0,''),(348565,111286,'117949','furniture','block_type','1',0,''),(348566,111286,'117949','furniture','padding-right','20',0,''),(348567,111286,'117949','furniture','padding-bottom','20',0,''),(348568,111287,'117950','furniture','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(348569,111288,'117951','furniture','orders_data','telephone',0,''),(348570,111289,'117952','furniture','block_type','1',0,''),(348571,111289,'117952','furniture','padding-right','20',0,''),(348572,111289,'117952','furniture','padding-bottom','20',0,''),(348573,111290,'117953','furniture','orders_data','name',0,''),(348574,111291,'117954','furniture','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(348575,111292,'117955','furniture','block_type','1',0,''),(348576,111292,'117955','furniture','padding-right','20',0,''),(348577,111293,'117956','furniture','orders_data','shipping_method',0,''),(348578,111294,'117957','furniture','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(348579,111295,'117958','furniture','block_type','1',0,''),(348580,111295,'117958','furniture','padding-right','20',0,''),(348581,111295,'117958','furniture','padding-bottom','20',0,''),(348582,111296,'117959','furniture','orders_data','delivery_address',0,''),(348583,111297,'117960','furniture','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(348584,111298,'117961','furniture','block_type','1',0,''),(348585,111299,'117962','furniture','orders_data','payment_method',0,''),(348586,111300,'117963','furniture','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(348587,111301,'117964','furniture','block_type','1',0,''),(348588,111301,'117964','furniture','padding-bottom','20',0,''),(348589,111302,'117965','furniture','orders_data','billing_address',0,''),(348590,111303,'117966','furniture','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(348591,111304,'117967','furniture','block_type','1',0,''),(348592,111305,'117968','furniture','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(348593,111306,'117969','furniture','block_type','6',0,''),(348594,111307,'117970','furniture','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(348595,111308,'117971','furniture','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(348596,111309,'117972','furniture','text','<div class=\"heading-4\">Categories</div>',0,''),(348597,111312,'117975','furniture','class','menu-simple',0,''),(348598,111314,'117977','furniture','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(348599,111315,'120878','furniture','float','left',0,''),(348600,111315,'120878','furniture','margin-right','10',0,''),(348601,111316,'117978','furniture','block_type','1',0,''),(348602,111317,'117979','furniture','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(348603,111317,'117979','furniture','style_class','middle-form',0,''),(348604,111318,'117980','furniture','style_class','middle-form',0,''),(348605,111319,'117981','furniture','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(348606,111320,'117982','furniture','style_class','middle-form',0,''),(348607,111320,'117982','furniture','margin-bottom','30',0,''),(348608,111321,'117983','furniture','block_type','1',0,''),(348609,111322,'117984','furniture','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(348610,111322,'117984','furniture','padding-top','100',0,''),(348611,111322,'117984','furniture','margin-bottom','100',0,''),(348612,111322,'117984','furniture','text-align','center',0,''),(348613,111322,'117984','furniture','font-size','20',0,''),(348614,111323,'117985','furniture','block_type','1',0,''),(348615,111324,'117986','furniture','block_type','6',0,''),(348616,111324,'117986','furniture','schema','6-3',0,'5140'),(348617,111325,'117987','furniture','aria_name','account-menu',0,''),(348675,111345,'117988','furniture','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(348676,111346,'117989','furniture','text','##SUBSCRIPTION_TEXT##',0,''),(348677,111348,'1695216662.204376','furniture','block_type','1',0,''),(348678,111348,'1695216662.204376','furniture','background-color','$content-bg-2',0,''),(348679,111348,'1695216662.204376','furniture','padding-bottom','30',0,''),(348680,111348,'1695216662.204376','furniture','style_class','success-page',0,''),(348681,111348,'1695216662.204376','furniture','color','$content-color-2',0,''),(348682,111349,'1695216662.283842','furniture','block_type','12',0,''),(348683,111349,'1695216662.283842','furniture','schema','4-2',0,'5140'),(348684,111350,'1695216662.28679','furniture','block_type','1',0,''),(348685,111350,'1695216662.28679','furniture','padding-right','40',0,''),(348686,111350,'1695216662.28679','furniture','padding-right','0',0,'5140'),(348687,111351,'1695216662.287367','furniture','block_type','2',0,''),(348688,111351,'1695216662.287367','furniture','margin-bottom','20',0,''),(348689,111351,'1695216662.287367','furniture','schema','2-2',0,'5131'),(348690,111351,'1695216662.287367','furniture','background-color','$content-bg-1',0,''),(348691,111351,'1695216662.287367','furniture','color','$content-color-1',0,''),(348692,111352,'1695216662.28994','furniture','block_type','1',0,''),(348693,111352,'1695216662.28994','furniture','border-right-width','20',0,''),(348694,111352,'1695216662.28994','furniture','border-right-color','$content-bg-2',0,''),(348695,111352,'1695216662.28994','furniture','margin-right','-10',0,''),(348696,111352,'1695216662.28994','furniture','padding-right','30',0,''),(348697,111352,'1695216662.28994','furniture','padding-top','20',0,''),(348698,111352,'1695216662.28994','furniture','padding-left','30',0,''),(348699,111352,'1695216662.28994','furniture','padding-bottom','20',0,''),(348700,111352,'1695216662.28994','furniture','border-right-width','0',0,'5140'),(348701,111352,'1695216662.28994','furniture','margin-right','0',0,'5140'),(348702,111352,'1695216662.28994','furniture','margin-bottom','20',0,'5140'),(348703,111352,'1695216662.28994','furniture','padding-left','20',0,'5140'),(348704,111352,'1695216662.28994','furniture','padding-right','20',0,'5140'),(348705,111352,'1695216662.28994','furniture','border-top-color','$content-bg-2',0,''),(348706,111354,'1695216662.293199','furniture','margin-bottom','20',0,''),(348707,111355,'1695216662.294382','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(348708,111355,'1695216662.294382','furniture','padding-top','20',0,''),(348709,111356,'1695216662.301223','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(348710,111356,'1695216662.301223','furniture','clear','none',0,''),(348711,111357,'1695216662.303717','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(348712,111359,'1695216662.306549','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(348713,111359,'1695216662.306549','furniture','clear','none',0,''),(348714,111360,'1695216662.308881','furniture','block_type','1',0,''),(348715,111360,'1695216662.308881','furniture','padding-left','30',0,''),(348716,111360,'1695216662.308881','furniture','border-left-width','20',0,''),(348717,111360,'1695216662.308881','furniture','border-left-color','$content-bg-2',0,''),(348718,111360,'1695216662.308881','furniture','margin-left','-10',0,''),(348719,111360,'1695216662.308881','furniture','padding-right','30',0,''),(348720,111360,'1695216662.308881','furniture','padding-top','20',0,''),(348721,111360,'1695216662.308881','furniture','padding-bottom','20',0,''),(348722,111360,'1695216662.308881','furniture','border-left-width','0',0,'5140'),(348723,111362,'1695216662.311766','furniture','margin-bottom','20',0,''),(348724,111363,'1695216662.312915','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(348725,111363,'1695216662.312915','furniture','clear','none',0,''),(348726,111364,'1695216662.314711','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(348727,111365,'1695216662.316646','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(348728,111365,'1695216662.316646','furniture','clear','none',0,''),(348729,111366,'1695216662.31980','furniture','text','<div class=\"page-success\">\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>',0,''),(348730,111366,'1695216662.31980','furniture','background-color','$content-bg-1',0,''),(348731,111366,'1695216662.31980','furniture','margin-bottom','30',0,''),(348732,111366,'1695216662.31980','furniture','padding-top','30',0,''),(348733,111366,'1695216662.31980','furniture','padding-bottom','30',0,''),(348734,111366,'1695216662.31980','furniture','padding-left','30',0,''),(348735,111366,'1695216662.31980','furniture','padding-right','30',0,''),(348736,111366,'1695216662.31980','furniture','color','$content-color-1',0,''),(348737,111367,'1695216662.322253','furniture','block_type','1',0,''),(348738,111367,'1695216662.322253','furniture','style_class','order-summary2 hiding-box',0,''),(348739,111368,'1695216662.323587','furniture','text-align','center',0,''),(348740,111368,'1695216662.323587','furniture','margin-bottom','20',0,''),(348741,111369,'1695216662.325129','furniture','text-align','center',0,''),(348742,111372,'1695216662.335222','furniture','block_type','12',0,''),(348743,111373,'1695216662.336556','furniture','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n</div>\n',0,''),(348744,111373,'1695216662.336556','furniture','margin-bottom','20',0,''),(348745,111374,'1695216662.338898','furniture','text-align','center',0,''),(348746,111374,'1695216662.338898','furniture','padding-top','40',0,''),(348747,111375,'117997','furniture','block_type','1',0,''),(348748,111376,'117998','furniture','block_type','1',0,''),(348749,111376,'117998','furniture','font-weight','normal',0,''),(348750,111377,'117999','furniture','block_type','1',0,''),(348751,111377,'117999','furniture','text-align','center',0,''),(348752,111377,'117999','furniture','padding-top','30',0,''),(348753,111377,'117999','furniture','margin-bottom','200',0,''),(348754,111378,'118000','furniture','display','inline-block',0,''),(348755,111378,'118000','furniture','clear','none',0,''),(348756,111378,'118000','furniture','margin-left','20',0,''),(348757,111379,'118001','furniture','display','inline-block',0,''),(348758,111380,'118002','furniture','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(348763,111385,'118007','furniture','width','680',0,''),(348764,111385,'118007','furniture','font-weight','normal',0,''),(348765,111385,'118007','furniture','font-size','12',0,''),(348766,111385,'118007','furniture','padding-top','20',0,''),(348767,111385,'118007','furniture','padding-bottom','20',0,''),(348768,111385,'118007','furniture','color','$content-color-1',0,''),(348769,111386,'118008','furniture','block_type','5',0,''),(348770,111386,'118008','furniture','font-weight','normal',0,''),(348771,111386,'118008','furniture','border-bottom-width','1',0,''),(348772,111386,'118008','furniture','border-bottom-color','$content-border-1',0,''),(348773,111386,'118008','furniture','border-top-width','1',0,''),(348774,111386,'118008','furniture','border-top-color','$content-border-1',0,''),(348775,111386,'118008','furniture','border-left-color','$content-border-1',0,''),(348776,111386,'118008','furniture','border-left-width','1',0,''),(348777,111387,'118009','furniture','block_type','1',0,''),(348778,111387,'118009','furniture','font-weight','normal',0,''),(348779,111387,'118009','furniture','padding-top','10',0,''),(348780,111387,'118009','furniture','padding-left','10',0,''),(348781,111387,'118009','furniture','padding-right','10',0,''),(348782,111388,'118010','furniture','font-weight','400',0,''),(348783,111388,'118010','furniture','line-height','120',0,''),(348784,111388,'118010','furniture','line_height_measure','%',0,''),(348785,111388,'118010','furniture','font-size','12',0,''),(348786,111389,'118011','furniture','text','<p>SHIPPING ADDRESS:</p>',1,''),(348787,111389,'118011','furniture','font-size','14',0,''),(348788,111389,'118011','furniture','font-weight','bold',0,''),(348789,111389,'118011','furniture','padding-bottom','10',0,''),(348790,111389,'118011','furniture','text','<p>SHIPPING ADDRESS:</p>',2,''),(348791,111389,'118011','furniture','text','<p>SHIPPING ADDRESS:</p>',3,''),(348792,111389,'118011','furniture','text','<p>SHIPPING ADDRESS:</p>',4,''),(348793,111390,'118012','furniture','block_type','1',0,''),(348794,111390,'118012','furniture','background-color','$content-bg-2',0,''),(348795,111390,'118012','furniture','padding-top','20',0,''),(348796,111390,'118012','furniture','padding-left','10',0,''),(348797,111390,'118012','furniture','padding-right','10',0,''),(348798,111390,'118012','furniture','padding-bottom','20',0,''),(348799,111390,'118012','furniture','font-size','14',0,''),(348800,111391,'118013','furniture','font-weight','normal',0,''),(348801,111391,'118013','furniture','text-align','right',0,''),(348802,111391,'118013','furniture','font-size','14',0,''),(348803,111391,'118013','furniture','box_align','3',0,''),(348804,111392,'118014','furniture','block_type','3',0,''),(348805,111392,'118014','furniture','font-weight','normal',0,''),(348806,111392,'118014','furniture','padding-top','20',0,''),(348807,111393,'118015','furniture','text','<p>If undelivered please return to:</p>',1,''),(348808,111393,'118015','furniture','font-size','12',0,''),(348809,111393,'118015','furniture','font-weight','bold',0,''),(348810,111393,'118015','furniture','text','<p>If undelivered please return to:</p>',2,''),(348811,111393,'118015','furniture','text','<p>If undelivered please return to:</p>',3,''),(348812,111393,'118015','furniture','text','<p>If undelivered please return to:</p>',4,''),(348813,111394,'118016','furniture','font-size','12',0,''),(348814,111395,'118018','furniture','text','<p>Thank you for your order</p>',1,''),(348815,111395,'118018','furniture','color','$content-color-1',0,''),(348816,111395,'118018','furniture','font-size','13',0,''),(348817,111395,'118018','furniture','font-weight','bold',0,''),(348818,111395,'118018','furniture','padding-top','5',0,''),(348819,111395,'118018','furniture','text-align','center',0,''),(348820,111395,'118018','furniture','text','<p>Thank you for your order</p>',2,''),(348821,111395,'118018','furniture','text','<p>Thank you for your order</p>',3,''),(348822,111395,'118018','furniture','text','<p>Thank you for your order</p>',4,''),(348823,111396,'118019','furniture','text','<p>If something has gone wrong please contact us at:</p>',1,''),(348824,111396,'118019','furniture','font-size','12',0,''),(348825,111396,'118019','furniture','font-weight','bold',0,''),(348826,111396,'118019','furniture','text-align','right',0,''),(348827,111396,'118019','furniture','text','<p>If something has gone wrong please contact us at:</p>',2,''),(348828,111396,'118019','furniture','text','<p>If something has gone wrong please contact us at:</p>',3,''),(348829,111396,'118019','furniture','text','<p>If something has gone wrong please contact us at:</p>',4,''),(348830,111397,'118020','furniture','block_type','6',0,''),(348831,111397,'118020','furniture','font-weight','normal',0,''),(348832,111397,'118020','furniture','font-size','16',0,''),(348833,111398,'118021','furniture','text','<p>Email:</p>',1,''),(348834,111398,'118021','furniture','font-weight','normal',0,''),(348835,111398,'118021','furniture','text-align','right',0,''),(348836,111398,'118021','furniture','font-size','12',0,''),(348837,111398,'118021','furniture','text','<p>Email:</p>',2,''),(348838,111398,'118021','furniture','text','<p>Email:</p>',3,''),(348839,111398,'118021','furniture','text','<p>Email:</p>',4,''),(348840,111399,'118022','furniture','font-weight','normal',0,''),(348841,111399,'118022','furniture','text-align','right',0,''),(348842,111399,'118022','furniture','font-size','12',0,''),(348843,111400,'118023','furniture','block_type','6',0,''),(348844,111400,'118023','furniture','font-weight','normal',0,''),(348845,111400,'118023','furniture','font-size','16',0,''),(348846,111401,'118024','furniture','text','<p>Phone:</p>',1,''),(348847,111401,'118024','furniture','font-weight','normal',0,''),(348848,111401,'118024','furniture','text-align','right',0,''),(348849,111401,'118024','furniture','font-size','12',0,''),(348850,111401,'118024','furniture','text','<p>Phone:</p>',2,''),(348851,111401,'118024','furniture','text','<p>Phone:</p>',3,''),(348852,111401,'118024','furniture','text','<p>Phone:</p>',4,''),(348853,111402,'118025','furniture','font-weight','normal',0,''),(348854,111402,'118025','furniture','text-align','right',0,''),(348855,111402,'118025','furniture','font-size','12',0,''),(348856,111403,'118026','furniture','font-weight','400',0,''),(348857,111403,'118026','furniture','padding-top','20',0,''),(348858,111403,'118026','furniture','padding-bottom','0',0,''),(348859,111403,'118026','furniture','font-size','12',0,''),(348860,111404,'118027','furniture','block_type','2',0,''),(348861,111404,'118027','furniture','font-weight','normal',0,''),(348862,111404,'118027','furniture','padding-bottom','20',0,''),(348863,111405,'118028','furniture','block_type','11',0,''),(348864,111405,'118028','furniture','font-weight','normal',0,''),(348865,111406,'118029','furniture','text','<p>Email:</p>',1,''),(348866,111406,'118029','furniture','font-weight','normal',0,''),(348867,111406,'118029','furniture','text-align','right',0,''),(348868,111406,'118029','furniture','text','<p>Email:</p>',2,''),(348869,111406,'118029','furniture','text','<p>Email:</p>',3,''),(348870,111406,'118029','furniture','text','<p>Email:</p>',4,''),(348871,111407,'118030','furniture','font-weight','normal',0,''),(348872,111407,'118030','furniture','text-align','right',0,''),(348873,111408,'118031','furniture','block_type','11',0,''),(348874,111408,'118031','furniture','font-weight','normal',0,''),(348875,111409,'118032','furniture','text','<p>Web:</p>',1,''),(348876,111409,'118032','furniture','font-weight','normal',0,''),(348877,111409,'118032','furniture','text-align','right',0,''),(348878,111409,'118032','furniture','text','<p>Web:</p>',2,''),(348879,111409,'118032','furniture','text','<p>Web:</p>',3,''),(348880,111409,'118032','furniture','text','<p>Web:</p>',4,''),(348881,111410,'118033','furniture','font-weight','normal',0,''),(348882,111410,'118033','furniture','text-align','right',0,''),(348883,111411,'118034','furniture','block_type','1',0,''),(348884,111412,'118035','furniture','font-weight','normal',0,''),(348885,111412,'118035','furniture','text-align','right',0,''),(348886,111412,'118035','furniture','padding-bottom','10',0,''),(348887,111412,'118035','furniture','address_spacer',',',0,''),(348888,111412,'118035','furniture','font-size','12',0,''),(348889,111413,'118036','furniture','block_type','11',0,''),(348890,111413,'118036','furniture','font-weight','normal',0,''),(348891,111414,'118037','furniture','text','<p>Phone:</p>',1,''),(348892,111414,'118037','furniture','font-weight','normal',0,''),(348893,111414,'118037','furniture','text-align','right',0,''),(348894,111414,'118037','furniture','text','<p>Phone:</p>',2,''),(348895,111414,'118037','furniture','text','<p>Phone:</p>',3,''),(348896,111414,'118037','furniture','text','<p>Phone:</p>',4,''),(348897,111415,'118038','furniture','font-weight','normal',0,''),(348898,111415,'118038','furniture','text-align','right',0,''),(348899,111416,'118039','furniture','block_type','4',0,''),(348900,111416,'118039','furniture','font-weight','normal',0,''),(348901,111416,'118039','furniture','border-top-width','1',0,''),(348902,111416,'118039','furniture','border-top-color','$content-border-1',0,''),(348903,111416,'118039','furniture','border-left-width','1',0,''),(348904,111416,'118039','furniture','border-left-color','$content-border-1',0,''),(348905,111416,'118039','furniture','border-right-width','1',0,''),(348906,111416,'118039','furniture','border-right-color','$content-border-1',0,''),(348907,111416,'118039','furniture','border-bottom-width','1',0,''),(348908,111416,'118039','furniture','border-bottom-color','$content-border-1',0,''),(348909,111417,'118040','furniture','block_type','2',0,''),(348910,111417,'118040','furniture','font-weight','normal',0,''),(348911,111417,'118040','furniture','border-top-width','1',0,''),(348912,111417,'118040','furniture','border-top-color','$content-border-1',0,''),(348913,111417,'118040','furniture','border-right-width','1',0,''),(348914,111417,'118040','furniture','border-right-color','$content-border-1',0,''),(348915,111418,'118041','furniture','block_type','1',0,''),(348916,111418,'118041','furniture','font-weight','normal',0,''),(348917,111418,'118041','furniture','padding-top','10',0,''),(348918,111418,'118041','furniture','padding-left','10',0,''),(348919,111418,'118041','furniture','padding-right','10',0,''),(348920,111418,'118041','furniture','padding-bottom','10',0,''),(348921,111418,'118041','furniture','border-right-width','1',0,''),(348922,111418,'118041','furniture','border-right-color','$content-border-1',0,''),(348923,111419,'118042','furniture','text','<p>Shipping via</p>',1,''),(348924,111419,'118042','furniture','font-weight','bold',0,''),(348925,111419,'118042','furniture','font-size','14',0,''),(348926,111419,'118042','furniture','text','<p>Shipping via</p>',2,''),(348927,111419,'118042','furniture','text','<p>Shipping via</p>',3,''),(348928,111419,'118042','furniture','text','<p>Shipping via</p>',4,''),(348929,111421,'118044','furniture','block_type','1',0,''),(348930,111421,'118044','furniture','font-weight','normal',0,''),(348931,111421,'118044','furniture','padding-top','10',0,''),(348932,111421,'118044','furniture','padding-left','10',0,''),(348933,111421,'118044','furniture','padding-right','10',0,''),(348934,111421,'118044','furniture','padding-bottom','10',0,''),(348935,111422,'118045','furniture','text','<p>Shipping service</p>',1,''),(348936,111422,'118045','furniture','font-weight','bold',0,''),(348937,111422,'118045','furniture','font-size','14',0,''),(348938,111422,'118045','furniture','text','<p>Shipping service</p>',2,''),(348939,111422,'118045','furniture','text','<p>Shipping service</p>',3,''),(348940,111422,'118045','furniture','text','<p>Shipping service</p>',4,''),(348941,111424,'118047','furniture','block_type','2',0,''),(348942,111424,'118047','furniture','font-weight','normal',0,''),(348943,111424,'118047','furniture','border-right-width','1',0,''),(348944,111424,'118047','furniture','border-right-color','$content-border-1',0,''),(348945,111425,'118048','furniture','block_type','1',0,''),(348946,111425,'118048','furniture','font-weight','400',0,''),(348947,111425,'118048','furniture','background-color','$content-bg-2',0,''),(348948,111425,'118048','furniture','padding-top','10',0,''),(348949,111425,'118048','furniture','padding-left','10',0,''),(348950,111425,'118048','furniture','padding-right','10',0,''),(348951,111425,'118048','furniture','padding-bottom','30',0,''),(348952,111426,'118049','furniture','font-size','12',0,''),(348953,111427,'118050','furniture','text','<p>INVOICE ADDRESS:</p>',1,''),(348954,111427,'118050','furniture','font-size','14',0,''),(348955,111427,'118050','furniture','font-weight','bold',0,''),(348956,111427,'118050','furniture','text','<p>INVOICE ADDRESS:</p>',2,''),(348957,111427,'118050','furniture','text','<p>INVOICE ADDRESS:</p>',3,''),(348958,111427,'118050','furniture','text','<p>INVOICE ADDRESS:</p>',4,''),(348959,111428,'118051','furniture','block_type','1',0,''),(348960,111428,'118051','furniture','font-weight','normal',0,''),(348961,111428,'118051','furniture','padding-top','10',0,''),(348962,111428,'118051','furniture','padding-left','10',0,''),(348963,111428,'118051','furniture','padding-right','10',0,''),(348964,111428,'118051','furniture','padding-bottom','10',0,''),(348965,111429,'118052','furniture','font-weight','normal',0,''),(348966,111430,'118053','furniture','text','<p>PHONE NUMBER:</p>',1,''),(348967,111430,'118053','furniture','font-size','14',0,''),(348968,111430,'118053','furniture','font-weight','bold',0,''),(348969,111430,'118053','furniture','padding-top','10',0,''),(348970,111430,'118053','furniture','text','<p>PHONE NUMBER:</p>',2,''),(348971,111430,'118053','furniture','text','<p>PHONE NUMBER:</p>',3,''),(348972,111430,'118053','furniture','text','<p>PHONE NUMBER:</p>',4,''),(348973,111432,'118055','furniture','font-weight','normal',0,''),(348974,111433,'118056','furniture','text','<p>E-MAIL ADDRESS:</p>',1,''),(348975,111433,'118056','furniture','font-weight','bold',0,''),(348976,111433,'118056','furniture','font-size','14',0,''),(348977,111433,'118056','furniture','padding-top','10',0,''),(348978,111433,'118056','furniture','text','<p>E-MAIL ADDRESS:</p>',2,''),(348979,111433,'118056','furniture','text','<p>E-MAIL ADDRESS:</p>',3,''),(348980,111433,'118056','furniture','text','<p>E-MAIL ADDRESS:</p>',4,''),(348981,111434,'118057','furniture','text','<p>CUSTOMER:</p>',1,''),(348982,111434,'118057','furniture','font-size','13',0,''),(348983,111434,'118057','furniture','font-weight','bold',0,''),(348984,111434,'118057','furniture','text','<p>CUSTOMER:</p>',2,''),(348985,111434,'118057','furniture','text','<p>CUSTOMER:</p>',3,''),(348986,111434,'118057','furniture','text','<p>CUSTOMER:</p>',4,''),(348987,111435,'118058','furniture','font-weight','normal',0,''),(348988,111435,'118058','furniture','text-align','center',0,''),(348989,111435,'118058','furniture','padding-bottom','10',0,''),(348990,111436,'118059','furniture','text','<p>Payment date:</p>',1,''),(348991,111436,'118059','furniture','font-weight','bold',0,''),(348992,111436,'118059','furniture','text-align','center',0,''),(348993,111436,'118059','furniture','font-size','12',0,''),(348994,111436,'118059','furniture','text','<p>Payment date:</p>',2,''),(348995,111436,'118059','furniture','text','<p>Payment date:</p>',3,''),(348996,111436,'118059','furniture','text','<p>Payment date:</p>',4,''),(348997,111437,'118060','furniture','text','<p>Payment Method:</p>',1,''),(348998,111437,'118060','furniture','font-weight','bold',0,''),(348999,111437,'118060','furniture','text-align','center',0,''),(349000,111437,'118060','furniture','text','<p>Payment Method:</p>',2,''),(349001,111437,'118060','furniture','text','<p>Payment Method:</p>',3,''),(349002,111437,'118060','furniture','text','<p>Payment Method:</p>',4,''),(349003,111438,'118061','furniture','font-size','14',0,''),(349004,111438,'118061','furniture','font-weight','bold',0,''),(349005,111438,'118061','furniture','text-align','center',0,''),(349006,111438,'118061','furniture','padding-bottom','10',0,''),(349007,111438,'118061','furniture','padding-top','10',0,''),(349008,111439,'118062','furniture','font-weight','normal',0,''),(349009,111439,'118062','furniture','text-align','center',0,''),(349010,111439,'118062','furniture','padding-bottom','20',0,''),(349011,111440,'118063','furniture','font-weight','normal',0,''),(349012,111440,'118063','furniture','text-align','center',0,''),(349013,111441,'118094','furniture','block_type','1',0,''),(349014,111442,'118095','furniture','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(349015,111444,'118318','furniture','block_type','1',0,''),(349016,111445,'118319','furniture','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(349017,111445,'118319','furniture','padding-top','100',0,''),(349018,111445,'118319','furniture','margin-bottom','100',0,''),(349019,111445,'118319','furniture','text-align','center',0,''),(349020,111445,'118319','furniture','font-size','20',0,''),(349021,111446,'118320','furniture','block_type','1',0,''),(349022,111446,'118320','furniture','background-color','$content-bg-2',0,''),(349023,111446,'118320','furniture','padding-bottom','30',0,''),(349024,111447,'118321','furniture','block_type','4',0,''),(349025,111447,'118321','furniture','schema','4-2',0,'5140'),(349026,111448,'118322','furniture','block_type','1',0,''),(349027,111448,'118322','furniture','padding-right','40',0,''),(349028,111448,'118322','furniture','padding-right','0',0,'5140'),(349029,111449,'118323','furniture','block_type','2',0,''),(349030,111449,'118323','furniture','margin-bottom','20',0,''),(349031,111449,'118323','furniture','schema','2-2',0,'5131'),(349032,111449,'118323','furniture','background-color','$content-bg-1',0,''),(349033,111450,'118324','furniture','block_type','1',0,''),(349034,111450,'118324','furniture','border-right-width','20',0,''),(349035,111450,'118324','furniture','border-right-color','$content-border-1',0,''),(349036,111450,'118324','furniture','margin-right','-10',0,''),(349037,111450,'118324','furniture','padding-right','30',0,''),(349038,111450,'118324','furniture','padding-top','20',0,''),(349039,111450,'118324','furniture','padding-left','30',0,''),(349040,111450,'118324','furniture','padding-bottom','20',0,''),(349041,111450,'118324','furniture','border-right-width','0',0,'5140'),(349042,111450,'118324','furniture','margin-right','0',0,'5140'),(349043,111450,'118324','furniture','margin-bottom','20',0,'5140'),(349044,111450,'118324','furniture','padding-left','20',0,'5140'),(349045,111450,'118324','furniture','padding-right','20',0,'5140'),(349046,111452,'118326','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(349047,111452,'118326','furniture','clear','none',0,''),(349048,111453,'118327','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(349049,111453,'118327','furniture','clear','none',0,''),(349050,111454,'118328','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(349051,111456,'118330','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(349052,111456,'118330','furniture','padding-top','20',0,''),(349053,111459,'118333','furniture','margin-bottom','20',0,''),(349054,111460,'118334','furniture','block_type','1',0,''),(349055,111460,'118334','furniture','padding-left','30',0,''),(349056,111460,'118334','furniture','border-left-width','20',0,''),(349057,111460,'118334','furniture','border-left-color','$content-border-1',0,''),(349058,111460,'118334','furniture','margin-left','-10',0,''),(349059,111460,'118334','furniture','padding-right','30',0,''),(349060,111460,'118334','furniture','padding-top','20',0,''),(349061,111460,'118334','furniture','padding-bottom','20',0,''),(349062,111460,'118334','furniture','border-left-width','0',0,'5140'),(349063,111461,'118335','furniture','margin-bottom','20',0,''),(349064,111463,'118337','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(349065,111464,'118338','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(349066,111464,'118338','furniture','clear','none',0,''),(349067,111465,'118339','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(349068,111465,'118339','furniture','clear','none',0,''),(349069,111466,'118340','furniture','block_type','1',0,''),(349070,111466,'118340','furniture','padding-right','30',0,''),(349071,111466,'118340','furniture','background-color','$content-bg-1',0,''),(349072,111466,'118340','furniture','padding-top','20',0,''),(349073,111466,'118340','furniture','padding-left','30',0,''),(349074,111466,'118340','furniture','padding-bottom','20',0,''),(349075,111466,'118340','furniture','padding-left','20',0,'5140'),(349076,111466,'118340','furniture','padding-right','20',0,'5140'),(349077,111468,'118342','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(349078,111469,'118343','furniture','block_type','1',0,''),(349079,111469,'118343','furniture','padding-top','20',0,''),(349080,111469,'118343','furniture','padding-left','20',0,''),(349081,111469,'118343','furniture','padding-right','20',0,''),(349082,111469,'118343','furniture','padding-bottom','20',0,''),(349083,111469,'118343','furniture','background-color','$content-bg-1',0,''),(349084,111469,'118343','furniture','style_class','order-summary',0,''),(349085,111470,'118344','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(349086,111474,'118348','furniture','block_type','1',0,''),(349087,111474,'118348','furniture','background-color','$content-bg-2',0,''),(349088,111474,'118348','furniture','padding-bottom','30',0,''),(349089,111475,'118349','furniture','block_type','4',0,''),(349090,111475,'118349','furniture','schema','4-2',0,'5140'),(349091,111476,'118350','furniture','block_type','1',0,''),(349092,111476,'118350','furniture','padding-right','40',0,''),(349093,111476,'118350','furniture','padding-right','0',0,'5140'),(349094,111477,'118351','furniture','block_type','2',0,''),(349095,111477,'118351','furniture','margin-bottom','20',0,''),(349096,111477,'118351','furniture','schema','2-2',0,'5131'),(349097,111477,'118351','furniture','background-color','$content-bg-1',0,''),(349098,111478,'118352','furniture','block_type','1',0,''),(349099,111478,'118352','furniture','border-right-width','20',0,''),(349100,111478,'118352','furniture','border-right-color','$content-border-1',0,''),(349101,111478,'118352','furniture','margin-right','-10',0,''),(349102,111478,'118352','furniture','padding-right','30',0,''),(349103,111478,'118352','furniture','padding-top','20',0,''),(349104,111478,'118352','furniture','padding-left','30',0,''),(349105,111478,'118352','furniture','padding-bottom','20',0,''),(349106,111478,'118352','furniture','border-right-width','0',0,'5140'),(349107,111478,'118352','furniture','margin-right','0',0,'5140'),(349108,111478,'118352','furniture','margin-bottom','20',0,'5140'),(349109,111478,'118352','furniture','padding-left','20',0,'5140'),(349110,111478,'118352','furniture','padding-right','20',0,'5140'),(349111,111479,'118353','furniture','margin-bottom','20',0,''),(349112,111482,'118356','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(349113,111482,'118356','furniture','padding-top','20',0,''),(349114,111484,'118358','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(349115,111484,'118358','furniture','clear','none',0,''),(349116,111486,'118360','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(349117,111487,'118361','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(349118,111487,'118361','furniture','clear','none',0,''),(349119,111489,'118362','furniture','block_type','1',0,''),(349120,111489,'118362','furniture','padding-left','30',0,''),(349121,111489,'118362','furniture','border-left-width','20',0,''),(349122,111489,'118362','furniture','border-left-color','$content-border-1',0,''),(349123,111489,'118362','furniture','margin-left','-10',0,''),(349124,111489,'118362','furniture','padding-right','30',0,''),(349125,111489,'118362','furniture','padding-top','20',0,''),(349126,111489,'118362','furniture','padding-bottom','20',0,''),(349127,111489,'118362','furniture','border-left-width','0',0,'5140'),(349128,111490,'118363','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(349129,111491,'118364','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(349130,111491,'118364','furniture','clear','none',0,''),(349131,111492,'118365','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(349132,111492,'118365','furniture','clear','none',0,''),(349133,111493,'118366','furniture','margin-bottom','20',0,''),(349134,111494,'118367','furniture','orders_data','name',0,''),(349135,111495,'118368','furniture','block_type','1',0,''),(349136,111495,'118368','furniture','padding-right','30',0,''),(349137,111495,'118368','furniture','background-color','$content-bg-1',0,''),(349138,111495,'118368','furniture','padding-top','20',0,''),(349139,111495,'118368','furniture','padding-left','30',0,''),(349140,111495,'118368','furniture','padding-bottom','20',0,''),(349141,111495,'118368','furniture','padding-left','20',0,'5140'),(349142,111495,'118368','furniture','padding-right','20',0,'5140'),(349143,111496,'118369','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(349144,111498,'118371','furniture','block_type','1',0,''),(349145,111498,'118371','furniture','padding-top','20',0,''),(349146,111498,'118371','furniture','padding-left','20',0,''),(349147,111498,'118371','furniture','padding-right','20',0,''),(349148,111498,'118371','furniture','padding-bottom','20',0,''),(349149,111498,'118371','furniture','background-color','$content-bg-1',0,''),(349150,111498,'118371','furniture','style_class','order-summary',0,''),(349151,111501,'118374','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(349152,111503,'118440','furniture','block_type','1',0,''),(349153,111504,'118441','furniture','block_type','6',0,''),(349154,111504,'118441','furniture','schema','6-3',0,'5140'),(349155,111505,'118442','furniture','aria_name','account-menu',0,''),(349156,111506,'116126','furniture','block_type','1',0,''),(349157,111506,'116126','furniture','padding-top','70',0,''),(349158,111506,'116126','furniture','padding-right','30',0,''),(349159,111506,'116126','furniture','padding-bottom','30',0,''),(349160,111506,'116126','furniture','padding-top','0',0,'5140'),(349161,111506,'116126','furniture','padding-left','0',0,'5140'),(349162,111506,'116126','furniture','padding-right','0',0,'5140'),(349163,111506,'116126','furniture','padding-bottom','0',0,'5140'),(349213,111525,'118443','furniture','margin-bottom','20',0,''),(349214,111526,'118444','furniture','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(349215,111527,'118445','furniture','block_type','1',0,''),(349216,111527,'118445','furniture','padding-top','20',0,''),(349217,111527,'118445','furniture','padding-bottom','20',0,''),(349218,111529,'118447','furniture','padding-top','20',0,''),(349219,111529,'118447','furniture','padding-bottom','20',0,''),(349220,111530,'73349','watch','text','##TEXT_PAGE_NOT_FOUND##',0,''),(349221,111530,'73349','watch','text-align','center',0,''),(349222,111530,'73349','watch','padding-top','100',0,''),(349223,111530,'73349','watch','padding-bottom','100',0,''),(349224,111531,'75904','watch','block_type','1',0,''),(349343,111547,'75920','watch','block_type','1',0,''),(349462,111563,'75936','watch','block_type','1',0,''),(349581,111579,'75952','watch','block_type','1',0,''),(349700,111595,'75968','watch','block_type','1',0,''),(349819,111611,'75984','watch','block_type','1',0,''),(349938,111627,'73350','watch','block_type','1',0,''),(349939,111627,'73350','watch','style_class','account-index',0,''),(350177,111691,'73393','watch','block_type','1',0,''),(350178,111691,'73393','watch','style_class','account-edit-wrap',0,''),(350240,111715,'73398','watch','block_type','1',0,''),(350241,111715,'73398','watch','style_class','account-address-book',0,''),(350311,111740,'73404','watch','block_type','1',0,''),(350312,111740,'73404','watch','style_class','account-address-book-process',0,''),(350374,111764,'73409','watch','block_type','1',0,''),(350375,111764,'73409','watch','style_class','item-holder',0,''),(350376,111764,'73409','watch','padding-top','25',0,''),(350377,111764,'73409','watch','padding-bottom','25',0,''),(350378,111764,'73409','watch','text-align','left',0,''),(350379,111764,'73409','watch','border-top-color','$content-border-1',0,''),(350380,111764,'73409','watch','border-top-width','1',0,''),(350381,111765,'73410','watch','block_type','6',0,''),(350382,111766,'73411','watch','padding-right','20',0,''),(350383,111767,'73412','watch','description_characters','200',0,''),(350384,111767,'73412','watch','clear','none',0,''),(350385,111767,'73412','watch','padding-right','20',0,''),(350386,111768,'73413','watch','clear','none',0,''),(350387,111770,'73415','watch','block_type','4',0,''),(350388,111771,'73416','watch','block_type','2',0,''),(350389,111772,'73417','watch','margin-bottom','7',0,''),(350390,111773,'73418','watch','clear','none',0,''),(350391,111774,'73419','watch','margin-bottom','20',0,''),(350392,111774,'73419','watch','text-align','right',0,''),(350393,111775,'73420','watch','padding-right','20',0,''),(350394,111776,'73421','watch','block_type','2',0,''),(350395,111777,'73422','watch','clear','none',0,''),(350396,111779,'76000','watch','block_type','1',0,''),(350397,111779,'76000','watch','style_class','item-holder',0,''),(350398,111779,'76000','watch','padding-top','25',0,''),(350399,111779,'76000','watch','padding-left','25',0,''),(350400,111779,'76000','watch','padding-right','25',0,''),(350401,111779,'76000','watch','padding-bottom','25',0,''),(350402,111779,'76000','watch','text-align','left',0,''),(350403,111781,'76002','watch','margin-bottom','7',0,''),(350404,111782,'76003','watch','clear','both',0,''),(350405,111785,'76006','watch','block_type','1',0,''),(350406,111785,'76006','watch','style_class','item-holder',0,''),(350407,111785,'76006','watch','padding-top','25',0,''),(350408,111785,'76006','watch','padding-left','25',0,''),(350409,111785,'76006','watch','padding-right','25',0,''),(350410,111785,'76006','watch','padding-bottom','25',0,''),(350411,111785,'76006','watch','text-align','left',0,''),(350412,111786,'76007','watch','block_type','5',0,''),(350413,111789,'76010','watch','margin-bottom','7',0,''),(350414,111790,'76011','watch','clear','both',0,''),(350415,111791,'76012','watch','block_type','1',0,''),(350416,111792,'76013','watch','block_type','6',0,''),(350417,111792,'76013','watch','font-weight','400',0,''),(350418,111792,'76013','watch','schema','6-2',0,'5261'),(350419,111792,'76013','watch','schema','6-2',0,'5240'),(350420,111793,'76014','watch','font-weight','400',0,''),(350421,111793,'76014','watch','padding-right','40',0,''),(350422,111793,'76014','watch','padding-right','0',0,'5261'),(350423,111793,'76014','watch','padding-right','0',0,'5240'),(350424,111794,'76015','watch','block_type','5',0,''),(350425,111794,'76015','watch','padding-top','10',0,''),(350426,111794,'76015','watch','padding-bottom','10',0,''),(350427,111794,'76015','watch','schema','5-2',0,'5261'),(350428,111794,'76015','watch','border-top-color','$content-border-1',0,''),(350429,111794,'76015','watch','border-top-width','1',0,''),(350430,111796,'76017','watch','float','right',0,''),(350431,111798,'76019','watch','col_in_row','3',0,''),(350432,111798,'76019','watch','products_align','left',0,''),(350433,111798,'76019','watch','font-weight','400',0,''),(350434,111798,'76019','watch','show_qty_input','0',0,''),(350435,111798,'76019','watch','listing_type','productListing',0,''),(350436,111798,'76019','watch','listing_type_rows','no',0,''),(350437,111798,'76019','watch','show_buy_button_b2b','on',0,''),(350438,111798,'76019','watch','show_wishlist_button_b2b','1',0,''),(350439,111798,'76019','watch','show_compare_b2b','1',0,''),(350440,111798,'76019','watch','show_stock','0',0,''),(350441,111798,'76019','watch','show_description','0',0,''),(350442,111798,'76019','watch','show_model','0',0,''),(350443,111798,'76019','watch','show_properties','0',0,''),(350444,111798,'76019','watch','show_rating','0',0,''),(350445,111798,'76019','watch','show_rating_counts','0',0,''),(350446,111798,'76019','watch','show_price','0',0,''),(350447,111798,'76019','watch','show_buy_button','0',0,''),(350448,111798,'76019','watch','show_view_button','0',0,''),(350449,111798,'76019','watch','show_wishlist_button','0',0,''),(350450,111798,'76019','watch','show_compare','0',0,''),(350451,111798,'76019','watch','show_name_rows','0',0,''),(350452,111798,'76019','watch','show_image_rows','0',0,''),(350453,111798,'76019','watch','show_stock_rows','0',0,''),(350454,111798,'76019','watch','show_description_rows','0',0,''),(350455,111798,'76019','watch','show_model_rows','0',0,''),(350456,111798,'76019','watch','show_properties_rows','0',0,''),(350457,111798,'76019','watch','show_rating_rows','0',0,''),(350458,111798,'76019','watch','show_rating_counts_rows','0',0,''),(350459,111798,'76019','watch','show_price_rows','0',0,''),(350460,111798,'76019','watch','show_buy_button_rows','0',0,''),(350461,111798,'76019','watch','show_qty_input_rows','0',0,''),(350462,111798,'76019','watch','show_view_button_rows','0',0,''),(350463,111798,'76019','watch','show_wishlist_button_rows','0',0,''),(350464,111798,'76019','watch','show_compare_rows','0',0,''),(350465,111798,'76019','watch','show_name_b2b','0',0,''),(350466,111798,'76019','watch','show_image_b2b','0',0,''),(350467,111798,'76019','watch','show_stock_b2b','0',0,''),(350468,111798,'76019','watch','show_description_b2b','0',0,''),(350469,111798,'76019','watch','show_model_b2b','0',0,''),(350470,111798,'76019','watch','show_properties_b2b','0',0,''),(350471,111798,'76019','watch','show_rating_b2b','0',0,''),(350472,111798,'76019','watch','show_rating_counts_b2b','0',0,''),(350473,111798,'76019','watch','show_price_b2b','0',0,''),(350474,111798,'76019','watch','show_qty_input_b2b','0',0,''),(350475,111798,'76019','watch','show_view_button_b2b','0',0,''),(350476,111798,'76019','watch','show_attributes_b2b','0',0,''),(350477,111798,'76019','watch','items_on_page','9',0,''),(350478,111798,'76019','watch','col_in_row','2',0,'5240'),(350479,111798,'76019','watch','col_in_row','1',0,'5261'),(350480,111798,'76019','watch','product_names_teg','h2',0,''),(350481,111799,'76020','watch','listing_type','productListing',0,''),(350482,111800,'76021','watch','block_type','1',0,''),(350483,111800,'76021','watch','padding-top','10',0,''),(350484,111800,'76021','watch','padding-bottom','10',0,''),(350485,111800,'76021','watch','border-bottom-width','1',0,''),(350486,111800,'76021','watch','border-bottom-color','$content-border-1',0,''),(350487,111800,'76021','watch','margin-left','0',0,''),(350488,111800,'76021','watch','margin-right','0',0,''),(350489,111801,'76022','watch','float','right',0,''),(350490,111801,'76022','watch','display','none',0,'5261'),(350491,111802,'76023','watch','margin-right','20',0,''),(350492,111802,'76023','watch','float','right',0,''),(350493,111802,'76023','watch','clear','none',0,''),(350494,111802,'76023','watch','display','none',0,'5240'),(350495,111803,'76024','watch','float','left',0,''),(350496,111803,'76024','watch','clear','none',0,''),(350497,111803,'76024','watch','margin-left','20',0,''),(350498,111803,'76024','watch','display','none',0,'5261'),(350499,111804,'76025','watch','float','left',0,''),(350500,111804,'76025','watch','clear','none',0,''),(350501,111804,'76025','watch','sort_pos_3','1',0,''),(350502,111804,'76025','watch','sort_pos_4','2',0,''),(350503,111804,'76025','watch','sort_pos_10','3',0,''),(350504,111804,'76025','watch','sort_pos_9','4',0,''),(350505,111804,'76025','watch','sort_pos_11','5',0,''),(350506,111804,'76025','watch','sort_pos_12','6',0,''),(350507,111804,'76025','watch','sort_pos_14','7',0,''),(350508,111804,'76025','watch','sort_pos_13','8',0,''),(350509,111804,'76025','watch','sort_pos_8','9',0,''),(350510,111804,'76025','watch','sort_pos_7','10',0,''),(350511,111804,'76025','watch','sort_pos_2','11',0,''),(350512,111804,'76025','watch','sort_pos_1','12',0,''),(350513,111804,'76025','watch','sort_pos_6','13',0,''),(350514,111804,'76025','watch','sort_pos_5','14',0,''),(350515,111804,'76025','watch','sort_pos_0','15',0,''),(350516,111804,'76025','watch','sort_hide_10','1',0,''),(350517,111804,'76025','watch','sort_hide_9','1',0,''),(350518,111804,'76025','watch','hide_icons','1',0,''),(350519,111804,'76025','watch','sort_hide_16','1',0,''),(350520,111804,'76025','watch','sort_hide_15','1',0,''),(350521,111804,'76025','watch','sort_hide_3','0',0,''),(350522,111804,'76025','watch','sort_hide_4','0',0,''),(350523,111804,'76025','watch','sort_hide_11','1',0,''),(350524,111804,'76025','watch','sort_hide_12','1',0,''),(350525,111804,'76025','watch','sort_hide_14','1',0,''),(350526,111804,'76025','watch','sort_hide_13','1',0,''),(350527,111804,'76025','watch','sort_hide_8','0',0,''),(350528,111804,'76025','watch','sort_hide_7','0',0,''),(350529,111804,'76025','watch','sort_hide_2','1',0,''),(350530,111804,'76025','watch','sort_hide_1','1',0,''),(350531,111804,'76025','watch','sort_hide_6','1',0,''),(350532,111804,'76025','watch','sort_hide_5','1',0,''),(350533,111804,'76025','watch','sort_hide_0','1',0,''),(350534,111807,'1683124632.767746','watch','block_type','1',0,''),(350535,111807,'1683124632.767746','watch','font-weight','normal',0,''),(350536,111807,'1683124632.767746','watch','padding-top','20',0,''),(350537,111807,'1683124632.767746','watch','background-color','$content-bg-2',0,''),(350538,111807,'1683124632.767746','watch','style_class','shopping-cart-index',0,''),(350539,111807,'1683124632.767746','watch','color','$content-color-2',0,''),(350540,111808,'1683124632.80670','watch','block_type','4',0,''),(350541,111808,'1683124632.80670','watch','schema','4-1',0,'5245'),(350542,111808,'1683124632.80670','watch','schema','4-2',0,'5240'),(350543,111809,'1683124632.809680','watch','block_type','1',0,''),(350544,111809,'1683124632.809680','watch','background-color','$content-bg-1',0,''),(350545,111809,'1683124632.809680','watch','padding-top','20',0,''),(350546,111809,'1683124632.809680','watch','padding-bottom','20',0,''),(350547,111809,'1683124632.809680','watch','padding-left','25',0,''),(350548,111809,'1683124632.809680','watch','padding-right','25',0,''),(350549,111809,'1683124632.809680','watch','margin-bottom','30',0,''),(350550,111809,'1683124632.809680','watch','color','$content-color-1',0,''),(350551,111810,'1683124632.816335','watch','block_type','1',0,''),(350552,111810,'1683124632.816335','watch','background-color','$content-bg-1',0,''),(350553,111810,'1683124632.816335','watch','margin-bottom','30',0,''),(350554,111810,'1683124632.816335','watch','color','$content-color-1',0,''),(350555,111811,'1683124632.817623','watch','padding-top','20',0,''),(350556,111811,'1683124632.817623','watch','padding-left','25',0,''),(350557,111811,'1683124632.817623','watch','padding-right','25',0,''),(350558,111811,'1683124632.817623','watch','padding-bottom','20',0,''),(350559,111812,'1683124632.818551','watch','block_type','2',0,''),(350560,111812,'1683124632.818551','watch','padding-bottom','20',0,''),(350561,111812,'1683124632.818551','watch','padding-top','20',0,''),(350562,111812,'1683124632.818551','watch','padding-left','25',0,''),(350563,111812,'1683124632.818551','watch','padding-right','25',0,''),(350564,111812,'1683124632.818551','watch','border-bottom-color','#e0e0e0',0,''),(350565,111812,'1683124632.818551','watch','border-bottom-width','1',0,''),(350566,111812,'1683124632.818551','watch','schema','2-2',0,'5240'),(350567,111813,'1683124632.820317','watch','float','left',0,''),(350568,111814,'1683124632.820914','watch','text-align','right',0,''),(350569,111814,'1683124632.820914','watch','clear','none',0,''),(350570,111814,'1683124632.820914','watch','float','right',0,''),(350571,111814,'1683124632.820914','watch','padding-top','22',0,''),(350572,111815,'1683124632.822588','watch','float','right',0,''),(350573,111815,'1683124632.822588','watch','padding-top','26',0,''),(350574,111816,'1683124632.823175','watch','block_type','3',0,''),(350575,111816,'1683124632.823175','watch','font-weight','400',0,''),(350576,111816,'1683124632.823175','watch','schema','2-2',0,'5232'),(350577,111816,'1683124632.823175','watch','style_class','closeable-content',0,''),(350578,111816,'1683124632.823175','watch','padding-top','10',0,''),(350579,111816,'1683124632.823175','watch','padding-left','25',0,''),(350580,111816,'1683124632.823175','watch','padding-right','25',0,''),(350581,111816,'1683124632.823175','watch','padding-bottom','20',0,''),(350582,111819,'1683124632.82683','watch','block_type','1',0,''),(350583,111819,'1683124632.82683','watch','padding-top','20',0,''),(350584,111819,'1683124632.82683','watch','padding-bottom','20',0,''),(350585,111819,'1683124632.82683','watch','padding-left','25',0,''),(350586,111819,'1683124632.82683','watch','padding-right','25',0,''),(350587,111819,'1683124632.82683','watch','background-color','$content-bg-1',0,''),(350588,111819,'1683124632.82683','watch','margin-bottom','30',0,''),(350589,111819,'1683124632.82683','watch','color','$content-color-1',0,''),(350590,111820,'1683124632.827413','watch','hide_parents','2',0,''),(350591,111821,'1683124632.828374','watch','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(350592,111822,'1683124632.829840','watch','block_type','1',0,''),(350593,111822,'1683124632.829840','watch','background-color','$content-bg-1',0,''),(350594,111822,'1683124632.829840','watch','padding-top','20',0,''),(350595,111822,'1683124632.829840','watch','padding-left','25',0,''),(350596,111822,'1683124632.829840','watch','padding-right','25',0,''),(350597,111822,'1683124632.829840','watch','padding-bottom','20',0,''),(350598,111822,'1683124632.829840','watch','margin-bottom','30',0,''),(350599,111822,'1683124632.829840','watch','style_class','closeable-box',0,''),(350600,111822,'1683124632.829840','watch','display','none',0,'5240'),(350601,111823,'1683124632.831459','watch','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(350602,111823,'1683124632.831459','watch','style_class','shipping-ico closeable-heading closeable-event',0,''),(350603,111824,'1683124632.832592','watch','font-weight','normal',0,''),(350604,111824,'1683124632.832592','watch','style_class','closeable-content',0,''),(350605,111824,'1683124632.832592','watch','padding-top','10',0,''),(350606,111824,'1683124632.832592','watch','hide_parents','2',0,''),(350607,111825,'1683124632.833353','watch','style_class','order-summary',0,''),(350608,111825,'1683124632.833353','watch','block_type','1',0,''),(350609,111825,'1683124632.833353','watch','margin-left','30',0,''),(350610,111825,'1683124632.833353','watch','margin-left','0',0,'5240'),(350611,111825,'1683124632.833353','watch','margin-bottom','30',0,'5240'),(350612,111826,'1683124632.834715','watch','block_type','1',0,''),(350613,111826,'1683124632.834715','watch','padding-left','20',0,''),(350614,111826,'1683124632.834715','watch','padding-right','20',0,''),(350615,111826,'1683124632.834715','watch','padding-bottom','20',0,''),(350616,111827,'1683124632.835884','watch','font-weight','400',0,''),(350617,111827,'1683124632.835884','watch','padding-top','12',0,'5232'),(350618,111827,'1683124632.835884','watch','padding-left','0',0,'5232'),(350619,111828,'1683124632.836532','watch','font-weight','400',0,''),(350620,111828,'1683124632.836532','watch','logo','themes/watch/img/payment.png',1,''),(350621,111828,'1683124632.836532','watch','padding-top','20',0,''),(350622,111828,'1683124632.836532','watch','padding-bottom','10',0,''),(350623,111828,'1683124632.836532','watch','logo','themes/watch/img/payment.png',2,''),(350624,111828,'1683124632.836532','watch','logo','themes/watch/img/payment.png',3,''),(350625,111828,'1683124632.836532','watch','logo','themes/watch/img/payment.png',4,''),(350626,111829,'1683124632.844829','watch','font-weight','400',0,''),(350627,111829,'1683124632.844829','watch','box_align','4',0,''),(350628,111829,'1683124632.844829','watch','text-align','center',0,'5232'),(350629,111829,'1683124632.844829','watch','float','none',0,'5232'),(350630,111829,'1683124632.844829','watch','width','100',0,'5232'),(350631,111829,'1683124632.844829','watch','width_measure','%',0,'5232'),(350632,111830,'1683124632.84681','watch','style_class','bottom-totals',0,''),(350633,111831,'1683124632.846538','watch','style_class','top-totals',0,''),(350634,111832,'1683124632.84726','watch','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(350635,111833,'94658','watch','block_type','1',0,''),(350636,111833,'94658','watch','font-weight','normal',0,''),(350637,111833,'94658','watch','padding-top','20',0,''),(350638,111833,'94658','watch','background-color','$content-bg-2',0,''),(350639,111835,'94660','watch','block_type','4',0,''),(350640,111835,'94660','watch','schema','4-1',0,'5245'),(350641,111835,'94660','watch','schema','4-2',0,'5240'),(350642,111836,'94661','watch','block_type','1',0,''),(350643,111836,'94661','watch','background-color','$content-bg-1',0,''),(350644,111836,'94661','watch','padding-top','20',0,''),(350645,111836,'94661','watch','padding-bottom','20',0,''),(350646,111836,'94661','watch','padding-left','25',0,''),(350647,111836,'94661','watch','padding-right','25',0,''),(350648,111836,'94661','watch','margin-bottom','30',0,''),(350649,111837,'94662','watch','col_in_row','3',0,''),(350650,111837,'94662','watch','show_description','1',0,''),(350651,111837,'94662','watch','show_model','1',0,''),(350652,111837,'94662','watch','show_properties','1',0,''),(350653,111837,'94662','watch','show_rating','1',0,''),(350654,111837,'94662','watch','show_rating_counts','1',0,''),(350655,111837,'94662','watch','show_qty_input','1',0,''),(350656,111837,'94662','watch','show_view_button','1',0,''),(350657,111837,'94662','watch','show_wishlist_button','1',0,''),(350658,111837,'94662','watch','show_compare','1',0,''),(350659,111837,'94662','watch','view_as','carousel',0,''),(350660,111837,'94662','watch','hide_parents','2',0,''),(350661,111838,'94663','watch','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(350662,111838,'94663','watch','style_class','bell-ico',0,''),(350663,111839,'94664','watch','block_type','1',0,''),(350664,111839,'94664','watch','background-color','$content-bg-1',0,''),(350665,111839,'94664','watch','margin-bottom','30',0,''),(350666,111840,'94665','watch','padding-top','20',0,''),(350667,111840,'94665','watch','padding-left','25',0,''),(350668,111840,'94665','watch','padding-right','25',0,''),(350669,111840,'94665','watch','padding-bottom','20',0,''),(350670,111841,'94666','watch','block_type','2',0,''),(350671,111841,'94666','watch','padding-bottom','20',0,''),(350672,111841,'94666','watch','padding-top','20',0,''),(350673,111841,'94666','watch','padding-left','25',0,''),(350674,111841,'94666','watch','padding-right','25',0,''),(350675,111841,'94666','watch','border-bottom-color','$content-border-1',0,''),(350676,111841,'94666','watch','border-bottom-width','1',0,''),(350677,111841,'94666','watch','schema','2-2',0,'5240'),(350678,111842,'94667','watch','float','left',0,''),(350679,111843,'94668','watch','text-align','right',0,''),(350680,111843,'94668','watch','clear','none',0,''),(350681,111843,'94668','watch','float','right',0,''),(350682,111843,'94668','watch','padding-top','22',0,''),(350683,111844,'94669','watch','float','right',0,''),(350684,111844,'94669','watch','padding-top','26',0,''),(350685,111845,'94670','watch','block_type','1',0,''),(350686,111845,'94670','watch','padding-top','20',0,''),(350687,111845,'94670','watch','padding-bottom','20',0,''),(350688,111845,'94670','watch','padding-left','25',0,''),(350689,111845,'94670','watch','padding-right','25',0,''),(350690,111845,'94670','watch','background-color','$content-bg-1',0,''),(350691,111845,'94670','watch','margin-bottom','30',0,''),(350692,111846,'94671','watch','hide_parents','2',0,''),(350693,111847,'94672','watch','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(350694,111848,'94673','watch','block_type','1',0,''),(350695,111848,'94673','watch','background-color','$content-bg-1',0,''),(350696,111848,'94673','watch','padding-top','20',0,''),(350697,111848,'94673','watch','padding-bottom','20',0,''),(350698,111848,'94673','watch','padding-left','25',0,''),(350699,111848,'94673','watch','padding-right','25',0,''),(350700,111848,'94673','watch','margin-bottom','30',0,''),(350701,111848,'94673','watch','style_class','closeable-box',0,''),(350702,111849,'94674','watch','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(350703,111849,'94674','watch','style_class','savings-ico closeable-heading closeable-event',0,''),(350704,111850,'94675','watch','block_type','3',0,''),(350705,111850,'94675','watch','font-weight','400',0,''),(350706,111850,'94675','watch','schema','2-2',0,'5232'),(350707,111850,'94675','watch','style_class','closeable-content',0,''),(350708,111850,'94675','watch','padding-top','10',0,''),(350709,111851,'94676','watch','font-weight','400',0,''),(350710,111851,'94676','watch','padding-top','12',0,'5232'),(350711,111851,'94676','watch','padding-left','0',0,'5232'),(350712,111854,'94679','watch','block_type','1',0,''),(350713,111854,'94679','watch','background-color','$content-bg-1',0,''),(350714,111854,'94679','watch','padding-top','20',0,''),(350715,111854,'94679','watch','padding-left','25',0,''),(350716,111854,'94679','watch','padding-right','25',0,''),(350717,111854,'94679','watch','padding-bottom','20',0,''),(350718,111854,'94679','watch','margin-bottom','30',0,''),(350719,111854,'94679','watch','style_class','closeable-box',0,''),(350720,111854,'94679','watch','display','none',0,'5240'),(350721,111855,'94680','watch','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(350722,111855,'94680','watch','style_class','shipping-ico closeable-heading closeable-event',0,''),(350723,111856,'94681','watch','font-weight','normal',0,''),(350724,111856,'94681','watch','style_class','closeable-content',0,''),(350725,111856,'94681','watch','padding-top','10',0,''),(350726,111856,'94681','watch','hide_parents','2',0,''),(350727,111857,'94682','watch','style_class','order-summary',0,''),(350728,111857,'94682','watch','block_type','1',0,''),(350729,111857,'94682','watch','margin-left','30',0,''),(350730,111857,'94682','watch','margin-left','0',0,'5240'),(350731,111857,'94682','watch','margin-bottom','30',0,'5240'),(350732,111858,'94683','watch','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(350733,111859,'94684','watch','block_type','1',0,''),(350734,111859,'94684','watch','padding-left','20',0,''),(350735,111859,'94684','watch','padding-right','20',0,''),(350736,111859,'94684','watch','padding-bottom','20',0,''),(350737,111860,'94685','watch','font-weight','400',0,''),(350738,111860,'94685','watch','logo','themes/watch/img/payicons.png',1,''),(350739,111860,'94685','watch','padding-top','20',0,''),(350740,111860,'94685','watch','padding-bottom','10',0,''),(350741,111860,'94685','watch','logo','themes/watch/img/payicons.png',2,''),(350742,111860,'94685','watch','logo','themes/watch/img/payicons.png',3,''),(350743,111860,'94685','watch','logo','themes/watch/img/payicons.png',4,''),(350744,111861,'94686','watch','font-weight','400',0,''),(350745,111861,'94686','watch','box_align','4',0,''),(350746,111861,'94686','watch','text-align','center',0,'5232'),(350747,111861,'94686','watch','float','none',0,'5232'),(350748,111861,'94686','watch','width','100',0,'5232'),(350749,111861,'94686','watch','width_measure','%',0,'5232'),(350750,111863,'73462','watch','block_type','1',0,''),(350751,111864,'73463','watch','block_type','6',0,''),(350752,111864,'73463','watch','font-weight','400',0,''),(350753,111864,'73463','watch','schema','6-2',0,'5261'),(350754,111864,'73463','watch','schema','6-2',0,'5240'),(350755,111865,'73464','watch','font-weight','400',0,''),(350756,111865,'73464','watch','padding-right','40',0,''),(350757,111865,'73464','watch','padding-right','0',0,'5261'),(350758,111865,'73464','watch','padding-right','0',0,'5240'),(350759,111866,'73465','watch','col_in_row','3',0,''),(350760,111866,'73465','watch','products_align','left',0,''),(350761,111866,'73465','watch','font-weight','400',0,''),(350762,111866,'73465','watch','show_qty_input','0',0,''),(350763,111866,'73465','watch','listing_type','productListing',0,''),(350764,111866,'73465','watch','listing_type_rows','Rows',0,''),(350765,111866,'73465','watch','show_buy_button_b2b','on',0,''),(350766,111866,'73465','watch','show_wishlist_button_b2b','1',0,''),(350767,111866,'73465','watch','show_compare_b2b','1',0,''),(350768,111866,'73465','watch','show_stock','0',0,''),(350769,111866,'73465','watch','show_description','0',0,''),(350770,111866,'73465','watch','show_model','0',0,''),(350771,111866,'73465','watch','show_properties','0',0,''),(350772,111866,'73465','watch','show_rating','0',0,''),(350773,111866,'73465','watch','show_rating_counts','0',0,''),(350774,111866,'73465','watch','show_price','0',0,''),(350775,111866,'73465','watch','show_buy_button','0',0,''),(350776,111866,'73465','watch','show_view_button','0',0,''),(350777,111866,'73465','watch','show_wishlist_button','0',0,''),(350778,111866,'73465','watch','show_compare','0',0,''),(350779,111866,'73465','watch','show_name_rows','0',0,''),(350780,111866,'73465','watch','show_image_rows','0',0,''),(350781,111866,'73465','watch','show_stock_rows','0',0,''),(350782,111866,'73465','watch','show_description_rows','0',0,''),(350783,111866,'73465','watch','show_model_rows','0',0,''),(350784,111866,'73465','watch','show_properties_rows','0',0,''),(350785,111866,'73465','watch','show_rating_rows','0',0,''),(350786,111866,'73465','watch','show_rating_counts_rows','0',0,''),(350787,111866,'73465','watch','show_price_rows','0',0,''),(350788,111866,'73465','watch','show_buy_button_rows','0',0,''),(350789,111866,'73465','watch','show_qty_input_rows','0',0,''),(350790,111866,'73465','watch','show_view_button_rows','0',0,''),(350791,111866,'73465','watch','show_wishlist_button_rows','0',0,''),(350792,111866,'73465','watch','show_compare_rows','0',0,''),(350793,111866,'73465','watch','show_name_b2b','0',0,''),(350794,111866,'73465','watch','show_image_b2b','0',0,''),(350795,111866,'73465','watch','show_stock_b2b','0',0,''),(350796,111866,'73465','watch','show_description_b2b','0',0,''),(350797,111866,'73465','watch','show_model_b2b','0',0,''),(350798,111866,'73465','watch','show_properties_b2b','0',0,''),(350799,111866,'73465','watch','show_rating_b2b','0',0,''),(350800,111866,'73465','watch','show_rating_counts_b2b','0',0,''),(350801,111866,'73465','watch','show_price_b2b','0',0,''),(350802,111866,'73465','watch','show_qty_input_b2b','0',0,''),(350803,111866,'73465','watch','show_view_button_b2b','0',0,''),(350804,111866,'73465','watch','show_attributes_b2b','0',0,''),(350805,111866,'73465','watch','items_on_page','9',0,''),(350806,111866,'73465','watch','col_in_row','2',0,'5240'),(350807,111866,'73465','watch','col_in_row','1',0,'5261'),(350808,111866,'73465','watch','product_names_teg','h2',0,''),(350809,111868,'73467','watch','block_type','5',0,''),(350810,111868,'73467','watch','padding-top','10',0,''),(350811,111868,'73467','watch','padding-bottom','10',0,''),(350812,111868,'73467','watch','schema','5-2',0,'5261'),(350813,111868,'73467','watch','border-top-color','$content-border-1',0,''),(350814,111868,'73467','watch','border-top-width','1',0,''),(350815,111870,'73469','watch','float','right',0,''),(350816,111871,'73470','watch','listing_type','productListing',0,''),(350817,111873,'73472','watch','block_type','1',0,''),(350818,111873,'73472','watch','padding-top','10',0,''),(350819,111873,'73472','watch','padding-bottom','10',0,''),(350820,111873,'73472','watch','border-bottom-width','1',0,''),(350821,111873,'73472','watch','border-bottom-color','$content-border-1',0,''),(350822,111873,'73472','watch','margin-left','0',0,''),(350823,111873,'73472','watch','margin-right','0',0,''),(350824,111874,'73473','watch','float','right',0,''),(350825,111874,'73473','watch','display','none',0,'5261'),(350826,111875,'73474','watch','margin-right','20',0,''),(350827,111875,'73474','watch','float','right',0,''),(350828,111875,'73474','watch','clear','none',0,''),(350829,111875,'73474','watch','display','none',0,'5240'),(350830,111876,'73475','watch','float','left',0,''),(350831,111876,'73475','watch','clear','none',0,''),(350832,111876,'73475','watch','margin-left','20',0,''),(350833,111876,'73475','watch','display','none',0,'5261'),(350834,111877,'73476','watch','float','left',0,''),(350835,111877,'73476','watch','clear','none',0,''),(350836,111877,'73476','watch','sort_pos_3','2',0,''),(350837,111877,'73476','watch','sort_pos_4','3',0,''),(350838,111877,'73476','watch','sort_pos_10','11',0,''),(350839,111877,'73476','watch','sort_pos_9','10',0,''),(350840,111877,'73476','watch','sort_pos_11','12',0,''),(350841,111877,'73476','watch','sort_pos_12','13',0,''),(350842,111877,'73476','watch','sort_pos_14','15',0,''),(350843,111877,'73476','watch','sort_pos_13','14',0,''),(350844,111877,'73476','watch','sort_pos_8','4',0,''),(350845,111877,'73476','watch','sort_pos_7','5',0,''),(350846,111877,'73476','watch','sort_pos_2','7',0,''),(350847,111877,'73476','watch','sort_pos_1','6',0,''),(350848,111877,'73476','watch','sort_pos_6','9',0,''),(350849,111877,'73476','watch','sort_pos_5','8',0,''),(350850,111877,'73476','watch','sort_pos_0','1',0,''),(350851,111877,'73476','watch','sort_hide_10','1',0,''),(350852,111877,'73476','watch','sort_hide_9','1',0,''),(350853,111877,'73476','watch','hide_icons','1',0,''),(350854,111877,'73476','watch','sort_hide_16','1',0,''),(350855,111877,'73476','watch','sort_hide_15','1',0,''),(350856,111877,'73476','watch','sort_hide_3','0',0,''),(350857,111877,'73476','watch','sort_hide_4','0',0,''),(350858,111877,'73476','watch','sort_hide_11','1',0,''),(350859,111877,'73476','watch','sort_hide_12','1',0,''),(350860,111877,'73476','watch','sort_hide_14','1',0,''),(350861,111877,'73476','watch','sort_hide_13','1',0,''),(350862,111877,'73476','watch','sort_hide_8','0',0,''),(350863,111877,'73476','watch','sort_hide_7','0',0,''),(350864,111877,'73476','watch','sort_hide_2','1',0,''),(350865,111877,'73476','watch','sort_hide_1','1',0,''),(350866,111877,'73476','watch','sort_hide_6','1',0,''),(350867,111877,'73476','watch','sort_hide_5','1',0,''),(350868,111877,'73476','watch','sort_hide_0','0',0,''),(350869,111877,'73476','watch','sort_pos_15','16',0,''),(350870,111877,'73476','watch','sort_pos_16','17',0,''),(350871,111884,'94688','watch','block_type','1',0,''),(350872,111886,'94690','watch','block_type','6',0,''),(350873,111886,'94690','watch','font-weight','400',0,''),(350874,111886,'94690','watch','schema','6-2',0,'5261'),(350875,111886,'94690','watch','schema','6-2',0,'5240'),(350876,111887,'94691','watch','font-weight','400',0,''),(350877,111887,'94691','watch','padding-right','40',0,''),(350878,111887,'94691','watch','padding-right','0',0,'5261'),(350879,111887,'94691','watch','padding-right','0',0,'5240'),(350880,111889,'94693','watch','col_in_row','3',0,''),(350881,111889,'94693','watch','products_align','left',0,''),(350882,111889,'94693','watch','font-weight','400',0,''),(350883,111889,'94693','watch','show_qty_input','0',0,''),(350884,111889,'94693','watch','listing_type','productListing',0,''),(350885,111889,'94693','watch','listing_type_rows','no',0,''),(350886,111889,'94693','watch','show_buy_button_b2b','on',0,''),(350887,111889,'94693','watch','show_wishlist_button_b2b','1',0,''),(350888,111889,'94693','watch','show_compare_b2b','1',0,''),(350889,111889,'94693','watch','show_stock','0',0,''),(350890,111889,'94693','watch','show_description','0',0,''),(350891,111889,'94693','watch','show_model','0',0,''),(350892,111889,'94693','watch','show_properties','0',0,''),(350893,111889,'94693','watch','show_rating','0',0,''),(350894,111889,'94693','watch','show_rating_counts','0',0,''),(350895,111889,'94693','watch','show_price','0',0,''),(350896,111889,'94693','watch','show_buy_button','0',0,''),(350897,111889,'94693','watch','show_view_button','0',0,''),(350898,111889,'94693','watch','show_wishlist_button','0',0,''),(350899,111889,'94693','watch','show_compare','0',0,''),(350900,111889,'94693','watch','show_name_rows','0',0,''),(350901,111889,'94693','watch','show_image_rows','0',0,''),(350902,111889,'94693','watch','show_stock_rows','0',0,''),(350903,111889,'94693','watch','show_description_rows','0',0,''),(350904,111889,'94693','watch','show_model_rows','0',0,''),(350905,111889,'94693','watch','show_properties_rows','0',0,''),(350906,111889,'94693','watch','show_rating_rows','0',0,''),(350907,111889,'94693','watch','show_rating_counts_rows','0',0,''),(350908,111889,'94693','watch','show_price_rows','0',0,''),(350909,111889,'94693','watch','show_buy_button_rows','0',0,''),(350910,111889,'94693','watch','show_qty_input_rows','0',0,''),(350911,111889,'94693','watch','show_view_button_rows','0',0,''),(350912,111889,'94693','watch','show_wishlist_button_rows','0',0,''),(350913,111889,'94693','watch','show_compare_rows','0',0,''),(350914,111889,'94693','watch','show_name_b2b','0',0,''),(350915,111889,'94693','watch','show_image_b2b','0',0,''),(350916,111889,'94693','watch','show_stock_b2b','0',0,''),(350917,111889,'94693','watch','show_description_b2b','0',0,''),(350918,111889,'94693','watch','show_model_b2b','0',0,''),(350919,111889,'94693','watch','show_properties_b2b','0',0,''),(350920,111889,'94693','watch','show_rating_b2b','0',0,''),(350921,111889,'94693','watch','show_rating_counts_b2b','0',0,''),(350922,111889,'94693','watch','show_price_b2b','0',0,''),(350923,111889,'94693','watch','show_qty_input_b2b','0',0,''),(350924,111889,'94693','watch','show_view_button_b2b','0',0,''),(350925,111889,'94693','watch','show_attributes_b2b','0',0,''),(350926,111889,'94693','watch','items_on_page','9',0,''),(350927,111889,'94693','watch','col_in_row','2',0,'5240'),(350928,111889,'94693','watch','col_in_row','1',0,'5261'),(350929,111889,'94693','watch','product_names_teg','h2',0,''),(350930,111890,'94694','watch','block_type','1',0,''),(350931,111890,'94694','watch','padding-top','10',0,''),(350932,111890,'94694','watch','padding-bottom','10',0,''),(350933,111890,'94694','watch','border-bottom-width','1',0,''),(350934,111890,'94694','watch','border-bottom-color','$content-border-1',0,''),(350935,111890,'94694','watch','margin-left','0',0,''),(350936,111890,'94694','watch','margin-right','0',0,''),(350937,111891,'94695','watch','float','left',0,''),(350938,111891,'94695','watch','clear','none',0,''),(350939,111891,'94695','watch','sort_pos_3','1',0,''),(350940,111891,'94695','watch','sort_pos_4','2',0,''),(350941,111891,'94695','watch','sort_pos_10','3',0,''),(350942,111891,'94695','watch','sort_pos_9','4',0,''),(350943,111891,'94695','watch','sort_pos_11','5',0,''),(350944,111891,'94695','watch','sort_pos_12','6',0,''),(350945,111891,'94695','watch','sort_pos_14','7',0,''),(350946,111891,'94695','watch','sort_pos_13','8',0,''),(350947,111891,'94695','watch','sort_pos_8','9',0,''),(350948,111891,'94695','watch','sort_pos_7','10',0,''),(350949,111891,'94695','watch','sort_pos_2','11',0,''),(350950,111891,'94695','watch','sort_pos_1','12',0,''),(350951,111891,'94695','watch','sort_pos_6','13',0,''),(350952,111891,'94695','watch','sort_pos_5','14',0,''),(350953,111891,'94695','watch','sort_pos_0','15',0,''),(350954,111891,'94695','watch','sort_hide_10','1',0,''),(350955,111891,'94695','watch','sort_hide_9','1',0,''),(350956,111891,'94695','watch','hide_icons','1',0,''),(350957,111891,'94695','watch','sort_hide_16','1',0,''),(350958,111891,'94695','watch','sort_hide_15','1',0,''),(350959,111891,'94695','watch','sort_hide_3','0',0,''),(350960,111891,'94695','watch','sort_hide_4','0',0,''),(350961,111891,'94695','watch','sort_hide_11','1',0,''),(350962,111891,'94695','watch','sort_hide_12','1',0,''),(350963,111891,'94695','watch','sort_hide_14','1',0,''),(350964,111891,'94695','watch','sort_hide_13','1',0,''),(350965,111891,'94695','watch','sort_hide_8','0',0,''),(350966,111891,'94695','watch','sort_hide_7','0',0,''),(350967,111891,'94695','watch','sort_hide_2','1',0,''),(350968,111891,'94695','watch','sort_hide_1','1',0,''),(350969,111891,'94695','watch','sort_hide_6','1',0,''),(350970,111891,'94695','watch','sort_hide_5','1',0,''),(350971,111891,'94695','watch','sort_hide_0','1',0,''),(350972,111892,'94696','watch','float','left',0,''),(350973,111892,'94696','watch','clear','none',0,''),(350974,111892,'94696','watch','margin-left','20',0,''),(350975,111892,'94696','watch','display','none',0,'5261'),(350976,111893,'94697','watch','margin-right','20',0,''),(350977,111893,'94697','watch','float','right',0,''),(350978,111893,'94697','watch','clear','none',0,''),(350979,111893,'94697','watch','display','none',0,'5240'),(350980,111894,'94698','watch','float','right',0,''),(350981,111894,'94698','watch','display','none',0,'5261'),(350982,111895,'94699','watch','listing_type','productListing',0,''),(350983,111897,'94701','watch','block_type','5',0,''),(350984,111897,'94701','watch','padding-top','10',0,''),(350985,111897,'94701','watch','padding-bottom','10',0,''),(350986,111897,'94701','watch','schema','5-2',0,'5261'),(350987,111897,'94701','watch','border-top-color','$content-border-1',0,''),(350988,111897,'94701','watch','border-top-width','1',0,''),(350989,111899,'94703','watch','float','right',0,''),(350990,111900,'73483','watch','block_type','1',0,''),(350991,111903,'73486','watch','block_type','1',0,''),(350992,111903,'73486','watch','padding-top','10',0,''),(350993,111903,'73486','watch','padding-bottom','10',0,''),(350994,111903,'73486','watch','border-bottom-width','1',0,''),(350995,111903,'73486','watch','border-bottom-color','$content-border-1',0,''),(350996,111903,'73486','watch','margin-left','0',0,''),(350997,111903,'73486','watch','margin-right','0',0,''),(350998,111904,'73487','watch','float','left',0,''),(350999,111904,'73487','watch','clear','none',0,''),(351000,111904,'73487','watch','margin-left','20',0,''),(351001,111904,'73487','watch','display','none',0,'5261'),(351002,111905,'73488','watch','float','left',0,''),(351003,111905,'73488','watch','clear','none',0,''),(351004,111905,'73488','watch','sort_pos_3','2',0,''),(351005,111905,'73488','watch','sort_pos_4','3',0,''),(351006,111905,'73488','watch','sort_pos_10','11',0,''),(351007,111905,'73488','watch','sort_pos_9','10',0,''),(351008,111905,'73488','watch','sort_pos_11','12',0,''),(351009,111905,'73488','watch','sort_pos_12','13',0,''),(351010,111905,'73488','watch','sort_pos_14','15',0,''),(351011,111905,'73488','watch','sort_pos_13','14',0,''),(351012,111905,'73488','watch','sort_pos_8','4',0,''),(351013,111905,'73488','watch','sort_pos_7','5',0,''),(351014,111905,'73488','watch','sort_pos_2','7',0,''),(351015,111905,'73488','watch','sort_pos_1','6',0,''),(351016,111905,'73488','watch','sort_pos_6','9',0,''),(351017,111905,'73488','watch','sort_pos_5','8',0,''),(351018,111905,'73488','watch','sort_pos_0','1',0,''),(351019,111905,'73488','watch','sort_hide_10','1',0,''),(351020,111905,'73488','watch','sort_hide_9','1',0,''),(351021,111905,'73488','watch','hide_icons','1',0,''),(351022,111905,'73488','watch','sort_hide_16','1',0,''),(351023,111905,'73488','watch','sort_hide_15','1',0,''),(351024,111905,'73488','watch','sort_hide_3','0',0,''),(351025,111905,'73488','watch','sort_hide_4','0',0,''),(351026,111905,'73488','watch','sort_hide_11','1',0,''),(351027,111905,'73488','watch','sort_hide_12','1',0,''),(351028,111905,'73488','watch','sort_hide_14','1',0,''),(351029,111905,'73488','watch','sort_hide_13','1',0,''),(351030,111905,'73488','watch','sort_hide_8','0',0,''),(351031,111905,'73488','watch','sort_hide_7','0',0,''),(351032,111905,'73488','watch','sort_hide_2','1',0,''),(351033,111905,'73488','watch','sort_hide_1','1',0,''),(351034,111905,'73488','watch','sort_hide_6','1',0,''),(351035,111905,'73488','watch','sort_hide_5','1',0,''),(351036,111905,'73488','watch','sort_hide_0','0',0,''),(351037,111905,'73488','watch','sort_pos_15','16',0,''),(351038,111905,'73488','watch','sort_pos_16','17',0,''),(351039,111906,'73489','watch','margin-right','20',0,''),(351040,111906,'73489','watch','float','right',0,''),(351041,111906,'73489','watch','clear','none',0,''),(351042,111906,'73489','watch','display','none',0,'5240'),(351043,111907,'73490','watch','float','right',0,''),(351044,111907,'73490','watch','display','none',0,'5261'),(351045,111908,'73491','watch','clear','none',0,''),(351046,111908,'73491','watch','float','left',0,''),(351047,111908,'73491','watch','padding-top','3',0,''),(351048,111908,'73491','watch','padding-left','20',0,''),(351049,111909,'73492','watch','block_type','5',0,''),(351050,111909,'73492','watch','padding-top','10',0,''),(351051,111909,'73492','watch','padding-bottom','10',0,''),(351052,111909,'73492','watch','schema','5-2',0,'5261'),(351053,111909,'73492','watch','border-top-color','$content-border-1',0,''),(351054,111909,'73492','watch','border-top-width','1',0,''),(351055,111911,'73494','watch','float','right',0,''),(351056,111912,'73495','watch','col_in_row','4',0,''),(351057,111912,'73495','watch','products_align','left',0,''),(351058,111912,'73495','watch','font-weight','400',0,''),(351059,111912,'73495','watch','show_qty_input','0',0,''),(351060,111912,'73495','watch','listing_type','productListing',0,''),(351061,111912,'73495','watch','listing_type_rows','Rows',0,''),(351062,111912,'73495','watch','show_buy_button_b2b','on',0,''),(351063,111912,'73495','watch','show_wishlist_button_b2b','1',0,''),(351064,111912,'73495','watch','show_compare_b2b','1',0,''),(351065,111912,'73495','watch','show_image','0',0,''),(351066,111912,'73495','watch','show_stock','0',0,''),(351067,111912,'73495','watch','show_description','0',0,''),(351068,111912,'73495','watch','show_model','0',0,''),(351069,111912,'73495','watch','show_properties','0',0,''),(351070,111912,'73495','watch','show_rating','0',0,''),(351071,111912,'73495','watch','show_rating_counts','0',0,''),(351072,111912,'73495','watch','show_price','0',0,''),(351073,111912,'73495','watch','show_buy_button','0',0,''),(351074,111912,'73495','watch','show_view_button','0',0,''),(351075,111912,'73495','watch','show_wishlist_button','0',0,''),(351076,111912,'73495','watch','show_compare','0',0,''),(351077,111912,'73495','watch','show_name_rows','0',0,''),(351078,111912,'73495','watch','show_image_rows','0',0,''),(351079,111912,'73495','watch','show_stock_rows','0',0,''),(351080,111912,'73495','watch','show_description_rows','0',0,''),(351081,111912,'73495','watch','show_model_rows','0',0,''),(351082,111912,'73495','watch','show_properties_rows','0',0,''),(351083,111912,'73495','watch','show_rating_rows','0',0,''),(351084,111912,'73495','watch','show_rating_counts_rows','0',0,''),(351085,111912,'73495','watch','show_price_rows','0',0,''),(351086,111912,'73495','watch','show_buy_button_rows','0',0,''),(351087,111912,'73495','watch','show_qty_input_rows','0',0,''),(351088,111912,'73495','watch','show_view_button_rows','0',0,''),(351089,111912,'73495','watch','show_wishlist_button_rows','0',0,''),(351090,111912,'73495','watch','show_compare_rows','0',0,''),(351091,111912,'73495','watch','show_name_b2b','0',0,''),(351092,111912,'73495','watch','show_image_b2b','0',0,''),(351093,111912,'73495','watch','show_stock_b2b','0',0,''),(351094,111912,'73495','watch','show_description_b2b','0',0,''),(351095,111912,'73495','watch','show_model_b2b','0',0,''),(351096,111912,'73495','watch','show_properties_b2b','0',0,''),(351097,111912,'73495','watch','show_rating_b2b','0',0,''),(351098,111912,'73495','watch','show_rating_counts_b2b','0',0,''),(351099,111912,'73495','watch','show_price_b2b','0',0,''),(351100,111912,'73495','watch','show_qty_input_b2b','0',0,''),(351101,111912,'73495','watch','show_view_button_b2b','0',0,''),(351102,111912,'73495','watch','show_attributes_b2b','0',0,''),(351103,111912,'73495','watch','items_on_page','12',0,''),(351104,111912,'73495','watch','col_in_row','2',0,'5240'),(351105,111912,'73495','watch','col_in_row','1',0,'5261'),(351106,111912,'73495','watch','product_names_teg','h2',0,''),(351107,111915,'1683125852.345798','watch','block_type','1',0,''),(351108,111915,'1683125852.345798','watch','background-color','$content-bg-2',0,''),(351109,111915,'1683125852.345798','watch','padding-top','30',0,''),(351110,111915,'1683125852.345798','watch','padding-bottom','30',0,''),(351111,111915,'1683125852.345798','watch','style_class','checkout-index-wrap',0,''),(351112,111915,'1683125852.345798','watch','color','$content-color-2',0,''),(351113,111916,'1683125852.356555','watch','block_type','4',0,''),(351114,111916,'1683125852.356555','watch','schema','4-2',0,'5240'),(351115,111916,'1683125852.356555','watch','style_class','checkoutDoubleBox',0,''),(351116,111917,'1683125852.358412','watch','block_type','1',0,''),(351117,111917,'1683125852.358412','watch','padding-right','40',0,''),(351118,111917,'1683125852.358412','watch','padding-right','0',0,'5240'),(351119,111918,'1683125852.35982','watch','block_type','1',0,''),(351120,111918,'1683125852.35982','watch','background-color','$content-bg-1',0,''),(351121,111918,'1683125852.35982','watch','padding-top','30',0,''),(351122,111918,'1683125852.35982','watch','padding-left','30',0,''),(351123,111918,'1683125852.35982','watch','padding-right','30',0,''),(351124,111918,'1683125852.35982','watch','padding-bottom','30',0,''),(351125,111918,'1683125852.35982','watch','margin-bottom','20',0,''),(351126,111918,'1683125852.35982','watch','style_class','hiding-box closeable-box',0,''),(351127,111918,'1683125852.35982','watch','color','$content-color-1',0,''),(351128,111919,'1683125852.361569','watch','style_class','closeable-content',0,''),(351129,111919,'1683125852.361569','watch','padding-bottom','20',0,''),(351130,111920,'1683125852.362847','watch','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(351131,111920,'1683125852.362847','watch','style_class','closeable-heading closeable-event closed',0,''),(351132,111921,'1683125852.36485','watch','block_type','1',0,''),(351133,111921,'1683125852.36485','watch','padding-top','30',0,''),(351134,111921,'1683125852.36485','watch','padding-left','30',0,''),(351135,111921,'1683125852.36485','watch','padding-right','30',0,''),(351136,111921,'1683125852.36485','watch','padding-bottom','30',0,''),(351137,111921,'1683125852.36485','watch','margin-bottom','20',0,''),(351138,111921,'1683125852.36485','watch','background-color','$content-bg-1',0,''),(351139,111921,'1683125852.36485','watch','style_class','hiding-box closeable-box',0,''),(351140,111921,'1683125852.36485','watch','color','$content-color-1',0,''),(351141,111922,'1683125852.366422','watch','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(351142,111922,'1683125852.366422','watch','style_class','closeable-heading closeable-event closed',0,''),(351143,111923,'1683125852.367732','watch','block_type','2',0,''),(351144,111923,'1683125852.367732','watch','style_class','closeable-content',0,''),(351145,111923,'1683125852.367732','watch','schema','2-2',0,'5240'),(351146,111924,'1683125852.36968','watch','padding-right','20',0,''),(351147,111924,'1683125852.36968','watch','padding-bottom','20',0,''),(351148,111924,'1683125852.36968','watch','padding-right','0',0,'5240'),(351149,111925,'1683125852.369745','watch','padding-left','20',0,''),(351150,111925,'1683125852.369745','watch','padding-bottom','20',0,''),(351151,111925,'1683125852.369745','watch','padding-left','0',0,'5240'),(351152,111926,'1683125852.37045','watch','padding-left','20',0,''),(351153,111926,'1683125852.37045','watch','padding-bottom','20',0,''),(351154,111926,'1683125852.37045','watch','padding-left','0',0,'5240'),(351155,111927,'1683125852.371233','watch','background-color','$content-bg-1',0,''),(351156,111927,'1683125852.371233','watch','block_type','1',0,''),(351157,111927,'1683125852.371233','watch','padding-top','30',0,''),(351158,111927,'1683125852.371233','watch','padding-left','30',0,''),(351159,111927,'1683125852.371233','watch','padding-right','30',0,''),(351160,111927,'1683125852.371233','watch','padding-bottom','30',0,''),(351161,111927,'1683125852.371233','watch','margin-bottom','20',0,''),(351162,111927,'1683125852.371233','watch','style_class','hiding-box',0,''),(351163,111927,'1683125852.371233','watch','color','$content-color-1',0,''),(351164,111928,'1683125852.37350','watch','block_type','1',0,''),(351165,111928,'1683125852.37350','watch','content','\\_',0,'3'),(351166,111928,'1683125852.37350','watch','border-top-width','1',0,'3'),(351167,111928,'1683125852.37350','watch','border-top-color','#e0e0e0',0,'3'),(351168,111928,'1683125852.37350','watch','display','block',0,'3'),(351169,111928,'1683125852.37350','watch','position','absolute',0,'3'),(351170,111928,'1683125852.37350','watch','top','19',0,'3'),(351171,111928,'1683125852.37350','watch','left','0',0,'3'),(351172,111928,'1683125852.37350','watch','right','0',0,'3'),(351173,111928,'1683125852.37350','watch','margin-top','-2',0,'3'),(351174,111928,'1683125852.37350','watch','position','relative',0,''),(351175,111929,'1683125852.374899','watch','box_align','2',0,''),(351176,111929,'1683125852.374899','watch','margin-bottom','10',0,''),(351177,111929,'1683125852.374899','watch','background-color','$content-bg-1',0,''),(351178,111929,'1683125852.374899','watch','position','relative',0,''),(351179,111930,'1683125852.375685','watch','background-color','$content-bg-2',0,''),(351180,111930,'1683125852.375685','watch','padding-top','10',0,''),(351181,111930,'1683125852.375685','watch','padding-left','10',0,''),(351182,111930,'1683125852.375685','watch','padding-right','10',0,''),(351183,111930,'1683125852.375685','watch','padding-bottom','10',0,''),(351184,111930,'1683125852.375685','watch','margin-top','10',0,''),(351185,111931,'1683125852.376557','watch','block_type','2',0,''),(351186,111931,'1683125852.376557','watch','schema','2-2',0,'5240'),(351187,111932,'1683125852.377637','watch','block_type','1',0,''),(351188,111932,'1683125852.377637','watch','padding-right','20',0,''),(351189,111932,'1683125852.377637','watch','padding-left','0',0,'5240'),(351190,111932,'1683125852.377637','watch','margin-bottom','20',0,'5240'),(351191,111932,'1683125852.377637','watch','padding-right','0',0,'5240'),(351192,111933,'1683125852.378829','watch','address_in','popup',0,''),(351193,111934,'1683125852.379375','watch','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(351194,111937,'1683125852.381183','watch','block_type','1',0,''),(351195,111937,'1683125852.381183','watch','padding-left','20',0,''),(351196,111937,'1683125852.381183','watch','padding-left','0',0,'5240'),(351197,111939,'1683125852.382635','watch','border-top-width','1',0,''),(351198,111939,'1683125852.382635','watch','border-top-color','#e0e0e0',0,''),(351199,111939,'1683125852.382635','watch','padding-top','13',0,''),(351200,111939,'1683125852.382635','watch','padding-bottom','10',0,''),(351201,111940,'1683125852.383516','watch','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(351202,111941,'1683125852.385278','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(351203,111942,'1683125852.386397','watch','margin-bottom','20',0,''),(351204,111942,'1683125852.386397','watch','style_class','hiding-box',0,''),(351205,111943,'1683125852.386970','watch','padding-top','30',0,''),(351206,111943,'1683125852.386970','watch','padding-left','30',0,''),(351207,111943,'1683125852.386970','watch','padding-right','30',0,''),(351208,111943,'1683125852.386970','watch','margin-top','20',0,''),(351209,111943,'1683125852.386970','watch','background-color','$content-bg-1',0,''),(351210,111943,'1683125852.386970','watch','padding-bottom','30',0,''),(351211,111943,'1683125852.386970','watch','margin-bottom','20',0,''),(351212,111943,'1683125852.386970','watch','color','$content-color-1',0,''),(351213,111944,'1683125852.38820','watch','block_type','1',0,''),(351214,111944,'1683125852.38820','watch','padding-top','30',0,''),(351215,111944,'1683125852.38820','watch','padding-left','30',0,''),(351216,111944,'1683125852.38820','watch','padding-right','30',0,''),(351217,111944,'1683125852.38820','watch','padding-bottom','23',0,''),(351218,111944,'1683125852.38820','watch','margin-bottom','20',0,''),(351219,111944,'1683125852.38820','watch','background-color','$content-bg-1',0,''),(351220,111944,'1683125852.38820','watch','style_class','hiding-box',0,''),(351221,111944,'1683125852.38820','watch','color','$content-color-1',0,''),(351222,111945,'1683125852.390244','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(351223,111946,'1683125852.391810','watch','block_type','2',0,''),(351224,111946,'1683125852.391810','watch','schema','2-2',0,'5240'),(351225,111947,'1683125852.393320','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351226,111948,'1683125852.394747','watch','padding-right','20',0,''),(351227,111948,'1683125852.394747','watch','padding-right','0',0,'5240'),(351228,111948,'1683125852.394747','watch','padding-bottom','20',0,'5240'),(351229,111948,'1683125852.394747','watch','address_in','popup',0,''),(351230,111949,'1683125852.395767','watch','block_type','1',0,''),(351231,111949,'1683125852.395767','watch','padding-left','20',0,''),(351232,111949,'1683125852.395767','watch','padding-left','0',0,'5240'),(351233,111951,'1683125852.398588','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351234,111952,'1683125852.400291','watch','block_type','1',0,''),(351235,111952,'1683125852.400291','watch','padding-top','30',0,''),(351236,111952,'1683125852.400291','watch','padding-left','30',0,''),(351237,111952,'1683125852.400291','watch','padding-right','30',0,''),(351238,111952,'1683125852.400291','watch','padding-bottom','30',0,''),(351239,111952,'1683125852.400291','watch','margin-bottom','20',0,''),(351240,111952,'1683125852.400291','watch','background-color','$content-bg-1',0,''),(351241,111952,'1683125852.400291','watch','color','$content-color-1',0,''),(351242,111955,'1683125852.403563','watch','block_type','1',0,''),(351243,111955,'1683125852.403563','watch','padding-top','20',0,''),(351244,111955,'1683125852.403563','watch','padding-left','20',0,''),(351245,111955,'1683125852.403563','watch','padding-right','20',0,''),(351246,111955,'1683125852.403563','watch','padding-bottom','20',0,''),(351247,111955,'1683125852.403563','watch','background-color','$content-bg-1',0,''),(351248,111955,'1683125852.403563','watch','style_class','order-summary',0,''),(351249,111955,'1683125852.403563','watch','color','$content-color-1',0,''),(351250,111956,'1683125852.405625','watch','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(351251,111956,'1683125852.405625','watch','text-align','center',0,''),(351252,111956,'1683125852.405625','watch','font-size','14',0,''),(351253,111956,'1683125852.405625','watch','color','$fade-color-1',0,''),(351254,111956,'1683125852.405625','watch','padding-top','10',0,''),(351255,111957,'1683125852.407666','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(351256,111958,'1683125852.40885','watch','hide_page','1',0,''),(351257,111958,'1683125852.40885','watch','hide_continue_button','1',0,''),(351258,111959,'1683125852.409688','watch','margin-bottom','10',0,''),(351259,111962,'73542','watch','block_type','1',0,''),(351260,111963,'73543','watch','margin-top','20',0,''),(351261,111964,'73544','watch','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(351262,111965,'73545','watch','link','products',0,''),(351263,111965,'73545','watch','margin-top','-33',0,''),(351264,111965,'73545','watch','float','right',0,''),(351265,111966,'73546','watch','block_type','2',0,''),(351266,111966,'73546','watch','margin-bottom','20',0,''),(351267,111966,'73546','watch','schema','2-2',0,'5232'),(351268,111967,'73547','watch','block_type','1',0,''),(351269,111967,'73547','watch','padding-right','20',0,''),(351270,111967,'73547','watch','padding-right','0',0,'5232'),(351271,111968,'73548','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(351272,111968,'73548','watch','clear','none',0,''),(351273,111970,'73550','watch','padding-left','20',0,''),(351274,111970,'73550','watch','block_type','1',0,''),(351275,111970,'73550','watch','padding-left','0',0,'5232'),(351276,111972,'73552','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351277,111972,'73552','watch','clear','none',0,''),(351278,111973,'73553','watch','text-align','right',0,''),(351279,111973,'73553','watch','margin-bottom','20',0,''),(351280,111973,'73553','watch','margin-top','20',0,''),(351281,111974,'73554','watch','block_type','2',0,''),(351282,111974,'73554','watch','margin-bottom','20',0,''),(351283,111974,'73554','watch','schema','2-2',0,'5232'),(351284,111975,'73555','watch','block_type','1',0,''),(351285,111975,'73555','watch','padding-right','20',0,''),(351286,111975,'73555','watch','padding-right','0',0,'5232'),(351287,111977,'73557','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(351288,111977,'73557','watch','clear','none',0,''),(351289,111978,'73558','watch','block_type','1',0,''),(351290,111978,'73558','watch','padding-left','20',0,''),(351291,111978,'73558','watch','padding-left','0',0,'5232'),(351292,111979,'73559','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351293,111979,'73559','watch','clear','none',0,''),(351294,111981,'73561','watch','margin-bottom','20',0,''),(351295,111981,'73561','watch','text-align','right',0,''),(351296,111983,'73576','watch','block_type','1',0,''),(351297,111984,'73577','watch','text-align','right',0,''),(351298,111984,'73577','watch','margin-bottom','20',0,''),(351299,111985,'73578','watch','block_type','2',0,''),(351300,111985,'73578','watch','margin-bottom','20',0,''),(351301,111985,'73578','watch','schema','2-2',0,'5232'),(351302,111986,'73579','watch','block_type','1',0,''),(351303,111986,'73579','watch','padding-right','20',0,''),(351304,111986,'73579','watch','padding-right','0',0,'5232'),(351305,111987,'73580','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351306,111987,'73580','watch','clear','none',0,''),(351307,111989,'73582','watch','block_type','1',0,''),(351308,111989,'73582','watch','padding-left','20',0,''),(351309,111989,'73582','watch','padding-left','0',0,'5232'),(351310,111990,'73583','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351311,111990,'73583','watch','clear','none',0,''),(351312,111992,'73585','watch','margin-bottom','20',0,''),(351313,111992,'73585','watch','text-align','right',0,''),(351314,111995,'73588','watch','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(351315,111996,'73563','watch','block_type','1',0,''),(351316,111997,'73564','watch','margin-bottom','20',0,''),(351317,111998,'73565','watch','margin-bottom','20',0,''),(351318,111998,'73565','watch','text-align','right',0,''),(351319,111999,'73566','watch','text-align','right',0,''),(351320,111999,'73566','watch','margin-bottom','20',0,''),(351321,112000,'73567','watch','block_type','2',0,''),(351322,112000,'73567','watch','margin-bottom','20',0,''),(351323,112000,'73567','watch','schema','2-2',0,'5232'),(351324,112001,'73568','watch','block_type','1',0,''),(351325,112001,'73568','watch','padding-right','20',0,''),(351326,112001,'73568','watch','padding-right','0',0,'5232'),(351327,112003,'73570','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351328,112003,'73570','watch','clear','none',0,''),(351329,112004,'73571','watch','block_type','1',0,''),(351330,112004,'73571','watch','padding-left','20',0,''),(351331,112004,'73571','watch','padding-left','0',0,'5232'),(351332,112006,'73573','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351333,112006,'73573','watch','clear','none',0,''),(351334,112007,'73574','watch','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(351335,112008,'73575','watch','margin-bottom','20',0,''),(351336,112009,'73589','watch','block_type','1',0,''),(351337,112010,'73590','watch','block_type','2',0,''),(351338,112010,'73590','watch','margin-bottom','20',0,''),(351339,112010,'73590','watch','schema','2-2',0,'5232'),(351340,112011,'73591','watch','block_type','1',0,''),(351341,112011,'73591','watch','padding-right','20',0,''),(351342,112011,'73591','watch','padding-right','0',0,'5232'),(351343,112013,'73593','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(351344,112013,'73593','watch','clear','none',0,''),(351345,112014,'73594','watch','block_type','1',0,''),(351346,112014,'73594','watch','padding-left','20',0,''),(351347,112014,'73594','watch','padding-left','0',0,'5232'),(351348,112016,'73596','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351349,112016,'73596','watch','clear','none',0,''),(351350,112017,'73597','watch','margin-bottom','20',0,''),(351351,112018,'73598','watch','margin-bottom','20',0,''),(351352,112019,'73599','watch','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(351353,112020,'73600','watch','link','products',0,''),(351354,112020,'73600','watch','margin-top','-33',0,''),(351355,112020,'73600','watch','float','right',0,''),(351356,112021,'73601','watch','text-align','right',0,''),(351357,112021,'73601','watch','margin-bottom','20',0,''),(351358,112022,'73602','watch','margin-bottom','20',0,''),(351359,112022,'73602','watch','text-align','right',0,''),(351360,112023,'73603','watch','block_type','2',0,''),(351361,112023,'73603','watch','margin-bottom','20',0,''),(351362,112023,'73603','watch','schema','2-2',0,'5232'),(351363,112024,'73604','watch','block_type','1',0,''),(351364,112024,'73604','watch','padding-right','20',0,''),(351365,112024,'73604','watch','padding-right','0',0,'5232'),(351366,112025,'73605','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(351367,112025,'73605','watch','clear','none',0,''),(351368,112027,'73607','watch','padding-left','20',0,''),(351369,112027,'73607','watch','block_type','1',0,''),(351370,112027,'73607','watch','padding-left','0',0,'5232'),(351371,112028,'73608','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351372,112028,'73608','watch','clear','none',0,''),(351373,112030,'73610','watch','text','##TEXT_CONFIRMATION##',0,''),(351374,112031,'73611','watch','text','##TEXT_CONFIRMATION##',0,''),(351375,112032,'73613','watch','text','##TEXT_CONFIRMATION##',0,''),(351376,112033,'73612','watch','text','##TEXT_CONFIRMATION##',0,''),(351377,112034,'73614','watch','text','##TEXT_CONFIRMATION##',0,''),(351378,112035,'73615','watch','text','##TEXT_CONFIRMATION##',0,''),(351379,112036,'73616','watch','block_type','2',0,''),(351380,112037,'73617','watch','block_type','1',0,''),(351381,112037,'73617','watch','padding-right','20',0,''),(351382,112038,'73618','watch','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(351383,112040,'73620','watch','block_type','1',0,''),(351384,112040,'73620','watch','padding-left','20',0,''),(351385,112040,'73620','watch','padding-left','0',0,'5240'),(351386,112041,'73621','watch','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(351387,112043,'73623','watch','block_type','4',0,''),(351388,112043,'73623','watch','schema','4-2',0,'5261'),(351389,112043,'73623','watch','padding-top','20',0,''),(351390,112044,'73624','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351391,112044,'73624','watch','text-align','right',0,''),(351392,112044,'73624','watch','padding-top','10',0,''),(351393,112044,'73624','watch','font_size_measure','em',0,''),(351394,112044,'73624','watch','font-size','1.2',0,''),(351395,112045,'73625','watch','text-align','right',0,''),(351396,112046,'73626','watch','block_type','2',0,''),(351397,112047,'73627','watch','block_type','1',0,''),(351398,112047,'73627','watch','padding-right','20',0,''),(351399,112047,'73627','watch','padding-right','0',0,'5240'),(351400,112048,'73628','watch','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(351401,112050,'73630','watch','block_type','1',0,''),(351402,112050,'73630','watch','padding-right','0',0,'5240'),(351403,112050,'73630','watch','padding-left','20',0,''),(351404,112053,'73633','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(351405,112055,'73635','watch','block_type','2',0,''),(351406,112056,'73636','watch','block_type','1',0,''),(351407,112056,'73636','watch','padding-right','20',0,''),(351408,112058,'73638','watch','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(351409,112059,'73639','watch','block_type','1',0,''),(351410,112059,'73639','watch','padding-left','20',0,''),(351411,112059,'73639','watch','padding-left','0',0,'5240'),(351412,112060,'73640','watch','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(351413,112062,'73642','watch','block_type','4',0,''),(351414,112062,'73642','watch','schema','4-2',0,'5261'),(351415,112063,'73643','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351416,112063,'73643','watch','text-align','right',0,''),(351417,112063,'73643','watch','padding-top','10',0,''),(351418,112063,'73643','watch','font_size_measure','em',0,''),(351419,112063,'73643','watch','font-size','1.2',0,''),(351420,112064,'73644','watch','text-align','right',0,''),(351421,112065,'73645','watch','block_type','2',0,''),(351422,112066,'73646','watch','block_type','1',0,''),(351423,112066,'73646','watch','padding-right','20',0,''),(351424,112066,'73646','watch','padding-right','0',0,'5240'),(351425,112068,'73648','watch','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(351426,112069,'73649','watch','block_type','1',0,''),(351427,112069,'73649','watch','padding-right','0',0,'5240'),(351428,112069,'73649','watch','padding-left','20',0,''),(351429,112071,'73651','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(351430,112074,'73654','watch','block_type','4',0,''),(351431,112074,'73654','watch','schema','4-2',0,'5261'),(351432,112075,'73655','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351433,112075,'73655','watch','text-align','right',0,''),(351434,112075,'73655','watch','padding-top','10',0,''),(351435,112075,'73655','watch','font_size_measure','em',0,''),(351436,112075,'73655','watch','font-size','1.2',0,''),(351437,112076,'73656','watch','text-align','right',0,''),(351438,112077,'73657','watch','block_type','2',0,''),(351439,112078,'73658','watch','block_type','1',0,''),(351440,112078,'73658','watch','padding-right','20',0,''),(351441,112080,'73660','watch','block_type','1',0,''),(351442,112080,'73660','watch','padding-left','20',0,''),(351443,112080,'73660','watch','padding-left','0',0,'5240'),(351444,112081,'73661','watch','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(351445,112083,'73663','watch','block_type','4',0,''),(351446,112083,'73663','watch','schema','4-2',0,'5261'),(351447,112084,'73664','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351448,112084,'73664','watch','text-align','right',0,''),(351449,112084,'73664','watch','padding-top','10',0,''),(351450,112084,'73664','watch','font_size_measure','em',0,''),(351451,112084,'73664','watch','font-size','1.2',0,''),(351452,112085,'73665','watch','text-align','right',0,''),(351453,112086,'73666','watch','block_type','2',0,''),(351454,112087,'73667','watch','block_type','1',0,''),(351455,112087,'73667','watch','padding-right','20',0,''),(351456,112089,'73669','watch','block_type','1',0,''),(351457,112089,'73669','watch','padding-left','20',0,''),(351458,112089,'73669','watch','padding-left','0',0,'5240'),(351459,112091,'73671','watch','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(351460,112092,'73672','watch','text','##DELIVERY_DETAILS##',0,''),(351461,112093,'73673','watch','text','##DELIVERY_DETAILS##',0,''),(351462,112094,'73675','watch','text','##CONTACT_INFORMATION##',0,''),(351463,112095,'73674','watch','text','##CONTACT_INFORMATION##',0,''),(351464,112096,'73676','watch','text','##DELIVERY_DETAILS##',0,''),(351465,112097,'73677','watch','text','##DELIVERY_DETAILS##',0,''),(351466,112098,'73678','watch','block_type','1',0,''),(351467,112098,'73678','watch','background-color','$content-bg-2',0,''),(351468,112098,'73678','watch','padding-top','30',0,''),(351469,112098,'73678','watch','padding-bottom','30',0,''),(351470,112099,'73679','watch','block_type','4',0,''),(351471,112099,'73679','watch','schema','4-2',0,'5240'),(351472,112100,'73680','watch','block_type','1',0,''),(351473,112100,'73680','watch','padding-right','40',0,''),(351474,112100,'73680','watch','padding-right','0',0,'5240'),(351475,112101,'73682','watch','block_type','1',0,''),(351476,112101,'73682','watch','background-color','$content-bg-1',0,''),(351477,112101,'73682','watch','padding-top','30',0,''),(351478,112101,'73682','watch','padding-left','30',0,''),(351479,112101,'73682','watch','padding-right','30',0,''),(351480,112101,'73682','watch','padding-bottom','30',0,''),(351481,112101,'73682','watch','margin-bottom','20',0,''),(351482,112101,'73682','watch','style_class','hiding-box',0,''),(351483,112102,'73683','watch','margin-bottom','20',0,''),(351484,112103,'73684','watch','padding-top','10',0,''),(351485,112103,'73684','watch','padding-left','20',0,''),(351486,112103,'73684','watch','padding-right','20',0,''),(351487,112103,'73684','watch','margin-top','20',0,''),(351488,112103,'73684','watch','background-color','$content-bg-2',0,''),(351489,112103,'73684','watch','padding-bottom','8',0,''),(351490,112104,'73685','watch','block_type','1',0,''),(351491,112104,'73685','watch','background-color','$content-bg-1',0,''),(351492,112104,'73685','watch','padding-top','30',0,''),(351493,112104,'73685','watch','padding-left','30',0,''),(351494,112104,'73685','watch','padding-right','30',0,''),(351495,112104,'73685','watch','padding-bottom','14',0,''),(351496,112104,'73685','watch','margin-bottom','20',0,''),(351497,112104,'73685','watch','style_class','hiding-box closeable-box',0,''),(351498,112105,'73686','watch','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(351499,112105,'73686','watch','style_class','closeable-heading closeable-event closed',0,''),(351500,112106,'73687','watch','style_class','closeable-content',0,''),(351501,112106,'73687','watch','padding-bottom','20',0,''),(351502,112107,'73688','watch','background-color','$content-bg-1',0,''),(351503,112107,'73688','watch','block_type','1',0,''),(351504,112107,'73688','watch','padding-top','30',0,''),(351505,112107,'73688','watch','padding-left','30',0,''),(351506,112107,'73688','watch','padding-right','30',0,''),(351507,112107,'73688','watch','padding-bottom','30',0,''),(351508,112107,'73688','watch','margin-bottom','20',0,''),(351509,112107,'73688','watch','style_class','hiding-box',0,''),(351510,112108,'73689','watch','block_type','1',0,''),(351511,112108,'73689','watch','content','\\_',0,'3'),(351512,112108,'73689','watch','border-top-width','1',0,'3'),(351513,112108,'73689','watch','border-top-color','$content-border-1',0,'3'),(351514,112108,'73689','watch','display','block',0,'3'),(351515,112108,'73689','watch','position','absolute',0,'3'),(351516,112108,'73689','watch','top','19',0,'3'),(351517,112108,'73689','watch','left','0',0,'3'),(351518,112108,'73689','watch','right','0',0,'3'),(351519,112108,'73689','watch','margin-top','-2',0,'3'),(351520,112108,'73689','watch','position','relative',0,''),(351521,112109,'73690','watch','box_align','2',0,''),(351522,112109,'73690','watch','margin-bottom','10',0,''),(351523,112109,'73690','watch','background-color','$content-bg-1',0,''),(351524,112109,'73690','watch','position','relative',0,''),(351525,112110,'73691','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(351526,112111,'73692','watch','block_type','2',0,''),(351527,112111,'73692','watch','schema','2-2',0,'5240'),(351528,112112,'73693','watch','block_type','1',0,''),(351529,112112,'73693','watch','padding-right','20',0,''),(351530,112112,'73693','watch','padding-left','0',0,'5240'),(351531,112112,'73693','watch','margin-bottom','20',0,'5240'),(351532,112115,'73696','watch','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(351533,112116,'73697','watch','block_type','1',0,''),(351534,112116,'73697','watch','padding-left','20',0,''),(351535,112116,'73697','watch','padding-left','0',0,'5240'),(351536,112117,'73698','watch','border-top-width','1',0,''),(351537,112117,'73698','watch','border-top-color','$content-border-1',0,''),(351538,112117,'73698','watch','padding-top','13',0,''),(351539,112117,'73698','watch','padding-bottom','10',0,''),(351540,112118,'73699','watch','background-color','$content-bg-2',0,''),(351541,112118,'73699','watch','padding-top','10',0,''),(351542,112118,'73699','watch','padding-left','10',0,''),(351543,112118,'73699','watch','padding-right','10',0,''),(351544,112118,'73699','watch','padding-bottom','10',0,''),(351545,112118,'73699','watch','margin-top','10',0,''),(351546,112119,'73700','watch','block_type','1',0,''),(351547,112119,'73700','watch','padding-top','20',0,''),(351548,112119,'73700','watch','padding-left','20',0,''),(351549,112119,'73700','watch','padding-right','20',0,''),(351550,112119,'73700','watch','padding-bottom','20',0,''),(351551,112119,'73700','watch','background-color','$content-bg-1',0,''),(351552,112119,'73700','watch','style_class','order-summary',0,''),(351553,112120,'73701','watch','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(351554,112120,'73701','watch','text-align','center',0,''),(351555,112120,'73701','watch','font-size','14',0,''),(351556,112120,'73701','watch','color','$fade-color-1',0,''),(351557,112120,'73701','watch','padding-top','10',0,''),(351558,112122,'115999','watch','hide_continue_button','1',0,''),(351559,112123,'73703','watch','block_type','1',0,''),(351560,112123,'73703','watch','background-color','$content-bg-2',0,''),(351561,112123,'73703','watch','padding-top','30',0,''),(351562,112123,'73703','watch','padding-bottom','30',0,''),(351563,112123,'73703','watch','color','$content-color-2',0,''),(351564,112124,'73704','watch','block_type','4',0,''),(351565,112125,'73705','watch','block_type','1',0,''),(351566,112125,'73705','watch','padding-right','40',0,''),(351567,112126,'73706','watch','block_type','1',0,''),(351568,112126,'73706','watch','background-color','$content-bg-1',0,''),(351569,112126,'73706','watch','padding-top','30',0,''),(351570,112126,'73706','watch','padding-left','30',0,''),(351571,112126,'73706','watch','padding-right','30',0,''),(351572,112126,'73706','watch','padding-bottom','30',0,''),(351573,112126,'73706','watch','margin-bottom','20',0,''),(351574,112126,'73706','watch','style_class','hiding-box',0,''),(351575,112126,'73706','watch','color','$content-color-1',0,''),(351576,112127,'73707','watch','padding-top','10',0,''),(351577,112127,'73707','watch','padding-left','20',0,''),(351578,112127,'73707','watch','padding-right','20',0,''),(351579,112127,'73707','watch','margin-top','20',0,''),(351580,112127,'73707','watch','background-color','$content-bg-2',0,''),(351581,112127,'73707','watch','padding-bottom','8',0,''),(351582,112127,'73707','watch','color','$content-color-2',0,''),(351583,112128,'73708','watch','margin-bottom','20',0,''),(351584,112129,'73709','watch','block_type','1',0,''),(351585,112129,'73709','watch','padding-top','30',0,''),(351586,112129,'73709','watch','padding-left','30',0,''),(351587,112129,'73709','watch','padding-right','30',0,''),(351588,112129,'73709','watch','padding-bottom','23',0,''),(351589,112129,'73709','watch','margin-bottom','20',0,''),(351590,112129,'73709','watch','background-color','$content-bg-1',0,''),(351591,112129,'73709','watch','style_class','hiding-box',0,''),(351592,112129,'73709','watch','color','$content-color-1',0,''),(351593,112130,'73710','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(351594,112131,'73711','watch','block_type','2',0,''),(351595,112132,'73712','watch','padding-right','20',0,''),(351596,112133,'73713','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351597,112134,'73714','watch','block_type','1',0,''),(351598,112134,'73714','watch','padding-left','20',0,''),(351599,112135,'73715','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351600,112137,'73717','watch','block_type','1',0,''),(351601,112137,'73717','watch','padding-top','30',0,''),(351602,112137,'73717','watch','padding-left','30',0,''),(351603,112137,'73717','watch','padding-right','30',0,''),(351604,112137,'73717','watch','padding-bottom','14',0,''),(351605,112137,'73717','watch','margin-bottom','20',0,''),(351606,112137,'73717','watch','background-color','$content-bg-1',0,''),(351607,112137,'73717','watch','style_class','hiding-box closeable-box',0,''),(351608,112137,'73717','watch','color','$content-color-1',0,''),(351609,112138,'73718','watch','block_type','2',0,''),(351610,112138,'73718','watch','style_class','closeable-content',0,''),(351611,112139,'73719','watch','padding-right','20',0,''),(351612,112139,'73719','watch','padding-bottom','20',0,''),(351613,112140,'73720','watch','padding-left','20',0,''),(351614,112140,'73720','watch','padding-bottom','20',0,''),(351615,112141,'73721','watch','padding-left','20',0,''),(351616,112141,'73721','watch','padding-bottom','20',0,''),(351617,112142,'73722','watch','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(351618,112142,'73722','watch','style_class','closeable-heading closeable-event closed',0,''),(351619,112143,'73723','watch','block_type','1',0,''),(351620,112143,'73723','watch','background-color','$content-bg-1',0,''),(351621,112143,'73723','watch','padding-top','30',0,''),(351622,112143,'73723','watch','padding-left','30',0,''),(351623,112143,'73723','watch','padding-right','30',0,''),(351624,112143,'73723','watch','padding-bottom','14',0,''),(351625,112143,'73723','watch','margin-bottom','20',0,''),(351626,112143,'73723','watch','style_class','hiding-box closeable-box',0,''),(351627,112143,'73723','watch','color','$content-color-1',0,''),(351628,112144,'73724','watch','style_class','closeable-content',0,''),(351629,112144,'73724','watch','padding-bottom','20',0,''),(351630,112145,'73725','watch','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(351631,112145,'73725','watch','style_class','closeable-heading closeable-event closed',0,''),(351632,112146,'73726','watch','block_type','1',0,''),(351633,112146,'73726','watch','padding-top','20',0,''),(351634,112146,'73726','watch','padding-left','20',0,''),(351635,112146,'73726','watch','padding-right','20',0,''),(351636,112146,'73726','watch','padding-bottom','20',0,''),(351637,112146,'73726','watch','background-color','$content-bg-1',0,''),(351638,112146,'73726','watch','style_class','order-summary hiding-box',0,''),(351639,112146,'73726','watch','color','$content-color-1',0,''),(351640,112147,'73727','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(351641,112148,'73728','watch','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(351642,112148,'73728','watch','text-align','center',0,''),(351643,112148,'73728','watch','font-size','14',0,''),(351644,112148,'73728','watch','color','$fade-color-1',0,''),(351645,112148,'73728','watch','padding-top','10',0,''),(351646,112149,'73729','watch','margin-bottom','10',0,''),(351647,112151,'73731','watch','hide_page','1',0,''),(351648,112151,'73731','watch','hide_continue_button','1',0,''),(351649,112152,'73732','watch','block_type','1',0,''),(351650,112154,'73734','watch','block_type','4',0,''),(351651,112154,'73734','watch','schema','4-2',0,'5261'),(351652,112155,'73735','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351653,112155,'73735','watch','text-align','right',0,''),(351654,112155,'73735','watch','padding-top','10',0,''),(351655,112155,'73735','watch','font_size_measure','em',0,''),(351656,112155,'73735','watch','font-size','1.2',0,''),(351657,112156,'73736','watch','text-align','right',0,''),(351658,112157,'73737','watch','block_type','2',0,''),(351659,112157,'73737','watch','schema','2-2',0,'5240'),(351660,112158,'73738','watch','block_type','1',0,''),(351661,112158,'73738','watch','padding-right','20',0,''),(351662,112158,'73738','watch','padding-right','0',0,'5240'),(351663,112160,'73740','watch','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(351664,112161,'73741','watch','block_type','1',0,''),(351665,112161,'73741','watch','padding-left','20',0,''),(351666,112161,'73741','watch','padding-left','0',0,'5240'),(351667,112163,'73743','watch','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(351668,112164,'73744','watch','block_type','2',0,''),(351669,112164,'73744','watch','schema','2-2',0,'5240'),(351670,112165,'73745','watch','block_type','1',0,''),(351671,112165,'73745','watch','padding-right','20',0,''),(351672,112165,'73745','watch','padding-right','0',0,'5240'),(351673,112166,'73746','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351674,112168,'73748','watch','block_type','1',0,''),(351675,112168,'73748','watch','padding-left','20',0,''),(351676,112168,'73748','watch','padding-left','0',0,'5240'),(351677,112173,'73753','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351678,112174,'73754','watch','margin-bottom','20',0,''),(351679,112175,'73755','watch','block_type','1',0,''),(351680,112175,'73755','watch','background-color','$content-bg-2',0,''),(351681,112175,'73755','watch','padding-top','30',0,''),(351682,112175,'73755','watch','padding-bottom','30',0,''),(351683,112176,'73756','watch','block_type','4',0,''),(351684,112176,'73756','watch','schema','4-2',0,'5240'),(351685,112177,'73757','watch','block_type','1',0,''),(351686,112177,'73757','watch','padding-right','40',0,''),(351687,112177,'73757','watch','padding-right','0',0,'5240'),(351688,112178,'73758','watch','background-color','$content-bg-1',0,''),(351689,112178,'73758','watch','padding-top','30',0,''),(351690,112178,'73758','watch','padding-left','30',0,''),(351691,112178,'73758','watch','padding-right','30',0,''),(351692,112178,'73758','watch','padding-bottom','30',0,''),(351693,112178,'73758','watch','margin-bottom','20',0,''),(351694,112179,'73759','watch','block_type','1',0,''),(351695,112179,'73759','watch','background-color','$content-bg-1',0,''),(351696,112179,'73759','watch','padding-top','30',0,''),(351697,112179,'73759','watch','padding-left','30',0,''),(351698,112179,'73759','watch','padding-right','30',0,''),(351699,112179,'73759','watch','padding-bottom','14',0,''),(351700,112179,'73759','watch','margin-bottom','20',0,''),(351701,112179,'73759','watch','style_class','hiding-box closeable-box',0,''),(351702,112180,'73760','watch','style_class','closeable-content',0,''),(351703,112180,'73760','watch','padding-bottom','20',0,''),(351704,112181,'73761','watch','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(351705,112181,'73761','watch','style_class','closeable-heading closeable-event closed',0,''),(351706,112182,'73762','watch','block_type','1',0,''),(351707,112182,'73762','watch','background-color','$content-bg-1',0,''),(351708,112182,'73762','watch','padding-top','30',0,''),(351709,112182,'73762','watch','padding-left','30',0,''),(351710,112182,'73762','watch','padding-right','30',0,''),(351711,112182,'73762','watch','padding-bottom','30',0,''),(351712,112182,'73762','watch','margin-bottom','20',0,''),(351713,112182,'73762','watch','style_class','hiding-box',0,''),(351714,112183,'73763','watch','padding-top','10',0,''),(351715,112183,'73763','watch','padding-left','20',0,''),(351716,112183,'73763','watch','padding-right','20',0,''),(351717,112183,'73763','watch','margin-top','20',0,''),(351718,112183,'73763','watch','background-color','$content-bg-2',0,''),(351719,112183,'73763','watch','padding-bottom','8',0,''),(351720,112184,'73764','watch','margin-bottom','20',0,''),(351721,112185,'73765','watch','block_type','1',0,''),(351722,112185,'73765','watch','padding-top','30',0,''),(351723,112185,'73765','watch','padding-left','30',0,''),(351724,112185,'73765','watch','padding-right','30',0,''),(351725,112185,'73765','watch','padding-bottom','23',0,''),(351726,112185,'73765','watch','margin-bottom','20',0,''),(351727,112185,'73765','watch','background-color','$content-bg-1',0,''),(351728,112185,'73765','watch','style_class','hiding-box',0,''),(351729,112186,'73766','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(351730,112187,'73767','watch','block_type','2',0,''),(351731,112187,'73767','watch','schema','2-2',0,'5240'),(351732,112188,'73768','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351733,112189,'73769','watch','padding-right','20',0,''),(351734,112189,'73769','watch','padding-right','0',0,'5240'),(351735,112189,'73769','watch','padding-bottom','20',0,'5240'),(351736,112190,'73770','watch','block_type','1',0,''),(351737,112190,'73770','watch','padding-left','20',0,''),(351738,112190,'73770','watch','padding-left','0',0,'5240'),(351739,112192,'73772','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351740,112193,'73773','watch','block_type','1',0,''),(351741,112193,'73773','watch','padding-top','20',0,''),(351742,112193,'73773','watch','padding-left','20',0,''),(351743,112193,'73773','watch','padding-right','20',0,''),(351744,112193,'73773','watch','padding-bottom','20',0,''),(351745,112193,'73773','watch','background-color','$content-bg-1',0,''),(351746,112193,'73773','watch','style_class','order-summary',0,''),(351747,112195,'73775','watch','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(351748,112195,'73775','watch','text-align','center',0,''),(351749,112195,'73775','watch','font-size','14',0,''),(351750,112195,'73775','watch','color','$fade-color-1',0,''),(351751,112195,'73775','watch','padding-top','10',0,''),(351752,112196,'73776','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(351753,112197,'73777','watch','margin-bottom','10',0,''),(351754,112198,'73778','watch','block_type','2',0,''),(351755,112199,'73779','watch','block_type','1',0,''),(351756,112199,'73779','watch','padding-left','0',0,'5240'),(351757,112199,'73779','watch','padding-right','20',0,''),(351758,112201,'73781','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351759,112202,'73782','watch','block_type','1',0,''),(351760,112202,'73782','watch','padding-left','20',0,''),(351761,112202,'73782','watch','padding-left','0',0,'5240'),(351762,112207,'73787','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351763,112208,'73788','watch','block_type','4',0,''),(351764,112208,'73788','watch','schema','4-2',0,'5261'),(351765,112208,'73788','watch','padding-top','20',0,''),(351766,112209,'73789','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351767,112209,'73789','watch','text-align','right',0,''),(351768,112209,'73789','watch','padding-top','10',0,''),(351769,112209,'73789','watch','font_size_measure','em',0,''),(351770,112209,'73789','watch','font-size','1.2',0,''),(351771,112210,'73790','watch','text-align','right',0,''),(351772,112211,'73791','watch','block_type','2',0,''),(351773,112212,'73792','watch','block_type','1',0,''),(351774,112212,'73792','watch','padding-left','0',0,'5240'),(351775,112212,'73792','watch','padding-right','20',0,''),(351776,112214,'73794','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351777,112215,'73795','watch','block_type','1',0,''),(351778,112215,'73795','watch','padding-left','20',0,''),(351779,112215,'73795','watch','padding-left','0',0,'5240'),(351780,112217,'73797','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351781,112221,'73801','watch','block_type','4',0,''),(351782,112221,'73801','watch','schema','4-2',0,'5261'),(351783,112222,'73802','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351784,112222,'73802','watch','text-align','right',0,''),(351785,112222,'73802','watch','padding-top','10',0,''),(351786,112222,'73802','watch','font_size_measure','em',0,''),(351787,112222,'73802','watch','font-size','1.2',0,''),(351788,112223,'73803','watch','text-align','right',0,''),(351789,112224,'73804','watch','block_type','4',0,''),(351790,112224,'73804','watch','schema','4-2',0,'5261'),(351791,112225,'73805','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351792,112225,'73805','watch','text-align','right',0,''),(351793,112225,'73805','watch','padding-top','10',0,''),(351794,112225,'73805','watch','font_size_measure','em',0,''),(351795,112225,'73805','watch','font-size','1.2',0,''),(351796,112226,'73806','watch','text-align','right',0,''),(351797,112227,'73807','watch','block_type','2',0,''),(351798,112228,'73808','watch','block_type','1',0,''),(351799,112228,'73808','watch','padding-left','0',0,'5240'),(351800,112228,'73808','watch','padding-right','20',0,''),(351801,112229,'73809','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351802,112231,'73811','watch','block_type','1',0,''),(351803,112231,'73811','watch','padding-left','20',0,''),(351804,112231,'73811','watch','padding-left','0',0,'5240'),(351805,112236,'73816','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351806,112237,'73817','watch','block_type','4',0,''),(351807,112237,'73817','watch','schema','4-2',0,'5261'),(351808,112238,'73818','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351809,112238,'73818','watch','text-align','right',0,''),(351810,112238,'73818','watch','padding-top','10',0,''),(351811,112238,'73818','watch','font_size_measure','em',0,''),(351812,112238,'73818','watch','font-size','1.2',0,''),(351813,112239,'73819','watch','text-align','right',0,''),(351814,112240,'73820','watch','block_type','2',0,''),(351815,112241,'73821','watch','block_type','1',0,''),(351816,112241,'73821','watch','padding-left','0',0,'5240'),(351817,112241,'73821','watch','padding-right','20',0,''),(351818,112243,'73823','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351819,112244,'73824','watch','block_type','1',0,''),(351820,112244,'73824','watch','padding-left','20',0,''),(351821,112244,'73824','watch','padding-left','0',0,'5240'),(351822,112248,'73828','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351823,112250,'73830','watch','text','##PAYMENT_DETAILS##',0,''),(351824,112251,'73831','watch','text','##PAYMENT_DETAILS##',0,''),(351825,112252,'73832','watch','text','##PAYMENT_DETAILS##',0,''),(351826,112253,'73833','watch','text','##PAYMENT_DETAILS##',0,''),(351827,112254,'73834','watch','text','##PAYMENT_DETAILS##',0,''),(351828,112255,'73835','watch','text','##PAYMENT_DETAILS##',0,''),(351829,112256,'73836','watch','block_type','1',0,''),(351830,112256,'73836','watch','background-color','$content-bg-2',0,''),(351831,112256,'73836','watch','padding-top','30',0,''),(351832,112256,'73836','watch','padding-bottom','30',0,''),(351833,112257,'73837','watch','block_type','4',0,''),(351834,112257,'73837','watch','schema','4-2',0,'5240'),(351835,112258,'73838','watch','block_type','1',0,''),(351836,112258,'73838','watch','padding-right','40',0,''),(351837,112258,'73838','watch','padding-right','0',0,'5240'),(351838,112259,'73839','watch','block_type','1',0,''),(351839,112259,'73839','watch','background-color','$content-bg-1',0,''),(351840,112259,'73839','watch','padding-top','30',0,''),(351841,112259,'73839','watch','padding-left','30',0,''),(351842,112259,'73839','watch','padding-right','30',0,''),(351843,112259,'73839','watch','padding-bottom','30',0,''),(351844,112259,'73839','watch','margin-bottom','20',0,''),(351845,112259,'73839','watch','style_class','hiding-box',0,''),(351846,112260,'73840','watch','padding-top','10',0,''),(351847,112260,'73840','watch','padding-left','20',0,''),(351848,112260,'73840','watch','padding-right','20',0,''),(351849,112260,'73840','watch','margin-top','20',0,''),(351850,112260,'73840','watch','background-color','$content-bg-2',0,''),(351851,112260,'73840','watch','padding-bottom','8',0,''),(351852,112261,'73841','watch','margin-bottom','20',0,''),(351853,112262,'73842','watch','background-color','$content-bg-1',0,''),(351854,112262,'73842','watch','block_type','1',0,''),(351855,112262,'73842','watch','padding-top','30',0,''),(351856,112262,'73842','watch','padding-left','30',0,''),(351857,112262,'73842','watch','padding-right','30',0,''),(351858,112262,'73842','watch','padding-bottom','30',0,''),(351859,112262,'73842','watch','margin-bottom','20',0,''),(351860,112262,'73842','watch','style_class','hiding-box',0,''),(351861,112263,'73843','watch','block_type','1',0,''),(351862,112263,'73843','watch','content','\\_',0,'3'),(351863,112263,'73843','watch','border-top-width','1',0,'3'),(351864,112263,'73843','watch','border-top-color','$content-border-1',0,'3'),(351865,112263,'73843','watch','display','block',0,'3'),(351866,112263,'73843','watch','position','absolute',0,'3'),(351867,112263,'73843','watch','top','19',0,'3'),(351868,112263,'73843','watch','left','0',0,'3'),(351869,112263,'73843','watch','right','0',0,'3'),(351870,112263,'73843','watch','margin-top','-2',0,'3'),(351871,112263,'73843','watch','position','relative',0,''),(351872,112264,'73844','watch','box_align','2',0,''),(351873,112264,'73844','watch','margin-bottom','10',0,''),(351874,112264,'73844','watch','background-color','$content-bg-1',0,''),(351875,112264,'73844','watch','position','relative',0,''),(351876,112265,'73845','watch','background-color','$content-bg-2',0,''),(351877,112265,'73845','watch','padding-top','10',0,''),(351878,112265,'73845','watch','padding-left','10',0,''),(351879,112265,'73845','watch','padding-right','10',0,''),(351880,112265,'73845','watch','padding-bottom','10',0,''),(351881,112265,'73845','watch','margin-top','10',0,''),(351882,112266,'73846','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(351883,112267,'73847','watch','block_type','2',0,''),(351884,112267,'73847','watch','schema','2-2',0,'5240'),(351885,112268,'73848','watch','block_type','1',0,''),(351886,112268,'73848','watch','padding-right','20',0,''),(351887,112268,'73848','watch','padding-left','0',0,'5240'),(351888,112268,'73848','watch','margin-bottom','20',0,'5240'),(351889,112271,'73851','watch','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(351890,112272,'73852','watch','block_type','1',0,''),(351891,112272,'73852','watch','padding-left','20',0,''),(351892,112272,'73852','watch','padding-left','0',0,'5240'),(351893,112274,'73854','watch','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(351894,112275,'73855','watch','border-top-width','1',0,''),(351895,112275,'73855','watch','border-top-color','$content-border-1',0,''),(351896,112275,'73855','watch','padding-top','13',0,''),(351897,112275,'73855','watch','padding-bottom','10',0,''),(351898,112276,'73856','watch','block_type','1',0,''),(351899,112276,'73856','watch','background-color','$content-bg-1',0,''),(351900,112276,'73856','watch','padding-top','30',0,''),(351901,112276,'73856','watch','padding-left','30',0,''),(351902,112276,'73856','watch','padding-right','30',0,''),(351903,112276,'73856','watch','padding-bottom','14',0,''),(351904,112276,'73856','watch','margin-bottom','20',0,''),(351905,112276,'73856','watch','style_class','hiding-box closeable-box',0,''),(351906,112277,'73857','watch','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(351907,112277,'73857','watch','style_class','closeable-heading closeable-event closed',0,''),(351908,112278,'73858','watch','style_class','closeable-content',0,''),(351909,112278,'73858','watch','padding-bottom','20',0,''),(351910,112279,'73860','watch','block_type','1',0,''),(351911,112279,'73860','watch','padding-top','30',0,''),(351912,112279,'73860','watch','padding-left','30',0,''),(351913,112279,'73860','watch','padding-right','30',0,''),(351914,112279,'73860','watch','padding-bottom','23',0,''),(351915,112279,'73860','watch','margin-bottom','20',0,''),(351916,112279,'73860','watch','background-color','$content-bg-1',0,''),(351917,112279,'73860','watch','style_class','hiding-box',0,''),(351918,112280,'73861','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(351919,112281,'73862','watch','block_type','2',0,''),(351920,112281,'73862','watch','schema','2-2',0,'5240'),(351921,112282,'73863','watch','padding-right','20',0,''),(351922,112282,'73863','watch','padding-right','0',0,'5240'),(351923,112282,'73863','watch','padding-bottom','20',0,'5240'),(351924,112283,'73864','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351925,112284,'73865','watch','block_type','1',0,''),(351926,112284,'73865','watch','padding-left','20',0,''),(351927,112284,'73865','watch','padding-left','0',0,'5240'),(351928,112286,'73867','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351929,112287,'73868','watch','block_type','1',0,''),(351930,112287,'73868','watch','padding-top','20',0,''),(351931,112287,'73868','watch','padding-left','20',0,''),(351932,112287,'73868','watch','padding-right','20',0,''),(351933,112287,'73868','watch','padding-bottom','20',0,''),(351934,112287,'73868','watch','background-color','$content-bg-1',0,''),(351935,112287,'73868','watch','style_class','order-summary',0,''),(351936,112288,'73869','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(351937,112289,'73870','watch','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(351938,112289,'73870','watch','text-align','center',0,''),(351939,112289,'73870','watch','font-size','14',0,''),(351940,112289,'73870','watch','color','$fade-color-1',0,''),(351941,112289,'73870','watch','padding-top','10',0,''),(351942,112290,'73871','watch','margin-bottom','10',0,''),(351943,112292,'115996','watch','hide_continue_button','1',0,''),(351944,112293,'73873','watch','block_type','1',0,''),(351945,112293,'73873','watch','background-color','$content-bg-2',0,''),(351946,112293,'73873','watch','padding-top','30',0,''),(351947,112293,'73873','watch','padding-bottom','30',0,''),(351948,112294,'73874','watch','block_type','4',0,''),(351949,112294,'73874','watch','schema','4-2',0,'5240'),(351950,112295,'73875','watch','block_type','1',0,''),(351951,112295,'73875','watch','padding-right','40',0,''),(351952,112295,'73875','watch','padding-right','0',0,'5240'),(351953,112296,'73876','watch','background-color','$content-bg-1',0,''),(351954,112296,'73876','watch','padding-top','30',0,''),(351955,112296,'73876','watch','padding-left','30',0,''),(351956,112296,'73876','watch','padding-right','30',0,''),(351957,112296,'73876','watch','padding-bottom','30',0,''),(351958,112296,'73876','watch','margin-bottom','20',0,''),(351959,112297,'73877','watch','block_type','1',0,''),(351960,112297,'73877','watch','background-color','$content-bg-1',0,''),(351961,112297,'73877','watch','padding-top','30',0,''),(351962,112297,'73877','watch','padding-left','30',0,''),(351963,112297,'73877','watch','padding-right','30',0,''),(351964,112297,'73877','watch','padding-bottom','30',0,''),(351965,112297,'73877','watch','margin-bottom','20',0,''),(351966,112297,'73877','watch','style_class','hiding-box',0,''),(351967,112298,'73878','watch','margin-bottom','20',0,''),(351968,112299,'73879','watch','padding-top','10',0,''),(351969,112299,'73879','watch','padding-left','20',0,''),(351970,112299,'73879','watch','padding-right','20',0,''),(351971,112299,'73879','watch','margin-top','20',0,''),(351972,112299,'73879','watch','background-color','$content-bg-2',0,''),(351973,112299,'73879','watch','padding-bottom','8',0,''),(351974,112300,'73880','watch','background-color','$content-bg-1',0,''),(351975,112300,'73880','watch','block_type','1',0,''),(351976,112300,'73880','watch','padding-top','30',0,''),(351977,112300,'73880','watch','padding-left','30',0,''),(351978,112300,'73880','watch','padding-right','30',0,''),(351979,112300,'73880','watch','padding-bottom','30',0,''),(351980,112300,'73880','watch','margin-bottom','20',0,''),(351981,112300,'73880','watch','style_class','hiding-box',0,''),(351982,112301,'73881','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(351983,112302,'73882','watch','background-color','$content-bg-2',0,''),(351984,112302,'73882','watch','padding-top','10',0,''),(351985,112302,'73882','watch','padding-left','10',0,''),(351986,112302,'73882','watch','padding-right','10',0,''),(351987,112302,'73882','watch','padding-bottom','10',0,''),(351988,112302,'73882','watch','margin-top','10',0,''),(351989,112303,'73883','watch','block_type','1',0,''),(351990,112303,'73883','watch','content','\\_',0,'3'),(351991,112303,'73883','watch','border-top-width','1',0,'3'),(351992,112303,'73883','watch','border-top-color','$content-border-1',0,'3'),(351993,112303,'73883','watch','display','block',0,'3'),(351994,112303,'73883','watch','position','absolute',0,'3'),(351995,112303,'73883','watch','top','19',0,'3'),(351996,112303,'73883','watch','left','0',0,'3'),(351997,112303,'73883','watch','right','0',0,'3'),(351998,112303,'73883','watch','margin-top','-2',0,'3'),(351999,112303,'73883','watch','position','relative',0,''),(352000,112304,'73884','watch','box_align','2',0,''),(352001,112304,'73884','watch','margin-bottom','10',0,''),(352002,112304,'73884','watch','background-color','$content-bg-1',0,''),(352003,112304,'73884','watch','position','relative',0,''),(352004,112305,'73885','watch','block_type','2',0,''),(352005,112305,'73885','watch','schema','2-2',0,'5240'),(352006,112306,'73886','watch','block_type','1',0,''),(352007,112306,'73886','watch','padding-right','20',0,''),(352008,112306,'73886','watch','padding-left','0',0,'5240'),(352009,112306,'73886','watch','margin-bottom','20',0,'5240'),(352010,112309,'73889','watch','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(352011,112310,'73890','watch','block_type','1',0,''),(352012,112310,'73890','watch','padding-left','20',0,''),(352013,112310,'73890','watch','padding-left','0',0,'5240'),(352014,112312,'73892','watch','border-top-width','1',0,''),(352015,112312,'73892','watch','border-top-color','$content-border-1',0,''),(352016,112312,'73892','watch','padding-top','13',0,''),(352017,112312,'73892','watch','padding-bottom','10',0,''),(352018,112313,'73893','watch','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(352019,112314,'73894','watch','block_type','1',0,''),(352020,112314,'73894','watch','padding-top','30',0,''),(352021,112314,'73894','watch','padding-left','30',0,''),(352022,112314,'73894','watch','padding-right','30',0,''),(352023,112314,'73894','watch','padding-bottom','23',0,''),(352024,112314,'73894','watch','margin-bottom','20',0,''),(352025,112314,'73894','watch','background-color','$content-bg-1',0,''),(352026,112314,'73894','watch','style_class','hiding-box',0,''),(352027,112315,'73895','watch','block_type','2',0,''),(352028,112315,'73895','watch','schema','2-2',0,'5240'),(352029,112316,'73896','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(352030,112317,'73897','watch','padding-right','20',0,''),(352031,112317,'73897','watch','padding-right','0',0,'5240'),(352032,112317,'73897','watch','padding-bottom','20',0,'5240'),(352033,112318,'73898','watch','block_type','1',0,''),(352034,112318,'73898','watch','padding-left','20',0,''),(352035,112318,'73898','watch','padding-left','0',0,'5240'),(352036,112319,'73899','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(352037,112321,'73901','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(352038,112322,'73902','watch','block_type','1',0,''),(352039,112322,'73902','watch','background-color','$content-bg-1',0,''),(352040,112322,'73902','watch','padding-top','30',0,''),(352041,112322,'73902','watch','padding-left','30',0,''),(352042,112322,'73902','watch','padding-right','30',0,''),(352043,112322,'73902','watch','padding-bottom','14',0,''),(352044,112322,'73902','watch','margin-bottom','20',0,''),(352045,112322,'73902','watch','style_class','hiding-box closeable-box',0,''),(352046,112323,'73903','watch','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(352047,112323,'73903','watch','style_class','closeable-heading closeable-event closed',0,''),(352048,112324,'73904','watch','style_class','closeable-content',0,''),(352049,112324,'73904','watch','padding-bottom','20',0,''),(352050,112325,'73905','watch','block_type','1',0,''),(352051,112325,'73905','watch','padding-top','30',0,''),(352052,112325,'73905','watch','padding-left','30',0,''),(352053,112325,'73905','watch','padding-right','30',0,''),(352054,112325,'73905','watch','padding-bottom','14',0,''),(352055,112325,'73905','watch','margin-bottom','20',0,''),(352056,112325,'73905','watch','background-color','$content-bg-1',0,''),(352057,112325,'73905','watch','style_class','hiding-box closeable-box',0,''),(352058,112326,'73906','watch','block_type','2',0,''),(352059,112326,'73906','watch','style_class','closeable-content',0,''),(352060,112326,'73906','watch','schema','2-2',0,'5240'),(352061,112327,'73907','watch','padding-right','20',0,''),(352062,112327,'73907','watch','padding-bottom','20',0,''),(352063,112327,'73907','watch','padding-right','0',0,'5240'),(352064,112328,'73908','watch','padding-left','20',0,''),(352065,112328,'73908','watch','padding-bottom','20',0,''),(352066,112328,'73908','watch','padding-left','0',0,'5240'),(352067,112329,'73909','watch','padding-left','20',0,''),(352068,112329,'73909','watch','padding-bottom','20',0,''),(352069,112329,'73909','watch','padding-left','0',0,'5240'),(352070,112330,'73910','watch','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(352071,112330,'73910','watch','style_class','closeable-heading closeable-event closed',0,''),(352072,112331,'73911','watch','block_type','1',0,''),(352073,112331,'73911','watch','padding-top','20',0,''),(352074,112331,'73911','watch','padding-left','20',0,''),(352075,112331,'73911','watch','padding-right','20',0,''),(352076,112331,'73911','watch','padding-bottom','20',0,''),(352077,112331,'73911','watch','background-color','$content-bg-1',0,''),(352078,112331,'73911','watch','style_class','order-summary',0,''),(352079,112332,'73912','watch','margin-bottom','10',0,''),(352080,112333,'73913','watch','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(352081,112333,'73913','watch','text-align','center',0,''),(352082,112333,'73913','watch','font-size','14',0,''),(352083,112333,'73913','watch','color','$fade-color-1',0,''),(352084,112333,'73913','watch','padding-top','10',0,''),(352085,112334,'73914','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(352086,112336,'115998','watch','hide_continue_button','1',0,''),(352087,112337,'73916','watch','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(352088,112342,'73921','watch','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(352089,112343,'73923','watch','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(352090,112344,'73924','watch','style_class','order-summary',0,''),(352091,112344,'73924','watch','box_align','3',0,''),(352092,112344,'73924','watch','width','400',0,''),(352093,112346,'73922','watch','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(352094,112349,'73928','watch','block_type','1',0,''),(352095,112350,'73929','watch','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(352096,112351,'73930','watch','float','right',0,''),(352097,112351,'73930','watch','position','relative',0,''),(352098,112351,'73930','watch','z-index','1',0,''),(352099,112351,'73930','watch','top','30',0,''),(352100,112351,'73930','watch','margin-bottom','-20',0,''),(352101,112352,'73931','watch','margin-bottom','30',0,''),(352102,112353,'94704','watch','block_type','1',0,''),(352103,112354,'94705','watch','listing_type','Compare Products',0,''),(352104,112355,'94706','watch','block_type','1',0,''),(352105,112355,'94706','watch','style_class','item-holder',0,''),(352106,112355,'94706','watch','padding-top','10',0,''),(352107,112355,'94706','watch','padding-left','20',0,''),(352108,112355,'94706','watch','padding-right','20',0,''),(352109,112355,'94706','watch','padding-bottom','10',0,''),(352110,112355,'94706','watch','text-align','left',0,''),(352111,112358,'94709','watch','margin-bottom','10',0,''),(352112,112359,'94710','watch','block_type','5',0,''),(352113,112361,'94712','watch','clear','both',0,''),(352114,112362,'94713','watch','block_type','2',0,''),(352115,112363,'94714','watch','margin-bottom','7',0,''),(352116,112364,'94715','watch','text-align','right',0,''),(352117,112364,'94715','watch','margin-bottom','10',0,''),(352118,112364,'94715','watch','float','right',0,''),(352119,112365,'73932','watch','block_type','1',0,''),(352120,112365,'73932','watch','background-color','$content-bg-2',0,''),(352121,112365,'73932','watch','padding-bottom','30',0,''),(352122,112365,'73932','watch','color','$content-color-2',0,''),(352123,112366,'73933','watch','block_type','4',0,''),(352124,112366,'73933','watch','schema','4-2',0,'5240'),(352125,112367,'73934','watch','block_type','1',0,''),(352126,112367,'73934','watch','padding-right','40',0,''),(352127,112367,'73934','watch','padding-right','0',0,'5240'),(352128,112368,'73935','watch','block_type','1',0,''),(352129,112368,'73935','watch','padding-right','30',0,''),(352130,112368,'73935','watch','background-color','$content-bg-1',0,''),(352131,112368,'73935','watch','padding-top','20',0,''),(352132,112368,'73935','watch','padding-left','30',0,''),(352133,112368,'73935','watch','padding-bottom','20',0,''),(352134,112368,'73935','watch','padding-left','20',0,'5240'),(352135,112368,'73935','watch','padding-right','20',0,'5240'),(352136,112368,'73935','watch','color','$content-color-1',0,''),(352137,112369,'73936','watch','link','products',0,''),(352138,112369,'73936','watch','float','right',0,''),(352139,112369,'73936','watch','margin-top','-37',0,''),(352140,112371,'73938','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(352141,112372,'73939','watch','block_type','1',0,''),(352142,112372,'73939','watch','background-color','$content-bg-1',0,''),(352143,112372,'73939','watch','padding-top','20',0,''),(352144,112372,'73939','watch','padding-bottom','20',0,''),(352145,112372,'73939','watch','padding-left','30',0,''),(352146,112372,'73939','watch','padding-right','30',0,''),(352147,112372,'73939','watch','margin-bottom','20',0,''),(352148,112372,'73939','watch','color','$content-color-1',0,''),(352149,112373,'73940','watch','float','right',0,''),(352150,112373,'73940','watch','margin-top','-37',0,''),(352151,112373,'73940','watch','link','comments',0,''),(352152,112374,'73941','watch','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(352153,112375,'73942','watch','hide_parents','2',0,''),(352154,112376,'73943','watch','block_type','2',0,''),(352155,112376,'73943','watch','margin-bottom','20',0,''),(352156,112376,'73943','watch','schema','2-2',0,'5232'),(352157,112376,'73943','watch','background-color','$content-bg-1',0,''),(352158,112376,'73943','watch','color','$content-color-1',0,''),(352159,112377,'73944','watch','block_type','1',0,''),(352160,112377,'73944','watch','border-right-width','20',0,''),(352161,112377,'73944','watch','border-right-color','$content-bg-2',0,''),(352162,112377,'73944','watch','margin-right','-10',0,''),(352163,112377,'73944','watch','padding-right','30',0,''),(352164,112377,'73944','watch','padding-top','20',0,''),(352165,112377,'73944','watch','padding-left','30',0,''),(352166,112377,'73944','watch','padding-bottom','20',0,''),(352167,112377,'73944','watch','border-right-width','0',0,'5240'),(352168,112377,'73944','watch','margin-right','0',0,'5240'),(352169,112377,'73944','watch','margin-bottom','20',0,'5240'),(352170,112377,'73944','watch','padding-left','20',0,'5240'),(352171,112377,'73944','watch','padding-right','20',0,'5240'),(352172,112378,'73945','watch','link','shipping_method',0,''),(352173,112378,'73945','watch','float','right',0,''),(352174,112378,'73945','watch','margin-top','-31',0,''),(352175,112380,'73947','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(352176,112380,'73947','watch','padding-top','20',0,''),(352177,112381,'73948','watch','link','contact_information',0,''),(352178,112381,'73948','watch','margin-top','-31',0,''),(352179,112381,'73948','watch','float','right',0,''),(352180,112382,'73949','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(352181,112382,'73949','watch','clear','none',0,''),(352182,112384,'73951','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(352183,112385,'73952','watch','link','shipping_address',0,''),(352184,112385,'73952','watch','float','right',0,''),(352185,112385,'73952','watch','margin-top','-31',0,''),(352186,112387,'73954','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(352187,112387,'73954','watch','clear','none',0,''),(352188,112388,'73955','watch','margin-bottom','20',0,''),(352189,112389,'73956','watch','block_type','1',0,''),(352190,112389,'73956','watch','padding-left','30',0,''),(352191,112389,'73956','watch','border-left-width','20',0,''),(352192,112389,'73956','watch','border-left-color','$content-bg-2',0,''),(352193,112389,'73956','watch','margin-left','-10',0,''),(352194,112389,'73956','watch','padding-right','30',0,''),(352195,112389,'73956','watch','padding-top','20',0,''),(352196,112389,'73956','watch','padding-bottom','20',0,''),(352197,112389,'73956','watch','border-left-width','0',0,'5240'),(352198,112390,'73957','watch','link','payment_method',0,''),(352199,112390,'73957','watch','float','right',0,''),(352200,112390,'73957','watch','margin-top','-31',0,''),(352201,112391,'73958','watch','link','billing_address',0,''),(352202,112391,'73958','watch','float','right',0,''),(352203,112391,'73958','watch','margin-top','-31',0,''),(352204,112393,'73960','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(352205,112393,'73960','watch','clear','none',0,''),(352206,112394,'73961','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(352207,112395,'73962','watch','margin-bottom','20',0,''),(352208,112396,'73963','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(352209,112396,'73963','watch','clear','none',0,''),(352210,112398,'73965','watch','block_type','1',0,''),(352211,112398,'73965','watch','padding-top','20',0,''),(352212,112398,'73965','watch','padding-left','20',0,''),(352213,112398,'73965','watch','padding-right','20',0,''),(352214,112398,'73965','watch','padding-bottom','20',0,''),(352215,112398,'73965','watch','background-color','$content-bg-1',0,''),(352216,112398,'73965','watch','style_class','order-summary2 hiding-box',0,''),(352217,112398,'73965','watch','color','$content-color-1',0,''),(352218,112399,'73966','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(352219,112400,'73967','watch','margin-bottom','20',0,''),(352220,112400,'73967','watch','text-align','right',0,''),(352221,112402,'73969','watch','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(352222,112403,'73970','watch','block_type','1',0,''),(352223,112403,'73970','watch','background-color','$content-bg-2',0,''),(352224,112403,'73970','watch','padding-bottom','30',0,''),(352225,112404,'73971','watch','block_type','4',0,''),(352226,112404,'73971','watch','schema','4-2',0,'5240'),(352227,112405,'73972','watch','block_type','1',0,''),(352228,112405,'73972','watch','padding-right','40',0,''),(352229,112405,'73972','watch','padding-right','0',0,'5240'),(352230,112406,'73973','watch','block_type','1',0,''),(352231,112406,'73973','watch','background-color','$content-bg-1',0,''),(352232,112406,'73973','watch','padding-top','20',0,''),(352233,112406,'73973','watch','padding-bottom','20',0,''),(352234,112406,'73973','watch','padding-left','30',0,''),(352235,112406,'73973','watch','padding-right','30',0,''),(352236,112406,'73973','watch','margin-bottom','20',0,''),(352237,112407,'73974','watch','hide_parents','2',0,''),(352238,112408,'73975','watch','float','right',0,''),(352239,112408,'73975','watch','margin-top','-37',0,''),(352240,112408,'73975','watch','link','comments',0,''),(352241,112409,'73976','watch','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(352242,112410,'73977','watch','block_type','1',0,''),(352243,112410,'73977','watch','padding-right','30',0,''),(352244,112410,'73977','watch','background-color','$content-bg-1',0,''),(352245,112410,'73977','watch','padding-top','20',0,''),(352246,112410,'73977','watch','padding-left','30',0,''),(352247,112410,'73977','watch','padding-bottom','20',0,''),(352248,112410,'73977','watch','padding-left','20',0,'5240'),(352249,112410,'73977','watch','padding-right','20',0,'5240'),(352250,112411,'73978','watch','link','products',0,''),(352251,112411,'73978','watch','float','right',0,''),(352252,112411,'73978','watch','margin-top','-37',0,''),(352253,112412,'73979','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(352254,112414,'73981','watch','block_type','2',0,''),(352255,112414,'73981','watch','margin-bottom','20',0,''),(352256,112414,'73981','watch','schema','2-2',0,'5232'),(352257,112414,'73981','watch','background-color','$content-bg-1',0,''),(352258,112415,'73982','watch','block_type','1',0,''),(352259,112415,'73982','watch','border-right-width','20',0,''),(352260,112415,'73982','watch','border-right-color','$content-border-1',0,''),(352261,112415,'73982','watch','margin-right','-10',0,''),(352262,112415,'73982','watch','padding-right','30',0,''),(352263,112415,'73982','watch','padding-top','20',0,''),(352264,112415,'73982','watch','padding-left','30',0,''),(352265,112415,'73982','watch','padding-bottom','20',0,''),(352266,112415,'73982','watch','border-right-width','0',0,'5240'),(352267,112415,'73982','watch','margin-right','0',0,'5240'),(352268,112415,'73982','watch','margin-bottom','20',0,'5240'),(352269,112415,'73982','watch','padding-left','20',0,'5240'),(352270,112415,'73982','watch','padding-right','20',0,'5240'),(352271,112416,'73983','watch','link','shipping_address',0,''),(352272,112416,'73983','watch','float','right',0,''),(352273,112416,'73983','watch','margin-top','-31',0,''),(352274,112418,'73985','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(352275,112418,'73985','watch','clear','none',0,''),(352276,112419,'73986','watch','link','shipping_method',0,''),(352277,112419,'73986','watch','float','right',0,''),(352278,112419,'73986','watch','margin-top','-31',0,''),(352279,112420,'73987','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(352280,112420,'73987','watch','clear','none',0,''),(352281,112421,'73988','watch','margin-bottom','20',0,''),(352282,112422,'73989','watch','block_type','1',0,''),(352283,112422,'73989','watch','padding-left','30',0,''),(352284,112422,'73989','watch','border-left-width','20',0,''),(352285,112422,'73989','watch','border-left-color','$content-border-1',0,''),(352286,112422,'73989','watch','margin-left','-10',0,''),(352287,112422,'73989','watch','padding-right','30',0,''),(352288,112422,'73989','watch','padding-top','20',0,''),(352289,112422,'73989','watch','padding-bottom','20',0,''),(352290,112422,'73989','watch','border-left-width','0',0,'5240'),(352291,112425,'73992','watch','link','contact_information',0,''),(352292,112425,'73992','watch','margin-top','-31',0,''),(352293,112425,'73992','watch','float','right',0,''),(352294,112426,'73993','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(352295,112427,'73994','watch','block_type','1',0,''),(352296,112427,'73994','watch','padding-top','20',0,''),(352297,112427,'73994','watch','padding-left','20',0,''),(352298,112427,'73994','watch','padding-right','20',0,''),(352299,112427,'73994','watch','padding-bottom','20',0,''),(352300,112427,'73994','watch','background-color','$content-bg-1',0,''),(352301,112427,'73994','watch','style_class','order-summary',0,''),(352302,112428,'73995','watch','margin-bottom','20',0,''),(352303,112428,'73995','watch','text-align','right',0,''),(352304,112429,'73996','watch','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(352305,112430,'73997','watch','block_type','1',0,''),(352306,112430,'73997','watch','background-color','$content-bg-2',0,''),(352307,112430,'73997','watch','padding-bottom','30',0,''),(352308,112430,'73997','watch','color','$content-color-2',0,''),(352309,112431,'73998','watch','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(352310,112432,'73999','watch','block_type','4',0,''),(352311,112433,'74000','watch','block_type','1',0,''),(352312,112433,'74000','watch','padding-right','40',0,''),(352313,112434,'74001','watch','block_type','2',0,''),(352314,112434,'74001','watch','margin-bottom','20',0,''),(352315,112434,'74001','watch','schema','2-2',0,'5232'),(352316,112434,'74001','watch','background-color','$content-bg-1',0,''),(352317,112434,'74001','watch','color','$content-color-1',0,''),(352318,112435,'74002','watch','block_type','1',0,''),(352319,112435,'74002','watch','padding-right','0',0,'5232'),(352320,112435,'74002','watch','border-right-width','20',0,''),(352321,112435,'74002','watch','border-right-color','$content-bg-2',0,''),(352322,112435,'74002','watch','margin-right','-10',0,''),(352323,112435,'74002','watch','padding-right','30',0,''),(352324,112435,'74002','watch','padding-top','20',0,''),(352325,112435,'74002','watch','padding-left','30',0,''),(352326,112435,'74002','watch','padding-bottom','20',0,''),(352327,112436,'74003','watch','link','contact_information',0,''),(352328,112436,'74003','watch','margin-top','-37',0,''),(352329,112436,'74003','watch','float','right',0,''),(352330,112437,'74004','watch','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(352331,112437,'74004','watch','padding-top','20',0,''),(352332,112439,'74006','watch','block_type','1',0,''),(352333,112439,'74006','watch','padding-left','30',0,''),(352334,112439,'74006','watch','padding-left','0',0,'5232'),(352335,112439,'74006','watch','border-left-width','20',0,''),(352336,112439,'74006','watch','border-left-color','$content-bg-2',0,''),(352337,112439,'74006','watch','margin-left','-10',0,''),(352338,112439,'74006','watch','padding-right','30',0,''),(352339,112439,'74006','watch','padding-top','20',0,''),(352340,112439,'74006','watch','padding-bottom','20',0,''),(352341,112441,'74008','watch','link','payment_method',0,''),(352342,112441,'74008','watch','float','right',0,''),(352343,112441,'74008','watch','margin-top','-31',0,''),(352344,112442,'74009','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(352345,112442,'74009','watch','clear','none',0,''),(352346,112443,'74010','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(352347,112444,'74011','watch','link','billing_address',0,''),(352348,112444,'74011','watch','float','right',0,''),(352349,112444,'74011','watch','margin-top','-31',0,''),(352350,112445,'74012','watch','margin-bottom','20',0,''),(352351,112446,'74013','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(352352,112446,'74013','watch','clear','none',0,''),(352353,112447,'74014','watch','block_type','1',0,''),(352354,112447,'74014','watch','background-color','$content-bg-1',0,''),(352355,112447,'74014','watch','padding-top','20',0,''),(352356,112447,'74014','watch','padding-bottom','20',0,''),(352357,112447,'74014','watch','padding-left','30',0,''),(352358,112447,'74014','watch','padding-right','30',0,''),(352359,112447,'74014','watch','margin-bottom','20',0,''),(352360,112447,'74014','watch','color','$content-color-1',0,''),(352361,112448,'74015','watch','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(352362,112449,'74016','watch','hide_parents','2',0,''),(352363,112450,'74017','watch','float','right',0,''),(352364,112450,'74017','watch','margin-top','-37',0,''),(352365,112450,'74017','watch','link','comments',0,''),(352366,112451,'74018','watch','block_type','1',0,''),(352367,112451,'74018','watch','padding-right','30',0,''),(352368,112451,'74018','watch','padding-right','0',0,'5232'),(352369,112451,'74018','watch','background-color','$content-bg-1',0,''),(352370,112451,'74018','watch','padding-top','20',0,''),(352371,112451,'74018','watch','padding-left','30',0,''),(352372,112451,'74018','watch','padding-bottom','20',0,''),(352373,112451,'74018','watch','color','$content-color-1',0,''),(352374,112452,'74019','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(352375,112453,'74020','watch','link','products',0,''),(352376,112453,'74020','watch','float','right',0,''),(352377,112453,'74020','watch','margin-top','-37',0,''),(352378,112455,'74022','watch','block_type','1',0,''),(352379,112455,'74022','watch','padding-top','20',0,''),(352380,112455,'74022','watch','padding-left','20',0,''),(352381,112455,'74022','watch','padding-right','20',0,''),(352382,112455,'74022','watch','padding-bottom','20',0,''),(352383,112455,'74022','watch','background-color','$content-bg-1',0,''),(352384,112455,'74022','watch','style_class','order-summary2 hiding-box',0,''),(352385,112455,'74022','watch','color','$content-color-1',0,''),(352386,112456,'74023','watch','margin-bottom','20',0,''),(352387,112456,'74023','watch','text-align','right',0,''),(352388,112457,'74024','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(352389,112459,'74026','watch','block_type','1',0,''),(352390,112459,'74026','watch','background-color','$content-bg-2',0,''),(352391,112459,'74026','watch','padding-bottom','30',0,''),(352392,112460,'74027','watch','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(352393,112461,'74028','watch','block_type','4',0,''),(352394,112461,'74028','watch','schema','4-2',0,'5240'),(352395,112462,'74029','watch','block_type','1',0,''),(352396,112462,'74029','watch','padding-right','40',0,''),(352397,112462,'74029','watch','padding-right','0',0,'5240'),(352398,112463,'74030','watch','block_type','1',0,''),(352399,112463,'74030','watch','background-color','$content-bg-1',0,''),(352400,112463,'74030','watch','padding-top','20',0,''),(352401,112463,'74030','watch','padding-bottom','20',0,''),(352402,112463,'74030','watch','padding-left','30',0,''),(352403,112463,'74030','watch','padding-right','30',0,''),(352404,112463,'74030','watch','margin-bottom','20',0,''),(352405,112464,'74031','watch','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(352406,112465,'74032','watch','hide_parents','2',0,''),(352407,112466,'74033','watch','float','right',0,''),(352408,112466,'74033','watch','margin-top','-37',0,''),(352409,112466,'74033','watch','link','comments',0,''),(352410,112467,'74034','watch','block_type','2',0,''),(352411,112467,'74034','watch','margin-bottom','20',0,''),(352412,112467,'74034','watch','schema','2-2',0,'5232'),(352413,112467,'74034','watch','background-color','$content-bg-1',0,''),(352414,112468,'74035','watch','block_type','1',0,''),(352415,112468,'74035','watch','border-right-width','20',0,''),(352416,112468,'74035','watch','border-right-color','$content-border-1',0,''),(352417,112468,'74035','watch','margin-right','-10',0,''),(352418,112468,'74035','watch','padding-right','30',0,''),(352419,112468,'74035','watch','padding-top','20',0,''),(352420,112468,'74035','watch','padding-left','30',0,''),(352421,112468,'74035','watch','padding-bottom','20',0,''),(352422,112468,'74035','watch','border-right-width','0',0,'5240'),(352423,112468,'74035','watch','margin-right','0',0,'5240'),(352424,112468,'74035','watch','margin-bottom','20',0,'5240'),(352425,112468,'74035','watch','padding-left','20',0,'5240'),(352426,112468,'74035','watch','padding-right','20',0,'5240'),(352427,112469,'74036','watch','link','contact_information',0,''),(352428,112469,'74036','watch','margin-top','-31',0,''),(352429,112469,'74036','watch','float','right',0,''),(352430,112472,'74039','watch','link','payment_method',0,''),(352431,112472,'74039','watch','float','right',0,''),(352432,112472,'74039','watch','margin-top','-31',0,''),(352433,112473,'74040','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(352434,112473,'74040','watch','padding-top','20',0,''),(352435,112474,'74041','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(352436,112474,'74041','watch','clear','none',0,''),(352437,112475,'74042','watch','block_type','1',0,''),(352438,112475,'74042','watch','padding-left','30',0,''),(352439,112475,'74042','watch','border-left-width','20',0,''),(352440,112475,'74042','watch','border-left-color','$content-border-1',0,''),(352441,112475,'74042','watch','margin-left','-10',0,''),(352442,112475,'74042','watch','padding-right','30',0,''),(352443,112475,'74042','watch','padding-top','20',0,''),(352444,112475,'74042','watch','padding-bottom','20',0,''),(352445,112475,'74042','watch','border-left-width','0',0,'5240'),(352446,112476,'74043','watch','margin-bottom','20',0,''),(352447,112477,'74044','watch','link','billing_address',0,''),(352448,112477,'74044','watch','float','right',0,''),(352449,112477,'74044','watch','margin-top','-31',0,''),(352450,112478,'74045','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(352451,112478,'74045','watch','clear','none',0,''),(352452,112479,'74046','watch','block_type','1',0,''),(352453,112479,'74046','watch','padding-right','30',0,''),(352454,112479,'74046','watch','background-color','$content-bg-1',0,''),(352455,112479,'74046','watch','padding-top','20',0,''),(352456,112479,'74046','watch','padding-left','30',0,''),(352457,112479,'74046','watch','padding-bottom','20',0,''),(352458,112479,'74046','watch','padding-left','20',0,'5240'),(352459,112479,'74046','watch','padding-right','20',0,'5240'),(352460,112480,'74047','watch','link','products',0,''),(352461,112480,'74047','watch','float','right',0,''),(352462,112480,'74047','watch','margin-top','-37',0,''),(352463,112481,'74048','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(352464,112482,'74049','watch','margin-bottom','20',0,''),(352465,112483,'74050','watch','block_type','1',0,''),(352466,112483,'74050','watch','padding-top','20',0,''),(352467,112483,'74050','watch','padding-left','20',0,''),(352468,112483,'74050','watch','padding-right','20',0,''),(352469,112483,'74050','watch','padding-bottom','20',0,''),(352470,112483,'74050','watch','background-color','$content-bg-1',0,''),(352471,112483,'74050','watch','style_class','order-summary',0,''),(352472,112484,'74051','watch','margin-bottom','20',0,''),(352473,112484,'74051','watch','text-align','right',0,''),(352474,112486,'74053','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(352475,112487,'74054','watch','block_type','1',0,''),(352476,112487,'74054','watch','background-color','$content-bg-2',0,''),(352477,112487,'74054','watch','padding-bottom','30',0,''),(352478,112488,'74055','watch','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(352479,112489,'74056','watch','block_type','4',0,''),(352480,112489,'74056','watch','schema','4-2',0,'5240'),(352481,112490,'74057','watch','block_type','1',0,''),(352482,112490,'74057','watch','padding-right','40',0,''),(352483,112490,'74057','watch','padding-right','0',0,'5240'),(352484,112491,'74058','watch','block_type','1',0,''),(352485,112491,'74058','watch','padding-right','30',0,''),(352486,112491,'74058','watch','background-color','$content-bg-1',0,''),(352487,112491,'74058','watch','padding-top','20',0,''),(352488,112491,'74058','watch','padding-left','30',0,''),(352489,112491,'74058','watch','padding-bottom','20',0,''),(352490,112491,'74058','watch','padding-left','20',0,'5240'),(352491,112491,'74058','watch','padding-right','20',0,'5240'),(352492,112493,'74060','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(352493,112494,'74061','watch','link','products',0,''),(352494,112494,'74061','watch','float','right',0,''),(352495,112494,'74061','watch','margin-top','-37',0,''),(352496,112495,'74062','watch','block_type','2',0,''),(352497,112495,'74062','watch','margin-bottom','20',0,''),(352498,112495,'74062','watch','schema','2-2',0,'5232'),(352499,112495,'74062','watch','background-color','$content-bg-1',0,''),(352500,112496,'74063','watch','block_type','1',0,''),(352501,112496,'74063','watch','border-right-width','20',0,''),(352502,112496,'74063','watch','border-right-color','$content-border-1',0,''),(352503,112496,'74063','watch','margin-right','-10',0,''),(352504,112496,'74063','watch','padding-right','30',0,''),(352505,112496,'74063','watch','padding-top','20',0,''),(352506,112496,'74063','watch','padding-left','30',0,''),(352507,112496,'74063','watch','padding-bottom','20',0,''),(352508,112496,'74063','watch','border-right-width','0',0,'5240'),(352509,112496,'74063','watch','margin-right','0',0,'5240'),(352510,112496,'74063','watch','margin-bottom','20',0,'5240'),(352511,112496,'74063','watch','padding-left','20',0,'5240'),(352512,112496,'74063','watch','padding-right','20',0,'5240'),(352513,112497,'74064','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(352514,112498,'74065','watch','link','contact_information',0,''),(352515,112498,'74065','watch','margin-top','-31',0,''),(352516,112498,'74065','watch','float','right',0,''),(352517,112499,'74066','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(352518,112499,'74066','watch','clear','none',0,''),(352519,112501,'74068','watch','margin-bottom','20',0,''),(352520,112503,'74070','watch','link','shipping_address',0,''),(352521,112503,'74070','watch','float','right',0,''),(352522,112503,'74070','watch','margin-top','-31',0,''),(352523,112505,'74072','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(352524,112505,'74072','watch','padding-top','20',0,''),(352525,112506,'74073','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(352526,112506,'74073','watch','clear','none',0,''),(352527,112507,'74074','watch','link','shipping_method',0,''),(352528,112507,'74074','watch','float','right',0,''),(352529,112507,'74074','watch','margin-top','-31',0,''),(352530,112508,'74075','watch','block_type','1',0,''),(352531,112508,'74075','watch','padding-left','30',0,''),(352532,112508,'74075','watch','border-left-width','20',0,''),(352533,112508,'74075','watch','border-left-color','$content-border-1',0,''),(352534,112508,'74075','watch','margin-left','-10',0,''),(352535,112508,'74075','watch','padding-right','30',0,''),(352536,112508,'74075','watch','padding-top','20',0,''),(352537,112508,'74075','watch','padding-bottom','20',0,''),(352538,112508,'74075','watch','border-left-width','0',0,'5240'),(352539,112509,'74076','watch','link','billing_address',0,''),(352540,112509,'74076','watch','float','right',0,''),(352541,112509,'74076','watch','margin-top','-31',0,''),(352542,112510,'74077','watch','margin-bottom','20',0,''),(352543,112512,'74079','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(352544,112513,'74080','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(352545,112513,'74080','watch','clear','none',0,''),(352546,112514,'74081','watch','link','payment_method',0,''),(352547,112514,'74081','watch','float','right',0,''),(352548,112514,'74081','watch','margin-top','-31',0,''),(352549,112515,'74082','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(352550,112515,'74082','watch','clear','none',0,''),(352551,112516,'74083','watch','block_type','1',0,''),(352552,112516,'74083','watch','background-color','$content-bg-1',0,''),(352553,112516,'74083','watch','padding-top','20',0,''),(352554,112516,'74083','watch','padding-bottom','20',0,''),(352555,112516,'74083','watch','padding-left','30',0,''),(352556,112516,'74083','watch','padding-right','30',0,''),(352557,112516,'74083','watch','margin-bottom','20',0,''),(352558,112517,'74084','watch','hide_parents','2',0,''),(352559,112518,'74085','watch','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(352560,112519,'74086','watch','float','right',0,''),(352561,112519,'74086','watch','margin-top','-37',0,''),(352562,112519,'74086','watch','link','comments',0,''),(352563,112520,'74087','watch','block_type','1',0,''),(352564,112520,'74087','watch','padding-top','20',0,''),(352565,112520,'74087','watch','padding-left','20',0,''),(352566,112520,'74087','watch','padding-right','20',0,''),(352567,112520,'74087','watch','padding-bottom','20',0,''),(352568,112520,'74087','watch','background-color','$content-bg-1',0,''),(352569,112520,'74087','watch','style_class','order-summary',0,''),(352570,112521,'74088','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(352571,112523,'74090','watch','margin-bottom','20',0,''),(352572,112523,'74090','watch','text-align','right',0,''),(352573,112524,'74091','watch','block_type','1',0,''),(352574,112524,'74091','watch','background-color','$content-bg-2',0,''),(352575,112524,'74091','watch','padding-bottom','30',0,''),(352576,112525,'74092','watch','block_type','4',0,''),(352577,112525,'74092','watch','schema','4-2',0,'5240'),(352578,112526,'74093','watch','block_type','1',0,''),(352579,112526,'74093','watch','padding-right','40',0,''),(352580,112526,'74093','watch','padding-right','0',0,'5240'),(352581,112527,'74094','watch','block_type','2',0,''),(352582,112527,'74094','watch','margin-bottom','20',0,''),(352583,112527,'74094','watch','schema','2-2',0,'5232'),(352584,112527,'74094','watch','background-color','$content-bg-1',0,''),(352585,112528,'74095','watch','block_type','1',0,''),(352586,112528,'74095','watch','border-right-width','20',0,''),(352587,112528,'74095','watch','border-right-color','$content-border-1',0,''),(352588,112528,'74095','watch','margin-right','-10',0,''),(352589,112528,'74095','watch','padding-right','30',0,''),(352590,112528,'74095','watch','padding-top','20',0,''),(352591,112528,'74095','watch','padding-left','30',0,''),(352592,112528,'74095','watch','padding-bottom','20',0,''),(352593,112528,'74095','watch','border-right-width','0',0,'5240'),(352594,112528,'74095','watch','margin-right','0',0,'5240'),(352595,112528,'74095','watch','margin-bottom','20',0,'5240'),(352596,112528,'74095','watch','padding-left','20',0,'5240'),(352597,112528,'74095','watch','padding-right','20',0,'5240'),(352598,112529,'74096','watch','margin-bottom','20',0,''),(352599,112530,'74097','watch','link','shipping_address',0,''),(352600,112530,'74097','watch','float','right',0,''),(352601,112530,'74097','watch','margin-top','-31',0,''),(352602,112531,'74098','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(352603,112531,'74098','watch','clear','none',0,''),(352604,112534,'74101','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(352605,112535,'74102','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(352606,112535,'74102','watch','clear','none',0,''),(352607,112536,'74103','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(352608,112536,'74103','watch','padding-top','20',0,''),(352609,112538,'74105','watch','link','shipping_method',0,''),(352610,112538,'74105','watch','float','right',0,''),(352611,112538,'74105','watch','margin-top','-31',0,''),(352612,112539,'74106','watch','link','contact_information',0,''),(352613,112539,'74106','watch','margin-top','-31',0,''),(352614,112539,'74106','watch','float','right',0,''),(352615,112540,'74107','watch','block_type','1',0,''),(352616,112540,'74107','watch','padding-left','30',0,''),(352617,112540,'74107','watch','border-left-width','20',0,''),(352618,112540,'74107','watch','border-left-color','$content-border-1',0,''),(352619,112540,'74107','watch','margin-left','-10',0,''),(352620,112540,'74107','watch','padding-right','30',0,''),(352621,112540,'74107','watch','padding-top','20',0,''),(352622,112540,'74107','watch','padding-bottom','20',0,''),(352623,112540,'74107','watch','border-left-width','0',0,'5240'),(352624,112541,'74108','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(352625,112541,'74108','watch','clear','none',0,''),(352626,112542,'74109','watch','margin-bottom','20',0,''),(352627,112543,'74110','watch','link','billing_address',0,''),(352628,112543,'74110','watch','float','right',0,''),(352629,112543,'74110','watch','margin-top','-31',0,''),(352630,112545,'74112','watch','link','payment_method',0,''),(352631,112545,'74112','watch','float','right',0,''),(352632,112545,'74112','watch','margin-top','-31',0,''),(352633,112546,'74113','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(352634,112547,'74114','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(352635,112547,'74114','watch','clear','none',0,''),(352636,112548,'74115','watch','block_type','1',0,''),(352637,112548,'74115','watch','padding-right','30',0,''),(352638,112548,'74115','watch','background-color','$content-bg-1',0,''),(352639,112548,'74115','watch','padding-top','20',0,''),(352640,112548,'74115','watch','padding-left','30',0,''),(352641,112548,'74115','watch','padding-bottom','20',0,''),(352642,112548,'74115','watch','padding-left','20',0,'5240'),(352643,112548,'74115','watch','padding-right','20',0,'5240'),(352644,112549,'74116','watch','link','products',0,''),(352645,112549,'74116','watch','float','right',0,''),(352646,112549,'74116','watch','margin-top','-37',0,''),(352647,112550,'74117','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(352648,112552,'74119','watch','block_type','1',0,''),(352649,112552,'74119','watch','background-color','$content-bg-1',0,''),(352650,112552,'74119','watch','padding-top','20',0,''),(352651,112552,'74119','watch','padding-bottom','20',0,''),(352652,112552,'74119','watch','padding-left','30',0,''),(352653,112552,'74119','watch','padding-right','30',0,''),(352654,112552,'74119','watch','margin-bottom','20',0,''),(352655,112553,'74120','watch','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(352656,112554,'74121','watch','float','right',0,''),(352657,112554,'74121','watch','margin-top','-37',0,''),(352658,112554,'74121','watch','link','comments',0,''),(352659,112555,'74122','watch','hide_parents','2',0,''),(352660,112556,'74123','watch','block_type','1',0,''),(352661,112556,'74123','watch','padding-top','20',0,''),(352662,112556,'74123','watch','padding-left','20',0,''),(352663,112556,'74123','watch','padding-right','20',0,''),(352664,112556,'74123','watch','padding-bottom','20',0,''),(352665,112556,'74123','watch','background-color','$content-bg-1',0,''),(352666,112556,'74123','watch','style_class','order-summary',0,''),(352667,112558,'74125','watch','margin-bottom','20',0,''),(352668,112558,'74125','watch','text-align','right',0,''),(352669,112559,'74126','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(352670,112560,'74127','watch','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(352671,112561,'74128','watch','block_type','1',0,''),(352672,112563,'74133','watch','block_type','2',0,''),(352673,112563,'74133','watch','font-weight','400',0,''),(352674,112563,'74133','watch','padding-bottom','20',0,''),(352675,112563,'74133','watch','schema','2-2',0,'5240'),(352676,112564,'74134','watch','show_captcha','on',0,''),(352677,112565,'74135','watch','font-weight','400',0,''),(352678,112565,'74135','watch','padding-left','40',0,''),(352679,112565,'74135','watch','time_format','24',0,''),(352680,112565,'74135','watch','show_icons','on',0,''),(352681,112565,'74135','watch','padding-left','0',0,'5240'),(352682,112566,'74136','watch','block_type','1',0,''),(352683,112567,'74137','watch','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(352684,112568,'74138','watch','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(352685,112568,'74138','watch','margin-bottom','40',0,''),(352686,112569,'74139','watch','width','680',0,''),(352687,112569,'74139','watch','font-weight','normal',0,''),(352688,112569,'74139','watch','font-size','12',0,''),(352689,112569,'74139','watch','padding-top','20',0,''),(352690,112569,'74139','watch','padding-bottom','20',0,''),(352691,112569,'74139','watch','color','$content-color-1',0,''),(352692,112570,'74140','watch','block_type','3',0,''),(352693,112570,'74140','watch','font-weight','normal',0,''),(352694,112570,'74140','watch','padding-top','20',0,''),(352695,112571,'74141','watch','font-size','12',0,''),(352696,112572,'74142','watch','text','<p>If undelivered please return to:</p>',1,''),(352697,112572,'74142','watch','font-size','12',0,''),(352698,112572,'74142','watch','font-weight','bold',0,''),(352699,112572,'74142','watch','text','<p>If undelivered please return to:</p>',2,''),(352700,112572,'74142','watch','text','<p>If undelivered please return to:</p>',3,''),(352701,112572,'74142','watch','text','<p>If undelivered please return to:</p>',4,''),(352702,112573,'74143','watch','text','<p>Thank you for your order</p>',1,''),(352703,112573,'74143','watch','color','$color-8',0,''),(352704,112573,'74143','watch','font-size','13',0,''),(352705,112573,'74143','watch','font-weight','bold',0,''),(352706,112573,'74143','watch','padding-top','5',0,''),(352707,112573,'74143','watch','text-align','center',0,''),(352708,112573,'74143','watch','text','<p>Thank you for your order</p>',2,''),(352709,112573,'74143','watch','text','<p>Thank you for your order</p>',3,''),(352710,112573,'74143','watch','text','<p>Thank you for your order</p>',4,''),(352711,112574,'74144','watch','font-weight','400',0,''),(352712,112574,'74144','watch','text-align','center',0,''),(352713,112574,'74144','watch','padding-top','0',0,''),(352715,112574,'74144','watch','padding-left','20',0,''),(352716,112574,'74144','watch','padding-right','20',0,''),(352720,112575,'74145','watch','text','<p>If something has gone wrong please contact us at:</p>',1,''),(352721,112575,'74145','watch','font-size','12',0,''),(352722,112575,'74145','watch','font-weight','bold',0,''),(352723,112575,'74145','watch','text-align','right',0,''),(352724,112575,'74145','watch','text','<p>If something has gone wrong please contact us at:</p>',2,''),(352725,112575,'74145','watch','text','<p>If something has gone wrong please contact us at:</p>',3,''),(352726,112575,'74145','watch','text','<p>If something has gone wrong please contact us at:</p>',4,''),(352727,112576,'74146','watch','block_type','6',0,''),(352728,112576,'74146','watch','font-weight','normal',0,''),(352729,112576,'74146','watch','font-size','16',0,''),(352730,112577,'74147','watch','text','<p>Email:</p>',1,''),(352731,112577,'74147','watch','font-weight','normal',0,''),(352732,112577,'74147','watch','text-align','right',0,''),(352733,112577,'74147','watch','font-size','12',0,''),(352734,112577,'74147','watch','text','<p>Email:</p>',2,''),(352735,112577,'74147','watch','text','<p>Email:</p>',3,''),(352736,112577,'74147','watch','text','<p>Email:</p>',4,''),(352737,112578,'74148','watch','font-weight','normal',0,''),(352738,112578,'74148','watch','text-align','right',0,''),(352739,112578,'74148','watch','font-size','12',0,''),(352740,112579,'74149','watch','block_type','6',0,''),(352741,112579,'74149','watch','font-weight','normal',0,''),(352742,112579,'74149','watch','font-size','16',0,''),(352743,112580,'74150','watch','text','<p>Phone:</p>',1,''),(352744,112580,'74150','watch','font-weight','normal',0,''),(352745,112580,'74150','watch','text-align','right',0,''),(352746,112580,'74150','watch','font-size','12',0,''),(352747,112580,'74150','watch','text','<p>Phone:</p>',2,''),(352748,112580,'74150','watch','text','<p>Phone:</p>',3,''),(352749,112580,'74150','watch','text','<p>Phone:</p>',4,''),(352750,112581,'74151','watch','font-weight','normal',0,''),(352751,112581,'74151','watch','text-align','right',0,''),(352752,112581,'74151','watch','font-size','12',0,''),(352753,112582,'74152','watch','font-weight','400',0,''),(352754,112582,'74152','watch','padding-top','20',0,''),(352755,112582,'74152','watch','padding-bottom','0',0,''),(352756,112582,'74152','watch','font-size','12',0,''),(352757,112583,'74153','watch','block_type','2',0,''),(352758,112583,'74153','watch','font-weight','normal',0,''),(352759,112583,'74153','watch','padding-bottom','20',0,''),(352760,112584,'74154','watch','font-weight','400',0,''),(352761,112584,'74154','watch','padding-top','20',0,''),(352766,112585,'74155','watch','block_type','11',0,''),(352767,112585,'74155','watch','font-weight','normal',0,''),(352768,112586,'74156','watch','text','<p>Web:</p>',1,''),(352769,112586,'74156','watch','font-weight','normal',0,''),(352770,112586,'74156','watch','text-align','right',0,''),(352771,112586,'74156','watch','text','<p>Web:</p>',2,''),(352772,112586,'74156','watch','text','<p>Web:</p>',3,''),(352773,112586,'74156','watch','text','<p>Web:</p>',4,''),(352774,112587,'74157','watch','font-weight','normal',0,''),(352775,112587,'74157','watch','text-align','right',0,''),(352776,112588,'74158','watch','block_type','11',0,''),(352777,112588,'74158','watch','font-weight','normal',0,''),(352778,112589,'74159','watch','text','<p>Phone:</p>',1,''),(352779,112589,'74159','watch','font-weight','normal',0,''),(352780,112589,'74159','watch','text-align','right',0,''),(352781,112589,'74159','watch','text','<p>Phone:</p>',2,''),(352782,112589,'74159','watch','text','<p>Phone:</p>',3,''),(352783,112589,'74159','watch','text','<p>Phone:</p>',4,''),(352784,112590,'74160','watch','font-weight','normal',0,''),(352785,112590,'74160','watch','text-align','right',0,''),(352786,112591,'74161','watch','block_type','11',0,''),(352787,112591,'74161','watch','font-weight','normal',0,''),(352788,112592,'74162','watch','text','<p>Email:</p>',1,''),(352789,112592,'74162','watch','font-weight','normal',0,''),(352790,112592,'74162','watch','text-align','right',0,''),(352791,112592,'74162','watch','text','<p>Email:</p>',2,''),(352792,112592,'74162','watch','text','<p>Email:</p>',3,''),(352793,112592,'74162','watch','text','<p>Email:</p>',4,''),(352794,112593,'74163','watch','font-weight','normal',0,''),(352795,112593,'74163','watch','text-align','right',0,''),(352796,112594,'74164','watch','block_type','1',0,''),(352797,112595,'74165','watch','font-weight','normal',0,''),(352798,112595,'74165','watch','text-align','right',0,''),(352799,112595,'74165','watch','padding-bottom','10',0,''),(352800,112595,'74165','watch','address_spacer',',',0,''),(352801,112595,'74165','watch','font-size','12',0,''),(352802,112596,'74166','watch','block_type','5',0,''),(352803,112596,'74166','watch','font-weight','normal',0,''),(352804,112596,'74166','watch','border-bottom-width','1',0,''),(352805,112596,'74166','watch','border-bottom-color','$content-border-1',0,''),(352806,112596,'74166','watch','border-top-width','1',0,''),(352807,112596,'74166','watch','border-top-color','$content-border-1',0,''),(352808,112596,'74166','watch','border-left-color','$content-border-1',0,''),(352809,112596,'74166','watch','border-left-width','1',0,''),(352810,112597,'74167','watch','block_type','1',0,''),(352811,112597,'74167','watch','font-weight','normal',0,''),(352812,112597,'74167','watch','padding-top','10',0,''),(352813,112597,'74167','watch','padding-left','10',0,''),(352814,112597,'74167','watch','padding-right','10',0,''),(352815,112598,'74168','watch','font-weight','400',0,''),(352816,112598,'74168','watch','line-height','120',0,''),(352817,112598,'74168','watch','line_height_measure','%',0,''),(352818,112598,'74168','watch','font-size','12',0,''),(352819,112599,'74169','watch','text','<p>SHIPPING ADDRESS:</p>',1,''),(352820,112599,'74169','watch','font-size','14',0,''),(352821,112599,'74169','watch','font-weight','bold',0,''),(352822,112599,'74169','watch','padding-bottom','10',0,''),(352823,112599,'74169','watch','text','<p>SHIPPING ADDRESS:</p>',2,''),(352824,112599,'74169','watch','text','<p>SHIPPING ADDRESS:</p>',3,''),(352825,112599,'74169','watch','text','<p>SHIPPING ADDRESS:</p>',4,''),(352826,112600,'74170','watch','block_type','1',0,''),(352827,112600,'74170','watch','background-color','$content-bg-2',0,''),(352828,112600,'74170','watch','padding-top','20',0,''),(352829,112600,'74170','watch','padding-left','10',0,''),(352830,112600,'74170','watch','padding-right','10',0,''),(352831,112600,'74170','watch','padding-bottom','20',0,''),(352832,112600,'74170','watch','font-size','14',0,''),(352833,112601,'74171','watch','block_type','4',0,''),(352834,112601,'74171','watch','font-weight','normal',0,''),(352835,112601,'74171','watch','border-top-width','1',0,''),(352836,112601,'74171','watch','border-top-color','$content-border-1',0,''),(352837,112601,'74171','watch','border-left-width','1',0,''),(352838,112601,'74171','watch','border-left-color','$content-border-1',0,''),(352839,112601,'74171','watch','border-right-width','1',0,''),(352840,112601,'74171','watch','border-right-color','$content-border-1',0,''),(352841,112601,'74171','watch','border-bottom-width','1',0,''),(352842,112601,'74171','watch','border-bottom-color','$content-border-1',0,''),(352843,112602,'74172','watch','block_type','2',0,''),(352844,112602,'74172','watch','font-weight','normal',0,''),(352845,112602,'74172','watch','border-right-width','1',0,''),(352846,112602,'74172','watch','border-right-color','$content-border-1',0,''),(352847,112603,'74173','watch','block_type','1',0,''),(352848,112603,'74173','watch','font-weight','400',0,''),(352849,112603,'74173','watch','background-color','$content-bg-2',0,''),(352850,112603,'74173','watch','padding-top','10',0,''),(352851,112603,'74173','watch','padding-left','10',0,''),(352852,112603,'74173','watch','padding-right','10',0,''),(352853,112603,'74173','watch','padding-bottom','30',0,''),(352854,112604,'74174','watch','text','<p>INVOICE ADDRESS:</p>',1,''),(352855,112604,'74174','watch','font-size','14',0,''),(352856,112604,'74174','watch','font-weight','bold',0,''),(352857,112604,'74174','watch','text','<p>INVOICE ADDRESS:</p>',2,''),(352858,112604,'74174','watch','text','<p>INVOICE ADDRESS:</p>',3,''),(352859,112604,'74174','watch','text','<p>INVOICE ADDRESS:</p>',4,''),(352860,112605,'74175','watch','font-size','12',0,''),(352861,112606,'74176','watch','block_type','1',0,''),(352862,112606,'74176','watch','font-weight','normal',0,''),(352863,112606,'74176','watch','padding-top','10',0,''),(352864,112606,'74176','watch','padding-left','10',0,''),(352865,112606,'74176','watch','padding-right','10',0,''),(352866,112606,'74176','watch','padding-bottom','10',0,''),(352867,112607,'74177','watch','font-weight','normal',0,''),(352868,112608,'74178','watch','text','<p>CUSTOMER:</p>',1,''),(352869,112608,'74178','watch','font-size','13',0,''),(352870,112608,'74178','watch','font-weight','bold',0,''),(352871,112608,'74178','watch','text','<p>CUSTOMER:</p>',2,''),(352872,112608,'74178','watch','text','<p>CUSTOMER:</p>',3,''),(352873,112608,'74178','watch','text','<p>CUSTOMER:</p>',4,''),(352874,112609,'74179','watch','text','<p>PHONE NUMBER:</p>',1,''),(352875,112609,'74179','watch','font-size','14',0,''),(352876,112609,'74179','watch','font-weight','bold',0,''),(352877,112609,'74179','watch','padding-top','10',0,''),(352878,112609,'74179','watch','text','<p>PHONE NUMBER:</p>',2,''),(352879,112609,'74179','watch','text','<p>PHONE NUMBER:</p>',3,''),(352880,112609,'74179','watch','text','<p>PHONE NUMBER:</p>',4,''),(352881,112610,'74180','watch','font-weight','normal',0,''),(352882,112612,'74182','watch','text','<p>E-MAIL ADDRESS:</p>',1,''),(352883,112612,'74182','watch','font-weight','bold',0,''),(352884,112612,'74182','watch','font-size','14',0,''),(352885,112612,'74182','watch','padding-top','10',0,''),(352886,112612,'74182','watch','text','<p>E-MAIL ADDRESS:</p>',2,''),(352887,112612,'74182','watch','text','<p>E-MAIL ADDRESS:</p>',3,''),(352888,112612,'74182','watch','text','<p>E-MAIL ADDRESS:</p>',4,''),(352889,112613,'74183','watch','block_type','2',0,''),(352890,112613,'74183','watch','font-weight','normal',0,''),(352891,112613,'74183','watch','border-top-width','1',0,''),(352892,112613,'74183','watch','border-top-color','$content-border-1',0,''),(352893,112613,'74183','watch','border-right-width','1',0,''),(352894,112613,'74183','watch','border-right-color','$content-border-1',0,''),(352895,112614,'74184','watch','block_type','1',0,''),(352896,112614,'74184','watch','font-weight','normal',0,''),(352897,112614,'74184','watch','padding-top','10',0,''),(352898,112614,'74184','watch','padding-left','10',0,''),(352899,112614,'74184','watch','padding-right','10',0,''),(352900,112614,'74184','watch','padding-bottom','10',0,''),(352901,112614,'74184','watch','border-right-width','1',0,''),(352902,112614,'74184','watch','border-right-color','$content-border-1',0,''),(352903,112616,'74186','watch','text','<p>Shipping via</p>',1,''),(352904,112616,'74186','watch','font-weight','bold',0,''),(352905,112616,'74186','watch','font-size','14',0,''),(352906,112616,'74186','watch','text','<p>Shipping via</p>',2,''),(352907,112616,'74186','watch','text','<p>Shipping via</p>',3,''),(352908,112616,'74186','watch','text','<p>Shipping via</p>',4,''),(352909,112617,'74187','watch','block_type','1',0,''),(352910,112617,'74187','watch','font-weight','normal',0,''),(352911,112617,'74187','watch','padding-top','10',0,''),(352912,112617,'74187','watch','padding-left','10',0,''),(352913,112617,'74187','watch','padding-right','10',0,''),(352914,112617,'74187','watch','padding-bottom','10',0,''),(352915,112618,'74188','watch','text','<p>Shipping service</p>',1,''),(352916,112618,'74188','watch','font-weight','bold',0,''),(352917,112618,'74188','watch','font-size','14',0,''),(352918,112618,'74188','watch','text','<p>Shipping service</p>',2,''),(352919,112618,'74188','watch','text','<p>Shipping service</p>',3,''),(352920,112618,'74188','watch','text','<p>Shipping service</p>',4,''),(352921,112620,'74190','watch','font-size','14',0,''),(352922,112620,'74190','watch','font-weight','bold',0,''),(352923,112620,'74190','watch','text-align','center',0,''),(352924,112620,'74190','watch','padding-bottom','10',0,''),(352925,112620,'74190','watch','padding-top','10',0,''),(352926,112621,'74191','watch','text','<p>Payment date:</p>',1,''),(352927,112621,'74191','watch','font-weight','bold',0,''),(352928,112621,'74191','watch','text-align','center',0,''),(352929,112621,'74191','watch','font-size','12',0,''),(352930,112621,'74191','watch','text','<p>Payment date:</p>',2,''),(352931,112621,'74191','watch','text','<p>Payment date:</p>',3,''),(352932,112621,'74191','watch','text','<p>Payment date:</p>',4,''),(352933,112622,'74192','watch','font-weight','normal',0,''),(352934,112622,'74192','watch','text-align','center',0,''),(352935,112622,'74192','watch','padding-bottom','10',0,''),(352936,112629,'74199','watch','text-align','center',0,''),(352937,112629,'74199','watch','padding-top','10',0,''),(352938,112631,'74201','watch','heading_type','h1',0,''),(352939,112634,'94718','watch','text-align','center',0,''),(352940,112634,'94718','watch','padding-top','10',0,''),(352941,112639,'74202','watch','block_type','1',0,''),(352942,112640,'74203','watch','block_type','1',0,''),(352943,112640,'74203','watch','max-width','800',0,''),(352944,112640,'74203','watch','margin','0 auto',0,''),(352945,112640,'74203','watch','background-color','$content-bg-1',0,''),(352946,112641,'74204','watch','color','$content-color-1',0,''),(352947,112641,'74204','watch','font-size','12',0,''),(352948,112641,'74204','watch','padding-top','20',0,''),(352949,112641,'74204','watch','padding-bottom','20',0,''),(352950,112641,'74204','watch','border-top-width','1',0,''),(352951,112641,'74204','watch','border-top-color','$content-border-1',0,''),(352952,112642,'74205','watch','font-weight','normal',0,''),(352953,112642,'74205','watch','padding-top','20',0,''),(352954,112642,'74205','watch','padding-left','10',0,''),(352955,112642,'74205','watch','padding-right','10',0,''),(352956,112642,'74205','watch','padding-bottom','20',0,''),(352957,112642,'74205','watch','color','$content-color-1',0,''),(352958,112642,'74205','watch','font-size','14',0,''),(352959,112643,'74206','watch','block_type','7',0,''),(352960,112643,'74206','watch','font-weight','normal',0,''),(352961,112643,'74206','watch','background-color','$highlight-box-bg-1',0,''),(352962,112643,'74206','watch','padding-top','5',0,''),(352963,112643,'74206','watch','padding-left','10',0,''),(352964,112643,'74206','watch','padding-right','10',0,''),(352965,112643,'74206','watch','padding-bottom','5',0,''),(352966,112644,'74207','watch','color','$highlight-box-color-1',0,''),(352967,112644,'74207','watch','font-size','14',0,''),(352968,112644,'74207','watch','font-weight','normal',0,''),(352969,112645,'74208','watch','font-weight','normal',0,''),(352970,112645,'74208','watch','text-align','right',0,''),(352971,112645,'74208','watch','color','$highlight-box-color-1',0,''),(352972,112645,'74208','watch','font-size','12',0,''),(352973,112646,'74209','watch','font-weight','normal',0,''),(352974,112646,'74209','watch','padding-bottom','10',0,''),(352975,112646,'74209','watch','padding-top','10',0,''),(352976,112646,'74209','watch','logo_from','theme',0,''),(352977,112647,'74210','watch','block_type','1',0,''),(352978,112648,'74211','watch','block_type','1',0,''),(352979,112648,'74211','watch','max-width','800',0,''),(352980,112648,'74211','watch','margin','0 auto',0,''),(352981,112648,'74211','watch','background-color','$content-bg-1',0,''),(352982,112649,'74212','watch','color','$content-color-1',0,''),(352983,112649,'74212','watch','font-size','12',0,''),(352984,112649,'74212','watch','padding-top','20',0,''),(352985,112649,'74212','watch','padding-bottom','20',0,''),(352986,112649,'74212','watch','border-top-width','1',0,''),(352987,112649,'74212','watch','border-top-color','$content-border-1',0,''),(352988,112650,'74213','watch','font-weight','normal',0,''),(352989,112650,'74213','watch','padding-bottom','10',0,''),(352990,112650,'74213','watch','background-color','$highlight-box-bg-1',0,''),(352992,112650,'74213','watch','padding-left','20',0,''),(352993,112650,'74213','watch','padding-top','10',0,''),(352997,112651,'74214','watch','font-weight','normal',0,''),(352998,112651,'74214','watch','padding-top','20',0,''),(352999,112651,'74214','watch','padding-left','10',0,''),(353000,112651,'74214','watch','padding-right','10',0,''),(353001,112651,'74214','watch','padding-bottom','20',0,''),(353002,112651,'74214','watch','color','$content-color-1',0,''),(353003,112651,'74214','watch','font-size','14',0,''),(353004,112652,'74215','watch','block_type','7',0,''),(353005,112652,'74215','watch','font-weight','normal',0,''),(353006,112652,'74215','watch','background-color','$highlight-box-bg-1',0,''),(353007,112652,'74215','watch','padding-top','5',0,''),(353008,112652,'74215','watch','padding-left','10',0,''),(353009,112652,'74215','watch','padding-right','10',0,''),(353010,112652,'74215','watch','padding-bottom','5',0,''),(353011,112653,'74216','watch','color','$highlight-box-color-1',0,''),(353012,112653,'74216','watch','font-size','15',0,''),(353013,112653,'74216','watch','font-weight','700',0,''),(353014,112654,'74217','watch','font-weight','normal',0,''),(353015,112654,'74217','watch','text-align','right',0,''),(353016,112654,'74217','watch','color','$highlight-box-color-1',0,''),(353017,112654,'74217','watch','font-size','12',0,''),(353018,112655,'74218','watch','block_type','1',0,''),(353019,112655,'74218','watch','background-color','$content-bg-2',0,''),(353020,112656,'74219','watch','block_type','1',0,''),(353021,112656,'74219','watch','max-width','800',0,''),(353022,112656,'74219','watch','margin','0 auto',0,''),(353023,112657,'74220','watch','block_type','1',0,''),(353024,112657,'74220','watch','background-color','$content-bg-1',0,''),(353025,112657,'74220','watch','padding-top','20',0,''),(353026,112657,'74220','watch','padding-left','20',0,''),(353027,112657,'74220','watch','padding-right','20',0,''),(353028,112657,'74220','watch','padding-bottom','20',0,''),(353029,112658,'74221','watch','font-weight','normal',0,''),(353030,112658,'74221','watch','padding-top','20',0,''),(353031,112658,'74221','watch','padding-bottom','20',0,''),(353032,112658,'74221','watch','color','$content-color-1',0,''),(353033,112658,'74221','watch','font-size','14',0,''),(353034,112659,'74222','watch','block_type','7',0,''),(353035,112659,'74222','watch','font-weight','normal',0,''),(353036,112659,'74222','watch','padding-left','10',0,''),(353037,112659,'74222','watch','padding-right','10',0,''),(353038,112659,'74222','watch','padding-bottom','15',0,''),(353039,112659,'74222','watch','border-bottom-width','1',0,''),(353040,112659,'74222','watch','border-bottom-color','$content-border-1',0,''),(353041,112660,'74223','watch','color','$content-color-1',0,''),(353042,112660,'74223','watch','font-size','14',0,''),(353043,112660,'74223','watch','font-weight','700',0,''),(353044,112661,'74224','watch','font-weight','normal',0,''),(353045,112661,'74224','watch','text-align','right',0,''),(353046,112661,'74224','watch','color','$fade-color-1',0,''),(353047,112661,'74224','watch','font-size','11',0,''),(353048,112661,'74224','watch','text-transform','uppercase',0,''),(353049,112662,'74225','watch','color','$fade-color-1',0,''),(353050,112662,'74225','watch','font-size','12',0,''),(353051,112662,'74225','watch','padding-top','20',0,''),(353052,112662,'74225','watch','padding-bottom','20',0,''),(353053,112662,'74225','watch','text-align','center',0,''),(353054,112663,'74226','watch','font-weight','normal',0,''),(353055,112663,'74226','watch','padding-bottom','10',0,''),(353056,112663,'74226','watch','padding-top','10',0,''),(353057,112663,'74226','watch','text-align','center',0,''),(353058,112663,'74226','watch','logo_from','theme',0,''),(353059,112664,'74227','watch','block_type','1',0,''),(353060,112664,'74227','watch','background-color','$content-bg-2',0,''),(353061,112664,'74227','watch','padding-top','20',0,''),(353062,112664,'74227','watch','padding-bottom','20',0,''),(353063,112665,'74228','watch','block_type','1',0,''),(353064,112665,'74228','watch','max-width','800',0,''),(353065,112665,'74228','watch','margin','0 auto',0,''),(353066,112666,'74229','watch','color','$fade-color-1',0,''),(353067,112666,'74229','watch','font-size','12',0,''),(353068,112666,'74229','watch','padding-top','20',0,''),(353069,112666,'74229','watch','padding-bottom','20',0,''),(353070,112666,'74229','watch','text-align','left',0,''),(353071,112667,'74230','watch','block_type','1',0,''),(353072,112667,'74230','watch','background-color','$content-bg-1',0,''),(353073,112667,'74230','watch','padding-top','20',0,''),(353074,112667,'74230','watch','padding-left','20',0,''),(353075,112667,'74230','watch','padding-right','20',0,''),(353076,112667,'74230','watch','padding-bottom','20',0,''),(353077,112667,'74230','watch','border-top-width','1',0,''),(353078,112667,'74230','watch','border-left-width','1',0,''),(353079,112667,'74230','watch','border-right-width','1',0,''),(353080,112667,'74230','watch','border-bottom-width','1',0,''),(353081,112667,'74230','watch','border-top-color','$content-border-1',0,''),(353082,112667,'74230','watch','border-left-color','$content-border-1',0,''),(353083,112667,'74230','watch','border-bottom-color','$content-border-1',0,''),(353084,112667,'74230','watch','border-right-color','$content-border-1',0,''),(353085,112668,'74231','watch','block_type','2',0,''),(353086,112669,'74232','watch','font-weight','normal',0,''),(353087,112669,'74232','watch','padding-bottom','10',0,''),(353088,112669,'74232','watch','padding-top','10',0,''),(353089,112669,'74232','watch','logo_from','theme',0,''),(353090,112670,'74233','watch','font-weight','normal',0,''),(353091,112670,'74233','watch','text-align','right',0,''),(353092,112670,'74233','watch','color','$fade-color-1',0,''),(353093,112670,'74233','watch','font-size','11',0,''),(353094,112670,'74233','watch','text-transform','uppercase',0,''),(353095,112671,'74234','watch','color','$content-color-1',0,''),(353096,112671,'74234','watch','font-size','14',0,''),(353097,112671,'74234','watch','font-weight','700',0,''),(353098,112671,'74234','watch','text-align','right',0,''),(353099,112672,'74235','watch','font-weight','normal',0,''),(353100,112672,'74235','watch','padding-top','20',0,''),(353101,112672,'74235','watch','padding-bottom','20',0,''),(353102,112672,'74235','watch','color','$content-color-1',0,''),(353103,112672,'74235','watch','font-size','14',0,''),(353104,112673,'74236','watch','block_type','1',0,''),(353105,112673,'74236','watch','font-weight','normal',0,''),(353106,112673,'74236','watch','padding-top','20',0,''),(353107,112673,'74236','watch','background-color','$footer-bg-1',0,''),(353108,112673,'74236','watch','color','$footer-color-1',0,''),(353109,112674,'74237','watch','block_type','14',0,''),(353110,112674,'74237','watch','margin-bottom','15',0,''),(353111,112674,'74237','watch','schema','14-2',0,'5240'),(353112,112674,'74237','watch','schema','14-3',0,'5232'),(353113,112674,'74237','watch','style_class','preFooter',0,''),(353114,112674,'74237','watch','visibility_checkout','1',0,''),(353115,112675,'74238','watch','block_type','1',0,''),(353116,112676,'74239','watch','class','menu-style-2',0,''),(353117,112677,'1695906739.5696','watch','text','##NAVBAR_TITLE_ACCOUNT##',0,''),(353118,112677,'1695906739.5696','watch','style_class','footerTitle',0,''),(353119,112677,'1695906739.5696','watch','font-family','$font-1',0,''),(353120,112677,'1695906739.5696','watch','font-size','20',0,''),(353121,112677,'1695906739.5696','watch','text-transform','uppercase',0,''),(353122,112678,'74241','watch','block_type','1',0,''),(353123,112679,'74243','watch','class','menu-style-2',0,''),(353124,112680,'1695906751.0591','watch','text','##TEXT_PRODUCTS##',0,''),(353125,112680,'1695906751.0591','watch','font-family','$font-1',0,''),(353126,112680,'1695906751.0591','watch','font-size','20',0,''),(353127,112680,'1695906751.0591','watch','text-transform','uppercase',0,''),(353128,112680,'1695906751.0591','watch','style_class','footerTitle',0,''),(353129,112681,'74244','watch','block_type','1',0,''),(353130,112682,'74246','watch','class','menu-style-2',0,''),(353131,112683,'1695906756.0887','watch','text','##TEXT_SHOP##',0,''),(353132,112683,'1695906756.0887','watch','style_class','footerTitle',0,''),(353133,112683,'1695906756.0887','watch','font-family','$font-1',0,''),(353134,112683,'1695906756.0887','watch','font-size','20',0,''),(353135,112683,'1695906756.0887','watch','text-transform','uppercase',0,''),(353136,112684,'74247','watch','block_type','1',0,''),(353137,112685,'74248','watch','view_item','phone_number',0,''),(353138,112686,'74249','watch','view_item','address',0,''),(353139,112686,'74249','watch','address_spacer',',<span> </span>',0,''),(353140,112687,'1695906761.6568','watch','text','##TEXT_CONTACT##',0,''),(353141,112687,'1695906761.6568','watch','font-family','$font-1',0,''),(353142,112687,'1695906761.6568','watch','font-size','20',0,''),(353143,112687,'1695906761.6568','watch','text-transform','uppercase',0,''),(353144,112687,'1695906761.6568','watch','style_class','footerTitle',0,''),(353145,112688,'74256','watch','block_type','2',0,''),(353146,112688,'74256','watch','font-weight','400',0,''),(353147,112688,'74256','watch','padding-top','20',0,''),(353148,112688,'74256','watch','padding-bottom','20',0,''),(353149,112688,'74256','watch','schema','2-2',0,''),(353150,112688,'74256','watch','schema','2-3',0,'5240'),(353151,112690,'74258','watch','address_spacer',', ',0,''),(353152,112690,'74258','watch','font-weight','400',0,''),(353153,112690,'74258','watch','padding-bottom','10',0,'5240'),(353154,112690,'74258','watch','margin-bottom','10',0,'5240'),(353155,112690,'74258','watch','border-bottom-width','1',0,'5240'),(353156,112690,'74258','watch','border-bottom-color','$content-border-1',0,'5240'),(353157,112691,'94723','watch','block_type','5',0,''),(353158,112692,'94724','watch','text','##TEXT_LANGUAGE##',0,''),(353159,112694,'94726','watch','block_type','5',0,''),(353160,112695,'94727','watch','text','##TEXT_CURRENCY##',0,''),(353161,112697,'74263','watch','block_type','1',0,''),(353162,112697,'74263','watch','font-weight','normal',0,''),(353163,112698,'74264','watch','block_type','2',0,''),(353164,112698,'74264','watch','font-weight','normal',0,''),(353165,112698,'74264','watch','padding-bottom','20',0,''),(353166,112699,'74265','watch','block_type','1',0,''),(353167,112699,'74265','watch','margin-right','20',0,''),(353168,112702,'74268','watch','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(353169,112702,'74268','watch','font-weight','normal',0,''),(353170,112702,'74268','watch','padding-bottom','20',0,''),(353171,112702,'74268','watch','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(353172,112702,'74268','watch','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(353173,112702,'74268','watch','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(353174,112704,'74270','watch','block_type','1',0,''),(353175,112704,'74270','watch','font-weight','normal',0,''),(353176,112704,'74270','watch','style_class','gift-card-view',0,''),(353177,112704,'74270','watch','text-align','center',0,''),(353178,112704,'74270','watch','padding-bottom','20',0,''),(353179,112704,'74270','watch','background-color','$highlight-box-bg-1',0,''),(353180,112704,'74270','watch','padding-left','20',0,''),(353181,112704,'74270','watch','padding-right','20',0,''),(353182,112704,'74270','watch','color','$highlight-box-color-1',0,''),(353183,112705,'74271','watch','block_type','1',0,''),(353184,112705,'74271','watch','font-weight','normal',0,''),(353185,112705,'74271','watch','padding-top','10',0,''),(353186,112706,'74272','watch','font-size','12',0,''),(353187,112706,'74272','watch','font-weight','bold',0,''),(353188,112706,'74272','watch','text-align','center',0,''),(353189,112706,'74272','watch','style_class','email',0,''),(353190,112707,'74273','watch','text','<p>If you require further assistance please contact us</p>',1,''),(353191,112707,'74273','watch','font-weight','normal',0,''),(353192,112707,'74273','watch','text-align','center',0,''),(353193,112707,'74273','watch','font-size','12',0,''),(353194,112707,'74273','watch','padding-top','10',0,''),(353195,112707,'74273','watch','padding-bottom','5',0,''),(353196,112707,'74273','watch','border-top-width','1',0,''),(353197,112707,'74273','watch','border-top-color','$content-border-3',0,''),(353198,112707,'74273','watch','text','<p>If you require further assistance please contact us</p>',2,''),(353199,112707,'74273','watch','text','<p>If you require further assistance please contact us</p>',3,''),(353200,112707,'74273','watch','text','<p>If you require further assistance please contact us</p>',4,''),(353201,112708,'74274','watch','font-size','12',0,''),(353202,112708,'74274','watch','font-weight','bold',0,''),(353203,112708,'74274','watch','text-align','center',0,''),(353204,112708,'74274','watch','style_class','phone',0,''),(353205,112708,'74274','watch','padding-bottom','5',0,''),(353206,112709,'74275','watch','text','<p>WHAT TO DO NEXT:</p>',1,''),(353207,112709,'74275','watch','font-weight','normal',0,''),(353208,112709,'74275','watch','text-align','center',0,''),(353209,112709,'74275','watch','padding-top','20',0,''),(353210,112709,'74275','watch','padding-bottom','10',0,''),(353211,112709,'74275','watch','style_class','question-ico',0,''),(353212,112709,'74275','watch','border-top-width','1',0,''),(353213,112709,'74275','watch','border-top-color','$content-border-3',0,''),(353214,112709,'74275','watch','font-size','18',0,''),(353215,112709,'74275','watch','text','<p>WHAT TO DO NEXT:</p>',2,''),(353216,112709,'74275','watch','text','<p>WHAT TO DO NEXT:</p>',3,''),(353217,112709,'74275','watch','text','<p>WHAT TO DO NEXT:</p>',4,''),(353218,112710,'74276','watch','text','<p>osCommerce</p>\n',1,''),(353219,112710,'74276','watch','font-family','$font-1',0,''),(353220,112710,'74276','watch','font-size','24',0,''),(353221,112710,'74276','watch','font-weight','normal',0,''),(353222,112710,'74276','watch','text-align','center',0,''),(353223,112710,'74276','watch','padding-top','10',0,''),(353224,112710,'74276','watch','padding-bottom','20',0,''),(353225,112710,'74276','watch','text','<p>osCommerce</p>\n',2,''),(353226,112710,'74276','watch','text','<p>osCommerce</p>\n',3,''),(353227,112710,'74276','watch','text','<p>osCommerce</p>\n',4,''),(353228,112711,'74277','watch','block_type','4',0,''),(353229,112711,'74277','watch','color','$highlight-box-color-2',0,''),(353230,112711,'74277','watch','font-size','30',0,''),(353231,112711,'74277','watch','font-weight','normal',0,''),(353232,112711,'74277','watch','background-color','$highlight-box-bg-2',0,''),(353233,112711,'74277','watch','padding-top','5',0,''),(353234,112711,'74277','watch','padding-left','10',0,''),(353235,112711,'74277','watch','padding-right','10',0,''),(353236,112711,'74277','watch','padding-bottom','5',0,''),(353237,112712,'74278','watch','text','<p>Your code is:</p>',1,''),(353238,112712,'74278','watch','font-weight','normal',0,''),(353239,112712,'74278','watch','text','<p>Your code is:</p>',2,''),(353240,112712,'74278','watch','text','<p>Your code is:</p>',3,''),(353241,112712,'74278','watch','text','<p>Your code is:</p>',4,''),(353242,112714,'74280','watch','font-weight','normal',0,''),(353243,112714,'74280','watch','text-align','center',0,''),(353244,112714,'74280','watch','padding-bottom','20',0,''),(353245,112715,'74281','watch','font-size','60',0,''),(353246,112715,'74281','watch','font-weight','bold',0,''),(353247,112715,'74281','watch','text-align','center',0,''),(353248,112715,'74281','watch','line-height','100',0,''),(353249,112715,'74281','watch','padding-bottom','20',0,''),(353250,112715,'74281','watch','line_height_measure','px',0,''),(353251,112716,'74282','watch','text','<p>PERSONAL MESSAGE</p>',1,''),(353252,112716,'74282','watch','font-size','18',0,''),(353253,112716,'74282','watch','font-weight','normal',0,''),(353254,112716,'74282','watch','text-align','center',0,''),(353255,112716,'74282','watch','padding-top','20',0,''),(353256,112716,'74282','watch','padding-bottom','10',0,''),(353257,112716,'74282','watch','border-top-width','1',0,''),(353258,112716,'74282','watch','border-top-color','$content-border-3',0,''),(353259,112716,'74282','watch','text','<p>PERSONAL MESSAGE</p>',2,''),(353260,112716,'74282','watch','text','<p>PERSONAL MESSAGE</p>',3,''),(353261,112716,'74282','watch','text','<p>PERSONAL MESSAGE</p>',4,''),(353266,112717,'74284','watch','text-align','center',0,''),(353267,112717,'74284','watch','padding-top','20',0,''),(353268,112717,'74284','watch','logo_from','theme',0,''),(353269,112718,'74285','watch','text','<p>GIFT CARD</p>',1,''),(353270,112718,'74285','watch','font-size','30',0,''),(353271,112718,'74285','watch','font-weight','normal',0,''),(353272,112718,'74285','watch','border-top-width','1',0,''),(353273,112718,'74285','watch','border-top-color','$content-border-3',0,''),(353274,112718,'74285','watch','style_class','gift-ico',0,''),(353275,112718,'74285','watch','text-align','center',0,''),(353276,112718,'74285','watch','padding-top','15',0,''),(353277,112718,'74285','watch','text','<p>GIFT CARD</p>',2,''),(353278,112718,'74285','watch','text','<p>GIFT CARD</p>',3,''),(353279,112718,'74285','watch','text','<p>GIFT CARD</p>',4,''),(353280,112719,'74286','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(353281,112719,'74286','watch','font-weight','normal',0,''),(353282,112719,'74286','watch','text-align','center',0,''),(353283,112719,'74286','watch','padding-bottom','10',0,''),(353284,112719,'74286','watch','font-size','14',0,''),(353285,112719,'74286','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(353286,112719,'74286','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(353287,112719,'74286','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(353288,112720,'74287','watch','block_type','1',0,''),(353289,112720,'74287','watch','font-weight','normal',0,''),(353290,112720,'74287','watch','style_class','gift-card-view',0,''),(353291,112720,'74287','watch','text-align','center',0,''),(353292,112720,'74287','watch','padding-bottom','20',0,''),(353293,112720,'74287','watch','background-color','$content-bg-2',0,''),(353294,112720,'74287','watch','padding-left','20',0,''),(353295,112720,'74287','watch','padding-right','20',0,''),(353296,112720,'74287','watch','color','$fade-color-2',0,''),(353297,112721,'74288','watch','font-size','60',0,''),(353298,112721,'74288','watch','font-weight','bold',0,''),(353299,112721,'74288','watch','text-align','center',0,''),(353300,112721,'74288','watch','line-height','100',0,''),(353301,112721,'74288','watch','padding-bottom','20',0,''),(353302,112721,'74288','watch','line_height_measure','px',0,''),(353303,112722,'74289','watch','block_type','4',0,''),(353304,112722,'74289','watch','color','$highlight-box-color-2',0,''),(353305,112722,'74289','watch','font-size','30',0,''),(353306,112722,'74289','watch','font-weight','normal',0,''),(353307,112722,'74289','watch','background-color','$highlight-box-bg-2',0,''),(353308,112722,'74289','watch','padding-top','5',0,''),(353309,112722,'74289','watch','padding-left','10',0,''),(353310,112722,'74289','watch','padding-right','10',0,''),(353311,112722,'74289','watch','padding-bottom','5',0,''),(353312,112723,'74290','watch','text','<p>Your code is:</p>',1,''),(353313,112723,'74290','watch','font-weight','normal',0,''),(353314,112723,'74290','watch','text','<p>Your code is:</p>',2,''),(353315,112723,'74290','watch','text','<p>Your code is:</p>',3,''),(353316,112723,'74290','watch','text','<p>Your code is:</p>',4,''),(353317,112725,'74292','watch','block_type','1',0,''),(353318,112725,'74292','watch','font-weight','normal',0,''),(353319,112725,'74292','watch','padding-top','10',0,''),(353320,112726,'74293','watch','font-size','12',0,''),(353321,112726,'74293','watch','font-weight','bold',0,''),(353322,112726,'74293','watch','text-align','center',0,''),(353323,112726,'74293','watch','style_class','email',0,''),(353324,112727,'74294','watch','text','<p>If you require further assistance please contact us</p>',1,''),(353325,112727,'74294','watch','font-weight','normal',0,''),(353326,112727,'74294','watch','text-align','center',0,''),(353327,112727,'74294','watch','font-size','12',0,''),(353328,112727,'74294','watch','padding-top','10',0,''),(353329,112727,'74294','watch','padding-bottom','5',0,''),(353330,112727,'74294','watch','border-top-width','1',0,''),(353331,112727,'74294','watch','border-top-color','$content-border-3',0,''),(353332,112727,'74294','watch','text','<p>If you require further assistance please contact us</p>',2,''),(353333,112727,'74294','watch','text','<p>If you require further assistance please contact us</p>',3,''),(353334,112727,'74294','watch','text','<p>If you require further assistance please contact us</p>',4,''),(353335,112728,'74295','watch','font-size','12',0,''),(353336,112728,'74295','watch','font-weight','bold',0,''),(353337,112728,'74295','watch','text-align','center',0,''),(353338,112728,'74295','watch','style_class','phone',0,''),(353339,112728,'74295','watch','padding-bottom','5',0,''),(353340,112729,'74296','watch','font-weight','normal',0,''),(353341,112729,'74296','watch','text-align','center',0,''),(353342,112729,'74296','watch','padding-bottom','20',0,''),(353343,112730,'74297','watch','text','<p>PERSONAL MESSAGE</p>',1,''),(353344,112730,'74297','watch','font-size','18',0,''),(353345,112730,'74297','watch','font-weight','normal',0,''),(353346,112730,'74297','watch','text-align','center',0,''),(353347,112730,'74297','watch','padding-top','20',0,''),(353348,112730,'74297','watch','padding-bottom','10',0,''),(353349,112730,'74297','watch','border-top-width','1',0,''),(353350,112730,'74297','watch','border-top-color','$content-border-3',0,''),(353351,112730,'74297','watch','text','<p>PERSONAL MESSAGE</p>',2,''),(353352,112730,'74297','watch','text','<p>PERSONAL MESSAGE</p>',3,''),(353353,112730,'74297','watch','text','<p>PERSONAL MESSAGE</p>',4,''),(353354,112731,'74298','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(353355,112731,'74298','watch','font-weight','normal',0,''),(353356,112731,'74298','watch','text-align','center',0,''),(353357,112731,'74298','watch','padding-bottom','10',0,''),(353358,112731,'74298','watch','font-size','14',0,''),(353359,112731,'74298','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(353360,112731,'74298','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(353361,112731,'74298','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(353362,112732,'74299','watch','text','<p>GIFT CARD</p>',1,''),(353363,112732,'74299','watch','font-size','30',0,''),(353364,112732,'74299','watch','font-weight','normal',0,''),(353365,112732,'74299','watch','border-top-width','1',0,''),(353366,112732,'74299','watch','border-top-color','$content-border-3',0,''),(353367,112732,'74299','watch','style_class','gift-ico',0,''),(353368,112732,'74299','watch','text-align','center',0,''),(353369,112732,'74299','watch','padding-top','15',0,''),(353370,112732,'74299','watch','text','<p>GIFT CARD</p>',2,''),(353371,112732,'74299','watch','text','<p>GIFT CARD</p>',3,''),(353372,112732,'74299','watch','text','<p>GIFT CARD</p>',4,''),(353373,112733,'74300','watch','text','<p>WHAT TO DO NEXT:</p>',1,''),(353374,112733,'74300','watch','font-weight','normal',0,''),(353375,112733,'74300','watch','text-align','center',0,''),(353376,112733,'74300','watch','padding-top','20',0,''),(353377,112733,'74300','watch','padding-bottom','10',0,''),(353378,112733,'74300','watch','style_class','question-ico',0,''),(353379,112733,'74300','watch','border-top-width','1',0,''),(353380,112733,'74300','watch','border-top-color','$content-border-3',0,''),(353381,112733,'74300','watch','font-size','18',0,''),(353382,112733,'74300','watch','text','<p>WHAT TO DO NEXT:</p>',2,''),(353383,112733,'74300','watch','text','<p>WHAT TO DO NEXT:</p>',3,''),(353384,112733,'74300','watch','text','<p>WHAT TO DO NEXT:</p>',4,''),(353385,112734,'74301','watch','text','<p>HOLBI</p>',1,''),(353386,112734,'74301','watch','font-family','$font-1',0,''),(353387,112734,'74301','watch','font-size','24',0,''),(353388,112734,'74301','watch','font-weight','normal',0,''),(353389,112734,'74301','watch','text-align','center',0,''),(353390,112734,'74301','watch','padding-top','10',0,''),(353391,112734,'74301','watch','padding-bottom','20',0,''),(353392,112734,'74301','watch','text','<p>HOLBI</p>',2,''),(353393,112734,'74301','watch','text','<p>HOLBI</p>',3,''),(353394,112734,'74301','watch','text','<p>HOLBI</p>',4,''),(353395,112735,'94729','watch','block_type','1',0,''),(353396,112735,'94729','watch','font-weight','normal',0,''),(353397,112735,'94729','watch','style_class','gift-card-view',0,''),(353398,112735,'94729','watch','text-align','center',0,''),(353399,112735,'94729','watch','padding-bottom','20',0,''),(353400,112735,'94729','watch','background-color','$content-bg-2',0,''),(353401,112735,'94729','watch','padding-left','20',0,''),(353402,112735,'94729','watch','padding-right','20',0,''),(353403,112736,'94730','watch','block_type','1',0,''),(353404,112736,'94730','watch','font-weight','normal',0,''),(353405,112736,'94730','watch','padding-top','10',0,''),(353406,112737,'94731','watch','font-size','12',0,''),(353407,112737,'94731','watch','font-weight','bold',0,''),(353408,112737,'94731','watch','text-align','center',0,''),(353409,112737,'94731','watch','style_class','email',0,''),(353410,112738,'94732','watch','font-size','12',0,''),(353411,112738,'94732','watch','font-weight','bold',0,''),(353412,112738,'94732','watch','text-align','center',0,''),(353413,112738,'94732','watch','style_class','phone',0,''),(353414,112738,'94732','watch','padding-bottom','5',0,''),(353415,112739,'94733','watch','text','If you require further assistance please contact us',0,''),(353416,112739,'94733','watch','font-size','12',0,''),(353417,112739,'94733','watch','text-align','center',0,''),(353418,112739,'94733','watch','padding-top','10',0,''),(353419,112740,'94734','watch','block_type','4',0,''),(353420,112740,'94734','watch','color','$highlight-box-color-2',0,''),(353421,112740,'94734','watch','font-size','30',0,''),(353422,112740,'94734','watch','font-weight','normal',0,''),(353423,112740,'94734','watch','background-color','$highlight-box-bg-2',0,''),(353424,112740,'94734','watch','padding-top','5',0,''),(353425,112740,'94734','watch','padding-left','10',0,''),(353426,112740,'94734','watch','padding-right','10',0,''),(353427,112740,'94734','watch','padding-bottom','5',0,''),(353428,112741,'94735','watch','text','Your code is:',0,''),(353429,112741,'94735','watch','font-size','30',0,''),(353430,112741,'94735','watch','color','$highlight-box-color-2',0,''),(353431,112742,'94736','watch','color','$highlight-box-color-2',0,''),(353432,112742,'94736','watch','font-size','30',0,''),(353433,112743,'94737','watch','block_type','1',0,''),(353434,112744,'94738','watch','text','<p>PERSONAL MESSAGE</p>',1,''),(353435,112744,'94738','watch','font-size','18',0,''),(353436,112744,'94738','watch','font-weight','normal',0,''),(353437,112744,'94738','watch','text-align','center',0,''),(353438,112744,'94738','watch','padding-top','20',0,''),(353439,112744,'94738','watch','padding-bottom','10',0,''),(353440,112744,'94738','watch','border-top-width','1',0,''),(353441,112744,'94738','watch','border-top-color','$content-border-3',0,''),(353442,112744,'94738','watch','text','<p>PERSONAL MESSAGE</p>',2,''),(353443,112744,'94738','watch','text','<p>PERSONAL MESSAGE</p>',3,''),(353444,112744,'94738','watch','text','<p>PERSONAL MESSAGE</p>',4,''),(353445,112745,'94739','watch','text','HOLBI',0,''),(353446,112745,'94739','watch','font-size','24',0,''),(353447,112745,'94739','watch','padding-top','20',0,''),(353448,112745,'94739','watch','text-align','center',0,''),(353449,112745,'94739','watch','padding-bottom','20',0,''),(353450,112746,'94740','watch','border-top-color','$content-border-3',0,''),(353451,112746,'94740','watch','border-top-width','1',0,''),(353452,112746,'94740','watch','padding-top','20',0,''),(353453,112746,'94740','watch','font-size','30',0,''),(353454,112746,'94740','watch','text-align','center',0,''),(353455,112746,'94740','watch','text','GIFT CARD',0,''),(353456,112747,'94741','watch','text-align','center',0,''),(353457,112747,'94741','watch','font-weight','bold',0,''),(353458,112747,'94741','watch','font-size','60',0,''),(353459,112748,'94742','watch','font-size','20',0,''),(353460,112748,'94742','watch','text-align','center',0,''),(353461,112748,'94742','watch','padding-top','20',0,''),(353462,112748,'94742','watch','padding-bottom','20',0,''),(353463,112749,'94743','watch','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(353464,112749,'94743','watch','text-align','center',0,''),(353465,112749,'94743','watch','font-size','14',0,''),(353466,112749,'94743','watch','padding-bottom','20',0,''),(353467,112750,'94744','watch','text','WHAT TO DO NEXT:',0,''),(353468,112750,'94744','watch','font-size','18',0,''),(353469,112750,'94744','watch','text-align','center',0,''),(353470,112750,'94744','watch','padding-top','20',0,''),(353471,112750,'94744','watch','padding-bottom','10',0,''),(353472,112750,'94744','watch','border-top-width','1',0,''),(353473,112750,'94744','watch','border-top-color','$content-border-3',0,''),(353474,112751,'94746','watch','block_type','1',0,''),(353475,112751,'94746','watch','font-weight','normal',0,''),(353476,112751,'94746','watch','style_class','gift-card-view',0,''),(353477,112751,'94746','watch','text-align','center',0,''),(353478,112751,'94746','watch','padding-bottom','20',0,''),(353479,112751,'94746','watch','background-color','$highlight-box-bg-1',0,''),(353480,112751,'94746','watch','padding-left','20',0,''),(353481,112751,'94746','watch','padding-right','20',0,''),(353482,112751,'94746','watch','color','$highlight-box-color-1',0,''),(353483,112752,'94747','watch','block_type','1',0,''),(353484,112752,'94747','watch','font-weight','normal',0,''),(353485,112752,'94747','watch','padding-top','10',0,''),(353486,112753,'94748','watch','font-size','12',0,''),(353487,112753,'94748','watch','font-weight','bold',0,''),(353488,112753,'94748','watch','text-align','center',0,''),(353489,112753,'94748','watch','style_class','email',0,''),(353490,112753,'94748','watch','color','$highlight-box-color-1',0,''),(353491,112754,'94749','watch','font-size','12',0,''),(353492,112754,'94749','watch','font-weight','bold',0,''),(353493,112754,'94749','watch','text-align','center',0,''),(353494,112754,'94749','watch','style_class','phone',0,''),(353495,112754,'94749','watch','padding-bottom','5',0,''),(353496,112754,'94749','watch','color','$highlight-box-color-1',0,''),(353497,112755,'94750','watch','text','If you require further assistance please contact us',0,''),(353498,112755,'94750','watch','font-size','12',0,''),(353499,112755,'94750','watch','color','$highlight-box-color-1',0,''),(353500,112755,'94750','watch','text-align','center',0,''),(353501,112755,'94750','watch','padding-top','10',0,''),(353502,112756,'94751','watch','block_type','4',0,''),(353503,112756,'94751','watch','color','$highlight-box-color-2',0,''),(353504,112756,'94751','watch','font-size','30',0,''),(353505,112756,'94751','watch','font-weight','normal',0,''),(353506,112756,'94751','watch','background-color','$highlight-box-bg-2',0,''),(353507,112756,'94751','watch','padding-top','5',0,''),(353508,112756,'94751','watch','padding-left','10',0,''),(353509,112756,'94751','watch','padding-right','10',0,''),(353510,112756,'94751','watch','padding-bottom','5',0,''),(353511,112757,'94752','watch','text','Your code is:',0,''),(353512,112757,'94752','watch','font-size','30',0,''),(353513,112757,'94752','watch','color','$highlight-box-color-2',0,''),(353514,112758,'94753','watch','color','$highlight-box-color-2',0,''),(353515,112758,'94753','watch','font-size','30',0,''),(353516,112759,'94754','watch','block_type','1',0,''),(353517,112760,'94755','watch','text','<p>PERSONAL MESSAGE</p>',1,''),(353518,112760,'94755','watch','font-size','18',0,''),(353519,112760,'94755','watch','font-weight','normal',0,''),(353520,112760,'94755','watch','text-align','center',0,''),(353521,112760,'94755','watch','padding-top','20',0,''),(353522,112760,'94755','watch','padding-bottom','10',0,''),(353523,112760,'94755','watch','border-top-width','1',0,''),(353524,112760,'94755','watch','border-top-color','$content-border-3',0,''),(353525,112760,'94755','watch','text','<p>PERSONAL MESSAGE</p>',2,''),(353526,112760,'94755','watch','text','<p>PERSONAL MESSAGE</p>',3,''),(353527,112760,'94755','watch','text','<p>PERSONAL MESSAGE</p>',4,''),(353528,112761,'94757','watch','border-top-color','$content-border-3',0,''),(353529,112761,'94757','watch','border-top-width','1',0,''),(353530,112761,'94757','watch','padding-top','20',0,''),(353531,112761,'94757','watch','font-size','30',0,''),(353532,112761,'94757','watch','text-align','center',0,''),(353533,112761,'94757','watch','color','$highlight-box-color-1',0,''),(353534,112761,'94757','watch','text','GIFT CARD',0,''),(353535,112762,'94758','watch','text-align','center',0,''),(353536,112762,'94758','watch','font-weight','bold',0,''),(353537,112762,'94758','watch','font-size','60',0,''),(353538,112762,'94758','watch','color','$highlight-box-color-1',0,''),(353539,112763,'94759','watch','font-size','20',0,''),(353540,112763,'94759','watch','text-align','center',0,''),(353541,112763,'94759','watch','color','$highlight-box-color-1',0,''),(353542,112763,'94759','watch','padding-top','20',0,''),(353543,112763,'94759','watch','padding-bottom','20',0,''),(353544,112764,'94760','watch','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(353545,112764,'94760','watch','text-align','center',0,''),(353546,112764,'94760','watch','color','$highlight-box-color-1',0,''),(353547,112764,'94760','watch','font-size','14',0,''),(353548,112764,'94760','watch','padding-bottom','20',0,''),(353549,112765,'94761','watch','text','WHAT TO DO NEXT:',0,''),(353550,112765,'94761','watch','font-size','18',0,''),(353551,112765,'94761','watch','text-align','center',0,''),(353552,112765,'94761','watch','padding-top','20',0,''),(353553,112765,'94761','watch','padding-bottom','10',0,''),(353554,112765,'94761','watch','border-top-width','1',0,''),(353555,112765,'94761','watch','border-top-color','$content-border-3',0,''),(353556,112766,'1707902674.2595','watch','logo_from','theme',0,''),(353557,112766,'1707902674.2595','watch','text-align','center',0,''),(353558,112766,'1707902674.2595','watch','padding-top','20',0,''),(353559,112768,'74302','watch','block_type','1',0,''),(353560,112770,'74304','watch','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(353561,112770,'74304','watch','text-align','center',0,''),(353562,112771,'74305','watch','block_type','1',0,''),(353563,112771,'74305','watch','font-weight','normal',0,''),(353564,112771,'74305','watch','style_class','gift-card-view',0,''),(353565,112771,'74305','watch','text-align','center',0,''),(353566,112771,'74305','watch','padding-bottom','20',0,''),(353567,112771,'74305','watch','background-color','$highlight-box-bg-3',0,''),(353568,112771,'74305','watch','padding-left','20',0,''),(353569,112771,'74305','watch','padding-right','20',0,''),(353570,112771,'74305','watch','color','$highlight-box-color-3',0,''),(353571,112772,'74306','watch','block_type','4',0,''),(353572,112772,'74306','watch','color','$highlight-box-color-2',0,''),(353573,112772,'74306','watch','font-size','30',0,''),(353574,112772,'74306','watch','font-weight','normal',0,''),(353575,112772,'74306','watch','background-color','$highlight-box-bg-2',0,''),(353576,112772,'74306','watch','padding-top','5',0,''),(353577,112772,'74306','watch','padding-left','10',0,''),(353578,112772,'74306','watch','padding-right','10',0,''),(353579,112772,'74306','watch','padding-bottom','5',0,''),(353580,112773,'74307','watch','text','<p>Your code is:</p>',1,''),(353581,112773,'74307','watch','font-weight','normal',0,''),(353582,112773,'74307','watch','text','<p>Your code is:</p>',2,''),(353583,112773,'74307','watch','text','<p>Your code is:</p>',3,''),(353584,112773,'74307','watch','text','<p>Your code is:</p>',4,''),(353585,112775,'74309','watch','text','<p>WHAT TO DO NEXT:</p>',1,''),(353586,112775,'74309','watch','font-weight','normal',0,''),(353587,112775,'74309','watch','text-align','center',0,''),(353588,112775,'74309','watch','padding-top','20',0,''),(353589,112775,'74309','watch','padding-bottom','10',0,''),(353590,112775,'74309','watch','style_class','question-ico',0,''),(353591,112775,'74309','watch','border-top-width','1',0,''),(353592,112775,'74309','watch','border-top-color','$content-border-3',0,''),(353593,112775,'74309','watch','font-size','18',0,''),(353594,112775,'74309','watch','text','<p>WHAT TO DO NEXT:</p>',2,''),(353595,112775,'74309','watch','text','<p>WHAT TO DO NEXT:</p>',3,''),(353596,112775,'74309','watch','text','<p>WHAT TO DO NEXT:</p>',4,''),(353597,112776,'74310','watch','text','<p>osCommerce</p>\n',1,''),(353598,112776,'74310','watch','font-family','$font-1',0,''),(353599,112776,'74310','watch','font-size','24',0,''),(353600,112776,'74310','watch','font-weight','normal',0,''),(353601,112776,'74310','watch','text-align','center',0,''),(353602,112776,'74310','watch','padding-top','10',0,''),(353603,112776,'74310','watch','padding-bottom','20',0,''),(353604,112776,'74310','watch','text','<p>osCommerce</p>\n',2,''),(353605,112776,'74310','watch','text','<p>osCommerce</p>\n',3,''),(353606,112776,'74310','watch','text','<p>osCommerce</p>\n',4,''),(353607,112777,'74311','watch','block_type','1',0,''),(353608,112777,'74311','watch','font-weight','normal',0,''),(353609,112777,'74311','watch','padding-top','10',0,''),(353610,112778,'74312','watch','text','<p>If you require further assistance please contact us</p>',1,''),(353611,112778,'74312','watch','font-weight','normal',0,''),(353612,112778,'74312','watch','text-align','center',0,''),(353613,112778,'74312','watch','font-size','12',0,''),(353614,112778,'74312','watch','padding-top','10',0,''),(353615,112778,'74312','watch','padding-bottom','5',0,''),(353616,112778,'74312','watch','border-top-width','1',0,''),(353617,112778,'74312','watch','border-top-color','$content-border-3',0,''),(353618,112778,'74312','watch','text','<p>If you require further assistance please contact us</p>',2,''),(353619,112778,'74312','watch','text','<p>If you require further assistance please contact us</p>',3,''),(353620,112778,'74312','watch','text','<p>If you require further assistance please contact us</p>',4,''),(353621,112779,'74313','watch','font-size','12',0,''),(353622,112779,'74313','watch','font-weight','bold',0,''),(353623,112779,'74313','watch','text-align','center',0,''),(353624,112779,'74313','watch','style_class','email',0,''),(353625,112780,'74314','watch','font-size','12',0,''),(353626,112780,'74314','watch','font-weight','bold',0,''),(353627,112780,'74314','watch','text-align','center',0,''),(353628,112780,'74314','watch','style_class','phone',0,''),(353629,112780,'74314','watch','padding-bottom','5',0,''),(353630,112781,'74315','watch','font-weight','normal',0,''),(353631,112781,'74315','watch','text-align','center',0,''),(353632,112781,'74315','watch','padding-bottom','20',0,''),(353633,112782,'74316','watch','text','<p>GIFT CARD</p>',1,''),(353634,112782,'74316','watch','font-size','30',0,''),(353635,112782,'74316','watch','font-weight','normal',0,''),(353636,112782,'74316','watch','border-top-width','1',0,''),(353637,112782,'74316','watch','border-top-color','$content-border-3',0,''),(353638,112782,'74316','watch','style_class','gift-ico',0,''),(353639,112782,'74316','watch','text-align','center',0,''),(353640,112782,'74316','watch','padding-top','15',0,''),(353641,112782,'74316','watch','text','<p>GIFT CARD</p>',2,''),(353642,112782,'74316','watch','text','<p>GIFT CARD</p>',3,''),(353643,112782,'74316','watch','text','<p>GIFT CARD</p>',4,''),(353644,112783,'74317','watch','text','<p>PERSONAL MESSAGE</p>',1,''),(353645,112783,'74317','watch','font-size','18',0,''),(353646,112783,'74317','watch','font-weight','normal',0,''),(353647,112783,'74317','watch','text-align','center',0,''),(353648,112783,'74317','watch','padding-top','20',0,''),(353649,112783,'74317','watch','padding-bottom','10',0,''),(353650,112783,'74317','watch','border-top-width','1',0,''),(353651,112783,'74317','watch','border-top-color','$content-border-3',0,''),(353652,112783,'74317','watch','text','<p>PERSONAL MESSAGE</p>',2,''),(353653,112783,'74317','watch','text','<p>PERSONAL MESSAGE</p>',3,''),(353654,112783,'74317','watch','text','<p>PERSONAL MESSAGE</p>',4,''),(353655,112784,'74318','watch','font-size','60',0,''),(353656,112784,'74318','watch','font-weight','bold',0,''),(353657,112784,'74318','watch','text-align','center',0,''),(353658,112784,'74318','watch','line-height','100',0,''),(353659,112784,'74318','watch','padding-bottom','20',0,''),(353660,112784,'74318','watch','line_height_measure','px',0,''),(353661,112785,'74319','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(353662,112785,'74319','watch','font-weight','normal',0,''),(353663,112785,'74319','watch','text-align','center',0,''),(353664,112785,'74319','watch','padding-bottom','10',0,''),(353665,112785,'74319','watch','font-size','14',0,''),(353666,112785,'74319','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(353667,112785,'74319','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(353668,112785,'74319','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(353669,112786,'94763','watch','block_type','1',0,''),(353670,112786,'94763','watch','font-weight','normal',0,''),(353671,112786,'94763','watch','style_class','gift-card-view',0,''),(353672,112786,'94763','watch','text-align','center',0,''),(353673,112786,'94763','watch','padding-bottom','20',0,''),(353674,112786,'94763','watch','background-color','$highlight-box-bg-3',0,''),(353675,112786,'94763','watch','padding-left','20',0,''),(353676,112786,'94763','watch','padding-right','20',0,''),(353677,112786,'94763','watch','color','$highlight-box-color-3',0,''),(353678,112787,'94764','watch','block_type','1',0,''),(353679,112787,'94764','watch','font-weight','normal',0,''),(353680,112787,'94764','watch','padding-top','10',0,''),(353681,112788,'94765','watch','font-size','12',0,''),(353682,112788,'94765','watch','font-weight','bold',0,''),(353683,112788,'94765','watch','text-align','center',0,''),(353684,112788,'94765','watch','style_class','email',0,''),(353685,112789,'94766','watch','font-size','12',0,''),(353686,112789,'94766','watch','font-weight','bold',0,''),(353687,112789,'94766','watch','text-align','center',0,''),(353688,112789,'94766','watch','style_class','phone',0,''),(353689,112789,'94766','watch','padding-bottom','5',0,''),(353690,112790,'94767','watch','text','If you require further assistance please contact us',0,''),(353691,112790,'94767','watch','font-size','12',0,''),(353692,112790,'94767','watch','text-align','center',0,''),(353693,112790,'94767','watch','padding-top','10',0,''),(353694,112791,'94768','watch','block_type','4',0,''),(353695,112791,'94768','watch','color','$highlight-box-color-2',0,''),(353696,112791,'94768','watch','font-size','30',0,''),(353697,112791,'94768','watch','font-weight','normal',0,''),(353698,112791,'94768','watch','background-color','$highlight-box-bg-2',0,''),(353699,112791,'94768','watch','padding-top','5',0,''),(353700,112791,'94768','watch','padding-left','10',0,''),(353701,112791,'94768','watch','padding-right','10',0,''),(353702,112791,'94768','watch','padding-bottom','5',0,''),(353703,112792,'94769','watch','text','Your code is:',0,''),(353704,112792,'94769','watch','font-size','30',0,''),(353705,112792,'94769','watch','color','$highlight-box-color-2',0,''),(353706,112793,'94770','watch','color','$highlight-box-color-2',0,''),(353707,112793,'94770','watch','font-size','30',0,''),(353708,112794,'94771','watch','block_type','1',0,''),(353709,112795,'94772','watch','text','<p>PERSONAL MESSAGE</p>',1,''),(353710,112795,'94772','watch','font-size','18',0,''),(353711,112795,'94772','watch','font-weight','normal',0,''),(353712,112795,'94772','watch','text-align','center',0,''),(353713,112795,'94772','watch','padding-top','20',0,''),(353714,112795,'94772','watch','padding-bottom','10',0,''),(353715,112795,'94772','watch','border-top-width','1',0,''),(353716,112795,'94772','watch','border-top-color','$content-border-3',0,''),(353717,112795,'94772','watch','text','<p>PERSONAL MESSAGE</p>',2,''),(353718,112795,'94772','watch','text','<p>PERSONAL MESSAGE</p>',3,''),(353719,112795,'94772','watch','text','<p>PERSONAL MESSAGE</p>',4,''),(353720,112796,'94773','watch','text','HOLBI',0,''),(353721,112796,'94773','watch','color','$highlight-box-color-3',0,''),(353722,112796,'94773','watch','font-size','24',0,''),(353723,112796,'94773','watch','padding-top','20',0,''),(353724,112796,'94773','watch','text-align','center',0,''),(353725,112796,'94773','watch','padding-bottom','20',0,''),(353726,112797,'94774','watch','border-top-color','$content-border-3',0,''),(353727,112797,'94774','watch','border-top-width','1',0,''),(353728,112797,'94774','watch','padding-top','20',0,''),(353729,112797,'94774','watch','font-size','30',0,''),(353730,112797,'94774','watch','text-align','center',0,''),(353731,112797,'94774','watch','color','$highlight-box-color-3',0,''),(353732,112797,'94774','watch','text','GIFT CARD',0,''),(353733,112798,'94775','watch','text-align','center',0,''),(353734,112798,'94775','watch','font-weight','bold',0,''),(353735,112798,'94775','watch','font-size','60',0,''),(353736,112798,'94775','watch','color','$highlight-box-color-3',0,''),(353737,112799,'94776','watch','font-size','20',0,''),(353738,112799,'94776','watch','text-align','center',0,''),(353739,112799,'94776','watch','padding-top','20',0,''),(353740,112799,'94776','watch','padding-bottom','20',0,''),(353741,112800,'94777','watch','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(353742,112800,'94777','watch','text-align','center',0,''),(353743,112800,'94777','watch','font-size','14',0,''),(353744,112800,'94777','watch','padding-bottom','20',0,''),(353745,112801,'94778','watch','text','WHAT TO DO NEXT:',0,''),(353746,112801,'94778','watch','font-size','18',0,''),(353747,112801,'94778','watch','text-align','center',0,''),(353748,112801,'94778','watch','padding-top','20',0,''),(353749,112801,'94778','watch','padding-bottom','10',0,''),(353750,112801,'94778','watch','border-top-width','1',0,''),(353751,112801,'94778','watch','border-top-color','$content-border-3',0,''),(353752,112802,'74328','watch','block_type','1',0,''),(353753,112802,'74328','watch','font-weight','400',0,''),(353754,112802,'74328','watch','background-color','$header-menu-bg-1',0,''),(353755,112802,'74328','watch','visibility_checkout','1',0,''),(353756,112802,'74328','watch','color','$header-menu-color-1',0,''),(353765,112805,'74331','watch','block_type','1',0,''),(353766,112805,'74331','watch','padding-top','20',0,''),(353767,112805,'74331','watch','padding-bottom','20',0,''),(353768,112805,'74331','watch','style_class','header-content',0,''),(353769,112805,'74331','watch','color','$header-color-1',0,''),(353770,112805,'74331','watch','background-color','$header-bg-1',0,''),(353802,112813,'74338','watch','block_type','1',0,''),(353803,112813,'74338','watch','border-bottom-width','1',0,''),(353804,112813,'74338','watch','border-bottom-color','$header-border-1',0,''),(353805,112813,'74338','watch','font-weight','normal',0,''),(353806,112813,'74338','watch','visibility_checkout','1',0,''),(353807,112813,'74338','watch','background-color','$header-bg-1',0,''),(353808,112813,'74338','watch','color','$header-color-1',0,''),(353847,112821,'74346','watch','block_type','1',0,''),(353848,112826,'74351','watch','width','680',0,''),(353849,112826,'74351','watch','font-weight','normal',0,''),(353850,112826,'74351','watch','font-size','12',0,''),(353851,112826,'74351','watch','padding-top','20',0,''),(353852,112826,'74351','watch','padding-bottom','20',0,''),(353853,112826,'74351','watch','color','$content-color-1',0,''),(353854,112827,'74352','watch','block_type','4',0,''),(353855,112827,'74352','watch','font-weight','normal',0,''),(353856,112827,'74352','watch','border-top-width','1',0,''),(353857,112827,'74352','watch','border-top-color','$content-border-1',0,''),(353858,112827,'74352','watch','border-left-width','1',0,''),(353859,112827,'74352','watch','border-left-color','$content-border-1',0,''),(353860,112827,'74352','watch','border-right-width','1',0,''),(353861,112827,'74352','watch','border-right-color','$content-border-1',0,''),(353862,112827,'74352','watch','border-bottom-width','1',0,''),(353863,112827,'74352','watch','border-bottom-color','$content-border-1',0,''),(353864,112828,'74353','watch','block_type','2',0,''),(353865,112828,'74353','watch','font-weight','normal',0,''),(353866,112828,'74353','watch','border-top-width','1',0,''),(353867,112828,'74353','watch','border-top-color','$content-border-1',0,''),(353868,112828,'74353','watch','border-right-width','1',0,''),(353869,112828,'74353','watch','border-right-color','$content-border-1',0,''),(353870,112829,'74354','watch','block_type','1',0,''),(353871,112829,'74354','watch','font-weight','normal',0,''),(353872,112829,'74354','watch','padding-top','10',0,''),(353873,112829,'74354','watch','padding-left','10',0,''),(353874,112829,'74354','watch','padding-right','10',0,''),(353875,112829,'74354','watch','padding-bottom','10',0,''),(353876,112829,'74354','watch','border-right-width','1',0,''),(353877,112829,'74354','watch','border-right-color','$content-border-1',0,''),(353878,112831,'74356','watch','text','<p>Shipping via</p>',1,''),(353879,112831,'74356','watch','font-weight','bold',0,''),(353880,112831,'74356','watch','font-size','14',0,''),(353881,112831,'74356','watch','text','<p>Shipping via</p>',2,''),(353882,112831,'74356','watch','text','<p>Shipping via</p>',3,''),(353883,112831,'74356','watch','text','<p>Shipping via</p>',4,''),(353884,112832,'74357','watch','block_type','1',0,''),(353885,112832,'74357','watch','font-weight','normal',0,''),(353886,112832,'74357','watch','padding-top','10',0,''),(353887,112832,'74357','watch','padding-left','10',0,''),(353888,112832,'74357','watch','padding-right','10',0,''),(353889,112832,'74357','watch','padding-bottom','10',0,''),(353890,112833,'74358','watch','text','<p>Shipping service</p>',1,''),(353891,112833,'74358','watch','font-weight','bold',0,''),(353892,112833,'74358','watch','font-size','14',0,''),(353893,112833,'74358','watch','text','<p>Shipping service</p>',2,''),(353894,112833,'74358','watch','text','<p>Shipping service</p>',3,''),(353895,112833,'74358','watch','text','<p>Shipping service</p>',4,''),(353896,112835,'74360','watch','block_type','2',0,''),(353897,112835,'74360','watch','font-weight','normal',0,''),(353898,112835,'74360','watch','border-right-width','1',0,''),(353899,112835,'74360','watch','border-right-color','$content-border-1',0,''),(353900,112836,'74361','watch','block_type','1',0,''),(353901,112836,'74361','watch','font-weight','400',0,''),(353902,112836,'74361','watch','background-color','$content-bg-2',0,''),(353903,112836,'74361','watch','padding-top','10',0,''),(353904,112836,'74361','watch','padding-left','10',0,''),(353905,112836,'74361','watch','padding-right','10',0,''),(353906,112836,'74361','watch','padding-bottom','30',0,''),(353907,112837,'74362','watch','text','<p>INVOICE ADDRESS:</p>',1,''),(353908,112837,'74362','watch','font-size','14',0,''),(353909,112837,'74362','watch','font-weight','bold',0,''),(353910,112837,'74362','watch','text','<p>INVOICE ADDRESS:</p>',2,''),(353911,112837,'74362','watch','text','<p>INVOICE ADDRESS:</p>',3,''),(353912,112837,'74362','watch','text','<p>INVOICE ADDRESS:</p>',4,''),(353913,112838,'74363','watch','font-size','12',0,''),(353914,112839,'74364','watch','block_type','1',0,''),(353915,112839,'74364','watch','font-weight','normal',0,''),(353916,112839,'74364','watch','padding-top','10',0,''),(353917,112839,'74364','watch','padding-left','10',0,''),(353918,112839,'74364','watch','padding-right','10',0,''),(353919,112839,'74364','watch','padding-bottom','10',0,''),(353920,112840,'74365','watch','text','<p>E-MAIL ADDRESS:</p>',1,''),(353921,112840,'74365','watch','font-weight','bold',0,''),(353922,112840,'74365','watch','font-size','14',0,''),(353923,112840,'74365','watch','padding-top','10',0,''),(353924,112840,'74365','watch','text','<p>E-MAIL ADDRESS:</p>',2,''),(353925,112840,'74365','watch','text','<p>E-MAIL ADDRESS:</p>',3,''),(353926,112840,'74365','watch','text','<p>E-MAIL ADDRESS:</p>',4,''),(353927,112841,'74366','watch','font-weight','normal',0,''),(353928,112842,'74367','watch','font-weight','normal',0,''),(353929,112843,'74368','watch','text','<p>CUSTOMER:</p>',1,''),(353930,112843,'74368','watch','font-size','13',0,''),(353931,112843,'74368','watch','font-weight','bold',0,''),(353932,112843,'74368','watch','text','<p>CUSTOMER:</p>',2,''),(353933,112843,'74368','watch','text','<p>CUSTOMER:</p>',3,''),(353934,112843,'74368','watch','text','<p>CUSTOMER:</p>',4,''),(353935,112844,'74369','watch','text','<p>PHONE NUMBER:</p>',1,''),(353936,112844,'74369','watch','font-size','14',0,''),(353937,112844,'74369','watch','font-weight','bold',0,''),(353938,112844,'74369','watch','padding-top','10',0,''),(353939,112844,'74369','watch','text','<p>PHONE NUMBER:</p>',2,''),(353940,112844,'74369','watch','text','<p>PHONE NUMBER:</p>',3,''),(353941,112844,'74369','watch','text','<p>PHONE NUMBER:</p>',4,''),(353942,112846,'74371','watch','font-weight','normal',0,''),(353943,112846,'74371','watch','text-align','center',0,''),(353944,112846,'74371','watch','padding-bottom','20',0,''),(353945,112847,'74372','watch','text','<p>Payment Method:</p>',1,''),(353946,112847,'74372','watch','font-weight','bold',0,''),(353947,112847,'74372','watch','text-align','center',0,''),(353948,112847,'74372','watch','text','<p>Payment Method:</p>',2,''),(353949,112847,'74372','watch','text','<p>Payment Method:</p>',3,''),(353950,112847,'74372','watch','text','<p>Payment Method:</p>',4,''),(353951,112848,'74373','watch','text','<p>Payment date:</p>',1,''),(353952,112848,'74373','watch','font-weight','bold',0,''),(353953,112848,'74373','watch','text-align','center',0,''),(353954,112848,'74373','watch','font-size','12',0,''),(353955,112848,'74373','watch','text','<p>Payment date:</p>',2,''),(353956,112848,'74373','watch','text','<p>Payment date:</p>',3,''),(353957,112848,'74373','watch','text','<p>Payment date:</p>',4,''),(353958,112849,'74374','watch','font-size','14',0,''),(353959,112849,'74374','watch','font-weight','bold',0,''),(353960,112849,'74374','watch','text-align','center',0,''),(353961,112849,'74374','watch','padding-bottom','10',0,''),(353962,112849,'74374','watch','padding-top','10',0,''),(353963,112850,'74375','watch','font-weight','normal',0,''),(353964,112850,'74375','watch','text-align','center',0,''),(353965,112850,'74375','watch','padding-bottom','10',0,''),(353966,112851,'74376','watch','font-weight','normal',0,''),(353967,112851,'74376','watch','text-align','center',0,''),(353968,112852,'74377','watch','block_type','3',0,''),(353969,112852,'74377','watch','font-weight','normal',0,''),(353970,112852,'74377','watch','padding-top','20',0,''),(353971,112853,'74378','watch','font-size','12',0,''),(353972,112854,'74379','watch','text','<p>If undelivered please return to:</p>',1,''),(353973,112854,'74379','watch','font-size','12',0,''),(353974,112854,'74379','watch','font-weight','bold',0,''),(353975,112854,'74379','watch','text','<p>If undelivered please return to:</p>',2,''),(353976,112854,'74379','watch','text','<p>If undelivered please return to:</p>',3,''),(353977,112854,'74379','watch','text','<p>If undelivered please return to:</p>',4,''),(353978,112855,'74380','watch','text','<p>Thank you for your order</p>',1,''),(353979,112855,'74380','watch','color','$color-8',0,''),(353980,112855,'74380','watch','font-size','13',0,''),(353981,112855,'74380','watch','font-weight','bold',0,''),(353982,112855,'74380','watch','padding-top','5',0,''),(353983,112855,'74380','watch','text-align','center',0,''),(353984,112855,'74380','watch','text','<p>Thank you for your order</p>',2,''),(353985,112855,'74380','watch','text','<p>Thank you for your order</p>',3,''),(353986,112855,'74380','watch','text','<p>Thank you for your order</p>',4,''),(353987,112856,'74381','watch','font-weight','400',0,''),(353988,112856,'74381','watch','text-align','center',0,''),(353989,112856,'74381','watch','padding-top','0',0,''),(353991,112856,'74381','watch','padding-left','20',0,''),(353992,112856,'74381','watch','padding-right','20',0,''),(353993,112856,'74381','watch','logo_from','theme',0,''),(353997,112857,'74382','watch','block_type','6',0,''),(353998,112857,'74382','watch','font-weight','normal',0,''),(353999,112857,'74382','watch','font-size','16',0,''),(354000,112858,'74383','watch','text','<p>Email:</p>',1,''),(354001,112858,'74383','watch','font-weight','normal',0,''),(354002,112858,'74383','watch','text-align','right',0,''),(354003,112858,'74383','watch','font-size','12',0,''),(354004,112858,'74383','watch','text','<p>Email:</p>',2,''),(354005,112858,'74383','watch','text','<p>Email:</p>',3,''),(354006,112858,'74383','watch','text','<p>Email:</p>',4,''),(354007,112859,'74384','watch','font-weight','normal',0,''),(354008,112859,'74384','watch','text-align','right',0,''),(354009,112859,'74384','watch','font-size','12',0,''),(354010,112860,'74385','watch','block_type','6',0,''),(354011,112860,'74385','watch','font-weight','normal',0,''),(354012,112860,'74385','watch','font-size','16',0,''),(354013,112861,'74386','watch','text','<p>Phone:</p>',1,''),(354014,112861,'74386','watch','font-weight','normal',0,''),(354015,112861,'74386','watch','text-align','right',0,''),(354016,112861,'74386','watch','font-size','12',0,''),(354017,112861,'74386','watch','text','<p>Phone:</p>',2,''),(354018,112861,'74386','watch','text','<p>Phone:</p>',3,''),(354019,112861,'74386','watch','text','<p>Phone:</p>',4,''),(354020,112862,'74387','watch','font-weight','normal',0,''),(354021,112862,'74387','watch','text-align','right',0,''),(354022,112862,'74387','watch','font-size','12',0,''),(354023,112863,'74388','watch','text','<p>If something has gone wrong please contact us at:</p>',1,''),(354024,112863,'74388','watch','font-size','12',0,''),(354025,112863,'74388','watch','font-weight','bold',0,''),(354026,112863,'74388','watch','text-align','right',0,''),(354027,112863,'74388','watch','text','<p>If something has gone wrong please contact us at:</p>',2,''),(354028,112863,'74388','watch','text','<p>If something has gone wrong please contact us at:</p>',3,''),(354029,112863,'74388','watch','text','<p>If something has gone wrong please contact us at:</p>',4,''),(354030,112864,'74389','watch','font-weight','400',0,''),(354031,112864,'74389','watch','padding-top','20',0,''),(354032,112864,'74389','watch','padding-bottom','0',0,''),(354033,112864,'74389','watch','font-size','12',0,''),(354034,112865,'74390','watch','block_type','5',0,''),(354035,112865,'74390','watch','font-weight','normal',0,''),(354036,112865,'74390','watch','border-bottom-width','1',0,''),(354037,112865,'74390','watch','border-bottom-color','$content-border-1',0,''),(354038,112865,'74390','watch','border-top-width','1',0,''),(354039,112865,'74390','watch','border-top-color','$content-border-1',0,''),(354040,112865,'74390','watch','border-left-color','$content-border-1',0,''),(354041,112865,'74390','watch','border-left-width','1',0,''),(354042,112866,'74391','watch','block_type','1',0,''),(354043,112866,'74391','watch','font-weight','normal',0,''),(354044,112866,'74391','watch','padding-top','10',0,''),(354045,112866,'74391','watch','padding-left','10',0,''),(354046,112866,'74391','watch','padding-right','10',0,''),(354047,112867,'74392','watch','font-weight','400',0,''),(354048,112867,'74392','watch','line-height','120',0,''),(354049,112867,'74392','watch','line_height_measure','%',0,''),(354050,112867,'74392','watch','font-size','12',0,''),(354051,112868,'74393','watch','text','<p>SHIPPING ADDRESS:</p>',1,''),(354052,112868,'74393','watch','font-size','14',0,''),(354053,112868,'74393','watch','font-weight','bold',0,''),(354054,112868,'74393','watch','padding-bottom','10',0,''),(354055,112868,'74393','watch','text','<p>SHIPPING ADDRESS:</p>',2,''),(354056,112868,'74393','watch','text','<p>SHIPPING ADDRESS:</p>',3,''),(354057,112868,'74393','watch','text','<p>SHIPPING ADDRESS:</p>',4,''),(354058,112869,'74394','watch','block_type','1',0,''),(354059,112869,'74394','watch','background-color','$content-bg-2',0,''),(354060,112869,'74394','watch','padding-top','20',0,''),(354061,112869,'74394','watch','padding-left','10',0,''),(354062,112869,'74394','watch','padding-right','10',0,''),(354063,112869,'74394','watch','padding-bottom','20',0,''),(354064,112869,'74394','watch','font-size','14',0,''),(354065,112870,'74395','watch','font-weight','normal',0,''),(354066,112870,'74395','watch','text-align','right',0,''),(354067,112870,'74395','watch','font-size','14',0,''),(354068,112870,'74395','watch','box_align','3',0,''),(354069,112871,'74396','watch','block_type','2',0,''),(354070,112871,'74396','watch','font-weight','normal',0,''),(354071,112871,'74396','watch','padding-bottom','20',0,''),(354072,112872,'74397','watch','font-weight','400',0,''),(354073,112872,'74397','watch','padding-top','20',0,''),(354075,112872,'74397','watch','logo_from','theme',0,''),(354079,112873,'74398','watch','block_type','11',0,''),(354080,112873,'74398','watch','font-weight','normal',0,''),(354081,112874,'74399','watch','text','<p>Web:</p>',1,''),(354082,112874,'74399','watch','font-weight','normal',0,''),(354083,112874,'74399','watch','text-align','right',0,''),(354084,112874,'74399','watch','text','<p>Web:</p>',2,''),(354085,112874,'74399','watch','text','<p>Web:</p>',3,''),(354086,112874,'74399','watch','text','<p>Web:</p>',4,''),(354087,112875,'74400','watch','font-weight','normal',0,''),(354088,112875,'74400','watch','text-align','right',0,''),(354089,112876,'74401','watch','block_type','11',0,''),(354090,112876,'74401','watch','font-weight','normal',0,''),(354091,112877,'74402','watch','text','<p>Email:</p>',1,''),(354092,112877,'74402','watch','font-weight','normal',0,''),(354093,112877,'74402','watch','text-align','right',0,''),(354094,112877,'74402','watch','text','<p>Email:</p>',2,''),(354095,112877,'74402','watch','text','<p>Email:</p>',3,''),(354096,112877,'74402','watch','text','<p>Email:</p>',4,''),(354097,112878,'74403','watch','font-weight','normal',0,''),(354098,112878,'74403','watch','text-align','right',0,''),(354099,112879,'74404','watch','block_type','1',0,''),(354100,112880,'74405','watch','font-weight','normal',0,''),(354101,112880,'74405','watch','text-align','right',0,''),(354102,112880,'74405','watch','padding-bottom','10',0,''),(354103,112880,'74405','watch','address_spacer',',',0,''),(354104,112880,'74405','watch','font-size','12',0,''),(354105,112881,'74406','watch','block_type','11',0,''),(354106,112881,'74406','watch','font-weight','normal',0,''),(354107,112882,'74407','watch','text','<p>Phone:</p>',1,''),(354108,112882,'74407','watch','font-weight','normal',0,''),(354109,112882,'74407','watch','text-align','right',0,''),(354110,112882,'74407','watch','text','<p>Phone:</p>',2,''),(354111,112882,'74407','watch','text','<p>Phone:</p>',3,''),(354112,112882,'74407','watch','text','<p>Phone:</p>',4,''),(354113,112883,'74408','watch','font-weight','normal',0,''),(354114,112883,'74408','watch','text-align','right',0,''),(354115,112884,'74409','watch','block_type','1',0,''),(354116,112884,'74409','watch','padding-top','20',0,''),(354117,112885,'74410','watch','tab_1','RETURNING CUSTOMER',1,''),(354118,112885,'74410','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(354119,112885,'74410','watch','tab_1','RETURNING CUSTOMER',2,''),(354120,112885,'74410','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(354121,112885,'74410','watch','tab_1','RETURNING CUSTOMER',3,''),(354122,112885,'74410','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(354123,112885,'74410','watch','tab_1','RETURNING CUSTOMER',4,''),(354124,112885,'74410','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(354125,112887,'74412','watch','block_type','8',0,''),(354126,112888,'74413','watch','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(354127,112889,'74414','watch','block_type','1',0,''),(354128,112889,'74414','watch','padding-left','20',0,''),(354129,112889,'74414','watch','padding-right','20',0,''),(354130,112890,'74415','watch','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(354131,112892,'74417','watch','block_type','1',0,''),(354132,112893,'74418','watch','text','##TEXT_OR##',0,''),(354133,112893,'74418','watch','font-size','18',0,''),(354134,112893,'74418','watch','font-weight','700',0,''),(354135,112893,'74418','watch','padding-top','15',0,''),(354136,112893,'74418','watch','text-align','center',0,''),(354137,112893,'74418','watch','content','\\_',0,'3'),(354138,112893,'74418','watch','height','5',0,'3'),(354139,112893,'74418','watch','width','70',0,'3'),(354140,112893,'74418','watch','display','inline-block',0,'3'),(354141,112893,'74418','watch','border-top-width','1',0,'3'),(354142,112893,'74418','watch','border-top-color','$content-border-1',0,'3'),(354143,112893,'74418','watch','margin-left','10',0,'3'),(354144,112893,'74418','watch','margin-right','10',0,'3'),(354145,112893,'74418','watch','content','\\_',0,'4'),(354146,112893,'74418','watch','display','inline-block',0,'4'),(354147,112893,'74418','watch','width','70',0,'4'),(354148,112893,'74418','watch','height','5',0,'4'),(354149,112893,'74418','watch','border-top-width','1',0,'4'),(354150,112893,'74418','watch','border-top-color','$content-border-1',0,'4'),(354151,112893,'74418','watch','margin-left','10',0,'4'),(354152,112893,'74418','watch','margin-right','10',0,'4'),(354153,112893,'74418','watch','position','relative',0,''),(354154,112893,'74418','watch','top','-10',0,''),(354155,112894,'74419','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354156,112894,'74419','watch','font-size','26',0,''),(354157,112894,'74419','watch','font-family','$font-1',0,''),(354158,112894,'74419','watch','padding-top','15',0,''),(354159,112894,'74419','watch','padding-bottom','15',0,''),(354160,112894,'74419','watch','text-align','center',0,''),(354161,112895,'74420','watch','text-align','center',0,''),(354162,112895,'74420','watch','hide_parents','2',0,''),(354163,112896,'74421','watch','block_type','1',0,''),(354164,112896,'74421','watch','padding-top','40',0,''),(354165,112896,'74421','watch','background-color','$content-bg-2',0,''),(354166,112896,'74421','watch','padding-bottom','40',0,''),(354167,112896,'74421','watch','style_class','checkout-login-wrap',0,''),(354168,112896,'74421','watch','color','$content-color-2',0,''),(354169,112897,'74422','watch','block_type','2',0,''),(354170,112897,'74422','watch','background-color','$content-bg-1',0,''),(354171,112897,'74422','watch','max-width','830',0,''),(354172,112897,'74422','watch','margin_left_measure','auto',0,''),(354173,112897,'74422','watch','margin_right_measure','auto',0,''),(354174,112897,'74422','watch','padding-top','40',0,''),(354175,112897,'74422','watch','padding-bottom','40',0,''),(354176,112897,'74422','watch','schema','2-3',0,'5240'),(354177,112897,'74422','watch','color','$content-color-1',0,''),(354178,112898,'74423','watch','text-align','center',0,''),(354179,112898,'74423','watch','margin-bottom','40',0,''),(354180,112899,'74424','watch','text-align','center',0,''),(354181,112900,'74425','watch','text','##TEXT_OR##',0,''),(354182,112900,'74425','watch','font-size','18',0,''),(354183,112900,'74425','watch','font-weight','700',0,''),(354184,112900,'74425','watch','text-align','center',0,''),(354185,112900,'74425','watch','content','\\_',0,'3'),(354186,112900,'74425','watch','height','5',0,'3'),(354187,112900,'74425','watch','width','70',0,'3'),(354188,112900,'74425','watch','display','inline-block',0,'3'),(354189,112900,'74425','watch','border-top-width','1',0,'3'),(354190,112900,'74425','watch','border-top-color','$content-border-1',0,'3'),(354191,112900,'74425','watch','margin-left','10',0,'3'),(354192,112900,'74425','watch','margin-right','10',0,'3'),(354193,112900,'74425','watch','content','\\_',0,'4'),(354194,112900,'74425','watch','display','inline-block',0,'4'),(354195,112900,'74425','watch','width','70',0,'4'),(354196,112900,'74425','watch','height','5',0,'4'),(354197,112900,'74425','watch','border-top-width','1',0,'4'),(354198,112900,'74425','watch','border-top-color','$content-border-1',0,'4'),(354199,112900,'74425','watch','margin-left','10',0,'4'),(354200,112900,'74425','watch','margin-right','10',0,'4'),(354201,112900,'74425','watch','position','relative',0,''),(354202,112900,'74425','watch','padding-top','10',0,''),(354203,112900,'74425','watch','padding-bottom','10',0,''),(354204,112901,'74426','watch','block_type','1',0,''),(354205,112902,'74427','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354206,112902,'74427','watch','font-size','18',0,''),(354207,112902,'74427','watch','font-family','$font-1',0,''),(354208,112902,'74427','watch','padding-top','15',0,''),(354209,112902,'74427','watch','padding-bottom','15',0,''),(354210,112902,'74427','watch','text-align','center',0,''),(354211,112902,'74427','watch','text-transform','uppercase',0,''),(354212,112903,'74428','watch','text-align','center',0,''),(354213,112903,'74428','watch','hide_parents','2',0,''),(354214,112904,'74429','watch','text','##NEW_CUSTOMER##',0,''),(354215,112904,'74429','watch','font-size','18',0,''),(354216,112904,'74429','watch','font-family','$font-1',0,''),(354217,112904,'74429','watch','text-align','center',0,''),(354218,112904,'74429','watch','text-transform','uppercase',0,''),(354219,112904,'74429','watch','margin-bottom','10',0,''),(354220,112905,'74430','watch','max-width','230',0,''),(354221,112905,'74430','watch','margin_left_measure','auto',0,''),(354222,112905,'74430','watch','margin_right_measure','auto',0,''),(354223,112906,'74431','watch','text','##RETURNING_CUSTOMER##',0,''),(354224,112906,'74431','watch','font-size','18',0,''),(354225,112906,'74431','watch','font-family','$font-1',0,''),(354226,112906,'74431','watch','text-transform','uppercase',0,''),(354227,112906,'74431','watch','text-align','center',0,''),(354228,112907,'74432','watch','block_type','1',0,''),(354229,112907,'74432','watch','padding-top','20',0,''),(354230,112908,'74433','watch','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(354231,112908,'74433','watch','tab_2','RETURNING CUSTOMER',1,''),(354232,112908,'74433','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(354233,112908,'74433','watch','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(354234,112908,'74433','watch','tab_2','RETURNING CUSTOMER',2,''),(354235,112908,'74433','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(354236,112908,'74433','watch','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(354237,112908,'74433','watch','tab_2','RETURNING CUSTOMER',3,''),(354238,112908,'74433','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(354239,112908,'74433','watch','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(354240,112908,'74433','watch','tab_2','RETURNING CUSTOMER',4,''),(354241,112908,'74433','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(354242,112909,'74434','watch','block_type','8',0,''),(354243,112910,'74435','watch','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(354244,112911,'74436','watch','block_type','1',0,''),(354245,112911,'74436','watch','padding-left','20',0,''),(354246,112911,'74436','watch','padding-right','20',0,''),(354247,112913,'74438','watch','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(354248,112913,'74438','watch','border-top-width','1',0,''),(354249,112913,'74438','watch','border-top-color','$content-border-1',0,''),(354250,112915,'74440','watch','block_type','8',0,''),(354251,112916,'74441','watch','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(354252,112917,'74442','watch','block_type','1',0,''),(354253,112917,'74442','watch','padding-left','20',0,''),(354254,112917,'74442','watch','padding-right','20',0,''),(354255,112918,'74443','watch','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(354256,112920,'74445','watch','text-align','center',0,''),(354257,112921,'74446','watch','text','##TEXT_OR##',0,''),(354258,112921,'74446','watch','font-size','18',0,''),(354259,112921,'74446','watch','font-weight','700',0,''),(354260,112921,'74446','watch','padding-top','15',0,''),(354261,112921,'74446','watch','text-align','center',0,''),(354262,112921,'74446','watch','content','\\_',0,'3'),(354263,112921,'74446','watch','height','5',0,'3'),(354264,112921,'74446','watch','width','70',0,'3'),(354265,112921,'74446','watch','display','inline-block',0,'3'),(354266,112921,'74446','watch','border-top-width','1',0,'3'),(354267,112921,'74446','watch','border-top-color','$content-border-1',0,'3'),(354268,112921,'74446','watch','margin-left','10',0,'3'),(354269,112921,'74446','watch','margin-right','10',0,'3'),(354270,112921,'74446','watch','content','\\_',0,'4'),(354271,112921,'74446','watch','display','inline-block',0,'4'),(354272,112921,'74446','watch','width','70',0,'4'),(354273,112921,'74446','watch','height','5',0,'4'),(354274,112921,'74446','watch','border-top-width','1',0,'4'),(354275,112921,'74446','watch','border-top-color','$content-border-1',0,'4'),(354276,112921,'74446','watch','margin-left','10',0,'4'),(354277,112921,'74446','watch','margin-right','10',0,'4'),(354278,112921,'74446','watch','position','relative',0,''),(354279,112921,'74446','watch','top','-10',0,''),(354280,112922,'74447','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354281,112922,'74447','watch','font-size','26',0,''),(354282,112922,'74447','watch','font-family','$font-1',0,''),(354283,112922,'74447','watch','padding-top','15',0,''),(354284,112922,'74447','watch','padding-bottom','15',0,''),(354285,112922,'74447','watch','text-align','center',0,''),(354286,112923,'74448','watch','block_type','1',0,''),(354287,112923,'74448','watch','padding-top','20',0,''),(354288,112924,'74449','watch','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(354289,112924,'74449','watch','tab_2','RETURNING CUSTOMER',1,''),(354290,112924,'74449','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(354291,112924,'74449','watch','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(354292,112924,'74449','watch','tab_2','RETURNING CUSTOMER',2,''),(354293,112924,'74449','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(354294,112924,'74449','watch','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(354295,112924,'74449','watch','tab_2','RETURNING CUSTOMER',3,''),(354296,112924,'74449','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(354297,112924,'74449','watch','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(354298,112924,'74449','watch','tab_2','RETURNING CUSTOMER',4,''),(354299,112924,'74449','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(354300,112925,'74450','watch','block_type','8',0,''),(354301,112926,'74451','watch','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(354302,112929,'74454','watch','block_type','8',0,''),(354303,112930,'74455','watch','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(354304,112932,'74457','watch','block_type','1',0,''),(354305,112932,'74457','watch','padding-left','20',0,''),(354306,112932,'74457','watch','padding-right','20',0,''),(354307,112934,'74459','watch','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(354308,112935,'74460','watch','text','##TEXT_OR##',0,''),(354309,112935,'74460','watch','font-size','18',0,''),(354310,112935,'74460','watch','font-weight','700',0,''),(354311,112935,'74460','watch','padding-top','15',0,''),(354312,112935,'74460','watch','text-align','center',0,''),(354313,112935,'74460','watch','content','\\_',0,'3'),(354314,112935,'74460','watch','height','5',0,'3'),(354315,112935,'74460','watch','width','70',0,'3'),(354316,112935,'74460','watch','display','inline-block',0,'3'),(354317,112935,'74460','watch','border-top-width','1',0,'3'),(354318,112935,'74460','watch','border-top-color','$content-border-1',0,'3'),(354319,112935,'74460','watch','margin-left','10',0,'3'),(354320,112935,'74460','watch','margin-right','10',0,'3'),(354321,112935,'74460','watch','content','\\_',0,'4'),(354322,112935,'74460','watch','display','inline-block',0,'4'),(354323,112935,'74460','watch','width','70',0,'4'),(354324,112935,'74460','watch','height','5',0,'4'),(354325,112935,'74460','watch','border-top-width','1',0,'4'),(354326,112935,'74460','watch','border-top-color','$content-border-1',0,'4'),(354327,112935,'74460','watch','margin-left','10',0,'4'),(354328,112935,'74460','watch','margin-right','10',0,'4'),(354329,112935,'74460','watch','position','relative',0,''),(354330,112935,'74460','watch','top','-10',0,''),(354331,112936,'74461','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354332,112936,'74461','watch','font-size','26',0,''),(354333,112936,'74461','watch','font-family','$font-1',0,''),(354334,112936,'74461','watch','padding-top','15',0,''),(354335,112936,'74461','watch','padding-bottom','15',0,''),(354336,112936,'74461','watch','text-align','center',0,''),(354337,112937,'74462','watch','text-align','center',0,''),(354338,112938,'74463','watch','block_type','1',0,''),(354339,112938,'74463','watch','padding-top','20',0,''),(354340,112939,'74464','watch','text-align','center',0,''),(354341,112940,'74465','watch','text','##TEXT_OR##',0,''),(354342,112940,'74465','watch','font-size','18',0,''),(354343,112940,'74465','watch','font-weight','700',0,''),(354344,112940,'74465','watch','padding-top','15',0,''),(354345,112940,'74465','watch','text-align','center',0,''),(354346,112940,'74465','watch','content','\\_',0,'3'),(354347,112940,'74465','watch','height','5',0,'3'),(354348,112940,'74465','watch','width','70',0,'3'),(354349,112940,'74465','watch','display','inline-block',0,'3'),(354350,112940,'74465','watch','border-top-width','1',0,'3'),(354351,112940,'74465','watch','border-top-color','$content-border-1',0,'3'),(354352,112940,'74465','watch','margin-left','10',0,'3'),(354353,112940,'74465','watch','margin-right','10',0,'3'),(354354,112940,'74465','watch','content','\\_',0,'4'),(354355,112940,'74465','watch','display','inline-block',0,'4'),(354356,112940,'74465','watch','width','70',0,'4'),(354357,112940,'74465','watch','height','5',0,'4'),(354358,112940,'74465','watch','border-top-width','1',0,'4'),(354359,112940,'74465','watch','border-top-color','$content-border-1',0,'4'),(354360,112940,'74465','watch','margin-left','10',0,'4'),(354361,112940,'74465','watch','margin-right','10',0,'4'),(354362,112940,'74465','watch','position','relative',0,''),(354363,112940,'74465','watch','top','-10',0,''),(354364,112941,'74466','watch','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(354365,112941,'74466','watch','tab_2','RETURNING CUSTOMER',1,''),(354366,112941,'74466','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(354367,112941,'74466','watch','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(354368,112941,'74466','watch','tab_2','RETURNING CUSTOMER',2,''),(354369,112941,'74466','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(354370,112941,'74466','watch','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(354371,112941,'74466','watch','tab_2','RETURNING CUSTOMER',3,''),(354372,112941,'74466','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(354373,112941,'74466','watch','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(354374,112941,'74466','watch','tab_2','RETURNING CUSTOMER',4,''),(354375,112941,'74466','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(354376,112942,'74467','watch','block_type','8',0,''),(354377,112943,'74468','watch','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(354378,112946,'74471','watch','block_type','8',0,''),(354379,112947,'74472','watch','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(354380,112948,'74473','watch','block_type','1',0,''),(354381,112948,'74473','watch','padding-left','20',0,''),(354382,112948,'74473','watch','padding-right','20',0,''),(354383,112950,'74475','watch','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(354384,112951,'74476','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354385,112951,'74476','watch','font-size','26',0,''),(354386,112951,'74476','watch','font-family','$font-1',0,''),(354387,112951,'74476','watch','padding-top','15',0,''),(354388,112951,'74476','watch','padding-bottom','15',0,''),(354389,112951,'74476','watch','text-align','center',0,''),(354390,112952,'74477','watch','block_type','1',0,''),(354391,112952,'74477','watch','padding-top','40',0,''),(354392,112952,'74477','watch','background-color','$content-bg-2',0,''),(354393,112952,'74477','watch','padding-bottom','40',0,''),(354394,112953,'74478','watch','block_type','2',0,''),(354395,112953,'74478','watch','background-color','$content-bg-1',0,''),(354396,112953,'74478','watch','max-width','830',0,''),(354397,112953,'74478','watch','margin_left_measure','auto',0,''),(354398,112953,'74478','watch','margin_right_measure','auto',0,''),(354399,112953,'74478','watch','padding-top','40',0,''),(354400,112953,'74478','watch','padding-bottom','40',0,''),(354401,112954,'74479','watch','block_type','1',0,''),(354402,112955,'74480','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354403,112955,'74480','watch','font-size','18',0,''),(354404,112955,'74480','watch','font-family','$font-1',0,''),(354405,112955,'74480','watch','padding-top','15',0,''),(354406,112955,'74480','watch','padding-bottom','15',0,''),(354407,112955,'74480','watch','text-align','center',0,''),(354408,112955,'74480','watch','text-transform','uppercase',0,''),(354409,112956,'74481','watch','text-align','center',0,''),(354410,112956,'74481','watch','hide_parents','2',0,''),(354411,112957,'74482','watch','text-align','center',0,''),(354412,112958,'74483','watch','text-align','center',0,''),(354413,112958,'74483','watch','margin-bottom','40',0,''),(354414,112959,'74484','watch','text','##TEXT_OR##',0,''),(354415,112959,'74484','watch','font-size','18',0,''),(354416,112959,'74484','watch','font-weight','700',0,''),(354417,112959,'74484','watch','text-align','center',0,''),(354418,112959,'74484','watch','content','\\_',0,'3'),(354419,112959,'74484','watch','height','5',0,'3'),(354420,112959,'74484','watch','width','70',0,'3'),(354421,112959,'74484','watch','display','inline-block',0,'3'),(354422,112959,'74484','watch','border-top-width','1',0,'3'),(354423,112959,'74484','watch','border-top-color','$content-border-1',0,'3'),(354424,112959,'74484','watch','margin-left','10',0,'3'),(354425,112959,'74484','watch','margin-right','10',0,'3'),(354426,112959,'74484','watch','content','\\_',0,'4'),(354427,112959,'74484','watch','display','inline-block',0,'4'),(354428,112959,'74484','watch','width','70',0,'4'),(354429,112959,'74484','watch','height','5',0,'4'),(354430,112959,'74484','watch','border-top-width','1',0,'4'),(354431,112959,'74484','watch','border-top-color','$content-border-1',0,'4'),(354432,112959,'74484','watch','margin-left','10',0,'4'),(354433,112959,'74484','watch','margin-right','10',0,'4'),(354434,112959,'74484','watch','position','relative',0,''),(354435,112959,'74484','watch','padding-top','10',0,''),(354436,112959,'74484','watch','padding-bottom','10',0,''),(354437,112960,'74485','watch','text','##NEW_CUSTOMER##',0,''),(354438,112960,'74485','watch','font-size','18',0,''),(354439,112960,'74485','watch','font-family','$font-1',0,''),(354440,112960,'74485','watch','text-align','center',0,''),(354441,112960,'74485','watch','text-transform','uppercase',0,''),(354442,112960,'74485','watch','margin-bottom','10',0,''),(354443,112961,'74486','watch','text','##RETURNING_CUSTOMER##',0,''),(354444,112961,'74486','watch','font-size','18',0,''),(354445,112961,'74486','watch','font-family','$font-1',0,''),(354446,112961,'74486','watch','text-transform','uppercase',0,''),(354447,112961,'74486','watch','text-align','center',0,''),(354448,112962,'74487','watch','max-width','230',0,''),(354449,112962,'74487','watch','margin_left_measure','auto',0,''),(354450,112962,'74487','watch','margin_right_measure','auto',0,''),(354451,112963,'74488','watch','block_type','1',0,''),(354452,112963,'74488','watch','padding-top','40',0,''),(354453,112963,'74488','watch','background-color','$content-bg-2',0,''),(354454,112963,'74488','watch','padding-bottom','40',0,''),(354455,112964,'74489','watch','block_type','2',0,''),(354456,112964,'74489','watch','background-color','$content-bg-1',0,''),(354457,112964,'74489','watch','max-width','830',0,''),(354458,112964,'74489','watch','margin_left_measure','auto',0,''),(354459,112964,'74489','watch','margin_right_measure','auto',0,''),(354460,112964,'74489','watch','padding-top','40',0,''),(354461,112964,'74489','watch','padding-bottom','40',0,''),(354462,112965,'74490','watch','text','##NEW_CUSTOMER##',0,''),(354463,112965,'74490','watch','font-size','18',0,''),(354464,112965,'74490','watch','font-family','$font-1',0,''),(354465,112965,'74490','watch','text-align','center',0,''),(354466,112965,'74490','watch','text-transform','uppercase',0,''),(354467,112965,'74490','watch','margin-bottom','10',0,''),(354468,112966,'74491','watch','text-align','center',0,''),(354469,112967,'74492','watch','text-align','center',0,''),(354470,112967,'74492','watch','margin-bottom','40',0,''),(354471,112968,'74493','watch','text','##TEXT_OR##',0,''),(354472,112968,'74493','watch','font-size','18',0,''),(354473,112968,'74493','watch','font-weight','700',0,''),(354474,112968,'74493','watch','text-align','center',0,''),(354475,112968,'74493','watch','content','\\_',0,'3'),(354476,112968,'74493','watch','height','5',0,'3'),(354477,112968,'74493','watch','width','70',0,'3'),(354478,112968,'74493','watch','display','inline-block',0,'3'),(354479,112968,'74493','watch','border-top-width','1',0,'3'),(354480,112968,'74493','watch','border-top-color','$content-border-1',0,'3'),(354481,112968,'74493','watch','margin-left','10',0,'3'),(354482,112968,'74493','watch','margin-right','10',0,'3'),(354483,112968,'74493','watch','content','\\_',0,'4'),(354484,112968,'74493','watch','display','inline-block',0,'4'),(354485,112968,'74493','watch','width','70',0,'4'),(354486,112968,'74493','watch','height','5',0,'4'),(354487,112968,'74493','watch','border-top-width','1',0,'4'),(354488,112968,'74493','watch','border-top-color','$content-border-1',0,'4'),(354489,112968,'74493','watch','margin-left','10',0,'4'),(354490,112968,'74493','watch','margin-right','10',0,'4'),(354491,112968,'74493','watch','position','relative',0,''),(354492,112968,'74493','watch','padding-top','10',0,''),(354493,112968,'74493','watch','padding-bottom','10',0,''),(354494,112969,'74494','watch','block_type','1',0,''),(354495,112970,'74495','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354496,112970,'74495','watch','font-size','18',0,''),(354497,112970,'74495','watch','font-family','$font-1',0,''),(354498,112970,'74495','watch','padding-top','15',0,''),(354499,112970,'74495','watch','padding-bottom','15',0,''),(354500,112970,'74495','watch','text-align','center',0,''),(354501,112970,'74495','watch','text-transform','uppercase',0,''),(354502,112971,'74496','watch','text-align','center',0,''),(354503,112971,'74496','watch','hide_parents','2',0,''),(354504,112972,'74497','watch','text','##RETURNING_CUSTOMER##',0,''),(354505,112972,'74497','watch','font-size','18',0,''),(354506,112972,'74497','watch','font-family','$font-1',0,''),(354507,112972,'74497','watch','text-transform','uppercase',0,''),(354508,112972,'74497','watch','text-align','center',0,''),(354509,112973,'74498','watch','max-width','230',0,''),(354510,112973,'74498','watch','margin_left_measure','auto',0,''),(354511,112973,'74498','watch','margin_right_measure','auto',0,''),(354512,112974,'74499','watch','block_type','1',0,''),(354513,112975,'74500','watch','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(354514,112975,'74500','watch','margin-bottom','30',0,''),(354515,112976,'74501','watch','block_type','1',0,''),(354516,112977,'74502','watch','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(354517,112977,'74502','watch','margin-bottom','30',0,''),(354518,112978,'74503','watch','block_type','1',0,''),(354519,112978,'74503','watch','background-color','$best-sellers-bg-1',0,''),(354520,112978,'74503','watch','padding-top','20',0,''),(354521,112978,'74503','watch','padding-bottom','20',0,''),(354522,112978,'74503','watch','font-weight','400',0,''),(354523,112978,'74503','watch','visibility_product','1',0,''),(354524,112978,'74503','watch','visibility_catalog','1',0,''),(354525,112978,'74503','watch','visibility_info','1',0,''),(354526,112978,'74503','watch','visibility_cart','1',0,''),(354527,112978,'74503','watch','visibility_checkout','1',0,''),(354528,112978,'74503','watch','visibility_success','1',0,''),(354529,112978,'74503','watch','visibility_account','1',0,''),(354530,112978,'74503','watch','visibility_login','1',0,''),(354531,112978,'74503','watch','visibility_other','1',0,''),(354532,112978,'74503','watch','margin-bottom','20',0,''),(354533,112978,'74503','watch','display_none','on',0,'5240'),(354534,112979,'74504','watch','block_type','2',0,''),(354535,112979,'74504','watch','font-weight','normal',0,''),(354536,112980,'74505','watch','font-weight','400',0,''),(354537,112980,'74505','watch','visibility_product','1',0,''),(354538,112980,'74505','watch','show_name','0',0,''),(354539,112980,'74505','watch','show_stock','1',0,''),(354540,112980,'74505','watch','show_description','1',0,''),(354541,112980,'74505','watch','show_model','1',0,''),(354542,112980,'74505','watch','show_rating','1',0,''),(354543,112980,'74505','watch','show_rating_counts','1',0,''),(354544,112980,'74505','watch','show_qty_input','1',0,''),(354545,112980,'74505','watch','show_view_button','1',0,''),(354546,112980,'74505','watch','show_wishlist_button','1',0,''),(354547,112980,'74505','watch','show_compare','1',0,''),(354548,112980,'74505','watch','listing_type','productListing',0,''),(354549,112980,'74505','watch','show_properties','1',0,''),(354550,112980,'74505','watch','col_in_row','2',0,''),(354551,112980,'74505','watch','show_bonus_points','1',0,''),(354552,112980,'74505','watch','show_buy_button','1',0,''),(354553,112980,'74505','watch','show_attributes','1',0,''),(354554,112981,'74506','watch','font-weight','normal',0,''),(354555,112981,'74506','watch','visibility_product','1',0,''),(354556,112982,'74507','watch','font-weight','400',0,''),(354557,112982,'74507','watch','visibility_product','1',0,''),(354558,112982,'74507','watch','visibility_catalog','1',0,''),(354559,112982,'74507','watch','visibility_info','1',0,''),(354560,112982,'74507','watch','visibility_cart','1',0,''),(354561,112982,'74507','watch','visibility_checkout','1',0,''),(354562,112982,'74507','watch','visibility_success','1',0,''),(354563,112982,'74507','watch','visibility_account','1',0,''),(354564,112982,'74507','watch','visibility_login','1',0,''),(354565,112982,'74507','watch','visibility_other','1',0,''),(354566,112982,'74507','watch','banners_group','home',0,''),(354567,112982,'74507','watch','banners_type','single',0,''),(354569,112982,'74507','watch','template','1',0,''),(354570,112982,'74507','watch','ban_id','41',0,''),(354571,112983,'74508','watch','block_type','1',0,''),(354572,112983,'74508','watch','font-weight','normal',0,''),(354573,112984,'74510','watch','tab_1','##NEW_PRODUCTS##',0,''),(354574,112984,'74510','watch','tab_2','##SPECIALS_PRODUCTS##',0,''),(354575,112984,'74510','watch','tab_3','##FEATURED_PRODUCTS##',0,''),(354576,112985,'74511','watch','col_in_row','4',0,''),(354577,112985,'74511','watch','view_as','carousel',0,''),(354578,112985,'74511','watch','show_attributes','1',0,''),(354579,112985,'74511','watch','col_in_row','3',0,'5240'),(354580,112985,'74511','watch','col_in_row','2',0,'5232'),(354581,112985,'74511','watch','col_in_row','1',0,'5261'),(354582,112985,'74511','watch','listing_type','productListing',0,''),(354583,112985,'74511','watch','show_qty_input','1',0,''),(354584,112985,'74511','watch','show_compare','1',0,''),(354585,112985,'74511','watch','lazy_load','1',0,''),(354586,112986,'74512','watch','font-weight','400',0,''),(354587,112986,'74512','watch','show_compare','1',0,''),(354588,112986,'74512','watch','listing_type','productListing',0,''),(354589,112986,'74512','watch','show_model','1',0,''),(354590,112986,'74512','watch','show_properties','1',0,''),(354591,112986,'74512','watch','col_in_row','4',0,''),(354592,112986,'74512','watch','show_name','0',0,''),(354593,112986,'74512','watch','show_image','0',0,''),(354594,112986,'74512','watch','show_stock','0',0,''),(354595,112986,'74512','watch','show_description','0',0,''),(354596,112986,'74512','watch','show_rating','0',0,''),(354597,112986,'74512','watch','show_rating_counts','0',0,''),(354598,112986,'74512','watch','show_price','0',0,''),(354599,112986,'74512','watch','show_buy_button','0',0,''),(354600,112986,'74512','watch','show_qty_input','0',0,''),(354601,112986,'74512','watch','show_view_button','0',0,''),(354602,112986,'74512','watch','show_wishlist_button','0',0,''),(354603,112986,'74512','watch','col_in_row','2',0,'5240'),(354604,112986,'74512','watch','col_in_row','1',0,'5261'),(354605,112986,'74512','watch','view_as','carousel',0,''),(354606,112986,'74512','watch','product_names_teg','h2',0,''),(354607,112986,'74512','watch','show_attributes','1',0,''),(354608,112987,'74513','watch','font-weight','400',0,''),(354609,112987,'74513','watch','listing_type','productListing',0,''),(354610,112987,'74513','watch','col_in_row','4',0,''),(354611,112987,'74513','watch','show_image','0',0,''),(354612,112987,'74513','watch','show_stock','0',0,''),(354613,112987,'74513','watch','show_description','0',0,''),(354614,112987,'74513','watch','show_rating','0',0,''),(354615,112987,'74513','watch','show_rating_counts','0',0,''),(354616,112987,'74513','watch','show_price','0',0,''),(354617,112987,'74513','watch','show_buy_button','0',0,''),(354618,112987,'74513','watch','show_qty_input','0',0,''),(354619,112987,'74513','watch','show_view_button','0',0,''),(354620,112987,'74513','watch','show_wishlist_button','0',0,''),(354621,112987,'74513','watch','col_in_row','2',0,'5240'),(354622,112987,'74513','watch','col_in_row','1',0,'5261'),(354623,112987,'74513','watch','view_as','carousel',0,''),(354624,112987,'74513','watch','col_in_row','2',0,'5232'),(354625,112987,'74513','watch','featured_type_id','0',0,''),(354626,112989,'1708695037.0808','watch','form_name','test',0,''),(354627,112990,'74515','watch','heading_type','h1',0,''),(354628,112992,'74516','watch','block_type','1',0,''),(354629,112993,'74517','watch','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(354630,112995,'74519','watch','block_type','1',0,''),(354631,112995,'74519','watch','padding-top','40',0,''),(354632,112995,'74519','watch','padding-bottom','80',0,''),(354633,112996,'74520','watch','block_type','6',0,''),(354634,112997,'74521','watch','block_type','1',0,''),(354635,112997,'74521','watch','padding-top','20',0,''),(354636,112997,'74521','watch','padding-left','20',0,''),(354637,112997,'74521','watch','padding-right','20',0,''),(354638,112997,'74521','watch','padding-bottom','20',0,''),(354639,112997,'74521','watch','border-top-width','1',0,''),(354640,112997,'74521','watch','border-left-width','1',0,''),(354641,112997,'74521','watch','border-right-width','1',0,''),(354642,112997,'74521','watch','border-bottom-width','1',0,''),(354643,112997,'74521','watch','border-top-color','$content-border-1',0,''),(354644,112997,'74521','watch','border-left-color','$content-border-1',0,''),(354645,112997,'74521','watch','border-right-color','$content-border-1',0,''),(354646,112997,'74521','watch','border-bottom-color','$content-border-1',0,''),(354647,112997,'74521','watch','margin-right','20',0,''),(354648,113000,'74524','watch','block_type','1',0,''),(354649,113000,'74524','watch','padding-top','20',0,''),(354650,113001,'74525','watch','block_type','6',0,''),(354651,113002,'74526','watch','padding-right','20',0,''),(354652,113004,'74528','watch','block_type','1',0,''),(354653,113004,'74528','watch','padding-top','20',0,''),(354654,113005,'74529','watch','block_type','6',0,''),(354655,113006,'74530','watch','padding-right','20',0,''),(354656,113008,'74532','watch','block_type','1',0,''),(354657,113008,'74532','watch','style_class','account-password-wrap',0,''),(354658,113009,'74533','watch','block_type','6',0,''),(354659,113009,'74533','watch','schema','6-3',0,'5240'),(354660,113010,'74534','watch','aria_name','account-menu',0,''),(354718,113031,'74536','watch','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(354719,113032,'74537','watch','block_type','1',0,''),(354720,113032,'74537','watch','padding-top','20',0,''),(354721,113033,'74538','watch','tab_1','RETURNING CUSTOMER',1,''),(354722,113033,'74538','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(354723,113033,'74538','watch','tab_1','RETURNING CUSTOMER',2,''),(354724,113033,'74538','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(354725,113033,'74538','watch','tab_1','RETURNING CUSTOMER',3,''),(354726,113033,'74538','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(354727,113033,'74538','watch','tab_1','RETURNING CUSTOMER',4,''),(354728,113033,'74538','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(354729,113035,'74540','watch','block_type','8',0,''),(354730,113036,'74541','watch','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(354731,113037,'74542','watch','block_type','1',0,''),(354732,113037,'74542','watch','padding-left','20',0,''),(354733,113037,'74542','watch','padding-right','20',0,''),(354734,113039,'74544','watch','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(354735,113040,'74545','watch','block_type','1',0,''),(354736,113041,'74546','watch','block_type','1',0,''),(354737,113042,'74547','watch','margin_left_measure','auto',0,''),(354738,113042,'74547','watch','margin_right_measure','auto',0,''),(354739,113042,'74547','watch','max-width','560',0,''),(354740,113043,'74548','watch','margin-bottom','30',0,''),(354741,113044,'74549','watch','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(354742,113045,'94779','watch','block_type','1',0,''),(354743,113047,'94781','watch','block_type','6',0,''),(354744,113047,'94781','watch','font-weight','400',0,''),(354745,113047,'94781','watch','schema','6-2',0,'5261'),(354746,113047,'94781','watch','schema','6-2',0,'5240'),(354747,113048,'94782','watch','font-weight','400',0,''),(354748,113048,'94782','watch','padding-right','40',0,''),(354749,113048,'94782','watch','padding-right','0',0,'5261'),(354750,113048,'94782','watch','padding-right','0',0,'5240'),(354751,113049,'94783','watch','col_in_row','3',0,''),(354752,113049,'94783','watch','products_align','left',0,''),(354753,113049,'94783','watch','font-weight','400',0,''),(354754,113049,'94783','watch','show_qty_input','0',0,''),(354755,113049,'94783','watch','listing_type','productListing',0,''),(354756,113049,'94783','watch','listing_type_rows','no',0,''),(354757,113049,'94783','watch','show_buy_button_b2b','on',0,''),(354758,113049,'94783','watch','show_wishlist_button_b2b','1',0,''),(354759,113049,'94783','watch','show_compare_b2b','1',0,''),(354760,113049,'94783','watch','show_stock','0',0,''),(354761,113049,'94783','watch','show_description','0',0,''),(354762,113049,'94783','watch','show_model','0',0,''),(354763,113049,'94783','watch','show_properties','0',0,''),(354764,113049,'94783','watch','show_rating','0',0,''),(354765,113049,'94783','watch','show_rating_counts','0',0,''),(354766,113049,'94783','watch','show_price','0',0,''),(354767,113049,'94783','watch','show_buy_button','0',0,''),(354768,113049,'94783','watch','show_view_button','0',0,''),(354769,113049,'94783','watch','show_wishlist_button','0',0,''),(354770,113049,'94783','watch','show_compare','0',0,''),(354771,113049,'94783','watch','show_name_rows','0',0,''),(354772,113049,'94783','watch','show_image_rows','0',0,''),(354773,113049,'94783','watch','show_stock_rows','0',0,''),(354774,113049,'94783','watch','show_description_rows','0',0,''),(354775,113049,'94783','watch','show_model_rows','0',0,''),(354776,113049,'94783','watch','show_properties_rows','0',0,''),(354777,113049,'94783','watch','show_rating_rows','0',0,''),(354778,113049,'94783','watch','show_rating_counts_rows','0',0,''),(354779,113049,'94783','watch','show_price_rows','0',0,''),(354780,113049,'94783','watch','show_buy_button_rows','0',0,''),(354781,113049,'94783','watch','show_qty_input_rows','0',0,''),(354782,113049,'94783','watch','show_view_button_rows','0',0,''),(354783,113049,'94783','watch','show_wishlist_button_rows','0',0,''),(354784,113049,'94783','watch','show_compare_rows','0',0,''),(354785,113049,'94783','watch','show_name_b2b','0',0,''),(354786,113049,'94783','watch','show_image_b2b','0',0,''),(354787,113049,'94783','watch','show_stock_b2b','0',0,''),(354788,113049,'94783','watch','show_description_b2b','0',0,''),(354789,113049,'94783','watch','show_model_b2b','0',0,''),(354790,113049,'94783','watch','show_properties_b2b','0',0,''),(354791,113049,'94783','watch','show_rating_b2b','0',0,''),(354792,113049,'94783','watch','show_rating_counts_b2b','0',0,''),(354793,113049,'94783','watch','show_price_b2b','0',0,''),(354794,113049,'94783','watch','show_qty_input_b2b','0',0,''),(354795,113049,'94783','watch','show_view_button_b2b','0',0,''),(354796,113049,'94783','watch','show_attributes_b2b','0',0,''),(354797,113049,'94783','watch','items_on_page','9',0,''),(354798,113049,'94783','watch','col_in_row','2',0,'5240'),(354799,113049,'94783','watch','col_in_row','1',0,'5261'),(354800,113049,'94783','watch','product_names_teg','h2',0,''),(354801,113051,'94785','watch','block_type','5',0,''),(354802,113051,'94785','watch','padding-top','10',0,''),(354803,113051,'94785','watch','padding-bottom','10',0,''),(354804,113051,'94785','watch','schema','5-2',0,'5261'),(354805,113051,'94785','watch','border-top-color','$content-border-1',0,''),(354806,113051,'94785','watch','border-top-width','1',0,''),(354807,113053,'94787','watch','float','right',0,''),(354808,113054,'94788','watch','listing_type','productListing',0,''),(354809,113056,'94790','watch','block_type','1',0,''),(354810,113056,'94790','watch','padding-top','10',0,''),(354811,113056,'94790','watch','padding-bottom','10',0,''),(354812,113056,'94790','watch','border-bottom-width','1',0,''),(354813,113056,'94790','watch','border-bottom-color','$content-border-1',0,''),(354814,113056,'94790','watch','margin-left','0',0,''),(354815,113056,'94790','watch','margin-right','0',0,''),(354816,113057,'94791','watch','float','right',0,''),(354817,113057,'94791','watch','display','none',0,'5261'),(354818,113058,'94792','watch','float','left',0,''),(354819,113058,'94792','watch','clear','none',0,''),(354820,113058,'94792','watch','margin-left','20',0,''),(354821,113058,'94792','watch','display','none',0,'5261'),(354822,113059,'94793','watch','margin-right','20',0,''),(354823,113059,'94793','watch','float','right',0,''),(354824,113059,'94793','watch','clear','none',0,''),(354825,113059,'94793','watch','display','none',0,'5240'),(354826,113060,'94794','watch','float','left',0,''),(354827,113060,'94794','watch','clear','none',0,''),(354828,113060,'94794','watch','sort_pos_3','1',0,''),(354829,113060,'94794','watch','sort_pos_4','2',0,''),(354830,113060,'94794','watch','sort_pos_10','3',0,''),(354831,113060,'94794','watch','sort_pos_9','4',0,''),(354832,113060,'94794','watch','sort_pos_11','5',0,''),(354833,113060,'94794','watch','sort_pos_12','6',0,''),(354834,113060,'94794','watch','sort_pos_14','7',0,''),(354835,113060,'94794','watch','sort_pos_13','8',0,''),(354836,113060,'94794','watch','sort_pos_8','9',0,''),(354837,113060,'94794','watch','sort_pos_7','10',0,''),(354838,113060,'94794','watch','sort_pos_2','11',0,''),(354839,113060,'94794','watch','sort_pos_1','12',0,''),(354840,113060,'94794','watch','sort_pos_6','13',0,''),(354841,113060,'94794','watch','sort_pos_5','14',0,''),(354842,113060,'94794','watch','sort_pos_0','15',0,''),(354843,113060,'94794','watch','sort_hide_10','1',0,''),(354844,113060,'94794','watch','sort_hide_9','1',0,''),(354845,113060,'94794','watch','hide_icons','1',0,''),(354846,113060,'94794','watch','sort_hide_16','1',0,''),(354847,113060,'94794','watch','sort_hide_15','1',0,''),(354848,113060,'94794','watch','sort_hide_3','0',0,''),(354849,113060,'94794','watch','sort_hide_4','0',0,''),(354850,113060,'94794','watch','sort_hide_11','1',0,''),(354851,113060,'94794','watch','sort_hide_12','1',0,''),(354852,113060,'94794','watch','sort_hide_14','1',0,''),(354853,113060,'94794','watch','sort_hide_13','1',0,''),(354854,113060,'94794','watch','sort_hide_8','0',0,''),(354855,113060,'94794','watch','sort_hide_7','0',0,''),(354856,113060,'94794','watch','sort_hide_2','1',0,''),(354857,113060,'94794','watch','sort_hide_1','1',0,''),(354858,113060,'94794','watch','sort_hide_6','1',0,''),(354859,113060,'94794','watch','sort_hide_5','1',0,''),(354860,113060,'94794','watch','sort_hide_0','1',0,''),(354861,113061,'74550','watch','block_type','1',0,''),(354862,113062,'74551','watch','margin-bottom','30',0,''),(354863,113063,'74552','watch','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(354864,113064,'74553','watch','block_type','1',0,''),(354865,113065,'74554','watch','block_type','5',0,''),(354866,113065,'74554','watch','padding-top','10',0,''),(354867,113065,'74554','watch','padding-bottom','10',0,''),(354868,113065,'74554','watch','schema','5-2',0,'5261'),(354869,113065,'74554','watch','border-top-color','$content-border-1',0,''),(354870,113065,'74554','watch','border-top-width','1',0,''),(354871,113066,'74555','watch','padding-top','3',0,''),(354872,113067,'74556','watch','float','right',0,''),(354873,113067,'74556','watch','height','31',0,''),(354874,113068,'74557','watch','col_in_row','4',0,''),(354875,113068,'74557','watch','products_align','left',0,''),(354876,113068,'74557','watch','font-weight','400',0,''),(354877,113068,'74557','watch','listing_type','productListing',0,''),(354878,113068,'74557','watch','listing_type_rows','Rows',0,''),(354879,113068,'74557','watch','show_buy_button_b2b','on',0,''),(354880,113068,'74557','watch','show_wishlist_button_b2b','1',0,''),(354881,113068,'74557','watch','show_compare_b2b','1',0,''),(354882,113068,'74557','watch','show_image','0',0,''),(354883,113068,'74557','watch','show_stock','0',0,''),(354884,113068,'74557','watch','show_description','0',0,''),(354885,113068,'74557','watch','show_model','0',0,''),(354886,113068,'74557','watch','show_properties','0',0,''),(354887,113068,'74557','watch','show_rating','0',0,''),(354888,113068,'74557','watch','show_rating_counts','0',0,''),(354889,113068,'74557','watch','show_price','0',0,''),(354890,113068,'74557','watch','show_buy_button','0',0,''),(354891,113068,'74557','watch','show_view_button','0',0,''),(354892,113068,'74557','watch','show_wishlist_button','0',0,''),(354893,113068,'74557','watch','show_compare','0',0,''),(354894,113068,'74557','watch','show_name_rows','0',0,''),(354895,113068,'74557','watch','show_image_rows','0',0,''),(354896,113068,'74557','watch','show_stock_rows','0',0,''),(354897,113068,'74557','watch','show_description_rows','0',0,''),(354898,113068,'74557','watch','show_model_rows','0',0,''),(354899,113068,'74557','watch','show_properties_rows','0',0,''),(354900,113068,'74557','watch','show_rating_rows','0',0,''),(354901,113068,'74557','watch','show_rating_counts_rows','0',0,''),(354902,113068,'74557','watch','show_price_rows','0',0,''),(354903,113068,'74557','watch','show_buy_button_rows','0',0,''),(354904,113068,'74557','watch','show_qty_input_rows','0',0,''),(354905,113068,'74557','watch','show_view_button_rows','0',0,''),(354906,113068,'74557','watch','show_wishlist_button_rows','0',0,''),(354907,113068,'74557','watch','show_compare_rows','0',0,''),(354908,113068,'74557','watch','show_name_b2b','0',0,''),(354909,113068,'74557','watch','show_image_b2b','0',0,''),(354910,113068,'74557','watch','show_stock_b2b','0',0,''),(354911,113068,'74557','watch','show_description_b2b','0',0,''),(354912,113068,'74557','watch','show_model_b2b','0',0,''),(354913,113068,'74557','watch','show_properties_b2b','0',0,''),(354914,113068,'74557','watch','show_rating_b2b','0',0,''),(354915,113068,'74557','watch','show_rating_counts_b2b','0',0,''),(354916,113068,'74557','watch','show_price_b2b','0',0,''),(354917,113068,'74557','watch','show_qty_input_b2b','0',0,''),(354918,113068,'74557','watch','show_view_button_b2b','0',0,''),(354919,113068,'74557','watch','show_attributes_b2b','0',0,''),(354920,113068,'74557','watch','items_on_page','12',0,''),(354921,113068,'74557','watch','col_in_row','2',0,'5240'),(354922,113068,'74557','watch','col_in_row','1',0,'5261'),(354923,113068,'74557','watch','product_names_teg','h2',0,''),(354924,113071,'74560','watch','block_type','1',0,''),(354925,113072,'74561','watch','block_type','1',0,''),(354926,113072,'74561','watch','padding-top','10',0,''),(354927,113072,'74561','watch','padding-bottom','10',0,''),(354928,113072,'74561','watch','border-bottom-width','1',0,''),(354929,113072,'74561','watch','border-bottom-color','$content-border-1',0,''),(354930,113072,'74561','watch','margin-left','0',0,''),(354931,113072,'74561','watch','margin-right','0',0,''),(354932,113073,'74562','watch','clear','none',0,''),(354933,113073,'74562','watch','float','left',0,''),(354934,113073,'74562','watch','padding-top','3',0,''),(354935,113073,'74562','watch','margin-left','20',0,''),(354936,113074,'74563','watch','float','right',0,''),(354937,113074,'74563','watch','display','none',0,'5261'),(354938,113075,'74564','watch','margin-right','20',0,''),(354939,113075,'74564','watch','float','right',0,''),(354940,113075,'74564','watch','clear','none',0,''),(354941,113075,'74564','watch','display','none',0,'5240'),(354942,113076,'74565','watch','float','left',0,''),(354943,113076,'74565','watch','clear','none',0,''),(354944,113076,'74565','watch','margin-left','20',0,''),(354945,113076,'74565','watch','display','none',0,'5261'),(354946,113077,'74566','watch','float','left',0,''),(354947,113077,'74566','watch','clear','none',0,''),(354948,113077,'74566','watch','sort_pos_3','2',0,''),(354949,113077,'74566','watch','sort_pos_4','3',0,''),(354950,113077,'74566','watch','sort_pos_10','11',0,''),(354951,113077,'74566','watch','sort_pos_9','10',0,''),(354952,113077,'74566','watch','sort_pos_11','12',0,''),(354953,113077,'74566','watch','sort_pos_12','13',0,''),(354954,113077,'74566','watch','sort_pos_14','15',0,''),(354955,113077,'74566','watch','sort_pos_13','14',0,''),(354956,113077,'74566','watch','sort_pos_8','4',0,''),(354957,113077,'74566','watch','sort_pos_7','5',0,''),(354958,113077,'74566','watch','sort_pos_2','7',0,''),(354959,113077,'74566','watch','sort_pos_1','6',0,''),(354960,113077,'74566','watch','sort_pos_6','9',0,''),(354961,113077,'74566','watch','sort_pos_5','8',0,''),(354962,113077,'74566','watch','sort_pos_0','1',0,''),(354963,113077,'74566','watch','sort_hide_10','1',0,''),(354964,113077,'74566','watch','sort_hide_9','1',0,''),(354965,113077,'74566','watch','sort_pos_15','16',0,''),(354966,113077,'74566','watch','sort_pos_16','17',0,''),(354967,113077,'74566','watch','sort_hide_4','0',0,''),(354968,113077,'74566','watch','sort_hide_3','0',0,''),(354969,113077,'74566','watch','sort_hide_16','1',0,''),(354970,113077,'74566','watch','sort_hide_15','1',0,''),(354971,113077,'74566','watch','sort_hide_11','1',0,''),(354972,113077,'74566','watch','sort_hide_12','1',0,''),(354973,113077,'74566','watch','sort_hide_14','1',0,''),(354974,113077,'74566','watch','sort_hide_13','1',0,''),(354975,113077,'74566','watch','sort_hide_8','0',0,''),(354976,113077,'74566','watch','sort_hide_7','0',0,''),(354977,113077,'74566','watch','sort_hide_2','1',0,''),(354978,113077,'74566','watch','sort_hide_1','1',0,''),(354979,113077,'74566','watch','sort_hide_6','1',0,''),(354980,113077,'74566','watch','sort_hide_5','1',0,''),(354981,113077,'74566','watch','sort_hide_0','0',0,''),(354982,113077,'74566','watch','hide_icons','1',0,''),(354983,113078,'74567','watch','margin-bottom','20',0,''),(354984,113079,'74568','watch','block_type','1',0,''),(354985,113079,'74568','watch','style_class','account-order-history',0,''),(355052,113103,'74573','watch','block_type','1',0,''),(355053,113103,'74573','watch','style_class','account-order-history-info',0,''),(355183,113162,'74613','watch','block_type','1',0,''),(355184,113162,'74613','watch','style_class','account-order-pay',0,''),(355185,113163,'74614','watch','block_type','6',0,''),(355186,113163,'74614','watch','schema','6-3',0,'5240'),(355187,113164,'74615','watch','aria_name','account-menu',0,''),(355245,113185,'74617','watch','block_type','3',0,''),(355246,113186,'74618','watch','block_type','1',0,''),(355247,113186,'74618','watch','padding-right','20',0,''),(355248,113186,'74618','watch','padding-bottom','20',0,''),(355249,113187,'74619','watch','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(355250,113188,'74620','watch','orders_data','name',0,''),(355251,113188,'74620','watch','padding-left','30',0,''),(355252,113189,'74621','watch','block_type','1',0,''),(355253,113190,'74622','watch','padding-left','30',0,''),(355254,113191,'74623','watch','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(355255,113192,'74624','watch','block_type','1',0,''),(355256,113192,'74624','watch','padding-right','20',0,''),(355257,113192,'74624','watch','padding-bottom','20',0,''),(355258,113193,'74625','watch','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(355259,113194,'74626','watch','orders_data','delivery_address',0,''),(355260,113194,'74626','watch','padding-left','30',0,''),(355261,113195,'74627','watch','block_type','1',0,''),(355262,113195,'74627','watch','padding-right','20',0,''),(355263,113196,'74628','watch','orders_data','shipping_method',0,''),(355264,113196,'74628','watch','padding-left','30',0,''),(355265,113197,'74629','watch','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(355266,113198,'74630','watch','block_type','1',0,''),(355267,113199,'74631','watch','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(355268,113200,'74632','watch','orders_data','payment_method',0,''),(355269,113200,'74632','watch','padding-left','30',0,''),(355270,113201,'74633','watch','block_type','1',0,''),(355271,113201,'74633','watch','padding-bottom','20',0,''),(355272,113202,'74634','watch','orders_data','billing_address',0,''),(355273,113202,'74634','watch','padding-left','30',0,''),(355274,113203,'74635','watch','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(355275,113204,'74636','watch','margin-bottom','20',0,''),(355276,113205,'74637','watch','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(355277,113208,'74640','watch','width','680',0,''),(355278,113208,'74640','watch','font-weight','400',0,''),(355279,113208,'74640','watch','font-size','12',0,''),(355280,113208,'74640','watch','padding-top','20',0,''),(355281,113208,'74640','watch','padding-bottom','20',0,''),(355282,113209,'74641','watch','block_type','2',0,''),(355283,113209,'74641','watch','font-weight','normal',0,''),(355284,113209,'74641','watch','padding-bottom','20',0,''),(355285,113210,'74642','watch','font-weight','400',0,''),(355286,113210,'74642','watch','text-align','center',0,''),(355287,113210,'74642','watch','padding-top','10',0,''),(355289,113210,'74642','watch','logo_from','theme',0,''),(355293,113211,'74643','watch','block_type','11',0,''),(355294,113211,'74643','watch','font-weight','normal',0,''),(355295,113212,'74644','watch','text','<p>Email:</p>',1,''),(355296,113212,'74644','watch','font-weight','normal',0,''),(355297,113212,'74644','watch','text-align','right',0,''),(355298,113212,'74644','watch','text','<p>Email:</p>',2,''),(355299,113212,'74644','watch','text','<p>Email:</p>',3,''),(355300,113212,'74644','watch','text','<p>Email:</p>',4,''),(355301,113213,'74645','watch','font-weight','normal',0,''),(355302,113213,'74645','watch','text-align','right',0,''),(355303,113214,'74646','watch','block_type','11',0,''),(355304,113214,'74646','watch','font-weight','normal',0,''),(355305,113215,'74647','watch','text','<p>Phone:</p>',1,''),(355306,113215,'74647','watch','font-weight','normal',0,''),(355307,113215,'74647','watch','text-align','right',0,''),(355308,113215,'74647','watch','text','<p>Phone:</p>',2,''),(355309,113215,'74647','watch','text','<p>Phone:</p>',3,''),(355310,113215,'74647','watch','text','<p>Phone:</p>',4,''),(355311,113216,'74648','watch','font-weight','normal',0,''),(355312,113216,'74648','watch','text-align','right',0,''),(355313,113217,'74649','watch','block_type','1',0,''),(355314,113218,'74650','watch','font-weight','400',0,''),(355315,113218,'74650','watch','text-align','right',0,''),(355316,113218,'74650','watch','padding-bottom','10',0,''),(355317,113218,'74650','watch','address_spacer',',',0,''),(355318,113218,'74650','watch','font-size','12',0,''),(355319,113219,'74651','watch','block_type','11',0,''),(355320,113219,'74651','watch','font-weight','400',0,''),(355321,113220,'74652','watch','text','<p>Web:</p>',1,''),(355322,113220,'74652','watch','font-weight','400',0,''),(355323,113220,'74652','watch','text-align','right',0,''),(355324,113220,'74652','watch','text','<p>Web:</p>',2,''),(355325,113220,'74652','watch','text','<p>Web:</p>',3,''),(355326,113220,'74652','watch','text','<p>Web:</p>',4,''),(355327,113221,'74653','watch','font-weight','normal',0,''),(355328,113221,'74653','watch','text-align','right',0,''),(355329,113222,'74654','watch','font-weight','normal',0,''),(355330,113222,'74654','watch','padding-top','20',0,''),(355331,113222,'74654','watch','font-size','12',0,''),(355332,113223,'74655','watch','block_type','1',0,''),(355333,113223,'74655','watch','font-weight','normal',0,''),(355334,113223,'74655','watch','padding-top','10',0,''),(355335,113223,'74655','watch','padding-bottom','10',0,''),(355336,113225,'74657','watch','text','<p>If undelivered please return to:</p>',1,''),(355337,113225,'74657','watch','font-weight','bold',0,''),(355338,113225,'74657','watch','text','<p>If undelivered please return to:</p>',2,''),(355339,113225,'74657','watch','text','<p>If undelivered please return to:</p>',3,''),(355340,113225,'74657','watch','text','<p>If undelivered please return to:</p>',4,''),(355341,113226,'74658','watch','block_type','4',0,''),(355342,113226,'74658','watch','font-weight','400',0,''),(355343,113226,'74658','watch','border-top-width','1',0,''),(355344,113226,'74658','watch','border-top-color','$content-border-1',0,''),(355345,113226,'74658','watch','border-left-width','1',0,''),(355346,113226,'74658','watch','border-left-color','$content-border-1',0,''),(355347,113226,'74658','watch','border-right-width','1',0,''),(355348,113226,'74658','watch','border-right-color','$content-border-1',0,''),(355349,113226,'74658','watch','border-bottom-width','1',0,''),(355350,113226,'74658','watch','border-bottom-color','$content-border-1',0,''),(355351,113227,'74659','watch','block_type','2',0,''),(355352,113227,'74659','watch','font-weight','normal',0,''),(355353,113227,'74659','watch','border-right-width','1',0,''),(355354,113227,'74659','watch','border-right-color','$content-border-1',0,''),(355355,113228,'74660','watch','block_type','1',0,''),(355356,113228,'74660','watch','font-weight','normal',0,''),(355357,113228,'74660','watch','border-right-width','1',0,''),(355358,113228,'74660','watch','border-right-color','$content-border-1',0,''),(355359,113228,'74660','watch','background-color','$content-bg-2',0,''),(355360,113228,'74660','watch','padding-top','10',0,''),(355361,113228,'74660','watch','padding-left','10',0,''),(355362,113228,'74660','watch','padding-right','10',0,''),(355363,113228,'74660','watch','padding-bottom','10',0,''),(355364,113229,'74661','watch','font-size','12',0,''),(355365,113229,'74661','watch','font-weight','normal',0,''),(355366,113230,'74662','watch','text','<p>SHIPPING ADDRESS:</p>',1,''),(355367,113230,'74662','watch','font-size','13',0,''),(355368,113230,'74662','watch','font-weight','bold',0,''),(355369,113230,'74662','watch','padding-bottom','10',0,''),(355370,113230,'74662','watch','text','<p>SHIPPING ADDRESS:</p>',2,''),(355371,113230,'74662','watch','text','<p>SHIPPING ADDRESS:</p>',3,''),(355372,113230,'74662','watch','text','<p>SHIPPING ADDRESS:</p>',4,''),(355373,113231,'74663','watch','block_type','1',0,''),(355374,113231,'74663','watch','font-weight','normal',0,''),(355375,113231,'74663','watch','padding-top','10',0,''),(355376,113231,'74663','watch','padding-left','10',0,''),(355377,113231,'74663','watch','padding-right','10',0,''),(355378,113231,'74663','watch','padding-bottom','10',0,''),(355379,113232,'74664','watch','text','<p>CUSTOMER:</p>',1,''),(355380,113232,'74664','watch','font-size','13',0,''),(355381,113232,'74664','watch','font-weight','bold',0,''),(355382,113232,'74664','watch','text','<p>CUSTOMER:</p>',2,''),(355383,113232,'74664','watch','text','<p>CUSTOMER:</p>',3,''),(355384,113232,'74664','watch','text','<p>CUSTOMER:</p>',4,''),(355385,113233,'74665','watch','font-size','12',0,''),(355386,113235,'74667','watch','text','<p>PHONE NUMBER:</p>',1,''),(355387,113235,'74667','watch','font-size','13',0,''),(355388,113235,'74667','watch','font-weight','bold',0,''),(355389,113235,'74667','watch','padding-top','10',0,''),(355390,113235,'74667','watch','text','<p>PHONE NUMBER:</p>',2,''),(355391,113235,'74667','watch','text','<p>PHONE NUMBER:</p>',3,''),(355392,113235,'74667','watch','text','<p>PHONE NUMBER:</p>',4,''),(355393,113236,'74668','watch','font-size','12',0,''),(355394,113237,'74669','watch','text','<p>E-MAIL ADDRESS:</p>',1,''),(355395,113237,'74669','watch','font-size','13',0,''),(355396,113237,'74669','watch','font-weight','bold',0,''),(355397,113237,'74669','watch','padding-top','10',0,''),(355398,113237,'74669','watch','text','<p>E-MAIL ADDRESS:</p>',2,''),(355399,113237,'74669','watch','text','<p>E-MAIL ADDRESS:</p>',3,''),(355400,113237,'74669','watch','text','<p>E-MAIL ADDRESS:</p>',4,''),(355401,113238,'74670','watch','block_type','2',0,''),(355402,113238,'74670','watch','font-weight','normal',0,''),(355403,113238,'74670','watch','border-right-width','1',0,''),(355404,113238,'74670','watch','border-right-color','$content-border-1',0,''),(355405,113238,'74670','watch','border-top-width','1',0,''),(355406,113238,'74670','watch','border-top-color','$content-border-1',0,''),(355407,113239,'74671','watch','block_type','1',0,''),(355408,113239,'74671','watch','font-weight','normal',0,''),(355409,113239,'74671','watch','padding-top','10',0,''),(355410,113239,'74671','watch','padding-left','10',0,''),(355411,113239,'74671','watch','padding-right','10',0,''),(355412,113239,'74671','watch','padding-bottom','10',0,''),(355413,113239,'74671','watch','border-right-width','1',0,''),(355414,113239,'74671','watch','border-right-color','$content-border-1',0,''),(355415,113241,'74673','watch','text','<p>Shipping via</p>',1,''),(355416,113241,'74673','watch','font-weight','bold',0,''),(355417,113241,'74673','watch','text','<p>Shipping via</p>',2,''),(355418,113241,'74673','watch','text','<p>Shipping via</p>',3,''),(355419,113241,'74673','watch','text','<p>Shipping via</p>',4,''),(355420,113242,'74674','watch','block_type','1',0,''),(355421,113242,'74674','watch','font-weight','normal',0,''),(355422,113242,'74674','watch','padding-top','10',0,''),(355423,113242,'74674','watch','padding-left','10',0,''),(355424,113242,'74674','watch','padding-right','10',0,''),(355425,113242,'74674','watch','padding-bottom','10',0,''),(355426,113244,'74676','watch','text','<p>Shipping service</p>',1,''),(355427,113244,'74676','watch','font-weight','bold',0,''),(355428,113244,'74676','watch','text','<p>Shipping service</p>',2,''),(355429,113244,'74676','watch','text','<p>Shipping service</p>',3,''),(355430,113244,'74676','watch','text','<p>Shipping service</p>',4,''),(355431,113245,'74677','watch','font-weight','normal',0,''),(355432,113245,'74677','watch','text-align','center',0,''),(355433,113245,'74677','watch','padding-top','40',0,''),(355434,113246,'74678','watch','block_type','1',0,''),(355435,113247,'74679','watch','block_type','8',0,''),(355436,113248,'74680','watch','text','##TEXT_MAIN##',0,''),(355437,113248,'74680','watch','margin-bottom','20',0,''),(355438,113248,'74680','watch','text-align','center',0,''),(355439,113249,'74681','watch','margin-bottom','20',0,''),(355440,113250,'74682','watch','text','<h1>##HEADING_TITLE##</h1>',0,''),(355441,113252,'74684','watch','block_type','2',0,''),(355442,113253,'74685','watch','block_type','1',0,''),(355443,113253,'74685','watch','style_class','product',0,''),(355444,113253,'74685','watch','padding-right','10',0,''),(355445,113253,'74685','watch','padding-bottom','20',0,''),(355446,113254,'74686','watch','block_type','1',0,''),(355447,113255,'74687','watch','product_element','products_name',0,''),(355448,113255,'74687','watch','font-family','$font-1',0,''),(355449,113255,'74687','watch','padding-bottom','10',0,''),(355450,113255,'74687','watch','font-size','16',0,''),(355451,113256,'74688','watch','block_type','2',0,''),(355452,113257,'74689','watch','product_element','image',0,''),(355453,113257,'74689','watch','padding-right','10',0,''),(355454,113258,'74690','watch','product_element','products_price_old',0,''),(355455,113258,'74690','watch','font-family','$font-1',0,''),(355456,113258,'74690','watch','font-size','14',0,''),(355457,113258,'74690','watch','text-decoration','line-through',0,''),(355458,113259,'74691','watch','product_element','products_price',0,''),(355459,113259,'74691','watch','font-family','$font-1',0,''),(355460,113259,'74691','watch','font-size','20',0,''),(355461,113259,'74691','watch','padding-top','20',0,''),(355462,113260,'74692','watch','block_type','1',0,''),(355463,113260,'74692','watch','style_class','product',0,''),(355464,113260,'74692','watch','padding-left','10',0,''),(355465,113260,'74692','watch','padding-bottom','20',0,''),(355466,113261,'74693','watch','block_type','2',0,''),(355467,113262,'74694','watch','product_element','image',0,''),(355468,113262,'74694','watch','padding-right','10',0,''),(355469,113263,'74695','watch','font-size','14',0,''),(355470,113263,'74695','watch','font-family','$font-1',0,''),(355471,113263,'74695','watch','text-decoration','line-through',0,''),(355472,113263,'74695','watch','product_element','products_price_old',0,''),(355473,113264,'74696','watch','product_element','products_price',0,''),(355474,113264,'74696','watch','font-family','$font-1',0,''),(355475,113264,'74696','watch','font-size','20',0,''),(355476,113264,'74696','watch','padding-top','20',0,''),(355477,113265,'74697','watch','block_type','1',0,''),(355478,113266,'74698','watch','product_element','products_name',0,''),(355479,113266,'74698','watch','font-family','$font-1',0,''),(355480,113266,'74698','watch','font-size','16',0,''),(355481,113266,'74698','watch','padding-bottom','10',0,''),(355482,113267,'74699','watch','font-size','30',0,''),(355483,113267,'74699','watch','font-family','$font-1',0,''),(355484,113267,'74699','watch','text-align','center',0,''),(355485,113267,'74699','watch','padding-bottom','50',0,''),(355486,113268,'74700','watch','padding-bottom','20',0,''),(355487,113268,'74700','watch','text-align','center',0,''),(355488,113269,'74701','watch','width','680',0,''),(355489,113270,'74702','watch','padding-top','200',0,''),(355490,113270,'74702','watch','padding-left','200',0,''),(355495,113271,'74703','watch','text','osCommerce 4',1,''),(355496,113271,'74703','watch','font-family','$font-1',0,''),(355497,113271,'74703','watch','font-size','40',0,''),(355498,113271,'74703','watch','padding-top','50',0,''),(355499,113271,'74703','watch','text-align','center',0,''),(355500,113271,'74703','watch','text','osCommerce 4',2,''),(355501,113271,'74703','watch','text','osCommerce 4',3,''),(355502,113271,'74703','watch','text','osCommerce 4',4,''),(355503,113272,'74704','watch','block_type','2',0,''),(355504,113272,'74704','watch','border-top-width','1',0,''),(355505,113272,'74704','watch','border-top-color','$content-border-1',0,''),(355506,113273,'74705','watch','text-align','right',0,''),(355507,113273,'74705','watch','padding-top','15',0,''),(355508,113273,'74705','watch','padding-bottom','15',0,''),(355509,113273,'74705','watch','font-size','14',0,''),(355510,113274,'74706','watch','font-family','$font-1',0,''),(355511,113274,'74706','watch','text-align','center',0,''),(355512,113274,'74706','watch','font-size','20',0,''),(355513,113274,'74706','watch','color','$highlight-color-1',0,''),(355514,113274,'74706','watch','border-bottom-width','1',0,''),(355515,113274,'74706','watch','border-bottom-color','$content-border-1',0,''),(355516,113274,'74706','watch','padding-top','10',0,''),(355517,113274,'74706','watch','padding-bottom','10',0,''),(355518,113275,'74707','watch','block_type','1',0,''),(355519,113276,'74708','watch','block_type','6',0,''),(355520,113276,'74708','watch','schema','6-3',0,'5240'),(355521,113277,'74709','watch','aria_name','account-menu',0,''),(355579,113297,'74710','watch','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(355580,113298,'74711','watch','like_button','1',0,''),(355581,113298,'74711','watch','link','personal_catalog',0,''),(355582,113298,'74711','watch','text','BOX_INFORMATION_ALLPRODS',0,''),(355583,113298,'74711','watch','text-align','center',0,''),(355584,113298,'74711','watch','padding-top','20',0,''),(355585,113298,'74711','watch','padding-bottom','20',0,''),(355586,113299,'74712','watch','max_items','10',0,''),(355587,113300,'74713','watch','block_type','1',0,''),(355588,113300,'74713','watch','padding-top','20',0,''),(355589,113300,'74713','watch','padding-left','20',0,''),(355590,113300,'74713','watch','padding-right','20',0,''),(355591,113300,'74713','watch','padding-bottom','20',0,''),(355592,113301,'74714','watch','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(355593,113303,'74716','watch','block_type','1',0,''),(355594,113304,'74717','watch','margin_left_measure','auto',0,''),(355595,113304,'74717','watch','margin_right_measure','auto',0,''),(355596,113304,'74717','watch','max-width','560',0,''),(355597,113305,'74718','watch','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(355598,113306,'74719','watch','margin-bottom','30',0,''),(355599,113307,'74720','watch','block_type','1',0,''),(355600,113307,'74720','watch','style_class','catalog-product-wrap',0,''),(355601,113309,'74722','watch','block_type','2',0,''),(355602,113309,'74722','watch','font-weight','400',0,''),(355603,113309,'74722','watch','padding-bottom','20',0,''),(355604,113309,'74722','watch','schema','2-2',0,'5261'),(355605,113310,'74724','watch','font-weight','400',0,''),(355606,113310,'74724','watch','padding-top','20',0,''),(355607,113310,'74724','watch','padding-right','20',0,''),(355608,113310,'74724','watch','box_align','4',0,''),(355609,113310,'74724','watch','margin-bottom','50',0,''),(355610,113310,'74724','watch','align_position','horizontal',0,''),(355611,113313,'74727','watch','block_type','12',0,''),(355612,113313,'74727','watch','padding-top','15',0,''),(355613,113313,'74727','watch','padding-bottom','5',0,''),(355614,113313,'74727','watch','border-top-width','1',0,''),(355615,113313,'74727','watch','border-top-color','$content-border-1',0,''),(355616,113313,'74727','watch','schema','2-2',0,'5232'),(355617,113313,'74727','watch','margin-bottom','15',0,''),(355618,113313,'74727','watch','border-bottom-width','1',0,''),(355619,113313,'74727','watch','border-bottom-color','$content-border-1',0,''),(355620,113313,'74727','watch','schema','12-2',0,'5240'),(355621,113314,'74728','watch','padding-top','10',0,''),(355622,113314,'74728','watch','padding-bottom','10',0,''),(355623,113315,'74729','watch','block_type','2',0,''),(355624,113315,'74729','watch','schema','2-1',0,'5240'),(355625,113316,'74730','watch','font-size','30',0,''),(355626,113316,'74730','watch','font-weight','400',0,''),(355627,113316,'74730','watch','line-height','35',0,''),(355628,113316,'74730','watch','font-family','$font-1',0,''),(355629,113316,'74730','watch','line_height_measure','px',0,''),(355630,113316,'74730','watch','padding-top','5',0,''),(355631,113317,'74731','watch','box_align','4',0,''),(355632,113317,'74731','watch','margin-bottom','15',0,'5240'),(355633,113317,'74731','watch','text-align','right',0,'5240'),(355634,113317,'74731','watch','padding-top','5',0,''),(355635,113317,'74731','watch','text-align','left',0,''),(355636,113318,'74732','watch','margin-bottom','15',0,''),(355637,113318,'74732','watch','padding-top','15',0,''),(355638,113319,'1694165842.4776','watch','padding-top','10',0,''),(355639,113320,'74733','watch','text-align','right',0,''),(355640,113320,'74733','watch','width','100',0,'5232'),(355641,113320,'74733','watch','width_measure','%',0,'5232'),(355642,113320,'74733','watch','float','none',0,'5232'),(355643,113320,'74733','watch','hide_additional_buttons','1',0,''),(355644,113321,'74734','watch','text-align','right',0,''),(355645,113322,'74735','watch','cat_description','on',0,''),(355646,113322,'74735','watch','length_description','250',0,''),(355647,113322,'74735','watch','padding-bottom','20',0,''),(355648,113323,'74737','watch','document_types_id','4',0,''),(355649,113324,'74738','watch','show_address','1',0,''),(355650,113324,'74738','watch','show_time','1',0,''),(355651,113324,'74738','watch','show_qty','1',0,''),(355652,113324,'74738','watch','show_qty_level1','500',0,''),(355653,113324,'74738','watch','show_qty_level2','2000',0,''),(355654,113324,'74738','watch','text-align','right',0,''),(355655,113324,'74738','watch','margin-bottom','10',0,''),(355656,113325,'74739','watch','block_type','2',0,''),(355657,113329,'74745','watch','font-weight','400',0,''),(355658,113333,'74750','watch','font-weight','normal',0,''),(355659,113333,'74750','watch','padding-top','10',0,''),(355660,113333,'74750','watch','padding-bottom','10',0,''),(355661,113333,'74750','watch','box_align','4',0,''),(355662,113334,'74752','watch','tab_1','Description',1,''),(355663,113334,'74752','watch','tab_2','Reviews',1,''),(355664,113334,'74752','watch','font-weight','400',0,''),(355665,113334,'74752','watch','tab_1','Description',2,''),(355666,113334,'74752','watch','tab_2','Reviews',2,''),(355667,113334,'74752','watch','tab_1','Description',3,''),(355668,113334,'74752','watch','tab_2','Reviews',3,''),(355669,113334,'74752','watch','tab_1','Description',4,''),(355670,113334,'74752','watch','tab_2','Reviews',4,''),(355671,113335,'74753','watch','hTagsInline','block',0,''),(355672,113336,'74754','watch','margin-bottom','20',0,''),(355673,113336,'74754','watch','max-width','500',0,''),(355674,113337,'74755','watch','padding-bottom','10',0,''),(355675,113337,'74755','watch','padding-top','5',0,''),(355676,113338,'74757','watch','font-weight','normal',0,''),(355677,113338,'74757','watch','padding-bottom','20',0,''),(355678,113339,'74758','watch','font-weight','normal',0,''),(355679,113339,'74758','watch','padding-bottom','20',0,''),(355680,113340,'1694166186.2638','watch','block_type','1',0,''),(355681,113341,'74751','watch','font-weight','400',0,''),(355682,113341,'74751','watch','padding-bottom','20',0,''),(355683,113341,'74751','watch','show_qty_input','1',0,''),(355684,113341,'74751','watch','show_compare','1',0,''),(355685,113341,'74751','watch','listing_type','productListing',0,''),(355686,113341,'74751','watch','view_as','carousel',0,''),(355687,113341,'74751','watch','show_name','0',0,''),(355688,113341,'74751','watch','show_image','0',0,''),(355689,113341,'74751','watch','show_stock','0',0,''),(355690,113341,'74751','watch','show_description','0',0,''),(355691,113341,'74751','watch','show_model','0',0,''),(355692,113341,'74751','watch','show_properties','0',0,''),(355693,113341,'74751','watch','show_rating','0',0,''),(355694,113341,'74751','watch','show_rating_counts','0',0,''),(355695,113341,'74751','watch','show_price','0',0,''),(355696,113341,'74751','watch','show_buy_button','0',0,''),(355697,113341,'74751','watch','show_view_button','0',0,''),(355698,113341,'74751','watch','show_wishlist_button','0',0,''),(355699,113341,'74751','watch','display','none',0,'5240'),(355700,113341,'74751','watch','product_names_teg','h2',0,''),(355701,113341,'74751','watch','show_attributes','1',0,''),(355702,113341,'74751','watch','col_in_row','4',0,''),(355703,113341,'74751','watch','hide_parents','2',0,''),(355704,113342,'1694166209.3278','watch','text','<div class=\"heading-3\">##PRODUCT_ALSO_PURCHASED##</div>',0,''),(355705,113343,'1694166191.5684','watch','block_type','1',0,''),(355706,113344,'74747','watch','font-weight','400',0,''),(355707,113344,'74747','watch','padding-bottom','20',0,''),(355708,113344,'74747','watch','show_compare','1',0,''),(355709,113344,'74747','watch','show_name','0',0,''),(355710,113344,'74747','watch','show_image','0',0,''),(355711,113344,'74747','watch','show_stock','0',0,''),(355712,113344,'74747','watch','show_description','0',0,''),(355713,113344,'74747','watch','show_model','0',0,''),(355714,113344,'74747','watch','show_properties','0',0,''),(355715,113344,'74747','watch','show_rating','0',0,''),(355716,113344,'74747','watch','show_rating_counts','0',0,''),(355717,113344,'74747','watch','show_price','0',0,''),(355718,113344,'74747','watch','show_buy_button','0',0,''),(355719,113344,'74747','watch','show_view_button','0',0,''),(355720,113344,'74747','watch','show_wishlist_button','0',0,''),(355721,113344,'74747','watch','listing_type','productListing',0,''),(355722,113344,'74747','watch','col_in_row','2',0,'5240'),(355723,113344,'74747','watch','col_in_row','1',0,'5261'),(355724,113344,'74747','watch','col_in_row','4',0,''),(355725,113344,'74747','watch','hide_parents','2',0,''),(355726,113345,'1694166222.3382','watch','text','<div class=\"heading-3\">##VIEWED_PRODUCTS##</div>',0,''),(355727,113356,'74771','watch','block_type','1',0,''),(355728,113356,'74771','watch','style_class','item-holder',0,''),(355729,113356,'74771','watch','padding-top','25',0,''),(355730,113356,'74771','watch','padding-left','25',0,''),(355731,113356,'74771','watch','padding-right','25',0,''),(355732,113356,'74771','watch','padding-bottom','25',0,''),(355733,113356,'74771','watch','text-align','left',0,''),(355734,113359,'74775','watch','description_characters','90',0,''),(355735,113360,'74776','watch','text-align','right',0,''),(355736,113360,'74776','watch','margin-bottom','10',0,''),(355737,113361,'74777','watch','text-align','right',0,''),(355738,113361,'74777','watch','clear','none',0,''),(355739,113361,'74777','watch','float','left',0,''),(355740,113363,'74779','watch','block_type','2',0,''),(355741,113364,'74780','watch','margin-bottom','7',0,''),(355742,113365,'74781','watch','margin-bottom','10',0,''),(355743,113365,'74781','watch','text-align','right',0,''),(355744,113365,'74781','watch','float','right',0,''),(355745,113366,'74782','watch','clear','both',0,''),(355746,113367,'74783','watch','float','left',0,''),(355747,113367,'74783','watch','margin-right','20',0,''),(355748,113367,'74783','watch','margin-bottom','5',0,''),(355749,113369,'74785','watch','block_type','1',0,''),(355750,113370,'74786','watch','block_type','6',0,''),(355751,113370,'74786','watch','font-weight','400',0,''),(355752,113370,'74786','watch','schema','6-2',0,'5261'),(355753,113370,'74786','watch','schema','6-2',0,'5240'),(355754,113371,'74787','watch','font-weight','400',0,''),(355755,113371,'74787','watch','padding-right','40',0,''),(355756,113371,'74787','watch','padding-right','0',0,'5261'),(355757,113371,'74787','watch','padding-right','0',0,'5240'),(355758,113371,'74787','watch','margin-bottom','20',0,''),(355759,113372,'74788','watch','margin-bottom','20',0,''),(355760,113374,'74790','watch','block_type','1',0,''),(355761,113374,'74790','watch','padding-top','10',0,''),(355762,113374,'74790','watch','padding-bottom','10',0,''),(355763,113374,'74790','watch','border-bottom-width','1',0,''),(355764,113374,'74790','watch','border-bottom-color','$content-border-1',0,''),(355765,113374,'74790','watch','margin-left','0',0,''),(355766,113374,'74790','watch','margin-right','0',0,''),(355767,113375,'74791','watch','float','left',0,''),(355768,113375,'74791','watch','clear','none',0,''),(355769,113375,'74791','watch','sort_pos_3','2',0,''),(355770,113375,'74791','watch','sort_pos_4','3',0,''),(355771,113375,'74791','watch','sort_pos_10','11',0,''),(355772,113375,'74791','watch','sort_pos_9','10',0,''),(355773,113375,'74791','watch','sort_pos_11','12',0,''),(355774,113375,'74791','watch','sort_pos_12','13',0,''),(355775,113375,'74791','watch','sort_pos_14','15',0,''),(355776,113375,'74791','watch','sort_pos_13','14',0,''),(355777,113375,'74791','watch','sort_pos_8','4',0,''),(355778,113375,'74791','watch','sort_pos_7','5',0,''),(355779,113375,'74791','watch','sort_pos_2','7',0,''),(355780,113375,'74791','watch','sort_pos_1','6',0,''),(355781,113375,'74791','watch','sort_pos_6','9',0,''),(355782,113375,'74791','watch','sort_pos_5','8',0,''),(355783,113375,'74791','watch','sort_pos_0','1',0,''),(355784,113375,'74791','watch','sort_hide_10','1',0,''),(355785,113375,'74791','watch','sort_hide_9','1',0,''),(355786,113375,'74791','watch','sort_pos_15','16',0,''),(355787,113375,'74791','watch','sort_pos_16','17',0,''),(355788,113375,'74791','watch','sort_hide_4','0',0,''),(355789,113375,'74791','watch','sort_hide_3','0',0,''),(355790,113375,'74791','watch','sort_hide_16','1',0,''),(355791,113375,'74791','watch','sort_hide_15','1',0,''),(355792,113375,'74791','watch','sort_hide_11','1',0,''),(355793,113375,'74791','watch','sort_hide_12','1',0,''),(355794,113375,'74791','watch','sort_hide_14','1',0,''),(355795,113375,'74791','watch','sort_hide_13','1',0,''),(355796,113375,'74791','watch','sort_hide_8','0',0,''),(355797,113375,'74791','watch','sort_hide_7','0',0,''),(355798,113375,'74791','watch','sort_hide_2','1',0,''),(355799,113375,'74791','watch','sort_hide_1','1',0,''),(355800,113375,'74791','watch','sort_hide_6','1',0,''),(355801,113375,'74791','watch','sort_hide_5','1',0,''),(355802,113375,'74791','watch','sort_hide_0','0',0,''),(355803,113375,'74791','watch','hide_icons','1',0,''),(355804,113376,'74792','watch','float','right',0,''),(355805,113376,'74792','watch','display','none',0,'5261'),(355806,113377,'74793','watch','float','left',0,''),(355807,113377,'74793','watch','clear','none',0,''),(355808,113377,'74793','watch','margin-left','20',0,''),(355809,113377,'74793','watch','display','none',0,'5261'),(355810,113378,'74794','watch','margin-right','20',0,''),(355811,113378,'74794','watch','float','right',0,''),(355812,113378,'74794','watch','clear','none',0,''),(355813,113378,'74794','watch','display','none',0,'5240'),(355814,113379,'74795','watch','block_type','5',0,''),(355815,113379,'74795','watch','padding-top','10',0,''),(355816,113379,'74795','watch','padding-bottom','10',0,''),(355817,113379,'74795','watch','schema','5-2',0,'5261'),(355818,113379,'74795','watch','border-top-color','$content-border-1',0,''),(355819,113379,'74795','watch','border-top-width','1',0,''),(355820,113380,'74796','watch','padding-top','3',0,''),(355821,113381,'74797','watch','float','right',0,''),(355822,113381,'74797','watch','height','31',0,''),(355823,113382,'74798','watch','col_in_row','3',0,''),(355824,113382,'74798','watch','products_align','left',0,''),(355825,113382,'74798','watch','font-weight','400',0,''),(355826,113382,'74798','watch','listing_type','productListing',0,''),(355827,113382,'74798','watch','listing_type_rows','Rows',0,''),(355828,113382,'74798','watch','show_buy_button_b2b','on',0,''),(355829,113382,'74798','watch','show_wishlist_button_b2b','1',0,''),(355830,113382,'74798','watch','show_compare_b2b','1',0,''),(355831,113382,'74798','watch','show_image','0',0,''),(355832,113382,'74798','watch','show_stock','0',0,''),(355833,113382,'74798','watch','show_description','0',0,''),(355834,113382,'74798','watch','show_model','0',0,''),(355835,113382,'74798','watch','show_properties','0',0,''),(355836,113382,'74798','watch','show_rating','0',0,''),(355837,113382,'74798','watch','show_rating_counts','0',0,''),(355838,113382,'74798','watch','show_price','0',0,''),(355839,113382,'74798','watch','show_buy_button','0',0,''),(355840,113382,'74798','watch','show_view_button','0',0,''),(355841,113382,'74798','watch','show_wishlist_button','0',0,''),(355842,113382,'74798','watch','show_compare','0',0,''),(355843,113382,'74798','watch','show_name_rows','0',0,''),(355844,113382,'74798','watch','show_image_rows','0',0,''),(355845,113382,'74798','watch','show_stock_rows','0',0,''),(355846,113382,'74798','watch','show_description_rows','0',0,''),(355847,113382,'74798','watch','show_model_rows','0',0,''),(355848,113382,'74798','watch','show_properties_rows','0',0,''),(355849,113382,'74798','watch','show_rating_rows','0',0,''),(355850,113382,'74798','watch','show_rating_counts_rows','0',0,''),(355851,113382,'74798','watch','show_price_rows','0',0,''),(355852,113382,'74798','watch','show_buy_button_rows','0',0,''),(355853,113382,'74798','watch','show_qty_input_rows','0',0,''),(355854,113382,'74798','watch','show_view_button_rows','0',0,''),(355855,113382,'74798','watch','show_wishlist_button_rows','0',0,''),(355856,113382,'74798','watch','show_compare_rows','0',0,''),(355857,113382,'74798','watch','show_name_b2b','0',0,''),(355858,113382,'74798','watch','show_image_b2b','0',0,''),(355859,113382,'74798','watch','show_stock_b2b','0',0,''),(355860,113382,'74798','watch','show_description_b2b','0',0,''),(355861,113382,'74798','watch','show_model_b2b','0',0,''),(355862,113382,'74798','watch','show_properties_b2b','0',0,''),(355863,113382,'74798','watch','show_rating_b2b','0',0,''),(355864,113382,'74798','watch','show_rating_counts_b2b','0',0,''),(355865,113382,'74798','watch','show_price_b2b','0',0,''),(355866,113382,'74798','watch','show_qty_input_b2b','0',0,''),(355867,113382,'74798','watch','show_view_button_b2b','0',0,''),(355868,113382,'74798','watch','show_attributes_b2b','0',0,''),(355869,113382,'74798','watch','items_on_page','9',0,''),(355870,113382,'74798','watch','col_in_row','2',0,'5240'),(355871,113382,'74798','watch','col_in_row','1',0,'5261'),(355872,113382,'74798','watch','product_names_teg','h2',0,''),(355873,113384,'74800','watch','block_type','1',0,''),(355874,113385,'74801','watch','margin-bottom','20',0,''),(355875,113387,'74802','watch','block_type','1',0,''),(355876,113389,'74804','watch','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(355877,113390,'74805','watch','width','680',0,''),(355878,113390,'74805','watch','font-weight','normal',0,''),(355879,113390,'74805','watch','font-size','12',0,''),(355880,113390,'74805','watch','padding-top','20',0,''),(355881,113390,'74805','watch','padding-bottom','20',0,''),(355882,113390,'74805','watch','color','$content-color-1',0,''),(355883,113391,'74806','watch','font-weight','400',0,''),(355884,113391,'74806','watch','padding-top','20',0,''),(355885,113391,'74806','watch','padding-bottom','0',0,''),(355886,113391,'74806','watch','font-size','12',0,''),(355887,113392,'74807','watch','block_type','3',0,''),(355888,113392,'74807','watch','font-weight','normal',0,''),(355889,113392,'74807','watch','padding-top','20',0,''),(355890,113393,'74808','watch','text','<p>If undelivered please return to:</p>',1,''),(355891,113393,'74808','watch','font-size','12',0,''),(355892,113393,'74808','watch','font-weight','bold',0,''),(355893,113393,'74808','watch','text','<p>If undelivered please return to:</p>',2,''),(355894,113393,'74808','watch','text','<p>If undelivered please return to:</p>',3,''),(355895,113393,'74808','watch','text','<p>If undelivered please return to:</p>',4,''),(355896,113394,'74809','watch','font-size','12',0,''),(355897,113395,'74810','watch','text','<p>Thank you for your order</p>',1,''),(355898,113395,'74810','watch','color','$color-8',0,''),(355899,113395,'74810','watch','font-size','13',0,''),(355900,113395,'74810','watch','font-weight','bold',0,''),(355901,113395,'74810','watch','padding-top','5',0,''),(355902,113395,'74810','watch','text-align','center',0,''),(355903,113395,'74810','watch','text','<p>Thank you for your order</p>',2,''),(355904,113395,'74810','watch','text','<p>Thank you for your order</p>',3,''),(355905,113395,'74810','watch','text','<p>Thank you for your order</p>',4,''),(355906,113396,'74811','watch','font-weight','400',0,''),(355907,113396,'74811','watch','text-align','center',0,''),(355908,113396,'74811','watch','padding-top','0',0,''),(355910,113396,'74811','watch','padding-left','20',0,''),(355911,113396,'74811','watch','padding-right','20',0,''),(355915,113397,'74812','watch','block_type','6',0,''),(355916,113397,'74812','watch','font-weight','normal',0,''),(355917,113397,'74812','watch','font-size','16',0,''),(355918,113398,'74813','watch','text','<p>Email:</p>',1,''),(355919,113398,'74813','watch','font-weight','normal',0,''),(355920,113398,'74813','watch','text-align','right',0,''),(355921,113398,'74813','watch','font-size','12',0,''),(355922,113398,'74813','watch','text','<p>Email:</p>',2,''),(355923,113398,'74813','watch','text','<p>Email:</p>',3,''),(355924,113398,'74813','watch','text','<p>Email:</p>',4,''),(355925,113399,'74814','watch','font-weight','normal',0,''),(355926,113399,'74814','watch','text-align','right',0,''),(355927,113399,'74814','watch','font-size','12',0,''),(355928,113400,'74815','watch','text','<p>If something has gone wrong please contact us at:</p>',1,''),(355929,113400,'74815','watch','font-size','12',0,''),(355930,113400,'74815','watch','font-weight','bold',0,''),(355931,113400,'74815','watch','text-align','right',0,''),(355932,113400,'74815','watch','text','<p>If something has gone wrong please contact us at:</p>',2,''),(355933,113400,'74815','watch','text','<p>If something has gone wrong please contact us at:</p>',3,''),(355934,113400,'74815','watch','text','<p>If something has gone wrong please contact us at:</p>',4,''),(355935,113401,'74816','watch','block_type','6',0,''),(355936,113401,'74816','watch','font-weight','normal',0,''),(355937,113401,'74816','watch','font-size','16',0,''),(355938,113402,'74817','watch','text','<p>Phone:</p>',1,''),(355939,113402,'74817','watch','font-weight','normal',0,''),(355940,113402,'74817','watch','text-align','right',0,''),(355941,113402,'74817','watch','font-size','12',0,''),(355942,113402,'74817','watch','text','<p>Phone:</p>',2,''),(355943,113402,'74817','watch','text','<p>Phone:</p>',3,''),(355944,113402,'74817','watch','text','<p>Phone:</p>',4,''),(355945,113403,'74818','watch','font-weight','normal',0,''),(355946,113403,'74818','watch','text-align','right',0,''),(355947,113403,'74818','watch','font-size','12',0,''),(355948,113404,'74819','watch','block_type','2',0,''),(355949,113404,'74819','watch','font-weight','normal',0,''),(355950,113404,'74819','watch','padding-bottom','20',0,''),(355951,113405,'74820','watch','font-weight','400',0,''),(355952,113405,'74820','watch','padding-top','20',0,''),(355957,113406,'74821','watch','block_type','11',0,''),(355958,113406,'74821','watch','font-weight','normal',0,''),(355959,113407,'74822','watch','text','<p>Phone:</p>',1,''),(355960,113407,'74822','watch','font-weight','normal',0,''),(355961,113407,'74822','watch','text-align','right',0,''),(355962,113407,'74822','watch','text','<p>Phone:</p>',2,''),(355963,113407,'74822','watch','text','<p>Phone:</p>',3,''),(355964,113407,'74822','watch','text','<p>Phone:</p>',4,''),(355965,113408,'74823','watch','font-weight','normal',0,''),(355966,113408,'74823','watch','text-align','right',0,''),(355967,113409,'74824','watch','block_type','11',0,''),(355968,113409,'74824','watch','font-weight','normal',0,''),(355969,113410,'74825','watch','text','<p>Web:</p>',1,''),(355970,113410,'74825','watch','font-weight','normal',0,''),(355971,113410,'74825','watch','text-align','right',0,''),(355972,113410,'74825','watch','text','<p>Web:</p>',2,''),(355973,113410,'74825','watch','text','<p>Web:</p>',3,''),(355974,113410,'74825','watch','text','<p>Web:</p>',4,''),(355975,113411,'74826','watch','font-weight','normal',0,''),(355976,113411,'74826','watch','text-align','right',0,''),(355977,113412,'74827','watch','block_type','1',0,''),(355978,113413,'74828','watch','font-weight','normal',0,''),(355979,113413,'74828','watch','text-align','right',0,''),(355980,113413,'74828','watch','padding-bottom','10',0,''),(355981,113413,'74828','watch','address_spacer',',',0,''),(355982,113413,'74828','watch','font-size','12',0,''),(355983,113414,'74829','watch','block_type','11',0,''),(355984,113414,'74829','watch','font-weight','normal',0,''),(355985,113415,'74830','watch','text','<p>Email:</p>',1,''),(355986,113415,'74830','watch','font-weight','normal',0,''),(355987,113415,'74830','watch','text-align','right',0,''),(355988,113415,'74830','watch','text','<p>Email:</p>',2,''),(355989,113415,'74830','watch','text','<p>Email:</p>',3,''),(355990,113415,'74830','watch','text','<p>Email:</p>',4,''),(355991,113416,'74831','watch','font-weight','normal',0,''),(355992,113416,'74831','watch','text-align','right',0,''),(355993,113417,'74832','watch','block_type','4',0,''),(355994,113417,'74832','watch','font-weight','normal',0,''),(355995,113417,'74832','watch','border-top-width','1',0,''),(355996,113417,'74832','watch','border-top-color','$content-border-1',0,''),(355997,113417,'74832','watch','border-left-width','1',0,''),(355998,113417,'74832','watch','border-left-color','$content-border-1',0,''),(355999,113417,'74832','watch','border-right-width','1',0,''),(356000,113417,'74832','watch','border-right-color','$content-border-1',0,''),(356001,113417,'74832','watch','border-bottom-width','1',0,''),(356002,113417,'74832','watch','border-bottom-color','$content-border-1',0,''),(356003,113418,'74833','watch','block_type','2',0,''),(356004,113418,'74833','watch','font-weight','normal',0,''),(356005,113418,'74833','watch','border-right-width','1',0,''),(356006,113418,'74833','watch','border-right-color','$content-border-1',0,''),(356007,113419,'74834','watch','block_type','1',0,''),(356008,113419,'74834','watch','font-weight','400',0,''),(356009,113419,'74834','watch','background-color','$content-bg-2',0,''),(356010,113419,'74834','watch','padding-top','10',0,''),(356011,113419,'74834','watch','padding-left','10',0,''),(356012,113419,'74834','watch','padding-right','10',0,''),(356013,113419,'74834','watch','padding-bottom','30',0,''),(356014,113420,'74835','watch','font-size','12',0,''),(356015,113421,'74836','watch','text','<p>ADDRESS:</p>\n',1,''),(356016,113421,'74836','watch','font-size','14',0,''),(356017,113421,'74836','watch','font-weight','bold',0,''),(356018,113421,'74836','watch','text','<p>ADDRESS:</p>\n',2,''),(356019,113421,'74836','watch','text','<p>ADDRESS:</p>\n',3,''),(356020,113421,'74836','watch','text','<p>ADDRESS:</p>\n',4,''),(356021,113422,'74837','watch','block_type','1',0,''),(356022,113422,'74837','watch','font-weight','normal',0,''),(356023,113422,'74837','watch','padding-top','10',0,''),(356024,113422,'74837','watch','padding-left','10',0,''),(356025,113422,'74837','watch','padding-right','10',0,''),(356026,113422,'74837','watch','padding-bottom','10',0,''),(356027,113424,'74839','watch','text','<p>E-MAIL ADDRESS:</p>',1,''),(356028,113424,'74839','watch','font-weight','bold',0,''),(356029,113424,'74839','watch','font-size','14',0,''),(356030,113424,'74839','watch','padding-top','10',0,''),(356031,113424,'74839','watch','text','<p>E-MAIL ADDRESS:</p>',2,''),(356032,113424,'74839','watch','text','<p>E-MAIL ADDRESS:</p>',3,''),(356033,113424,'74839','watch','text','<p>E-MAIL ADDRESS:</p>',4,''),(356034,113425,'74840','watch','font-weight','normal',0,''),(356035,113426,'74841','watch','font-weight','normal',0,''),(356036,113427,'74842','watch','text','<p>PHONE NUMBER:</p>',1,''),(356037,113427,'74842','watch','font-size','14',0,''),(356038,113427,'74842','watch','font-weight','bold',0,''),(356039,113427,'74842','watch','padding-top','10',0,''),(356040,113427,'74842','watch','text','<p>PHONE NUMBER:</p>',2,''),(356041,113427,'74842','watch','text','<p>PHONE NUMBER:</p>',3,''),(356042,113427,'74842','watch','text','<p>PHONE NUMBER:</p>',4,''),(356043,113428,'74843','watch','text','<p>CUSTOMER:</p>',1,''),(356044,113428,'74843','watch','font-size','13',0,''),(356045,113428,'74843','watch','font-weight','bold',0,''),(356046,113428,'74843','watch','text','<p>CUSTOMER:</p>',2,''),(356047,113428,'74843','watch','text','<p>CUSTOMER:</p>',3,''),(356048,113428,'74843','watch','text','<p>CUSTOMER:</p>',4,''),(356049,113429,'74844','watch','font-size','14',0,''),(356050,113429,'74844','watch','font-weight','bold',0,''),(356051,113429,'74844','watch','text-align','center',0,''),(356052,113429,'74844','watch','padding-bottom','10',0,''),(356053,113429,'74844','watch','padding-top','10',0,''),(356054,113430,'74845','watch','text','<p>Order date:</p>\n',1,''),(356055,113430,'74845','watch','font-weight','bold',0,''),(356056,113430,'74845','watch','text-align','center',0,''),(356057,113430,'74845','watch','font-size','12',0,''),(356058,113430,'74845','watch','text','<p>Order date:</p>\n',2,''),(356059,113430,'74845','watch','text','<p>Order date:</p>\n',3,''),(356060,113430,'74845','watch','text','<p>Order date:</p>\n',4,''),(356061,113431,'74846','watch','font-weight','normal',0,''),(356062,113431,'74846','watch','text-align','center',0,''),(356063,113431,'74846','watch','padding-bottom','10',0,''),(356064,113432,'74847','watch','block_type','5',0,''),(356065,113432,'74847','watch','font-weight','normal',0,''),(356066,113432,'74847','watch','border-bottom-width','1',0,''),(356067,113432,'74847','watch','border-bottom-color','$content-border-1',0,''),(356068,113432,'74847','watch','border-top-width','1',0,''),(356069,113432,'74847','watch','border-top-color','$content-border-1',0,''),(356070,113432,'74847','watch','border-left-color','$content-border-1',0,''),(356071,113432,'74847','watch','border-left-width','1',0,''),(356072,113433,'74848','watch','block_type','1',0,''),(356073,113433,'74848','watch','font-weight','normal',0,''),(356074,113433,'74848','watch','padding-top','10',0,''),(356075,113433,'74848','watch','padding-left','10',0,''),(356076,113433,'74848','watch','padding-right','10',0,''),(356077,113434,'74849','watch','font-weight','400',0,''),(356078,113434,'74849','watch','line-height','120',0,''),(356079,113434,'74849','watch','line_height_measure','%',0,''),(356080,113434,'74849','watch','font-size','12',0,''),(356081,113435,'74850','watch','text','<p>SHIPPING ADDRESS:</p>',1,''),(356082,113435,'74850','watch','font-size','14',0,''),(356083,113435,'74850','watch','font-weight','bold',0,''),(356084,113435,'74850','watch','padding-bottom','10',0,''),(356085,113435,'74850','watch','text','<p>SHIPPING ADDRESS:</p>',2,''),(356086,113435,'74850','watch','text','<p>SHIPPING ADDRESS:</p>',3,''),(356087,113435,'74850','watch','text','<p>SHIPPING ADDRESS:</p>',4,''),(356088,113436,'74851','watch','block_type','1',0,''),(356089,113437,'74852','watch','block_type','6',0,''),(356090,113438,'74853','watch','aria_name','account-menu',0,''),(356148,113458,'74854','watch','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(356149,113459,'74855','watch','link','Quotation Info',0,''),(356150,113459,'74855','watch','margin-bottom','20',0,''),(356151,113460,'74856','watch','block_type','1',0,''),(356152,113461,'74857','watch','block_type','6',0,''),(356153,113461,'74857','watch','schema','6-3',0,'5240'),(356154,113462,'74858','watch','aria_name','account-menu',0,''),(356212,113482,'74859','watch','block_type','3',0,''),(356213,113483,'74860','watch','block_type','1',0,''),(356214,113483,'74860','watch','padding-right','20',0,''),(356215,113483,'74860','watch','padding-bottom','20',0,''),(356216,113484,'74861','watch','orders_data','name',0,''),(356217,113485,'74862','watch','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(356218,113486,'74863','watch','block_type','1',0,''),(356219,113486,'74863','watch','padding-right','20',0,''),(356220,113486,'74863','watch','padding-bottom','20',0,''),(356221,113487,'74864','watch','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(356222,113488,'74865','watch','orders_data','telephone',0,''),(356223,113489,'74866','watch','block_type','1',0,''),(356224,113489,'74866','watch','padding-right','20',0,''),(356225,113490,'74867','watch','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(356226,113491,'74868','watch','orders_data','shipping_method',0,''),(356227,113492,'74869','watch','block_type','1',0,''),(356228,113492,'74869','watch','padding-right','20',0,''),(356229,113492,'74869','watch','padding-bottom','20',0,''),(356230,113493,'74870','watch','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(356231,113494,'74871','watch','orders_data','delivery_address',0,''),(356232,113495,'74872','watch','block_type','1',0,''),(356233,113495,'74872','watch','padding-bottom','20',0,''),(356234,113496,'74873','watch','orders_data','billing_address',0,''),(356235,113497,'74874','watch','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(356236,113498,'74875','watch','block_type','1',0,''),(356237,113499,'74876','watch','orders_data','payment_method',0,''),(356238,113500,'74877','watch','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(356239,113501,'74878','watch','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(356240,113503,'74880','watch','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(356241,113506,'74883','watch','block_type','2',0,''),(356242,113506,'74883','watch','padding-top','20',0,''),(356243,113506,'74883','watch','margin-bottom','20',0,''),(356244,113507,'74884','watch','like_button','1',0,''),(356245,113507,'74884','watch','text','IMAGE_BUTTON_BACK',0,''),(356246,113507,'74884','watch','link','Quotations',0,''),(356247,113508,'74885','watch','text','<h1>##HEADING_TITLE##</h1>',0,''),(356248,113509,'74886','watch','padding-top','20',0,''),(356249,113509,'74886','watch','padding-bottom','20',0,''),(356250,113509,'74886','watch','block_type','1',0,''),(356251,113509,'74886','watch','background-color','$content-bg-2',0,''),(356252,113511,'74888','watch','block_type','4',0,''),(356253,113512,'74889','watch','background-color','$content-bg-1',0,''),(356254,113513,'74890','watch','block_type','1',0,''),(356255,113513,'74890','watch','style_class','order-summary',0,''),(356256,113513,'74890','watch','margin-left','30',0,''),(356257,113514,'74891','watch','block_type','1',0,''),(356258,113514,'74891','watch','padding-left','20',0,''),(356259,113514,'74891','watch','padding-right','20',0,''),(356260,113514,'74891','watch','padding-bottom','30',0,''),(356261,113517,'74894','watch','block_type','1',0,''),(356324,113541,'74899','watch','block_type','1',0,''),(356325,113543,'74901','watch','pagination','bottom',0,''),(356326,113544,'74902','watch','width','800',0,''),(356327,113545,'74903','watch','block_type','11',0,''),(356328,113545,'74903','watch','border-top-width','1',0,''),(356329,113545,'74903','watch','border-left-width','1',0,''),(356330,113545,'74903','watch','border-right-width','1',0,''),(356331,113545,'74903','watch','border-bottom-width','1',0,''),(356332,113545,'74903','watch','border-top-color','$content-border-1',0,''),(356333,113545,'74903','watch','border-left-color','$content-border-1',0,''),(356334,113545,'74903','watch','border-right-color','$content-border-1',0,''),(356335,113545,'74903','watch','border-bottom-color','$content-border-1',0,''),(356336,113546,'74904','watch','block_type','1',0,''),(356337,113546,'74904','watch','border-right-width','1',0,''),(356338,113546,'74904','watch','border-right-color','$content-border-1',0,''),(356339,113546,'74904','watch','padding-top','10',0,''),(356340,113546,'74904','watch','padding-right','10',0,''),(356341,113546,'74904','watch','padding-bottom','10',0,''),(356342,113547,'74905','watch','block_type','9',0,''),(356343,113548,'74906','watch','text','1.',0,''),(356344,113548,'74906','watch','font-size','12',0,''),(356345,113548,'74906','watch','text-align','right',0,''),(356346,113548,'74906','watch','padding-right','5',0,''),(356347,113549,'74907','watch','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(356348,113549,'74907','watch','font-size','12',0,''),(356349,113549,'74907','watch','padding-bottom','5',0,''),(356350,113550,'74908','watch','block_type','9',0,''),(356351,113551,'74909','watch','text','4.',0,''),(356352,113551,'74909','watch','font-size','12',0,''),(356353,113551,'74909','watch','text-align','right',0,''),(356354,113551,'74909','watch','margin-right','5',0,''),(356355,113552,'74910','watch','text','Our Replacement Department will process your request.',0,''),(356356,113552,'74910','watch','font-size','12',0,''),(356357,113552,'74910','watch','padding-bottom','5',0,''),(356358,113553,'74911','watch','block_type','9',0,''),(356359,113554,'74912','watch','text','3.',0,''),(356360,113554,'74912','watch','font-size','12',0,''),(356361,113554,'74912','watch','text-align','right',0,''),(356362,113554,'74912','watch','margin-right','5',0,''),(356363,113555,'74913','watch','text','Return the authorized item(s) per shipping instructions.',0,''),(356364,113555,'74913','watch','font-size','12',0,''),(356365,113555,'74913','watch','padding-bottom','5',0,''),(356366,113556,'74914','watch','block_type','9',0,''),(356367,113557,'74915','watch','text','2.',0,''),(356368,113557,'74915','watch','font-size','12',0,''),(356369,113557,'74915','watch','text-align','right',0,''),(356370,113557,'74915','watch','margin-right','5',0,''),(356371,113558,'74916','watch','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(356372,113558,'74916','watch','font-size','12',0,''),(356373,113558,'74916','watch','padding-bottom','5',0,''),(356374,113559,'74917','watch','block_type','1',0,''),(356375,113559,'74917','watch','padding-left','15',0,''),(356376,113560,'74918','watch','text','Replacement Policy:',0,''),(356377,113560,'74918','watch','font-size','14',0,''),(356378,113560,'74918','watch','padding-bottom','5',0,''),(356379,113560,'74918','watch','font-weight','bold',0,''),(356380,113561,'74919','watch','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(356381,113561,'74919','watch','font-size','11',0,''),(356382,113561,'74919','watch','font-style','italic',0,''),(356383,113561,'74919','watch','padding-bottom','5',0,''),(356384,113562,'74920','watch','block_type','1',0,''),(356385,113562,'74920','watch','border-bottom-width','1',0,''),(356386,113562,'74920','watch','border-bottom-color','$content-border-1',0,''),(356387,113563,'74921','watch','text','Return Material Authorization (RMA) Form',0,''),(356388,113563,'74921','watch','text-align','center',0,''),(356389,113563,'74921','watch','font-size','16',0,''),(356390,113563,'74921','watch','font-weight','bold',0,''),(356391,113564,'74922','watch','text-align','center',0,''),(356393,113564,'74922','watch','padding-top','10',0,''),(356394,113564,'74922','watch','padding-bottom','10',0,''),(356398,113565,'74923','watch','block_type','1',0,''),(356399,113565,'74923','watch','padding-top','10',0,''),(356400,113565,'74923','watch','padding-left','10',0,''),(356401,113565,'74923','watch','padding-right','10',0,''),(356402,113565,'74923','watch','padding-bottom','20',0,''),(356403,113566,'74924','watch','block_type','2',0,''),(356404,113566,'74924','watch','padding-top','5',0,''),(356405,113567,'74925','watch','block_type','11',0,''),(356406,113568,'74926','watch','text','Email:',0,''),(356407,113568,'74926','watch','font-size','12',0,''),(356408,113569,'74927','watch','data','rrDelivery_email_address',0,''),(356409,113569,'74927','watch','font-size','12',0,''),(356410,113570,'74928','watch','block_type','11',0,''),(356411,113571,'74929','watch','text','Phone:',0,''),(356412,113571,'74929','watch','font-size','12',0,''),(356413,113572,'74930','watch','data','rrDelivery_telephone',0,''),(356414,113572,'74930','watch','font-size','12',0,''),(356415,113573,'74931','watch','block_type','2',0,''),(356416,113573,'74931','watch','padding-top','5',0,''),(356417,113574,'74932','watch','block_type','11',0,''),(356418,113575,'74933','watch','text','Country:',0,''),(356419,113575,'74933','watch','font-size','12',0,''),(356420,113576,'74934','watch','data','rrDelivery_country',0,''),(356421,113576,'74934','watch','font-size','12',0,''),(356422,113577,'74935','watch','block_type','11',0,''),(356423,113578,'74936','watch','text','Postcode:',0,''),(356424,113578,'74936','watch','font-size','12',0,''),(356425,113579,'74937','watch','data','rrDelivery_postcode',0,''),(356426,113579,'74937','watch','font-size','12',0,''),(356427,113580,'74938','watch','block_type','2',0,''),(356428,113580,'74938','watch','padding-top','5',0,''),(356429,113581,'74939','watch','block_type','11',0,''),(356430,113582,'74940','watch','text','City:',0,''),(356431,113582,'74940','watch','font-size','12',0,''),(356432,113583,'74941','watch','data','rrDelivery_city',0,''),(356433,113583,'74941','watch','font-size','12',0,''),(356434,113584,'74942','watch','block_type','11',0,''),(356435,113585,'74943','watch','text','State:',0,''),(356436,113585,'74943','watch','font-size','12',0,''),(356437,113586,'74944','watch','data','rrDelivery_state',0,''),(356438,113586,'74944','watch','font-size','12',0,''),(356439,113587,'74945','watch','block_type','9',0,''),(356440,113587,'74945','watch','padding-top','5',0,''),(356441,113588,'74946','watch','text','Address:',0,''),(356442,113588,'74946','watch','font-size','12',0,''),(356443,113589,'74947','watch','data','rrDelivery_street_address',0,''),(356444,113589,'74947','watch','font-size','12',0,''),(356445,113590,'74948','watch','block_type','2',0,''),(356446,113591,'74949','watch','block_type','11',0,''),(356447,113592,'74950','watch','text','Company:',0,''),(356448,113592,'74950','watch','font-size','12',0,''),(356449,113593,'74951','watch','data','rrDelivery_company',0,''),(356450,113593,'74951','watch','font-size','12',0,''),(356451,113594,'74952','watch','block_type','2',0,''),(356452,113595,'74953','watch','text','Contact Name:',0,''),(356453,113595,'74953','watch','font-size','12',0,''),(356454,113596,'74954','watch','data','rrDelivery_name',0,''),(356455,113596,'74954','watch','font-size','12',0,''),(356456,113597,'74955','watch','block_type','2',0,''),(356457,113597,'74955','watch','padding-left','10',0,''),(356458,113597,'74955','watch','padding-top','20',0,''),(356459,113597,'74955','watch','padding-right','10',0,''),(356460,113598,'74956','watch','block_type','5',0,''),(356461,113599,'74957','watch','text','RMA No:',0,''),(356462,113599,'74957','watch','font-size','12',0,''),(356463,113599,'74957','watch','font-weight','bold',0,''),(356464,113600,'74958','watch','data','rrNumber',0,''),(356465,113600,'74958','watch','font-size','12',0,''),(356466,113600,'74958','watch','font-weight','bold',0,''),(356467,113601,'74959','watch','block_type','2',0,''),(356468,113602,'74960','watch','text','Date Issued:',0,''),(356469,113602,'74960','watch','font-size','12',0,''),(356470,113602,'74960','watch','font-weight','bold',0,''),(356471,113603,'74961','watch','data','rrDateCreate',0,''),(356472,113603,'74961','watch','font-size','12',0,''),(356473,113603,'74961','watch','font-weight','bold',0,''),(356474,113604,'74962','watch','block_type','1',0,''),(356475,113605,'74963','watch','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(356476,113605,'74963','watch','font-size','12',0,''),(356477,113605,'74963','watch','font-style','italic',0,''),(356478,113605,'74963','watch','padding-bottom','20',0,''),(356479,113607,'74965','watch','block_type','1',0,''),(356480,113607,'74965','watch','border-top-width','1',0,''),(356481,113607,'74965','watch','border-left-width','1',0,''),(356482,113607,'74965','watch','border-right-width','1',0,''),(356483,113607,'74965','watch','border-bottom-width','1',0,''),(356484,113607,'74965','watch','border-top-color','$content-border-1',0,''),(356485,113607,'74965','watch','border-left-color','$content-border-1',0,''),(356486,113607,'74965','watch','border-right-color','$content-border-1',0,''),(356487,113607,'74965','watch','border-bottom-color','$content-border-1',0,''),(356488,113608,'74966','watch','block_type','11',0,''),(356489,113609,'74967','watch','block_type','1',0,''),(356490,113609,'74967','watch','padding-top','10',0,''),(356491,113609,'74967','watch','padding-right','10',0,''),(356492,113609,'74967','watch','padding-bottom','10',0,''),(356493,113609,'74967','watch','border-right-width','1',0,''),(356494,113609,'74967','watch','border-right-color','$content-border-1',0,''),(356495,113610,'74968','watch','block_type','9',0,''),(356496,113611,'74969','watch','text','4.',0,''),(356497,113611,'74969','watch','font-size','12',0,''),(356498,113611,'74969','watch','text-align','right',0,''),(356499,113611,'74969','watch','padding-right','5',0,''),(356500,113612,'74970','watch','font-size','11',0,''),(356501,113612,'74970','watch','font-style','italic',0,''),(356502,113612,'74970','watch','padding-bottom','5',0,''),(356503,113613,'74971','watch','text','Ship returned items to:',0,''),(356504,113613,'74971','watch','font-size','12',0,''),(356505,113613,'74971','watch','padding-bottom','5',0,''),(356506,113614,'74972','watch','block_type','9',0,''),(356507,113615,'74973','watch','text','3.',0,''),(356508,113615,'74973','watch','font-size','12',0,''),(356509,113615,'74973','watch','text-align','right',0,''),(356510,113615,'74973','watch','padding-right','5',0,''),(356511,113616,'74974','watch','text','Ship only the items that are authorized.',0,''),(356512,113616,'74974','watch','font-size','12',0,''),(356513,113616,'74974','watch','padding-bottom','10',0,''),(356514,113617,'74975','watch','block_type','9',0,''),(356515,113618,'74976','watch','text','1.',0,''),(356516,113618,'74976','watch','font-size','12',0,''),(356517,113618,'74976','watch','text-align','right',0,''),(356518,113618,'74976','watch','padding-right','5',0,''),(356519,113619,'74977','watch','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(356520,113619,'74977','watch','font-size','12',0,''),(356521,113619,'74977','watch','padding-bottom','10',0,''),(356522,113620,'74978','watch','block_type','1',0,''),(356523,113621,'74979','watch','text','Shipping Instructions:',0,''),(356524,113621,'74979','watch','font-weight','bold',0,''),(356525,113621,'74979','watch','font-size','14',0,''),(356526,113621,'74979','watch','padding-bottom','5',0,''),(356527,113621,'74979','watch','padding-left','10',0,''),(356528,113622,'74980','watch','block_type','9',0,''),(356529,113623,'74981','watch','text','2.',0,''),(356530,113623,'74981','watch','font-size','12',0,''),(356531,113623,'74981','watch','text-align','right',0,''),(356532,113623,'74981','watch','padding-right','5',0,''),(356533,113624,'74982','watch','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(356534,113624,'74982','watch','font-size','12',0,''),(356535,113624,'74982','watch','padding-bottom','10',0,''),(356536,113625,'74983','watch','block_type','1',0,''),(356537,113625,'74983','watch','padding-left','10',0,''),(356538,113625,'74983','watch','padding-right','10',0,''),(356539,113625,'74983','watch','padding-bottom','10',0,''),(356540,113626,'74984','watch','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(356541,113626,'74984','watch','font-size','11',0,''),(356542,113626,'74984','watch','font-style','italic',0,''),(356543,113627,'74985','watch','block_type','1',0,''),(356544,113627,'74985','watch','padding-top','10',0,''),(356545,113627,'74985','watch','padding-left','40',0,''),(356546,113627,'74985','watch','padding-right','40',0,''),(356547,113627,'74985','watch','padding-bottom','10',0,''),(356548,113628,'74986','watch','block_type','1',0,''),(356549,113628,'74986','watch','padding-top','10',0,''),(356550,113628,'74986','watch','padding-left','10',0,''),(356551,113628,'74986','watch','padding-right','10',0,''),(356552,113628,'74986','watch','padding-bottom','10',0,''),(356553,113628,'74986','watch','border-top-width','1',0,''),(356554,113628,'74986','watch','border-left-width','1',0,''),(356555,113628,'74986','watch','border-right-width','1',0,''),(356556,113628,'74986','watch','border-bottom-width','1',0,''),(356557,113628,'74986','watch','border-top-color','$content-border-1',0,''),(356558,113628,'74986','watch','border-left-color','$content-border-1',0,''),(356559,113628,'74986','watch','border-right-color','$content-border-1',0,''),(356560,113628,'74986','watch','border-bottom-color','$content-border-1',0,''),(356561,113629,'74987','watch','block_type','3',0,''),(356562,113630,'74988','watch','data','rrDelivery_name',0,''),(356563,113630,'74988','watch','font-size','9',0,''),(356564,113631,'74989','watch','block_type','2',0,''),(356565,113632,'74990','watch','text','RMA#:',0,''),(356566,113632,'74990','watch','font-size','10',0,''),(356567,113633,'74991','watch','data','rrNumber',0,''),(356568,113633,'74991','watch','font-size','9',0,''),(356569,113634,'74992','watch','block_type','5',0,''),(356570,113635,'74993','watch','font-size','9',0,''),(356571,113636,'74994','watch','block_type','1',0,''),(356572,113636,'74994','watch','padding-left','10',0,''),(356573,113636,'74994','watch','padding-right','10',0,''),(356574,113636,'74994','watch','padding-bottom','10',0,''),(356575,113637,'74995','watch','text','Use this space for additional Comments:',0,''),(356576,113637,'74995','watch','font-size','11',0,''),(356577,113637,'74995','watch','font-style','italic',0,''),(356578,113638,'74996','watch','text','&nbsp;',0,''),(356579,113638,'74996','watch','border-bottom-width','1',0,''),(356580,113638,'74996','watch','border-bottom-color','$content-border-1',0,''),(356581,113639,'74997','watch','text','&nbsp;',0,''),(356582,113639,'74997','watch','border-bottom-width','1',0,''),(356583,113639,'74997','watch','border-bottom-color','$content-border-1',0,''),(356584,113639,'74997','watch','padding-top','5',0,''),(356585,113640,'74998','watch','text','&nbsp;',0,''),(356586,113640,'74998','watch','border-bottom-width','1',0,''),(356587,113640,'74998','watch','border-bottom-color','$content-border-1',0,''),(356588,113640,'74998','watch','padding-top','5',0,''),(356589,113641,'74999','watch','text','&nbsp;',0,''),(356590,113641,'74999','watch','border-bottom-width','1',0,''),(356591,113641,'74999','watch','border-bottom-color','$content-border-1',0,''),(356592,113641,'74999','watch','padding-top','5',0,''),(356593,113642,'75000','watch','block_type','3',0,''),(356594,113642,'75000','watch','padding-top','10',0,''),(356595,113642,'75000','watch','padding-bottom','10',0,''),(356596,113642,'75000','watch','padding-right','10',0,''),(356597,113643,'75001','watch','font-size','11',0,''),(356598,113643,'75001','watch','font-weight','bold',0,''),(356599,113643,'75001','watch','text','Return Approval:',0,''),(356600,113643,'75001','watch','padding-top','5',0,''),(356601,113643,'75001','watch','padding-left','10',0,''),(356602,113644,'75002','watch','border-bottom-width','1',0,''),(356603,113644,'75002','watch','border-bottom-color','$content-border-1',0,''),(356604,113644,'75002','watch','text','&nbsp;',0,''),(356605,113645,'75003','watch','block_type','5',0,''),(356606,113646,'75004','watch','text','Date:',0,''),(356607,113646,'75004','watch','padding-top','5',0,''),(356608,113646,'75004','watch','font-size','11',0,''),(356609,113646,'75004','watch','font-weight','bold',0,''),(356610,113646,'75004','watch','padding-left','5',0,''),(356611,113647,'75005','watch','text','&nbsp;',0,''),(356612,113647,'75005','watch','border-bottom-width','1',0,''),(356613,113647,'75005','watch','border-bottom-color','$content-border-1',0,''),(356614,113648,'75006','watch','block_type','3',0,''),(356615,113648,'75006','watch','padding-right','10',0,''),(356616,113649,'75007','watch','text','Customer Signature:',0,''),(356617,113649,'75007','watch','font-weight','bold',0,''),(356618,113649,'75007','watch','font-size','11',0,''),(356619,113649,'75007','watch','padding-top','5',0,''),(356620,113649,'75007','watch','padding-left','10',0,''),(356621,113650,'75008','watch','text','&nbsp;',0,''),(356622,113650,'75008','watch','border-bottom-width','1',0,''),(356623,113650,'75008','watch','border-bottom-color','$content-border-1',0,''),(356624,113651,'75009','watch','block_type','5',0,''),(356625,113652,'75010','watch','text','Date:',0,''),(356626,113652,'75010','watch','padding-top','5',0,''),(356627,113652,'75010','watch','font-size','11',0,''),(356628,113652,'75010','watch','font-weight','bold',0,''),(356629,113652,'75010','watch','padding-left','5',0,''),(356630,113653,'75011','watch','text','&nbsp;',0,''),(356631,113653,'75011','watch','border-bottom-width','1',0,''),(356632,113653,'75011','watch','border-bottom-color','$content-border-1',0,''),(356633,113654,'75012','watch','block_type','1',0,''),(356634,113654,'75012','watch','style_class','item-holder',0,''),(356635,113654,'75012','watch','padding-top','25',0,''),(356636,113654,'75012','watch','padding-bottom','25',0,''),(356637,113654,'75012','watch','text-align','left',0,''),(356638,113654,'75012','watch','border-top-width','1',0,''),(356639,113654,'75012','watch','border-top-color','$content-border-1',0,''),(356640,113655,'75013','watch','block_type','7',0,''),(356641,113655,'75013','watch','schema','7-2',0,'5240'),(356642,113656,'75014','watch','block_type','5',0,''),(356643,113656,'75014','watch','schema','5-2',0,'5240'),(356644,113657,'75015','watch','clear','none',0,''),(356645,113657,'75015','watch','padding-right','20',0,''),(356646,113658,'75016','watch','padding-right','20',0,''),(356647,113658,'75016','watch','max-width','300',0,'5240'),(356648,113658,'75016','watch','margin_left_measure','auto',0,'5240'),(356649,113658,'75016','watch','margin_right_measure','auto',0,'5240'),(356650,113659,'75017','watch','block_type','1',0,''),(356651,113660,'75018','watch','text-align','right',0,''),(356652,113660,'75018','watch','margin-top','4',0,''),(356653,113660,'75018','watch','margin-bottom','7',0,''),(356654,113660,'75018','watch','float','left',0,''),(356655,113661,'75019','watch','padding-top','6',0,''),(356656,113661,'75019','watch','padding-left','5',0,''),(356657,113661,'75019','watch','float','left',0,''),(356658,113661,'75019','watch','clear','none',0,''),(356659,113662,'75020','watch','padding-right','20',0,''),(356660,113663,'75021','watch','description_characters','200',0,''),(356661,113663,'75021','watch','clear','none',0,''),(356662,113663,'75021','watch','padding-right','20',0,''),(356663,113664,'75022','watch','clear','none',0,''),(356664,113665,'75023','watch','margin-bottom','20',0,''),(356665,113666,'75024','watch','block_type','1',0,''),(356666,113666,'75024','watch','padding-left','40',0,''),(356667,113666,'75024','watch','style_class','right-aria',0,''),(356668,113666,'75024','watch','padding-left','0',0,'5240'),(356669,113667,'75025','watch','margin-bottom','15',0,''),(356670,113667,'75025','watch','text-align','right',0,''),(356671,113668,'75026','watch','margin-bottom','10',0,''),(356672,113668,'75026','watch','text-align','right',0,''),(356673,113669,'75027','watch','margin-bottom','10',0,''),(356674,113670,'75028','watch','text-align','right',0,''),(356675,113670,'75028','watch','margin-bottom','15',0,''),(356676,113671,'75030','watch','text-align','right',0,''),(356677,113671,'75030','watch','margin-bottom','10',0,''),(356678,113672,'75031','watch','block_type','1',0,''),(356679,113672,'75031','watch','padding-top','20',0,''),(356680,113672,'75031','watch','padding-bottom','20',0,''),(356681,113672,'75031','watch','background-color','$content-bg-2',0,''),(356682,113674,'75033','watch','block_type','4',0,''),(356683,113675,'75034','watch','padding-bottom','20',0,''),(356684,113675,'75034','watch','background-color','$content-bg-1',0,''),(356685,113676,'75035','watch','style_class','order-summary',0,''),(356686,113676,'75035','watch','padding-left','30',0,''),(356687,113676,'75035','watch','block_type','1',0,''),(356688,113677,'75036','watch','block_type','1',0,''),(356689,113677,'75036','watch','padding-left','20',0,''),(356690,113677,'75036','watch','padding-right','20',0,''),(356691,113677,'75036','watch','padding-bottom','20',0,''),(356692,113677,'75036','watch','padding-top','20',0,''),(356693,113678,'75037','watch','margin-bottom','40',0,''),(356694,113679,'75038','watch','block_type','1',0,''),(356695,113679,'75038','watch','style_class','account-samples',0,''),(356696,113680,'75039','watch','block_type','6',0,''),(356697,113680,'75039','watch','schema','6-3',0,'5240'),(356698,113681,'75040','watch','aria_name','account-menu',0,''),(356756,113701,'75041','watch','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(356757,113702,'75042','watch','show_pagenation','1',0,''),(356758,113702,'75042','watch','link','Sample Info',0,''),(356759,113702,'75042','watch','margin-bottom','20',0,''),(356760,113703,'75043','watch','block_type','1',0,''),(356761,113703,'75043','watch','style_class','account-sample-info',0,''),(356762,113704,'75044','watch','block_type','6',0,''),(356763,113705,'75045','watch','aria_name','account-menu',0,''),(356821,113725,'75046','watch','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(356822,113726,'75047','watch','block_type','2',0,''),(356823,113726,'75047','watch','padding-top','20',0,''),(356824,113726,'75047','watch','margin-bottom','20',0,''),(356825,113727,'75048','watch','like_button','1',0,''),(356826,113727,'75048','watch','text','IMAGE_BUTTON_BACK',0,''),(356827,113727,'75048','watch','link','Samples',0,''),(356828,113729,'75050','watch','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(356829,113732,'75053','watch','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(356830,113733,'75054','watch','block_type','3',0,''),(356831,113734,'75055','watch','block_type','1',0,''),(356832,113734,'75055','watch','padding-right','20',0,''),(356833,113734,'75055','watch','padding-bottom','20',0,''),(356834,113735,'75056','watch','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(356835,113736,'75057','watch','orders_data','telephone',0,''),(356836,113737,'75058','watch','block_type','1',0,''),(356837,113737,'75058','watch','padding-right','20',0,''),(356838,113737,'75058','watch','padding-bottom','20',0,''),(356839,113738,'75059','watch','orders_data','name',0,''),(356840,113739,'75060','watch','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(356841,113740,'75061','watch','block_type','1',0,''),(356842,113740,'75061','watch','padding-right','20',0,''),(356843,113741,'75062','watch','orders_data','shipping_method',0,''),(356844,113742,'75063','watch','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(356845,113743,'75064','watch','block_type','1',0,''),(356846,113743,'75064','watch','padding-right','20',0,''),(356847,113743,'75064','watch','padding-bottom','20',0,''),(356848,113744,'75065','watch','orders_data','delivery_address',0,''),(356849,113745,'75066','watch','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(356850,113746,'75067','watch','block_type','1',0,''),(356851,113747,'75068','watch','orders_data','payment_method',0,''),(356852,113748,'75069','watch','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(356853,113749,'75070','watch','block_type','1',0,''),(356854,113749,'75070','watch','padding-bottom','20',0,''),(356855,113750,'75071','watch','orders_data','billing_address',0,''),(356856,113751,'75072','watch','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(356857,113752,'75073','watch','block_type','1',0,''),(356858,113753,'75074','watch','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(356859,113754,'75075','watch','block_type','6',0,''),(356860,113755,'75076','watch','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(356861,113756,'75077','watch','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(356862,113757,'75078','watch','text','<div class=\"heading-4\">Categories</div>',0,''),(356863,113760,'75081','watch','class','menu-simple',0,''),(356864,113762,'75083','watch','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(356865,113763,'75084','watch','block_type','1',0,''),(356866,113764,'75085','watch','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(356867,113764,'75085','watch','style_class','middle-form',0,''),(356868,113765,'75086','watch','style_class','middle-form',0,''),(356869,113766,'75087','watch','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(356870,113767,'75088','watch','style_class','middle-form',0,''),(356871,113767,'75088','watch','margin-bottom','30',0,''),(356872,113768,'75089','watch','block_type','1',0,''),(356873,113769,'75090','watch','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(356874,113769,'75090','watch','padding-top','100',0,''),(356875,113769,'75090','watch','margin-bottom','100',0,''),(356876,113769,'75090','watch','text-align','center',0,''),(356877,113769,'75090','watch','font-size','20',0,''),(356878,113770,'94795','watch','block_type','1',0,''),(356879,113771,'94796','watch','block_type','6',0,''),(356880,113771,'94796','watch','schema','6-3',0,'5240'),(356881,113772,'94797','watch','aria_name','account-menu',0,''),(356939,113792,'94798','watch','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(356940,113793,'94799','watch','text','##SUBSCRIPTION_TEXT##',0,''),(356941,113795,'1694099590.22143','watch','block_type','1',0,''),(356942,113795,'1694099590.22143','watch','background-color','$content-bg-2',0,''),(356943,113795,'1694099590.22143','watch','padding-bottom','30',0,''),(356944,113795,'1694099590.22143','watch','style_class','success-page',0,''),(356945,113795,'1694099590.22143','watch','color','$content-color-2',0,''),(356946,113796,'1694099590.340695','watch','block_type','12',0,''),(356947,113796,'1694099590.340695','watch','schema','4-2',0,'5240'),(356948,113797,'1694099590.343733','watch','block_type','1',0,''),(356949,113797,'1694099590.343733','watch','padding-right','40',0,''),(356950,113797,'1694099590.343733','watch','padding-right','0',0,'5240'),(356951,113798,'1694099590.345212','watch','block_type','2',0,''),(356952,113798,'1694099590.345212','watch','margin-bottom','20',0,''),(356953,113798,'1694099590.345212','watch','schema','2-2',0,'5232'),(356954,113798,'1694099590.345212','watch','background-color','$content-bg-1',0,''),(356955,113798,'1694099590.345212','watch','color','$content-color-1',0,''),(356956,113799,'1694099590.34749','watch','block_type','1',0,''),(356957,113799,'1694099590.34749','watch','border-right-width','20',0,''),(356958,113799,'1694099590.34749','watch','border-right-color','$content-bg-2',0,''),(356959,113799,'1694099590.34749','watch','margin-right','-10',0,''),(356960,113799,'1694099590.34749','watch','padding-right','30',0,''),(356961,113799,'1694099590.34749','watch','padding-top','20',0,''),(356962,113799,'1694099590.34749','watch','padding-left','30',0,''),(356963,113799,'1694099590.34749','watch','padding-bottom','20',0,''),(356964,113799,'1694099590.34749','watch','border-right-width','0',0,'5240'),(356965,113799,'1694099590.34749','watch','margin-right','0',0,'5240'),(356966,113799,'1694099590.34749','watch','margin-bottom','20',0,'5240'),(356967,113799,'1694099590.34749','watch','padding-left','20',0,'5240'),(356968,113799,'1694099590.34749','watch','padding-right','20',0,'5240'),(356969,113801,'1694099590.351567','watch','margin-bottom','20',0,''),(356970,113802,'1694099590.35337','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(356971,113802,'1694099590.35337','watch','padding-top','20',0,''),(356972,113803,'1694099590.360420','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(356973,113803,'1694099590.360420','watch','clear','none',0,''),(356974,113804,'1694099590.362714','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(356975,113806,'1694099590.365625','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(356976,113806,'1694099590.365625','watch','clear','none',0,''),(356977,113807,'1694099590.367789','watch','block_type','1',0,''),(356978,113807,'1694099590.367789','watch','padding-left','30',0,''),(356979,113807,'1694099590.367789','watch','border-left-width','20',0,''),(356980,113807,'1694099590.367789','watch','border-left-color','$content-bg-2',0,''),(356981,113807,'1694099590.367789','watch','margin-left','-10',0,''),(356982,113807,'1694099590.367789','watch','padding-right','30',0,''),(356983,113807,'1694099590.367789','watch','padding-top','20',0,''),(356984,113807,'1694099590.367789','watch','padding-bottom','20',0,''),(356985,113807,'1694099590.367789','watch','border-left-width','0',0,'5240'),(356986,113809,'1694099590.370690','watch','margin-bottom','20',0,''),(356987,113810,'1694099590.371953','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(356988,113810,'1694099590.371953','watch','clear','none',0,''),(356989,113811,'1694099590.373633','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(356990,113812,'1694099590.37590','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(356991,113812,'1694099590.37590','watch','clear','none',0,''),(356992,113813,'1694099590.376747','watch','text','<div class=\"page-success\">\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>',0,''),(356993,113813,'1694099590.376747','watch','background-color','$content-bg-1',0,''),(356994,113813,'1694099590.376747','watch','margin-bottom','30',0,''),(356995,113813,'1694099590.376747','watch','padding-top','30',0,''),(356996,113813,'1694099590.376747','watch','padding-bottom','30',0,''),(356997,113813,'1694099590.376747','watch','padding-left','30',0,''),(356998,113813,'1694099590.376747','watch','padding-right','30',0,''),(356999,113813,'1694099590.376747','watch','color','$content-color-1',0,''),(357000,113814,'1694099590.38020','watch','block_type','1',0,''),(357001,113814,'1694099590.38020','watch','style_class','order-summary2 hiding-box',0,''),(357002,113815,'1694099590.381373','watch','text-align','center',0,''),(357003,113815,'1694099590.381373','watch','margin-bottom','20',0,''),(357004,113816,'1694099590.382864','watch','text-align','center',0,''),(357005,113819,'1694099590.386683','watch','block_type','12',0,''),(357006,113820,'1694099590.387673','watch','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n</div>\n',0,''),(357007,113820,'1694099590.387673','watch','margin-bottom','20',0,''),(357008,113821,'1694099590.389337','watch','text-align','center',0,''),(357009,113821,'1694099590.389337','watch','padding-top','40',0,''),(357010,113822,'75097','watch','block_type','1',0,''),(357011,113823,'75098','watch','block_type','1',0,''),(357012,113823,'75098','watch','font-weight','normal',0,''),(357013,113824,'75099','watch','block_type','1',0,''),(357014,113824,'75099','watch','text-align','center',0,''),(357015,113824,'75099','watch','padding-top','30',0,''),(357016,113824,'75099','watch','margin-bottom','200',0,''),(357017,113825,'75100','watch','display','inline-block',0,''),(357018,113825,'75100','watch','clear','none',0,''),(357019,113825,'75100','watch','margin-left','20',0,''),(357020,113826,'75101','watch','display','inline-block',0,''),(357021,113827,'75102','watch','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(357026,113832,'75107','watch','width','680',0,''),(357027,113832,'75107','watch','font-weight','normal',0,''),(357028,113832,'75107','watch','font-size','12',0,''),(357029,113832,'75107','watch','padding-top','20',0,''),(357030,113832,'75107','watch','padding-bottom','20',0,''),(357031,113832,'75107','watch','color','$content-color-1',0,''),(357032,113833,'75108','watch','block_type','5',0,''),(357033,113833,'75108','watch','font-weight','normal',0,''),(357034,113833,'75108','watch','border-bottom-width','1',0,''),(357035,113833,'75108','watch','border-bottom-color','$content-border-1',0,''),(357036,113833,'75108','watch','border-top-width','1',0,''),(357037,113833,'75108','watch','border-top-color','$content-border-1',0,''),(357038,113833,'75108','watch','border-left-color','$content-border-1',0,''),(357039,113833,'75108','watch','border-left-width','1',0,''),(357040,113834,'75109','watch','block_type','1',0,''),(357041,113834,'75109','watch','font-weight','normal',0,''),(357042,113834,'75109','watch','padding-top','10',0,''),(357043,113834,'75109','watch','padding-left','10',0,''),(357044,113834,'75109','watch','padding-right','10',0,''),(357045,113835,'75110','watch','font-weight','400',0,''),(357046,113835,'75110','watch','line-height','120',0,''),(357047,113835,'75110','watch','line_height_measure','%',0,''),(357048,113835,'75110','watch','font-size','12',0,''),(357049,113836,'75111','watch','text','<p>SHIPPING ADDRESS:</p>',1,''),(357050,113836,'75111','watch','font-size','14',0,''),(357051,113836,'75111','watch','font-weight','bold',0,''),(357052,113836,'75111','watch','padding-bottom','10',0,''),(357053,113836,'75111','watch','text','<p>SHIPPING ADDRESS:</p>',2,''),(357054,113836,'75111','watch','text','<p>SHIPPING ADDRESS:</p>',3,''),(357055,113836,'75111','watch','text','<p>SHIPPING ADDRESS:</p>',4,''),(357056,113837,'75112','watch','block_type','1',0,''),(357057,113837,'75112','watch','background-color','$content-bg-2',0,''),(357058,113837,'75112','watch','padding-top','20',0,''),(357059,113837,'75112','watch','padding-left','10',0,''),(357060,113837,'75112','watch','padding-right','10',0,''),(357061,113837,'75112','watch','padding-bottom','20',0,''),(357062,113837,'75112','watch','font-size','14',0,''),(357063,113838,'75113','watch','font-weight','normal',0,''),(357064,113838,'75113','watch','text-align','right',0,''),(357065,113838,'75113','watch','font-size','14',0,''),(357066,113838,'75113','watch','box_align','3',0,''),(357067,113839,'75114','watch','block_type','3',0,''),(357068,113839,'75114','watch','font-weight','normal',0,''),(357069,113839,'75114','watch','padding-top','20',0,''),(357070,113840,'75115','watch','text','<p>If undelivered please return to:</p>',1,''),(357071,113840,'75115','watch','font-size','12',0,''),(357072,113840,'75115','watch','font-weight','bold',0,''),(357073,113840,'75115','watch','text','<p>If undelivered please return to:</p>',2,''),(357074,113840,'75115','watch','text','<p>If undelivered please return to:</p>',3,''),(357075,113840,'75115','watch','text','<p>If undelivered please return to:</p>',4,''),(357076,113841,'75116','watch','font-size','12',0,''),(357077,113842,'75117','watch','font-weight','400',0,''),(357078,113842,'75117','watch','text-align','center',0,''),(357079,113842,'75117','watch','padding-top','0',0,''),(357081,113842,'75117','watch','padding-left','20',0,''),(357082,113842,'75117','watch','padding-right','20',0,''),(357086,113843,'75118','watch','text','<p>Thank you for your order</p>',1,''),(357087,113843,'75118','watch','color','$color-8',0,''),(357088,113843,'75118','watch','font-size','13',0,''),(357089,113843,'75118','watch','font-weight','bold',0,''),(357090,113843,'75118','watch','padding-top','5',0,''),(357091,113843,'75118','watch','text-align','center',0,''),(357092,113843,'75118','watch','text','<p>Thank you for your order</p>',2,''),(357093,113843,'75118','watch','text','<p>Thank you for your order</p>',3,''),(357094,113843,'75118','watch','text','<p>Thank you for your order</p>',4,''),(357095,113844,'75119','watch','text','<p>If something has gone wrong please contact us at:</p>',1,''),(357096,113844,'75119','watch','font-size','12',0,''),(357097,113844,'75119','watch','font-weight','bold',0,''),(357098,113844,'75119','watch','text-align','right',0,''),(357099,113844,'75119','watch','text','<p>If something has gone wrong please contact us at:</p>',2,''),(357100,113844,'75119','watch','text','<p>If something has gone wrong please contact us at:</p>',3,''),(357101,113844,'75119','watch','text','<p>If something has gone wrong please contact us at:</p>',4,''),(357102,113845,'75120','watch','block_type','6',0,''),(357103,113845,'75120','watch','font-weight','normal',0,''),(357104,113845,'75120','watch','font-size','16',0,''),(357105,113846,'75121','watch','text','<p>Email:</p>',1,''),(357106,113846,'75121','watch','font-weight','normal',0,''),(357107,113846,'75121','watch','text-align','right',0,''),(357108,113846,'75121','watch','font-size','12',0,''),(357109,113846,'75121','watch','text','<p>Email:</p>',2,''),(357110,113846,'75121','watch','text','<p>Email:</p>',3,''),(357111,113846,'75121','watch','text','<p>Email:</p>',4,''),(357112,113847,'75122','watch','font-weight','normal',0,''),(357113,113847,'75122','watch','text-align','right',0,''),(357114,113847,'75122','watch','font-size','12',0,''),(357115,113848,'75123','watch','block_type','6',0,''),(357116,113848,'75123','watch','font-weight','normal',0,''),(357117,113848,'75123','watch','font-size','16',0,''),(357118,113849,'75124','watch','text','<p>Phone:</p>',1,''),(357119,113849,'75124','watch','font-weight','normal',0,''),(357120,113849,'75124','watch','text-align','right',0,''),(357121,113849,'75124','watch','font-size','12',0,''),(357122,113849,'75124','watch','text','<p>Phone:</p>',2,''),(357123,113849,'75124','watch','text','<p>Phone:</p>',3,''),(357124,113849,'75124','watch','text','<p>Phone:</p>',4,''),(357125,113850,'75125','watch','font-weight','normal',0,''),(357126,113850,'75125','watch','text-align','right',0,''),(357127,113850,'75125','watch','font-size','12',0,''),(357128,113851,'75126','watch','font-weight','400',0,''),(357129,113851,'75126','watch','padding-top','20',0,''),(357130,113851,'75126','watch','padding-bottom','0',0,''),(357131,113851,'75126','watch','font-size','12',0,''),(357132,113852,'75127','watch','block_type','2',0,''),(357133,113852,'75127','watch','font-weight','normal',0,''),(357134,113852,'75127','watch','padding-bottom','20',0,''),(357135,113853,'75128','watch','block_type','11',0,''),(357136,113853,'75128','watch','font-weight','normal',0,''),(357137,113854,'75129','watch','text','<p>Email:</p>',1,''),(357138,113854,'75129','watch','font-weight','normal',0,''),(357139,113854,'75129','watch','text-align','right',0,''),(357140,113854,'75129','watch','text','<p>Email:</p>',2,''),(357141,113854,'75129','watch','text','<p>Email:</p>',3,''),(357142,113854,'75129','watch','text','<p>Email:</p>',4,''),(357143,113855,'75130','watch','font-weight','normal',0,''),(357144,113855,'75130','watch','text-align','right',0,''),(357145,113856,'75131','watch','block_type','11',0,''),(357146,113856,'75131','watch','font-weight','normal',0,''),(357147,113857,'75132','watch','text','<p>Web:</p>',1,''),(357148,113857,'75132','watch','font-weight','normal',0,''),(357149,113857,'75132','watch','text-align','right',0,''),(357150,113857,'75132','watch','text','<p>Web:</p>',2,''),(357151,113857,'75132','watch','text','<p>Web:</p>',3,''),(357152,113857,'75132','watch','text','<p>Web:</p>',4,''),(357153,113858,'75133','watch','font-weight','normal',0,''),(357154,113858,'75133','watch','text-align','right',0,''),(357155,113859,'75134','watch','block_type','1',0,''),(357156,113860,'75135','watch','font-weight','normal',0,''),(357157,113860,'75135','watch','text-align','right',0,''),(357158,113860,'75135','watch','padding-bottom','10',0,''),(357159,113860,'75135','watch','address_spacer',',',0,''),(357160,113860,'75135','watch','font-size','12',0,''),(357161,113861,'75136','watch','block_type','11',0,''),(357162,113861,'75136','watch','font-weight','normal',0,''),(357163,113862,'75137','watch','text','<p>Phone:</p>',1,''),(357164,113862,'75137','watch','font-weight','normal',0,''),(357165,113862,'75137','watch','text-align','right',0,''),(357166,113862,'75137','watch','text','<p>Phone:</p>',2,''),(357167,113862,'75137','watch','text','<p>Phone:</p>',3,''),(357168,113862,'75137','watch','text','<p>Phone:</p>',4,''),(357169,113863,'75138','watch','font-weight','normal',0,''),(357170,113863,'75138','watch','text-align','right',0,''),(357171,113864,'75139','watch','block_type','4',0,''),(357172,113864,'75139','watch','font-weight','normal',0,''),(357173,113864,'75139','watch','border-top-width','1',0,''),(357174,113864,'75139','watch','border-top-color','$content-border-1',0,''),(357175,113864,'75139','watch','border-left-width','1',0,''),(357176,113864,'75139','watch','border-left-color','$content-border-1',0,''),(357177,113864,'75139','watch','border-right-width','1',0,''),(357178,113864,'75139','watch','border-right-color','$content-border-1',0,''),(357179,113864,'75139','watch','border-bottom-width','1',0,''),(357180,113864,'75139','watch','border-bottom-color','$content-border-1',0,''),(357181,113865,'75140','watch','block_type','2',0,''),(357182,113865,'75140','watch','font-weight','normal',0,''),(357183,113865,'75140','watch','border-top-width','1',0,''),(357184,113865,'75140','watch','border-top-color','$content-border-1',0,''),(357185,113865,'75140','watch','border-right-width','1',0,''),(357186,113865,'75140','watch','border-right-color','$content-border-1',0,''),(357187,113866,'75141','watch','block_type','1',0,''),(357188,113866,'75141','watch','font-weight','normal',0,''),(357189,113866,'75141','watch','padding-top','10',0,''),(357190,113866,'75141','watch','padding-left','10',0,''),(357191,113866,'75141','watch','padding-right','10',0,''),(357192,113866,'75141','watch','padding-bottom','10',0,''),(357193,113866,'75141','watch','border-right-width','1',0,''),(357194,113866,'75141','watch','border-right-color','$content-border-1',0,''),(357195,113867,'75142','watch','text','<p>Shipping via</p>',1,''),(357196,113867,'75142','watch','font-weight','bold',0,''),(357197,113867,'75142','watch','font-size','14',0,''),(357198,113867,'75142','watch','text','<p>Shipping via</p>',2,''),(357199,113867,'75142','watch','text','<p>Shipping via</p>',3,''),(357200,113867,'75142','watch','text','<p>Shipping via</p>',4,''),(357201,113869,'75144','watch','block_type','1',0,''),(357202,113869,'75144','watch','font-weight','normal',0,''),(357203,113869,'75144','watch','padding-top','10',0,''),(357204,113869,'75144','watch','padding-left','10',0,''),(357205,113869,'75144','watch','padding-right','10',0,''),(357206,113869,'75144','watch','padding-bottom','10',0,''),(357207,113870,'75145','watch','text','<p>Shipping service</p>',1,''),(357208,113870,'75145','watch','font-weight','bold',0,''),(357209,113870,'75145','watch','font-size','14',0,''),(357210,113870,'75145','watch','text','<p>Shipping service</p>',2,''),(357211,113870,'75145','watch','text','<p>Shipping service</p>',3,''),(357212,113870,'75145','watch','text','<p>Shipping service</p>',4,''),(357213,113872,'75147','watch','block_type','2',0,''),(357214,113872,'75147','watch','font-weight','normal',0,''),(357215,113872,'75147','watch','border-right-width','1',0,''),(357216,113872,'75147','watch','border-right-color','$content-border-1',0,''),(357217,113873,'75148','watch','block_type','1',0,''),(357218,113873,'75148','watch','font-weight','400',0,''),(357219,113873,'75148','watch','background-color','$content-bg-2',0,''),(357220,113873,'75148','watch','padding-top','10',0,''),(357221,113873,'75148','watch','padding-left','10',0,''),(357222,113873,'75148','watch','padding-right','10',0,''),(357223,113873,'75148','watch','padding-bottom','30',0,''),(357224,113874,'75149','watch','font-size','12',0,''),(357225,113875,'75150','watch','text','<p>INVOICE ADDRESS:</p>',1,''),(357226,113875,'75150','watch','font-size','14',0,''),(357227,113875,'75150','watch','font-weight','bold',0,''),(357228,113875,'75150','watch','text','<p>INVOICE ADDRESS:</p>',2,''),(357229,113875,'75150','watch','text','<p>INVOICE ADDRESS:</p>',3,''),(357230,113875,'75150','watch','text','<p>INVOICE ADDRESS:</p>',4,''),(357231,113876,'75151','watch','block_type','1',0,''),(357232,113876,'75151','watch','font-weight','normal',0,''),(357233,113876,'75151','watch','padding-top','10',0,''),(357234,113876,'75151','watch','padding-left','10',0,''),(357235,113876,'75151','watch','padding-right','10',0,''),(357236,113876,'75151','watch','padding-bottom','10',0,''),(357237,113877,'75152','watch','font-weight','normal',0,''),(357238,113878,'75153','watch','text','<p>PHONE NUMBER:</p>',1,''),(357239,113878,'75153','watch','font-size','14',0,''),(357240,113878,'75153','watch','font-weight','bold',0,''),(357241,113878,'75153','watch','padding-top','10',0,''),(357242,113878,'75153','watch','text','<p>PHONE NUMBER:</p>',2,''),(357243,113878,'75153','watch','text','<p>PHONE NUMBER:</p>',3,''),(357244,113878,'75153','watch','text','<p>PHONE NUMBER:</p>',4,''),(357245,113880,'75155','watch','font-weight','normal',0,''),(357246,113881,'75156','watch','text','<p>E-MAIL ADDRESS:</p>',1,''),(357247,113881,'75156','watch','font-weight','bold',0,''),(357248,113881,'75156','watch','font-size','14',0,''),(357249,113881,'75156','watch','padding-top','10',0,''),(357250,113881,'75156','watch','text','<p>E-MAIL ADDRESS:</p>',2,''),(357251,113881,'75156','watch','text','<p>E-MAIL ADDRESS:</p>',3,''),(357252,113881,'75156','watch','text','<p>E-MAIL ADDRESS:</p>',4,''),(357253,113882,'75157','watch','text','<p>CUSTOMER:</p>',1,''),(357254,113882,'75157','watch','font-size','13',0,''),(357255,113882,'75157','watch','font-weight','bold',0,''),(357256,113882,'75157','watch','text','<p>CUSTOMER:</p>',2,''),(357257,113882,'75157','watch','text','<p>CUSTOMER:</p>',3,''),(357258,113882,'75157','watch','text','<p>CUSTOMER:</p>',4,''),(357259,113883,'75158','watch','font-weight','normal',0,''),(357260,113883,'75158','watch','text-align','center',0,''),(357261,113883,'75158','watch','padding-bottom','10',0,''),(357262,113884,'75159','watch','text','<p>Payment date:</p>',1,''),(357263,113884,'75159','watch','font-weight','bold',0,''),(357264,113884,'75159','watch','text-align','center',0,''),(357265,113884,'75159','watch','font-size','12',0,''),(357266,113884,'75159','watch','text','<p>Payment date:</p>',2,''),(357267,113884,'75159','watch','text','<p>Payment date:</p>',3,''),(357268,113884,'75159','watch','text','<p>Payment date:</p>',4,''),(357269,113885,'75160','watch','text','<p>Payment Method:</p>',1,''),(357270,113885,'75160','watch','font-weight','bold',0,''),(357271,113885,'75160','watch','text-align','center',0,''),(357272,113885,'75160','watch','text','<p>Payment Method:</p>',2,''),(357273,113885,'75160','watch','text','<p>Payment Method:</p>',3,''),(357274,113885,'75160','watch','text','<p>Payment Method:</p>',4,''),(357275,113886,'75161','watch','font-size','14',0,''),(357276,113886,'75161','watch','font-weight','bold',0,''),(357277,113886,'75161','watch','text-align','center',0,''),(357278,113886,'75161','watch','padding-bottom','10',0,''),(357279,113886,'75161','watch','padding-top','10',0,''),(357280,113887,'75162','watch','font-weight','normal',0,''),(357281,113887,'75162','watch','text-align','center',0,''),(357282,113887,'75162','watch','padding-bottom','20',0,''),(357283,113888,'75163','watch','font-weight','normal',0,''),(357284,113888,'75163','watch','text-align','center',0,''),(357285,113889,'75194','watch','block_type','1',0,''),(357286,113890,'75195','watch','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(357287,113892,'75418','watch','block_type','1',0,''),(357288,113893,'75419','watch','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(357289,113893,'75419','watch','padding-top','100',0,''),(357290,113893,'75419','watch','margin-bottom','100',0,''),(357291,113893,'75419','watch','text-align','center',0,''),(357292,113893,'75419','watch','font-size','20',0,''),(357293,113894,'75420','watch','block_type','1',0,''),(357294,113894,'75420','watch','background-color','$content-bg-2',0,''),(357295,113894,'75420','watch','padding-bottom','30',0,''),(357296,113895,'75421','watch','block_type','4',0,''),(357297,113895,'75421','watch','schema','4-2',0,'5240'),(357298,113896,'75422','watch','block_type','1',0,''),(357299,113896,'75422','watch','padding-right','40',0,''),(357300,113896,'75422','watch','padding-right','0',0,'5240'),(357301,113897,'75423','watch','block_type','2',0,''),(357302,113897,'75423','watch','margin-bottom','20',0,''),(357303,113897,'75423','watch','schema','2-2',0,'5232'),(357304,113897,'75423','watch','background-color','$content-bg-1',0,''),(357305,113898,'75424','watch','block_type','1',0,''),(357306,113898,'75424','watch','border-right-width','20',0,''),(357307,113898,'75424','watch','border-right-color','$content-border-1',0,''),(357308,113898,'75424','watch','margin-right','-10',0,''),(357309,113898,'75424','watch','padding-right','30',0,''),(357310,113898,'75424','watch','padding-top','20',0,''),(357311,113898,'75424','watch','padding-left','30',0,''),(357312,113898,'75424','watch','padding-bottom','20',0,''),(357313,113898,'75424','watch','border-right-width','0',0,'5240'),(357314,113898,'75424','watch','margin-right','0',0,'5240'),(357315,113898,'75424','watch','margin-bottom','20',0,'5240'),(357316,113898,'75424','watch','padding-left','20',0,'5240'),(357317,113898,'75424','watch','padding-right','20',0,'5240'),(357318,113900,'75426','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(357319,113900,'75426','watch','clear','none',0,''),(357320,113901,'75427','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(357321,113901,'75427','watch','clear','none',0,''),(357322,113902,'75428','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(357323,113904,'75430','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(357324,113904,'75430','watch','padding-top','20',0,''),(357325,113907,'75433','watch','margin-bottom','20',0,''),(357326,113908,'75434','watch','block_type','1',0,''),(357327,113908,'75434','watch','padding-left','30',0,''),(357328,113908,'75434','watch','border-left-width','20',0,''),(357329,113908,'75434','watch','border-left-color','$content-border-1',0,''),(357330,113908,'75434','watch','margin-left','-10',0,''),(357331,113908,'75434','watch','padding-right','30',0,''),(357332,113908,'75434','watch','padding-top','20',0,''),(357333,113908,'75434','watch','padding-bottom','20',0,''),(357334,113908,'75434','watch','border-left-width','0',0,'5240'),(357335,113909,'75435','watch','margin-bottom','20',0,''),(357336,113911,'75437','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(357337,113912,'75438','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(357338,113912,'75438','watch','clear','none',0,''),(357339,113913,'75439','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(357340,113913,'75439','watch','clear','none',0,''),(357341,113914,'75440','watch','block_type','1',0,''),(357342,113914,'75440','watch','padding-right','30',0,''),(357343,113914,'75440','watch','background-color','$content-bg-1',0,''),(357344,113914,'75440','watch','padding-top','20',0,''),(357345,113914,'75440','watch','padding-left','30',0,''),(357346,113914,'75440','watch','padding-bottom','20',0,''),(357347,113914,'75440','watch','padding-left','20',0,'5240'),(357348,113914,'75440','watch','padding-right','20',0,'5240'),(357349,113916,'75442','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(357350,113917,'75443','watch','block_type','1',0,''),(357351,113917,'75443','watch','padding-top','20',0,''),(357352,113917,'75443','watch','padding-left','20',0,''),(357353,113917,'75443','watch','padding-right','20',0,''),(357354,113917,'75443','watch','padding-bottom','20',0,''),(357355,113917,'75443','watch','background-color','$content-bg-1',0,''),(357356,113917,'75443','watch','style_class','order-summary',0,''),(357357,113918,'75444','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(357358,113922,'75448','watch','block_type','1',0,''),(357359,113922,'75448','watch','background-color','$content-bg-2',0,''),(357360,113922,'75448','watch','padding-bottom','30',0,''),(357361,113923,'75449','watch','block_type','4',0,''),(357362,113923,'75449','watch','schema','4-2',0,'5240'),(357363,113924,'75450','watch','block_type','1',0,''),(357364,113924,'75450','watch','padding-right','40',0,''),(357365,113924,'75450','watch','padding-right','0',0,'5240'),(357366,113925,'75451','watch','block_type','2',0,''),(357367,113925,'75451','watch','margin-bottom','20',0,''),(357368,113925,'75451','watch','schema','2-2',0,'5232'),(357369,113925,'75451','watch','background-color','$content-bg-1',0,''),(357370,113926,'75452','watch','block_type','1',0,''),(357371,113926,'75452','watch','border-right-width','20',0,''),(357372,113926,'75452','watch','border-right-color','$content-border-1',0,''),(357373,113926,'75452','watch','margin-right','-10',0,''),(357374,113926,'75452','watch','padding-right','30',0,''),(357375,113926,'75452','watch','padding-top','20',0,''),(357376,113926,'75452','watch','padding-left','30',0,''),(357377,113926,'75452','watch','padding-bottom','20',0,''),(357378,113926,'75452','watch','border-right-width','0',0,'5240'),(357379,113926,'75452','watch','margin-right','0',0,'5240'),(357380,113926,'75452','watch','margin-bottom','20',0,'5240'),(357381,113926,'75452','watch','padding-left','20',0,'5240'),(357382,113926,'75452','watch','padding-right','20',0,'5240'),(357383,113927,'75453','watch','margin-bottom','20',0,''),(357384,113930,'75456','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(357385,113930,'75456','watch','padding-top','20',0,''),(357386,113932,'75458','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(357387,113932,'75458','watch','clear','none',0,''),(357388,113934,'75460','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(357389,113935,'75461','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(357390,113935,'75461','watch','clear','none',0,''),(357391,113936,'75462','watch','block_type','1',0,''),(357392,113936,'75462','watch','padding-left','30',0,''),(357393,113936,'75462','watch','border-left-width','20',0,''),(357394,113936,'75462','watch','border-left-color','$content-border-1',0,''),(357395,113936,'75462','watch','margin-left','-10',0,''),(357396,113936,'75462','watch','padding-right','30',0,''),(357397,113936,'75462','watch','padding-top','20',0,''),(357398,113936,'75462','watch','padding-bottom','20',0,''),(357399,113936,'75462','watch','border-left-width','0',0,'5240'),(357400,113937,'75463','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(357401,113938,'75464','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(357402,113938,'75464','watch','clear','none',0,''),(357403,113939,'75465','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(357404,113939,'75465','watch','clear','none',0,''),(357405,113940,'75466','watch','margin-bottom','20',0,''),(357406,113942,'75468','watch','block_type','1',0,''),(357407,113942,'75468','watch','padding-right','30',0,''),(357408,113942,'75468','watch','background-color','$content-bg-1',0,''),(357409,113942,'75468','watch','padding-top','20',0,''),(357410,113942,'75468','watch','padding-left','30',0,''),(357411,113942,'75468','watch','padding-bottom','20',0,''),(357412,113942,'75468','watch','padding-left','20',0,'5240'),(357413,113942,'75468','watch','padding-right','20',0,'5240'),(357414,113943,'75469','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(357415,113945,'75471','watch','block_type','1',0,''),(357416,113945,'75471','watch','padding-top','20',0,''),(357417,113945,'75471','watch','padding-left','20',0,''),(357418,113945,'75471','watch','padding-right','20',0,''),(357419,113945,'75471','watch','padding-bottom','20',0,''),(357420,113945,'75471','watch','background-color','$content-bg-1',0,''),(357421,113945,'75471','watch','style_class','order-summary',0,''),(357422,113948,'75474','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(357423,113950,'75540','watch','block_type','1',0,''),(357424,113951,'75541','watch','block_type','6',0,''),(357425,113951,'75541','watch','schema','6-3',0,'5240'),(357426,113952,'75542','watch','aria_name','account-menu',0,''),(357427,113953,'73374','watch','block_type','1',0,''),(357428,113953,'73374','watch','padding-top','70',0,''),(357429,113953,'73374','watch','padding-right','30',0,''),(357430,113953,'73374','watch','padding-bottom','30',0,''),(357431,113953,'73374','watch','padding-top','0',0,'5240'),(357432,113953,'73374','watch','padding-left','0',0,'5240'),(357433,113953,'73374','watch','padding-right','0',0,'5240'),(357434,113953,'73374','watch','padding-bottom','0',0,'5240'),(357484,113972,'75543','watch','margin-bottom','20',0,''),(357485,113973,'75544','watch','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(357486,113974,'75545','watch','block_type','1',0,''),(357487,113974,'75545','watch','padding-top','20',0,''),(357488,113974,'75545','watch','padding-bottom','20',0,''),(357489,113976,'75547','watch','padding-top','20',0,''),(357490,113976,'75547','watch','padding-bottom','20',0,''),(357491,113977,'116005','printshop','text','##TEXT_PAGE_NOT_FOUND##',0,''),(357492,113977,'116005','printshop','text-align','center',0,''),(357493,113977,'116005','printshop','padding-top','100',0,''),(357494,113977,'116005','printshop','padding-bottom','100',0,''),(357495,113978,'116006','printshop','block_type','1',0,''),(357614,113994,'116022','printshop','block_type','1',0,''),(357733,114010,'116038','printshop','block_type','1',0,''),(357852,114026,'116054','printshop','block_type','1',0,''),(357971,114042,'116070','printshop','block_type','1',0,''),(358090,114058,'116086','printshop','block_type','1',0,''),(358209,114074,'116102','printshop','block_type','1',0,''),(358210,114074,'116102','printshop','style_class','account-index',0,''),(358445,114132,'116145','printshop','block_type','1',0,''),(358446,114132,'116145','printshop','style_class','account-edit-wrap',0,''),(358513,114156,'116150','printshop','block_type','1',0,''),(358514,114156,'116150','printshop','style_class','account-address-book',0,''),(358590,114181,'116156','printshop','block_type','1',0,''),(358591,114181,'116156','printshop','style_class','account-address-book-process',0,''),(358658,114205,'117906.000001','printshop','block_type','1',0,''),(358659,114205,'117906.000001','printshop','style_class','item-holder',0,''),(358660,114205,'117906.000001','printshop','padding-top','25',0,''),(358661,114205,'117906.000001','printshop','padding-bottom','25',0,''),(358662,114205,'117906.000001','printshop','text-align','left',0,''),(358663,114205,'117906.000001','printshop','border-top-width','1',0,''),(358664,114205,'117906.000001','printshop','border-top-color','$content-border-3',0,''),(358665,114206,'117907.000001','printshop','block_type','7',0,''),(358666,114206,'117907.000001','printshop','schema','7-2',0,'5342'),(358667,114207,'117908.000001','printshop','block_type','5',0,''),(358668,114207,'117908.000001','printshop','schema','5-2',0,'5342'),(358669,114208,'117909.000001','printshop','clear','none',0,''),(358670,114208,'117909.000001','printshop','padding-right','20',0,''),(358671,114209,'117910.000001','printshop','padding-right','20',0,''),(358672,114209,'117910.000001','printshop','max-width','300',0,'5342'),(358673,114209,'117910.000001','printshop','margin_left_measure','auto',0,'5342'),(358674,114209,'117910.000001','printshop','margin_right_measure','auto',0,'5342'),(358675,114210,'117914.000001','printshop','padding-right','20',0,''),(358676,114211,'117915.000001','printshop','description_characters','200',0,''),(358677,114211,'117915.000001','printshop','clear','none',0,''),(358678,114211,'117915.000001','printshop','padding-right','20',0,''),(358679,114212,'117916.000001','printshop','clear','none',0,''),(358680,114213,'117917.000001','printshop','margin-bottom','20',0,''),(358681,114215,'117918.000001','printshop','block_type','1',0,''),(358682,114215,'117918.000001','printshop','padding-left','40',0,''),(358683,114215,'117918.000001','printshop','style_class','right-aria',0,''),(358684,114215,'117918.000001','printshop','padding-left','0',0,'5342'),(358685,114216,'117911.000001','printshop','block_type','1',0,''),(358686,114216,'117911.000001','printshop','text-align','center',0,''),(358687,114217,'117912.000001','printshop','margin-top','4',0,''),(358688,114217,'117912.000001','printshop','margin-bottom','7',0,''),(358689,114218,'117913.000001','printshop','padding-top','6',0,''),(358690,114218,'117913.000001','printshop','padding-left','5',0,''),(358691,114219,'117919.000001','printshop','margin-bottom','15',0,''),(358692,114219,'117919.000001','printshop','text-align','center',0,''),(358693,114220,'117920.000001','printshop','margin-bottom','10',0,''),(358694,114220,'117920.000001','printshop','text-align','center',0,''),(358695,114221,'117922.000001','printshop','text-align','center',0,''),(358696,114221,'117922.000001','printshop','margin-bottom','15',0,''),(358697,114222,'117924.000001','printshop','text-align','center',0,''),(358698,114222,'117924.000001','printshop','margin-bottom','10',0,''),(358699,114224,'120926.000001','printshop','text-align','center',0,''),(358700,114224,'120926.000001','printshop','margin-bottom','15',0,''),(358701,114225,'120927.000001','printshop','text-align','center',0,''),(358702,114225,'120927.000001','printshop','margin-bottom','15',0,''),(358703,114226,'116176','printshop','block_type','1',0,''),(358704,114226,'116176','printshop','style_class','item-holder',0,''),(358705,114226,'116176','printshop','padding-top','25',0,''),(358706,114226,'116176','printshop','padding-left','25',0,''),(358707,114226,'116176','printshop','padding-right','25',0,''),(358708,114226,'116176','printshop','padding-bottom','25',0,''),(358709,114226,'116176','printshop','text-align','left',0,''),(358710,114228,'116178','printshop','margin-bottom','7',0,''),(358711,114229,'116179','printshop','clear','both',0,''),(358712,114232,'116182','printshop','block_type','1',0,''),(358713,114232,'116182','printshop','style_class','item-holder',0,''),(358714,114232,'116182','printshop','padding-top','25',0,''),(358715,114232,'116182','printshop','padding-left','25',0,''),(358716,114232,'116182','printshop','padding-right','25',0,''),(358717,114232,'116182','printshop','padding-bottom','25',0,''),(358718,114232,'116182','printshop','text-align','left',0,''),(358719,114233,'116183','printshop','block_type','5',0,''),(358720,114236,'116186','printshop','margin-bottom','7',0,''),(358721,114237,'116187','printshop','clear','both',0,''),(358722,114238,'116188','printshop','block_type','1',0,''),(358723,114239,'116189','printshop','block_type','6',0,''),(358724,114239,'116189','printshop','font-weight','400',0,''),(358725,114239,'116189','printshop','schema','6-2',0,'5363'),(358726,114239,'116189','printshop','schema','6-2',0,'5342'),(358727,114240,'116190','printshop','font-weight','400',0,''),(358728,114240,'116190','printshop','padding-right','40',0,''),(358729,114240,'116190','printshop','padding-right','0',0,'5363'),(358730,114240,'116190','printshop','padding-right','0',0,'5342'),(358731,114241,'116191','printshop','block_type','5',0,''),(358732,114241,'116191','printshop','padding-top','10',0,''),(358733,114241,'116191','printshop','padding-bottom','10',0,''),(358734,114241,'116191','printshop','schema','5-2',0,'5363'),(358735,114241,'116191','printshop','border-top-color','$content-border-3',0,''),(358736,114241,'116191','printshop','border-top-width','1',0,''),(358737,114243,'116193','printshop','float','right',0,''),(358738,114245,'116195','printshop','col_in_row','3',0,''),(358739,114245,'116195','printshop','products_align','left',0,''),(358740,114245,'116195','printshop','font-weight','400',0,''),(358741,114245,'116195','printshop','show_qty_input','0',0,''),(358742,114245,'116195','printshop','listing_type','productListing',0,''),(358743,114245,'116195','printshop','listing_type_rows','no',0,''),(358744,114245,'116195','printshop','show_buy_button_b2b','on',0,''),(358745,114245,'116195','printshop','show_wishlist_button_b2b','1',0,''),(358746,114245,'116195','printshop','show_compare_b2b','1',0,''),(358747,114245,'116195','printshop','show_stock','0',0,''),(358748,114245,'116195','printshop','show_description','0',0,''),(358749,114245,'116195','printshop','show_model','0',0,''),(358750,114245,'116195','printshop','show_properties','0',0,''),(358751,114245,'116195','printshop','show_rating','0',0,''),(358752,114245,'116195','printshop','show_rating_counts','0',0,''),(358753,114245,'116195','printshop','show_price','0',0,''),(358754,114245,'116195','printshop','show_buy_button','0',0,''),(358755,114245,'116195','printshop','show_view_button','0',0,''),(358756,114245,'116195','printshop','show_wishlist_button','0',0,''),(358757,114245,'116195','printshop','show_compare','0',0,''),(358758,114245,'116195','printshop','show_name_rows','0',0,''),(358759,114245,'116195','printshop','show_image_rows','0',0,''),(358760,114245,'116195','printshop','show_stock_rows','0',0,''),(358761,114245,'116195','printshop','show_description_rows','0',0,''),(358762,114245,'116195','printshop','show_model_rows','0',0,''),(358763,114245,'116195','printshop','show_properties_rows','0',0,''),(358764,114245,'116195','printshop','show_rating_rows','0',0,''),(358765,114245,'116195','printshop','show_rating_counts_rows','0',0,''),(358766,114245,'116195','printshop','show_price_rows','0',0,''),(358767,114245,'116195','printshop','show_buy_button_rows','0',0,''),(358768,114245,'116195','printshop','show_qty_input_rows','0',0,''),(358769,114245,'116195','printshop','show_view_button_rows','0',0,''),(358770,114245,'116195','printshop','show_wishlist_button_rows','0',0,''),(358771,114245,'116195','printshop','show_compare_rows','0',0,''),(358772,114245,'116195','printshop','show_name_b2b','0',0,''),(358773,114245,'116195','printshop','show_image_b2b','0',0,''),(358774,114245,'116195','printshop','show_stock_b2b','0',0,''),(358775,114245,'116195','printshop','show_description_b2b','0',0,''),(358776,114245,'116195','printshop','show_model_b2b','0',0,''),(358777,114245,'116195','printshop','show_properties_b2b','0',0,''),(358778,114245,'116195','printshop','show_rating_b2b','0',0,''),(358779,114245,'116195','printshop','show_rating_counts_b2b','0',0,''),(358780,114245,'116195','printshop','show_price_b2b','0',0,''),(358781,114245,'116195','printshop','show_qty_input_b2b','0',0,''),(358782,114245,'116195','printshop','show_view_button_b2b','0',0,''),(358783,114245,'116195','printshop','show_attributes_b2b','0',0,''),(358784,114245,'116195','printshop','items_on_page','9',0,''),(358785,114245,'116195','printshop','col_in_row','2',0,'5342'),(358786,114245,'116195','printshop','col_in_row','1',0,'5363'),(358787,114245,'116195','printshop','product_names_teg','h2',0,''),(358788,114246,'116196','printshop','listing_type','productListing',0,''),(358789,114247,'116197','printshop','block_type','1',0,''),(358790,114247,'116197','printshop','padding-top','10',0,''),(358791,114247,'116197','printshop','padding-bottom','10',0,''),(358792,114247,'116197','printshop','border-bottom-width','1',0,''),(358793,114247,'116197','printshop','border-bottom-color','$content-border-3',0,''),(358794,114247,'116197','printshop','margin-left','0',0,''),(358795,114247,'116197','printshop','margin-right','0',0,''),(358796,114248,'116198','printshop','float','right',0,''),(358797,114248,'116198','printshop','display','none',0,'5363'),(358798,114249,'116199','printshop','margin-right','20',0,''),(358799,114249,'116199','printshop','float','right',0,''),(358800,114249,'116199','printshop','clear','none',0,''),(358801,114249,'116199','printshop','display','none',0,'5342'),(358802,114250,'116200','printshop','float','left',0,''),(358803,114250,'116200','printshop','clear','none',0,''),(358804,114250,'116200','printshop','margin-left','20',0,''),(358805,114250,'116200','printshop','display','none',0,'5363'),(358806,114251,'116201','printshop','float','left',0,''),(358807,114251,'116201','printshop','clear','none',0,''),(358808,114251,'116201','printshop','sort_pos_3','1',0,''),(358809,114251,'116201','printshop','sort_pos_4','2',0,''),(358810,114251,'116201','printshop','sort_pos_10','3',0,''),(358811,114251,'116201','printshop','sort_pos_9','4',0,''),(358812,114251,'116201','printshop','sort_pos_11','5',0,''),(358813,114251,'116201','printshop','sort_pos_12','6',0,''),(358814,114251,'116201','printshop','sort_pos_14','7',0,''),(358815,114251,'116201','printshop','sort_pos_13','8',0,''),(358816,114251,'116201','printshop','sort_pos_8','9',0,''),(358817,114251,'116201','printshop','sort_pos_7','10',0,''),(358818,114251,'116201','printshop','sort_pos_2','11',0,''),(358819,114251,'116201','printshop','sort_pos_1','12',0,''),(358820,114251,'116201','printshop','sort_pos_6','13',0,''),(358821,114251,'116201','printshop','sort_pos_5','14',0,''),(358822,114251,'116201','printshop','sort_pos_0','15',0,''),(358823,114251,'116201','printshop','sort_hide_10','1',0,''),(358824,114251,'116201','printshop','sort_hide_9','1',0,''),(358825,114251,'116201','printshop','hide_icons','1',0,''),(358826,114251,'116201','printshop','sort_hide_16','1',0,''),(358827,114251,'116201','printshop','sort_hide_15','1',0,''),(358828,114251,'116201','printshop','sort_hide_3','0',0,''),(358829,114251,'116201','printshop','sort_hide_4','0',0,''),(358830,114251,'116201','printshop','sort_hide_11','1',0,''),(358831,114251,'116201','printshop','sort_hide_12','1',0,''),(358832,114251,'116201','printshop','sort_hide_14','1',0,''),(358833,114251,'116201','printshop','sort_hide_13','1',0,''),(358834,114251,'116201','printshop','sort_hide_8','0',0,''),(358835,114251,'116201','printshop','sort_hide_7','0',0,''),(358836,114251,'116201','printshop','sort_hide_2','1',0,''),(358837,114251,'116201','printshop','sort_hide_1','1',0,''),(358838,114251,'116201','printshop','sort_hide_6','1',0,''),(358839,114251,'116201','printshop','sort_hide_5','1',0,''),(358840,114251,'116201','printshop','sort_hide_0','1',0,''),(358841,114254,'1683121571.054367','printshop','block_type','1',0,''),(358842,114254,'1683121571.054367','printshop','font-weight','normal',0,''),(358843,114254,'1683121571.054367','printshop','padding-top','20',0,''),(358844,114254,'1683121571.054367','printshop','background-color','$content-bg-2',0,''),(358845,114254,'1683121571.054367','printshop','style_class','shopping-cart-index',0,''),(358846,114254,'1683121571.054367','printshop','color','$content-color-2',0,''),(358847,114255,'1683121571.06664','printshop','block_type','4',0,''),(358848,114255,'1683121571.06664','printshop','schema','4-1',0,'5347'),(358849,114255,'1683121571.06664','printshop','schema','4-2',0,'5342'),(358850,114256,'1683121571.069437','printshop','block_type','1',0,''),(358851,114256,'1683121571.069437','printshop','background-color','$content-bg-1',0,''),(358852,114256,'1683121571.069437','printshop','padding-top','20',0,''),(358853,114256,'1683121571.069437','printshop','padding-bottom','20',0,''),(358854,114256,'1683121571.069437','printshop','padding-left','25',0,''),(358855,114256,'1683121571.069437','printshop','padding-right','25',0,''),(358856,114256,'1683121571.069437','printshop','margin-bottom','5',0,''),(358857,114256,'1683121571.069437','printshop','padding-left','15',0,'5333'),(358858,114256,'1683121571.069437','printshop','padding-right','15',0,'5333'),(358859,114256,'1683121571.069437','printshop','color','$content-color-1',0,''),(358860,114257,'1683121571.078735','printshop','block_type','1',0,''),(358861,114257,'1683121571.078735','printshop','background-color','$content-bg-1',0,''),(358862,114257,'1683121571.078735','printshop','margin-bottom','5',0,''),(358863,114257,'1683121571.078735','printshop','padding-left','25',0,''),(358864,114257,'1683121571.078735','printshop','padding-right','25',0,''),(358865,114257,'1683121571.078735','printshop','padding-bottom','25',0,''),(358866,114257,'1683121571.078735','printshop','padding-left','15',0,'5333'),(358867,114257,'1683121571.078735','printshop','padding-right','15',0,'5333'),(358868,114257,'1683121571.078735','printshop','color','$content-color-1',0,''),(358869,114258,'1683121571.080729','printshop','padding-top','20',0,''),(358870,114258,'1683121571.080729','printshop','padding-bottom','20',0,''),(358871,114259,'1683121571.081549','printshop','block_type','4',0,''),(358872,114259,'1683121571.081549','printshop','padding-bottom','20',0,''),(358873,114259,'1683121571.081549','printshop','padding-top','20',0,''),(358874,114259,'1683121571.081549','printshop','border-bottom-color','$content-border-3',0,''),(358875,114259,'1683121571.081549','printshop','border-bottom-width','1',0,''),(358876,114259,'1683121571.081549','printshop','schema','2-1',0,'5342'),(358877,114259,'1683121571.081549','printshop','schema','2-1',0,'5333'),(358878,114259,'1683121571.081549','printshop','schema','2-2',0,'5363'),(358879,114260,'1683121571.08463','printshop','float','left',0,''),(358880,114260,'1683121571.08463','printshop','float','none',0,'5342'),(358881,114261,'1683121571.085411','printshop','text-align','right',0,''),(358882,114261,'1683121571.085411','printshop','clear','none',0,''),(358883,114261,'1683121571.085411','printshop','float','right',0,''),(358884,114261,'1683121571.085411','printshop','padding-top','22',0,''),(358885,114261,'1683121571.085411','printshop','float','none',0,'5342'),(358886,114261,'1683121571.085411','printshop','text-align','left',0,'5342'),(358887,114262,'1683121571.086647','printshop','float','right',0,''),(358888,114262,'1683121571.086647','printshop','padding-top','26',0,''),(358889,114262,'1683121571.086647','printshop','text-align','left',0,'5363'),(358890,114262,'1683121571.086647','printshop','float','none',0,'5363'),(358891,114263,'1683121571.087562','printshop','block_type','1',0,''),(358892,114263,'1683121571.087562','printshop','font-weight','400',0,''),(358893,114263,'1683121571.087562','printshop','schema','2-2',0,'5333'),(358894,114263,'1683121571.087562','printshop','style_class','closeable-content',0,''),(358895,114264,'1683121571.088844','printshop','block_type','2',0,''),(358896,114264,'1683121571.088844','printshop','schema','2-2',0,'5333'),(358897,114266,'1683121571.09021','printshop','padding-right','24',0,''),(358898,114266,'1683121571.09021','printshop','padding-right','0',0,'5333'),(358899,114266,'1683121571.09021','printshop','padding-bottom','20',0,'5333'),(358900,114267,'1683121571.090954','printshop','text','<div><span>##TEXT_YOUR_SHOPPING_CART##</span></div>',0,''),(358901,114267,'1683121571.090954','printshop','style_class','cartTitle',0,''),(358902,114267,'1683121571.090954','printshop','font-size','36',0,''),(358903,114267,'1683121571.090954','printshop','font-weight','bold',0,''),(358904,114267,'1683121571.090954','printshop','text-align','center',0,''),(358905,114267,'1683121571.090954','printshop','padding-top','20',0,''),(358906,114267,'1683121571.090954','printshop','margin-bottom','20',0,''),(358907,114268,'1683121571.092944','printshop','font-weight','normal',0,''),(358908,114268,'1683121571.092944','printshop','hide_parents','2',0,''),(358909,114268,'1683121571.092944','printshop','background-color','$content-bg-1',0,''),(358910,114268,'1683121571.092944','printshop','padding-top','25',0,''),(358911,114268,'1683121571.092944','printshop','padding-left','25',0,''),(358912,114268,'1683121571.092944','printshop','padding-right','25',0,''),(358913,114268,'1683121571.092944','printshop','padding-bottom','25',0,''),(358914,114268,'1683121571.092944','printshop','margin-bottom','20',0,''),(358915,114268,'1683121571.092944','printshop','color','$content-color-1',0,''),(358916,114269,'1683121571.09410','printshop','style_class','order-summary',0,''),(358917,114269,'1683121571.09410','printshop','block_type','1',0,''),(358918,114269,'1683121571.09410','printshop','margin-left','25',0,''),(358919,114269,'1683121571.09410','printshop','margin-left','0',0,'5342'),(358920,114269,'1683121571.09410','printshop','margin-bottom','30',0,'5342'),(358921,114269,'1683121571.09410','printshop','background-color','$content-bg-1',0,''),(358922,114269,'1683121571.09410','printshop','color','$content-color-1',0,''),(358923,114270,'1683121571.095515','printshop','block_type','1',0,''),(358924,114271,'1683121571.096422','printshop','font-weight','400',0,''),(358925,114271,'1683121571.096422','printshop','padding-right','0',0,'5333'),(358926,114272,'1683121571.107437','printshop','font-weight','400',0,''),(358927,114272,'1683121571.107437','printshop','box_align','4',0,''),(358928,114272,'1683121571.107437','printshop','text-align','center',0,'5333'),(358929,114272,'1683121571.107437','printshop','float','none',0,'5333'),(358930,114272,'1683121571.107437','printshop','width','100',0,'5333'),(358931,114272,'1683121571.107437','printshop','width_measure','%',0,'5333'),(358932,114273,'1683121571.108775','printshop','style_class','bottom-totals',0,''),(358933,114274,'1683121571.109664','printshop','style_class','top-totals',0,''),(358934,114275,'1683121571.110832','printshop','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(358935,114276,'116242','printshop','block_type','1',0,''),(358936,114276,'116242','printshop','font-weight','normal',0,''),(358937,114276,'116242','printshop','padding-top','20',0,''),(358938,114276,'116242','printshop','background-color','$content-bg-2',0,''),(358939,114278,'116244','printshop','block_type','4',0,''),(358940,114278,'116244','printshop','schema','4-1',0,'5347'),(358941,114278,'116244','printshop','schema','4-2',0,'5342'),(358942,114279,'116245','printshop','block_type','1',0,''),(358943,114279,'116245','printshop','background-color','$content-bg-1',0,''),(358944,114279,'116245','printshop','padding-top','20',0,''),(358945,114279,'116245','printshop','padding-bottom','20',0,''),(358946,114279,'116245','printshop','padding-left','25',0,''),(358947,114279,'116245','printshop','padding-right','25',0,''),(358948,114279,'116245','printshop','margin-bottom','30',0,''),(358949,114280,'116246','printshop','col_in_row','3',0,''),(358950,114280,'116246','printshop','show_description','1',0,''),(358951,114280,'116246','printshop','show_model','1',0,''),(358952,114280,'116246','printshop','show_properties','1',0,''),(358953,114280,'116246','printshop','show_rating','1',0,''),(358954,114280,'116246','printshop','show_rating_counts','1',0,''),(358955,114280,'116246','printshop','show_qty_input','1',0,''),(358956,114280,'116246','printshop','show_view_button','1',0,''),(358957,114280,'116246','printshop','show_wishlist_button','1',0,''),(358958,114280,'116246','printshop','show_compare','1',0,''),(358959,114280,'116246','printshop','view_as','carousel',0,''),(358960,114280,'116246','printshop','hide_parents','2',0,''),(358961,114281,'116247','printshop','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(358962,114281,'116247','printshop','style_class','bell-ico',0,''),(358963,114282,'116248','printshop','block_type','1',0,''),(358964,114282,'116248','printshop','background-color','$content-bg-1',0,''),(358965,114282,'116248','printshop','margin-bottom','30',0,''),(358966,114283,'116249','printshop','padding-top','20',0,''),(358967,114283,'116249','printshop','padding-left','25',0,''),(358968,114283,'116249','printshop','padding-right','25',0,''),(358969,114283,'116249','printshop','padding-bottom','20',0,''),(358970,114284,'116250','printshop','block_type','2',0,''),(358971,114284,'116250','printshop','padding-bottom','20',0,''),(358972,114284,'116250','printshop','padding-top','20',0,''),(358973,114284,'116250','printshop','padding-left','25',0,''),(358974,114284,'116250','printshop','padding-right','25',0,''),(358975,114284,'116250','printshop','border-bottom-color','$content-border-3',0,''),(358976,114284,'116250','printshop','border-bottom-width','1',0,''),(358977,114284,'116250','printshop','schema','2-2',0,'5342'),(358978,114285,'116251','printshop','float','left',0,''),(358979,114286,'116252','printshop','text-align','right',0,''),(358980,114286,'116252','printshop','clear','none',0,''),(358981,114286,'116252','printshop','float','right',0,''),(358982,114286,'116252','printshop','padding-top','22',0,''),(358983,114287,'116253','printshop','float','right',0,''),(358984,114287,'116253','printshop','padding-top','26',0,''),(358985,114288,'116254','printshop','block_type','1',0,''),(358986,114288,'116254','printshop','padding-top','20',0,''),(358987,114288,'116254','printshop','padding-bottom','20',0,''),(358988,114288,'116254','printshop','padding-left','25',0,''),(358989,114288,'116254','printshop','padding-right','25',0,''),(358990,114288,'116254','printshop','background-color','$content-bg-1',0,''),(358991,114288,'116254','printshop','margin-bottom','30',0,''),(358992,114289,'116255','printshop','hide_parents','2',0,''),(358993,114290,'116256','printshop','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(358994,114291,'116257','printshop','block_type','1',0,''),(358995,114291,'116257','printshop','background-color','$content-bg-1',0,''),(358996,114291,'116257','printshop','padding-top','20',0,''),(358997,114291,'116257','printshop','padding-bottom','20',0,''),(358998,114291,'116257','printshop','padding-left','25',0,''),(358999,114291,'116257','printshop','padding-right','25',0,''),(359000,114291,'116257','printshop','margin-bottom','30',0,''),(359001,114291,'116257','printshop','style_class','closeable-box',0,''),(359002,114292,'116258','printshop','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(359003,114292,'116258','printshop','style_class','savings-ico closeable-heading closeable-event',0,''),(359004,114293,'116259','printshop','block_type','3',0,''),(359005,114293,'116259','printshop','font-weight','400',0,''),(359006,114293,'116259','printshop','schema','2-2',0,'5333'),(359007,114293,'116259','printshop','style_class','closeable-content',0,''),(359008,114293,'116259','printshop','padding-top','10',0,''),(359009,114294,'116260','printshop','font-weight','400',0,''),(359010,114294,'116260','printshop','padding-top','12',0,'5333'),(359011,114294,'116260','printshop','padding-left','0',0,'5333'),(359012,114297,'116263','printshop','block_type','1',0,''),(359013,114297,'116263','printshop','background-color','$content-bg-1',0,''),(359014,114297,'116263','printshop','padding-top','20',0,''),(359015,114297,'116263','printshop','padding-left','25',0,''),(359016,114297,'116263','printshop','padding-right','25',0,''),(359017,114297,'116263','printshop','padding-bottom','20',0,''),(359018,114297,'116263','printshop','margin-bottom','30',0,''),(359019,114297,'116263','printshop','style_class','closeable-box',0,''),(359020,114297,'116263','printshop','display','none',0,'5342'),(359021,114298,'116264','printshop','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(359022,114298,'116264','printshop','style_class','shipping-ico closeable-heading closeable-event',0,''),(359023,114299,'116265','printshop','font-weight','normal',0,''),(359024,114299,'116265','printshop','style_class','closeable-content',0,''),(359025,114299,'116265','printshop','padding-top','10',0,''),(359026,114299,'116265','printshop','hide_parents','2',0,''),(359027,114300,'116266','printshop','style_class','order-summary',0,''),(359028,114300,'116266','printshop','block_type','1',0,''),(359029,114300,'116266','printshop','margin-left','30',0,''),(359030,114300,'116266','printshop','margin-left','0',0,'5342'),(359031,114300,'116266','printshop','margin-bottom','30',0,'5342'),(359032,114301,'116267','printshop','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(359033,114302,'116268','printshop','block_type','1',0,''),(359034,114302,'116268','printshop','padding-left','20',0,''),(359035,114302,'116268','printshop','padding-right','20',0,''),(359036,114302,'116268','printshop','padding-bottom','20',0,''),(359037,114303,'116269','printshop','font-weight','400',0,''),(359038,114303,'116269','printshop','logo','themes/printshop/img/themes/printshop/img/payicons.png',1,''),(359039,114303,'116269','printshop','padding-top','20',0,''),(359040,114303,'116269','printshop','padding-bottom','10',0,''),(359041,114303,'116269','printshop','logo','themes/printshop/img/themes/printshop/img/payicons.png',2,''),(359042,114303,'116269','printshop','logo','themes/printshop/img/themes/printshop/img/payicons.png',3,''),(359043,114303,'116269','printshop','logo','themes/printshop/img/themes/printshop/img/payicons.png',4,''),(359044,114304,'116270','printshop','font-weight','400',0,''),(359045,114304,'116270','printshop','box_align','4',0,''),(359046,114304,'116270','printshop','text-align','center',0,'5333'),(359047,114304,'116270','printshop','float','none',0,'5333'),(359048,114304,'116270','printshop','width','100',0,'5333'),(359049,114304,'116270','printshop','width_measure','%',0,'5333'),(359054,114316,'116272','printshop','block_type','1',0,''),(359055,114319,'1644410221.0341','printshop','block_type','1',0,''),(359056,114319,'1644410221.0341','printshop','background-color','$content-bg-2',0,''),(359057,114319,'1644410221.0341','printshop','padding-top','10',0,''),(359058,114319,'1644410221.0341','printshop','padding-bottom','10',0,''),(359059,114319,'1644410221.0341','printshop','color','$content-color-2',0,''),(359060,114326,'116293','printshop','block_type','1',0,''),(359061,114328,'116295','printshop','block_type','6',0,''),(359062,114328,'116295','printshop','font-weight','400',0,''),(359063,114328,'116295','printshop','schema','6-2',0,'5363'),(359064,114328,'116295','printshop','schema','6-2',0,'5342'),(359065,114329,'116296','printshop','font-weight','400',0,''),(359066,114329,'116296','printshop','padding-right','40',0,''),(359067,114329,'116296','printshop','padding-right','0',0,'5363'),(359068,114329,'116296','printshop','padding-right','0',0,'5342'),(359069,114331,'116298','printshop','col_in_row','3',0,''),(359070,114331,'116298','printshop','products_align','left',0,''),(359071,114331,'116298','printshop','font-weight','400',0,''),(359072,114331,'116298','printshop','show_qty_input','0',0,''),(359073,114331,'116298','printshop','listing_type','productListing',0,''),(359074,114331,'116298','printshop','listing_type_rows','no',0,''),(359075,114331,'116298','printshop','show_buy_button_b2b','on',0,''),(359076,114331,'116298','printshop','show_wishlist_button_b2b','1',0,''),(359077,114331,'116298','printshop','show_compare_b2b','1',0,''),(359078,114331,'116298','printshop','show_stock','0',0,''),(359079,114331,'116298','printshop','show_description','0',0,''),(359080,114331,'116298','printshop','show_model','0',0,''),(359081,114331,'116298','printshop','show_properties','0',0,''),(359082,114331,'116298','printshop','show_rating','0',0,''),(359083,114331,'116298','printshop','show_rating_counts','0',0,''),(359084,114331,'116298','printshop','show_price','0',0,''),(359085,114331,'116298','printshop','show_buy_button','0',0,''),(359086,114331,'116298','printshop','show_view_button','0',0,''),(359087,114331,'116298','printshop','show_wishlist_button','0',0,''),(359088,114331,'116298','printshop','show_compare','0',0,''),(359089,114331,'116298','printshop','show_name_rows','0',0,''),(359090,114331,'116298','printshop','show_image_rows','0',0,''),(359091,114331,'116298','printshop','show_stock_rows','0',0,''),(359092,114331,'116298','printshop','show_description_rows','0',0,''),(359093,114331,'116298','printshop','show_model_rows','0',0,''),(359094,114331,'116298','printshop','show_properties_rows','0',0,''),(359095,114331,'116298','printshop','show_rating_rows','0',0,''),(359096,114331,'116298','printshop','show_rating_counts_rows','0',0,''),(359097,114331,'116298','printshop','show_price_rows','0',0,''),(359098,114331,'116298','printshop','show_buy_button_rows','0',0,''),(359099,114331,'116298','printshop','show_qty_input_rows','0',0,''),(359100,114331,'116298','printshop','show_view_button_rows','0',0,''),(359101,114331,'116298','printshop','show_wishlist_button_rows','0',0,''),(359102,114331,'116298','printshop','show_compare_rows','0',0,''),(359103,114331,'116298','printshop','show_name_b2b','0',0,''),(359104,114331,'116298','printshop','show_image_b2b','0',0,''),(359105,114331,'116298','printshop','show_stock_b2b','0',0,''),(359106,114331,'116298','printshop','show_description_b2b','0',0,''),(359107,114331,'116298','printshop','show_model_b2b','0',0,''),(359108,114331,'116298','printshop','show_properties_b2b','0',0,''),(359109,114331,'116298','printshop','show_rating_b2b','0',0,''),(359110,114331,'116298','printshop','show_rating_counts_b2b','0',0,''),(359111,114331,'116298','printshop','show_price_b2b','0',0,''),(359112,114331,'116298','printshop','show_qty_input_b2b','0',0,''),(359113,114331,'116298','printshop','show_view_button_b2b','0',0,''),(359114,114331,'116298','printshop','show_attributes_b2b','0',0,''),(359115,114331,'116298','printshop','items_on_page','9',0,''),(359116,114331,'116298','printshop','col_in_row','2',0,'5342'),(359117,114331,'116298','printshop','col_in_row','1',0,'5363'),(359118,114331,'116298','printshop','product_names_teg','h2',0,''),(359119,114332,'116299','printshop','block_type','1',0,''),(359120,114332,'116299','printshop','padding-top','10',0,''),(359121,114332,'116299','printshop','padding-bottom','10',0,''),(359122,114332,'116299','printshop','border-bottom-width','1',0,''),(359123,114332,'116299','printshop','border-bottom-color','$content-border-3',0,''),(359124,114332,'116299','printshop','margin-left','0',0,''),(359125,114332,'116299','printshop','margin-right','0',0,''),(359126,114333,'116300','printshop','float','left',0,''),(359127,114333,'116300','printshop','clear','none',0,''),(359128,114333,'116300','printshop','sort_pos_3','1',0,''),(359129,114333,'116300','printshop','sort_pos_4','2',0,''),(359130,114333,'116300','printshop','sort_pos_10','3',0,''),(359131,114333,'116300','printshop','sort_pos_9','4',0,''),(359132,114333,'116300','printshop','sort_pos_11','5',0,''),(359133,114333,'116300','printshop','sort_pos_12','6',0,''),(359134,114333,'116300','printshop','sort_pos_14','7',0,''),(359135,114333,'116300','printshop','sort_pos_13','8',0,''),(359136,114333,'116300','printshop','sort_pos_8','9',0,''),(359137,114333,'116300','printshop','sort_pos_7','10',0,''),(359138,114333,'116300','printshop','sort_pos_2','11',0,''),(359139,114333,'116300','printshop','sort_pos_1','12',0,''),(359140,114333,'116300','printshop','sort_pos_6','13',0,''),(359141,114333,'116300','printshop','sort_pos_5','14',0,''),(359142,114333,'116300','printshop','sort_pos_0','15',0,''),(359143,114333,'116300','printshop','sort_hide_10','1',0,''),(359144,114333,'116300','printshop','sort_hide_9','1',0,''),(359145,114333,'116300','printshop','hide_icons','1',0,''),(359146,114333,'116300','printshop','sort_hide_16','1',0,''),(359147,114333,'116300','printshop','sort_hide_15','1',0,''),(359148,114333,'116300','printshop','sort_hide_3','0',0,''),(359149,114333,'116300','printshop','sort_hide_4','0',0,''),(359150,114333,'116300','printshop','sort_hide_11','1',0,''),(359151,114333,'116300','printshop','sort_hide_12','1',0,''),(359152,114333,'116300','printshop','sort_hide_14','1',0,''),(359153,114333,'116300','printshop','sort_hide_13','1',0,''),(359154,114333,'116300','printshop','sort_hide_8','0',0,''),(359155,114333,'116300','printshop','sort_hide_7','0',0,''),(359156,114333,'116300','printshop','sort_hide_2','1',0,''),(359157,114333,'116300','printshop','sort_hide_1','1',0,''),(359158,114333,'116300','printshop','sort_hide_6','1',0,''),(359159,114333,'116300','printshop','sort_hide_5','1',0,''),(359160,114333,'116300','printshop','sort_hide_0','1',0,''),(359161,114334,'116301','printshop','float','left',0,''),(359162,114334,'116301','printshop','clear','none',0,''),(359163,114334,'116301','printshop','margin-left','20',0,''),(359164,114334,'116301','printshop','display','none',0,'5363'),(359165,114335,'116302','printshop','margin-right','20',0,''),(359166,114335,'116302','printshop','float','right',0,''),(359167,114335,'116302','printshop','clear','none',0,''),(359168,114335,'116302','printshop','display','none',0,'5342'),(359169,114336,'116303','printshop','float','right',0,''),(359170,114336,'116303','printshop','display','none',0,'5363'),(359171,114337,'116304','printshop','listing_type','productListing',0,''),(359172,114339,'116306','printshop','block_type','5',0,''),(359173,114339,'116306','printshop','padding-top','10',0,''),(359174,114339,'116306','printshop','padding-bottom','10',0,''),(359175,114339,'116306','printshop','schema','5-2',0,'5363'),(359176,114339,'116306','printshop','border-top-color','$content-border-3',0,''),(359177,114339,'116306','printshop','border-top-width','1',0,''),(359178,114341,'116308','printshop','float','right',0,''),(359179,114342,'116309','printshop','block_type','1',0,''),(359180,114345,'116312','printshop','block_type','1',0,''),(359181,114345,'116312','printshop','padding-top','10',0,''),(359182,114345,'116312','printshop','padding-bottom','10',0,''),(359183,114345,'116312','printshop','margin-left','0',0,''),(359184,114345,'116312','printshop','margin-right','0',0,''),(359185,114346,'116313','printshop','float','left',0,''),(359186,114346,'116313','printshop','clear','none',0,''),(359187,114346,'116313','printshop','margin-left','20',0,''),(359188,114346,'116313','printshop','display','none',0,'5363'),(359189,114347,'116314','printshop','float','left',0,''),(359190,114347,'116314','printshop','clear','none',0,''),(359191,114347,'116314','printshop','sort_pos_3','2',0,''),(359192,114347,'116314','printshop','sort_pos_4','3',0,''),(359193,114347,'116314','printshop','sort_pos_10','11',0,''),(359194,114347,'116314','printshop','sort_pos_9','10',0,''),(359195,114347,'116314','printshop','sort_pos_11','12',0,''),(359196,114347,'116314','printshop','sort_pos_12','13',0,''),(359197,114347,'116314','printshop','sort_pos_14','15',0,''),(359198,114347,'116314','printshop','sort_pos_13','14',0,''),(359199,114347,'116314','printshop','sort_pos_8','4',0,''),(359200,114347,'116314','printshop','sort_pos_7','5',0,''),(359201,114347,'116314','printshop','sort_pos_2','7',0,''),(359202,114347,'116314','printshop','sort_pos_1','6',0,''),(359203,114347,'116314','printshop','sort_pos_6','9',0,''),(359204,114347,'116314','printshop','sort_pos_5','8',0,''),(359205,114347,'116314','printshop','sort_pos_0','1',0,''),(359206,114347,'116314','printshop','sort_hide_10','1',0,''),(359207,114347,'116314','printshop','sort_hide_9','1',0,''),(359208,114347,'116314','printshop','hide_icons','1',0,''),(359209,114347,'116314','printshop','sort_hide_16','1',0,''),(359210,114347,'116314','printshop','sort_hide_15','1',0,''),(359211,114347,'116314','printshop','sort_hide_3','0',0,''),(359212,114347,'116314','printshop','sort_hide_4','0',0,''),(359213,114347,'116314','printshop','sort_hide_11','1',0,''),(359214,114347,'116314','printshop','sort_hide_12','1',0,''),(359215,114347,'116314','printshop','sort_hide_14','1',0,''),(359216,114347,'116314','printshop','sort_hide_13','1',0,''),(359217,114347,'116314','printshop','sort_hide_8','0',0,''),(359218,114347,'116314','printshop','sort_hide_7','0',0,''),(359219,114347,'116314','printshop','sort_hide_2','1',0,''),(359220,114347,'116314','printshop','sort_hide_1','1',0,''),(359221,114347,'116314','printshop','sort_hide_6','1',0,''),(359222,114347,'116314','printshop','sort_hide_5','1',0,''),(359223,114347,'116314','printshop','sort_hide_0','0',0,''),(359224,114347,'116314','printshop','sort_pos_15','16',0,''),(359225,114347,'116314','printshop','sort_pos_16','17',0,''),(359226,114348,'116315','printshop','margin-right','20',0,''),(359227,114348,'116315','printshop','float','right',0,''),(359228,114348,'116315','printshop','clear','none',0,''),(359229,114348,'116315','printshop','display','none',0,'5342'),(359230,114349,'116316','printshop','float','right',0,''),(359231,114349,'116316','printshop','display','none',0,'5363'),(359232,114350,'116317','printshop','clear','none',0,''),(359233,114350,'116317','printshop','float','left',0,''),(359234,114350,'116317','printshop','padding-top','3',0,''),(359235,114350,'116317','printshop','padding-left','20',0,''),(359236,114351,'116318','printshop','block_type','5',0,''),(359237,114351,'116318','printshop','padding-top','10',0,''),(359238,114351,'116318','printshop','padding-bottom','10',0,''),(359239,114351,'116318','printshop','schema','5-2',0,'5363'),(359240,114351,'116318','printshop','border-top-color','$content-border-3',0,''),(359241,114351,'116318','printshop','border-top-width','1',0,''),(359242,114353,'116320','printshop','float','right',0,''),(359243,114354,'116321','printshop','col_in_row','2',0,''),(359244,114354,'116321','printshop','products_align','left',0,''),(359245,114354,'116321','printshop','font-weight','400',0,''),(359246,114354,'116321','printshop','show_qty_input','0',0,''),(359247,114354,'116321','printshop','listing_type','productListing',0,''),(359248,114354,'116321','printshop','listing_type_rows','Rows',0,''),(359249,114354,'116321','printshop','show_buy_button_b2b','on',0,''),(359250,114354,'116321','printshop','show_wishlist_button_b2b','1',0,''),(359251,114354,'116321','printshop','show_compare_b2b','1',0,''),(359252,114354,'116321','printshop','show_image','0',0,''),(359253,114354,'116321','printshop','show_stock','0',0,''),(359254,114354,'116321','printshop','show_description','0',0,''),(359255,114354,'116321','printshop','show_model','0',0,''),(359256,114354,'116321','printshop','show_properties','0',0,''),(359257,114354,'116321','printshop','show_rating','0',0,''),(359258,114354,'116321','printshop','show_rating_counts','0',0,''),(359259,114354,'116321','printshop','show_price','0',0,''),(359260,114354,'116321','printshop','show_buy_button','0',0,''),(359261,114354,'116321','printshop','show_view_button','0',0,''),(359262,114354,'116321','printshop','show_wishlist_button','0',0,''),(359263,114354,'116321','printshop','show_compare','0',0,''),(359264,114354,'116321','printshop','show_name_rows','0',0,''),(359265,114354,'116321','printshop','show_image_rows','0',0,''),(359266,114354,'116321','printshop','show_stock_rows','0',0,''),(359267,114354,'116321','printshop','show_description_rows','0',0,''),(359268,114354,'116321','printshop','show_model_rows','0',0,''),(359269,114354,'116321','printshop','show_properties_rows','0',0,''),(359270,114354,'116321','printshop','show_rating_rows','0',0,''),(359271,114354,'116321','printshop','show_rating_counts_rows','0',0,''),(359272,114354,'116321','printshop','show_price_rows','0',0,''),(359273,114354,'116321','printshop','show_buy_button_rows','0',0,''),(359274,114354,'116321','printshop','show_qty_input_rows','0',0,''),(359275,114354,'116321','printshop','show_view_button_rows','0',0,''),(359276,114354,'116321','printshop','show_wishlist_button_rows','0',0,''),(359277,114354,'116321','printshop','show_compare_rows','0',0,''),(359278,114354,'116321','printshop','show_name_b2b','0',0,''),(359279,114354,'116321','printshop','show_image_b2b','0',0,''),(359280,114354,'116321','printshop','show_stock_b2b','0',0,''),(359281,114354,'116321','printshop','show_description_b2b','0',0,''),(359282,114354,'116321','printshop','show_model_b2b','0',0,''),(359283,114354,'116321','printshop','show_properties_b2b','0',0,''),(359284,114354,'116321','printshop','show_rating_b2b','0',0,''),(359285,114354,'116321','printshop','show_rating_counts_b2b','0',0,''),(359286,114354,'116321','printshop','show_price_b2b','0',0,''),(359287,114354,'116321','printshop','show_qty_input_b2b','0',0,''),(359288,114354,'116321','printshop','show_view_button_b2b','0',0,''),(359289,114354,'116321','printshop','show_attributes_b2b','0',0,''),(359290,114354,'116321','printshop','items_on_page','12',0,''),(359291,114354,'116321','printshop','col_in_row','1',0,'5363'),(359292,114354,'116321','printshop','product_names_teg','h2',0,''),(359293,114357,'1645199413.4466','printshop','block_type','1',0,''),(359294,114357,'1645199413.4466','printshop','background-color','$content-bg-2',0,''),(359295,114357,'1645199413.4466','printshop','padding-top','10',0,''),(359296,114357,'1645199413.4466','printshop','padding-bottom','10',0,''),(359297,114357,'1645199413.4466','printshop','color','$content-color-2',0,''),(359298,114359,'1683123155.763578','printshop','block_type','1',0,''),(359299,114359,'1683123155.763578','printshop','background-color','$content-bg-2',0,''),(359300,114359,'1683123155.763578','printshop','padding-top','30',0,''),(359301,114359,'1683123155.763578','printshop','padding-bottom','30',0,''),(359302,114359,'1683123155.763578','printshop','style_class','checkout-index-wrap',0,''),(359303,114359,'1683123155.763578','printshop','color','$content-color-2',0,''),(359304,114360,'1683123155.780265','printshop','block_type','4',0,''),(359305,114360,'1683123155.780265','printshop','schema','4-2',0,'5342'),(359306,114361,'1683123155.783425','printshop','block_type','1',0,''),(359307,114361,'1683123155.783425','printshop','padding-right','0',0,'5342'),(359308,114362,'1683123155.78537','printshop','block_type','1',0,''),(359309,114362,'1683123155.78537','printshop','background-color','$content-bg-1',0,''),(359310,114362,'1683123155.78537','printshop','padding-top','30',0,''),(359311,114362,'1683123155.78537','printshop','padding-left','30',0,''),(359312,114362,'1683123155.78537','printshop','padding-right','30',0,''),(359313,114362,'1683123155.78537','printshop','padding-bottom','14',0,''),(359314,114362,'1683123155.78537','printshop','margin-bottom','20',0,''),(359315,114362,'1683123155.78537','printshop','style_class','hiding-box closeable-box',0,''),(359316,114362,'1683123155.78537','printshop','padding-left','15',0,'5333'),(359317,114362,'1683123155.78537','printshop','padding-right','15',0,'5333'),(359318,114362,'1683123155.78537','printshop','padding-top','15',0,'5333'),(359319,114362,'1683123155.78537','printshop','padding-bottom','10',0,'5333'),(359320,114362,'1683123155.78537','printshop','color','$content-color-1',0,''),(359321,114363,'1683123155.788891','printshop','style_class','closeable-content',0,''),(359322,114363,'1683123155.788891','printshop','padding-bottom','20',0,''),(359323,114364,'1683123155.790851','printshop','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(359324,114364,'1683123155.790851','printshop','style_class','closeable-heading closeable-event closed',0,''),(359325,114365,'1683123155.79411','printshop','block_type','1',0,''),(359326,114365,'1683123155.79411','printshop','padding-top','30',0,''),(359327,114365,'1683123155.79411','printshop','padding-left','30',0,''),(359328,114365,'1683123155.79411','printshop','padding-right','30',0,''),(359329,114365,'1683123155.79411','printshop','padding-bottom','14',0,''),(359330,114365,'1683123155.79411','printshop','margin-bottom','20',0,''),(359331,114365,'1683123155.79411','printshop','background-color','$content-bg-1',0,''),(359332,114365,'1683123155.79411','printshop','style_class','hiding-box closeable-box',0,''),(359333,114365,'1683123155.79411','printshop','padding-left','15',0,'5333'),(359334,114365,'1683123155.79411','printshop','padding-right','15',0,'5333'),(359335,114365,'1683123155.79411','printshop','padding-top','15',0,'5333'),(359336,114365,'1683123155.79411','printshop','padding-bottom','10',0,'5333'),(359337,114365,'1683123155.79411','printshop','color','$content-color-1',0,''),(359338,114366,'1683123155.797477','printshop','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(359339,114366,'1683123155.797477','printshop','style_class','closeable-heading closeable-event closed',0,''),(359340,114367,'1683123155.799115','printshop','block_type','2',0,''),(359341,114367,'1683123155.799115','printshop','style_class','closeable-content',0,''),(359342,114367,'1683123155.799115','printshop','schema','2-2',0,'5342'),(359343,114368,'1683123155.800526','printshop','padding-right','20',0,''),(359344,114368,'1683123155.800526','printshop','padding-bottom','20',0,''),(359345,114368,'1683123155.800526','printshop','padding-right','0',0,'5342'),(359346,114369,'1683123155.802510','printshop','padding-left','20',0,''),(359347,114369,'1683123155.802510','printshop','padding-bottom','20',0,''),(359348,114369,'1683123155.802510','printshop','padding-left','0',0,'5342'),(359349,114370,'1683123155.804496','printshop','padding-left','20',0,''),(359350,114370,'1683123155.804496','printshop','padding-bottom','20',0,''),(359351,114370,'1683123155.804496','printshop','padding-left','0',0,'5342'),(359352,114371,'1683123155.806347','printshop','background-color','$content-bg-1',0,''),(359353,114371,'1683123155.806347','printshop','block_type','1',0,''),(359354,114371,'1683123155.806347','printshop','padding-top','30',0,''),(359355,114371,'1683123155.806347','printshop','padding-left','30',0,''),(359356,114371,'1683123155.806347','printshop','padding-right','30',0,''),(359357,114371,'1683123155.806347','printshop','padding-bottom','30',0,''),(359358,114371,'1683123155.806347','printshop','margin-bottom','20',0,''),(359359,114371,'1683123155.806347','printshop','style_class','hiding-box',0,''),(359360,114371,'1683123155.806347','printshop','padding-left','15',0,'5333'),(359361,114371,'1683123155.806347','printshop','padding-right','15',0,'5333'),(359362,114371,'1683123155.806347','printshop','padding-top','15',0,'5333'),(359363,114371,'1683123155.806347','printshop','padding-bottom','15',0,'5333'),(359364,114371,'1683123155.806347','printshop','color','$content-color-1',0,''),(359365,114372,'1683123155.808713','printshop','block_type','1',0,''),(359366,114372,'1683123155.808713','printshop','content','\\_',0,'3'),(359367,114372,'1683123155.808713','printshop','border-top-width','1',0,'3'),(359368,114372,'1683123155.808713','printshop','border-top-color','$content-border-3',0,'3'),(359369,114372,'1683123155.808713','printshop','display','block',0,'3'),(359370,114372,'1683123155.808713','printshop','position','absolute',0,'3'),(359371,114372,'1683123155.808713','printshop','top','19',0,'3'),(359372,114372,'1683123155.808713','printshop','left','0',0,'3'),(359373,114372,'1683123155.808713','printshop','right','0',0,'3'),(359374,114372,'1683123155.808713','printshop','margin-top','-2',0,'3'),(359375,114372,'1683123155.808713','printshop','position','relative',0,''),(359376,114373,'1683123155.81126','printshop','box_align','2',0,''),(359377,114373,'1683123155.81126','printshop','margin-bottom','10',0,''),(359378,114373,'1683123155.81126','printshop','background-color','$content-bg-1',0,''),(359379,114373,'1683123155.81126','printshop','position','relative',0,''),(359380,114374,'1683123155.81663','printshop','background-color','$content-bg-2',0,''),(359381,114374,'1683123155.81663','printshop','padding-top','10',0,''),(359382,114374,'1683123155.81663','printshop','padding-left','10',0,''),(359383,114374,'1683123155.81663','printshop','padding-right','10',0,''),(359384,114374,'1683123155.81663','printshop','padding-bottom','10',0,''),(359385,114374,'1683123155.81663','printshop','margin-top','10',0,''),(359386,114375,'1683123155.81847','printshop','block_type','2',0,''),(359387,114375,'1683123155.81847','printshop','schema','2-2',0,'5342'),(359388,114376,'1683123155.819772','printshop','block_type','1',0,''),(359389,114376,'1683123155.819772','printshop','padding-right','20',0,''),(359390,114376,'1683123155.819772','printshop','padding-left','0',0,'5342'),(359391,114376,'1683123155.819772','printshop','margin-bottom','20',0,'5342'),(359392,114376,'1683123155.819772','printshop','padding-right','0',0,'5342'),(359393,114377,'1683123155.821777','printshop','address_in','popup',0,''),(359394,114378,'1683123155.824396','printshop','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(359395,114381,'1683123155.830610','printshop','block_type','1',0,''),(359396,114381,'1683123155.830610','printshop','padding-left','20',0,''),(359397,114381,'1683123155.830610','printshop','padding-left','0',0,'5342'),(359398,114383,'1683123155.833668','printshop','border-top-width','1',0,''),(359399,114383,'1683123155.833668','printshop','border-top-color','$content-border-3',0,''),(359400,114383,'1683123155.833668','printshop','padding-top','13',0,''),(359401,114383,'1683123155.833668','printshop','padding-bottom','10',0,''),(359402,114384,'1683123155.835296','printshop','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(359403,114385,'1683123155.83711','printshop','show_day','next_day',0,''),(359404,114386,'1683123155.840722','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(359405,114387,'1683123155.842595','printshop','margin-bottom','20',0,''),(359406,114387,'1683123155.842595','printshop','style_class','hiding-box',0,''),(359407,114388,'1683123155.846131','printshop','padding-top','30',0,''),(359408,114388,'1683123155.846131','printshop','padding-left','30',0,''),(359409,114388,'1683123155.846131','printshop','padding-right','30',0,''),(359410,114388,'1683123155.846131','printshop','background-color','$content-bg-1',0,''),(359411,114388,'1683123155.846131','printshop','padding-bottom','30',0,''),(359412,114388,'1683123155.846131','printshop','padding-top','20',0,'5342'),(359413,114388,'1683123155.846131','printshop','padding-left','20',0,'5342'),(359414,114388,'1683123155.846131','printshop','padding-right','20',0,'5342'),(359415,114388,'1683123155.846131','printshop','padding-bottom','20',0,'5342'),(359416,114388,'1683123155.846131','printshop','margin-bottom','20',0,''),(359417,114388,'1683123155.846131','printshop','color','$content-color-1',0,''),(359418,114390,'1683123155.851776','printshop','block_type','1',0,''),(359419,114390,'1683123155.851776','printshop','padding-top','30',0,''),(359420,114390,'1683123155.851776','printshop','padding-left','30',0,''),(359421,114390,'1683123155.851776','printshop','padding-right','30',0,''),(359422,114390,'1683123155.851776','printshop','padding-bottom','23',0,''),(359423,114390,'1683123155.851776','printshop','margin-bottom','20',0,''),(359424,114390,'1683123155.851776','printshop','background-color','$content-bg-1',0,''),(359425,114390,'1683123155.851776','printshop','style_class','hiding-box',0,''),(359426,114390,'1683123155.851776','printshop','padding-left','15',0,'5333'),(359427,114390,'1683123155.851776','printshop','padding-right','15',0,'5333'),(359428,114390,'1683123155.851776','printshop','padding-top','15',0,'5333'),(359429,114390,'1683123155.851776','printshop','padding-bottom','10',0,'5333'),(359430,114390,'1683123155.851776','printshop','color','$content-color-1',0,''),(359431,114391,'1683123155.855125','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(359432,114392,'1683123155.856899','printshop','block_type','2',0,''),(359433,114392,'1683123155.856899','printshop','schema','2-2',0,'5342'),(359434,114393,'1683123155.858186','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359435,114394,'1683123155.859329','printshop','padding-right','20',0,''),(359436,114394,'1683123155.859329','printshop','padding-right','0',0,'5342'),(359437,114394,'1683123155.859329','printshop','padding-bottom','20',0,'5342'),(359438,114394,'1683123155.859329','printshop','address_in','popup',0,''),(359439,114395,'1683123155.863160','printshop','block_type','1',0,''),(359440,114395,'1683123155.863160','printshop','padding-left','20',0,''),(359441,114395,'1683123155.863160','printshop','padding-left','0',0,'5342'),(359442,114397,'1683123155.866124','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359443,114398,'1683123155.867656','printshop','block_type','1',0,''),(359444,114398,'1683123155.867656','printshop','background-color','$content-bg-1',0,''),(359445,114398,'1683123155.867656','printshop','padding-top','30',0,''),(359446,114398,'1683123155.867656','printshop','padding-left','30',0,''),(359447,114398,'1683123155.867656','printshop','padding-right','30',0,''),(359448,114398,'1683123155.867656','printshop','padding-bottom','30',0,''),(359449,114398,'1683123155.867656','printshop','margin-bottom','20',0,''),(359450,114398,'1683123155.867656','printshop','color','$content-color-1',0,''),(359451,114400,'1683123155.87110','printshop','block_type','1',0,''),(359452,114400,'1683123155.87110','printshop','background-color','$content-bg-1',0,''),(359453,114400,'1683123155.87110','printshop','style_class','order-summary',0,''),(359454,114400,'1683123155.87110','printshop','margin-left','25',0,''),(359455,114400,'1683123155.87110','printshop','margin-left','0',0,'5342'),(359456,114400,'1683123155.87110','printshop','color','$content-color-1',0,''),(359457,114401,'1683123155.877884','printshop','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(359458,114401,'1683123155.877884','printshop','text-align','center',0,''),(359459,114401,'1683123155.877884','printshop','font-size','14',0,''),(359460,114401,'1683123155.877884','printshop','color','$fade-color-1',0,''),(359461,114401,'1683123155.877884','printshop','padding-top','10',0,''),(359462,114402,'1683123155.879734','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(359463,114403,'1683123155.881441','printshop','hide_page','1',0,''),(359464,114403,'1683123155.881441','printshop','hide_continue_button','1',0,''),(359465,114404,'1683123155.883138','printshop','margin-bottom','10',0,''),(359466,114407,'116368','printshop','block_type','1',0,''),(359467,114409,'116370','printshop','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(359468,114410,'116371','printshop','link','products',0,''),(359469,114410,'116371','printshop','margin-top','-33',0,''),(359470,114410,'116371','printshop','float','right',0,''),(359471,114411,'116372','printshop','block_type','2',0,''),(359472,114411,'116372','printshop','margin-bottom','20',0,''),(359473,114411,'116372','printshop','schema','2-2',0,'5333'),(359474,114412,'116373','printshop','block_type','1',0,''),(359475,114412,'116373','printshop','padding-right','20',0,''),(359476,114412,'116373','printshop','padding-right','0',0,'5333'),(359477,114413,'116374','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(359478,114413,'116374','printshop','clear','none',0,''),(359479,114415,'116376','printshop','padding-left','20',0,''),(359480,114415,'116376','printshop','block_type','1',0,''),(359481,114415,'116376','printshop','padding-left','0',0,'5333'),(359482,114417,'116378','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359483,114417,'116378','printshop','clear','none',0,''),(359484,114418,'116379','printshop','text-align','right',0,''),(359485,114418,'116379','printshop','margin-bottom','20',0,''),(359486,114418,'116379','printshop','margin-top','20',0,''),(359487,114419,'116380','printshop','block_type','2',0,''),(359488,114419,'116380','printshop','margin-bottom','20',0,''),(359489,114419,'116380','printshop','schema','2-2',0,'5333'),(359490,114420,'116381','printshop','block_type','1',0,''),(359491,114420,'116381','printshop','padding-right','20',0,''),(359492,114420,'116381','printshop','padding-right','0',0,'5333'),(359493,114422,'116383','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(359494,114422,'116383','printshop','clear','none',0,''),(359495,114423,'116384','printshop','block_type','1',0,''),(359496,114423,'116384','printshop','padding-left','20',0,''),(359497,114423,'116384','printshop','padding-left','0',0,'5333'),(359498,114424,'116385','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359499,114424,'116385','printshop','clear','none',0,''),(359500,114426,'116387','printshop','margin-bottom','20',0,''),(359501,114426,'116387','printshop','text-align','right',0,''),(359502,114428,'116402','printshop','block_type','1',0,''),(359503,114429,'116403','printshop','text-align','right',0,''),(359504,114429,'116403','printshop','margin-bottom','20',0,''),(359505,114430,'116404','printshop','block_type','2',0,''),(359506,114430,'116404','printshop','margin-bottom','20',0,''),(359507,114430,'116404','printshop','schema','2-2',0,'5333'),(359508,114431,'116405','printshop','block_type','1',0,''),(359509,114431,'116405','printshop','padding-right','20',0,''),(359510,114431,'116405','printshop','padding-right','0',0,'5333'),(359511,114432,'116406','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359512,114432,'116406','printshop','clear','none',0,''),(359513,114434,'116408','printshop','block_type','1',0,''),(359514,114434,'116408','printshop','padding-left','20',0,''),(359515,114434,'116408','printshop','padding-left','0',0,'5333'),(359516,114435,'116409','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359517,114435,'116409','printshop','clear','none',0,''),(359518,114437,'116411','printshop','margin-bottom','20',0,''),(359519,114437,'116411','printshop','text-align','right',0,''),(359520,114440,'116414','printshop','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(359521,114441,'116389','printshop','block_type','1',0,''),(359522,114442,'116390','printshop','margin-bottom','20',0,''),(359523,114443,'116391','printshop','margin-bottom','20',0,''),(359524,114443,'116391','printshop','text-align','right',0,''),(359525,114444,'116392','printshop','text-align','right',0,''),(359526,114444,'116392','printshop','margin-bottom','20',0,''),(359527,114445,'116393','printshop','block_type','2',0,''),(359528,114445,'116393','printshop','margin-bottom','20',0,''),(359529,114445,'116393','printshop','schema','2-2',0,'5333'),(359530,114446,'116394','printshop','block_type','1',0,''),(359531,114446,'116394','printshop','padding-right','20',0,''),(359532,114446,'116394','printshop','padding-right','0',0,'5333'),(359533,114448,'116396','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359534,114448,'116396','printshop','clear','none',0,''),(359535,114449,'116397','printshop','block_type','1',0,''),(359536,114449,'116397','printshop','padding-left','20',0,''),(359537,114449,'116397','printshop','padding-left','0',0,'5333'),(359538,114451,'116399','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359539,114451,'116399','printshop','clear','none',0,''),(359540,114452,'116400','printshop','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(359541,114453,'116401','printshop','margin-bottom','20',0,''),(359542,114454,'116415','printshop','block_type','1',0,''),(359543,114455,'116416','printshop','block_type','2',0,''),(359544,114455,'116416','printshop','margin-bottom','20',0,''),(359545,114455,'116416','printshop','schema','2-2',0,'5333'),(359546,114456,'116417','printshop','block_type','1',0,''),(359547,114456,'116417','printshop','padding-right','20',0,''),(359548,114456,'116417','printshop','padding-right','0',0,'5333'),(359549,114458,'116419','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(359550,114458,'116419','printshop','clear','none',0,''),(359551,114459,'116420','printshop','block_type','1',0,''),(359552,114459,'116420','printshop','padding-left','20',0,''),(359553,114459,'116420','printshop','padding-left','0',0,'5333'),(359554,114461,'116422','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359555,114461,'116422','printshop','clear','none',0,''),(359556,114462,'116423','printshop','margin-bottom','20',0,''),(359557,114463,'116424','printshop','margin-bottom','20',0,''),(359558,114464,'116425','printshop','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(359559,114465,'116426','printshop','link','products',0,''),(359560,114465,'116426','printshop','margin-top','-33',0,''),(359561,114465,'116426','printshop','float','right',0,''),(359562,114466,'116427','printshop','text-align','right',0,''),(359563,114466,'116427','printshop','margin-bottom','20',0,''),(359564,114467,'116428','printshop','margin-bottom','20',0,''),(359565,114467,'116428','printshop','text-align','right',0,''),(359566,114468,'116429','printshop','block_type','2',0,''),(359567,114468,'116429','printshop','margin-bottom','20',0,''),(359568,114468,'116429','printshop','schema','2-2',0,'5333'),(359569,114469,'116430','printshop','block_type','1',0,''),(359570,114469,'116430','printshop','padding-right','20',0,''),(359571,114469,'116430','printshop','padding-right','0',0,'5333'),(359572,114470,'116431','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(359573,114470,'116431','printshop','clear','none',0,''),(359574,114472,'116433','printshop','padding-left','20',0,''),(359575,114472,'116433','printshop','block_type','1',0,''),(359576,114472,'116433','printshop','padding-left','0',0,'5333'),(359577,114473,'116434','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359578,114473,'116434','printshop','clear','none',0,''),(359579,114475,'116436','printshop','text','##TEXT_CONFIRMATION##',0,''),(359580,114476,'116437','printshop','text','##TEXT_CONFIRMATION##',0,''),(359581,114477,'116439','printshop','text','##TEXT_CONFIRMATION##',0,''),(359582,114478,'116438','printshop','text','##TEXT_CONFIRMATION##',0,''),(359583,114479,'116440','printshop','text','##TEXT_CONFIRMATION##',0,''),(359584,114480,'116441','printshop','text','##TEXT_CONFIRMATION##',0,''),(359585,114481,'116442','printshop','block_type','2',0,''),(359586,114481,'116442','printshop','schema','2-2',0,'5411'),(359587,114481,'116442','printshop','schema','2-1',0,'5333'),(359588,114482,'116443','printshop','block_type','1',0,''),(359589,114482,'116443','printshop','padding-right','20',0,''),(359590,114483,'116444','printshop','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(359591,114485,'116446','printshop','block_type','1',0,''),(359592,114485,'116446','printshop','padding-left','20',0,''),(359593,114485,'116446','printshop','padding-left','0',0,'5342'),(359594,114486,'116447','printshop','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(359595,114488,'116449','printshop','block_type','4',0,''),(359596,114488,'116449','printshop','schema','4-2',0,'5363'),(359597,114488,'116449','printshop','padding-top','20',0,''),(359598,114489,'116450','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359599,114489,'116450','printshop','text-align','right',0,''),(359600,114489,'116450','printshop','padding-top','10',0,''),(359601,114489,'116450','printshop','font_size_measure','em',0,''),(359602,114489,'116450','printshop','font-size','1.2',0,''),(359603,114489,'116450','printshop','text-align','center',0,'5411'),(359604,114490,'116451','printshop','text-align','right',0,''),(359605,114490,'116451','printshop','text-align','center',0,'5411'),(359606,114491,'116452','printshop','block_type','2',0,''),(359607,114491,'116452','printshop','schema','2-1',0,'5333'),(359608,114491,'116452','printshop','schema','2-2',0,'5411'),(359609,114492,'116453','printshop','block_type','1',0,''),(359610,114492,'116453','printshop','padding-right','20',0,''),(359611,114492,'116453','printshop','padding-right','0',0,'5342'),(359612,114493,'116454','printshop','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(359613,114495,'116456','printshop','block_type','1',0,''),(359614,114495,'116456','printshop','padding-right','0',0,'5342'),(359615,114495,'116456','printshop','padding-left','20',0,''),(359616,114495,'116456','printshop','padding-left','0',0,'5333'),(359617,114498,'116459','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(359618,114500,'116461','printshop','block_type','2',0,''),(359619,114501,'116462','printshop','block_type','1',0,''),(359620,114501,'116462','printshop','padding-right','20',0,''),(359621,114503,'116464','printshop','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(359622,114504,'116465','printshop','block_type','1',0,''),(359623,114504,'116465','printshop','padding-left','20',0,''),(359624,114504,'116465','printshop','padding-left','0',0,'5342'),(359625,114505,'116466','printshop','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(359626,114507,'116468','printshop','block_type','4',0,''),(359627,114507,'116468','printshop','schema','4-2',0,'5363'),(359628,114508,'116469','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359629,114508,'116469','printshop','text-align','right',0,''),(359630,114508,'116469','printshop','padding-top','10',0,''),(359631,114508,'116469','printshop','font_size_measure','em',0,''),(359632,114508,'116469','printshop','font-size','1.2',0,''),(359633,114509,'116470','printshop','text-align','right',0,''),(359634,114510,'116471','printshop','block_type','2',0,''),(359635,114511,'116472','printshop','block_type','1',0,''),(359636,114511,'116472','printshop','padding-right','20',0,''),(359637,114511,'116472','printshop','padding-right','0',0,'5342'),(359638,114513,'116474','printshop','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(359639,114514,'116475','printshop','block_type','1',0,''),(359640,114514,'116475','printshop','padding-right','0',0,'5342'),(359641,114514,'116475','printshop','padding-left','20',0,''),(359642,114516,'116477','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(359643,114519,'116480','printshop','block_type','4',0,''),(359644,114519,'116480','printshop','schema','4-2',0,'5363'),(359645,114520,'116481','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359646,114520,'116481','printshop','text-align','right',0,''),(359647,114520,'116481','printshop','padding-top','10',0,''),(359648,114520,'116481','printshop','font_size_measure','em',0,''),(359649,114520,'116481','printshop','font-size','1.2',0,''),(359650,114521,'116482','printshop','text-align','right',0,''),(359651,114522,'116483','printshop','block_type','2',0,''),(359652,114523,'116484','printshop','block_type','1',0,''),(359653,114523,'116484','printshop','padding-right','20',0,''),(359654,114525,'116486','printshop','block_type','1',0,''),(359655,114525,'116486','printshop','padding-left','20',0,''),(359656,114525,'116486','printshop','padding-left','0',0,'5342'),(359657,114526,'116487','printshop','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(359658,114528,'116489','printshop','block_type','4',0,''),(359659,114528,'116489','printshop','schema','4-2',0,'5363'),(359660,114529,'116490','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359661,114529,'116490','printshop','text-align','right',0,''),(359662,114529,'116490','printshop','padding-top','10',0,''),(359663,114529,'116490','printshop','font_size_measure','em',0,''),(359664,114529,'116490','printshop','font-size','1.2',0,''),(359665,114530,'116491','printshop','text-align','right',0,''),(359666,114531,'116492','printshop','block_type','2',0,''),(359667,114532,'116493','printshop','block_type','1',0,''),(359668,114532,'116493','printshop','padding-right','20',0,''),(359669,114534,'116495','printshop','block_type','1',0,''),(359670,114534,'116495','printshop','padding-left','20',0,''),(359671,114534,'116495','printshop','padding-left','0',0,'5342'),(359672,114536,'116497','printshop','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(359673,114537,'116498','printshop','text','##DELIVERY_DETAILS##',0,''),(359674,114538,'116499','printshop','text','##DELIVERY_DETAILS##',0,''),(359675,114539,'116501','printshop','text','##CONTACT_INFORMATION##',0,''),(359676,114540,'116500','printshop','text','##CONTACT_INFORMATION##',0,''),(359677,114541,'116502','printshop','text','##DELIVERY_DETAILS##',0,''),(359678,114542,'116503','printshop','text','##DELIVERY_DETAILS##',0,''),(359679,114543,'116504','printshop','block_type','1',0,''),(359680,114543,'116504','printshop','background-color','$content-bg-2',0,''),(359681,114543,'116504','printshop','padding-top','30',0,''),(359682,114543,'116504','printshop','padding-bottom','30',0,''),(359683,114544,'116505','printshop','block_type','7',0,''),(359684,114544,'116505','printshop','schema','4-2',0,'5342'),(359685,114545,'116506','printshop','block_type','1',0,''),(359686,114545,'116506','printshop','padding-right','0',0,'5342'),(359687,114546,'116508','printshop','block_type','1',0,''),(359688,114546,'116508','printshop','background-color','$content-bg-1',0,''),(359689,114546,'116508','printshop','padding-top','30',0,''),(359690,114546,'116508','printshop','padding-left','30',0,''),(359691,114546,'116508','printshop','padding-right','30',0,''),(359692,114546,'116508','printshop','padding-bottom','30',0,''),(359693,114546,'116508','printshop','margin-bottom','20',0,''),(359694,114546,'116508','printshop','style_class','hiding-box',0,''),(359695,114547,'116509','printshop','margin-bottom','20',0,''),(359696,114548,'116510','printshop','padding-top','10',0,''),(359697,114548,'116510','printshop','padding-left','20',0,''),(359698,114548,'116510','printshop','padding-right','20',0,''),(359699,114548,'116510','printshop','margin-top','20',0,''),(359700,114548,'116510','printshop','background-color','$content-bg-2',0,''),(359701,114548,'116510','printshop','padding-bottom','8',0,''),(359702,114549,'116511','printshop','block_type','1',0,''),(359703,114549,'116511','printshop','background-color','$content-bg-1',0,''),(359704,114549,'116511','printshop','padding-top','30',0,''),(359705,114549,'116511','printshop','padding-left','30',0,''),(359706,114549,'116511','printshop','padding-right','30',0,''),(359707,114549,'116511','printshop','padding-bottom','14',0,''),(359708,114549,'116511','printshop','margin-bottom','20',0,''),(359709,114549,'116511','printshop','style_class','hiding-box closeable-box',0,''),(359710,114550,'116512','printshop','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(359711,114550,'116512','printshop','style_class','closeable-heading closeable-event closed',0,''),(359712,114551,'116513','printshop','style_class','closeable-content',0,''),(359713,114551,'116513','printshop','padding-bottom','20',0,''),(359714,114552,'116514','printshop','background-color','$content-bg-1',0,''),(359715,114552,'116514','printshop','block_type','1',0,''),(359716,114552,'116514','printshop','padding-top','30',0,''),(359717,114552,'116514','printshop','padding-left','30',0,''),(359718,114552,'116514','printshop','padding-right','30',0,''),(359719,114552,'116514','printshop','padding-bottom','30',0,''),(359720,114552,'116514','printshop','margin-bottom','20',0,''),(359721,114552,'116514','printshop','style_class','hiding-box',0,''),(359722,114553,'116515','printshop','block_type','1',0,''),(359723,114553,'116515','printshop','content','\\_',0,'3'),(359724,114553,'116515','printshop','border-top-width','1',0,'3'),(359725,114553,'116515','printshop','border-top-color','$content-border-3',0,'3'),(359726,114553,'116515','printshop','display','block',0,'3'),(359727,114553,'116515','printshop','position','absolute',0,'3'),(359728,114553,'116515','printshop','top','19',0,'3'),(359729,114553,'116515','printshop','left','0',0,'3'),(359730,114553,'116515','printshop','right','0',0,'3'),(359731,114553,'116515','printshop','margin-top','-2',0,'3'),(359732,114553,'116515','printshop','position','relative',0,''),(359733,114554,'116516','printshop','box_align','2',0,''),(359734,114554,'116516','printshop','margin-bottom','10',0,''),(359735,114554,'116516','printshop','background-color','$content-bg-1',0,''),(359736,114554,'116516','printshop','position','relative',0,''),(359737,114555,'116517','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(359738,114556,'116518','printshop','block_type','2',0,''),(359739,114556,'116518','printshop','schema','2-2',0,'5342'),(359740,114557,'116519','printshop','block_type','1',0,''),(359741,114557,'116519','printshop','padding-right','20',0,''),(359742,114557,'116519','printshop','padding-left','0',0,'5342'),(359743,114557,'116519','printshop','margin-bottom','20',0,'5342'),(359744,114557,'116519','printshop','padding-right','0',0,'5342'),(359745,114560,'116522','printshop','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(359746,114561,'116523','printshop','block_type','1',0,''),(359747,114561,'116523','printshop','padding-left','20',0,''),(359748,114561,'116523','printshop','padding-left','0',0,'5342'),(359749,114562,'116524','printshop','padding-bottom','10',0,''),(359750,114563,'116525','printshop','background-color','$content-bg-2',0,''),(359751,114563,'116525','printshop','padding-top','10',0,''),(359752,114563,'116525','printshop','padding-left','10',0,''),(359753,114563,'116525','printshop','padding-right','10',0,''),(359754,114563,'116525','printshop','padding-bottom','10',0,''),(359755,114563,'116525','printshop','margin-top','10',0,''),(359756,114564,'116526','printshop','block_type','1',0,''),(359757,114564,'116526','printshop','padding-top','10',0,''),(359758,114564,'116526','printshop','padding-left','10',0,''),(359759,114564,'116526','printshop','padding-right','10',0,''),(359760,114564,'116526','printshop','padding-bottom','10',0,''),(359761,114564,'116526','printshop','background-color','$content-bg-1',0,''),(359762,114564,'116526','printshop','style_class','order-summary',0,''),(359763,114564,'116526','printshop','margin-left','25',0,''),(359764,114564,'116526','printshop','margin-left','0',0,'5342'),(359765,114565,'116527','printshop','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(359766,114565,'116527','printshop','text-align','center',0,''),(359767,114565,'116527','printshop','font-size','14',0,''),(359768,114565,'116527','printshop','color','$fade-color-1',0,''),(359769,114565,'116527','printshop','padding-top','10',0,''),(359770,114568,'1638957135.2709','printshop','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(359771,114569,'116529','printshop','block_type','1',0,''),(359772,114569,'116529','printshop','background-color','$content-bg-2',0,''),(359773,114569,'116529','printshop','padding-top','30',0,''),(359774,114569,'116529','printshop','padding-bottom','30',0,''),(359775,114569,'116529','printshop','color','$content-color-2',0,''),(359776,114570,'116530','printshop','block_type','7',0,''),(359777,114571,'116531','printshop','block_type','1',0,''),(359778,114572,'116532','printshop','block_type','1',0,''),(359779,114572,'116532','printshop','background-color','$content-bg-1',0,''),(359780,114572,'116532','printshop','padding-top','30',0,''),(359781,114572,'116532','printshop','padding-left','30',0,''),(359782,114572,'116532','printshop','padding-right','30',0,''),(359783,114572,'116532','printshop','padding-bottom','30',0,''),(359784,114572,'116532','printshop','margin-bottom','20',0,''),(359785,114572,'116532','printshop','style_class','hiding-box',0,''),(359786,114572,'116532','printshop','color','$content-color-1',0,''),(359787,114573,'116533','printshop','padding-top','10',0,''),(359788,114573,'116533','printshop','padding-left','20',0,''),(359789,114573,'116533','printshop','padding-right','20',0,''),(359790,114573,'116533','printshop','margin-top','20',0,''),(359791,114573,'116533','printshop','background-color','$content-bg-2',0,''),(359792,114573,'116533','printshop','padding-bottom','8',0,''),(359793,114573,'116533','printshop','color','$content-color-2',0,''),(359794,114574,'116534','printshop','margin-bottom','20',0,''),(359795,114575,'116535','printshop','block_type','1',0,''),(359796,114575,'116535','printshop','padding-top','30',0,''),(359797,114575,'116535','printshop','padding-left','30',0,''),(359798,114575,'116535','printshop','padding-right','30',0,''),(359799,114575,'116535','printshop','padding-bottom','23',0,''),(359800,114575,'116535','printshop','margin-bottom','20',0,''),(359801,114575,'116535','printshop','background-color','$content-bg-1',0,''),(359802,114575,'116535','printshop','style_class','hiding-box',0,''),(359803,114575,'116535','printshop','color','$content-color-1',0,''),(359804,114576,'116536','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(359805,114577,'116537','printshop','block_type','2',0,''),(359806,114578,'116538','printshop','padding-right','20',0,''),(359807,114579,'116539','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359808,114580,'116540','printshop','block_type','1',0,''),(359809,114580,'116540','printshop','padding-left','20',0,''),(359810,114581,'116541','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359811,114583,'116543','printshop','block_type','1',0,''),(359812,114583,'116543','printshop','padding-top','30',0,''),(359813,114583,'116543','printshop','padding-left','30',0,''),(359814,114583,'116543','printshop','padding-right','30',0,''),(359815,114583,'116543','printshop','padding-bottom','14',0,''),(359816,114583,'116543','printshop','margin-bottom','20',0,''),(359817,114583,'116543','printshop','background-color','$content-bg-1',0,''),(359818,114583,'116543','printshop','style_class','hiding-box closeable-box',0,''),(359819,114583,'116543','printshop','color','$content-color-1',0,''),(359820,114584,'116544','printshop','block_type','2',0,''),(359821,114584,'116544','printshop','style_class','closeable-content',0,''),(359822,114585,'116545','printshop','padding-right','20',0,''),(359823,114585,'116545','printshop','padding-bottom','20',0,''),(359824,114586,'116546','printshop','padding-left','20',0,''),(359825,114586,'116546','printshop','padding-bottom','20',0,''),(359826,114587,'116547','printshop','padding-left','20',0,''),(359827,114587,'116547','printshop','padding-bottom','20',0,''),(359828,114588,'116548','printshop','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(359829,114588,'116548','printshop','style_class','closeable-heading closeable-event closed',0,''),(359830,114589,'116549','printshop','block_type','1',0,''),(359831,114589,'116549','printshop','background-color','$content-bg-1',0,''),(359832,114589,'116549','printshop','padding-top','30',0,''),(359833,114589,'116549','printshop','padding-left','30',0,''),(359834,114589,'116549','printshop','padding-right','30',0,''),(359835,114589,'116549','printshop','padding-bottom','14',0,''),(359836,114589,'116549','printshop','margin-bottom','20',0,''),(359837,114589,'116549','printshop','style_class','hiding-box closeable-box',0,''),(359838,114589,'116549','printshop','color','$content-color-1',0,''),(359839,114590,'116550','printshop','style_class','closeable-content',0,''),(359840,114590,'116550','printshop','padding-bottom','20',0,''),(359841,114591,'116551','printshop','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(359842,114591,'116551','printshop','style_class','closeable-heading closeable-event closed',0,''),(359843,114592,'116552','printshop','block_type','1',0,''),(359844,114592,'116552','printshop','padding-top','10',0,''),(359845,114592,'116552','printshop','padding-left','10',0,''),(359846,114592,'116552','printshop','padding-right','10',0,''),(359847,114592,'116552','printshop','padding-bottom','10',0,''),(359848,114592,'116552','printshop','background-color','$content-bg-1',0,''),(359849,114592,'116552','printshop','style_class','order-summary hiding-box',0,''),(359850,114592,'116552','printshop','margin-left','25',0,''),(359851,114592,'116552','printshop','color','$content-color-1',0,''),(359852,114593,'116553','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(359853,114594,'116554','printshop','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(359854,114594,'116554','printshop','text-align','center',0,''),(359855,114594,'116554','printshop','font-size','14',0,''),(359856,114594,'116554','printshop','color','$fade-color-1',0,''),(359857,114594,'116554','printshop','padding-top','10',0,''),(359858,114595,'116555','printshop','margin-bottom','10',0,''),(359859,114597,'116557','printshop','hide_page','1',0,''),(359860,114597,'116557','printshop','hide_continue_button','1',0,''),(359861,114598,'116558','printshop','block_type','1',0,''),(359862,114600,'116560','printshop','block_type','4',0,''),(359863,114600,'116560','printshop','schema','4-2',0,'5363'),(359864,114601,'116561','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359865,114601,'116561','printshop','text-align','right',0,''),(359866,114601,'116561','printshop','padding-top','10',0,''),(359867,114601,'116561','printshop','font_size_measure','em',0,''),(359868,114601,'116561','printshop','font-size','1.2',0,''),(359869,114602,'116562','printshop','text-align','right',0,''),(359870,114603,'116563','printshop','block_type','2',0,''),(359871,114603,'116563','printshop','schema','2-2',0,'5342'),(359872,114604,'116564','printshop','block_type','1',0,''),(359873,114604,'116564','printshop','padding-right','20',0,''),(359874,114604,'116564','printshop','padding-right','0',0,'5342'),(359875,114606,'116566','printshop','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(359876,114607,'116567','printshop','block_type','1',0,''),(359877,114607,'116567','printshop','padding-left','20',0,''),(359878,114607,'116567','printshop','padding-left','0',0,'5342'),(359879,114609,'116569','printshop','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(359880,114610,'116570','printshop','block_type','2',0,''),(359881,114610,'116570','printshop','schema','2-2',0,'5342'),(359882,114611,'116571','printshop','block_type','1',0,''),(359883,114611,'116571','printshop','padding-right','20',0,''),(359884,114611,'116571','printshop','padding-right','0',0,'5342'),(359885,114612,'116572','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359886,114614,'116574','printshop','block_type','1',0,''),(359887,114614,'116574','printshop','padding-left','20',0,''),(359888,114614,'116574','printshop','padding-left','0',0,'5342'),(359889,114619,'116579','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359890,114620,'116580','printshop','margin-bottom','20',0,''),(359891,114621,'116581','printshop','block_type','1',0,''),(359892,114621,'116581','printshop','background-color','$content-bg-2',0,''),(359893,114621,'116581','printshop','padding-top','30',0,''),(359894,114621,'116581','printshop','padding-bottom','30',0,''),(359895,114622,'116582','printshop','block_type','7',0,''),(359896,114622,'116582','printshop','schema','4-2',0,'5342'),(359897,114622,'116582','printshop','margin-bottom','30',0,''),(359898,114623,'116583','printshop','block_type','1',0,''),(359899,114623,'116583','printshop','padding-right','0',0,'5342'),(359900,114624,'116585','printshop','block_type','1',0,''),(359901,114624,'116585','printshop','background-color','$content-bg-1',0,''),(359902,114624,'116585','printshop','padding-top','30',0,''),(359903,114624,'116585','printshop','padding-left','30',0,''),(359904,114624,'116585','printshop','padding-right','30',0,''),(359905,114624,'116585','printshop','padding-bottom','14',0,''),(359906,114624,'116585','printshop','margin-bottom','20',0,''),(359907,114624,'116585','printshop','style_class','hiding-box closeable-box',0,''),(359908,114625,'116586','printshop','style_class','closeable-content',0,''),(359909,114625,'116586','printshop','padding-bottom','20',0,''),(359910,114626,'116587','printshop','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(359911,114626,'116587','printshop','style_class','closeable-heading closeable-event closed',0,''),(359912,114627,'116588','printshop','block_type','1',0,''),(359913,114627,'116588','printshop','background-color','$content-bg-1',0,''),(359914,114627,'116588','printshop','padding-top','30',0,''),(359915,114627,'116588','printshop','padding-left','30',0,''),(359916,114627,'116588','printshop','padding-right','30',0,''),(359917,114627,'116588','printshop','padding-bottom','30',0,''),(359918,114627,'116588','printshop','margin-bottom','20',0,''),(359919,114627,'116588','printshop','style_class','hiding-box',0,''),(359920,114628,'116589','printshop','padding-top','10',0,''),(359921,114628,'116589','printshop','padding-left','20',0,''),(359922,114628,'116589','printshop','padding-right','20',0,''),(359923,114628,'116589','printshop','margin-top','20',0,''),(359924,114628,'116589','printshop','background-color','$content-bg-2',0,''),(359925,114628,'116589','printshop','padding-bottom','8',0,''),(359926,114629,'116590','printshop','margin-bottom','20',0,''),(359927,114630,'116591','printshop','block_type','1',0,''),(359928,114630,'116591','printshop','padding-top','30',0,''),(359929,114630,'116591','printshop','padding-left','30',0,''),(359930,114630,'116591','printshop','padding-right','30',0,''),(359931,114630,'116591','printshop','padding-bottom','23',0,''),(359932,114630,'116591','printshop','margin-bottom','20',0,''),(359933,114630,'116591','printshop','background-color','$content-bg-1',0,''),(359934,114630,'116591','printshop','style_class','hiding-box',0,''),(359935,114631,'116592','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(359936,114632,'116593','printshop','block_type','2',0,''),(359937,114632,'116593','printshop','schema','2-2',0,'5342'),(359938,114633,'116594','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359939,114634,'116595','printshop','padding-right','20',0,''),(359940,114634,'116595','printshop','padding-right','0',0,'5342'),(359941,114634,'116595','printshop','padding-bottom','20',0,'5342'),(359942,114635,'116596','printshop','block_type','1',0,''),(359943,114635,'116596','printshop','padding-left','20',0,''),(359944,114635,'116596','printshop','padding-left','0',0,'5342'),(359945,114637,'116598','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359946,114638,'116599','printshop','block_type','1',0,''),(359947,114638,'116599','printshop','padding-top','10',0,''),(359948,114638,'116599','printshop','padding-left','10',0,''),(359949,114638,'116599','printshop','padding-right','10',0,''),(359950,114638,'116599','printshop','padding-bottom','10',0,''),(359951,114638,'116599','printshop','background-color','$content-bg-1',0,''),(359952,114638,'116599','printshop','style_class','order-summary',0,''),(359953,114638,'116599','printshop','margin-left','25',0,''),(359954,114640,'116601','printshop','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(359955,114640,'116601','printshop','text-align','center',0,''),(359956,114640,'116601','printshop','font-size','14',0,''),(359957,114640,'116601','printshop','color','$fade-color-1',0,''),(359958,114640,'116601','printshop','padding-top','10',0,''),(359959,114641,'116602','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(359960,114642,'116603','printshop','margin-bottom','10',0,''),(359961,114644,'116604','printshop','block_type','2',0,''),(359962,114644,'116604','printshop','schema','2-2',0,'5411'),(359963,114645,'116605','printshop','block_type','1',0,''),(359964,114645,'116605','printshop','padding-left','0',0,'5342'),(359965,114645,'116605','printshop','padding-right','20',0,''),(359966,114647,'116607','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359967,114648,'116608','printshop','block_type','1',0,''),(359968,114648,'116608','printshop','padding-left','20',0,''),(359969,114648,'116608','printshop','padding-left','0',0,'5342'),(359970,114653,'116613','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359971,114654,'116614','printshop','block_type','4',0,''),(359972,114654,'116614','printshop','schema','4-2',0,'5363'),(359973,114654,'116614','printshop','padding-top','20',0,''),(359974,114655,'116615','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359975,114655,'116615','printshop','text-align','right',0,''),(359976,114655,'116615','printshop','padding-top','10',0,''),(359977,114655,'116615','printshop','font_size_measure','em',0,''),(359978,114655,'116615','printshop','font-size','1.2',0,''),(359979,114655,'116615','printshop','text-align','center',0,'5411'),(359980,114656,'116616','printshop','text-align','right',0,''),(359981,114656,'116616','printshop','text-align','center',0,'5411'),(359982,114657,'116617','printshop','block_type','2',0,''),(359983,114658,'116618','printshop','block_type','1',0,''),(359984,114658,'116618','printshop','padding-left','0',0,'5342'),(359985,114658,'116618','printshop','padding-right','20',0,''),(359986,114660,'116620','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359987,114661,'116621','printshop','block_type','1',0,''),(359988,114661,'116621','printshop','padding-left','20',0,''),(359989,114661,'116621','printshop','padding-left','0',0,'5342'),(359990,114663,'116623','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359991,114667,'116627','printshop','block_type','4',0,''),(359992,114667,'116627','printshop','schema','4-2',0,'5363'),(359993,114668,'116628','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359994,114668,'116628','printshop','text-align','right',0,''),(359995,114668,'116628','printshop','padding-top','10',0,''),(359996,114668,'116628','printshop','font_size_measure','em',0,''),(359997,114668,'116628','printshop','font-size','1.2',0,''),(359998,114669,'116629','printshop','text-align','right',0,''),(359999,114670,'116630','printshop','block_type','4',0,''),(360000,114670,'116630','printshop','schema','4-2',0,'5363'),(360001,114671,'116631','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(360002,114671,'116631','printshop','text-align','right',0,''),(360003,114671,'116631','printshop','padding-top','10',0,''),(360004,114671,'116631','printshop','font_size_measure','em',0,''),(360005,114671,'116631','printshop','font-size','1.2',0,''),(360006,114672,'116632','printshop','text-align','right',0,''),(360007,114673,'116633','printshop','block_type','2',0,''),(360008,114674,'116634','printshop','block_type','1',0,''),(360009,114674,'116634','printshop','padding-left','0',0,'5342'),(360010,114674,'116634','printshop','padding-right','20',0,''),(360011,114675,'116635','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360012,114677,'116637','printshop','block_type','1',0,''),(360013,114677,'116637','printshop','padding-left','20',0,''),(360014,114677,'116637','printshop','padding-left','0',0,'5342'),(360015,114682,'116642','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360016,114683,'116643','printshop','block_type','4',0,''),(360017,114683,'116643','printshop','schema','4-2',0,'5363'),(360018,114684,'116644','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(360019,114684,'116644','printshop','text-align','right',0,''),(360020,114684,'116644','printshop','padding-top','10',0,''),(360021,114684,'116644','printshop','font_size_measure','em',0,''),(360022,114684,'116644','printshop','font-size','1.2',0,''),(360023,114685,'116645','printshop','text-align','right',0,''),(360024,114686,'116646','printshop','block_type','2',0,''),(360025,114687,'116647','printshop','block_type','1',0,''),(360026,114687,'116647','printshop','padding-left','0',0,'5342'),(360027,114687,'116647','printshop','padding-right','20',0,''),(360028,114689,'116649','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360029,114690,'116650','printshop','block_type','1',0,''),(360030,114690,'116650','printshop','padding-left','20',0,''),(360031,114690,'116650','printshop','padding-left','0',0,'5342'),(360032,114694,'116654','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360033,114696,'116656','printshop','text','##PAYMENT_DETAILS##',0,''),(360034,114697,'116657','printshop','text','##PAYMENT_DETAILS##',0,''),(360035,114698,'116658','printshop','text','##PAYMENT_DETAILS##',0,''),(360036,114699,'116659','printshop','text','##PAYMENT_DETAILS##',0,''),(360037,114700,'116660','printshop','text','##PAYMENT_DETAILS##',0,''),(360038,114701,'116661','printshop','text','##PAYMENT_DETAILS##',0,''),(360039,114702,'120947','printshop','block_type','1',0,''),(360040,114702,'120947','printshop','background-color','$content-bg-2',0,''),(360041,114702,'120947','printshop','padding-top','30',0,''),(360042,114702,'120947','printshop','padding-bottom','30',0,''),(360043,114703,'120948','printshop','block_type','7',0,''),(360044,114703,'120948','printshop','schema','4-2',0,'5342'),(360045,114704,'120949','printshop','block_type','1',0,''),(360046,114704,'120949','printshop','padding-right','0',0,'5342'),(360047,114705,'120950','printshop','block_type','1',0,''),(360048,114705,'120950','printshop','background-color','$content-bg-1',0,''),(360049,114705,'120950','printshop','padding-top','30',0,''),(360050,114705,'120950','printshop','padding-left','30',0,''),(360051,114705,'120950','printshop','padding-right','30',0,''),(360052,114705,'120950','printshop','padding-bottom','30',0,''),(360053,114705,'120950','printshop','margin-bottom','20',0,''),(360054,114705,'120950','printshop','style_class','hiding-box',0,''),(360055,114706,'120951','printshop','padding-top','10',0,''),(360056,114706,'120951','printshop','padding-left','20',0,''),(360057,114706,'120951','printshop','padding-right','20',0,''),(360058,114706,'120951','printshop','margin-top','20',0,''),(360059,114706,'120951','printshop','background-color','$content-bg-2',0,''),(360060,114706,'120951','printshop','padding-bottom','8',0,''),(360061,114707,'120952','printshop','margin-bottom','20',0,''),(360062,114708,'120953','printshop','background-color','$content-bg-1',0,''),(360063,114708,'120953','printshop','block_type','1',0,''),(360064,114708,'120953','printshop','padding-top','30',0,''),(360065,114708,'120953','printshop','padding-left','30',0,''),(360066,114708,'120953','printshop','padding-right','30',0,''),(360067,114708,'120953','printshop','padding-bottom','30',0,''),(360068,114708,'120953','printshop','margin-bottom','20',0,''),(360069,114708,'120953','printshop','style_class','hiding-box',0,''),(360070,114709,'120954','printshop','block_type','1',0,''),(360071,114709,'120954','printshop','content','\\_',0,'3'),(360072,114709,'120954','printshop','border-top-width','1',0,'3'),(360073,114709,'120954','printshop','border-top-color','$content-border-3',0,'3'),(360074,114709,'120954','printshop','display','block',0,'3'),(360075,114709,'120954','printshop','position','absolute',0,'3'),(360076,114709,'120954','printshop','top','19',0,'3'),(360077,114709,'120954','printshop','left','0',0,'3'),(360078,114709,'120954','printshop','right','0',0,'3'),(360079,114709,'120954','printshop','margin-top','-2',0,'3'),(360080,114709,'120954','printshop','position','relative',0,''),(360081,114710,'120955','printshop','box_align','2',0,''),(360082,114710,'120955','printshop','margin-bottom','10',0,''),(360083,114710,'120955','printshop','background-color','$content-bg-1',0,''),(360084,114710,'120955','printshop','position','relative',0,''),(360085,114711,'120956','printshop','background-color','$content-bg-2',0,''),(360086,114711,'120956','printshop','padding-top','10',0,''),(360087,114711,'120956','printshop','padding-left','10',0,''),(360088,114711,'120956','printshop','padding-right','10',0,''),(360089,114711,'120956','printshop','padding-bottom','10',0,''),(360090,114711,'120956','printshop','margin-top','10',0,''),(360091,114712,'120957','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(360092,114713,'120958','printshop','block_type','2',0,''),(360093,114713,'120958','printshop','schema','2-2',0,'5342'),(360094,114714,'120959','printshop','block_type','1',0,''),(360095,114714,'120959','printshop','padding-right','20',0,''),(360096,114714,'120959','printshop','padding-left','0',0,'5342'),(360097,114714,'120959','printshop','margin-bottom','20',0,'5342'),(360098,114714,'120959','printshop','padding-right','0',0,'5342'),(360099,114717,'120962','printshop','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(360100,114718,'120963','printshop','block_type','1',0,''),(360101,114718,'120963','printshop','padding-left','20',0,''),(360102,114718,'120963','printshop','padding-left','0',0,'5342'),(360103,114720,'120965','printshop','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(360104,114721,'120966','printshop','border-top-width','1',0,''),(360105,114721,'120966','printshop','border-top-color','$content-border-3',0,''),(360106,114721,'120966','printshop','padding-top','13',0,''),(360107,114721,'120966','printshop','padding-bottom','10',0,''),(360108,114722,'120967','printshop','block_type','1',0,''),(360109,114722,'120967','printshop','background-color','$content-bg-1',0,''),(360110,114722,'120967','printshop','padding-top','30',0,''),(360111,114722,'120967','printshop','padding-left','30',0,''),(360112,114722,'120967','printshop','padding-right','30',0,''),(360113,114722,'120967','printshop','padding-bottom','14',0,''),(360114,114722,'120967','printshop','margin-bottom','20',0,''),(360115,114722,'120967','printshop','style_class','hiding-box closeable-box',0,''),(360116,114723,'120968','printshop','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(360117,114723,'120968','printshop','style_class','closeable-heading closeable-event closed',0,''),(360118,114724,'120969','printshop','style_class','closeable-content',0,''),(360119,114724,'120969','printshop','padding-bottom','20',0,''),(360120,114725,'120970','printshop','block_type','1',0,''),(360121,114725,'120970','printshop','padding-top','30',0,''),(360122,114725,'120970','printshop','padding-left','30',0,''),(360123,114725,'120970','printshop','padding-right','30',0,''),(360124,114725,'120970','printshop','padding-bottom','23',0,''),(360125,114725,'120970','printshop','margin-bottom','20',0,''),(360126,114725,'120970','printshop','background-color','$content-bg-1',0,''),(360127,114725,'120970','printshop','style_class','hiding-box',0,''),(360128,114726,'120971','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(360129,114727,'120972','printshop','block_type','2',0,''),(360130,114727,'120972','printshop','schema','2-2',0,'5342'),(360131,114728,'120973','printshop','padding-right','20',0,''),(360132,114728,'120973','printshop','padding-right','0',0,'5342'),(360133,114728,'120973','printshop','padding-bottom','20',0,'5342'),(360134,114729,'120974','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360135,114730,'120975','printshop','block_type','1',0,''),(360136,114730,'120975','printshop','padding-left','20',0,''),(360137,114730,'120975','printshop','padding-left','0',0,'5342'),(360138,114732,'120977','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360139,114733,'120978','printshop','block_type','1',0,''),(360140,114733,'120978','printshop','padding-left','10',0,''),(360141,114733,'120978','printshop','padding-right','10',0,''),(360142,114733,'120978','printshop','padding-bottom','10',0,''),(360143,114733,'120978','printshop','background-color','$content-bg-1',0,''),(360144,114733,'120978','printshop','style_class','order-summary',0,''),(360145,114733,'120978','printshop','margin-left','25',0,''),(360146,114733,'120978','printshop','margin-left','0',0,'5342'),(360147,114734,'120979','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360148,114735,'120980','printshop','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(360149,114735,'120980','printshop','text-align','center',0,''),(360150,114735,'120980','printshop','font-size','14',0,''),(360151,114735,'120980','printshop','color','$fade-color-1',0,''),(360152,114735,'120980','printshop','padding-top','10',0,''),(360153,114736,'120981','printshop','margin-bottom','10',0,''),(360154,114738,'120983','printshop','hide_continue_button','1',0,''),(360155,114739,'116699','printshop','block_type','1',0,''),(360156,114739,'116699','printshop','background-color','$content-bg-2',0,''),(360157,114739,'116699','printshop','padding-top','30',0,''),(360158,114739,'116699','printshop','padding-bottom','30',0,''),(360159,114740,'116700','printshop','block_type','7',0,''),(360160,114740,'116700','printshop','schema','7-2',0,'5342'),(360161,114741,'116701','printshop','block_type','1',0,''),(360162,114741,'116701','printshop','padding-right','0',0,'5342'),(360163,114742,'116703','printshop','block_type','1',0,''),(360164,114742,'116703','printshop','background-color','$content-bg-1',0,''),(360165,114742,'116703','printshop','padding-top','30',0,''),(360166,114742,'116703','printshop','padding-left','30',0,''),(360167,114742,'116703','printshop','padding-right','30',0,''),(360168,114742,'116703','printshop','padding-bottom','30',0,''),(360169,114742,'116703','printshop','margin-bottom','20',0,''),(360170,114742,'116703','printshop','style_class','hiding-box',0,''),(360171,114743,'116704','printshop','margin-bottom','20',0,''),(360172,114744,'116705','printshop','padding-top','10',0,''),(360173,114744,'116705','printshop','padding-left','20',0,''),(360174,114744,'116705','printshop','padding-right','20',0,''),(360175,114744,'116705','printshop','margin-top','20',0,''),(360176,114744,'116705','printshop','background-color','$content-bg-2',0,''),(360177,114744,'116705','printshop','padding-bottom','8',0,''),(360178,114745,'116706','printshop','background-color','$content-bg-1',0,''),(360179,114745,'116706','printshop','block_type','1',0,''),(360180,114745,'116706','printshop','padding-top','30',0,''),(360181,114745,'116706','printshop','padding-left','30',0,''),(360182,114745,'116706','printshop','padding-right','30',0,''),(360183,114745,'116706','printshop','padding-bottom','30',0,''),(360184,114745,'116706','printshop','margin-bottom','20',0,''),(360185,114745,'116706','printshop','style_class','hiding-box',0,''),(360186,114746,'116707','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(360187,114747,'116708','printshop','background-color','$content-bg-2',0,''),(360188,114747,'116708','printshop','padding-top','10',0,''),(360189,114747,'116708','printshop','padding-left','10',0,''),(360190,114747,'116708','printshop','padding-right','10',0,''),(360191,114747,'116708','printshop','padding-bottom','10',0,''),(360192,114747,'116708','printshop','margin-top','10',0,''),(360193,114748,'116709','printshop','block_type','1',0,''),(360194,114748,'116709','printshop','content','\\_',0,'3'),(360195,114748,'116709','printshop','border-top-width','1',0,'3'),(360196,114748,'116709','printshop','border-top-color','$content-border-3',0,'3'),(360197,114748,'116709','printshop','display','block',0,'3'),(360198,114748,'116709','printshop','position','absolute',0,'3'),(360199,114748,'116709','printshop','top','19',0,'3'),(360200,114748,'116709','printshop','left','0',0,'3'),(360201,114748,'116709','printshop','right','0',0,'3'),(360202,114748,'116709','printshop','margin-top','-2',0,'3'),(360203,114748,'116709','printshop','position','relative',0,''),(360204,114749,'116710','printshop','box_align','2',0,''),(360205,114749,'116710','printshop','margin-bottom','10',0,''),(360206,114749,'116710','printshop','background-color','$content-bg-1',0,''),(360207,114749,'116710','printshop','position','relative',0,''),(360208,114750,'116711','printshop','block_type','2',0,''),(360209,114750,'116711','printshop','schema','2-2',0,'5342'),(360210,114751,'116712','printshop','block_type','1',0,''),(360211,114751,'116712','printshop','padding-right','20',0,''),(360212,114751,'116712','printshop','padding-left','0',0,'5342'),(360213,114751,'116712','printshop','margin-bottom','20',0,'5342'),(360214,114751,'116712','printshop','padding-right','0',0,'5342'),(360215,114754,'116715','printshop','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(360216,114755,'116716','printshop','block_type','1',0,''),(360217,114755,'116716','printshop','padding-left','20',0,''),(360218,114755,'116716','printshop','padding-left','0',0,'5342'),(360219,114757,'116718','printshop','border-top-width','1',0,''),(360220,114757,'116718','printshop','border-top-color','$content-border-3',0,''),(360221,114757,'116718','printshop','padding-top','13',0,''),(360222,114757,'116718','printshop','padding-bottom','10',0,''),(360223,114758,'116719','printshop','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(360224,114759,'116720','printshop','block_type','1',0,''),(360225,114759,'116720','printshop','padding-top','30',0,''),(360226,114759,'116720','printshop','padding-left','30',0,''),(360227,114759,'116720','printshop','padding-right','30',0,''),(360228,114759,'116720','printshop','padding-bottom','23',0,''),(360229,114759,'116720','printshop','margin-bottom','20',0,''),(360230,114759,'116720','printshop','background-color','$content-bg-1',0,''),(360231,114759,'116720','printshop','style_class','hiding-box',0,''),(360232,114760,'116721','printshop','block_type','2',0,''),(360233,114760,'116721','printshop','schema','2-2',0,'5342'),(360234,114761,'116722','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360235,114762,'116723','printshop','padding-right','20',0,''),(360236,114762,'116723','printshop','padding-right','0',0,'5342'),(360237,114762,'116723','printshop','padding-bottom','20',0,'5342'),(360238,114763,'116724','printshop','block_type','1',0,''),(360239,114763,'116724','printshop','padding-left','20',0,''),(360240,114763,'116724','printshop','padding-left','0',0,'5342'),(360241,114764,'116725','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360242,114766,'116727','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(360243,114767,'116728','printshop','block_type','1',0,''),(360244,114767,'116728','printshop','background-color','$content-bg-1',0,''),(360245,114767,'116728','printshop','padding-top','30',0,''),(360246,114767,'116728','printshop','padding-left','30',0,''),(360247,114767,'116728','printshop','padding-right','30',0,''),(360248,114767,'116728','printshop','padding-bottom','14',0,''),(360249,114767,'116728','printshop','margin-bottom','20',0,''),(360250,114767,'116728','printshop','style_class','hiding-box closeable-box',0,''),(360251,114768,'116729','printshop','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(360252,114768,'116729','printshop','style_class','closeable-heading closeable-event closed',0,''),(360253,114769,'116730','printshop','style_class','closeable-content',0,''),(360254,114769,'116730','printshop','padding-bottom','20',0,''),(360255,114770,'116731','printshop','block_type','1',0,''),(360256,114770,'116731','printshop','padding-top','30',0,''),(360257,114770,'116731','printshop','padding-left','30',0,''),(360258,114770,'116731','printshop','padding-right','30',0,''),(360259,114770,'116731','printshop','padding-bottom','14',0,''),(360260,114770,'116731','printshop','margin-bottom','20',0,''),(360261,114770,'116731','printshop','background-color','$content-bg-1',0,''),(360262,114770,'116731','printshop','style_class','hiding-box closeable-box',0,''),(360263,114771,'116732','printshop','block_type','2',0,''),(360264,114771,'116732','printshop','style_class','closeable-content',0,''),(360265,114771,'116732','printshop','schema','2-2',0,'5342'),(360266,114772,'116733','printshop','padding-right','20',0,''),(360267,114772,'116733','printshop','padding-bottom','20',0,''),(360268,114772,'116733','printshop','padding-right','0',0,'5342'),(360269,114773,'116734','printshop','padding-left','20',0,''),(360270,114773,'116734','printshop','padding-bottom','20',0,''),(360271,114773,'116734','printshop','padding-left','0',0,'5342'),(360272,114774,'116735','printshop','padding-left','20',0,''),(360273,114774,'116735','printshop','padding-bottom','20',0,''),(360274,114774,'116735','printshop','padding-left','0',0,'5342'),(360275,114775,'116736','printshop','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(360276,114775,'116736','printshop','style_class','closeable-heading closeable-event closed',0,''),(360277,114776,'116737','printshop','block_type','1',0,''),(360278,114776,'116737','printshop','padding-top','20',0,''),(360279,114776,'116737','printshop','padding-left','20',0,''),(360280,114776,'116737','printshop','padding-right','20',0,''),(360281,114776,'116737','printshop','padding-bottom','20',0,''),(360282,114776,'116737','printshop','background-color','$content-bg-1',0,''),(360283,114776,'116737','printshop','style_class','order-summary',0,''),(360284,114776,'116737','printshop','margin-left','25',0,''),(360285,114776,'116737','printshop','padding-left','0',0,'5342'),(360286,114777,'116738','printshop','margin-bottom','10',0,''),(360287,114778,'116739','printshop','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(360288,114778,'116739','printshop','text-align','center',0,''),(360289,114778,'116739','printshop','font-size','14',0,''),(360290,114778,'116739','printshop','color','$fade-color-1',0,''),(360291,114778,'116739','printshop','padding-top','10',0,''),(360292,114779,'116740','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360293,114781,'120986','printshop','hide_continue_button','1',0,''),(360294,114782,'116742','printshop','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(360295,114787,'116747','printshop','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(360296,114788,'116749','printshop','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(360297,114789,'116750','printshop','style_class','order-summary',0,''),(360298,114789,'116750','printshop','box_align','3',0,''),(360299,114789,'116750','printshop','width','400',0,''),(360300,114791,'116748','printshop','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(360301,114794,'116754','printshop','block_type','1',0,''),(360302,114795,'116755','printshop','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(360303,114796,'116756','printshop','float','right',0,''),(360304,114796,'116756','printshop','position','relative',0,''),(360305,114796,'116756','printshop','z-index','1',0,''),(360306,114796,'116756','printshop','top','30',0,''),(360307,114796,'116756','printshop','margin-bottom','-10',0,''),(360308,114797,'116757','printshop','margin-bottom','30',0,''),(360309,114798,'116758','printshop','block_type','1',0,''),(360310,114799,'116759','printshop','listing_type','CompareProduct',0,''),(360311,114800,'117665.000001','printshop','block_type','1',0,''),(360312,114800,'117665.000001','printshop','style_class','item-holder',0,''),(360313,114800,'117665.000001','printshop','padding-top','25',0,''),(360314,114800,'117665.000001','printshop','padding-left','25',0,''),(360315,114800,'117665.000001','printshop','padding-right','25',0,''),(360316,114800,'117665.000001','printshop','padding-bottom','25',0,''),(360317,114800,'117665.000001','printshop','text-align','left',0,''),(360318,114801,'120921.000001','printshop','block_type','1',0,''),(360319,114801,'120921.000001','printshop','style_class','item-wrapper',0,''),(360320,114802,'120919.000001','printshop','block_type','1',0,''),(360321,114802,'120919.000001','printshop','style_class','item-content',0,''),(360322,114803,'1638872990.9609','printshop','block_type','5',0,''),(360323,114805,'117677.000001','printshop','float','right',0,''),(360324,114806,'117675.000001','printshop','clear','none',0,''),(360325,114807,'117676.000001','printshop','margin-bottom','10',0,''),(360326,114808,'1638873112.0384','printshop','block_type','2',0,''),(360327,114810,'117673.000001','printshop','margin-bottom','7',0,''),(360328,114810,'117673.000001','printshop','text-align','right',0,''),(360329,114811,'116760','printshop','block_type','1',0,''),(360330,114811,'116760','printshop','style_class','item-holder',0,''),(360331,114811,'116760','printshop','padding-top','10',0,''),(360332,114811,'116760','printshop','padding-left','20',0,''),(360333,114811,'116760','printshop','padding-right','20',0,''),(360334,114811,'116760','printshop','padding-bottom','10',0,''),(360335,114811,'116760','printshop','text-align','left',0,''),(360336,114814,'116763','printshop','margin-bottom','10',0,''),(360337,114815,'116764','printshop','block_type','5',0,''),(360338,114817,'116766','printshop','clear','both',0,''),(360339,114818,'116767','printshop','block_type','2',0,''),(360340,114819,'116768','printshop','margin-bottom','7',0,''),(360341,114820,'116769','printshop','text-align','right',0,''),(360342,114820,'116769','printshop','margin-bottom','10',0,''),(360343,114820,'116769','printshop','float','right',0,''),(360344,114821,'116770','printshop','block_type','1',0,''),(360345,114821,'116770','printshop','background-color','$content-bg-2',0,''),(360346,114821,'116770','printshop','padding-bottom','30',0,''),(360347,114821,'116770','printshop','style_class','checkout-order-confirmation',0,''),(360348,114821,'116770','printshop','color','$content-color-2',0,''),(360349,114822,'116771','printshop','block_type','4',0,''),(360350,114822,'116771','printshop','schema','4-2',0,'5342'),(360351,114823,'116772','printshop','block_type','1',0,''),(360352,114823,'116772','printshop','padding-right','40',0,''),(360353,114823,'116772','printshop','padding-right','0',0,'5342'),(360354,114823,'116772','printshop','padding-bottom','20',0,''),(360355,114824,'116773','printshop','block_type','1',0,''),(360356,114824,'116773','printshop','padding-right','30',0,''),(360357,114824,'116773','printshop','background-color','$content-bg-1',0,''),(360358,114824,'116773','printshop','padding-top','20',0,''),(360359,114824,'116773','printshop','padding-left','30',0,''),(360360,114824,'116773','printshop','padding-bottom','20',0,''),(360361,114824,'116773','printshop','padding-left','20',0,'5342'),(360362,114824,'116773','printshop','padding-right','20',0,'5342'),(360363,114824,'116773','printshop','color','$content-color-1',0,''),(360364,114825,'116774','printshop','link','products',0,''),(360365,114825,'116774','printshop','float','right',0,''),(360366,114825,'116774','printshop','margin-top','-37',0,''),(360367,114827,'116776','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(360368,114828,'116777','printshop','block_type','1',0,''),(360369,114828,'116777','printshop','background-color','$content-bg-1',0,''),(360370,114828,'116777','printshop','padding-top','20',0,''),(360371,114828,'116777','printshop','padding-bottom','20',0,''),(360372,114828,'116777','printshop','padding-left','30',0,''),(360373,114828,'116777','printshop','padding-right','30',0,''),(360374,114828,'116777','printshop','margin-bottom','20',0,''),(360375,114828,'116777','printshop','color','$content-color-1',0,''),(360376,114829,'116778','printshop','float','right',0,''),(360377,114829,'116778','printshop','margin-top','-37',0,''),(360378,114829,'116778','printshop','link','comments',0,''),(360379,114830,'116779','printshop','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(360380,114831,'116780','printshop','hide_parents','2',0,''),(360381,114832,'116781','printshop','block_type','2',0,''),(360382,114832,'116781','printshop','margin-bottom','20',0,''),(360383,114832,'116781','printshop','schema','2-2',0,'5333'),(360384,114832,'116781','printshop','background-color','$content-bg-1',0,''),(360385,114832,'116781','printshop','color','$content-color-1',0,''),(360386,114833,'116782','printshop','block_type','1',0,''),(360387,114833,'116782','printshop','border-right-width','20',0,''),(360388,114833,'116782','printshop','border-right-color','$content-bg-2',0,''),(360389,114833,'116782','printshop','margin-right','-10',0,''),(360390,114833,'116782','printshop','padding-right','30',0,''),(360391,114833,'116782','printshop','padding-top','20',0,''),(360392,114833,'116782','printshop','padding-left','30',0,''),(360393,114833,'116782','printshop','padding-bottom','20',0,''),(360394,114833,'116782','printshop','border-right-width','0',0,'5342'),(360395,114833,'116782','printshop','margin-right','0',0,'5342'),(360396,114833,'116782','printshop','margin-bottom','20',0,'5342'),(360397,114833,'116782','printshop','padding-left','20',0,'5342'),(360398,114833,'116782','printshop','padding-right','20',0,'5342'),(360399,114833,'116782','printshop','margin-bottom','0',0,'5333'),(360400,114834,'116783','printshop','link','shipping_method',0,''),(360401,114834,'116783','printshop','float','right',0,''),(360402,114834,'116783','printshop','margin-top','-31',0,''),(360403,114836,'116785','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(360404,114836,'116785','printshop','padding-top','20',0,''),(360405,114837,'116786','printshop','link','contact_information',0,''),(360406,114837,'116786','printshop','margin-top','-31',0,''),(360407,114837,'116786','printshop','float','right',0,''),(360408,114838,'116787','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(360409,114838,'116787','printshop','clear','none',0,''),(360410,114840,'116789','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(360411,114841,'116790','printshop','link','shipping_address',0,''),(360412,114841,'116790','printshop','float','right',0,''),(360413,114841,'116790','printshop','margin-top','-31',0,''),(360414,114843,'116792','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(360415,114843,'116792','printshop','clear','none',0,''),(360416,114844,'116793','printshop','margin-bottom','20',0,''),(360417,114845,'116794','printshop','block_type','1',0,''),(360418,114845,'116794','printshop','padding-left','30',0,''),(360419,114845,'116794','printshop','border-left-width','20',0,''),(360420,114845,'116794','printshop','border-left-color','$content-bg-2',0,''),(360421,114845,'116794','printshop','margin-left','-10',0,''),(360422,114845,'116794','printshop','padding-right','30',0,''),(360423,114845,'116794','printshop','padding-top','20',0,''),(360424,114845,'116794','printshop','padding-bottom','20',0,''),(360425,114845,'116794','printshop','border-left-width','0',0,'5342'),(360426,114845,'116794','printshop','margin-left','0',0,'5342'),(360427,114845,'116794','printshop','padding-right','20',0,'5342'),(360428,114845,'116794','printshop','padding-left','20',0,'5342'),(360429,114846,'116795','printshop','link','payment_method',0,''),(360430,114846,'116795','printshop','float','right',0,''),(360431,114846,'116795','printshop','margin-top','-31',0,''),(360432,114847,'116796','printshop','link','billing_address',0,''),(360433,114847,'116796','printshop','float','right',0,''),(360434,114847,'116796','printshop','margin-top','-31',0,''),(360435,114849,'116798','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360436,114849,'116798','printshop','clear','none',0,''),(360437,114850,'116799','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(360438,114851,'116800','printshop','margin-bottom','20',0,''),(360439,114852,'116801','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360440,114852,'116801','printshop','clear','none',0,''),(360441,114854,'116803','printshop','block_type','1',0,''),(360442,114854,'116803','printshop','padding-top','10',0,''),(360443,114854,'116803','printshop','padding-left','20',0,''),(360444,114854,'116803','printshop','padding-right','20',0,''),(360445,114854,'116803','printshop','padding-bottom','10',0,''),(360446,114854,'116803','printshop','background-color','$content-bg-1',0,''),(360447,114854,'116803','printshop','style_class','order-summary hiding-box',0,''),(360448,114854,'116803','printshop','color','$content-color-1',0,''),(360449,114855,'116804','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360450,114856,'116805','printshop','margin-bottom','20',0,''),(360451,114856,'116805','printshop','text-align','right',0,''),(360452,114858,'116807','printshop','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(360453,114859,'116808','printshop','block_type','1',0,''),(360454,114859,'116808','printshop','background-color','$content-bg-2',0,''),(360455,114859,'116808','printshop','padding-bottom','30',0,''),(360456,114860,'116809','printshop','block_type','4',0,''),(360457,114860,'116809','printshop','schema','4-2',0,'5342'),(360458,114861,'116810','printshop','block_type','1',0,''),(360459,114861,'116810','printshop','padding-right','40',0,''),(360460,114861,'116810','printshop','padding-right','0',0,'5342'),(360461,114862,'116811','printshop','block_type','1',0,''),(360462,114862,'116811','printshop','background-color','$content-bg-1',0,''),(360463,114862,'116811','printshop','padding-top','20',0,''),(360464,114862,'116811','printshop','padding-bottom','20',0,''),(360465,114862,'116811','printshop','padding-left','30',0,''),(360466,114862,'116811','printshop','padding-right','30',0,''),(360467,114862,'116811','printshop','margin-bottom','20',0,''),(360468,114863,'116812','printshop','hide_parents','2',0,''),(360469,114864,'116813','printshop','float','right',0,''),(360470,114864,'116813','printshop','margin-top','-37',0,''),(360471,114864,'116813','printshop','link','comments',0,''),(360472,114865,'116814','printshop','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(360473,114866,'116815','printshop','block_type','1',0,''),(360474,114866,'116815','printshop','padding-right','30',0,''),(360475,114866,'116815','printshop','background-color','$content-bg-1',0,''),(360476,114866,'116815','printshop','padding-top','20',0,''),(360477,114866,'116815','printshop','padding-left','30',0,''),(360478,114866,'116815','printshop','padding-bottom','20',0,''),(360479,114866,'116815','printshop','padding-left','20',0,'5342'),(360480,114866,'116815','printshop','padding-right','20',0,'5342'),(360481,114867,'116816','printshop','link','products',0,''),(360482,114867,'116816','printshop','float','right',0,''),(360483,114867,'116816','printshop','margin-top','-37',0,''),(360484,114868,'116817','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(360485,114870,'116819','printshop','block_type','2',0,''),(360486,114870,'116819','printshop','margin-bottom','20',0,''),(360487,114870,'116819','printshop','schema','2-2',0,'5333'),(360488,114870,'116819','printshop','background-color','$content-bg-1',0,''),(360489,114871,'116820','printshop','block_type','1',0,''),(360490,114871,'116820','printshop','border-right-width','20',0,''),(360491,114871,'116820','printshop','border-right-color','$content-border-3',0,''),(360492,114871,'116820','printshop','margin-right','-10',0,''),(360493,114871,'116820','printshop','padding-right','30',0,''),(360494,114871,'116820','printshop','padding-top','20',0,''),(360495,114871,'116820','printshop','padding-left','30',0,''),(360496,114871,'116820','printshop','padding-bottom','20',0,''),(360497,114871,'116820','printshop','border-right-width','0',0,'5342'),(360498,114871,'116820','printshop','margin-right','0',0,'5342'),(360499,114871,'116820','printshop','margin-bottom','20',0,'5342'),(360500,114871,'116820','printshop','padding-left','20',0,'5342'),(360501,114871,'116820','printshop','padding-right','20',0,'5342'),(360502,114872,'116821','printshop','link','shipping_address',0,''),(360503,114872,'116821','printshop','float','right',0,''),(360504,114872,'116821','printshop','margin-top','-31',0,''),(360505,114874,'116823','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(360506,114874,'116823','printshop','clear','none',0,''),(360507,114875,'116824','printshop','link','shipping_method',0,''),(360508,114875,'116824','printshop','float','right',0,''),(360509,114875,'116824','printshop','margin-top','-31',0,''),(360510,114876,'116825','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(360511,114876,'116825','printshop','clear','none',0,''),(360512,114877,'116826','printshop','margin-bottom','20',0,''),(360513,114878,'116827','printshop','block_type','1',0,''),(360514,114878,'116827','printshop','padding-left','30',0,''),(360515,114878,'116827','printshop','border-left-width','20',0,''),(360516,114878,'116827','printshop','border-left-color','$content-border-3',0,''),(360517,114878,'116827','printshop','margin-left','-10',0,''),(360518,114878,'116827','printshop','padding-right','30',0,''),(360519,114878,'116827','printshop','padding-top','20',0,''),(360520,114878,'116827','printshop','padding-bottom','20',0,''),(360521,114878,'116827','printshop','border-left-width','0',0,'5342'),(360522,114881,'116830','printshop','link','contact_information',0,''),(360523,114881,'116830','printshop','margin-top','-31',0,''),(360524,114881,'116830','printshop','float','right',0,''),(360525,114882,'116831','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(360526,114883,'116832','printshop','block_type','1',0,''),(360527,114883,'116832','printshop','padding-top','20',0,''),(360528,114883,'116832','printshop','padding-left','20',0,''),(360529,114883,'116832','printshop','padding-right','20',0,''),(360530,114883,'116832','printshop','padding-bottom','20',0,''),(360531,114883,'116832','printshop','background-color','$content-bg-1',0,''),(360532,114883,'116832','printshop','style_class','order-summary',0,''),(360533,114884,'116833','printshop','margin-bottom','20',0,''),(360534,114884,'116833','printshop','text-align','right',0,''),(360535,114885,'116834','printshop','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(360536,114886,'116835','printshop','block_type','1',0,''),(360537,114886,'116835','printshop','background-color','$content-bg-2',0,''),(360538,114886,'116835','printshop','padding-bottom','30',0,''),(360539,114886,'116835','printshop','color','$content-color-2',0,''),(360540,114887,'116836','printshop','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(360541,114888,'116837','printshop','block_type','4',0,''),(360542,114889,'116838','printshop','block_type','1',0,''),(360543,114889,'116838','printshop','padding-right','40',0,''),(360544,114890,'116839','printshop','block_type','2',0,''),(360545,114890,'116839','printshop','margin-bottom','20',0,''),(360546,114890,'116839','printshop','schema','2-2',0,'5333'),(360547,114890,'116839','printshop','background-color','$content-bg-1',0,''),(360548,114890,'116839','printshop','color','$content-color-1',0,''),(360549,114891,'116840','printshop','block_type','1',0,''),(360550,114891,'116840','printshop','padding-right','0',0,'5333'),(360551,114891,'116840','printshop','border-right-width','20',0,''),(360552,114891,'116840','printshop','border-right-color','$content-bg-2',0,''),(360553,114891,'116840','printshop','margin-right','-10',0,''),(360554,114891,'116840','printshop','padding-right','30',0,''),(360555,114891,'116840','printshop','padding-top','20',0,''),(360556,114891,'116840','printshop','padding-left','30',0,''),(360557,114891,'116840','printshop','padding-bottom','20',0,''),(360558,114892,'116841','printshop','link','contact_information',0,''),(360559,114892,'116841','printshop','float','right',0,''),(360560,114893,'116842','printshop','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(360561,114895,'116844','printshop','block_type','1',0,''),(360562,114895,'116844','printshop','padding-left','30',0,''),(360563,114895,'116844','printshop','padding-left','0',0,'5333'),(360564,114895,'116844','printshop','border-left-width','20',0,''),(360565,114895,'116844','printshop','border-left-color','$content-bg-2',0,''),(360566,114895,'116844','printshop','margin-left','-10',0,''),(360567,114895,'116844','printshop','padding-right','30',0,''),(360568,114895,'116844','printshop','padding-top','20',0,''),(360569,114895,'116844','printshop','padding-bottom','20',0,''),(360570,114897,'116846','printshop','link','payment_method',0,''),(360571,114897,'116846','printshop','float','right',0,''),(360572,114897,'116846','printshop','margin-top','-31',0,''),(360573,114898,'116847','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360574,114898,'116847','printshop','clear','none',0,''),(360575,114899,'116848','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(360576,114900,'116849','printshop','link','billing_address',0,''),(360577,114900,'116849','printshop','float','right',0,''),(360578,114900,'116849','printshop','margin-top','-31',0,''),(360579,114901,'116850','printshop','margin-bottom','20',0,''),(360580,114902,'116851','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360581,114902,'116851','printshop','clear','none',0,''),(360582,114903,'116852','printshop','block_type','1',0,''),(360583,114903,'116852','printshop','background-color','$content-bg-1',0,''),(360584,114903,'116852','printshop','padding-top','20',0,''),(360585,114903,'116852','printshop','padding-bottom','20',0,''),(360586,114903,'116852','printshop','padding-left','30',0,''),(360587,114903,'116852','printshop','padding-right','30',0,''),(360588,114903,'116852','printshop','margin-bottom','20',0,''),(360589,114903,'116852','printshop','color','$content-color-1',0,''),(360590,114904,'116853','printshop','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(360591,114905,'116854','printshop','hide_parents','2',0,''),(360592,114906,'116855','printshop','float','right',0,''),(360593,114906,'116855','printshop','margin-top','-37',0,''),(360594,114906,'116855','printshop','link','comments',0,''),(360595,114907,'116856','printshop','block_type','1',0,''),(360596,114907,'116856','printshop','padding-right','30',0,''),(360597,114907,'116856','printshop','padding-right','0',0,'5333'),(360598,114907,'116856','printshop','background-color','$content-bg-1',0,''),(360599,114907,'116856','printshop','padding-top','20',0,''),(360600,114907,'116856','printshop','padding-left','30',0,''),(360601,114907,'116856','printshop','padding-bottom','20',0,''),(360602,114907,'116856','printshop','color','$content-color-1',0,''),(360603,114908,'116857','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(360604,114909,'116858','printshop','link','products',0,''),(360605,114909,'116858','printshop','float','right',0,''),(360606,114909,'116858','printshop','margin-top','-37',0,''),(360607,114911,'116860','printshop','block_type','1',0,''),(360608,114911,'116860','printshop','padding-top','20',0,''),(360609,114911,'116860','printshop','padding-left','20',0,''),(360610,114911,'116860','printshop','padding-right','20',0,''),(360611,114911,'116860','printshop','padding-bottom','20',0,''),(360612,114911,'116860','printshop','background-color','$content-bg-1',0,''),(360613,114911,'116860','printshop','style_class','order-summary2 hiding-box',0,''),(360614,114911,'116860','printshop','color','$content-bg-1',0,''),(360615,114912,'116861','printshop','margin-bottom','20',0,''),(360616,114912,'116861','printshop','text-align','right',0,''),(360617,114913,'116862','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360618,114915,'116864','printshop','block_type','1',0,''),(360619,114915,'116864','printshop','background-color','$content-bg-2',0,''),(360620,114915,'116864','printshop','padding-bottom','30',0,''),(360621,114916,'116865','printshop','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(360622,114917,'116866','printshop','block_type','4',0,''),(360623,114917,'116866','printshop','schema','4-2',0,'5342'),(360624,114918,'116867','printshop','block_type','1',0,''),(360625,114918,'116867','printshop','padding-right','40',0,''),(360626,114918,'116867','printshop','padding-right','0',0,'5342'),(360627,114919,'116868','printshop','block_type','1',0,''),(360628,114919,'116868','printshop','background-color','$content-bg-1',0,''),(360629,114919,'116868','printshop','padding-top','20',0,''),(360630,114919,'116868','printshop','padding-bottom','20',0,''),(360631,114919,'116868','printshop','padding-left','30',0,''),(360632,114919,'116868','printshop','padding-right','30',0,''),(360633,114919,'116868','printshop','margin-bottom','20',0,''),(360634,114920,'116869','printshop','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(360635,114921,'116870','printshop','hide_parents','2',0,''),(360636,114922,'116871','printshop','float','right',0,''),(360637,114922,'116871','printshop','margin-top','-37',0,''),(360638,114922,'116871','printshop','link','comments',0,''),(360639,114923,'116872','printshop','block_type','2',0,''),(360640,114923,'116872','printshop','margin-bottom','20',0,''),(360641,114923,'116872','printshop','schema','2-2',0,'5333'),(360642,114923,'116872','printshop','background-color','$content-bg-1',0,''),(360643,114924,'116873','printshop','block_type','1',0,''),(360644,114924,'116873','printshop','border-right-width','20',0,''),(360645,114924,'116873','printshop','border-right-color','$content-border-3',0,''),(360646,114924,'116873','printshop','margin-right','-10',0,''),(360647,114924,'116873','printshop','padding-right','30',0,''),(360648,114924,'116873','printshop','padding-top','20',0,''),(360649,114924,'116873','printshop','padding-left','30',0,''),(360650,114924,'116873','printshop','padding-bottom','20',0,''),(360651,114924,'116873','printshop','border-right-width','0',0,'5342'),(360652,114924,'116873','printshop','margin-right','0',0,'5342'),(360653,114924,'116873','printshop','margin-bottom','20',0,'5342'),(360654,114924,'116873','printshop','padding-left','20',0,'5342'),(360655,114924,'116873','printshop','padding-right','20',0,'5342'),(360656,114925,'116874','printshop','link','contact_information',0,''),(360657,114925,'116874','printshop','margin-top','-31',0,''),(360658,114925,'116874','printshop','float','right',0,''),(360659,114928,'116877','printshop','link','payment_method',0,''),(360660,114928,'116877','printshop','float','right',0,''),(360661,114928,'116877','printshop','margin-top','-31',0,''),(360662,114929,'116878','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(360663,114929,'116878','printshop','padding-top','20',0,''),(360664,114930,'116879','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360665,114930,'116879','printshop','clear','none',0,''),(360666,114931,'116880','printshop','block_type','1',0,''),(360667,114931,'116880','printshop','padding-left','30',0,''),(360668,114931,'116880','printshop','border-left-width','20',0,''),(360669,114931,'116880','printshop','border-left-color','$content-border-3',0,''),(360670,114931,'116880','printshop','margin-left','-10',0,''),(360671,114931,'116880','printshop','padding-right','30',0,''),(360672,114931,'116880','printshop','padding-top','20',0,''),(360673,114931,'116880','printshop','padding-bottom','20',0,''),(360674,114931,'116880','printshop','border-left-width','0',0,'5342'),(360675,114932,'116881','printshop','margin-bottom','20',0,''),(360676,114933,'116882','printshop','link','billing_address',0,''),(360677,114933,'116882','printshop','float','right',0,''),(360678,114933,'116882','printshop','margin-top','-31',0,''),(360679,114934,'116883','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360680,114934,'116883','printshop','clear','none',0,''),(360681,114935,'116884','printshop','block_type','1',0,''),(360682,114935,'116884','printshop','padding-right','30',0,''),(360683,114935,'116884','printshop','background-color','$content-bg-1',0,''),(360684,114935,'116884','printshop','padding-top','20',0,''),(360685,114935,'116884','printshop','padding-left','30',0,''),(360686,114935,'116884','printshop','padding-bottom','20',0,''),(360687,114935,'116884','printshop','padding-left','20',0,'5342'),(360688,114935,'116884','printshop','padding-right','20',0,'5342'),(360689,114936,'116885','printshop','link','products',0,''),(360690,114936,'116885','printshop','float','right',0,''),(360691,114936,'116885','printshop','margin-top','-37',0,''),(360692,114937,'116886','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(360693,114938,'116887','printshop','margin-bottom','20',0,''),(360694,114939,'116888','printshop','block_type','1',0,''),(360695,114939,'116888','printshop','padding-top','20',0,''),(360696,114939,'116888','printshop','padding-left','20',0,''),(360697,114939,'116888','printshop','padding-right','20',0,''),(360698,114939,'116888','printshop','padding-bottom','20',0,''),(360699,114939,'116888','printshop','background-color','$content-bg-1',0,''),(360700,114939,'116888','printshop','style_class','order-summary',0,''),(360701,114940,'116889','printshop','margin-bottom','20',0,''),(360702,114940,'116889','printshop','text-align','right',0,''),(360703,114942,'116891','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360704,114943,'116892','printshop','block_type','1',0,''),(360705,114943,'116892','printshop','background-color','$content-bg-2',0,''),(360706,114943,'116892','printshop','padding-bottom','30',0,''),(360707,114944,'116893','printshop','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(360708,114945,'116894','printshop','block_type','4',0,''),(360709,114945,'116894','printshop','schema','4-2',0,'5342'),(360710,114946,'116895','printshop','block_type','1',0,''),(360711,114946,'116895','printshop','padding-right','40',0,''),(360712,114946,'116895','printshop','padding-right','0',0,'5342'),(360713,114947,'116896','printshop','block_type','1',0,''),(360714,114947,'116896','printshop','padding-right','30',0,''),(360715,114947,'116896','printshop','background-color','$content-bg-1',0,''),(360716,114947,'116896','printshop','padding-top','20',0,''),(360717,114947,'116896','printshop','padding-left','30',0,''),(360718,114947,'116896','printshop','padding-bottom','20',0,''),(360719,114947,'116896','printshop','padding-left','20',0,'5342'),(360720,114947,'116896','printshop','padding-right','20',0,'5342'),(360721,114949,'116898','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(360722,114950,'116899','printshop','link','products',0,''),(360723,114950,'116899','printshop','float','right',0,''),(360724,114950,'116899','printshop','margin-top','-37',0,''),(360725,114951,'116900','printshop','block_type','2',0,''),(360726,114951,'116900','printshop','margin-bottom','20',0,''),(360727,114951,'116900','printshop','schema','2-2',0,'5333'),(360728,114951,'116900','printshop','background-color','$content-bg-1',0,''),(360729,114952,'116901','printshop','block_type','1',0,''),(360730,114952,'116901','printshop','border-right-width','20',0,''),(360731,114952,'116901','printshop','border-right-color','$content-border-3',0,''),(360732,114952,'116901','printshop','margin-right','-10',0,''),(360733,114952,'116901','printshop','padding-right','30',0,''),(360734,114952,'116901','printshop','padding-top','20',0,''),(360735,114952,'116901','printshop','padding-left','30',0,''),(360736,114952,'116901','printshop','padding-bottom','20',0,''),(360737,114952,'116901','printshop','border-right-width','0',0,'5342'),(360738,114952,'116901','printshop','margin-right','0',0,'5342'),(360739,114952,'116901','printshop','margin-bottom','20',0,'5342'),(360740,114952,'116901','printshop','padding-left','20',0,'5342'),(360741,114952,'116901','printshop','padding-right','20',0,'5342'),(360742,114953,'116902','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(360743,114954,'116903','printshop','link','contact_information',0,''),(360744,114954,'116903','printshop','margin-top','-31',0,''),(360745,114954,'116903','printshop','float','right',0,''),(360746,114955,'116904','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(360747,114955,'116904','printshop','clear','none',0,''),(360748,114957,'116906','printshop','margin-bottom','20',0,''),(360749,114959,'116908','printshop','link','shipping_address',0,''),(360750,114959,'116908','printshop','float','right',0,''),(360751,114959,'116908','printshop','margin-top','-31',0,''),(360752,114961,'116910','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(360753,114961,'116910','printshop','padding-top','20',0,''),(360754,114962,'116911','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(360755,114962,'116911','printshop','clear','none',0,''),(360756,114963,'116912','printshop','link','shipping_method',0,''),(360757,114963,'116912','printshop','float','right',0,''),(360758,114963,'116912','printshop','margin-top','-31',0,''),(360759,114964,'116913','printshop','block_type','1',0,''),(360760,114964,'116913','printshop','padding-left','30',0,''),(360761,114964,'116913','printshop','border-left-width','20',0,''),(360762,114964,'116913','printshop','border-left-color','$content-border-3',0,''),(360763,114964,'116913','printshop','margin-left','-10',0,''),(360764,114964,'116913','printshop','padding-right','30',0,''),(360765,114964,'116913','printshop','padding-top','20',0,''),(360766,114964,'116913','printshop','padding-bottom','20',0,''),(360767,114964,'116913','printshop','border-left-width','0',0,'5342'),(360768,114965,'116914','printshop','link','billing_address',0,''),(360769,114965,'116914','printshop','float','right',0,''),(360770,114965,'116914','printshop','margin-top','-31',0,''),(360771,114966,'116915','printshop','margin-bottom','20',0,''),(360772,114968,'116917','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(360773,114969,'116918','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360774,114969,'116918','printshop','clear','none',0,''),(360775,114970,'116919','printshop','link','payment_method',0,''),(360776,114970,'116919','printshop','float','right',0,''),(360777,114970,'116919','printshop','margin-top','-31',0,''),(360778,114971,'116920','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360779,114971,'116920','printshop','clear','none',0,''),(360780,114972,'116921','printshop','block_type','1',0,''),(360781,114972,'116921','printshop','background-color','$content-bg-1',0,''),(360782,114972,'116921','printshop','padding-top','20',0,''),(360783,114972,'116921','printshop','padding-bottom','20',0,''),(360784,114972,'116921','printshop','padding-left','30',0,''),(360785,114972,'116921','printshop','padding-right','30',0,''),(360786,114972,'116921','printshop','margin-bottom','20',0,''),(360787,114973,'116922','printshop','hide_parents','2',0,''),(360788,114974,'116923','printshop','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(360789,114975,'116924','printshop','float','right',0,''),(360790,114975,'116924','printshop','margin-top','-37',0,''),(360791,114975,'116924','printshop','link','comments',0,''),(360792,114976,'116925','printshop','block_type','1',0,''),(360793,114976,'116925','printshop','padding-top','20',0,''),(360794,114976,'116925','printshop','padding-left','20',0,''),(360795,114976,'116925','printshop','padding-right','20',0,''),(360796,114976,'116925','printshop','padding-bottom','20',0,''),(360797,114976,'116925','printshop','background-color','$content-bg-1',0,''),(360798,114976,'116925','printshop','style_class','order-summary',0,''),(360799,114977,'116926','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360800,114979,'116928','printshop','margin-bottom','20',0,''),(360801,114979,'116928','printshop','text-align','right',0,''),(360802,114980,'116929','printshop','block_type','1',0,''),(360803,114980,'116929','printshop','background-color','$content-bg-2',0,''),(360804,114980,'116929','printshop','padding-bottom','30',0,''),(360805,114981,'116930','printshop','block_type','4',0,''),(360806,114981,'116930','printshop','schema','4-2',0,'5342'),(360807,114982,'116931','printshop','block_type','1',0,''),(360808,114982,'116931','printshop','padding-right','40',0,''),(360809,114982,'116931','printshop','padding-right','0',0,'5342'),(360810,114983,'116932','printshop','block_type','2',0,''),(360811,114983,'116932','printshop','margin-bottom','20',0,''),(360812,114983,'116932','printshop','schema','2-2',0,'5333'),(360813,114983,'116932','printshop','background-color','$content-bg-1',0,''),(360814,114984,'116933','printshop','block_type','1',0,''),(360815,114984,'116933','printshop','border-right-width','20',0,''),(360816,114984,'116933','printshop','border-right-color','$content-border-3',0,''),(360817,114984,'116933','printshop','margin-right','-10',0,''),(360818,114984,'116933','printshop','padding-right','30',0,''),(360819,114984,'116933','printshop','padding-top','20',0,''),(360820,114984,'116933','printshop','padding-left','30',0,''),(360821,114984,'116933','printshop','padding-bottom','20',0,''),(360822,114984,'116933','printshop','border-right-width','0',0,'5342'),(360823,114984,'116933','printshop','margin-right','0',0,'5342'),(360824,114984,'116933','printshop','margin-bottom','20',0,'5342'),(360825,114984,'116933','printshop','padding-left','20',0,'5342'),(360826,114984,'116933','printshop','padding-right','20',0,'5342'),(360827,114985,'116934','printshop','margin-bottom','20',0,''),(360828,114986,'116935','printshop','link','shipping_address',0,''),(360829,114986,'116935','printshop','float','right',0,''),(360830,114986,'116935','printshop','margin-top','-31',0,''),(360831,114987,'116936','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(360832,114987,'116936','printshop','clear','none',0,''),(360833,114990,'116939','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(360834,114991,'116940','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(360835,114991,'116940','printshop','clear','none',0,''),(360836,114992,'116941','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(360837,114992,'116941','printshop','padding-top','20',0,''),(360838,114994,'116943','printshop','link','shipping_method',0,''),(360839,114994,'116943','printshop','float','right',0,''),(360840,114994,'116943','printshop','margin-top','-31',0,''),(360841,114995,'116944','printshop','link','contact_information',0,''),(360842,114995,'116944','printshop','margin-top','-31',0,''),(360843,114995,'116944','printshop','float','right',0,''),(360844,114996,'116945','printshop','block_type','1',0,''),(360845,114996,'116945','printshop','padding-left','30',0,''),(360846,114996,'116945','printshop','border-left-width','20',0,''),(360847,114996,'116945','printshop','border-left-color','$content-border-3',0,''),(360848,114996,'116945','printshop','margin-left','-10',0,''),(360849,114996,'116945','printshop','padding-right','30',0,''),(360850,114996,'116945','printshop','padding-top','20',0,''),(360851,114996,'116945','printshop','padding-bottom','20',0,''),(360852,114996,'116945','printshop','border-left-width','0',0,'5342'),(360853,114997,'116946','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360854,114997,'116946','printshop','clear','none',0,''),(360855,114998,'116947','printshop','margin-bottom','20',0,''),(360856,114999,'116948','printshop','link','billing_address',0,''),(360857,114999,'116948','printshop','float','right',0,''),(360858,114999,'116948','printshop','margin-top','-31',0,''),(360859,115001,'116950','printshop','link','payment_method',0,''),(360860,115001,'116950','printshop','float','right',0,''),(360861,115001,'116950','printshop','margin-top','-31',0,''),(360862,115002,'116951','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(360863,115003,'116952','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360864,115003,'116952','printshop','clear','none',0,''),(360865,115004,'116953','printshop','block_type','1',0,''),(360866,115004,'116953','printshop','padding-right','30',0,''),(360867,115004,'116953','printshop','background-color','$content-bg-1',0,''),(360868,115004,'116953','printshop','padding-top','20',0,''),(360869,115004,'116953','printshop','padding-left','30',0,''),(360870,115004,'116953','printshop','padding-bottom','20',0,''),(360871,115004,'116953','printshop','padding-left','20',0,'5342'),(360872,115004,'116953','printshop','padding-right','20',0,'5342'),(360873,115005,'116954','printshop','link','products',0,''),(360874,115005,'116954','printshop','float','right',0,''),(360875,115005,'116954','printshop','margin-top','-37',0,''),(360876,115006,'116955','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(360877,115008,'116957','printshop','block_type','1',0,''),(360878,115008,'116957','printshop','background-color','$content-bg-1',0,''),(360879,115008,'116957','printshop','padding-top','20',0,''),(360880,115008,'116957','printshop','padding-bottom','20',0,''),(360881,115008,'116957','printshop','padding-left','30',0,''),(360882,115008,'116957','printshop','padding-right','30',0,''),(360883,115008,'116957','printshop','margin-bottom','20',0,''),(360884,115009,'116958','printshop','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(360885,115010,'116959','printshop','float','right',0,''),(360886,115010,'116959','printshop','margin-top','-37',0,''),(360887,115010,'116959','printshop','link','comments',0,''),(360888,115011,'116960','printshop','hide_parents','2',0,''),(360889,115012,'116961','printshop','block_type','1',0,''),(360890,115012,'116961','printshop','padding-top','20',0,''),(360891,115012,'116961','printshop','padding-left','20',0,''),(360892,115012,'116961','printshop','padding-right','20',0,''),(360893,115012,'116961','printshop','padding-bottom','20',0,''),(360894,115012,'116961','printshop','background-color','$content-bg-1',0,''),(360895,115012,'116961','printshop','style_class','order-summary',0,''),(360896,115014,'116963','printshop','margin-bottom','20',0,''),(360897,115014,'116963','printshop','text-align','right',0,''),(360898,115015,'116964','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360899,115016,'116965','printshop','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(360900,115017,'116966','printshop','block_type','1',0,''),(360901,115019,'116968','printshop','block_type','2',0,''),(360902,115019,'116968','printshop','font-weight','400',0,''),(360903,115019,'116968','printshop','padding-bottom','20',0,''),(360904,115019,'116968','printshop','schema','2-2',0,'5342'),(360905,115020,'116969','printshop','show_captcha','on',0,''),(360906,115021,'116970','printshop','font-weight','400',0,''),(360907,115021,'116970','printshop','padding-left','40',0,''),(360908,115021,'116970','printshop','time_format','24',0,''),(360909,115021,'116970','printshop','show_icons','on',0,''),(360910,115021,'116970','printshop','padding-left','0',0,'5342'),(360911,115022,'116971','printshop','block_type','1',0,''),(360912,115023,'116972','printshop','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(360913,115024,'116973','printshop','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(360914,115024,'116973','printshop','margin-bottom','40',0,''),(360915,115025,'116102.000001','printshop','block_type','1',0,''),(360916,115026,'116103.000001','printshop','block_type','6',0,''),(360917,115026,'116103.000001','printshop','schema','6-3',0,'5342'),(360918,115027,'116104.000001','printshop','aria_name','account-menu',0,''),(360981,115047,'116109.000001','printshop','text','<h1>##CREDIT_AMOUNT_HISTORY##</h1>',0,''),(360982,115048,'1638895944.9672','printshop','margin-bottom','20',0,''),(360983,115049,'116974','printshop','width','680',0,''),(360984,115049,'116974','printshop','font-weight','normal',0,''),(360985,115049,'116974','printshop','font-size','12',0,''),(360986,115049,'116974','printshop','padding-top','20',0,''),(360987,115049,'116974','printshop','padding-bottom','20',0,''),(360988,115049,'116974','printshop','color','$content-color-1',0,''),(360989,115050,'116975','printshop','block_type','3',0,''),(360990,115050,'116975','printshop','font-weight','normal',0,''),(360991,115050,'116975','printshop','padding-top','20',0,''),(360992,115051,'116976','printshop','font-size','12',0,''),(360993,115052,'116977','printshop','text','<p>If undelivered please return to:</p>',1,''),(360994,115052,'116977','printshop','font-size','12',0,''),(360995,115052,'116977','printshop','font-weight','bold',0,''),(360996,115052,'116977','printshop','text','<p>If undelivered please return to:</p>',2,''),(360997,115052,'116977','printshop','text','<p>If undelivered please return to:</p>',3,''),(360998,115052,'116977','printshop','text','<p>If undelivered please return to:</p>',4,''),(360999,115053,'116978','printshop','text','<p>Thank you for your order</p>',1,''),(361000,115053,'116978','printshop','color','$hileght-color-1',0,''),(361001,115053,'116978','printshop','font-size','13',0,''),(361002,115053,'116978','printshop','font-weight','bold',0,''),(361003,115053,'116978','printshop','padding-top','5',0,''),(361004,115053,'116978','printshop','text-align','center',0,''),(361005,115053,'116978','printshop','text','<p>Thank you for your order</p>',2,''),(361006,115053,'116978','printshop','text','<p>Thank you for your order</p>',3,''),(361007,115053,'116978','printshop','text','<p>Thank you for your order</p>',4,''),(361008,115054,'116979','printshop','font-weight','400',0,''),(361009,115054,'116979','printshop','text-align','center',0,''),(361010,115054,'116979','printshop','padding-top','0',0,''),(361012,115054,'116979','printshop','padding-left','20',0,''),(361013,115054,'116979','printshop','padding-right','20',0,''),(361017,115055,'116980','printshop','text','<p>If something has gone wrong please contact us at:</p>',1,''),(361018,115055,'116980','printshop','font-size','12',0,''),(361019,115055,'116980','printshop','font-weight','bold',0,''),(361020,115055,'116980','printshop','text-align','right',0,''),(361021,115055,'116980','printshop','text','<p>If something has gone wrong please contact us at:</p>',2,''),(361022,115055,'116980','printshop','text','<p>If something has gone wrong please contact us at:</p>',3,''),(361023,115055,'116980','printshop','text','<p>If something has gone wrong please contact us at:</p>',4,''),(361024,115056,'116981','printshop','block_type','6',0,''),(361025,115056,'116981','printshop','font-weight','normal',0,''),(361026,115056,'116981','printshop','font-size','16',0,''),(361027,115057,'116982','printshop','text','<p>Email:</p>',1,''),(361028,115057,'116982','printshop','font-weight','normal',0,''),(361029,115057,'116982','printshop','text-align','right',0,''),(361030,115057,'116982','printshop','font-size','12',0,''),(361031,115057,'116982','printshop','text','<p>Email:</p>',2,''),(361032,115057,'116982','printshop','text','<p>Email:</p>',3,''),(361033,115057,'116982','printshop','text','<p>Email:</p>',4,''),(361034,115058,'116983','printshop','font-weight','normal',0,''),(361035,115058,'116983','printshop','text-align','right',0,''),(361036,115058,'116983','printshop','font-size','12',0,''),(361037,115059,'116984','printshop','block_type','6',0,''),(361038,115059,'116984','printshop','font-weight','normal',0,''),(361039,115059,'116984','printshop','font-size','16',0,''),(361040,115060,'116985','printshop','text','<p>Phone:</p>',1,''),(361041,115060,'116985','printshop','font-weight','normal',0,''),(361042,115060,'116985','printshop','text-align','right',0,''),(361043,115060,'116985','printshop','font-size','12',0,''),(361044,115060,'116985','printshop','text','<p>Phone:</p>',2,''),(361045,115060,'116985','printshop','text','<p>Phone:</p>',3,''),(361046,115060,'116985','printshop','text','<p>Phone:</p>',4,''),(361047,115061,'116986','printshop','font-weight','normal',0,''),(361048,115061,'116986','printshop','text-align','right',0,''),(361049,115061,'116986','printshop','font-size','12',0,''),(361050,115062,'116987','printshop','font-weight','400',0,''),(361051,115062,'116987','printshop','padding-top','20',0,''),(361052,115062,'116987','printshop','padding-bottom','0',0,''),(361053,115062,'116987','printshop','font-size','12',0,''),(361054,115063,'116988','printshop','block_type','2',0,''),(361055,115063,'116988','printshop','font-weight','normal',0,''),(361056,115063,'116988','printshop','padding-bottom','20',0,''),(361057,115064,'116989','printshop','font-weight','400',0,''),(361058,115064,'116989','printshop','padding-top','20',0,''),(361063,115065,'116990','printshop','block_type','11',0,''),(361064,115065,'116990','printshop','font-weight','normal',0,''),(361065,115066,'116991','printshop','text','<p>Web:</p>',1,''),(361066,115066,'116991','printshop','font-weight','normal',0,''),(361067,115066,'116991','printshop','text-align','right',0,''),(361068,115066,'116991','printshop','text','<p>Web:</p>',2,''),(361069,115066,'116991','printshop','text','<p>Web:</p>',3,''),(361070,115066,'116991','printshop','text','<p>Web:</p>',4,''),(361071,115067,'116992','printshop','font-weight','normal',0,''),(361072,115067,'116992','printshop','text-align','right',0,''),(361073,115068,'116993','printshop','block_type','11',0,''),(361074,115068,'116993','printshop','font-weight','normal',0,''),(361075,115069,'116994','printshop','text','<p>Phone:</p>',1,''),(361076,115069,'116994','printshop','font-weight','normal',0,''),(361077,115069,'116994','printshop','text-align','right',0,''),(361078,115069,'116994','printshop','text','<p>Phone:</p>',2,''),(361079,115069,'116994','printshop','text','<p>Phone:</p>',3,''),(361080,115069,'116994','printshop','text','<p>Phone:</p>',4,''),(361081,115070,'116995','printshop','font-weight','normal',0,''),(361082,115070,'116995','printshop','text-align','right',0,''),(361083,115071,'116996','printshop','block_type','11',0,''),(361084,115071,'116996','printshop','font-weight','normal',0,''),(361085,115072,'116997','printshop','text','<p>Email:</p>',1,''),(361086,115072,'116997','printshop','font-weight','normal',0,''),(361087,115072,'116997','printshop','text-align','right',0,''),(361088,115072,'116997','printshop','text','<p>Email:</p>',2,''),(361089,115072,'116997','printshop','text','<p>Email:</p>',3,''),(361090,115072,'116997','printshop','text','<p>Email:</p>',4,''),(361091,115073,'116998','printshop','font-weight','normal',0,''),(361092,115073,'116998','printshop','text-align','right',0,''),(361093,115074,'116999','printshop','block_type','1',0,''),(361094,115075,'117000','printshop','font-weight','normal',0,''),(361095,115075,'117000','printshop','text-align','right',0,''),(361096,115075,'117000','printshop','padding-bottom','10',0,''),(361097,115075,'117000','printshop','address_spacer',',',0,''),(361098,115075,'117000','printshop','font-size','12',0,''),(361099,115076,'117001','printshop','block_type','5',0,''),(361100,115076,'117001','printshop','font-weight','normal',0,''),(361101,115076,'117001','printshop','border-bottom-width','1',0,''),(361102,115076,'117001','printshop','border-bottom-color','$content-border-3',0,''),(361103,115076,'117001','printshop','border-top-width','1',0,''),(361104,115076,'117001','printshop','border-top-color','$content-border-3',0,''),(361105,115076,'117001','printshop','border-left-color','$content-border-3',0,''),(361106,115076,'117001','printshop','border-left-width','1',0,''),(361107,115077,'117002','printshop','block_type','1',0,''),(361108,115077,'117002','printshop','font-weight','normal',0,''),(361109,115077,'117002','printshop','padding-top','10',0,''),(361110,115077,'117002','printshop','padding-left','10',0,''),(361111,115077,'117002','printshop','padding-right','10',0,''),(361112,115078,'117003','printshop','font-weight','400',0,''),(361113,115078,'117003','printshop','line-height','120',0,''),(361114,115078,'117003','printshop','line_height_measure','%',0,''),(361115,115078,'117003','printshop','font-size','12',0,''),(361116,115079,'117004','printshop','text','<p>SHIPPING ADDRESS:</p>',1,''),(361117,115079,'117004','printshop','font-size','14',0,''),(361118,115079,'117004','printshop','font-weight','bold',0,''),(361119,115079,'117004','printshop','padding-bottom','10',0,''),(361120,115079,'117004','printshop','text','<p>SHIPPING ADDRESS:</p>',2,''),(361121,115079,'117004','printshop','text','<p>SHIPPING ADDRESS:</p>',3,''),(361122,115079,'117004','printshop','text','<p>SHIPPING ADDRESS:</p>',4,''),(361123,115080,'117005','printshop','block_type','1',0,''),(361124,115080,'117005','printshop','background-color','$content-bg-2',0,''),(361125,115080,'117005','printshop','padding-top','20',0,''),(361126,115080,'117005','printshop','padding-left','10',0,''),(361127,115080,'117005','printshop','padding-right','10',0,''),(361128,115080,'117005','printshop','padding-bottom','20',0,''),(361129,115080,'117005','printshop','font-size','14',0,''),(361130,115081,'117006','printshop','block_type','4',0,''),(361131,115081,'117006','printshop','font-weight','normal',0,''),(361132,115081,'117006','printshop','border-top-width','1',0,''),(361133,115081,'117006','printshop','border-top-color','$content-border-3',0,''),(361134,115081,'117006','printshop','border-left-width','1',0,''),(361135,115081,'117006','printshop','border-left-color','$content-border-3',0,''),(361136,115081,'117006','printshop','border-right-width','1',0,''),(361137,115081,'117006','printshop','border-right-color','$content-border-3',0,''),(361138,115081,'117006','printshop','border-bottom-width','1',0,''),(361139,115081,'117006','printshop','border-bottom-color','$content-border-3',0,''),(361140,115082,'117007','printshop','block_type','2',0,''),(361141,115082,'117007','printshop','font-weight','normal',0,''),(361142,115082,'117007','printshop','border-right-width','1',0,''),(361143,115082,'117007','printshop','border-right-color','$content-border-3',0,''),(361144,115083,'117008','printshop','block_type','1',0,''),(361145,115083,'117008','printshop','font-weight','400',0,''),(361146,115083,'117008','printshop','background-color','$content-bg-2',0,''),(361147,115083,'117008','printshop','padding-top','10',0,''),(361148,115083,'117008','printshop','padding-left','10',0,''),(361149,115083,'117008','printshop','padding-right','10',0,''),(361150,115083,'117008','printshop','padding-bottom','30',0,''),(361151,115084,'117009','printshop','text','<p>INVOICE ADDRESS:</p>',1,''),(361152,115084,'117009','printshop','font-size','14',0,''),(361153,115084,'117009','printshop','font-weight','bold',0,''),(361154,115084,'117009','printshop','text','<p>INVOICE ADDRESS:</p>',2,''),(361155,115084,'117009','printshop','text','<p>INVOICE ADDRESS:</p>',3,''),(361156,115084,'117009','printshop','text','<p>INVOICE ADDRESS:</p>',4,''),(361157,115085,'117010','printshop','font-size','12',0,''),(361158,115086,'117011','printshop','block_type','1',0,''),(361159,115086,'117011','printshop','font-weight','normal',0,''),(361160,115086,'117011','printshop','padding-top','10',0,''),(361161,115086,'117011','printshop','padding-left','10',0,''),(361162,115086,'117011','printshop','padding-right','10',0,''),(361163,115086,'117011','printshop','padding-bottom','10',0,''),(361164,115087,'117012','printshop','font-weight','normal',0,''),(361165,115088,'117013','printshop','text','<p>CUSTOMER:</p>',1,''),(361166,115088,'117013','printshop','font-size','13',0,''),(361167,115088,'117013','printshop','font-weight','bold',0,''),(361168,115088,'117013','printshop','text','<p>CUSTOMER:</p>',2,''),(361169,115088,'117013','printshop','text','<p>CUSTOMER:</p>',3,''),(361170,115088,'117013','printshop','text','<p>CUSTOMER:</p>',4,''),(361171,115089,'117014','printshop','text','<p>PHONE NUMBER:</p>',1,''),(361172,115089,'117014','printshop','font-size','14',0,''),(361173,115089,'117014','printshop','font-weight','bold',0,''),(361174,115089,'117014','printshop','padding-top','10',0,''),(361175,115089,'117014','printshop','text','<p>PHONE NUMBER:</p>',2,''),(361176,115089,'117014','printshop','text','<p>PHONE NUMBER:</p>',3,''),(361177,115089,'117014','printshop','text','<p>PHONE NUMBER:</p>',4,''),(361178,115090,'117015','printshop','font-weight','normal',0,''),(361179,115092,'117017','printshop','text','<p>E-MAIL ADDRESS:</p>',1,''),(361180,115092,'117017','printshop','font-weight','bold',0,''),(361181,115092,'117017','printshop','font-size','14',0,''),(361182,115092,'117017','printshop','padding-top','10',0,''),(361183,115092,'117017','printshop','text','<p>E-MAIL ADDRESS:</p>',2,''),(361184,115092,'117017','printshop','text','<p>E-MAIL ADDRESS:</p>',3,''),(361185,115092,'117017','printshop','text','<p>E-MAIL ADDRESS:</p>',4,''),(361186,115093,'117018','printshop','block_type','2',0,''),(361187,115093,'117018','printshop','font-weight','normal',0,''),(361188,115093,'117018','printshop','border-top-width','1',0,''),(361189,115093,'117018','printshop','border-top-color','$content-border-3',0,''),(361190,115093,'117018','printshop','border-right-width','1',0,''),(361191,115093,'117018','printshop','border-right-color','$content-border-3',0,''),(361192,115094,'117019','printshop','block_type','1',0,''),(361193,115094,'117019','printshop','font-weight','normal',0,''),(361194,115094,'117019','printshop','padding-top','10',0,''),(361195,115094,'117019','printshop','padding-left','10',0,''),(361196,115094,'117019','printshop','padding-right','10',0,''),(361197,115094,'117019','printshop','padding-bottom','10',0,''),(361198,115094,'117019','printshop','border-right-width','1',0,''),(361199,115094,'117019','printshop','border-right-color','$content-border-3',0,''),(361200,115096,'117021','printshop','text','<p>Shipping via</p>',1,''),(361201,115096,'117021','printshop','font-weight','bold',0,''),(361202,115096,'117021','printshop','font-size','14',0,''),(361203,115096,'117021','printshop','text','<p>Shipping via</p>',2,''),(361204,115096,'117021','printshop','text','<p>Shipping via</p>',3,''),(361205,115096,'117021','printshop','text','<p>Shipping via</p>',4,''),(361206,115097,'117022','printshop','block_type','1',0,''),(361207,115097,'117022','printshop','font-weight','normal',0,''),(361208,115097,'117022','printshop','padding-top','10',0,''),(361209,115097,'117022','printshop','padding-left','10',0,''),(361210,115097,'117022','printshop','padding-right','10',0,''),(361211,115097,'117022','printshop','padding-bottom','10',0,''),(361212,115098,'117023','printshop','text','<p>Shipping service</p>',1,''),(361213,115098,'117023','printshop','font-weight','bold',0,''),(361214,115098,'117023','printshop','font-size','14',0,''),(361215,115098,'117023','printshop','text','<p>Shipping service</p>',2,''),(361216,115098,'117023','printshop','text','<p>Shipping service</p>',3,''),(361217,115098,'117023','printshop','text','<p>Shipping service</p>',4,''),(361218,115100,'117025','printshop','font-size','14',0,''),(361219,115100,'117025','printshop','font-weight','bold',0,''),(361220,115100,'117025','printshop','text-align','center',0,''),(361221,115100,'117025','printshop','padding-bottom','10',0,''),(361222,115100,'117025','printshop','padding-top','10',0,''),(361223,115101,'117026','printshop','text','<p>Payment date:</p>',1,''),(361224,115101,'117026','printshop','font-weight','bold',0,''),(361225,115101,'117026','printshop','text-align','center',0,''),(361226,115101,'117026','printshop','font-size','12',0,''),(361227,115101,'117026','printshop','text','<p>Payment date:</p>',2,''),(361228,115101,'117026','printshop','text','<p>Payment date:</p>',3,''),(361229,115101,'117026','printshop','text','<p>Payment date:</p>',4,''),(361230,115102,'117027','printshop','font-weight','normal',0,''),(361231,115102,'117027','printshop','text-align','center',0,''),(361232,115102,'117027','printshop','padding-bottom','10',0,''),(361233,115103,'117034','printshop','text-align','center',0,''),(361234,115103,'117034','printshop','padding-top','10',0,''),(361235,115104,'1639155816.3893','printshop','block_type','1',0,''),(361236,115105,'117028','printshop','padding-top','30',0,''),(361237,115105,'117028','printshop','padding-bottom','30',0,''),(361238,115109,'117032','printshop','col_in_row','4',0,''),(361239,115109,'117032','printshop','listing_type','productListing',0,''),(361240,115109,'117032','printshop','view_as','carousel',0,''),(361241,115109,'117032','printshop','col_in_row','3',0,'5342'),(361242,115109,'117032','printshop','col_in_row','2',0,'5333'),(361243,115109,'117032','printshop','col_in_row','1',0,'5363'),(361244,115111,'1639485067.5512','printshop','padding-top','30',0,''),(361245,115111,'1639485067.5512','printshop','padding-bottom','30',0,''),(361246,115113,'1639154415.2739','printshop','block_type','1',0,''),(361247,115115,'117036','printshop','heading_type','h1',0,''),(361248,115116,'1639419797.9718','printshop','page_id','4',0,''),(361249,115116,'1639419797.9718','printshop','padding-top','30',0,''),(361250,115116,'1639419797.9718','printshop','padding-bottom','30',0,''),(361251,115119,'117039','printshop','text-align','center',0,''),(361252,115119,'117039','printshop','padding-top','10',0,''),(361253,115124,'117044','printshop','block_type','1',0,''),(361254,115125,'117045','printshop','block_type','1',0,''),(361255,115125,'117045','printshop','max-width','800',0,''),(361256,115125,'117045','printshop','margin','0 auto',0,''),(361257,115125,'117045','printshop','background-color','$content-bg-1',0,''),(361258,115126,'117046','printshop','color','$content-color-1',0,''),(361259,115126,'117046','printshop','font-size','12',0,''),(361260,115126,'117046','printshop','padding-top','20',0,''),(361261,115126,'117046','printshop','padding-bottom','20',0,''),(361262,115126,'117046','printshop','border-top-width','1',0,''),(361263,115126,'117046','printshop','border-top-color','$content-border-3',0,''),(361264,115127,'117047','printshop','font-weight','normal',0,''),(361265,115127,'117047','printshop','padding-top','20',0,''),(361266,115127,'117047','printshop','padding-left','10',0,''),(361267,115127,'117047','printshop','padding-right','10',0,''),(361268,115127,'117047','printshop','padding-bottom','20',0,''),(361269,115127,'117047','printshop','color','$content-color-1',0,''),(361270,115127,'117047','printshop','font-size','14',0,''),(361271,115128,'117048','printshop','block_type','7',0,''),(361272,115128,'117048','printshop','font-weight','normal',0,''),(361273,115128,'117048','printshop','background-color','$highlight-box-bg-2',0,''),(361274,115128,'117048','printshop','padding-top','5',0,''),(361275,115128,'117048','printshop','padding-left','10',0,''),(361276,115128,'117048','printshop','padding-right','10',0,''),(361277,115128,'117048','printshop','padding-bottom','5',0,''),(361278,115129,'117049','printshop','color','$highlight-box-color-2',0,''),(361279,115129,'117049','printshop','font-size','14',0,''),(361280,115129,'117049','printshop','font-weight','normal',0,''),(361281,115130,'117050','printshop','font-weight','normal',0,''),(361282,115130,'117050','printshop','text-align','right',0,''),(361283,115130,'117050','printshop','color','$highlight-box-color-2',0,''),(361284,115130,'117050','printshop','font-size','12',0,''),(361285,115131,'117051','printshop','font-weight','normal',0,''),(361286,115131,'117051','printshop','padding-bottom','10',0,''),(361287,115131,'117051','printshop','padding-top','10',0,''),(361288,115131,'117051','printshop','logo_from','theme',0,''),(361289,115131,'117051','printshop','padding-left','20',0,''),(361290,115132,'117052','printshop','block_type','1',0,''),(361291,115133,'117053','printshop','block_type','1',0,''),(361292,115133,'117053','printshop','max-width','800',0,''),(361293,115133,'117053','printshop','margin','0 auto',0,''),(361294,115133,'117053','printshop','background-color','$content-bg-1',0,''),(361295,115134,'117054','printshop','color','$content-color-1',0,''),(361296,115134,'117054','printshop','font-size','12',0,''),(361297,115134,'117054','printshop','padding-top','20',0,''),(361298,115134,'117054','printshop','padding-bottom','20',0,''),(361299,115134,'117054','printshop','border-top-width','1',0,''),(361300,115134,'117054','printshop','border-top-color','$content-border-3',0,''),(361301,115135,'117055','printshop','font-weight','normal',0,''),(361302,115135,'117055','printshop','padding-bottom','10',0,''),(361303,115135,'117055','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',1,''),(361304,115135,'117055','printshop','padding-left','20',0,''),(361305,115135,'117055','printshop','padding-top','10',0,''),(361306,115135,'117055','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',2,''),(361307,115135,'117055','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',3,''),(361308,115135,'117055','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',4,''),(361309,115136,'117056','printshop','font-weight','normal',0,''),(361310,115136,'117056','printshop','padding-top','20',0,''),(361311,115136,'117056','printshop','padding-left','10',0,''),(361312,115136,'117056','printshop','padding-right','10',0,''),(361313,115136,'117056','printshop','padding-bottom','20',0,''),(361314,115136,'117056','printshop','color','$content-color-1',0,''),(361315,115136,'117056','printshop','font-size','14',0,''),(361316,115137,'117057','printshop','block_type','7',0,''),(361317,115137,'117057','printshop','font-weight','normal',0,''),(361318,115137,'117057','printshop','background-color','$highlight-box-bg-1',0,''),(361319,115137,'117057','printshop','padding-top','5',0,''),(361320,115137,'117057','printshop','padding-left','10',0,''),(361321,115137,'117057','printshop','padding-right','10',0,''),(361322,115137,'117057','printshop','padding-bottom','5',0,''),(361323,115138,'117058','printshop','color','$highlight-box-color-1',0,''),(361324,115138,'117058','printshop','font-size','15',0,''),(361325,115138,'117058','printshop','font-weight','700',0,''),(361326,115139,'117059','printshop','font-weight','normal',0,''),(361327,115139,'117059','printshop','text-align','right',0,''),(361328,115139,'117059','printshop','color','$highlight-box-color-1',0,''),(361329,115139,'117059','printshop','font-size','12',0,''),(361330,115140,'117060','printshop','block_type','1',0,''),(361331,115140,'117060','printshop','background-color','$content-bg-2',0,''),(361332,115141,'117061','printshop','block_type','1',0,''),(361333,115141,'117061','printshop','max-width','800',0,''),(361334,115141,'117061','printshop','margin','0 auto',0,''),(361335,115142,'117062','printshop','block_type','1',0,''),(361336,115142,'117062','printshop','background-color','$content-bg-1',0,''),(361337,115142,'117062','printshop','padding-top','20',0,''),(361338,115142,'117062','printshop','padding-left','20',0,''),(361339,115142,'117062','printshop','padding-right','20',0,''),(361340,115142,'117062','printshop','padding-bottom','20',0,''),(361341,115143,'117063','printshop','font-weight','normal',0,''),(361342,115143,'117063','printshop','padding-top','20',0,''),(361343,115143,'117063','printshop','padding-bottom','20',0,''),(361344,115143,'117063','printshop','color','$content-color-1',0,''),(361345,115143,'117063','printshop','font-size','14',0,''),(361346,115144,'117064','printshop','block_type','7',0,''),(361347,115144,'117064','printshop','font-weight','normal',0,''),(361348,115144,'117064','printshop','padding-left','10',0,''),(361349,115144,'117064','printshop','padding-right','10',0,''),(361350,115144,'117064','printshop','padding-bottom','15',0,''),(361351,115144,'117064','printshop','border-bottom-width','1',0,''),(361352,115144,'117064','printshop','border-bottom-color','$content-border-3',0,''),(361353,115145,'117065','printshop','color','$content-color-1',0,''),(361354,115145,'117065','printshop','font-size','14',0,''),(361355,115145,'117065','printshop','font-weight','700',0,''),(361356,115146,'117066','printshop','font-weight','normal',0,''),(361357,115146,'117066','printshop','text-align','right',0,''),(361358,115146,'117066','printshop','color','$fade-color-1',0,''),(361359,115146,'117066','printshop','font-size','11',0,''),(361360,115146,'117066','printshop','text-transform','uppercase',0,''),(361361,115147,'117067','printshop','color','$fade-color-1',0,''),(361362,115147,'117067','printshop','font-size','12',0,''),(361363,115147,'117067','printshop','padding-top','20',0,''),(361364,115147,'117067','printshop','padding-bottom','20',0,''),(361365,115147,'117067','printshop','text-align','center',0,''),(361366,115148,'117068','printshop','font-weight','normal',0,''),(361367,115148,'117068','printshop','padding-bottom','10',0,''),(361368,115148,'117068','printshop','padding-top','10',0,''),(361369,115148,'117068','printshop','text-align','center',0,''),(361370,115148,'117068','printshop','logo_from','theme',0,''),(361371,115149,'117069','printshop','block_type','1',0,''),(361372,115149,'117069','printshop','background-color','$content-bg-2',0,''),(361373,115149,'117069','printshop','padding-top','20',0,''),(361374,115149,'117069','printshop','padding-bottom','20',0,''),(361375,115150,'117070','printshop','block_type','1',0,''),(361376,115150,'117070','printshop','max-width','800',0,''),(361377,115150,'117070','printshop','margin','0 auto',0,''),(361378,115151,'117071','printshop','color','$fade-color-1',0,''),(361379,115151,'117071','printshop','font-size','12',0,''),(361380,115151,'117071','printshop','padding-top','20',0,''),(361381,115151,'117071','printshop','padding-bottom','20',0,''),(361382,115151,'117071','printshop','text-align','left',0,''),(361383,115152,'117072','printshop','block_type','1',0,''),(361384,115152,'117072','printshop','background-color','$content-bg-1',0,''),(361385,115152,'117072','printshop','padding-top','20',0,''),(361386,115152,'117072','printshop','padding-left','20',0,''),(361387,115152,'117072','printshop','padding-right','20',0,''),(361388,115152,'117072','printshop','padding-bottom','20',0,''),(361389,115152,'117072','printshop','border-top-width','1',0,''),(361390,115152,'117072','printshop','border-left-width','1',0,''),(361391,115152,'117072','printshop','border-right-width','1',0,''),(361392,115152,'117072','printshop','border-bottom-width','1',0,''),(361393,115152,'117072','printshop','border-top-color','$content-border-3',0,''),(361394,115152,'117072','printshop','border-left-color','$content-border-3',0,''),(361395,115152,'117072','printshop','border-bottom-color','$content-border-3',0,''),(361396,115152,'117072','printshop','border-right-color','$content-border-3',0,''),(361397,115153,'117073','printshop','block_type','2',0,''),(361398,115154,'117074','printshop','font-weight','normal',0,''),(361399,115154,'117074','printshop','padding-bottom','10',0,''),(361400,115154,'117074','printshop','padding-top','10',0,''),(361401,115154,'117074','printshop','logo_from','theme',0,''),(361402,115155,'117075','printshop','font-weight','normal',0,''),(361403,115155,'117075','printshop','text-align','right',0,''),(361404,115155,'117075','printshop','color','$fade-color-1',0,''),(361405,115155,'117075','printshop','font-size','11',0,''),(361406,115155,'117075','printshop','text-transform','uppercase',0,''),(361407,115156,'117076','printshop','color','$content-color-1',0,''),(361408,115156,'117076','printshop','font-size','14',0,''),(361409,115156,'117076','printshop','font-weight','700',0,''),(361410,115156,'117076','printshop','text-align','right',0,''),(361411,115157,'117077','printshop','font-weight','normal',0,''),(361412,115157,'117077','printshop','padding-top','20',0,''),(361413,115157,'117077','printshop','padding-bottom','20',0,''),(361414,115157,'117077','printshop','color','$content-color-1',0,''),(361415,115157,'117077','printshop','font-size','14',0,''),(361416,115158,'121029','printshop','block_type','1',0,''),(361417,115161,'121032','printshop','margin-bottom','30',0,''),(361418,115162,'121025','printshop','block_type','1',0,''),(361419,115163,'121026','printshop','text','<h1>CATALOGUE</h1>',0,''),(361420,115165,'117078','printshop','block_type','1',0,''),(361421,115165,'117078','printshop','font-weight','normal',0,''),(361422,115165,'117078','printshop','padding-top','50',0,''),(361423,115165,'117078','printshop','background-color','$footer-bg-1',0,''),(361424,115165,'117078','printshop','style_class','preFooter',0,''),(361425,115165,'117078','printshop','padding-bottom','25',0,''),(361426,115165,'117078','printshop','padding-top','20',0,'5342'),(361427,115165,'117078','printshop','padding-bottom','20',0,'5342'),(361428,115165,'117078','printshop','color','$footer-color-1',0,''),(361429,115166,'120869','printshop','block_type','3',0,''),(361430,115166,'120869','printshop','padding-top','30',0,''),(361431,115166,'120869','printshop','margin-top','24',0,''),(361432,115166,'120869','printshop','border-top-width','1',0,''),(361433,115166,'120869','printshop','border-top-color','$footer-border-1',0,''),(361434,115166,'120869','printshop','border-top-width','0',0,'5342'),(361435,115166,'120869','printshop','padding-top','0',0,'5342'),(361436,115166,'120869','printshop','schema','3-6',0,'5342'),(361437,115167,'120870','printshop','logo','themes/printshop/img/delivery-box.png',1,''),(361438,115167,'120870','printshop','float','left',0,''),(361439,115167,'120870','printshop','clear','none',0,''),(361440,115167,'120870','printshop','padding-bottom','20',0,'5342'),(361441,115167,'120870','printshop','text-align','center',0,'5342'),(361442,115167,'120870','printshop','float','none',0,'5342'),(361443,115167,'120870','printshop','logo','themes/printshop/img/delivery-box.png',2,''),(361444,115167,'120870','printshop','logo','themes/printshop/img/delivery-box.png',3,''),(361445,115167,'120870','printshop','logo','themes/printshop/img/delivery-box.png',4,''),(361446,115168,'1644341222.4626','printshop','text-align','center',0,''),(361447,115168,'1644341222.4626','printshop','padding-bottom','20',0,'5342'),(361448,115169,'1644573331.7071','printshop','logo','themes/printshop/img/Untitled-2.png',1,''),(361449,115169,'1644573331.7071','printshop','text-align','right',0,''),(361450,115169,'1644573331.7071','printshop','padding-top','4',0,''),(361451,115169,'1644573331.7071','printshop','text-align','center',0,'5342'),(361452,115169,'1644573331.7071','printshop','logo','themes/printshop/img/Untitled-2.png',2,''),(361453,115169,'1644573331.7071','printshop','logo','themes/printshop/img/Untitled-2.png',3,''),(361454,115169,'1644573331.7071','printshop','logo','themes/printshop/img/Untitled-2.png',4,''),(361455,115170,'1644340895.1318','printshop','block_type','12',0,''),(361456,115170,'1644340895.1318','printshop','schema','12-2',0,'5342'),(361457,115171,'117085','printshop','class','menu-style-2',0,''),(361458,115171,'117085','printshop','type','builder',0,''),(361459,115171,'117085','printshop','style','3',0,''),(361460,115171,'117085','printshop','lev2_vis','click',0,'5342'),(361461,115171,'117085','printshop','style_class','footer-menu',0,''),(361462,115172,'1644342832.3703','printshop','block_type','2',0,''),(361463,115172,'1644342832.3703','printshop','schema','2-2',0,'5333'),(361464,115173,'117091','printshop','view_item','address',0,''),(361465,115173,'117091','printshop','address_spacer',',<br>',0,''),(361466,115173,'117091','printshop','color','$fade-color-2',0,''),(361467,115173,'117091','printshop','data_format_content','<div>##TITLE##</div><div>Location: ##POST_ADDRESS##</div><div>Phone number: ##TELEPHONE##</div>',0,''),(361468,115173,'117091','printshop','margin-top','20',0,'5333'),(361469,115173,'117091','printshop','padding-right','30',0,''),(361470,115174,'1644406988.3921','printshop','text','Contact',1,''),(361471,115174,'1644406988.3921','printshop','color','$fade-color-2',0,''),(361472,115174,'1644406988.3921','printshop','font-size','18',0,''),(361473,115174,'1644406988.3921','printshop','text-transform','uppercase',0,''),(361474,115174,'1644406988.3921','printshop','margin-bottom','10',0,''),(361475,115174,'1644406988.3921','printshop','font-weight','300',0,''),(361476,115174,'1644406988.3921','printshop','text','Contact',2,''),(361477,115174,'1644406988.3921','printshop','text','Contact',3,''),(361478,115174,'1644406988.3921','printshop','text','Contact',4,''),(361479,115175,'1644406713.4425','printshop','view_item','phone_number',0,''),(361480,115175,'1644406713.4425','printshop','color','$fade-color-2',0,''),(361481,115175,'1644406713.4425','printshop','font-size','18',0,''),(361482,115175,'1644406713.4425','printshop','padding-top','40',0,''),(361483,115175,'1644406713.4425','printshop','content','\\f095',0,'3'),(361484,115175,'1644406713.4425','printshop','font-family','$font-icons-1',0,'3'),(361485,115175,'1644406713.4425','printshop','font-size','18',0,'3'),(361486,115175,'1644406713.4425','printshop','margin-right','14',0,'3'),(361487,115175,'1644406713.4425','printshop','display','inline-block',0,'3'),(361488,115175,'1644406713.4425','printshop','vertical-align','middle',0,'3'),(361489,115176,'1644406751.9542','printshop','view_item','email',0,''),(361490,115176,'1644406751.9542','printshop','add_link_on_email','1',0,''),(361491,115176,'1644406751.9542','printshop','color','$footer-color-2',0,''),(361492,115176,'1644406751.9542','printshop','font-size','16',0,''),(361493,115176,'1644406751.9542','printshop','content','\\e75a',0,'3'),(361494,115176,'1644406751.9542','printshop','font-family','$font-icons-3',0,'3'),(361495,115176,'1644406751.9542','printshop','font-size','18',0,'3'),(361496,115176,'1644406751.9542','printshop','margin-right','10',0,'3'),(361497,115176,'1644406751.9542','printshop','display','inline-block',0,'3'),(361498,115176,'1644406751.9542','printshop','vertical-align','middle',0,'3'),(361499,115176,'1644406751.9542','printshop','color','$fade-color-2',0,'3'),(361500,115177,'117093','printshop','block_type','1',0,''),(361501,115177,'117093','printshop','font-weight','400',0,''),(361502,115177,'117093','printshop','padding-top','20',0,''),(361503,115177,'117093','printshop','padding-bottom','20',0,''),(361504,115177,'117093','printshop','schema','2-2',0,''),(361505,115177,'117093','printshop','schema','2-3',0,'5342'),(361506,115177,'117093','printshop','background-color','$footer-bg-2',0,''),(361507,115177,'117093','printshop','color','$footer-color-1',0,''),(361508,115178,'117094','printshop','color','$fade-color-2',0,''),(361509,115178,'117094','printshop','text-align','center',0,''),(361510,115178,'117094','printshop','font-size','14',0,''),(361511,115178,'117094','printshop','font-family','$font-1',0,''),(361512,115178,'117094','printshop','font-weight','400',0,''),(361513,115179,'117096','printshop','block_type','5',0,''),(361514,115180,'117097','printshop','text','##TEXT_LANGUAGE##',0,''),(361515,115182,'117099','printshop','block_type','5',0,''),(361516,115183,'117100','printshop','text','##TEXT_CURRENCY##',0,''),(361517,115185,'117102','printshop','block_type','1',0,''),(361518,115185,'117102','printshop','font-weight','normal',0,''),(361519,115186,'117103','printshop','block_type','2',0,''),(361520,115186,'117103','printshop','font-weight','normal',0,''),(361521,115186,'117103','printshop','padding-bottom','20',0,''),(361522,115187,'117104','printshop','block_type','1',0,''),(361523,115187,'117104','printshop','margin-right','20',0,''),(361524,115190,'117107','printshop','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(361525,115190,'117107','printshop','font-weight','normal',0,''),(361526,115190,'117107','printshop','padding-bottom','20',0,''),(361527,115190,'117107','printshop','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(361528,115190,'117107','printshop','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(361529,115190,'117107','printshop','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(361530,115192,'117109','printshop','block_type','1',0,''),(361531,115192,'117109','printshop','font-weight','normal',0,''),(361532,115192,'117109','printshop','style_class','gift-card-view',0,''),(361533,115192,'117109','printshop','text-align','center',0,''),(361534,115192,'117109','printshop','padding-bottom','20',0,''),(361535,115192,'117109','printshop','background-color','$highlight-box-bg-1',0,''),(361536,115192,'117109','printshop','padding-left','20',0,''),(361537,115192,'117109','printshop','padding-right','20',0,''),(361538,115192,'117109','printshop','color','$highlight-box-color-1',0,''),(361539,115193,'117110','printshop','block_type','1',0,''),(361540,115193,'117110','printshop','font-weight','normal',0,''),(361541,115193,'117110','printshop','padding-top','10',0,''),(361542,115194,'117111','printshop','font-size','12',0,''),(361543,115194,'117111','printshop','font-weight','bold',0,''),(361544,115194,'117111','printshop','text-align','center',0,''),(361545,115194,'117111','printshop','style_class','email',0,''),(361546,115195,'117112','printshop','text','<p>If you require further assistance please contact us</p>',1,''),(361547,115195,'117112','printshop','font-weight','normal',0,''),(361548,115195,'117112','printshop','text-align','center',0,''),(361549,115195,'117112','printshop','font-size','12',0,''),(361550,115195,'117112','printshop','padding-top','10',0,''),(361551,115195,'117112','printshop','padding-bottom','5',0,''),(361552,115195,'117112','printshop','border-top-width','1',0,''),(361553,115195,'117112','printshop','border-top-color','$warning-border',0,''),(361554,115195,'117112','printshop','text','<p>If you require further assistance please contact us</p>',2,''),(361555,115195,'117112','printshop','text','<p>If you require further assistance please contact us</p>',3,''),(361556,115195,'117112','printshop','text','<p>If you require further assistance please contact us</p>',4,''),(361557,115196,'117113','printshop','font-size','12',0,''),(361558,115196,'117113','printshop','font-weight','bold',0,''),(361559,115196,'117113','printshop','text-align','center',0,''),(361560,115196,'117113','printshop','style_class','phone',0,''),(361561,115196,'117113','printshop','padding-bottom','5',0,''),(361562,115197,'117114','printshop','text','<p>WHAT TO DO NEXT:</p>',1,''),(361563,115197,'117114','printshop','font-weight','normal',0,''),(361564,115197,'117114','printshop','text-align','center',0,''),(361565,115197,'117114','printshop','padding-top','20',0,''),(361566,115197,'117114','printshop','padding-bottom','10',0,''),(361567,115197,'117114','printshop','style_class','question-ico',0,''),(361568,115197,'117114','printshop','border-top-width','1',0,''),(361569,115197,'117114','printshop','border-top-color','$warning-border',0,''),(361570,115197,'117114','printshop','font-size','18',0,''),(361571,115197,'117114','printshop','text','<p>WHAT TO DO NEXT:</p>',2,''),(361572,115197,'117114','printshop','text','<p>WHAT TO DO NEXT:</p>',3,''),(361573,115197,'117114','printshop','text','<p>WHAT TO DO NEXT:</p>',4,''),(361574,115198,'117115','printshop','text','<p>osCommerce</p>\n',1,''),(361575,115198,'117115','printshop','font-family','$font-1',0,''),(361576,115198,'117115','printshop','font-size','24',0,''),(361577,115198,'117115','printshop','font-weight','normal',0,''),(361578,115198,'117115','printshop','text-align','center',0,''),(361579,115198,'117115','printshop','padding-top','10',0,''),(361580,115198,'117115','printshop','padding-bottom','20',0,''),(361581,115198,'117115','printshop','text','<p>osCommerce</p>\n',2,''),(361582,115198,'117115','printshop','text','<p>osCommerce</p>\n',3,''),(361583,115198,'117115','printshop','text','<p>osCommerce</p>\n',4,''),(361584,115199,'117116','printshop','block_type','4',0,''),(361585,115199,'117116','printshop','color','$highlight-box-color-4',0,''),(361586,115199,'117116','printshop','font-size','30',0,''),(361587,115199,'117116','printshop','font-weight','normal',0,''),(361588,115199,'117116','printshop','background-color','$highlight-box-bg-4',0,''),(361589,115199,'117116','printshop','padding-top','5',0,''),(361590,115199,'117116','printshop','padding-left','10',0,''),(361591,115199,'117116','printshop','padding-right','10',0,''),(361592,115199,'117116','printshop','padding-bottom','5',0,''),(361593,115200,'117117','printshop','text','<p>Your code is:</p>',1,''),(361594,115200,'117117','printshop','font-weight','normal',0,''),(361595,115200,'117117','printshop','text','<p>Your code is:</p>',2,''),(361596,115200,'117117','printshop','text','<p>Your code is:</p>',3,''),(361597,115200,'117117','printshop','text','<p>Your code is:</p>',4,''),(361598,115202,'117119','printshop','font-weight','normal',0,''),(361599,115202,'117119','printshop','text-align','center',0,''),(361600,115202,'117119','printshop','padding-bottom','20',0,''),(361601,115203,'117120','printshop','font-size','60',0,''),(361602,115203,'117120','printshop','font-weight','bold',0,''),(361603,115203,'117120','printshop','text-align','center',0,''),(361604,115203,'117120','printshop','line-height','100',0,''),(361605,115203,'117120','printshop','padding-bottom','20',0,''),(361606,115203,'117120','printshop','line_height_measure','px',0,''),(361607,115204,'117121','printshop','text','<p>PERSONAL MESSAGE</p>',1,''),(361608,115204,'117121','printshop','font-size','18',0,''),(361609,115204,'117121','printshop','font-weight','normal',0,''),(361610,115204,'117121','printshop','text-align','center',0,''),(361611,115204,'117121','printshop','padding-top','20',0,''),(361612,115204,'117121','printshop','padding-bottom','10',0,''),(361613,115204,'117121','printshop','border-top-width','1',0,''),(361614,115204,'117121','printshop','border-top-color','$warning-border',0,''),(361615,115204,'117121','printshop','text','<p>PERSONAL MESSAGE</p>',2,''),(361616,115204,'117121','printshop','text','<p>PERSONAL MESSAGE</p>',3,''),(361617,115204,'117121','printshop','text','<p>PERSONAL MESSAGE</p>',4,''),(361618,115205,'117123','printshop','logo','themes/printshop/img/themes/printshop/img/Logo.jpg',1,''),(361619,115205,'117123','printshop','logo_from','theme',0,''),(361620,115205,'117123','printshop','padding-top','20',0,''),(361621,115205,'117123','printshop','text-align','center',0,''),(361622,115205,'117123','printshop','logo','themes/printshop/img/themes/printshop/img/Logo.jpg',2,''),(361623,115205,'117123','printshop','logo','themes/printshop/img/themes/printshop/img/Logo.jpg',3,''),(361624,115205,'117123','printshop','logo','themes/printshop/img/themes/printshop/img/Logo.jpg',4,''),(361625,115206,'117124','printshop','text','<p>GIFT CARD</p>',1,''),(361626,115206,'117124','printshop','font-size','30',0,''),(361627,115206,'117124','printshop','font-weight','normal',0,''),(361628,115206,'117124','printshop','border-top-width','1',0,''),(361629,115206,'117124','printshop','border-top-color','$warning-border',0,''),(361630,115206,'117124','printshop','style_class','gift-ico',0,''),(361631,115206,'117124','printshop','text-align','center',0,''),(361632,115206,'117124','printshop','padding-top','15',0,''),(361633,115206,'117124','printshop','text','<p>GIFT CARD</p>',2,''),(361634,115206,'117124','printshop','text','<p>GIFT CARD</p>',3,''),(361635,115206,'117124','printshop','text','<p>GIFT CARD</p>',4,''),(361636,115207,'117125','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(361637,115207,'117125','printshop','font-weight','normal',0,''),(361638,115207,'117125','printshop','text-align','center',0,''),(361639,115207,'117125','printshop','padding-bottom','10',0,''),(361640,115207,'117125','printshop','font-size','14',0,''),(361641,115207,'117125','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(361642,115207,'117125','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(361643,115207,'117125','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(361644,115208,'117126','printshop','block_type','1',0,''),(361645,115208,'117126','printshop','font-weight','normal',0,''),(361646,115208,'117126','printshop','style_class','gift-card-view',0,''),(361647,115208,'117126','printshop','text-align','center',0,''),(361648,115208,'117126','printshop','padding-bottom','20',0,''),(361649,115208,'117126','printshop','background-color','$highlight-box-bg-2',0,''),(361650,115208,'117126','printshop','padding-left','20',0,''),(361651,115208,'117126','printshop','padding-right','20',0,''),(361652,115208,'117126','printshop','color','$highlight-box-color-2',0,''),(361653,115209,'117127','printshop','font-size','60',0,''),(361654,115209,'117127','printshop','font-weight','bold',0,''),(361655,115209,'117127','printshop','text-align','center',0,''),(361656,115209,'117127','printshop','line-height','100',0,''),(361657,115209,'117127','printshop','padding-bottom','20',0,''),(361658,115209,'117127','printshop','line_height_measure','px',0,''),(361659,115210,'117128','printshop','block_type','4',0,''),(361660,115210,'117128','printshop','color','$highlight-box-color-4',0,''),(361661,115210,'117128','printshop','font-size','30',0,''),(361662,115210,'117128','printshop','font-weight','normal',0,''),(361663,115210,'117128','printshop','background-color','$highlight-box-bg-4',0,''),(361664,115210,'117128','printshop','padding-top','5',0,''),(361665,115210,'117128','printshop','padding-left','10',0,''),(361666,115210,'117128','printshop','padding-right','10',0,''),(361667,115210,'117128','printshop','padding-bottom','5',0,''),(361668,115211,'117129','printshop','text','<p>Your code is:</p>',1,''),(361669,115211,'117129','printshop','font-weight','normal',0,''),(361670,115211,'117129','printshop','text','<p>Your code is:</p>',2,''),(361671,115211,'117129','printshop','text','<p>Your code is:</p>',3,''),(361672,115211,'117129','printshop','text','<p>Your code is:</p>',4,''),(361673,115213,'117131','printshop','block_type','1',0,''),(361674,115213,'117131','printshop','font-weight','normal',0,''),(361675,115213,'117131','printshop','padding-top','10',0,''),(361676,115214,'117132','printshop','font-size','12',0,''),(361677,115214,'117132','printshop','font-weight','bold',0,''),(361678,115214,'117132','printshop','text-align','center',0,''),(361679,115214,'117132','printshop','style_class','email',0,''),(361680,115215,'117133','printshop','text','<p>If you require further assistance please contact us</p>',1,''),(361681,115215,'117133','printshop','font-weight','normal',0,''),(361682,115215,'117133','printshop','text-align','center',0,''),(361683,115215,'117133','printshop','font-size','12',0,''),(361684,115215,'117133','printshop','padding-top','10',0,''),(361685,115215,'117133','printshop','padding-bottom','5',0,''),(361686,115215,'117133','printshop','border-top-width','1',0,''),(361687,115215,'117133','printshop','border-top-color','$warning-border',0,''),(361688,115215,'117133','printshop','text','<p>If you require further assistance please contact us</p>',2,''),(361689,115215,'117133','printshop','text','<p>If you require further assistance please contact us</p>',3,''),(361690,115215,'117133','printshop','text','<p>If you require further assistance please contact us</p>',4,''),(361691,115216,'117134','printshop','font-size','12',0,''),(361692,115216,'117134','printshop','font-weight','bold',0,''),(361693,115216,'117134','printshop','text-align','center',0,''),(361694,115216,'117134','printshop','style_class','phone',0,''),(361695,115216,'117134','printshop','padding-bottom','5',0,''),(361696,115217,'117135','printshop','font-weight','normal',0,''),(361697,115217,'117135','printshop','text-align','center',0,''),(361698,115217,'117135','printshop','padding-bottom','20',0,''),(361699,115218,'117136','printshop','text','<p>PERSONAL MESSAGE</p>',1,''),(361700,115218,'117136','printshop','font-size','18',0,''),(361701,115218,'117136','printshop','font-weight','normal',0,''),(361702,115218,'117136','printshop','text-align','center',0,''),(361703,115218,'117136','printshop','padding-top','20',0,''),(361704,115218,'117136','printshop','padding-bottom','10',0,''),(361705,115218,'117136','printshop','border-top-width','1',0,''),(361706,115218,'117136','printshop','border-top-color','$warning-border',0,''),(361707,115218,'117136','printshop','text','<p>PERSONAL MESSAGE</p>',2,''),(361708,115218,'117136','printshop','text','<p>PERSONAL MESSAGE</p>',3,''),(361709,115218,'117136','printshop','text','<p>PERSONAL MESSAGE</p>',4,''),(361710,115219,'117137','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(361711,115219,'117137','printshop','font-weight','normal',0,''),(361712,115219,'117137','printshop','text-align','center',0,''),(361713,115219,'117137','printshop','padding-bottom','10',0,''),(361714,115219,'117137','printshop','font-size','14',0,''),(361715,115219,'117137','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(361716,115219,'117137','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(361717,115219,'117137','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(361718,115220,'117138','printshop','text','<p>GIFT CARD</p>',1,''),(361719,115220,'117138','printshop','font-size','30',0,''),(361720,115220,'117138','printshop','font-weight','normal',0,''),(361721,115220,'117138','printshop','border-top-width','1',0,''),(361722,115220,'117138','printshop','border-top-color','$warning-border',0,''),(361723,115220,'117138','printshop','style_class','gift-ico',0,''),(361724,115220,'117138','printshop','text-align','center',0,''),(361725,115220,'117138','printshop','padding-top','15',0,''),(361726,115220,'117138','printshop','text','<p>GIFT CARD</p>',2,''),(361727,115220,'117138','printshop','text','<p>GIFT CARD</p>',3,''),(361728,115220,'117138','printshop','text','<p>GIFT CARD</p>',4,''),(361729,115221,'117139','printshop','text','<p>WHAT TO DO NEXT:</p>',1,''),(361730,115221,'117139','printshop','font-weight','normal',0,''),(361731,115221,'117139','printshop','text-align','center',0,''),(361732,115221,'117139','printshop','padding-top','20',0,''),(361733,115221,'117139','printshop','padding-bottom','10',0,''),(361734,115221,'117139','printshop','style_class','question-ico',0,''),(361735,115221,'117139','printshop','border-top-width','1',0,''),(361736,115221,'117139','printshop','border-top-color','$warning-border',0,''),(361737,115221,'117139','printshop','font-size','18',0,''),(361738,115221,'117139','printshop','text','<p>WHAT TO DO NEXT:</p>',2,''),(361739,115221,'117139','printshop','text','<p>WHAT TO DO NEXT:</p>',3,''),(361740,115221,'117139','printshop','text','<p>WHAT TO DO NEXT:</p>',4,''),(361741,115222,'1638804282.8587','printshop','logo_from','theme',0,''),(361742,115222,'1638804282.8587','printshop','padding-top','20',0,''),(361743,115222,'1638804282.8587','printshop','text-align','center',0,''),(361744,115222,'1638804282.8587','printshop','padding-bottom','20',0,''),(361745,115223,'117141','printshop','block_type','1',0,''),(361746,115223,'117141','printshop','font-weight','normal',0,''),(361747,115223,'117141','printshop','style_class','gift-card-view',0,''),(361748,115223,'117141','printshop','text-align','center',0,''),(361749,115223,'117141','printshop','padding-bottom','20',0,''),(361750,115223,'117141','printshop','background-color','$highlight-box-bg-2',0,''),(361751,115223,'117141','printshop','padding-left','20',0,''),(361752,115223,'117141','printshop','padding-right','20',0,''),(361753,115223,'117141','printshop','color','$highlight-box-color-2',0,''),(361754,115224,'117142','printshop','block_type','1',0,''),(361755,115224,'117142','printshop','font-weight','normal',0,''),(361756,115224,'117142','printshop','padding-top','10',0,''),(361757,115225,'117143','printshop','font-size','12',0,''),(361758,115225,'117143','printshop','font-weight','bold',0,''),(361759,115225,'117143','printshop','text-align','center',0,''),(361760,115225,'117143','printshop','style_class','email',0,''),(361761,115225,'117143','printshop','color','$highlight-box-color-2',0,''),(361762,115226,'117144','printshop','font-size','12',0,''),(361763,115226,'117144','printshop','font-weight','bold',0,''),(361764,115226,'117144','printshop','text-align','center',0,''),(361765,115226,'117144','printshop','style_class','phone',0,''),(361766,115226,'117144','printshop','padding-bottom','5',0,''),(361767,115226,'117144','printshop','color','$highlight-box-color-2',0,''),(361768,115227,'117145','printshop','text','If you require further assistance please contact us',0,''),(361769,115227,'117145','printshop','font-size','12',0,''),(361770,115227,'117145','printshop','color','$highlight-box-color-2',0,''),(361771,115227,'117145','printshop','text-align','center',0,''),(361772,115227,'117145','printshop','padding-top','10',0,''),(361773,115228,'117146','printshop','block_type','4',0,''),(361774,115228,'117146','printshop','color','$highlight-box-color-4',0,''),(361775,115228,'117146','printshop','font-size','30',0,''),(361776,115228,'117146','printshop','font-weight','normal',0,''),(361777,115228,'117146','printshop','background-color','$highlight-box-bg-4',0,''),(361778,115228,'117146','printshop','padding-top','5',0,''),(361779,115228,'117146','printshop','padding-left','10',0,''),(361780,115228,'117146','printshop','padding-right','10',0,''),(361781,115228,'117146','printshop','padding-bottom','5',0,''),(361782,115229,'117147','printshop','text','Your code is:',0,''),(361783,115229,'117147','printshop','font-size','30',0,''),(361784,115229,'117147','printshop','color','$highlight-box-color-4',0,''),(361785,115230,'117148','printshop','font-size','30',0,''),(361786,115230,'117148','printshop','color','$highlight-box-color-4',0,''),(361787,115231,'117149','printshop','block_type','1',0,''),(361788,115232,'117150','printshop','text','<p>PERSONAL MESSAGE</p>',1,''),(361789,115232,'117150','printshop','font-size','18',0,''),(361790,115232,'117150','printshop','font-weight','normal',0,''),(361791,115232,'117150','printshop','text-align','center',0,'');
INSERT INTO `design_boxes_settings` VALUES (361792,115232,'117150','printshop','padding-top','20',0,''),(361793,115232,'117150','printshop','padding-bottom','10',0,''),(361794,115232,'117150','printshop','border-top-width','1',0,''),(361795,115232,'117150','printshop','border-top-color','$warning-border',0,''),(361796,115232,'117150','printshop','text','<p>PERSONAL MESSAGE</p>',2,''),(361797,115232,'117150','printshop','text','<p>PERSONAL MESSAGE</p>',3,''),(361798,115232,'117150','printshop','text','<p>PERSONAL MESSAGE</p>',4,''),(361799,115232,'117150','printshop','color','$highlight-box-color-2',0,''),(361800,115233,'117151','printshop','text','HOLBI',0,''),(361801,115233,'117151','printshop','font-size','24',0,''),(361802,115233,'117151','printshop','padding-top','20',0,''),(361803,115233,'117151','printshop','text-align','center',0,''),(361804,115233,'117151','printshop','padding-bottom','20',0,''),(361805,115233,'117151','printshop','color','$highlight-box-color-2',0,''),(361806,115234,'117152','printshop','border-top-color','$warning-border',0,''),(361807,115234,'117152','printshop','border-top-width','1',0,''),(361808,115234,'117152','printshop','padding-top','20',0,''),(361809,115234,'117152','printshop','font-size','30',0,''),(361810,115234,'117152','printshop','text-align','center',0,''),(361811,115234,'117152','printshop','text','GIFT CARD',0,''),(361812,115234,'117152','printshop','color','$highlight-box-color-2',0,''),(361813,115235,'117153','printshop','text-align','center',0,''),(361814,115235,'117153','printshop','font-weight','bold',0,''),(361815,115235,'117153','printshop','font-size','60',0,''),(361816,115235,'117153','printshop','color','$highlight-box-color-2',0,''),(361817,115236,'117154','printshop','font-size','20',0,''),(361818,115236,'117154','printshop','text-align','center',0,''),(361819,115236,'117154','printshop','color','$highlight-box-color-2',0,''),(361820,115236,'117154','printshop','padding-top','20',0,''),(361821,115236,'117154','printshop','padding-bottom','20',0,''),(361822,115237,'117155','printshop','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(361823,115237,'117155','printshop','text-align','center',0,''),(361824,115237,'117155','printshop','color','$highlight-box-color-2',0,''),(361825,115237,'117155','printshop','font-size','14',0,''),(361826,115237,'117155','printshop','padding-bottom','20',0,''),(361827,115238,'117156','printshop','text','WHAT TO DO NEXT:',0,''),(361828,115238,'117156','printshop','font-size','18',0,''),(361829,115238,'117156','printshop','text-align','center',0,''),(361830,115238,'117156','printshop','color','$highlight-box-color-2',0,''),(361831,115238,'117156','printshop','padding-top','20',0,''),(361832,115238,'117156','printshop','padding-bottom','10',0,''),(361833,115238,'117156','printshop','border-top-width','1',0,''),(361834,115238,'117156','printshop','border-top-color','$warning-border',0,''),(361835,115239,'117158','printshop','block_type','1',0,''),(361836,115239,'117158','printshop','font-weight','normal',0,''),(361837,115239,'117158','printshop','style_class','gift-card-view',0,''),(361838,115239,'117158','printshop','text-align','center',0,''),(361839,115239,'117158','printshop','padding-bottom','20',0,''),(361840,115239,'117158','printshop','background-color','$highlight-box-bg-1',0,''),(361841,115239,'117158','printshop','padding-left','20',0,''),(361842,115239,'117158','printshop','padding-right','20',0,''),(361843,115239,'117158','printshop','color','$highlight-box-color-1',0,''),(361844,115240,'117159','printshop','block_type','1',0,''),(361845,115240,'117159','printshop','font-weight','normal',0,''),(361846,115240,'117159','printshop','padding-top','10',0,''),(361847,115241,'117160','printshop','font-size','12',0,''),(361848,115241,'117160','printshop','font-weight','bold',0,''),(361849,115241,'117160','printshop','text-align','center',0,''),(361850,115241,'117160','printshop','style_class','email',0,''),(361851,115241,'117160','printshop','color','$highlight-box-color-1',0,''),(361852,115242,'117161','printshop','font-size','12',0,''),(361853,115242,'117161','printshop','font-weight','bold',0,''),(361854,115242,'117161','printshop','text-align','center',0,''),(361855,115242,'117161','printshop','style_class','phone',0,''),(361856,115242,'117161','printshop','padding-bottom','5',0,''),(361857,115242,'117161','printshop','color','$highlight-box-color-1',0,''),(361858,115243,'117162','printshop','text','If you require further assistance please contact us',0,''),(361859,115243,'117162','printshop','font-size','12',0,''),(361860,115243,'117162','printshop','color','$highlight-box-color-1',0,''),(361861,115243,'117162','printshop','text-align','center',0,''),(361862,115243,'117162','printshop','padding-top','10',0,''),(361863,115244,'117163','printshop','block_type','2',0,''),(361864,115244,'117163','printshop','color','$highlight-box-color-4',0,''),(361865,115244,'117163','printshop','font-size','30',0,''),(361866,115244,'117163','printshop','font-weight','normal',0,''),(361867,115244,'117163','printshop','background-color','$highlight-box-bg-4',0,''),(361868,115244,'117163','printshop','padding-top','5',0,''),(361869,115244,'117163','printshop','padding-left','10',0,''),(361870,115244,'117163','printshop','padding-right','10',0,''),(361871,115244,'117163','printshop','padding-bottom','5',0,''),(361872,115245,'117164','printshop','text','Your code is:',0,''),(361873,115245,'117164','printshop','font-size','30',0,''),(361874,115245,'117164','printshop','color','$highlight-box-color-4',0,''),(361875,115245,'117164','printshop','background-color','$hileght-color-4',0,''),(361876,115246,'117165','printshop','color','$highlight-box-color-4',0,''),(361877,115246,'117165','printshop','font-size','30',0,''),(361878,115247,'117166','printshop','block_type','1',0,''),(361879,115248,'117167','printshop','text','<p>PERSONAL MESSAGE</p>',1,''),(361880,115248,'117167','printshop','font-size','18',0,''),(361881,115248,'117167','printshop','font-weight','normal',0,''),(361882,115248,'117167','printshop','text-align','center',0,''),(361883,115248,'117167','printshop','padding-top','20',0,''),(361884,115248,'117167','printshop','padding-bottom','10',0,''),(361885,115248,'117167','printshop','border-top-width','1',0,''),(361886,115248,'117167','printshop','border-top-color','$warning-border',0,''),(361887,115248,'117167','printshop','text','<p>PERSONAL MESSAGE</p>',2,''),(361888,115248,'117167','printshop','text','<p>PERSONAL MESSAGE</p>',3,''),(361889,115248,'117167','printshop','text','<p>PERSONAL MESSAGE</p>',4,''),(361890,115249,'117169','printshop','border-top-color','$warning-border',0,''),(361891,115249,'117169','printshop','border-top-width','1',0,''),(361892,115249,'117169','printshop','padding-top','20',0,''),(361893,115249,'117169','printshop','font-size','30',0,''),(361894,115249,'117169','printshop','text-align','center',0,''),(361895,115249,'117169','printshop','color','$highlight-box-color-1',0,''),(361896,115249,'117169','printshop','text','GIFT CARD',0,''),(361897,115250,'117170','printshop','text-align','center',0,''),(361898,115250,'117170','printshop','font-weight','bold',0,''),(361899,115250,'117170','printshop','font-size','60',0,''),(361900,115250,'117170','printshop','color','$highlight-box-color-1',0,''),(361901,115251,'117171','printshop','font-size','20',0,''),(361902,115251,'117171','printshop','text-align','center',0,''),(361903,115251,'117171','printshop','color','$highlight-box-color-1',0,''),(361904,115251,'117171','printshop','padding-top','20',0,''),(361905,115251,'117171','printshop','padding-bottom','20',0,''),(361906,115252,'117172','printshop','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(361907,115252,'117172','printshop','text-align','center',0,''),(361908,115252,'117172','printshop','color','$highlight-box-color-1',0,''),(361909,115252,'117172','printshop','font-size','14',0,''),(361910,115252,'117172','printshop','padding-bottom','20',0,''),(361911,115253,'117173','printshop','text','WHAT TO DO NEXT:',0,''),(361912,115253,'117173','printshop','font-size','18',0,''),(361913,115253,'117173','printshop','text-align','center',0,''),(361914,115253,'117173','printshop','color','$highlight-box-color-1',0,''),(361915,115253,'117173','printshop','padding-top','20',0,''),(361916,115253,'117173','printshop','padding-bottom','10',0,''),(361917,115253,'117173','printshop','border-top-width','1',0,''),(361918,115253,'117173','printshop','border-top-color','$warning-border',0,''),(361919,115254,'1638978695.8384','printshop','logo_from','theme',0,''),(361920,115254,'1638978695.8384','printshop','text-align','center',0,''),(361921,115254,'1638978695.8384','printshop','padding-top','20',0,''),(361922,115254,'1638978695.8384','printshop','padding-bottom','20',0,''),(361923,115255,'117175','printshop','block_type','1',0,''),(361924,115255,'117175','printshop','padding-left','20',0,''),(361925,115255,'117175','printshop','padding-right','20',0,''),(361926,115255,'117175','printshop','padding-bottom','20',0,''),(361927,115257,'117177','printshop','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(361928,115257,'117177','printshop','text-align','center',0,''),(361929,115258,'117178','printshop','block_type','1',0,''),(361930,115258,'117178','printshop','font-weight','normal',0,''),(361931,115258,'117178','printshop','style_class','gift-card-view',0,''),(361932,115258,'117178','printshop','text-align','center',0,''),(361933,115258,'117178','printshop','padding-bottom','20',0,''),(361934,115258,'117178','printshop','background-color','$highlight-box-bg-3',0,''),(361935,115258,'117178','printshop','padding-left','20',0,''),(361936,115258,'117178','printshop','padding-right','20',0,''),(361937,115258,'117178','printshop','color','$highlight-box-color-3',0,''),(361938,115259,'117179','printshop','block_type','4',0,''),(361939,115259,'117179','printshop','color','$highlight-box-color-4',0,''),(361940,115259,'117179','printshop','font-size','30',0,''),(361941,115259,'117179','printshop','font-weight','normal',0,''),(361942,115259,'117179','printshop','background-color','$highlight-box-bg-4',0,''),(361943,115259,'117179','printshop','padding-top','5',0,''),(361944,115259,'117179','printshop','padding-left','10',0,''),(361945,115259,'117179','printshop','padding-right','10',0,''),(361946,115259,'117179','printshop','padding-bottom','5',0,''),(361947,115260,'117180','printshop','text','<p>Your code is:</p>',1,''),(361948,115260,'117180','printshop','font-weight','normal',0,''),(361949,115260,'117180','printshop','text','<p>Your code is:</p>',2,''),(361950,115260,'117180','printshop','text','<p>Your code is:</p>',3,''),(361951,115260,'117180','printshop','text','<p>Your code is:</p>',4,''),(361952,115262,'117182','printshop','text','<p>WHAT TO DO NEXT:</p>',1,''),(361953,115262,'117182','printshop','font-weight','normal',0,''),(361954,115262,'117182','printshop','text-align','center',0,''),(361955,115262,'117182','printshop','padding-top','20',0,''),(361956,115262,'117182','printshop','padding-bottom','10',0,''),(361957,115262,'117182','printshop','style_class','question-ico',0,''),(361958,115262,'117182','printshop','border-top-width','1',0,''),(361959,115262,'117182','printshop','border-top-color','$warning-border',0,''),(361960,115262,'117182','printshop','font-size','18',0,''),(361961,115262,'117182','printshop','text','<p>WHAT TO DO NEXT:</p>',2,''),(361962,115262,'117182','printshop','text','<p>WHAT TO DO NEXT:</p>',3,''),(361963,115262,'117182','printshop','text','<p>WHAT TO DO NEXT:</p>',4,''),(361964,115263,'117184','printshop','block_type','1',0,''),(361965,115263,'117184','printshop','font-weight','normal',0,''),(361966,115263,'117184','printshop','padding-top','10',0,''),(361967,115264,'117185','printshop','text','<p>If you require further assistance please contact us</p>',1,''),(361968,115264,'117185','printshop','font-weight','normal',0,''),(361969,115264,'117185','printshop','text-align','center',0,''),(361970,115264,'117185','printshop','font-size','12',0,''),(361971,115264,'117185','printshop','padding-top','10',0,''),(361972,115264,'117185','printshop','padding-bottom','5',0,''),(361973,115264,'117185','printshop','border-top-width','1',0,''),(361974,115264,'117185','printshop','border-top-color','$warning-border',0,''),(361975,115264,'117185','printshop','text','<p>If you require further assistance please contact us</p>',2,''),(361976,115264,'117185','printshop','text','<p>If you require further assistance please contact us</p>',3,''),(361977,115264,'117185','printshop','text','<p>If you require further assistance please contact us</p>',4,''),(361978,115265,'117186','printshop','font-size','12',0,''),(361979,115265,'117186','printshop','font-weight','bold',0,''),(361980,115265,'117186','printshop','text-align','center',0,''),(361981,115265,'117186','printshop','style_class','email',0,''),(361982,115266,'117187','printshop','font-size','12',0,''),(361983,115266,'117187','printshop','font-weight','bold',0,''),(361984,115266,'117187','printshop','text-align','center',0,''),(361985,115266,'117187','printshop','style_class','phone',0,''),(361986,115266,'117187','printshop','padding-bottom','5',0,''),(361987,115267,'117188','printshop','font-weight','normal',0,''),(361988,115267,'117188','printshop','text-align','center',0,''),(361989,115267,'117188','printshop','padding-bottom','20',0,''),(361990,115268,'117189','printshop','text','<p>GIFT CARD</p>',1,''),(361991,115268,'117189','printshop','font-size','30',0,''),(361992,115268,'117189','printshop','font-weight','normal',0,''),(361993,115268,'117189','printshop','border-top-width','1',0,''),(361994,115268,'117189','printshop','border-top-color','$warning-border',0,''),(361995,115268,'117189','printshop','style_class','gift-ico',0,''),(361996,115268,'117189','printshop','text-align','center',0,''),(361997,115268,'117189','printshop','padding-top','15',0,''),(361998,115268,'117189','printshop','text','<p>GIFT CARD</p>',2,''),(361999,115268,'117189','printshop','text','<p>GIFT CARD</p>',3,''),(362000,115268,'117189','printshop','text','<p>GIFT CARD</p>',4,''),(362001,115269,'117190','printshop','text','<p>PERSONAL MESSAGE</p>',1,''),(362002,115269,'117190','printshop','font-size','18',0,''),(362003,115269,'117190','printshop','font-weight','normal',0,''),(362004,115269,'117190','printshop','text-align','center',0,''),(362005,115269,'117190','printshop','padding-top','20',0,''),(362006,115269,'117190','printshop','padding-bottom','10',0,''),(362007,115269,'117190','printshop','border-top-width','1',0,''),(362008,115269,'117190','printshop','border-top-color','$warning-border',0,''),(362009,115269,'117190','printshop','text','<p>PERSONAL MESSAGE</p>',2,''),(362010,115269,'117190','printshop','text','<p>PERSONAL MESSAGE</p>',3,''),(362011,115269,'117190','printshop','text','<p>PERSONAL MESSAGE</p>',4,''),(362012,115270,'117191','printshop','font-size','60',0,''),(362013,115270,'117191','printshop','font-weight','bold',0,''),(362014,115270,'117191','printshop','text-align','center',0,''),(362015,115270,'117191','printshop','line-height','100',0,''),(362016,115270,'117191','printshop','padding-bottom','20',0,''),(362017,115270,'117191','printshop','line_height_measure','px',0,''),(362018,115271,'117192','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(362019,115271,'117192','printshop','font-weight','normal',0,''),(362020,115271,'117192','printshop','text-align','center',0,''),(362021,115271,'117192','printshop','padding-bottom','10',0,''),(362022,115271,'117192','printshop','font-size','14',0,''),(362023,115271,'117192','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(362024,115271,'117192','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(362025,115271,'117192','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(362026,115272,'1638804328.7281','printshop','logo_from','theme',0,''),(362027,115272,'1638804328.7281','printshop','padding-top','20',0,''),(362028,115272,'1638804328.7281','printshop','text-align','center',0,''),(362029,115272,'1638804328.7281','printshop','padding-bottom','20',0,''),(362030,115273,'117193','printshop','block_type','1',0,''),(362031,115273,'117193','printshop','font-weight','normal',0,''),(362032,115273,'117193','printshop','style_class','gift-card-view',0,''),(362033,115273,'117193','printshop','text-align','center',0,''),(362034,115273,'117193','printshop','padding-bottom','20',0,''),(362035,115273,'117193','printshop','background-color','$highlight-box-bg-3',0,''),(362036,115273,'117193','printshop','padding-left','20',0,''),(362037,115273,'117193','printshop','padding-right','20',0,''),(362038,115273,'117193','printshop','color','$highlight-box-color-3',0,''),(362039,115274,'117194','printshop','block_type','1',0,''),(362040,115274,'117194','printshop','font-weight','normal',0,''),(362041,115274,'117194','printshop','padding-top','10',0,''),(362042,115275,'117195','printshop','font-size','12',0,''),(362043,115275,'117195','printshop','font-weight','bold',0,''),(362044,115275,'117195','printshop','text-align','center',0,''),(362045,115275,'117195','printshop','style_class','email',0,''),(362046,115275,'117195','printshop','color','$highlight-box-color-3',0,''),(362047,115276,'117196','printshop','font-size','12',0,''),(362048,115276,'117196','printshop','font-weight','bold',0,''),(362049,115276,'117196','printshop','text-align','center',0,''),(362050,115276,'117196','printshop','style_class','phone',0,''),(362051,115276,'117196','printshop','padding-bottom','5',0,''),(362052,115277,'117197','printshop','text','If you require further assistance please contact us',0,''),(362053,115277,'117197','printshop','font-size','12',0,''),(362054,115277,'117197','printshop','color','$highlight-box-color-3',0,''),(362055,115277,'117197','printshop','text-align','center',0,''),(362056,115277,'117197','printshop','padding-top','10',0,''),(362057,115278,'117198','printshop','block_type','4',0,''),(362058,115278,'117198','printshop','color','$highlight-box-color-4',0,''),(362059,115278,'117198','printshop','font-size','30',0,''),(362060,115278,'117198','printshop','font-weight','normal',0,''),(362061,115278,'117198','printshop','background-color','$highlight-box-bg-4',0,''),(362062,115278,'117198','printshop','padding-top','5',0,''),(362063,115278,'117198','printshop','padding-left','10',0,''),(362064,115278,'117198','printshop','padding-right','10',0,''),(362065,115278,'117198','printshop','padding-bottom','5',0,''),(362066,115279,'117199','printshop','text','Your code is:',0,''),(362067,115279,'117199','printshop','font-size','30',0,''),(362068,115279,'117199','printshop','color','$highlight-box-color-4',0,''),(362069,115280,'117200','printshop','color','$highlight-box-color-4',0,''),(362070,115280,'117200','printshop','font-size','30',0,''),(362071,115281,'117201','printshop','block_type','1',0,''),(362072,115282,'117202','printshop','text','<p>PERSONAL MESSAGE</p>',1,''),(362073,115282,'117202','printshop','font-size','18',0,''),(362074,115282,'117202','printshop','font-weight','normal',0,''),(362075,115282,'117202','printshop','text-align','center',0,''),(362076,115282,'117202','printshop','padding-top','20',0,''),(362077,115282,'117202','printshop','padding-bottom','10',0,''),(362078,115282,'117202','printshop','border-top-width','1',0,''),(362079,115282,'117202','printshop','border-top-color','$warning-border',0,''),(362080,115282,'117202','printshop','text','<p>PERSONAL MESSAGE</p>',2,''),(362081,115282,'117202','printshop','text','<p>PERSONAL MESSAGE</p>',3,''),(362082,115282,'117202','printshop','text','<p>PERSONAL MESSAGE</p>',4,''),(362083,115283,'117203','printshop','text','HOLBI',0,''),(362084,115283,'117203','printshop','color','$highlight-box-color-3',0,''),(362085,115283,'117203','printshop','font-size','24',0,''),(362086,115283,'117203','printshop','padding-top','20',0,''),(362087,115283,'117203','printshop','text-align','center',0,''),(362088,115283,'117203','printshop','padding-bottom','20',0,''),(362089,115284,'117204','printshop','border-top-color','$warning-border',0,''),(362090,115284,'117204','printshop','border-top-width','1',0,''),(362091,115284,'117204','printshop','padding-top','20',0,''),(362092,115284,'117204','printshop','font-size','30',0,''),(362093,115284,'117204','printshop','text-align','center',0,''),(362094,115284,'117204','printshop','color','$highlight-box-color-3',0,''),(362095,115284,'117204','printshop','text','GIFT CARD',0,''),(362096,115285,'117205','printshop','text-align','center',0,''),(362097,115285,'117205','printshop','font-weight','bold',0,''),(362098,115285,'117205','printshop','font-size','60',0,''),(362099,115285,'117205','printshop','color','$highlight-box-color-3',0,''),(362100,115286,'117206','printshop','font-size','20',0,''),(362101,115286,'117206','printshop','text-align','center',0,''),(362102,115286,'117206','printshop','padding-top','20',0,''),(362103,115286,'117206','printshop','padding-bottom','20',0,''),(362104,115287,'117207','printshop','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(362105,115287,'117207','printshop','text-align','center',0,''),(362106,115287,'117207','printshop','color','$highlight-box-color-3',0,''),(362107,115287,'117207','printshop','font-size','14',0,''),(362108,115287,'117207','printshop','padding-bottom','20',0,''),(362109,115288,'117208','printshop','text','WHAT TO DO NEXT:',0,''),(362110,115288,'117208','printshop','font-size','18',0,''),(362111,115288,'117208','printshop','text-align','center',0,''),(362112,115288,'117208','printshop','color','$highlight-box-color-3',0,''),(362113,115288,'117208','printshop','padding-top','20',0,''),(362114,115288,'117208','printshop','padding-bottom','10',0,''),(362115,115288,'117208','printshop','border-top-width','1',0,''),(362116,115288,'117208','printshop','border-top-color','$warning-border',0,''),(362117,115289,'117212','printshop','block_type','1',0,''),(362118,115289,'117212','printshop','padding-top','3',0,''),(362119,115289,'117212','printshop','padding-top','0',0,'5363'),(362120,115289,'117212','printshop','padding-bottom','0',0,'5363'),(362121,115289,'117212','printshop','style_class','header-middle',0,''),(362122,115289,'117212','printshop','position','relative',0,''),(362123,115289,'117212','printshop','background-color','$header-bg-1',0,''),(362124,115289,'117212','printshop','border-bottom-width','1',0,''),(362125,115289,'117212','printshop','border-bottom-color','$header-border-1',0,''),(362126,115289,'117212','printshop','color','$header-color-1',0,''),(362209,115296,'117219','printshop','block_type','1',0,''),(362210,115296,'117219','printshop','border-bottom-width','1',0,''),(362211,115296,'117219','printshop','border-bottom-color','$header-border-1',0,''),(362212,115296,'117219','printshop','font-weight','normal',0,''),(362213,115296,'117219','printshop','visibility_checkout','1',0,''),(362214,115296,'117219','printshop','display_none','1',0,'5342'),(362215,115296,'117219','printshop','style_class','topHeader',0,''),(362216,115296,'117219','printshop','padding-top','10',0,''),(362217,115296,'117219','printshop','padding-bottom','10',0,''),(362218,115296,'117219','printshop','background-color','$header-bg-1',0,''),(362219,115296,'117219','printshop','color','$header-color-1',0,''),(362264,115306,'117224','printshop','block_type','1',0,''),(362265,115312,'117229','printshop','width','680',0,''),(362266,115312,'117229','printshop','font-weight','normal',0,''),(362267,115312,'117229','printshop','font-size','12',0,''),(362268,115312,'117229','printshop','padding-top','20',0,''),(362269,115312,'117229','printshop','padding-bottom','20',0,''),(362270,115312,'117229','printshop','color','$content-color-1',0,''),(362271,115313,'117230','printshop','block_type','4',0,''),(362272,115313,'117230','printshop','font-weight','normal',0,''),(362273,115313,'117230','printshop','border-top-width','1',0,''),(362274,115313,'117230','printshop','border-top-color','$content-border-3',0,''),(362275,115313,'117230','printshop','border-left-width','1',0,''),(362276,115313,'117230','printshop','border-left-color','$content-border-3',0,''),(362277,115313,'117230','printshop','border-right-width','1',0,''),(362278,115313,'117230','printshop','border-right-color','$content-border-3',0,''),(362279,115313,'117230','printshop','border-bottom-width','1',0,''),(362280,115313,'117230','printshop','border-bottom-color','$content-border-3',0,''),(362281,115314,'117231','printshop','block_type','2',0,''),(362282,115314,'117231','printshop','font-weight','normal',0,''),(362283,115314,'117231','printshop','border-top-width','1',0,''),(362284,115314,'117231','printshop','border-top-color','$content-border-3',0,''),(362285,115314,'117231','printshop','border-right-width','1',0,''),(362286,115314,'117231','printshop','border-right-color','$content-border-3',0,''),(362287,115315,'117232','printshop','block_type','1',0,''),(362288,115315,'117232','printshop','font-weight','normal',0,''),(362289,115315,'117232','printshop','padding-top','10',0,''),(362290,115315,'117232','printshop','padding-left','10',0,''),(362291,115315,'117232','printshop','padding-right','10',0,''),(362292,115315,'117232','printshop','padding-bottom','10',0,''),(362293,115315,'117232','printshop','border-right-width','1',0,''),(362294,115315,'117232','printshop','border-right-color','$content-border-3',0,''),(362295,115317,'117234','printshop','text','<p>Shipping via</p>',1,''),(362296,115317,'117234','printshop','font-weight','bold',0,''),(362297,115317,'117234','printshop','font-size','14',0,''),(362298,115317,'117234','printshop','text','<p>Shipping via</p>',2,''),(362299,115317,'117234','printshop','text','<p>Shipping via</p>',3,''),(362300,115317,'117234','printshop','text','<p>Shipping via</p>',4,''),(362301,115318,'117235','printshop','block_type','1',0,''),(362302,115318,'117235','printshop','font-weight','normal',0,''),(362303,115318,'117235','printshop','padding-top','10',0,''),(362304,115318,'117235','printshop','padding-left','10',0,''),(362305,115318,'117235','printshop','padding-right','10',0,''),(362306,115318,'117235','printshop','padding-bottom','10',0,''),(362307,115319,'117236','printshop','text','<p>Shipping service</p>',1,''),(362308,115319,'117236','printshop','font-weight','bold',0,''),(362309,115319,'117236','printshop','font-size','14',0,''),(362310,115319,'117236','printshop','text','<p>Shipping service</p>',2,''),(362311,115319,'117236','printshop','text','<p>Shipping service</p>',3,''),(362312,115319,'117236','printshop','text','<p>Shipping service</p>',4,''),(362313,115321,'117238','printshop','block_type','2',0,''),(362314,115321,'117238','printshop','font-weight','normal',0,''),(362315,115321,'117238','printshop','border-right-width','1',0,''),(362316,115321,'117238','printshop','border-right-color','$content-border-3',0,''),(362317,115322,'117239','printshop','block_type','1',0,''),(362318,115322,'117239','printshop','font-weight','400',0,''),(362319,115322,'117239','printshop','background-color','$content-bg-2',0,''),(362320,115322,'117239','printshop','padding-top','10',0,''),(362321,115322,'117239','printshop','padding-left','10',0,''),(362322,115322,'117239','printshop','padding-right','10',0,''),(362323,115322,'117239','printshop','padding-bottom','30',0,''),(362324,115323,'117240','printshop','text','<p>INVOICE ADDRESS:</p>',1,''),(362325,115323,'117240','printshop','font-size','14',0,''),(362326,115323,'117240','printshop','font-weight','bold',0,''),(362327,115323,'117240','printshop','text','<p>INVOICE ADDRESS:</p>',2,''),(362328,115323,'117240','printshop','text','<p>INVOICE ADDRESS:</p>',3,''),(362329,115323,'117240','printshop','text','<p>INVOICE ADDRESS:</p>',4,''),(362330,115324,'117241','printshop','font-size','12',0,''),(362331,115326,'117242','printshop','block_type','1',0,''),(362332,115326,'117242','printshop','font-weight','normal',0,''),(362333,115326,'117242','printshop','padding-top','10',0,''),(362334,115326,'117242','printshop','padding-left','10',0,''),(362335,115326,'117242','printshop','padding-right','10',0,''),(362336,115326,'117242','printshop','padding-bottom','10',0,''),(362337,115327,'117243','printshop','text','<p>E-MAIL ADDRESS:</p>',1,''),(362338,115327,'117243','printshop','font-weight','bold',0,''),(362339,115327,'117243','printshop','font-size','14',0,''),(362340,115327,'117243','printshop','padding-top','10',0,''),(362341,115327,'117243','printshop','text','<p>E-MAIL ADDRESS:</p>',2,''),(362342,115327,'117243','printshop','text','<p>E-MAIL ADDRESS:</p>',3,''),(362343,115327,'117243','printshop','text','<p>E-MAIL ADDRESS:</p>',4,''),(362344,115328,'117244','printshop','font-weight','normal',0,''),(362345,115329,'117245','printshop','font-weight','normal',0,''),(362346,115330,'117246','printshop','text','<p>CUSTOMER:</p>',1,''),(362347,115330,'117246','printshop','font-size','13',0,''),(362348,115330,'117246','printshop','font-weight','bold',0,''),(362349,115330,'117246','printshop','text','<p>CUSTOMER:</p>',2,''),(362350,115330,'117246','printshop','text','<p>CUSTOMER:</p>',3,''),(362351,115330,'117246','printshop','text','<p>CUSTOMER:</p>',4,''),(362352,115331,'117247','printshop','text','<p>PHONE NUMBER:</p>',1,''),(362353,115331,'117247','printshop','font-size','14',0,''),(362354,115331,'117247','printshop','font-weight','bold',0,''),(362355,115331,'117247','printshop','padding-top','10',0,''),(362356,115331,'117247','printshop','text','<p>PHONE NUMBER:</p>',2,''),(362357,115331,'117247','printshop','text','<p>PHONE NUMBER:</p>',3,''),(362358,115331,'117247','printshop','text','<p>PHONE NUMBER:</p>',4,''),(362359,115333,'117249','printshop','font-weight','normal',0,''),(362360,115333,'117249','printshop','text-align','center',0,''),(362361,115333,'117249','printshop','padding-bottom','20',0,''),(362362,115334,'117250','printshop','text','<p>Payment Method:</p>',1,''),(362363,115334,'117250','printshop','font-weight','bold',0,''),(362364,115334,'117250','printshop','text-align','center',0,''),(362365,115334,'117250','printshop','text','<p>Payment Method:</p>',2,''),(362366,115334,'117250','printshop','text','<p>Payment Method:</p>',3,''),(362367,115334,'117250','printshop','text','<p>Payment Method:</p>',4,''),(362368,115335,'117251','printshop','text','<p>Payment date:</p>',1,''),(362369,115335,'117251','printshop','font-weight','bold',0,''),(362370,115335,'117251','printshop','text-align','center',0,''),(362371,115335,'117251','printshop','font-size','12',0,''),(362372,115335,'117251','printshop','text','<p>Payment date:</p>',2,''),(362373,115335,'117251','printshop','text','<p>Payment date:</p>',3,''),(362374,115335,'117251','printshop','text','<p>Payment date:</p>',4,''),(362375,115336,'117252','printshop','font-size','14',0,''),(362376,115336,'117252','printshop','font-weight','bold',0,''),(362377,115336,'117252','printshop','text-align','center',0,''),(362378,115336,'117252','printshop','padding-bottom','10',0,''),(362379,115336,'117252','printshop','padding-top','10',0,''),(362380,115337,'117253','printshop','font-weight','normal',0,''),(362381,115337,'117253','printshop','text-align','center',0,''),(362382,115337,'117253','printshop','padding-bottom','10',0,''),(362383,115338,'117254','printshop','font-weight','normal',0,''),(362384,115338,'117254','printshop','text-align','center',0,''),(362385,115339,'117255','printshop','block_type','3',0,''),(362386,115339,'117255','printshop','font-weight','normal',0,''),(362387,115339,'117255','printshop','padding-top','20',0,''),(362388,115340,'117256','printshop','font-size','12',0,''),(362389,115341,'117257','printshop','text','<p>If undelivered please return to:</p>',1,''),(362390,115341,'117257','printshop','font-size','12',0,''),(362391,115341,'117257','printshop','font-weight','bold',0,''),(362392,115341,'117257','printshop','text','<p>If undelivered please return to:</p>',2,''),(362393,115341,'117257','printshop','text','<p>If undelivered please return to:</p>',3,''),(362394,115341,'117257','printshop','text','<p>If undelivered please return to:</p>',4,''),(362395,115342,'117258','printshop','text','<p>Thank you for your order</p>',1,''),(362396,115342,'117258','printshop','color','$hileght-color-1',0,''),(362397,115342,'117258','printshop','font-size','13',0,''),(362398,115342,'117258','printshop','font-weight','bold',0,''),(362399,115342,'117258','printshop','padding-top','5',0,''),(362400,115342,'117258','printshop','text-align','center',0,''),(362401,115342,'117258','printshop','text','<p>Thank you for your order</p>',2,''),(362402,115342,'117258','printshop','text','<p>Thank you for your order</p>',3,''),(362403,115342,'117258','printshop','text','<p>Thank you for your order</p>',4,''),(362404,115343,'117260','printshop','block_type','6',0,''),(362405,115343,'117260','printshop','font-weight','normal',0,''),(362406,115343,'117260','printshop','font-size','16',0,''),(362407,115344,'117261','printshop','text','<p>Email:</p>',1,''),(362408,115344,'117261','printshop','font-weight','normal',0,''),(362409,115344,'117261','printshop','text-align','right',0,''),(362410,115344,'117261','printshop','font-size','12',0,''),(362411,115344,'117261','printshop','text','<p>Email:</p>',2,''),(362412,115344,'117261','printshop','text','<p>Email:</p>',3,''),(362413,115344,'117261','printshop','text','<p>Email:</p>',4,''),(362414,115345,'117262','printshop','font-weight','normal',0,''),(362415,115345,'117262','printshop','text-align','right',0,''),(362416,115345,'117262','printshop','font-size','12',0,''),(362417,115346,'117263','printshop','block_type','6',0,''),(362418,115346,'117263','printshop','font-weight','normal',0,''),(362419,115346,'117263','printshop','font-size','16',0,''),(362420,115347,'117264','printshop','text','<p>Phone:</p>',1,''),(362421,115347,'117264','printshop','font-weight','normal',0,''),(362422,115347,'117264','printshop','text-align','right',0,''),(362423,115347,'117264','printshop','font-size','12',0,''),(362424,115347,'117264','printshop','text','<p>Phone:</p>',2,''),(362425,115347,'117264','printshop','text','<p>Phone:</p>',3,''),(362426,115347,'117264','printshop','text','<p>Phone:</p>',4,''),(362427,115348,'117265','printshop','font-weight','normal',0,''),(362428,115348,'117265','printshop','text-align','right',0,''),(362429,115348,'117265','printshop','font-size','12',0,''),(362430,115349,'117266','printshop','text','<p>If something has gone wrong please contact us at:</p>',1,''),(362431,115349,'117266','printshop','font-size','12',0,''),(362432,115349,'117266','printshop','font-weight','bold',0,''),(362433,115349,'117266','printshop','text-align','right',0,''),(362434,115349,'117266','printshop','text','<p>If something has gone wrong please contact us at:</p>',2,''),(362435,115349,'117266','printshop','text','<p>If something has gone wrong please contact us at:</p>',3,''),(362436,115349,'117266','printshop','text','<p>If something has gone wrong please contact us at:</p>',4,''),(362437,115350,'117267','printshop','font-weight','400',0,''),(362438,115350,'117267','printshop','padding-top','20',0,''),(362439,115350,'117267','printshop','padding-bottom','0',0,''),(362440,115350,'117267','printshop','font-size','12',0,''),(362441,115351,'117268','printshop','block_type','5',0,''),(362442,115351,'117268','printshop','font-weight','normal',0,''),(362443,115351,'117268','printshop','border-bottom-width','1',0,''),(362444,115351,'117268','printshop','border-bottom-color','$content-border-3',0,''),(362445,115351,'117268','printshop','border-top-width','1',0,''),(362446,115351,'117268','printshop','border-top-color','$content-border-3',0,''),(362447,115351,'117268','printshop','border-left-color','$content-border-3',0,''),(362448,115351,'117268','printshop','border-left-width','1',0,''),(362449,115352,'117269','printshop','block_type','1',0,''),(362450,115352,'117269','printshop','font-weight','normal',0,''),(362451,115352,'117269','printshop','padding-top','10',0,''),(362452,115352,'117269','printshop','padding-left','10',0,''),(362453,115352,'117269','printshop','padding-right','10',0,''),(362454,115353,'117270','printshop','font-weight','400',0,''),(362455,115353,'117270','printshop','line-height','120',0,''),(362456,115353,'117270','printshop','line_height_measure','%',0,''),(362457,115353,'117270','printshop','font-size','12',0,''),(362458,115354,'117271','printshop','text','<p>SHIPPING ADDRESS:</p>',1,''),(362459,115354,'117271','printshop','font-size','14',0,''),(362460,115354,'117271','printshop','font-weight','bold',0,''),(362461,115354,'117271','printshop','padding-bottom','10',0,''),(362462,115354,'117271','printshop','text','<p>SHIPPING ADDRESS:</p>',2,''),(362463,115354,'117271','printshop','text','<p>SHIPPING ADDRESS:</p>',3,''),(362464,115354,'117271','printshop','text','<p>SHIPPING ADDRESS:</p>',4,''),(362465,115355,'117272','printshop','block_type','1',0,''),(362466,115355,'117272','printshop','background-color','$content-bg-2',0,''),(362467,115355,'117272','printshop','padding-top','20',0,''),(362468,115355,'117272','printshop','padding-left','10',0,''),(362469,115355,'117272','printshop','padding-right','10',0,''),(362470,115355,'117272','printshop','padding-bottom','20',0,''),(362471,115355,'117272','printshop','font-size','14',0,''),(362472,115356,'117273','printshop','font-weight','normal',0,''),(362473,115356,'117273','printshop','text-align','right',0,''),(362474,115356,'117273','printshop','font-size','14',0,''),(362475,115356,'117273','printshop','box_align','3',0,''),(362476,115357,'117274','printshop','block_type','2',0,''),(362477,115357,'117274','printshop','font-weight','normal',0,''),(362478,115357,'117274','printshop','padding-bottom','20',0,''),(362479,115358,'117275','printshop','font-weight','400',0,''),(362480,115358,'117275','printshop','padding-top','20',0,''),(362481,115358,'117275','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',1,''),(362482,115358,'117275','printshop','padding-bottom','20',0,''),(362483,115358,'117275','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',2,''),(362484,115358,'117275','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',3,''),(362485,115358,'117275','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',4,''),(362486,115359,'117276','printshop','block_type','11',0,''),(362487,115359,'117276','printshop','font-weight','normal',0,''),(362488,115360,'117277','printshop','text','<p>Web:</p>',1,''),(362489,115360,'117277','printshop','font-weight','normal',0,''),(362490,115360,'117277','printshop','text-align','right',0,''),(362491,115360,'117277','printshop','text','<p>Web:</p>',2,''),(362492,115360,'117277','printshop','text','<p>Web:</p>',3,''),(362493,115360,'117277','printshop','text','<p>Web:</p>',4,''),(362494,115361,'117278','printshop','font-weight','normal',0,''),(362495,115361,'117278','printshop','text-align','right',0,''),(362496,115362,'117279','printshop','block_type','11',0,''),(362497,115362,'117279','printshop','font-weight','normal',0,''),(362498,115363,'117280','printshop','text','<p>Email:</p>',1,''),(362499,115363,'117280','printshop','font-weight','normal',0,''),(362500,115363,'117280','printshop','text-align','right',0,''),(362501,115363,'117280','printshop','text','<p>Email:</p>',2,''),(362502,115363,'117280','printshop','text','<p>Email:</p>',3,''),(362503,115363,'117280','printshop','text','<p>Email:</p>',4,''),(362504,115364,'117281','printshop','font-weight','normal',0,''),(362505,115364,'117281','printshop','text-align','right',0,''),(362506,115365,'117282','printshop','block_type','1',0,''),(362507,115366,'117283','printshop','font-weight','normal',0,''),(362508,115366,'117283','printshop','text-align','right',0,''),(362509,115366,'117283','printshop','padding-bottom','10',0,''),(362510,115366,'117283','printshop','address_spacer',',',0,''),(362511,115366,'117283','printshop','font-size','12',0,''),(362512,115367,'117284','printshop','block_type','11',0,''),(362513,115367,'117284','printshop','font-weight','normal',0,''),(362514,115368,'117285','printshop','text','<p>Phone:</p>',1,''),(362515,115368,'117285','printshop','font-weight','normal',0,''),(362516,115368,'117285','printshop','text-align','right',0,''),(362517,115368,'117285','printshop','text','<p>Phone:</p>',2,''),(362518,115368,'117285','printshop','text','<p>Phone:</p>',3,''),(362519,115368,'117285','printshop','text','<p>Phone:</p>',4,''),(362520,115369,'117286','printshop','font-weight','normal',0,''),(362521,115369,'117286','printshop','text-align','right',0,''),(362522,115370,'1640103567.8175','printshop','column_qty','1',0,''),(362523,115370,'1640103567.8175','printshop','column_name','1',0,''),(362524,115370,'1640103567.8175','printshop','column_model','1',0,''),(362525,115371,'117287','printshop','block_type','1',0,''),(362526,115371,'117287','printshop','padding-top','20',0,''),(362527,115372,'117288','printshop','tab_1','RETURNING CUSTOMER',1,''),(362528,115372,'117288','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(362529,115372,'117288','printshop','tab_1','RETURNING CUSTOMER',2,''),(362530,115372,'117288','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(362531,115372,'117288','printshop','tab_1','RETURNING CUSTOMER',3,''),(362532,115372,'117288','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(362533,115372,'117288','printshop','tab_1','RETURNING CUSTOMER',4,''),(362534,115372,'117288','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(362535,115373,'117289','printshop','max-width','600',0,''),(362536,115373,'117289','printshop','margin_left_measure','auto',0,''),(362537,115373,'117289','printshop','margin_right_measure','auto',0,''),(362538,115374,'117290','printshop','block_type','8',0,''),(362539,115374,'117290','printshop','schema','8-6',0,'5342'),(362540,115375,'117291','printshop','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(362541,115375,'117291','printshop','padding-left','20',0,'5342'),(362542,115376,'117292','printshop','block_type','1',0,''),(362543,115376,'117292','printshop','padding-left','20',0,''),(362544,115376,'117292','printshop','padding-right','20',0,''),(362545,115377,'117293','printshop','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(362546,115379,'117295','printshop','block_type','1',0,''),(362547,115380,'117296','printshop','text','##TEXT_OR##',0,''),(362548,115380,'117296','printshop','font-size','18',0,''),(362549,115380,'117296','printshop','font-weight','700',0,''),(362550,115380,'117296','printshop','padding-top','15',0,''),(362551,115380,'117296','printshop','text-align','center',0,''),(362552,115380,'117296','printshop','content','\\_',0,'3'),(362553,115380,'117296','printshop','height','5',0,'3'),(362554,115380,'117296','printshop','width','70',0,'3'),(362555,115380,'117296','printshop','display','inline-block',0,'3'),(362556,115380,'117296','printshop','border-top-width','1',0,'3'),(362557,115380,'117296','printshop','border-top-color','$content-border-3',0,'3'),(362558,115380,'117296','printshop','margin-left','10',0,'3'),(362559,115380,'117296','printshop','margin-right','10',0,'3'),(362560,115380,'117296','printshop','content','\\_',0,'4'),(362561,115380,'117296','printshop','display','inline-block',0,'4'),(362562,115380,'117296','printshop','width','70',0,'4'),(362563,115380,'117296','printshop','height','5',0,'4'),(362564,115380,'117296','printshop','border-top-width','1',0,'4'),(362565,115380,'117296','printshop','border-top-color','$content-border-3',0,'4'),(362566,115380,'117296','printshop','margin-left','10',0,'4'),(362567,115380,'117296','printshop','margin-right','10',0,'4'),(362568,115380,'117296','printshop','position','relative',0,''),(362569,115380,'117296','printshop','top','-10',0,''),(362570,115381,'117297','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362571,115381,'117297','printshop','font-size','26',0,''),(362572,115381,'117297','printshop','font-family','$font-1',0,''),(362573,115381,'117297','printshop','padding-top','15',0,''),(362574,115381,'117297','printshop','padding-bottom','15',0,''),(362575,115381,'117297','printshop','text-align','center',0,''),(362576,115382,'117298','printshop','text-align','center',0,''),(362577,115382,'117298','printshop','hide_parents','2',0,''),(362578,115383,'117299','printshop','block_type','1',0,''),(362579,115383,'117299','printshop','padding-top','40',0,''),(362580,115383,'117299','printshop','background-color','$content-bg-2',0,''),(362581,115383,'117299','printshop','padding-bottom','40',0,''),(362582,115383,'117299','printshop','style_class','checkout-login-wrap',0,''),(362583,115383,'117299','printshop','color','$content-bg-2',0,''),(362584,115384,'117300','printshop','block_type','2',0,''),(362585,115384,'117300','printshop','background-color','$content-bg-1',0,''),(362586,115384,'117300','printshop','max-width','830',0,''),(362587,115384,'117300','printshop','margin_left_measure','auto',0,''),(362588,115384,'117300','printshop','margin_right_measure','auto',0,''),(362589,115384,'117300','printshop','padding-top','40',0,''),(362590,115384,'117300','printshop','padding-bottom','40',0,''),(362591,115384,'117300','printshop','schema','2-1',0,'5342'),(362592,115384,'117300','printshop','schema','2-3',0,'5333'),(362593,115384,'117300','printshop','color','$content-color-1',0,''),(362594,115385,'1644496194.7022','printshop','block_type','1',0,''),(362595,115385,'1644496194.7022','printshop','padding-left','30',0,''),(362596,115385,'1644496194.7022','printshop','padding-right','20',0,''),(362597,115385,'1644496194.7022','printshop','padding-left','20',0,'5333'),(362598,115386,'117301','printshop','text-align','center',0,''),(362599,115386,'117301','printshop','margin-bottom','40',0,''),(362600,115387,'117302','printshop','text-align','center',0,''),(362601,115388,'117303','printshop','text','##TEXT_OR##',0,''),(362602,115388,'117303','printshop','font-size','18',0,''),(362603,115388,'117303','printshop','text-align','center',0,''),(362604,115388,'117303','printshop','content','\\_',0,'3'),(362605,115388,'117303','printshop','height','5',0,'3'),(362606,115388,'117303','printshop','width','70',0,'3'),(362607,115388,'117303','printshop','display','inline-block',0,'3'),(362608,115388,'117303','printshop','border-top-width','1',0,'3'),(362609,115388,'117303','printshop','border-top-color','$content-border-3',0,'3'),(362610,115388,'117303','printshop','margin-left','10',0,'3'),(362611,115388,'117303','printshop','margin-right','10',0,'3'),(362612,115388,'117303','printshop','content','\\_',0,'4'),(362613,115388,'117303','printshop','display','inline-block',0,'4'),(362614,115388,'117303','printshop','width','70',0,'4'),(362615,115388,'117303','printshop','height','5',0,'4'),(362616,115388,'117303','printshop','border-top-width','1',0,'4'),(362617,115388,'117303','printshop','border-top-color','$content-border-3',0,'4'),(362618,115388,'117303','printshop','margin-left','10',0,'4'),(362619,115388,'117303','printshop','margin-right','10',0,'4'),(362620,115388,'117303','printshop','position','relative',0,''),(362621,115388,'117303','printshop','padding-top','10',0,''),(362622,115388,'117303','printshop','padding-bottom','10',0,''),(362623,115388,'117303','printshop','font-family','$font-1',0,''),(362624,115389,'117304','printshop','block_type','1',0,''),(362625,115390,'117305','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362626,115390,'117305','printshop','font-size','20',0,''),(362627,115390,'117305','printshop','font-family','$font-1',0,''),(362628,115390,'117305','printshop','padding-top','12',0,''),(362629,115390,'117305','printshop','text-align','left',0,''),(362630,115390,'117305','printshop','font-weight','bold',0,''),(362631,115390,'117305','printshop','margin-bottom','20',0,''),(362632,115390,'117305','printshop','position','relative',0,''),(362633,115390,'117305','printshop','height','4',0,'3'),(362634,115390,'117305','printshop','width','54',0,'3'),(362635,115390,'117305','printshop','content',' ',0,'3'),(362636,115390,'117305','printshop','background-color','$highlight-box-border-2',0,'3'),(362637,115390,'117305','printshop','position','absolute',0,'3'),(362638,115390,'117305','printshop','top','0',0,'3'),(362639,115390,'117305','printshop','left','0',0,'3'),(362640,115391,'117306','printshop','text-align','center',0,''),(362641,115391,'117306','printshop','hide_parents','2',0,''),(362642,115392,'117307','printshop','text','##NEW_CUSTOMER##',0,''),(362643,115392,'117307','printshop','font-size','20',0,''),(362644,115392,'117307','printshop','font-family','$font-1',0,''),(362645,115392,'117307','printshop','margin-bottom','20',0,''),(362646,115392,'117307','printshop','font-weight','bold',0,''),(362647,115392,'117307','printshop','height','4',0,'3'),(362648,115392,'117307','printshop','width','54',0,'3'),(362649,115392,'117307','printshop','background-color','$highlight-box-border-2',0,'3'),(362650,115392,'117307','printshop','position','absolute',0,'3'),(362651,115392,'117307','printshop','top','0',0,'3'),(362652,115392,'117307','printshop','left','0',0,'3'),(362653,115392,'117307','printshop','position','relative',0,''),(362654,115392,'117307','printshop','display','block',0,'3'),(362655,115392,'117307','printshop','content',' ',0,'3'),(362656,115392,'117307','printshop','padding-top','12',0,''),(362657,115393,'1644496248.7478','printshop','block_type','1',0,''),(362658,115393,'1644496248.7478','printshop','padding-left','20',0,''),(362659,115393,'1644496248.7478','printshop','padding-right','30',0,''),(362660,115393,'1644496248.7478','printshop','padding-right','20',0,'5333'),(362661,115394,'117308','printshop','margin_left_measure','auto',0,''),(362662,115394,'117308','printshop','margin_right_measure','auto',0,''),(362663,115394,'117308','printshop','padding-top','0',0,'5333'),(362664,115395,'117309','printshop','text','##RETURNING_CUSTOMER##',0,''),(362665,115395,'117309','printshop','font-size','20',0,''),(362666,115395,'117309','printshop','font-family','$font-1',0,''),(362667,115395,'117309','printshop','text-align','left',0,''),(362668,115395,'117309','printshop','position','relative',0,''),(362669,115395,'117309','printshop','font-weight','bold',0,''),(362670,115395,'117309','printshop','padding-top','12',0,''),(362671,115395,'117309','printshop','margin-bottom','20',0,''),(362672,115395,'117309','printshop','background-color','$highlight-box-border-2',0,'3'),(362673,115395,'117309','printshop','content',' ',0,'3'),(362674,115395,'117309','printshop','width','54',0,'3'),(362675,115395,'117309','printshop','height','4',0,'3'),(362676,115395,'117309','printshop','position','absolute',0,'3'),(362677,115395,'117309','printshop','top','0',0,'3'),(362678,115395,'117309','printshop','left','0',0,'3'),(362679,115396,'117310','printshop','block_type','1',0,''),(362680,115396,'117310','printshop','padding-top','20',0,''),(362681,115397,'117311','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(362682,115397,'117311','printshop','tab_2','RETURNING CUSTOMER',1,''),(362683,115397,'117311','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(362684,115397,'117311','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(362685,115397,'117311','printshop','tab_2','RETURNING CUSTOMER',2,''),(362686,115397,'117311','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(362687,115397,'117311','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(362688,115397,'117311','printshop','tab_2','RETURNING CUSTOMER',3,''),(362689,115397,'117311','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(362690,115397,'117311','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(362691,115397,'117311','printshop','tab_2','RETURNING CUSTOMER',4,''),(362692,115397,'117311','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(362693,115398,'117312','printshop','block_type','8',0,''),(362694,115399,'117313','printshop','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(362695,115400,'117314','printshop','block_type','1',0,''),(362696,115400,'117314','printshop','padding-left','20',0,''),(362697,115400,'117314','printshop','padding-right','20',0,''),(362698,115402,'117316','printshop','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(362699,115402,'117316','printshop','border-top-width','1',0,''),(362700,115402,'117316','printshop','border-top-color','$content-border-3',0,''),(362701,115404,'117318','printshop','block_type','8',0,''),(362702,115405,'117319','printshop','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(362703,115406,'117320','printshop','block_type','1',0,''),(362704,115406,'117320','printshop','padding-left','20',0,''),(362705,115406,'117320','printshop','padding-right','20',0,''),(362706,115407,'117321','printshop','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(362707,115409,'117323','printshop','text-align','center',0,''),(362708,115410,'117324','printshop','text','##TEXT_OR##',0,''),(362709,115410,'117324','printshop','font-size','18',0,''),(362710,115410,'117324','printshop','font-weight','700',0,''),(362711,115410,'117324','printshop','padding-top','15',0,''),(362712,115410,'117324','printshop','text-align','center',0,''),(362713,115410,'117324','printshop','content','\\_',0,'3'),(362714,115410,'117324','printshop','height','5',0,'3'),(362715,115410,'117324','printshop','width','70',0,'3'),(362716,115410,'117324','printshop','display','inline-block',0,'3'),(362717,115410,'117324','printshop','border-top-width','1',0,'3'),(362718,115410,'117324','printshop','border-top-color','$content-border-3',0,'3'),(362719,115410,'117324','printshop','margin-left','10',0,'3'),(362720,115410,'117324','printshop','margin-right','10',0,'3'),(362721,115410,'117324','printshop','content','\\_',0,'4'),(362722,115410,'117324','printshop','display','inline-block',0,'4'),(362723,115410,'117324','printshop','width','70',0,'4'),(362724,115410,'117324','printshop','height','5',0,'4'),(362725,115410,'117324','printshop','border-top-width','1',0,'4'),(362726,115410,'117324','printshop','border-top-color','$content-border-3',0,'4'),(362727,115410,'117324','printshop','margin-left','10',0,'4'),(362728,115410,'117324','printshop','margin-right','10',0,'4'),(362729,115410,'117324','printshop','position','relative',0,''),(362730,115410,'117324','printshop','top','-10',0,''),(362731,115411,'117325','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362732,115411,'117325','printshop','font-size','26',0,''),(362733,115411,'117325','printshop','font-family','$font-1',0,''),(362734,115411,'117325','printshop','padding-top','15',0,''),(362735,115411,'117325','printshop','padding-bottom','15',0,''),(362736,115411,'117325','printshop','text-align','center',0,''),(362737,115412,'117326','printshop','block_type','1',0,''),(362738,115412,'117326','printshop','padding-top','20',0,''),(362739,115413,'117327','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(362740,115413,'117327','printshop','tab_2','RETURNING CUSTOMER',1,''),(362741,115413,'117327','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(362742,115413,'117327','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(362743,115413,'117327','printshop','tab_2','RETURNING CUSTOMER',2,''),(362744,115413,'117327','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(362745,115413,'117327','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(362746,115413,'117327','printshop','tab_2','RETURNING CUSTOMER',3,''),(362747,115413,'117327','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(362748,115413,'117327','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(362749,115413,'117327','printshop','tab_2','RETURNING CUSTOMER',4,''),(362750,115413,'117327','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(362751,115414,'117328','printshop','block_type','8',0,''),(362752,115415,'117329','printshop','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(362753,115418,'117332','printshop','block_type','8',0,''),(362754,115419,'117333','printshop','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(362755,115421,'117335','printshop','block_type','1',0,''),(362756,115421,'117335','printshop','padding-left','20',0,''),(362757,115421,'117335','printshop','padding-right','20',0,''),(362758,115423,'117337','printshop','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(362759,115424,'117338','printshop','text','##TEXT_OR##',0,''),(362760,115424,'117338','printshop','font-size','18',0,''),(362761,115424,'117338','printshop','font-weight','700',0,''),(362762,115424,'117338','printshop','padding-top','15',0,''),(362763,115424,'117338','printshop','text-align','center',0,''),(362764,115424,'117338','printshop','content','\\_',0,'3'),(362765,115424,'117338','printshop','height','5',0,'3'),(362766,115424,'117338','printshop','width','70',0,'3'),(362767,115424,'117338','printshop','display','inline-block',0,'3'),(362768,115424,'117338','printshop','border-top-width','1',0,'3'),(362769,115424,'117338','printshop','border-top-color','$content-border-3',0,'3'),(362770,115424,'117338','printshop','margin-left','10',0,'3'),(362771,115424,'117338','printshop','margin-right','10',0,'3'),(362772,115424,'117338','printshop','content','\\_',0,'4'),(362773,115424,'117338','printshop','display','inline-block',0,'4'),(362774,115424,'117338','printshop','width','70',0,'4'),(362775,115424,'117338','printshop','height','5',0,'4'),(362776,115424,'117338','printshop','border-top-width','1',0,'4'),(362777,115424,'117338','printshop','border-top-color','$content-border-3',0,'4'),(362778,115424,'117338','printshop','margin-left','10',0,'4'),(362779,115424,'117338','printshop','margin-right','10',0,'4'),(362780,115424,'117338','printshop','position','relative',0,''),(362781,115424,'117338','printshop','top','-10',0,''),(362782,115425,'117339','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362783,115425,'117339','printshop','font-size','26',0,''),(362784,115425,'117339','printshop','font-family','$font-1',0,''),(362785,115425,'117339','printshop','padding-top','15',0,''),(362786,115425,'117339','printshop','padding-bottom','15',0,''),(362787,115425,'117339','printshop','text-align','center',0,''),(362788,115426,'117340','printshop','text-align','center',0,''),(362789,115427,'117341','printshop','block_type','1',0,''),(362790,115427,'117341','printshop','padding-top','20',0,''),(362791,115428,'117342','printshop','text-align','center',0,''),(362792,115429,'117343','printshop','text','##TEXT_OR##',0,''),(362793,115429,'117343','printshop','font-size','18',0,''),(362794,115429,'117343','printshop','font-weight','700',0,''),(362795,115429,'117343','printshop','padding-top','15',0,''),(362796,115429,'117343','printshop','text-align','center',0,''),(362797,115429,'117343','printshop','content','\\_',0,'3'),(362798,115429,'117343','printshop','height','5',0,'3'),(362799,115429,'117343','printshop','width','70',0,'3'),(362800,115429,'117343','printshop','display','inline-block',0,'3'),(362801,115429,'117343','printshop','border-top-width','1',0,'3'),(362802,115429,'117343','printshop','border-top-color','$content-border-3',0,'3'),(362803,115429,'117343','printshop','margin-left','10',0,'3'),(362804,115429,'117343','printshop','margin-right','10',0,'3'),(362805,115429,'117343','printshop','content','\\_',0,'4'),(362806,115429,'117343','printshop','display','inline-block',0,'4'),(362807,115429,'117343','printshop','width','70',0,'4'),(362808,115429,'117343','printshop','height','5',0,'4'),(362809,115429,'117343','printshop','border-top-width','1',0,'4'),(362810,115429,'117343','printshop','border-top-color','$content-border-3',0,'4'),(362811,115429,'117343','printshop','margin-left','10',0,'4'),(362812,115429,'117343','printshop','margin-right','10',0,'4'),(362813,115429,'117343','printshop','position','relative',0,''),(362814,115429,'117343','printshop','top','-10',0,''),(362815,115430,'117344','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(362816,115430,'117344','printshop','tab_2','RETURNING CUSTOMER',1,''),(362817,115430,'117344','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(362818,115430,'117344','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(362819,115430,'117344','printshop','tab_2','RETURNING CUSTOMER',2,''),(362820,115430,'117344','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(362821,115430,'117344','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(362822,115430,'117344','printshop','tab_2','RETURNING CUSTOMER',3,''),(362823,115430,'117344','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(362824,115430,'117344','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(362825,115430,'117344','printshop','tab_2','RETURNING CUSTOMER',4,''),(362826,115430,'117344','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(362827,115431,'117345','printshop','block_type','8',0,''),(362828,115432,'117346','printshop','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(362829,115435,'117349','printshop','block_type','8',0,''),(362830,115436,'117350','printshop','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(362831,115437,'117351','printshop','block_type','1',0,''),(362832,115437,'117351','printshop','padding-left','20',0,''),(362833,115437,'117351','printshop','padding-right','20',0,''),(362834,115439,'117353','printshop','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(362835,115440,'117354','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362836,115440,'117354','printshop','font-size','26',0,''),(362837,115440,'117354','printshop','font-family','$font-1',0,''),(362838,115440,'117354','printshop','padding-top','15',0,''),(362839,115440,'117354','printshop','padding-bottom','15',0,''),(362840,115440,'117354','printshop','text-align','center',0,''),(362841,115441,'117355','printshop','block_type','1',0,''),(362842,115441,'117355','printshop','padding-top','40',0,''),(362843,115441,'117355','printshop','background-color','$content-bg-2',0,''),(362844,115441,'117355','printshop','padding-bottom','40',0,''),(362845,115442,'117356','printshop','block_type','2',0,''),(362846,115442,'117356','printshop','background-color','$content-bg-1',0,''),(362847,115442,'117356','printshop','max-width','830',0,''),(362848,115442,'117356','printshop','margin_left_measure','auto',0,''),(362849,115442,'117356','printshop','margin_right_measure','auto',0,''),(362850,115442,'117356','printshop','padding-top','40',0,''),(362851,115442,'117356','printshop','padding-bottom','40',0,''),(362852,115442,'117356','printshop','schema','2-3',0,'5342'),(362853,115443,'117357','printshop','block_type','1',0,''),(362854,115444,'117358','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362855,115444,'117358','printshop','font-size','18',0,''),(362856,115444,'117358','printshop','font-family','$font-1',0,''),(362857,115444,'117358','printshop','padding-top','15',0,''),(362858,115444,'117358','printshop','padding-bottom','15',0,''),(362859,115444,'117358','printshop','text-align','center',0,''),(362860,115444,'117358','printshop','text-transform','uppercase',0,''),(362861,115445,'117359','printshop','text-align','center',0,''),(362862,115445,'117359','printshop','hide_parents','2',0,''),(362863,115446,'117360','printshop','text-align','center',0,''),(362864,115447,'117361','printshop','text-align','center',0,''),(362865,115447,'117361','printshop','margin-bottom','40',0,''),(362866,115448,'117362','printshop','text','##TEXT_OR##',0,''),(362867,115448,'117362','printshop','font-size','18',0,''),(362868,115448,'117362','printshop','font-weight','700',0,''),(362869,115448,'117362','printshop','text-align','center',0,''),(362870,115448,'117362','printshop','content','\\_',0,'3'),(362871,115448,'117362','printshop','height','5',0,'3'),(362872,115448,'117362','printshop','width','70',0,'3'),(362873,115448,'117362','printshop','display','inline-block',0,'3'),(362874,115448,'117362','printshop','border-top-width','1',0,'3'),(362875,115448,'117362','printshop','border-top-color','$content-border-3',0,'3'),(362876,115448,'117362','printshop','margin-left','10',0,'3'),(362877,115448,'117362','printshop','margin-right','10',0,'3'),(362878,115448,'117362','printshop','content','\\_',0,'4'),(362879,115448,'117362','printshop','display','inline-block',0,'4'),(362880,115448,'117362','printshop','width','70',0,'4'),(362881,115448,'117362','printshop','height','5',0,'4'),(362882,115448,'117362','printshop','border-top-width','1',0,'4'),(362883,115448,'117362','printshop','border-top-color','$content-border-3',0,'4'),(362884,115448,'117362','printshop','margin-left','10',0,'4'),(362885,115448,'117362','printshop','margin-right','10',0,'4'),(362886,115448,'117362','printshop','position','relative',0,''),(362887,115448,'117362','printshop','padding-top','10',0,''),(362888,115448,'117362','printshop','padding-bottom','10',0,''),(362889,115449,'117363','printshop','text','##NEW_CUSTOMER##',0,''),(362890,115449,'117363','printshop','font-size','18',0,''),(362891,115449,'117363','printshop','font-family','$font-1',0,''),(362892,115449,'117363','printshop','text-align','center',0,''),(362893,115449,'117363','printshop','text-transform','uppercase',0,''),(362894,115449,'117363','printshop','margin-bottom','10',0,''),(362895,115450,'117364','printshop','text','##RETURNING_CUSTOMER##',0,''),(362896,115450,'117364','printshop','font-size','18',0,''),(362897,115450,'117364','printshop','font-family','$font-1',0,''),(362898,115450,'117364','printshop','text-transform','uppercase',0,''),(362899,115450,'117364','printshop','text-align','center',0,''),(362900,115451,'117365','printshop','max-width','230',0,''),(362901,115451,'117365','printshop','margin_left_measure','auto',0,''),(362902,115451,'117365','printshop','margin_right_measure','auto',0,''),(362903,115452,'117366','printshop','block_type','1',0,''),(362904,115452,'117366','printshop','padding-top','40',0,''),(362905,115452,'117366','printshop','background-color','$content-bg-2',0,''),(362906,115452,'117366','printshop','padding-bottom','40',0,''),(362907,115453,'117367','printshop','block_type','2',0,''),(362908,115453,'117367','printshop','background-color','$content-bg-1',0,''),(362909,115453,'117367','printshop','max-width','830',0,''),(362910,115453,'117367','printshop','margin_left_measure','auto',0,''),(362911,115453,'117367','printshop','margin_right_measure','auto',0,''),(362912,115453,'117367','printshop','padding-top','40',0,''),(362913,115453,'117367','printshop','padding-bottom','40',0,''),(362914,115453,'117367','printshop','schema','2-3',0,'5342'),(362915,115454,'117368','printshop','text','##NEW_CUSTOMER##',0,''),(362916,115454,'117368','printshop','font-size','18',0,''),(362917,115454,'117368','printshop','font-family','$font-1',0,''),(362918,115454,'117368','printshop','text-align','center',0,''),(362919,115454,'117368','printshop','text-transform','uppercase',0,''),(362920,115454,'117368','printshop','margin-bottom','10',0,''),(362921,115455,'117369','printshop','text-align','center',0,''),(362922,115456,'117370','printshop','text-align','center',0,''),(362923,115456,'117370','printshop','margin-bottom','40',0,''),(362924,115457,'117371','printshop','text','##TEXT_OR##',0,''),(362925,115457,'117371','printshop','font-size','18',0,''),(362926,115457,'117371','printshop','font-weight','700',0,''),(362927,115457,'117371','printshop','text-align','center',0,''),(362928,115457,'117371','printshop','content','\\_',0,'3'),(362929,115457,'117371','printshop','height','5',0,'3'),(362930,115457,'117371','printshop','width','70',0,'3'),(362931,115457,'117371','printshop','display','inline-block',0,'3'),(362932,115457,'117371','printshop','border-top-width','1',0,'3'),(362933,115457,'117371','printshop','border-top-color','$content-border-3',0,'3'),(362934,115457,'117371','printshop','margin-left','10',0,'3'),(362935,115457,'117371','printshop','margin-right','10',0,'3'),(362936,115457,'117371','printshop','content','\\_',0,'4'),(362937,115457,'117371','printshop','display','inline-block',0,'4'),(362938,115457,'117371','printshop','width','70',0,'4'),(362939,115457,'117371','printshop','height','5',0,'4'),(362940,115457,'117371','printshop','border-top-width','1',0,'4'),(362941,115457,'117371','printshop','border-top-color','$content-border-3',0,'4'),(362942,115457,'117371','printshop','margin-left','10',0,'4'),(362943,115457,'117371','printshop','margin-right','10',0,'4'),(362944,115457,'117371','printshop','position','relative',0,''),(362945,115457,'117371','printshop','padding-top','10',0,''),(362946,115457,'117371','printshop','padding-bottom','10',0,''),(362947,115458,'117372','printshop','block_type','1',0,''),(362948,115459,'117373','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362949,115459,'117373','printshop','font-size','18',0,''),(362950,115459,'117373','printshop','font-family','$font-1',0,''),(362951,115459,'117373','printshop','padding-top','15',0,''),(362952,115459,'117373','printshop','padding-bottom','15',0,''),(362953,115459,'117373','printshop','text-align','center',0,''),(362954,115459,'117373','printshop','text-transform','uppercase',0,''),(362955,115460,'117374','printshop','text-align','center',0,''),(362956,115460,'117374','printshop','hide_parents','2',0,''),(362957,115461,'117375','printshop','text','##RETURNING_CUSTOMER##',0,''),(362958,115461,'117375','printshop','font-size','18',0,''),(362959,115461,'117375','printshop','font-family','$font-1',0,''),(362960,115461,'117375','printshop','text-transform','uppercase',0,''),(362961,115461,'117375','printshop','text-align','center',0,''),(362962,115462,'117376','printshop','max-width','230',0,''),(362963,115462,'117376','printshop','margin_left_measure','auto',0,''),(362964,115462,'117376','printshop','margin_right_measure','auto',0,''),(362965,115463,'117377','printshop','block_type','1',0,''),(362966,115464,'117378','printshop','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(362967,115464,'117378','printshop','margin-bottom','30',0,''),(362968,115465,'117379','printshop','block_type','1',0,''),(362969,115466,'117380','printshop','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(362970,115466,'117380','printshop','margin-bottom','30',0,''),(362971,115467,'117386','printshop','block_type','1',0,''),(362972,115467,'117386','printshop','font-weight','normal',0,''),(362973,115467,'117386','printshop','style_class','index-wrap',0,''),(362974,115468,'120856','printshop','block_type','1',0,''),(362975,115468,'120856','printshop','style_class','doubleBanner',0,''),(362976,115469,'120857','printshop','banners_group','double-pri',0,''),(362977,115469,'120857','printshop','template','1',0,''),(362978,115469,'120857','printshop','banners_type','banner',0,''),(362979,115470,'120862','printshop','block_type','1',0,''),(362980,115471,'117389','printshop','col_in_row','2',0,''),(362981,115471,'117389','printshop','show_attributes','1',0,''),(362982,115471,'117389','printshop','listing_type','productListing',0,''),(362983,115471,'117389','printshop','show_qty_input','1',0,''),(362984,115471,'117389','printshop','show_compare','1',0,''),(362985,115471,'117389','printshop','lazy_load','1',0,''),(362986,115471,'117389','printshop','show_model','1',0,''),(362987,115471,'117389','printshop','show_properties','1',0,''),(362988,115471,'117389','printshop','show_bonus_points','1',0,''),(362989,115471,'117389','printshop','show_buy_button','1',0,''),(362990,115471,'117389','printshop','show_wishlist_button','1',0,''),(362991,115471,'117389','printshop','hide_parents','2',0,''),(362992,115471,'117389','printshop','col_in_row','1',0,'5363'),(362993,115472,'121014','printshop','text','<h2>New Arrivals</h2>',0,''),(362994,115473,'1644485886.0558','printshop','block_type','1',0,''),(362995,115473,'1644485886.0558','printshop','style_class','tripleLine',0,''),(362996,115473,'1644485886.0558','printshop','padding-top','30',0,''),(362997,115473,'1644485886.0558','printshop','padding-bottom','30',0,''),(362998,115474,'1644486520.9017','printshop','banners_group','triple-lin',0,''),(362999,115474,'1644486520.9017','printshop','banners_type','banner',0,''),(363000,115474,'1644486520.9017','printshop','template','1',0,''),(363001,115475,'1644577826.0002','printshop','block_type','1',0,''),(363002,115475,'1644577826.0002','printshop','style_class','middleBanner',0,''),(363003,115476,'1644321730.7025','printshop','banners_group','middle-pri',0,''),(363004,115476,'1644321730.7025','printshop','margin-bottom','30',0,''),(363005,115476,'1644321730.7025','printshop','template','1',0,''),(363006,115476,'1644321730.7025','printshop','banners_type','banner',0,''),(363007,115476,'1644321730.7025','printshop','ban_id','124',0,''),(363008,115477,'1644580572.4789','printshop','block_type','1',0,''),(363009,115477,'1644580572.4789','printshop','style_class','bottomDoubleBanner',0,''),(363010,115478,'1644580744.5807','printshop','banners_group','bottom-dou',0,''),(363011,115478,'1644580744.5807','printshop','banners_type','banner',0,''),(363012,115478,'1644580744.5807','printshop','template','1',0,''),(363013,115479,'1644580721.7097','printshop','block_type','1',0,''),(363014,115479,'1644580721.7097','printshop','style_class','bottomBanner',0,''),(363015,115480,'120865','printshop','banners_group','home-botto',0,''),(363016,115480,'120865','printshop','banners_type','banner',0,''),(363017,115480,'120865','printshop','margin-bottom','30',0,''),(363018,115480,'120865','printshop','template','1',0,''),(363019,115481,'1644601798.7155','printshop','block_type','1',0,''),(363020,115481,'1644601798.7155','printshop','style_class','topBanner',0,''),(363021,115482,'1683025508.153','printshop','banners_group','4',0,''),(363022,115484,'117394','printshop','block_type','1',0,''),(363023,115485,'117395','printshop','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(363024,115487,'117397','printshop','block_type','1',0,''),(363025,115487,'117397','printshop','padding-top','40',0,''),(363026,115487,'117397','printshop','padding-bottom','80',0,''),(363027,115488,'117398','printshop','block_type','6',0,''),(363028,115489,'117399','printshop','block_type','1',0,''),(363029,115489,'117399','printshop','padding-top','20',0,''),(363030,115489,'117399','printshop','padding-left','20',0,''),(363031,115489,'117399','printshop','padding-right','20',0,''),(363032,115489,'117399','printshop','padding-bottom','20',0,''),(363033,115489,'117399','printshop','border-top-width','1',0,''),(363034,115489,'117399','printshop','border-left-width','1',0,''),(363035,115489,'117399','printshop','border-right-width','1',0,''),(363036,115489,'117399','printshop','border-bottom-width','1',0,''),(363037,115489,'117399','printshop','border-top-color','$content-border-3',0,''),(363038,115489,'117399','printshop','border-left-color','$content-border-3',0,''),(363039,115489,'117399','printshop','border-right-color','$content-border-3',0,''),(363040,115489,'117399','printshop','border-bottom-color','$content-border-3',0,''),(363041,115489,'117399','printshop','margin-right','20',0,''),(363042,115492,'117402','printshop','block_type','1',0,''),(363043,115492,'117402','printshop','padding-top','20',0,''),(363044,115493,'117403','printshop','block_type','6',0,''),(363045,115494,'117404','printshop','padding-right','20',0,''),(363046,115496,'117406','printshop','block_type','1',0,''),(363047,115496,'117406','printshop','padding-top','20',0,''),(363048,115497,'117407','printshop','block_type','6',0,''),(363049,115498,'117408','printshop','padding-right','20',0,''),(363050,115500,'117410','printshop','block_type','1',0,''),(363051,115500,'117410','printshop','style_class','account-password-wrap',0,''),(363052,115501,'117411','printshop','block_type','6',0,''),(363053,115501,'117411','printshop','schema','6-3',0,'5342'),(363054,115502,'117412','printshop','aria_name','account-menu',0,''),(363117,115523,'117414','printshop','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(363118,115524,'117415','printshop','block_type','1',0,''),(363119,115524,'117415','printshop','padding-top','20',0,''),(363120,115525,'117416','printshop','tab_1','RETURNING CUSTOMER',1,''),(363121,115525,'117416','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(363122,115525,'117416','printshop','tab_1','RETURNING CUSTOMER',2,''),(363123,115525,'117416','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(363124,115525,'117416','printshop','tab_1','RETURNING CUSTOMER',3,''),(363125,115525,'117416','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(363126,115525,'117416','printshop','tab_1','RETURNING CUSTOMER',4,''),(363127,115525,'117416','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(363128,115526,'117417','printshop','max-width','800',0,''),(363129,115526,'117417','printshop','margin_left_measure','auto',0,''),(363130,115526,'117417','printshop','margin_right_measure','auto',0,''),(363131,115527,'117418','printshop','block_type','8',0,''),(363132,115528,'117419','printshop','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(363133,115529,'117420','printshop','block_type','1',0,''),(363134,115529,'117420','printshop','padding-left','20',0,''),(363135,115529,'117420','printshop','padding-right','20',0,''),(363136,115531,'117422','printshop','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(363137,115532,'117423','printshop','block_type','1',0,''),(363138,115533,'117424','printshop','block_type','1',0,''),(363139,115534,'117425','printshop','margin-left','0',0,''),(363140,115534,'117425','printshop','margin-right','0',0,''),(363141,115534,'117425','printshop','margin-bottom','20',0,''),(363142,115535,'117426','printshop','margin-bottom','30',0,''),(363143,115536,'117427','printshop','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(363144,115537,'117428','printshop','block_type','1',0,''),(363145,115539,'117430','printshop','block_type','6',0,''),(363146,115539,'117430','printshop','font-weight','400',0,''),(363147,115539,'117430','printshop','schema','6-2',0,'5363'),(363148,115539,'117430','printshop','schema','6-2',0,'5342'),(363149,115540,'117431','printshop','font-weight','400',0,''),(363150,115540,'117431','printshop','padding-right','40',0,''),(363151,115540,'117431','printshop','padding-right','0',0,'5363'),(363152,115540,'117431','printshop','padding-right','0',0,'5342'),(363153,115541,'117432','printshop','col_in_row','3',0,''),(363154,115541,'117432','printshop','products_align','left',0,''),(363155,115541,'117432','printshop','font-weight','400',0,''),(363156,115541,'117432','printshop','show_qty_input','0',0,''),(363157,115541,'117432','printshop','listing_type','productListing',0,''),(363158,115541,'117432','printshop','listing_type_rows','no',0,''),(363159,115541,'117432','printshop','show_buy_button_b2b','on',0,''),(363160,115541,'117432','printshop','show_wishlist_button_b2b','1',0,''),(363161,115541,'117432','printshop','show_compare_b2b','1',0,''),(363162,115541,'117432','printshop','show_stock','0',0,''),(363163,115541,'117432','printshop','show_description','0',0,''),(363164,115541,'117432','printshop','show_model','0',0,''),(363165,115541,'117432','printshop','show_properties','0',0,''),(363166,115541,'117432','printshop','show_rating','0',0,''),(363167,115541,'117432','printshop','show_rating_counts','0',0,''),(363168,115541,'117432','printshop','show_price','0',0,''),(363169,115541,'117432','printshop','show_buy_button','0',0,''),(363170,115541,'117432','printshop','show_view_button','0',0,''),(363171,115541,'117432','printshop','show_wishlist_button','0',0,''),(363172,115541,'117432','printshop','show_compare','0',0,''),(363173,115541,'117432','printshop','show_name_rows','0',0,''),(363174,115541,'117432','printshop','show_image_rows','0',0,''),(363175,115541,'117432','printshop','show_stock_rows','0',0,''),(363176,115541,'117432','printshop','show_description_rows','0',0,''),(363177,115541,'117432','printshop','show_model_rows','0',0,''),(363178,115541,'117432','printshop','show_properties_rows','0',0,''),(363179,115541,'117432','printshop','show_rating_rows','0',0,''),(363180,115541,'117432','printshop','show_rating_counts_rows','0',0,''),(363181,115541,'117432','printshop','show_price_rows','0',0,''),(363182,115541,'117432','printshop','show_buy_button_rows','0',0,''),(363183,115541,'117432','printshop','show_qty_input_rows','0',0,''),(363184,115541,'117432','printshop','show_view_button_rows','0',0,''),(363185,115541,'117432','printshop','show_wishlist_button_rows','0',0,''),(363186,115541,'117432','printshop','show_compare_rows','0',0,''),(363187,115541,'117432','printshop','show_name_b2b','0',0,''),(363188,115541,'117432','printshop','show_image_b2b','0',0,''),(363189,115541,'117432','printshop','show_stock_b2b','0',0,''),(363190,115541,'117432','printshop','show_description_b2b','0',0,''),(363191,115541,'117432','printshop','show_model_b2b','0',0,''),(363192,115541,'117432','printshop','show_properties_b2b','0',0,''),(363193,115541,'117432','printshop','show_rating_b2b','0',0,''),(363194,115541,'117432','printshop','show_rating_counts_b2b','0',0,''),(363195,115541,'117432','printshop','show_price_b2b','0',0,''),(363196,115541,'117432','printshop','show_qty_input_b2b','0',0,''),(363197,115541,'117432','printshop','show_view_button_b2b','0',0,''),(363198,115541,'117432','printshop','show_attributes_b2b','0',0,''),(363199,115541,'117432','printshop','items_on_page','9',0,''),(363200,115541,'117432','printshop','col_in_row','2',0,'5342'),(363201,115541,'117432','printshop','col_in_row','1',0,'5363'),(363202,115541,'117432','printshop','product_names_teg','h2',0,''),(363203,115543,'117434','printshop','block_type','5',0,''),(363204,115543,'117434','printshop','padding-top','10',0,''),(363205,115543,'117434','printshop','padding-bottom','10',0,''),(363206,115543,'117434','printshop','schema','5-2',0,'5363'),(363207,115543,'117434','printshop','border-top-color','$content-border-3',0,''),(363208,115543,'117434','printshop','border-top-width','1',0,''),(363209,115545,'117436','printshop','float','right',0,''),(363210,115546,'117437','printshop','listing_type','productListing',0,''),(363211,115548,'117439','printshop','block_type','1',0,''),(363212,115548,'117439','printshop','padding-top','10',0,''),(363213,115548,'117439','printshop','padding-bottom','10',0,''),(363214,115548,'117439','printshop','border-bottom-width','1',0,''),(363215,115548,'117439','printshop','border-bottom-color','$content-border-3',0,''),(363216,115548,'117439','printshop','margin-left','0',0,''),(363217,115548,'117439','printshop','margin-right','0',0,''),(363218,115549,'117440','printshop','float','right',0,''),(363219,115549,'117440','printshop','display','none',0,'5363'),(363220,115550,'117441','printshop','float','left',0,''),(363221,115550,'117441','printshop','clear','none',0,''),(363222,115550,'117441','printshop','margin-left','20',0,''),(363223,115550,'117441','printshop','display','none',0,'5363'),(363224,115551,'117442','printshop','margin-right','20',0,''),(363225,115551,'117442','printshop','float','right',0,''),(363226,115551,'117442','printshop','clear','none',0,''),(363227,115551,'117442','printshop','display','none',0,'5342'),(363228,115552,'117443','printshop','float','left',0,''),(363229,115552,'117443','printshop','clear','none',0,''),(363230,115552,'117443','printshop','sort_pos_3','1',0,''),(363231,115552,'117443','printshop','sort_pos_4','2',0,''),(363232,115552,'117443','printshop','sort_pos_10','3',0,''),(363233,115552,'117443','printshop','sort_pos_9','4',0,''),(363234,115552,'117443','printshop','sort_pos_11','5',0,''),(363235,115552,'117443','printshop','sort_pos_12','6',0,''),(363236,115552,'117443','printshop','sort_pos_14','7',0,''),(363237,115552,'117443','printshop','sort_pos_13','8',0,''),(363238,115552,'117443','printshop','sort_pos_8','9',0,''),(363239,115552,'117443','printshop','sort_pos_7','10',0,''),(363240,115552,'117443','printshop','sort_pos_2','11',0,''),(363241,115552,'117443','printshop','sort_pos_1','12',0,''),(363242,115552,'117443','printshop','sort_pos_6','13',0,''),(363243,115552,'117443','printshop','sort_pos_5','14',0,''),(363244,115552,'117443','printshop','sort_pos_0','15',0,''),(363245,115552,'117443','printshop','sort_hide_10','1',0,''),(363246,115552,'117443','printshop','sort_hide_9','1',0,''),(363247,115552,'117443','printshop','hide_icons','1',0,''),(363248,115552,'117443','printshop','sort_hide_16','1',0,''),(363249,115552,'117443','printshop','sort_hide_15','1',0,''),(363250,115552,'117443','printshop','sort_hide_3','0',0,''),(363251,115552,'117443','printshop','sort_hide_4','0',0,''),(363252,115552,'117443','printshop','sort_hide_11','1',0,''),(363253,115552,'117443','printshop','sort_hide_12','1',0,''),(363254,115552,'117443','printshop','sort_hide_14','1',0,''),(363255,115552,'117443','printshop','sort_hide_13','1',0,''),(363256,115552,'117443','printshop','sort_hide_8','0',0,''),(363257,115552,'117443','printshop','sort_hide_7','0',0,''),(363258,115552,'117443','printshop','sort_hide_2','1',0,''),(363259,115552,'117443','printshop','sort_hide_1','1',0,''),(363260,115552,'117443','printshop','sort_hide_6','1',0,''),(363261,115552,'117443','printshop','sort_hide_5','1',0,''),(363262,115552,'117443','printshop','sort_hide_0','1',0,''),(363263,115553,'117444','printshop','block_type','1',0,''),(363264,115554,'117445','printshop','margin-bottom','30',0,''),(363265,115555,'117446','printshop','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(363266,115556,'117447','printshop','block_type','1',0,''),(363267,115557,'117448','printshop','block_type','5',0,''),(363268,115557,'117448','printshop','padding-top','10',0,''),(363269,115557,'117448','printshop','padding-bottom','10',0,''),(363270,115557,'117448','printshop','schema','5-2',0,'5363'),(363271,115557,'117448','printshop','border-top-color','$content-border-3',0,''),(363272,115557,'117448','printshop','border-top-width','1',0,''),(363273,115558,'117449','printshop','padding-top','3',0,''),(363274,115559,'117450','printshop','float','right',0,''),(363275,115559,'117450','printshop','height','31',0,''),(363276,115560,'117451','printshop','col_in_row','2',0,''),(363277,115560,'117451','printshop','products_align','left',0,''),(363278,115560,'117451','printshop','font-weight','400',0,''),(363279,115560,'117451','printshop','listing_type','productListing',0,''),(363280,115560,'117451','printshop','listing_type_rows','Rows',0,''),(363281,115560,'117451','printshop','show_buy_button_b2b','on',0,''),(363282,115560,'117451','printshop','show_wishlist_button_b2b','1',0,''),(363283,115560,'117451','printshop','show_compare_b2b','1',0,''),(363284,115560,'117451','printshop','show_image','0',0,''),(363285,115560,'117451','printshop','show_stock','0',0,''),(363286,115560,'117451','printshop','show_description','0',0,''),(363287,115560,'117451','printshop','show_model','0',0,''),(363288,115560,'117451','printshop','show_properties','0',0,''),(363289,115560,'117451','printshop','show_rating','0',0,''),(363290,115560,'117451','printshop','show_rating_counts','0',0,''),(363291,115560,'117451','printshop','show_price','0',0,''),(363292,115560,'117451','printshop','show_buy_button','0',0,''),(363293,115560,'117451','printshop','show_view_button','0',0,''),(363294,115560,'117451','printshop','show_wishlist_button','0',0,''),(363295,115560,'117451','printshop','show_compare','0',0,''),(363296,115560,'117451','printshop','show_name_rows','0',0,''),(363297,115560,'117451','printshop','show_image_rows','0',0,''),(363298,115560,'117451','printshop','show_stock_rows','0',0,''),(363299,115560,'117451','printshop','show_description_rows','0',0,''),(363300,115560,'117451','printshop','show_model_rows','0',0,''),(363301,115560,'117451','printshop','show_properties_rows','0',0,''),(363302,115560,'117451','printshop','show_rating_rows','0',0,''),(363303,115560,'117451','printshop','show_rating_counts_rows','0',0,''),(363304,115560,'117451','printshop','show_price_rows','0',0,''),(363305,115560,'117451','printshop','show_buy_button_rows','0',0,''),(363306,115560,'117451','printshop','show_qty_input_rows','0',0,''),(363307,115560,'117451','printshop','show_view_button_rows','0',0,''),(363308,115560,'117451','printshop','show_wishlist_button_rows','0',0,''),(363309,115560,'117451','printshop','show_compare_rows','0',0,''),(363310,115560,'117451','printshop','show_name_b2b','0',0,''),(363311,115560,'117451','printshop','show_image_b2b','0',0,''),(363312,115560,'117451','printshop','show_stock_b2b','0',0,''),(363313,115560,'117451','printshop','show_description_b2b','0',0,''),(363314,115560,'117451','printshop','show_model_b2b','0',0,''),(363315,115560,'117451','printshop','show_properties_b2b','0',0,''),(363316,115560,'117451','printshop','show_rating_b2b','0',0,''),(363317,115560,'117451','printshop','show_rating_counts_b2b','0',0,''),(363318,115560,'117451','printshop','show_price_b2b','0',0,''),(363319,115560,'117451','printshop','show_qty_input_b2b','0',0,''),(363320,115560,'117451','printshop','show_view_button_b2b','0',0,''),(363321,115560,'117451','printshop','show_attributes_b2b','0',0,''),(363322,115560,'117451','printshop','items_on_page','12',0,''),(363323,115560,'117451','printshop','col_in_row','2',0,'5342'),(363324,115560,'117451','printshop','col_in_row','1',0,'5363'),(363325,115560,'117451','printshop','product_names_teg','h2',0,''),(363326,115561,'117452','printshop','show_heading','h1',0,''),(363327,115563,'117454','printshop','block_type','1',0,''),(363328,115564,'117455','printshop','block_type','1',0,''),(363329,115564,'117455','printshop','padding-top','10',0,''),(363330,115564,'117455','printshop','padding-bottom','10',0,''),(363331,115564,'117455','printshop','margin-left','0',0,''),(363332,115564,'117455','printshop','margin-right','0',0,''),(363333,115565,'117456','printshop','clear','none',0,''),(363334,115565,'117456','printshop','float','left',0,''),(363335,115565,'117456','printshop','padding-top','3',0,''),(363336,115565,'117456','printshop','margin-left','20',0,''),(363337,115566,'117457','printshop','float','right',0,''),(363338,115566,'117457','printshop','display','none',0,'5363'),(363339,115567,'117458','printshop','margin-right','20',0,''),(363340,115567,'117458','printshop','float','right',0,''),(363341,115567,'117458','printshop','clear','none',0,''),(363342,115567,'117458','printshop','display','none',0,'5342'),(363343,115568,'117459','printshop','float','left',0,''),(363344,115568,'117459','printshop','clear','none',0,''),(363345,115568,'117459','printshop','margin-left','20',0,''),(363346,115568,'117459','printshop','display','none',0,'5363'),(363347,115569,'117460','printshop','float','left',0,''),(363348,115569,'117460','printshop','clear','none',0,''),(363349,115569,'117460','printshop','sort_pos_3','2',0,''),(363350,115569,'117460','printshop','sort_pos_4','3',0,''),(363351,115569,'117460','printshop','sort_pos_10','11',0,''),(363352,115569,'117460','printshop','sort_pos_9','10',0,''),(363353,115569,'117460','printshop','sort_pos_11','12',0,''),(363354,115569,'117460','printshop','sort_pos_12','13',0,''),(363355,115569,'117460','printshop','sort_pos_14','15',0,''),(363356,115569,'117460','printshop','sort_pos_13','14',0,''),(363357,115569,'117460','printshop','sort_pos_8','4',0,''),(363358,115569,'117460','printshop','sort_pos_7','5',0,''),(363359,115569,'117460','printshop','sort_pos_2','7',0,''),(363360,115569,'117460','printshop','sort_pos_1','6',0,''),(363361,115569,'117460','printshop','sort_pos_6','9',0,''),(363362,115569,'117460','printshop','sort_pos_5','8',0,''),(363363,115569,'117460','printshop','sort_pos_0','1',0,''),(363364,115569,'117460','printshop','sort_hide_10','1',0,''),(363365,115569,'117460','printshop','sort_hide_9','1',0,''),(363366,115569,'117460','printshop','sort_pos_15','16',0,''),(363367,115569,'117460','printshop','sort_pos_16','17',0,''),(363368,115569,'117460','printshop','sort_hide_4','0',0,''),(363369,115569,'117460','printshop','sort_hide_3','0',0,''),(363370,115569,'117460','printshop','sort_hide_16','1',0,''),(363371,115569,'117460','printshop','sort_hide_15','1',0,''),(363372,115569,'117460','printshop','sort_hide_11','1',0,''),(363373,115569,'117460','printshop','sort_hide_12','1',0,''),(363374,115569,'117460','printshop','sort_hide_14','1',0,''),(363375,115569,'117460','printshop','sort_hide_13','1',0,''),(363376,115569,'117460','printshop','sort_hide_8','0',0,''),(363377,115569,'117460','printshop','sort_hide_7','0',0,''),(363378,115569,'117460','printshop','sort_hide_2','1',0,''),(363379,115569,'117460','printshop','sort_hide_1','1',0,''),(363380,115569,'117460','printshop','sort_hide_6','1',0,''),(363381,115569,'117460','printshop','sort_hide_5','1',0,''),(363382,115569,'117460','printshop','sort_hide_0','0',0,''),(363383,115569,'117460','printshop','hide_icons','1',0,''),(363384,115570,'117461','printshop','margin-bottom','20',0,''),(363385,115571,'1645199275.381','printshop','block_type','1',0,''),(363386,115571,'1645199275.381','printshop','background-color','$content-bg-2',0,''),(363387,115571,'1645199275.381','printshop','padding-top','10',0,''),(363388,115571,'1645199275.381','printshop','padding-bottom','10',0,''),(363389,115571,'1645199275.381','printshop','color','$content-color-2',0,''),(363390,115573,'117462','printshop','block_type','1',0,''),(363391,115573,'117462','printshop','style_class','account-order-history',0,''),(363463,115597,'117467','printshop','block_type','1',0,''),(363464,115597,'117467','printshop','style_class','account-order-history-info',0,''),(363601,115656,'117507','printshop','block_type','1',0,''),(363602,115656,'117507','printshop','style_class','account-order-pay',0,''),(363603,115657,'117508','printshop','block_type','6',0,''),(363604,115657,'117508','printshop','schema','6-3',0,'5342'),(363605,115658,'117509','printshop','aria_name','account-menu',0,''),(363668,115679,'117511','printshop','block_type','3',0,''),(363669,115680,'117512','printshop','block_type','1',0,''),(363670,115680,'117512','printshop','padding-right','20',0,''),(363671,115680,'117512','printshop','padding-bottom','20',0,''),(363672,115681,'117513','printshop','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(363673,115682,'117514','printshop','orders_data','name',0,''),(363674,115682,'117514','printshop','padding-left','30',0,''),(363675,115683,'117515','printshop','block_type','1',0,''),(363676,115684,'117516','printshop','padding-left','30',0,''),(363677,115685,'117517','printshop','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(363678,115686,'117518','printshop','block_type','1',0,''),(363679,115686,'117518','printshop','padding-right','20',0,''),(363680,115686,'117518','printshop','padding-bottom','20',0,''),(363681,115687,'117519','printshop','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(363682,115688,'117520','printshop','orders_data','delivery_address',0,''),(363683,115688,'117520','printshop','padding-left','30',0,''),(363684,115689,'117521','printshop','block_type','1',0,''),(363685,115689,'117521','printshop','padding-right','20',0,''),(363686,115690,'117522','printshop','orders_data','shipping_method',0,''),(363687,115690,'117522','printshop','padding-left','30',0,''),(363688,115691,'117523','printshop','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(363689,115692,'117524','printshop','block_type','1',0,''),(363690,115693,'117525','printshop','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(363691,115694,'117526','printshop','orders_data','payment_method',0,''),(363692,115694,'117526','printshop','padding-left','30',0,''),(363693,115695,'117527','printshop','block_type','1',0,''),(363694,115695,'117527','printshop','padding-bottom','20',0,''),(363695,115696,'117528','printshop','orders_data','billing_address',0,''),(363696,115696,'117528','printshop','padding-left','30',0,''),(363697,115697,'117529','printshop','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(363698,115698,'117530','printshop','margin-bottom','20',0,''),(363699,115698,'117530','printshop','orders_data','name',0,''),(363700,115699,'117531','printshop','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(363701,115702,'117534','printshop','width','680',0,''),(363702,115702,'117534','printshop','font-weight','400',0,''),(363703,115702,'117534','printshop','font-size','12',0,''),(363704,115702,'117534','printshop','padding-top','20',0,''),(363705,115702,'117534','printshop','padding-bottom','20',0,''),(363706,115703,'117535','printshop','block_type','2',0,''),(363707,115703,'117535','printshop','font-weight','normal',0,''),(363708,115703,'117535','printshop','padding-bottom','20',0,''),(363709,115704,'117536','printshop','font-weight','400',0,''),(363710,115704,'117536','printshop','padding-top','10',0,''),(363711,115704,'117536','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',1,''),(363712,115704,'117536','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',2,''),(363713,115704,'117536','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',3,''),(363714,115704,'117536','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',4,''),(363715,115705,'117537','printshop','block_type','11',0,''),(363716,115705,'117537','printshop','font-weight','normal',0,''),(363717,115706,'117538','printshop','text','<p>Email:</p>',1,''),(363718,115706,'117538','printshop','font-weight','normal',0,''),(363719,115706,'117538','printshop','text-align','right',0,''),(363720,115706,'117538','printshop','text','<p>Email:</p>',2,''),(363721,115706,'117538','printshop','text','<p>Email:</p>',3,''),(363722,115706,'117538','printshop','text','<p>Email:</p>',4,''),(363723,115707,'117539','printshop','font-weight','normal',0,''),(363724,115707,'117539','printshop','text-align','right',0,''),(363725,115708,'117540','printshop','block_type','11',0,''),(363726,115708,'117540','printshop','font-weight','normal',0,''),(363727,115709,'117541','printshop','text','<p>Phone:</p>',1,''),(363728,115709,'117541','printshop','font-weight','normal',0,''),(363729,115709,'117541','printshop','text-align','right',0,''),(363730,115709,'117541','printshop','text','<p>Phone:</p>',2,''),(363731,115709,'117541','printshop','text','<p>Phone:</p>',3,''),(363732,115709,'117541','printshop','text','<p>Phone:</p>',4,''),(363733,115710,'117542','printshop','font-weight','normal',0,''),(363734,115710,'117542','printshop','text-align','right',0,''),(363735,115711,'117543','printshop','block_type','1',0,''),(363736,115712,'117544','printshop','font-weight','400',0,''),(363737,115712,'117544','printshop','text-align','right',0,''),(363738,115712,'117544','printshop','padding-bottom','10',0,''),(363739,115712,'117544','printshop','address_spacer',',',0,''),(363740,115712,'117544','printshop','font-size','12',0,''),(363741,115713,'117545','printshop','block_type','11',0,''),(363742,115713,'117545','printshop','font-weight','400',0,''),(363743,115714,'117546','printshop','text','<p>Web:</p>',1,''),(363744,115714,'117546','printshop','font-weight','400',0,''),(363745,115714,'117546','printshop','text-align','right',0,''),(363746,115714,'117546','printshop','text','<p>Web:</p>',2,''),(363747,115714,'117546','printshop','text','<p>Web:</p>',3,''),(363748,115714,'117546','printshop','text','<p>Web:</p>',4,''),(363749,115715,'117547','printshop','font-weight','normal',0,''),(363750,115715,'117547','printshop','text-align','right',0,''),(363751,115716,'117548','printshop','font-weight','normal',0,''),(363752,115716,'117548','printshop','padding-top','20',0,''),(363753,115716,'117548','printshop','font-size','12',0,''),(363754,115717,'117549','printshop','block_type','1',0,''),(363755,115717,'117549','printshop','font-weight','normal',0,''),(363756,115717,'117549','printshop','padding-top','10',0,''),(363757,115717,'117549','printshop','padding-bottom','10',0,''),(363758,115719,'117551','printshop','text','<p>If undelivered please return to:</p>',1,''),(363759,115719,'117551','printshop','font-weight','bold',0,''),(363760,115719,'117551','printshop','text','<p>If undelivered please return to:</p>',2,''),(363761,115719,'117551','printshop','text','<p>If undelivered please return to:</p>',3,''),(363762,115719,'117551','printshop','text','<p>If undelivered please return to:</p>',4,''),(363763,115720,'117552','printshop','block_type','4',0,''),(363764,115720,'117552','printshop','font-weight','400',0,''),(363765,115720,'117552','printshop','border-top-width','1',0,''),(363766,115720,'117552','printshop','border-top-color','$content-border-3',0,''),(363767,115720,'117552','printshop','border-left-width','1',0,''),(363768,115720,'117552','printshop','border-left-color','$content-border-3',0,''),(363769,115720,'117552','printshop','border-right-width','1',0,''),(363770,115720,'117552','printshop','border-right-color','$content-border-3',0,''),(363771,115720,'117552','printshop','border-bottom-width','1',0,''),(363772,115720,'117552','printshop','border-bottom-color','$content-border-3',0,''),(363773,115721,'117553','printshop','block_type','2',0,''),(363774,115721,'117553','printshop','font-weight','normal',0,''),(363775,115721,'117553','printshop','border-right-width','1',0,''),(363776,115721,'117553','printshop','border-right-color','$content-border-3',0,''),(363777,115722,'117554','printshop','block_type','1',0,''),(363778,115722,'117554','printshop','font-weight','normal',0,''),(363779,115722,'117554','printshop','border-right-width','1',0,''),(363780,115722,'117554','printshop','border-right-color','$content-border-3',0,''),(363781,115722,'117554','printshop','background-color','$content-bg-2',0,''),(363782,115722,'117554','printshop','padding-top','10',0,''),(363783,115722,'117554','printshop','padding-left','10',0,''),(363784,115722,'117554','printshop','padding-right','10',0,''),(363785,115722,'117554','printshop','padding-bottom','10',0,''),(363786,115723,'117555','printshop','font-size','12',0,''),(363787,115723,'117555','printshop','font-weight','normal',0,''),(363788,115724,'117556','printshop','text','<p>SHIPPING ADDRESS:</p>',1,''),(363789,115724,'117556','printshop','font-size','13',0,''),(363790,115724,'117556','printshop','font-weight','bold',0,''),(363791,115724,'117556','printshop','padding-bottom','10',0,''),(363792,115724,'117556','printshop','text','<p>SHIPPING ADDRESS:</p>',2,''),(363793,115724,'117556','printshop','text','<p>SHIPPING ADDRESS:</p>',3,''),(363794,115724,'117556','printshop','text','<p>SHIPPING ADDRESS:</p>',4,''),(363795,115725,'117557','printshop','block_type','1',0,''),(363796,115725,'117557','printshop','font-weight','normal',0,''),(363797,115725,'117557','printshop','padding-top','10',0,''),(363798,115725,'117557','printshop','padding-left','10',0,''),(363799,115725,'117557','printshop','padding-right','10',0,''),(363800,115725,'117557','printshop','padding-bottom','10',0,''),(363801,115726,'117558','printshop','text','<p>CUSTOMER:</p>',1,''),(363802,115726,'117558','printshop','font-size','13',0,''),(363803,115726,'117558','printshop','font-weight','bold',0,''),(363804,115726,'117558','printshop','text','<p>CUSTOMER:</p>',2,''),(363805,115726,'117558','printshop','text','<p>CUSTOMER:</p>',3,''),(363806,115726,'117558','printshop','text','<p>CUSTOMER:</p>',4,''),(363807,115727,'117559','printshop','font-size','12',0,''),(363808,115729,'117561','printshop','text','<p>PHONE NUMBER:</p>',1,''),(363809,115729,'117561','printshop','font-size','13',0,''),(363810,115729,'117561','printshop','font-weight','bold',0,''),(363811,115729,'117561','printshop','padding-top','10',0,''),(363812,115729,'117561','printshop','text','<p>PHONE NUMBER:</p>',2,''),(363813,115729,'117561','printshop','text','<p>PHONE NUMBER:</p>',3,''),(363814,115729,'117561','printshop','text','<p>PHONE NUMBER:</p>',4,''),(363815,115730,'117562','printshop','font-size','12',0,''),(363816,115731,'117563','printshop','text','<p>E-MAIL ADDRESS:</p>',1,''),(363817,115731,'117563','printshop','font-size','13',0,''),(363818,115731,'117563','printshop','font-weight','bold',0,''),(363819,115731,'117563','printshop','padding-top','10',0,''),(363820,115731,'117563','printshop','text','<p>E-MAIL ADDRESS:</p>',2,''),(363821,115731,'117563','printshop','text','<p>E-MAIL ADDRESS:</p>',3,''),(363822,115731,'117563','printshop','text','<p>E-MAIL ADDRESS:</p>',4,''),(363823,115732,'117564','printshop','block_type','2',0,''),(363824,115732,'117564','printshop','font-weight','normal',0,''),(363825,115732,'117564','printshop','border-right-width','1',0,''),(363826,115732,'117564','printshop','border-right-color','$content-border-3',0,''),(363827,115732,'117564','printshop','border-top-width','1',0,''),(363828,115732,'117564','printshop','border-top-color','$content-border-3',0,''),(363829,115733,'117565','printshop','block_type','1',0,''),(363830,115733,'117565','printshop','font-weight','normal',0,''),(363831,115733,'117565','printshop','padding-top','10',0,''),(363832,115733,'117565','printshop','padding-left','10',0,''),(363833,115733,'117565','printshop','padding-right','10',0,''),(363834,115733,'117565','printshop','padding-bottom','10',0,''),(363835,115733,'117565','printshop','border-right-width','1',0,''),(363836,115733,'117565','printshop','border-right-color','$content-border-3',0,''),(363837,115735,'117567','printshop','text','<p>Shipping via</p>',1,''),(363838,115735,'117567','printshop','font-weight','bold',0,''),(363839,115735,'117567','printshop','text','<p>Shipping via</p>',2,''),(363840,115735,'117567','printshop','text','<p>Shipping via</p>',3,''),(363841,115735,'117567','printshop','text','<p>Shipping via</p>',4,''),(363842,115736,'117568','printshop','block_type','1',0,''),(363843,115736,'117568','printshop','font-weight','normal',0,''),(363844,115736,'117568','printshop','padding-top','10',0,''),(363845,115736,'117568','printshop','padding-left','10',0,''),(363846,115736,'117568','printshop','padding-right','10',0,''),(363847,115736,'117568','printshop','padding-bottom','10',0,''),(363848,115738,'117570','printshop','text','<p>Shipping service</p>',1,''),(363849,115738,'117570','printshop','font-weight','bold',0,''),(363850,115738,'117570','printshop','text','<p>Shipping service</p>',2,''),(363851,115738,'117570','printshop','text','<p>Shipping service</p>',3,''),(363852,115738,'117570','printshop','text','<p>Shipping service</p>',4,''),(363853,115739,'117571','printshop','font-weight','normal',0,''),(363854,115739,'117571','printshop','text-align','center',0,''),(363855,115739,'117571','printshop','padding-top','40',0,''),(363856,115741,'1639661081.5616','printshop','padding-top','15',0,''),(363857,115742,'117572','printshop','block_type','1',0,''),(363858,115743,'117573','printshop','block_type','1',0,''),(363859,115744,'1638807246.6206','printshop','text','<span></span>',0,''),(363860,115745,'117574','printshop','text','##TEXT_MAIN##',0,''),(363861,115745,'117574','printshop','margin-bottom','20',0,''),(363862,115745,'117574','printshop','text-align','center',0,''),(363863,115746,'117575','printshop','margin-bottom','20',0,''),(363864,115747,'117576','printshop','text','<h1>##HEADING_TITLE##</h1>',0,''),(363865,115749,'117578','printshop','block_type','2',0,''),(363866,115750,'117579','printshop','block_type','1',0,''),(363867,115750,'117579','printshop','style_class','product',0,''),(363868,115750,'117579','printshop','padding-right','10',0,''),(363869,115750,'117579','printshop','padding-bottom','20',0,''),(363870,115751,'117580','printshop','block_type','1',0,''),(363871,115752,'117581','printshop','product_element','products_name',0,''),(363872,115752,'117581','printshop','font-family','$font-1',0,''),(363873,115752,'117581','printshop','padding-bottom','10',0,''),(363874,115752,'117581','printshop','font-size','16',0,''),(363875,115753,'117582','printshop','block_type','2',0,''),(363876,115754,'117583','printshop','product_element','image',0,''),(363877,115754,'117583','printshop','padding-right','10',0,''),(363878,115755,'117584','printshop','product_element','products_price_old',0,''),(363879,115755,'117584','printshop','font-family','$font-1',0,''),(363880,115755,'117584','printshop','font-size','14',0,''),(363881,115755,'117584','printshop','text-decoration','line-through',0,''),(363882,115756,'117585','printshop','product_element','products_price',0,''),(363883,115756,'117585','printshop','font-family','$font-1',0,''),(363884,115756,'117585','printshop','font-size','20',0,''),(363885,115756,'117585','printshop','padding-top','20',0,''),(363886,115757,'117586','printshop','block_type','1',0,''),(363887,115757,'117586','printshop','style_class','product',0,''),(363888,115757,'117586','printshop','padding-left','10',0,''),(363889,115757,'117586','printshop','padding-bottom','20',0,''),(363890,115758,'117587','printshop','block_type','2',0,''),(363891,115759,'117588','printshop','product_element','image',0,''),(363892,115759,'117588','printshop','padding-right','10',0,''),(363893,115760,'117589','printshop','font-size','14',0,''),(363894,115760,'117589','printshop','font-family','$font-1',0,''),(363895,115760,'117589','printshop','text-decoration','line-through',0,''),(363896,115760,'117589','printshop','product_element','products_price_old',0,''),(363897,115761,'117590','printshop','product_element','products_price',0,''),(363898,115761,'117590','printshop','font-family','$font-1',0,''),(363899,115761,'117590','printshop','font-size','20',0,''),(363900,115761,'117590','printshop','padding-top','20',0,''),(363901,115762,'117591','printshop','block_type','1',0,''),(363902,115763,'117592','printshop','product_element','products_name',0,''),(363903,115763,'117592','printshop','font-family','$font-1',0,''),(363904,115763,'117592','printshop','font-size','16',0,''),(363905,115763,'117592','printshop','padding-bottom','10',0,''),(363906,115764,'117593','printshop','font-size','30',0,''),(363907,115764,'117593','printshop','font-family','$font-1',0,''),(363908,115764,'117593','printshop','text-align','center',0,''),(363909,115764,'117593','printshop','padding-bottom','50',0,''),(363910,115765,'117594','printshop','padding-bottom','20',0,''),(363911,115765,'117594','printshop','text-align','center',0,''),(363912,115766,'117595','printshop','width','680',0,''),(363913,115767,'117596','printshop','padding-top','200',0,''),(363914,115767,'117596','printshop','padding-left','200',0,''),(363915,115767,'117596','printshop','logo','themes/printshop/img/themes/printshop/img/oscommerce_logo.jpg',1,''),(363916,115767,'117596','printshop','logo','themes/printshop/img/themes/printshop/img/oscommerce_logo.jpg',2,''),(363917,115767,'117596','printshop','logo','themes/printshop/img/themes/printshop/img/oscommerce_logo.jpg',3,''),(363918,115767,'117596','printshop','logo','themes/printshop/img/themes/printshop/img/oscommerce_logo.jpg',4,''),(363919,115768,'117597','printshop','text','osCommerce 4',1,''),(363920,115768,'117597','printshop','font-family','$font-1',0,''),(363921,115768,'117597','printshop','font-size','40',0,''),(363922,115768,'117597','printshop','padding-top','50',0,''),(363923,115768,'117597','printshop','text-align','center',0,''),(363924,115768,'117597','printshop','text','osCommerce 4',2,''),(363925,115768,'117597','printshop','text','osCommerce 4',3,''),(363926,115768,'117597','printshop','text','osCommerce 4',4,''),(363927,115769,'117598','printshop','block_type','2',0,''),(363928,115769,'117598','printshop','border-top-width','1',0,''),(363929,115769,'117598','printshop','border-top-color','$content-border-3',0,''),(363930,115770,'117599','printshop','text-align','right',0,''),(363931,115770,'117599','printshop','padding-top','15',0,''),(363932,115770,'117599','printshop','padding-bottom','15',0,''),(363933,115770,'117599','printshop','font-size','14',0,''),(363934,115771,'117600','printshop','font-family','$font-1',0,''),(363935,115771,'117600','printshop','text-align','center',0,''),(363936,115771,'117600','printshop','font-size','20',0,''),(363937,115771,'117600','printshop','color','$content-color-1',0,''),(363938,115771,'117600','printshop','border-bottom-width','1',0,''),(363939,115771,'117600','printshop','border-bottom-color','$content-border-3',0,''),(363940,115771,'117600','printshop','padding-top','10',0,''),(363941,115771,'117600','printshop','padding-bottom','10',0,''),(363942,115772,'117601','printshop','block_type','1',0,''),(363943,115773,'117602','printshop','block_type','6',0,''),(363944,115773,'117602','printshop','schema','6-3',0,'5342'),(363945,115774,'117603','printshop','aria_name','account-menu',0,''),(364008,115794,'117606','printshop','max_items','10',0,''),(364009,115794,'117606','printshop','padding-bottom','20',0,''),(364010,115795,'117604','printshop','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(364011,115796,'117607','printshop','block_type','1',0,''),(364012,115796,'117607','printshop','padding-top','20',0,''),(364013,115796,'117607','printshop','padding-left','20',0,''),(364014,115796,'117607','printshop','padding-right','20',0,''),(364015,115796,'117607','printshop','padding-bottom','20',0,''),(364016,115797,'117608','printshop','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(364017,115799,'117610','printshop','block_type','1',0,''),(364018,115800,'117611','printshop','margin_left_measure','auto',0,''),(364019,115800,'117611','printshop','margin_right_measure','auto',0,''),(364020,115800,'117611','printshop','max-width','560',0,''),(364021,115801,'117612','printshop','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(364022,115802,'117613','printshop','margin-bottom','30',0,''),(364023,115803,'1639053523.9657','printshop','block_type','1',0,''),(364024,115803,'1639053523.9657','printshop','background-color','$content-bg-2',0,''),(364025,115803,'1639053523.9657','printshop','padding-top','25',0,''),(364026,115803,'1639053523.9657','printshop','padding-bottom','25',0,''),(364027,115803,'1639053523.9657','printshop','color','$content-color-2',0,''),(364028,115804,'1638963486.2331','printshop','background-color','$content-bg-1',0,''),(364029,115804,'1638963486.2331','printshop','padding-top','20',0,''),(364030,115804,'1638963486.2331','printshop','padding-left','20',0,''),(364031,115804,'1638963486.2331','printshop','padding-right','20',0,''),(364032,115804,'1638963486.2331','printshop','padding-bottom','20',0,''),(364033,115804,'1638963486.2331','printshop','color','$content-color-1',0,''),(364034,115805,'1639659357.0881','printshop','block_type','1',0,''),(364035,115805,'1639659357.0881','printshop','background-color','$content-bg-1',0,''),(364036,115805,'1639659357.0881','printshop','padding-top','20',0,''),(364037,115805,'1639659357.0881','printshop','padding-left','20',0,''),(364038,115805,'1639659357.0881','printshop','padding-right','20',0,''),(364039,115805,'1639659357.0881','printshop','padding-bottom','20',0,''),(364040,115805,'1639659357.0881','printshop','margin-bottom','20',0,''),(364041,115805,'1639659357.0881','printshop','color','$content-color-1',0,''),(364042,115806,'1639659044.5523','printshop','count_products','4',0,''),(364043,115806,'1639659044.5523','printshop','view_as','carousel',0,''),(364044,115806,'1639659044.5523','printshop','col_in_row','4',0,''),(364045,115806,'1639659044.5523','printshop','listing_type','productListing',0,''),(364046,115806,'1639659044.5523','printshop','col_in_row','3',0,'5342'),(364047,115806,'1639659044.5523','printshop','col_in_row','2',0,'5333'),(364048,115806,'1639659044.5523','printshop','col_in_row','1',0,'5363'),(364049,115807,'1644421585.0243','printshop','block_type','1',0,''),(364050,115807,'1644421585.0243','printshop','padding-top','10',0,''),(364051,115807,'1644421585.0243','printshop','padding-bottom','10',0,''),(364052,115807,'1644421585.0243','printshop','background-color','$content-bg-2',0,''),(364053,115807,'1644421585.0243','printshop','color','$content-color-2',0,''),(364054,115808,'117644','printshop','font-weight','normal',0,''),(364055,115808,'117644','printshop','box_align','4',0,''),(364056,115809,'1683120066.375199','printshop','block_type','1',0,''),(364057,115810,'1683120066.40840','printshop','block_type','5',0,''),(364058,115810,'1683120066.40840','printshop','font-weight','400',0,''),(364059,115810,'1683120066.40840','printshop','padding-bottom','20',0,''),(364060,115810,'1683120066.40840','printshop','schema','2-2',0,'5363'),(364061,115810,'1683120066.40840','printshop','schema','2-2',0,'5342'),(364062,115810,'1683120066.40840','printshop','padding-bottom','0',0,'5342'),(364063,115811,'1683120066.411537','printshop','font-weight','400',0,''),(364064,115811,'1683120066.411537','printshop','padding-top','20',0,''),(364065,115811,'1683120066.411537','printshop','padding-right','20',0,''),(364066,115811,'1683120066.411537','printshop','box_align','4',0,''),(364067,115811,'1683120066.411537','printshop','margin-bottom','10',0,''),(364068,115811,'1683120066.411537','printshop','align_position','horizontal',0,''),(364069,115812,'1683120066.412741','printshop','float','left',0,''),(364070,115813,'1683120066.41444','printshop','padding-bottom','20',0,''),(364071,115814,'1696601788.1354','printshop','block_type','1',0,''),(364072,115814,'1696601788.1354','printshop','padding-left','30',0,''),(364073,115814,'1696601788.1354','printshop','padding-left','0',0,'5342'),(364074,115815,'1683120066.4157','printshop','block_type','2',0,''),(364075,115815,'1683120066.4157','printshop','schema','2-2',0,'5347'),(364076,115816,'1683120066.416580','printshop','margin-bottom','20',0,''),(364077,115816,'1683120066.416580','printshop','max-width','500',0,''),(364078,115817,'1683120066.417385','printshop','block_type','1',0,''),(364079,115817,'1683120066.417385','printshop','padding-right','9',0,''),(364080,115817,'1683120066.417385','printshop','padding-right','0',0,'5347'),(364081,115818,'1683120066.41899','printshop','padding-bottom','20',0,''),(364082,115819,'1683120066.41955','printshop','cat_description','on',0,''),(364083,115819,'1683120066.41955','printshop','length_description','250',0,''),(364084,115819,'1683120066.41955','printshop','padding-bottom','7',0,''),(364085,115819,'1683120066.41955','printshop','link_description','1',0,''),(364086,115819,'1683120066.41955','printshop','border-bottom-width','1',0,''),(364087,115819,'1683120066.41955','printshop','border-bottom-color','$content-border-3',0,''),(364088,115819,'1683120066.41955','printshop','margin-bottom','20',0,''),(364089,115820,'1683120066.42249','printshop','margin-bottom','20',0,''),(364090,115823,'1683120066.432243','printshop','block_type','1',0,''),(364091,115823,'1683120066.432243','printshop','padding-left','9',0,''),(364092,115823,'1683120066.432243','printshop','margin-top','20',0,'5347'),(364093,115823,'1683120066.432243','printshop','padding-left','0',0,'5347'),(364094,115824,'1683120066.43441','printshop','block_type','1',0,''),(364095,115824,'1683120066.43441','printshop','style_class','productNavigation',0,''),(364096,115824,'1683120066.43441','printshop','border-top-width','1',0,''),(364097,115824,'1683120066.43441','printshop','border-left-width','1',0,''),(364098,115824,'1683120066.43441','printshop','border-right-width','1',0,''),(364099,115824,'1683120066.43441','printshop','border-bottom-width','1',0,''),(364100,115824,'1683120066.43441','printshop','border-top-color','$content-border-3',0,''),(364101,115824,'1683120066.43441','printshop','border-left-color','$content-border-3',0,''),(364102,115824,'1683120066.43441','printshop','border-right-color','$content-border-3',0,''),(364103,115824,'1683120066.43441','printshop','border-bottom-color','$content-border-3',0,''),(364104,115825,'1683120066.437271','printshop','padding-top','15',0,''),(364105,115825,'1683120066.437271','printshop','padding-left','20',0,''),(364106,115825,'1683120066.437271','printshop','padding-right','20',0,''),(364107,115825,'1683120066.437271','printshop','padding-bottom','20',0,''),(364108,115825,'1683120066.437271','printshop','border-bottom-width','1',0,''),(364109,115825,'1683120066.437271','printshop','border-bottom-color','$content-border-3',0,''),(364110,115826,'1683120066.450387','printshop','block_type','1',0,''),(364111,115826,'1683120066.450387','printshop','padding-top','20',0,''),(364112,115826,'1683120066.450387','printshop','padding-left','20',0,''),(364113,115826,'1683120066.450387','printshop','padding-right','20',0,''),(364114,115826,'1683120066.450387','printshop','padding-bottom','20',0,''),(364115,115827,'1683120066.452834','printshop','margin-bottom','20',0,''),(364116,115828,'1683120066.454686','printshop','text-align','left',0,''),(364117,115828,'1683120066.454686','printshop','text-align','center',0,'5363'),(364118,115829,'1683120066.458637','printshop','block_type','1',0,''),(364119,115829,'1683120066.458637','printshop','schema','2-3',0,'5363'),(364120,115830,'1683120066.460688','printshop','font-size','36',0,''),(364121,115830,'1683120066.460688','printshop','font-weight','400',0,''),(364122,115830,'1683120066.460688','printshop','line-height','35',0,''),(364123,115830,'1683120066.460688','printshop','font-family','$font-1',0,''),(364124,115830,'1683120066.460688','printshop','line_height_measure','px',0,''),(364125,115830,'1683120066.460688','printshop','padding-top','5',0,''),(364126,115830,'1683120066.460688','printshop','text-align','left',0,''),(364127,115830,'1683120066.460688','printshop','padding-bottom','15',0,''),(364128,115830,'1683120066.460688','printshop','text-align','center',0,'5363'),(364129,115830,'1683120066.460688','printshop','float','left',0,''),(364130,115831,'1683120066.46336','printshop','padding-bottom','10',0,''),(364131,115831,'1683120066.46336','printshop','text-align','center',0,'5363'),(364132,115831,'1683120066.46336','printshop','text-align','right',0,''),(364133,115831,'1683120066.46336','printshop','float','right',0,''),(364134,115832,'1683120066.465283','printshop','block_type','2',0,''),(364135,115832,'1683120066.465283','printshop','schema','2-3',0,'5363'),(364136,115833,'1683120066.468523','printshop','width','100',0,'5333'),(364137,115833,'1683120066.468523','printshop','width_measure','%',0,'5333'),(364138,115833,'1683120066.468523','printshop','float','none',0,'5333'),(364139,115833,'1683120066.468523','printshop','hide_additional_buttons','1',0,''),(364140,115833,'1683120066.468523','printshop','margin-bottom','15',0,''),(364141,115833,'1683120066.468523','printshop','text-align','center',0,'5363'),(364142,115834,'1683120066.472391','printshop','box_align','4',0,''),(364143,115834,'1683120066.472391','printshop','margin-bottom','15',0,'5342'),(364144,115834,'1683120066.472391','printshop','text-align','right',0,'5342'),(364145,115834,'1683120066.472391','printshop','margin-bottom','25',0,''),(364146,115834,'1683120066.472391','printshop','text-align','center',0,'5363'),(364147,115835,'1683120066.480552','printshop','block_type','2',0,''),(364148,115835,'1683120066.480552','printshop','schema','2-2',0,'5363'),(364149,115836,'1683120066.48186','printshop','text-align','left',0,''),(364150,115836,'1683120066.48186','printshop','margin-bottom','10',0,''),(364151,115836,'1683120066.48186','printshop','text-align','center',0,'5363'),(364152,115837,'1683120066.483821','printshop','text-align','left',0,''),(364153,115837,'1683120066.483821','printshop','margin-bottom','10',0,''),(364154,115837,'1683120066.483821','printshop','text-align','center',0,'5363'),(364155,115838,'1683120066.485594','printshop','margin-bottom','15',0,''),(364156,115838,'1683120066.485594','printshop','padding-top','15',0,''),(364157,115839,'1683120066.488481','printshop','font-weight','400',0,''),(364158,115839,'1683120066.488481','printshop','show_heading','h1',0,''),(364159,115840,'1683120066.489437','printshop','block_type','1',0,''),(364160,115841,'1683120066.490651','printshop','font-weight','normal',0,''),(364161,115841,'1683120066.490651','printshop','padding-bottom','20',0,''),(364162,115843,'1683120087.08448','printshop','block_type','1',0,''),(364163,115843,'1683120087.08448','printshop','padding-top','25',0,''),(364164,115843,'1683120087.08448','printshop','padding-bottom','25',0,''),(364165,115843,'1683120087.08448','printshop','style_class','catalog-product-wrap',0,''),(364166,115844,'1683120087.116193','printshop','block_type','1',0,''),(364167,115845,'1683120087.118690','printshop','tab_1','##TEXT_PRODUCT_OVERVIEW##',1,''),(364168,115845,'1683120087.118690','printshop','tab_2','##TEXT_DELIVERY_AND_RETURNS##',1,''),(364169,115845,'1683120087.118690','printshop','font-weight','400',0,''),(364170,115845,'1683120087.118690','printshop','tab_3','##TEXT_ASSEMBLY##',1,''),(364171,115845,'1683120087.118690','printshop','tab_1','##TEXT_PRODUCT_OVERVIEW##',2,''),(364172,115845,'1683120087.118690','printshop','tab_2','##TEXT_DELIVERY_AND_RETURNS##',2,''),(364173,115845,'1683120087.118690','printshop','tab_3','##TEXT_ASSEMBLY##',2,''),(364174,115845,'1683120087.118690','printshop','tab_1','##TEXT_PRODUCT_OVERVIEW##',3,''),(364175,115845,'1683120087.118690','printshop','tab_2','##TEXT_DELIVERY_AND_RETURNS##',3,''),(364176,115845,'1683120087.118690','printshop','tab_3','##TEXT_ASSEMBLY##',3,''),(364177,115845,'1683120087.118690','printshop','tab_1','##TEXT_PRODUCT_OVERVIEW##',4,''),(364178,115845,'1683120087.118690','printshop','tab_2','##TEXT_DELIVERY_AND_RETURNS##',4,''),(364179,115845,'1683120087.118690','printshop','tab_3','##TEXT_ASSEMBLY##',4,''),(364180,115846,'1683120087.12923','printshop','hTagsInline','block',0,''),(364181,115847,'1683120087.13141','printshop','info_page','42',0,''),(364182,115849,'1683120087.14498','printshop','tab_1','##TEXT_CUSTOMER_ALSO_BOUGHT##',0,''),(364183,115849,'1683120087.14498','printshop','tab_2','##TEXT_YOU_RECENTLY_VIEWED##',0,''),(364184,115849,'1683120087.14498','printshop','margin-bottom','20',0,''),(364185,115850,'1683120087.145578','printshop','font-weight','400',0,''),(364186,115850,'1683120087.145578','printshop','padding-bottom','20',0,''),(364187,115850,'1683120087.145578','printshop','show_qty_input','1',0,''),(364188,115850,'1683120087.145578','printshop','show_compare','1',0,''),(364189,115850,'1683120087.145578','printshop','listing_type','productListing',0,''),(364190,115850,'1683120087.145578','printshop','view_as','carousel',0,''),(364191,115850,'1683120087.145578','printshop','show_name','0',0,''),(364192,115850,'1683120087.145578','printshop','show_image','0',0,''),(364193,115850,'1683120087.145578','printshop','show_stock','0',0,''),(364194,115850,'1683120087.145578','printshop','show_description','0',0,''),(364195,115850,'1683120087.145578','printshop','show_model','1',0,''),(364196,115850,'1683120087.145578','printshop','show_properties','1',0,''),(364197,115850,'1683120087.145578','printshop','show_rating','0',0,''),(364198,115850,'1683120087.145578','printshop','show_rating_counts','0',0,''),(364199,115850,'1683120087.145578','printshop','show_price','0',0,''),(364200,115850,'1683120087.145578','printshop','show_buy_button','1',0,''),(364201,115850,'1683120087.145578','printshop','show_view_button','1',0,''),(364202,115850,'1683120087.145578','printshop','show_wishlist_button','1',0,''),(364203,115850,'1683120087.145578','printshop','display','none',0,'5342'),(364204,115850,'1683120087.145578','printshop','product_names_teg','h2',0,''),(364205,115850,'1683120087.145578','printshop','show_attributes','1',0,''),(364206,115850,'1683120087.145578','printshop','col_in_row','2',0,''),(364207,115850,'1683120087.145578','printshop','show_bonus_points','1',0,''),(364208,115851,'1683120087.150199','printshop','font-weight','400',0,''),(364209,115851,'1683120087.150199','printshop','padding-bottom','20',0,''),(364210,115851,'1683120087.150199','printshop','show_compare','1',0,''),(364211,115851,'1683120087.150199','printshop','show_name','0',0,''),(364212,115851,'1683120087.150199','printshop','show_image','0',0,''),(364213,115851,'1683120087.150199','printshop','show_stock','0',0,''),(364214,115851,'1683120087.150199','printshop','show_description','0',0,''),(364215,115851,'1683120087.150199','printshop','show_model','1',0,''),(364216,115851,'1683120087.150199','printshop','show_properties','1',0,''),(364217,115851,'1683120087.150199','printshop','show_rating','0',0,''),(364218,115851,'1683120087.150199','printshop','show_rating_counts','0',0,''),(364219,115851,'1683120087.150199','printshop','show_price','0',0,''),(364220,115851,'1683120087.150199','printshop','show_buy_button','1',0,''),(364221,115851,'1683120087.150199','printshop','show_view_button','1',0,''),(364222,115851,'1683120087.150199','printshop','show_wishlist_button','1',0,''),(364223,115851,'1683120087.150199','printshop','listing_type','productListing',0,''),(364224,115851,'1683120087.150199','printshop','col_in_row','2',0,'5342'),(364225,115851,'1683120087.150199','printshop','col_in_row','1',0,'5363'),(364226,115851,'1683120087.150199','printshop','col_in_row','2',0,''),(364227,115851,'1683120087.150199','printshop','view_as','carousel',0,''),(364228,115851,'1683120087.150199','printshop','show_bonus_points','1',0,''),(364229,115851,'1683120087.150199','printshop','show_qty_input','1',0,''),(364230,115851,'1683120087.150199','printshop','show_attributes','1',0,''),(364231,115852,'1683120087.154258','printshop','block_type','1',0,''),(364232,115853,'1683120087.155397','printshop','padding-bottom','10',0,''),(364233,115853,'1683120087.155397','printshop','padding-top','5',0,''),(364234,115854,'1683120087.157963','printshop','block_type','1',0,''),(364235,115854,'1683120087.157963','printshop','style_class','tripleLine',0,''),(364236,115854,'1683120087.157963','printshop','padding-top','30',0,''),(364237,115854,'1683120087.157963','printshop','padding-bottom','50',0,''),(364238,115855,'1683120087.159777','printshop','banners_group','triple-lin',0,''),(364239,115866,'117665','printshop','block_type','1',0,''),(364240,115866,'117665','printshop','style_class','item-holder',0,''),(364241,115866,'117665','printshop','padding-top','25',0,''),(364242,115866,'117665','printshop','padding-left','25',0,''),(364243,115866,'117665','printshop','padding-right','25',0,''),(364244,115866,'117665','printshop','padding-bottom','25',0,''),(364245,115866,'117665','printshop','text-align','left',0,''),(364246,115867,'120921','printshop','block_type','11',0,''),(364247,115867,'120921','printshop','style_class','item-wrapper',0,''),(364248,115867,'120921','printshop','schema','11-2',0,'5363'),(364249,115867,'120921','printshop','schema','11-2',0,'5342'),(364250,115872,'120919','printshop','block_type','1',0,''),(364251,115872,'120919','printshop','style_class','item-content',0,''),(364252,115873,'117668','printshop','description_characters','90',0,''),(364253,115874,'117675','printshop','clear','both',0,''),(364254,115875,'1644336042.3199','printshop','block_type','2',0,''),(364255,115875,'1644336042.3199','printshop','padding-bottom','5',0,''),(364256,115875,'1644336042.3199','printshop','border-bottom-width','1',0,''),(364257,115875,'1644336042.3199','printshop','border-bottom-color','$content-border-3',0,''),(364258,115875,'1644336042.3199','printshop','margin-bottom','15',0,''),(364259,115876,'117676','printshop','margin-bottom','10',0,''),(364260,115879,'1644336088.4429','printshop','block_type','2',0,''),(364261,115879,'1644336088.4429','printshop','margin-bottom','15',0,''),(364262,115880,'117673','printshop','margin-bottom','7',0,''),(364263,115882,'1644336183.1139','printshop','block_type','2',0,''),(364264,115884,'117678','printshop','block_type','1',0,''),(364265,115884,'117678','printshop','padding-bottom','30',0,''),(364266,115885,'117679','printshop','block_type','6',0,''),(364267,115885,'117679','printshop','font-weight','400',0,''),(364268,115885,'117679','printshop','schema','6-2',0,'5363'),(364269,115885,'117679','printshop','schema','6-2',0,'5342'),(364270,115886,'117680','printshop','font-weight','400',0,''),(364271,115886,'117680','printshop','padding-right','40',0,''),(364272,115886,'117680','printshop','padding-right','0',0,'5363'),(364273,115886,'117680','printshop','padding-right','0',0,'5342'),(364274,115886,'117680','printshop','margin-bottom','20',0,''),(364275,115887,'117681','printshop','margin-bottom','20',0,''),(364276,115889,'117683','printshop','block_type','1',0,''),(364277,115889,'117683','printshop','padding-top','10',0,''),(364278,115889,'117683','printshop','padding-bottom','10',0,''),(364279,115889,'117683','printshop','border-bottom-width','1',0,''),(364280,115889,'117683','printshop','border-bottom-color','$content-border-3',0,''),(364281,115889,'117683','printshop','margin-left','0',0,''),(364282,115889,'117683','printshop','margin-right','0',0,''),(364283,115890,'117684','printshop','float','left',0,''),(364284,115890,'117684','printshop','clear','none',0,''),(364285,115890,'117684','printshop','sort_pos_3','2',0,''),(364286,115890,'117684','printshop','sort_pos_4','3',0,''),(364287,115890,'117684','printshop','sort_pos_10','11',0,''),(364288,115890,'117684','printshop','sort_pos_9','10',0,''),(364289,115890,'117684','printshop','sort_pos_11','12',0,''),(364290,115890,'117684','printshop','sort_pos_12','13',0,''),(364291,115890,'117684','printshop','sort_pos_14','15',0,''),(364292,115890,'117684','printshop','sort_pos_13','14',0,''),(364293,115890,'117684','printshop','sort_pos_8','4',0,''),(364294,115890,'117684','printshop','sort_pos_7','5',0,''),(364295,115890,'117684','printshop','sort_pos_2','7',0,''),(364296,115890,'117684','printshop','sort_pos_1','6',0,''),(364297,115890,'117684','printshop','sort_pos_6','9',0,''),(364298,115890,'117684','printshop','sort_pos_5','8',0,''),(364299,115890,'117684','printshop','sort_pos_0','1',0,''),(364300,115890,'117684','printshop','sort_hide_10','1',0,''),(364301,115890,'117684','printshop','sort_hide_9','1',0,''),(364302,115890,'117684','printshop','sort_pos_15','16',0,''),(364303,115890,'117684','printshop','sort_pos_16','17',0,''),(364304,115890,'117684','printshop','sort_hide_4','0',0,''),(364305,115890,'117684','printshop','sort_hide_3','0',0,''),(364306,115890,'117684','printshop','sort_hide_16','1',0,''),(364307,115890,'117684','printshop','sort_hide_15','1',0,''),(364308,115890,'117684','printshop','sort_hide_11','1',0,''),(364309,115890,'117684','printshop','sort_hide_12','1',0,''),(364310,115890,'117684','printshop','sort_hide_14','1',0,''),(364311,115890,'117684','printshop','sort_hide_13','1',0,''),(364312,115890,'117684','printshop','sort_hide_8','0',0,''),(364313,115890,'117684','printshop','sort_hide_7','0',0,''),(364314,115890,'117684','printshop','sort_hide_2','1',0,''),(364315,115890,'117684','printshop','sort_hide_1','1',0,''),(364316,115890,'117684','printshop','sort_hide_6','1',0,''),(364317,115890,'117684','printshop','sort_hide_5','1',0,''),(364318,115890,'117684','printshop','sort_hide_0','0',0,''),(364319,115890,'117684','printshop','hide_icons','1',0,''),(364320,115891,'117685','printshop','float','right',0,''),(364321,115891,'117685','printshop','display','none',0,'5363'),(364322,115892,'117686','printshop','float','left',0,''),(364323,115892,'117686','printshop','clear','none',0,''),(364324,115892,'117686','printshop','margin-left','20',0,''),(364325,115892,'117686','printshop','display','none',0,'5363'),(364326,115892,'117686','printshop','display','none',0,'5347'),(364327,115893,'117687','printshop','margin-right','20',0,''),(364328,115893,'117687','printshop','float','right',0,''),(364329,115893,'117687','printshop','clear','none',0,''),(364330,115893,'117687','printshop','display','none',0,'5342'),(364331,115894,'117688','printshop','block_type','5',0,''),(364332,115894,'117688','printshop','padding-top','10',0,''),(364333,115894,'117688','printshop','padding-bottom','10',0,''),(364334,115894,'117688','printshop','schema','5-2',0,'5363'),(364335,115894,'117688','printshop','border-top-color','$content-border-3',0,''),(364336,115894,'117688','printshop','border-top-width','1',0,''),(364337,115895,'117689','printshop','padding-top','3',0,''),(364338,115896,'117690','printshop','float','right',0,''),(364339,115896,'117690','printshop','height','31',0,''),(364340,115897,'117691','printshop','col_in_row','2',0,''),(364341,115897,'117691','printshop','products_align','left',0,''),(364342,115897,'117691','printshop','font-weight','400',0,''),(364343,115897,'117691','printshop','listing_type','productListing',0,''),(364344,115897,'117691','printshop','listing_type_rows','Rows',0,''),(364345,115897,'117691','printshop','show_buy_button_b2b','on',0,''),(364346,115897,'117691','printshop','show_wishlist_button_b2b','1',0,''),(364347,115897,'117691','printshop','show_compare_b2b','1',0,''),(364348,115897,'117691','printshop','show_image','0',0,''),(364349,115897,'117691','printshop','show_stock','0',0,''),(364350,115897,'117691','printshop','show_description','0',0,''),(364351,115897,'117691','printshop','show_rating','0',0,''),(364352,115897,'117691','printshop','show_rating_counts','0',0,''),(364353,115897,'117691','printshop','show_price','0',0,''),(364354,115897,'117691','printshop','show_view_button','0',0,''),(364355,115897,'117691','printshop','show_wishlist_button','0',0,''),(364356,115897,'117691','printshop','show_compare','0',0,''),(364357,115897,'117691','printshop','show_name_rows','0',0,''),(364358,115897,'117691','printshop','show_image_rows','0',0,''),(364359,115897,'117691','printshop','show_stock_rows','0',0,''),(364360,115897,'117691','printshop','show_description_rows','0',0,''),(364361,115897,'117691','printshop','show_model_rows','0',0,''),(364362,115897,'117691','printshop','show_properties_rows','0',0,''),(364363,115897,'117691','printshop','show_rating_rows','0',0,''),(364364,115897,'117691','printshop','show_rating_counts_rows','0',0,''),(364365,115897,'117691','printshop','show_price_rows','0',0,''),(364366,115897,'117691','printshop','show_buy_button_rows','0',0,''),(364367,115897,'117691','printshop','show_qty_input_rows','0',0,''),(364368,115897,'117691','printshop','show_view_button_rows','0',0,''),(364369,115897,'117691','printshop','show_wishlist_button_rows','0',0,''),(364370,115897,'117691','printshop','show_compare_rows','0',0,''),(364371,115897,'117691','printshop','show_name_b2b','0',0,''),(364372,115897,'117691','printshop','show_image_b2b','0',0,''),(364373,115897,'117691','printshop','show_stock_b2b','0',0,''),(364374,115897,'117691','printshop','show_description_b2b','0',0,''),(364375,115897,'117691','printshop','show_model_b2b','0',0,''),(364376,115897,'117691','printshop','show_properties_b2b','0',0,''),(364377,115897,'117691','printshop','show_rating_b2b','0',0,''),(364378,115897,'117691','printshop','show_rating_counts_b2b','0',0,''),(364379,115897,'117691','printshop','show_price_b2b','0',0,''),(364380,115897,'117691','printshop','show_qty_input_b2b','0',0,''),(364381,115897,'117691','printshop','show_view_button_b2b','0',0,''),(364382,115897,'117691','printshop','show_attributes_b2b','0',0,''),(364383,115897,'117691','printshop','items_on_page','8',0,''),(364384,115897,'117691','printshop','col_in_row','2',0,'5342'),(364385,115897,'117691','printshop','col_in_row','1',0,'5363'),(364386,115897,'117691','printshop','product_names_teg','h2',0,''),(364387,115897,'117691','printshop','padding-top','10',0,''),(364388,115897,'117691','printshop','padding-bottom','20',0,''),(364389,115897,'117691','printshop','col_in_row','2',0,'5347'),(364390,115898,'1639760443.0645','printshop','carousel','1',0,''),(364391,115898,'1639760443.0645','printshop','col_in_row','4',0,''),(364392,115898,'1639760443.0645','printshop','fancibox','1',0,''),(364393,115898,'1639760443.0645','printshop','col_in_row','3',0,'5347'),(364394,115898,'1639760443.0645','printshop','col_in_row','2',0,'5333'),(364395,115898,'1639760443.0645','printshop','col_in_row','1',0,'5363'),(364396,115899,'117692','printshop','show_heading','h1',0,''),(364397,115900,'117693','printshop','block_type','1',0,''),(364398,115901,'117694','printshop','margin-bottom','20',0,''),(364399,115904,'1645192276.9329','printshop','block_type','1',0,''),(364400,115904,'1645192276.9329','printshop','background-color','$content-bg-2',0,''),(364401,115904,'1645192276.9329','printshop','padding-top','10',0,''),(364402,115904,'1645192276.9329','printshop','padding-bottom','10',0,''),(364403,115904,'1645192276.9329','printshop','color','$content-color-2',0,''),(364404,115907,'117696','printshop','block_type','1',0,''),(364405,115909,'117698','printshop','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(364406,115910,'117699','printshop','width','680',0,''),(364407,115910,'117699','printshop','font-weight','normal',0,''),(364408,115910,'117699','printshop','font-size','12',0,''),(364409,115910,'117699','printshop','padding-top','20',0,''),(364410,115910,'117699','printshop','padding-bottom','20',0,''),(364411,115910,'117699','printshop','color','$content-color-1',0,''),(364412,115911,'117700','printshop','font-weight','400',0,''),(364413,115911,'117700','printshop','padding-top','20',0,''),(364414,115911,'117700','printshop','padding-bottom','0',0,''),(364415,115911,'117700','printshop','font-size','12',0,''),(364416,115912,'117701','printshop','block_type','3',0,''),(364417,115912,'117701','printshop','font-weight','normal',0,''),(364418,115912,'117701','printshop','padding-top','20',0,''),(364419,115913,'117702','printshop','text','<p>If undelivered please return to:</p>',1,''),(364420,115913,'117702','printshop','font-size','12',0,''),(364421,115913,'117702','printshop','font-weight','bold',0,''),(364422,115913,'117702','printshop','text','<p>If undelivered please return to:</p>',2,''),(364423,115913,'117702','printshop','text','<p>If undelivered please return to:</p>',3,''),(364424,115913,'117702','printshop','text','<p>If undelivered please return to:</p>',4,''),(364425,115914,'117703','printshop','font-size','12',0,''),(364426,115915,'117704','printshop','text','<p>Thank you for your order</p>',1,''),(364427,115915,'117704','printshop','color','$hileght-color-1',0,''),(364428,115915,'117704','printshop','font-size','13',0,''),(364429,115915,'117704','printshop','font-weight','bold',0,''),(364430,115915,'117704','printshop','padding-top','5',0,''),(364431,115915,'117704','printshop','text-align','center',0,''),(364432,115915,'117704','printshop','text','<p>Thank you for your order</p>',2,''),(364433,115915,'117704','printshop','text','<p>Thank you for your order</p>',3,''),(364434,115915,'117704','printshop','text','<p>Thank you for your order</p>',4,''),(364435,115916,'117705','printshop','font-weight','400',0,''),(364436,115916,'117705','printshop','text-align','center',0,''),(364437,115916,'117705','printshop','padding-top','0',0,''),(364439,115916,'117705','printshop','padding-left','20',0,''),(364440,115916,'117705','printshop','padding-right','20',0,''),(364444,115917,'117706','printshop','block_type','6',0,''),(364445,115917,'117706','printshop','font-weight','normal',0,''),(364446,115917,'117706','printshop','font-size','16',0,''),(364447,115918,'117707','printshop','text','<p>Email:</p>',1,''),(364448,115918,'117707','printshop','font-weight','normal',0,''),(364449,115918,'117707','printshop','text-align','right',0,''),(364450,115918,'117707','printshop','font-size','12',0,''),(364451,115918,'117707','printshop','text','<p>Email:</p>',2,''),(364452,115918,'117707','printshop','text','<p>Email:</p>',3,''),(364453,115918,'117707','printshop','text','<p>Email:</p>',4,''),(364454,115919,'117708','printshop','font-weight','normal',0,''),(364455,115919,'117708','printshop','text-align','right',0,''),(364456,115919,'117708','printshop','font-size','12',0,''),(364457,115920,'117709','printshop','text','<p>If something has gone wrong please contact us at:</p>',1,''),(364458,115920,'117709','printshop','font-size','12',0,''),(364459,115920,'117709','printshop','font-weight','bold',0,''),(364460,115920,'117709','printshop','text-align','right',0,''),(364461,115920,'117709','printshop','text','<p>If something has gone wrong please contact us at:</p>',2,''),(364462,115920,'117709','printshop','text','<p>If something has gone wrong please contact us at:</p>',3,''),(364463,115920,'117709','printshop','text','<p>If something has gone wrong please contact us at:</p>',4,''),(364464,115921,'117710','printshop','block_type','6',0,''),(364465,115921,'117710','printshop','font-weight','normal',0,''),(364466,115921,'117710','printshop','font-size','16',0,''),(364467,115922,'117711','printshop','text','<p>Phone:</p>',1,''),(364468,115922,'117711','printshop','font-weight','normal',0,''),(364469,115922,'117711','printshop','text-align','right',0,''),(364470,115922,'117711','printshop','font-size','12',0,''),(364471,115922,'117711','printshop','text','<p>Phone:</p>',2,''),(364472,115922,'117711','printshop','text','<p>Phone:</p>',3,''),(364473,115922,'117711','printshop','text','<p>Phone:</p>',4,''),(364474,115923,'117712','printshop','font-weight','normal',0,''),(364475,115923,'117712','printshop','text-align','right',0,''),(364476,115923,'117712','printshop','font-size','12',0,''),(364477,115924,'117713','printshop','block_type','2',0,''),(364478,115924,'117713','printshop','font-weight','normal',0,''),(364479,115924,'117713','printshop','padding-bottom','20',0,''),(364480,115925,'117714','printshop','font-weight','400',0,''),(364481,115925,'117714','printshop','padding-top','20',0,''),(364486,115926,'117715','printshop','block_type','11',0,''),(364487,115926,'117715','printshop','font-weight','normal',0,''),(364488,115927,'117716','printshop','text','<p>Phone:</p>',1,''),(364489,115927,'117716','printshop','font-weight','normal',0,''),(364490,115927,'117716','printshop','text-align','right',0,''),(364491,115927,'117716','printshop','text','<p>Phone:</p>',2,''),(364492,115927,'117716','printshop','text','<p>Phone:</p>',3,''),(364493,115927,'117716','printshop','text','<p>Phone:</p>',4,''),(364494,115928,'117717','printshop','font-weight','normal',0,''),(364495,115928,'117717','printshop','text-align','right',0,''),(364496,115929,'117718','printshop','block_type','11',0,''),(364497,115929,'117718','printshop','font-weight','normal',0,''),(364498,115930,'117719','printshop','text','<p>Web:</p>',1,''),(364499,115930,'117719','printshop','font-weight','normal',0,''),(364500,115930,'117719','printshop','text-align','right',0,''),(364501,115930,'117719','printshop','text','<p>Web:</p>',2,''),(364502,115930,'117719','printshop','text','<p>Web:</p>',3,''),(364503,115930,'117719','printshop','text','<p>Web:</p>',4,''),(364504,115931,'117720','printshop','font-weight','normal',0,''),(364505,115931,'117720','printshop','text-align','right',0,''),(364506,115932,'117721','printshop','block_type','1',0,''),(364507,115933,'117722','printshop','font-weight','normal',0,''),(364508,115933,'117722','printshop','text-align','right',0,''),(364509,115933,'117722','printshop','padding-bottom','10',0,''),(364510,115933,'117722','printshop','address_spacer',',',0,''),(364511,115933,'117722','printshop','font-size','12',0,''),(364512,115934,'117723','printshop','block_type','11',0,''),(364513,115934,'117723','printshop','font-weight','normal',0,''),(364514,115935,'117724','printshop','text','<p>Email:</p>',1,''),(364515,115935,'117724','printshop','font-weight','normal',0,''),(364516,115935,'117724','printshop','text-align','right',0,''),(364517,115935,'117724','printshop','text','<p>Email:</p>',2,''),(364518,115935,'117724','printshop','text','<p>Email:</p>',3,''),(364519,115935,'117724','printshop','text','<p>Email:</p>',4,''),(364520,115936,'117725','printshop','font-weight','normal',0,''),(364521,115936,'117725','printshop','text-align','right',0,''),(364522,115937,'117726','printshop','block_type','4',0,''),(364523,115937,'117726','printshop','font-weight','normal',0,''),(364524,115937,'117726','printshop','border-top-width','1',0,''),(364525,115937,'117726','printshop','border-top-color','$content-border-3',0,''),(364526,115937,'117726','printshop','border-left-width','1',0,''),(364527,115937,'117726','printshop','border-left-color','$content-border-3',0,''),(364528,115937,'117726','printshop','border-right-width','1',0,''),(364529,115937,'117726','printshop','border-right-color','$content-border-3',0,''),(364530,115937,'117726','printshop','border-bottom-width','1',0,''),(364531,115937,'117726','printshop','border-bottom-color','$content-border-3',0,''),(364532,115938,'117727','printshop','block_type','2',0,''),(364533,115938,'117727','printshop','font-weight','normal',0,''),(364534,115938,'117727','printshop','border-right-width','1',0,''),(364535,115938,'117727','printshop','border-right-color','$content-border-3',0,''),(364536,115939,'117728','printshop','block_type','1',0,''),(364537,115939,'117728','printshop','font-weight','400',0,''),(364538,115939,'117728','printshop','background-color','$content-bg-2',0,''),(364539,115939,'117728','printshop','padding-top','10',0,''),(364540,115939,'117728','printshop','padding-left','10',0,''),(364541,115939,'117728','printshop','padding-right','10',0,''),(364542,115939,'117728','printshop','padding-bottom','30',0,''),(364543,115940,'117729','printshop','font-size','12',0,''),(364544,115941,'117730','printshop','text','<p>ADDRESS:</p>\n',1,''),(364545,115941,'117730','printshop','font-size','14',0,''),(364546,115941,'117730','printshop','font-weight','bold',0,''),(364547,115941,'117730','printshop','text','<p>ADDRESS:</p>\n',2,''),(364548,115941,'117730','printshop','text','<p>ADDRESS:</p>\n',3,''),(364549,115941,'117730','printshop','text','<p>ADDRESS:</p>\n',4,''),(364550,115942,'117731','printshop','block_type','1',0,''),(364551,115942,'117731','printshop','font-weight','normal',0,''),(364552,115942,'117731','printshop','padding-top','10',0,''),(364553,115942,'117731','printshop','padding-left','10',0,''),(364554,115942,'117731','printshop','padding-right','10',0,''),(364555,115942,'117731','printshop','padding-bottom','10',0,''),(364556,115944,'117733','printshop','text','<p>E-MAIL ADDRESS:</p>',1,''),(364557,115944,'117733','printshop','font-weight','bold',0,''),(364558,115944,'117733','printshop','font-size','14',0,''),(364559,115944,'117733','printshop','padding-top','10',0,''),(364560,115944,'117733','printshop','text','<p>E-MAIL ADDRESS:</p>',2,''),(364561,115944,'117733','printshop','text','<p>E-MAIL ADDRESS:</p>',3,''),(364562,115944,'117733','printshop','text','<p>E-MAIL ADDRESS:</p>',4,''),(364563,115945,'117734','printshop','font-weight','normal',0,''),(364564,115946,'117735','printshop','font-weight','normal',0,''),(364565,115947,'117736','printshop','text','<p>PHONE NUMBER:</p>',1,''),(364566,115947,'117736','printshop','font-size','14',0,''),(364567,115947,'117736','printshop','font-weight','bold',0,''),(364568,115947,'117736','printshop','padding-top','10',0,''),(364569,115947,'117736','printshop','text','<p>PHONE NUMBER:</p>',2,''),(364570,115947,'117736','printshop','text','<p>PHONE NUMBER:</p>',3,''),(364571,115947,'117736','printshop','text','<p>PHONE NUMBER:</p>',4,''),(364572,115948,'117737','printshop','text','<p>CUSTOMER:</p>',1,''),(364573,115948,'117737','printshop','font-size','13',0,''),(364574,115948,'117737','printshop','font-weight','bold',0,''),(364575,115948,'117737','printshop','text','<p>CUSTOMER:</p>',2,''),(364576,115948,'117737','printshop','text','<p>CUSTOMER:</p>',3,''),(364577,115948,'117737','printshop','text','<p>CUSTOMER:</p>',4,''),(364578,115949,'117738','printshop','font-size','14',0,''),(364579,115949,'117738','printshop','font-weight','bold',0,''),(364580,115949,'117738','printshop','text-align','center',0,''),(364581,115949,'117738','printshop','padding-bottom','10',0,''),(364582,115949,'117738','printshop','padding-top','10',0,''),(364583,115950,'117739','printshop','text','<p>Order date:</p>\n',1,''),(364584,115950,'117739','printshop','font-weight','bold',0,''),(364585,115950,'117739','printshop','text-align','center',0,''),(364586,115950,'117739','printshop','font-size','12',0,''),(364587,115950,'117739','printshop','text','<p>Order date:</p>\n',2,''),(364588,115950,'117739','printshop','text','<p>Order date:</p>\n',3,''),(364589,115950,'117739','printshop','text','<p>Order date:</p>\n',4,''),(364590,115951,'117740','printshop','font-weight','normal',0,''),(364591,115951,'117740','printshop','text-align','center',0,''),(364592,115951,'117740','printshop','padding-bottom','10',0,''),(364593,115952,'117741','printshop','block_type','5',0,''),(364594,115952,'117741','printshop','font-weight','normal',0,''),(364595,115952,'117741','printshop','border-bottom-width','1',0,''),(364596,115952,'117741','printshop','border-bottom-color','$content-border-3',0,''),(364597,115952,'117741','printshop','border-top-width','1',0,''),(364598,115952,'117741','printshop','border-top-color','$content-border-3',0,''),(364599,115952,'117741','printshop','border-left-color','$content-border-3',0,''),(364600,115952,'117741','printshop','border-left-width','1',0,''),(364601,115953,'117742','printshop','block_type','1',0,''),(364602,115953,'117742','printshop','font-weight','normal',0,''),(364603,115953,'117742','printshop','padding-top','10',0,''),(364604,115953,'117742','printshop','padding-left','10',0,''),(364605,115953,'117742','printshop','padding-right','10',0,''),(364606,115954,'117743','printshop','font-weight','400',0,''),(364607,115954,'117743','printshop','line-height','120',0,''),(364608,115954,'117743','printshop','line_height_measure','%',0,''),(364609,115954,'117743','printshop','font-size','12',0,''),(364610,115955,'117744','printshop','text','<p>SHIPPING ADDRESS:</p>',1,''),(364611,115955,'117744','printshop','font-size','14',0,''),(364612,115955,'117744','printshop','font-weight','bold',0,''),(364613,115955,'117744','printshop','padding-bottom','10',0,''),(364614,115955,'117744','printshop','text','<p>SHIPPING ADDRESS:</p>',2,''),(364615,115955,'117744','printshop','text','<p>SHIPPING ADDRESS:</p>',3,''),(364616,115955,'117744','printshop','text','<p>SHIPPING ADDRESS:</p>',4,''),(364619,115959,'117745','printshop','block_type','1',0,''),(364620,115960,'117746','printshop','block_type','6',0,''),(364621,115960,'117746','printshop','schema','6-3',0,'5342'),(364622,115961,'117747','printshop','aria_name','account-menu',0,''),(364685,115981,'117748','printshop','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(364686,115982,'117749','printshop','link','Quotation Info',0,''),(364687,115982,'117749','printshop','margin-bottom','20',0,''),(364688,115983,'117750','printshop','block_type','1',0,''),(364689,115984,'117751','printshop','block_type','6',0,''),(364690,115984,'117751','printshop','schema','6-3',0,'5342'),(364691,115985,'117752','printshop','aria_name','account-menu',0,''),(364754,116005,'117753','printshop','block_type','3',0,''),(364755,116006,'117754','printshop','block_type','1',0,''),(364756,116006,'117754','printshop','padding-right','20',0,''),(364757,116006,'117754','printshop','padding-bottom','20',0,''),(364758,116007,'117755','printshop','orders_data','name',0,''),(364759,116008,'117756','printshop','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(364760,116009,'117757','printshop','block_type','1',0,''),(364761,116009,'117757','printshop','padding-right','20',0,''),(364762,116009,'117757','printshop','padding-bottom','20',0,''),(364763,116010,'117758','printshop','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(364764,116011,'117759','printshop','orders_data','telephone',0,''),(364765,116012,'117760','printshop','block_type','1',0,''),(364766,116012,'117760','printshop','padding-right','20',0,''),(364767,116013,'117761','printshop','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(364768,116014,'117762','printshop','orders_data','shipping_method',0,''),(364769,116015,'117763','printshop','block_type','1',0,''),(364770,116015,'117763','printshop','padding-right','20',0,''),(364771,116015,'117763','printshop','padding-bottom','20',0,''),(364772,116016,'117764','printshop','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(364773,116017,'117765','printshop','orders_data','delivery_address',0,''),(364774,116018,'117766','printshop','block_type','1',0,''),(364775,116018,'117766','printshop','padding-bottom','20',0,''),(364776,116019,'117767','printshop','orders_data','billing_address',0,''),(364777,116020,'117768','printshop','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(364778,116021,'117769','printshop','block_type','1',0,''),(364779,116022,'117770','printshop','orders_data','payment_method',0,''),(364780,116023,'117771','printshop','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(364781,116024,'117772','printshop','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(364782,116026,'117774','printshop','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(364783,116029,'117777','printshop','block_type','2',0,''),(364784,116029,'117777','printshop','padding-top','20',0,''),(364785,116029,'117777','printshop','margin-bottom','20',0,''),(364786,116030,'117778','printshop','like_button','1',0,''),(364787,116030,'117778','printshop','text','IMAGE_BUTTON_BACK',0,''),(364788,116030,'117778','printshop','link','Quotations',0,''),(364789,116031,'117779','printshop','text','<h1>##HEADING_TITLE##</h1>',0,''),(364790,116032,'117780','printshop','padding-top','20',0,''),(364791,116032,'117780','printshop','padding-bottom','20',0,''),(364792,116032,'117780','printshop','block_type','1',0,''),(364793,116032,'117780','printshop','background-color','$content-bg-2',0,''),(364794,116034,'117782','printshop','block_type','4',0,''),(364795,116034,'117782','printshop','schema','4-2',0,'5342'),(364796,116034,'117782','printshop','schema','4-2',0,'5333'),(364797,116035,'117783','printshop','background-color','$content-bg-1',0,''),(364798,116036,'117784','printshop','block_type','1',0,''),(364799,116036,'117784','printshop','style_class','order-summary',0,''),(364800,116036,'117784','printshop','margin-left','30',0,''),(364801,116036,'117784','printshop','margin-left','0',0,'5342'),(364802,116037,'117785','printshop','block_type','1',0,''),(364803,116037,'117785','printshop','padding-left','20',0,''),(364804,116037,'117785','printshop','padding-right','20',0,''),(364805,116037,'117785','printshop','padding-bottom','30',0,''),(364806,116038,'117786','printshop','max-width','300',0,'5342'),(364807,116038,'117786','printshop','margin_left_measure','auto',0,'5342'),(364808,116038,'117786','printshop','margin_right_measure','auto',0,'5342'),(364809,116038,'117786','printshop','margin-bottom','0',0,''),(364810,116040,'117788','printshop','block_type','1',0,''),(364878,116064,'117793','printshop','block_type','1',0,''),(364879,116066,'117795','printshop','pagination','bottom',0,''),(364880,116067,'117796','printshop','width','800',0,''),(364881,116068,'117797','printshop','block_type','11',0,''),(364882,116068,'117797','printshop','border-top-width','1',0,''),(364883,116068,'117797','printshop','border-left-width','1',0,''),(364884,116068,'117797','printshop','border-right-width','1',0,''),(364885,116068,'117797','printshop','border-bottom-width','1',0,''),(364886,116068,'117797','printshop','border-top-color','$highlight-box-border-1',0,''),(364887,116068,'117797','printshop','border-left-color','$highlight-box-border-1',0,''),(364888,116068,'117797','printshop','border-right-color','$highlight-box-border-1',0,''),(364889,116068,'117797','printshop','border-bottom-color','$highlight-box-border-1',0,''),(364890,116069,'117798','printshop','block_type','1',0,''),(364891,116069,'117798','printshop','border-right-width','1',0,''),(364892,116069,'117798','printshop','border-right-color','$highlight-box-border-1',0,''),(364893,116069,'117798','printshop','padding-top','10',0,''),(364894,116069,'117798','printshop','padding-right','10',0,''),(364895,116069,'117798','printshop','padding-bottom','10',0,''),(364896,116070,'117799','printshop','block_type','9',0,''),(364897,116071,'117800','printshop','text','1.',0,''),(364898,116071,'117800','printshop','font-size','12',0,''),(364899,116071,'117800','printshop','text-align','right',0,''),(364900,116071,'117800','printshop','padding-right','5',0,''),(364901,116072,'117801','printshop','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(364902,116072,'117801','printshop','font-size','12',0,''),(364903,116072,'117801','printshop','padding-bottom','5',0,''),(364904,116073,'117802','printshop','block_type','9',0,''),(364905,116074,'117803','printshop','text','4.',0,''),(364906,116074,'117803','printshop','font-size','12',0,''),(364907,116074,'117803','printshop','text-align','right',0,''),(364908,116074,'117803','printshop','margin-right','5',0,''),(364909,116075,'117804','printshop','text','Our Replacement Department will process your request.',0,''),(364910,116075,'117804','printshop','font-size','12',0,''),(364911,116075,'117804','printshop','padding-bottom','5',0,''),(364912,116076,'117805','printshop','block_type','9',0,''),(364913,116077,'117806','printshop','text','3.',0,''),(364914,116077,'117806','printshop','font-size','12',0,''),(364915,116077,'117806','printshop','text-align','right',0,''),(364916,116077,'117806','printshop','margin-right','5',0,''),(364917,116078,'117807','printshop','text','Return the authorized item(s) per shipping instructions.',0,''),(364918,116078,'117807','printshop','font-size','12',0,''),(364919,116078,'117807','printshop','padding-bottom','5',0,''),(364920,116079,'117808','printshop','block_type','9',0,''),(364921,116080,'117809','printshop','text','2.',0,''),(364922,116080,'117809','printshop','font-size','12',0,''),(364923,116080,'117809','printshop','text-align','right',0,''),(364924,116080,'117809','printshop','margin-right','5',0,''),(364925,116081,'117810','printshop','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(364926,116081,'117810','printshop','font-size','12',0,''),(364927,116081,'117810','printshop','padding-bottom','5',0,''),(364928,116082,'117811','printshop','block_type','1',0,''),(364929,116082,'117811','printshop','padding-left','15',0,''),(364930,116083,'117812','printshop','text','Replacement Policy:',0,''),(364931,116083,'117812','printshop','font-size','14',0,''),(364932,116083,'117812','printshop','padding-bottom','5',0,''),(364933,116083,'117812','printshop','font-weight','bold',0,''),(364934,116084,'117813','printshop','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(364935,116084,'117813','printshop','font-size','11',0,''),(364936,116084,'117813','printshop','font-style','italic',0,''),(364937,116084,'117813','printshop','padding-bottom','5',0,''),(364938,116085,'117814','printshop','block_type','1',0,''),(364939,116085,'117814','printshop','border-bottom-width','1',0,''),(364940,116085,'117814','printshop','border-bottom-color','$highlight-box-border-1',0,''),(364941,116086,'117815','printshop','text','Return Material Authorization (RMA) Form',0,''),(364942,116086,'117815','printshop','text-align','center',0,''),(364943,116086,'117815','printshop','font-size','16',0,''),(364944,116086,'117815','printshop','font-weight','bold',0,''),(364945,116087,'117816','printshop','text-align','center',0,''),(364946,116087,'117816','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',1,''),(364947,116087,'117816','printshop','padding-top','10',0,''),(364948,116087,'117816','printshop','padding-bottom','10',0,''),(364949,116087,'117816','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',2,''),(364950,116087,'117816','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',3,''),(364951,116087,'117816','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',4,''),(364952,116088,'117817','printshop','block_type','1',0,''),(364953,116088,'117817','printshop','padding-top','10',0,''),(364954,116088,'117817','printshop','padding-left','10',0,''),(364955,116088,'117817','printshop','padding-right','10',0,''),(364956,116088,'117817','printshop','padding-bottom','20',0,''),(364957,116089,'117818','printshop','block_type','2',0,''),(364958,116089,'117818','printshop','padding-top','5',0,''),(364959,116090,'117819','printshop','block_type','11',0,''),(364960,116091,'117820','printshop','text','Email:',0,''),(364961,116091,'117820','printshop','font-size','12',0,''),(364962,116092,'117821','printshop','data','rrDelivery_email_address',0,''),(364963,116092,'117821','printshop','font-size','12',0,''),(364964,116093,'117822','printshop','block_type','11',0,''),(364965,116094,'117823','printshop','text','Phone:',0,''),(364966,116094,'117823','printshop','font-size','12',0,''),(364967,116095,'117824','printshop','data','rrDelivery_telephone',0,''),(364968,116095,'117824','printshop','font-size','12',0,''),(364969,116096,'117825','printshop','block_type','2',0,''),(364970,116096,'117825','printshop','padding-top','5',0,''),(364971,116097,'117826','printshop','block_type','11',0,''),(364972,116098,'117827','printshop','text','Country:',0,''),(364973,116098,'117827','printshop','font-size','12',0,''),(364974,116099,'117828','printshop','data','rrDelivery_country',0,''),(364975,116099,'117828','printshop','font-size','12',0,''),(364976,116100,'117829','printshop','block_type','11',0,''),(364977,116101,'117830','printshop','text','Postcode:',0,''),(364978,116101,'117830','printshop','font-size','12',0,''),(364979,116102,'117831','printshop','data','rrDelivery_postcode',0,''),(364980,116102,'117831','printshop','font-size','12',0,''),(364981,116103,'117832','printshop','block_type','2',0,''),(364982,116103,'117832','printshop','padding-top','5',0,''),(364983,116104,'117833','printshop','block_type','11',0,''),(364984,116105,'117834','printshop','text','City:',0,''),(364985,116105,'117834','printshop','font-size','12',0,''),(364986,116106,'117835','printshop','data','rrDelivery_city',0,''),(364987,116106,'117835','printshop','font-size','12',0,''),(364988,116107,'117836','printshop','block_type','11',0,''),(364989,116108,'117837','printshop','text','State:',0,''),(364990,116108,'117837','printshop','font-size','12',0,''),(364991,116109,'117838','printshop','data','rrDelivery_state',0,''),(364992,116109,'117838','printshop','font-size','12',0,''),(364993,116110,'117839','printshop','block_type','9',0,''),(364994,116110,'117839','printshop','padding-top','5',0,''),(364995,116111,'117840','printshop','text','Address:',0,''),(364996,116111,'117840','printshop','font-size','12',0,''),(364997,116112,'117841','printshop','data','rrDelivery_street_address',0,''),(364998,116112,'117841','printshop','font-size','12',0,''),(364999,116113,'117842','printshop','block_type','2',0,''),(365000,116114,'117843','printshop','block_type','11',0,''),(365001,116115,'117844','printshop','text','Company:',0,''),(365002,116115,'117844','printshop','font-size','12',0,''),(365003,116116,'117845','printshop','data','rrDelivery_company',0,''),(365004,116116,'117845','printshop','font-size','12',0,''),(365005,116117,'117846','printshop','block_type','2',0,''),(365006,116118,'117847','printshop','text','Contact Name:',0,''),(365007,116118,'117847','printshop','font-size','12',0,''),(365008,116119,'117848','printshop','data','rrDelivery_name',0,''),(365009,116119,'117848','printshop','font-size','12',0,''),(365010,116120,'117849','printshop','block_type','2',0,''),(365011,116120,'117849','printshop','padding-left','10',0,''),(365012,116120,'117849','printshop','padding-top','20',0,''),(365013,116120,'117849','printshop','padding-right','10',0,''),(365014,116121,'117850','printshop','block_type','5',0,''),(365015,116122,'117851','printshop','text','RMA No:',0,''),(365016,116122,'117851','printshop','font-size','12',0,''),(365017,116122,'117851','printshop','font-weight','bold',0,''),(365018,116123,'117852','printshop','data','rrNumber',0,''),(365019,116123,'117852','printshop','font-size','12',0,''),(365020,116123,'117852','printshop','font-weight','bold',0,''),(365021,116124,'117853','printshop','block_type','2',0,''),(365022,116125,'117854','printshop','text','Date Issued:',0,''),(365023,116125,'117854','printshop','font-size','12',0,''),(365024,116125,'117854','printshop','font-weight','bold',0,''),(365025,116126,'117855','printshop','data','rrDateCreate',0,''),(365026,116126,'117855','printshop','font-size','12',0,''),(365027,116126,'117855','printshop','font-weight','bold',0,''),(365028,116127,'117856','printshop','block_type','1',0,''),(365029,116128,'117857','printshop','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(365030,116128,'117857','printshop','font-size','12',0,''),(365031,116128,'117857','printshop','font-style','italic',0,''),(365032,116128,'117857','printshop','padding-bottom','20',0,''),(365033,116130,'117859','printshop','block_type','1',0,''),(365034,116130,'117859','printshop','border-top-width','1',0,''),(365035,116130,'117859','printshop','border-left-width','1',0,''),(365036,116130,'117859','printshop','border-right-width','1',0,''),(365037,116130,'117859','printshop','border-bottom-width','1',0,''),(365038,116130,'117859','printshop','border-top-color','$highlight-box-border-1',0,''),(365039,116130,'117859','printshop','border-left-color','$highlight-box-border-1',0,''),(365040,116130,'117859','printshop','border-right-color','$highlight-box-border-1',0,''),(365041,116130,'117859','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365042,116131,'117860','printshop','block_type','11',0,''),(365043,116132,'117861','printshop','block_type','1',0,''),(365044,116132,'117861','printshop','padding-top','10',0,''),(365045,116132,'117861','printshop','padding-right','10',0,''),(365046,116132,'117861','printshop','padding-bottom','10',0,''),(365047,116132,'117861','printshop','border-right-width','1',0,''),(365048,116132,'117861','printshop','border-right-color','$highlight-box-border-1',0,''),(365049,116133,'117862','printshop','block_type','9',0,''),(365050,116134,'117863','printshop','text','4.',0,''),(365051,116134,'117863','printshop','font-size','12',0,''),(365052,116134,'117863','printshop','text-align','right',0,''),(365053,116134,'117863','printshop','padding-right','5',0,''),(365054,116135,'117864','printshop','font-size','11',0,''),(365055,116135,'117864','printshop','font-style','italic',0,''),(365056,116135,'117864','printshop','padding-bottom','5',0,''),(365057,116136,'117865','printshop','text','Ship returned items to:',0,''),(365058,116136,'117865','printshop','font-size','12',0,''),(365059,116136,'117865','printshop','padding-bottom','5',0,''),(365060,116137,'117866','printshop','block_type','9',0,''),(365061,116138,'117867','printshop','text','3.',0,''),(365062,116138,'117867','printshop','font-size','12',0,''),(365063,116138,'117867','printshop','text-align','right',0,''),(365064,116138,'117867','printshop','padding-right','5',0,''),(365065,116139,'117868','printshop','text','Ship only the items that are authorized.',0,''),(365066,116139,'117868','printshop','font-size','12',0,''),(365067,116139,'117868','printshop','padding-bottom','10',0,''),(365068,116140,'117869','printshop','block_type','9',0,''),(365069,116141,'117870','printshop','text','1.',0,''),(365070,116141,'117870','printshop','font-size','12',0,''),(365071,116141,'117870','printshop','text-align','right',0,''),(365072,116141,'117870','printshop','padding-right','5',0,''),(365073,116142,'117871','printshop','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(365074,116142,'117871','printshop','font-size','12',0,''),(365075,116142,'117871','printshop','padding-bottom','10',0,''),(365076,116143,'117872','printshop','block_type','1',0,''),(365077,116144,'117873','printshop','text','Shipping Instructions:',0,''),(365078,116144,'117873','printshop','font-weight','bold',0,''),(365079,116144,'117873','printshop','font-size','14',0,''),(365080,116144,'117873','printshop','padding-bottom','5',0,''),(365081,116144,'117873','printshop','padding-left','10',0,''),(365082,116145,'117874','printshop','block_type','9',0,''),(365083,116146,'117875','printshop','text','2.',0,''),(365084,116146,'117875','printshop','font-size','12',0,''),(365085,116146,'117875','printshop','text-align','right',0,''),(365086,116146,'117875','printshop','padding-right','5',0,''),(365087,116147,'117876','printshop','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(365088,116147,'117876','printshop','font-size','12',0,''),(365089,116147,'117876','printshop','padding-bottom','10',0,''),(365090,116148,'117877','printshop','block_type','1',0,''),(365091,116148,'117877','printshop','padding-left','10',0,''),(365092,116148,'117877','printshop','padding-right','10',0,''),(365093,116148,'117877','printshop','padding-bottom','10',0,''),(365094,116149,'117878','printshop','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(365095,116149,'117878','printshop','font-size','11',0,''),(365096,116149,'117878','printshop','font-style','italic',0,''),(365097,116150,'117879','printshop','block_type','1',0,''),(365098,116150,'117879','printshop','padding-top','10',0,''),(365099,116150,'117879','printshop','padding-left','40',0,''),(365100,116150,'117879','printshop','padding-right','40',0,''),(365101,116150,'117879','printshop','padding-bottom','10',0,''),(365102,116151,'117880','printshop','block_type','1',0,''),(365103,116151,'117880','printshop','padding-top','10',0,''),(365104,116151,'117880','printshop','padding-left','10',0,''),(365105,116151,'117880','printshop','padding-right','10',0,''),(365106,116151,'117880','printshop','padding-bottom','10',0,''),(365107,116151,'117880','printshop','border-top-width','1',0,''),(365108,116151,'117880','printshop','border-left-width','1',0,''),(365109,116151,'117880','printshop','border-right-width','1',0,''),(365110,116151,'117880','printshop','border-bottom-width','1',0,''),(365111,116151,'117880','printshop','border-top-color','$highlight-box-border-1',0,''),(365112,116151,'117880','printshop','border-left-color','$highlight-box-border-1',0,''),(365113,116151,'117880','printshop','border-right-color','$highlight-box-border-1',0,''),(365114,116151,'117880','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365115,116152,'117881','printshop','block_type','3',0,''),(365116,116153,'117882','printshop','data','rrDelivery_name',0,''),(365117,116153,'117882','printshop','font-size','9',0,''),(365118,116154,'117883','printshop','block_type','2',0,''),(365119,116155,'117884','printshop','text','RMA#:',0,''),(365120,116155,'117884','printshop','font-size','10',0,''),(365121,116156,'117885','printshop','data','rrNumber',0,''),(365122,116156,'117885','printshop','font-size','9',0,''),(365123,116157,'117886','printshop','block_type','5',0,''),(365124,116158,'117887','printshop','font-size','9',0,''),(365125,116159,'117888','printshop','block_type','1',0,''),(365126,116159,'117888','printshop','padding-left','10',0,''),(365127,116159,'117888','printshop','padding-right','10',0,''),(365128,116159,'117888','printshop','padding-bottom','10',0,''),(365129,116160,'117889','printshop','text','Use this space for additional Comments:',0,''),(365130,116160,'117889','printshop','font-size','11',0,''),(365131,116160,'117889','printshop','font-style','italic',0,''),(365132,116161,'117890','printshop','text','&nbsp;',0,''),(365133,116161,'117890','printshop','border-bottom-width','1',0,''),(365134,116161,'117890','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365135,116162,'117891','printshop','text','&nbsp;',0,''),(365136,116162,'117891','printshop','border-bottom-width','1',0,''),(365137,116162,'117891','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365138,116162,'117891','printshop','padding-top','5',0,''),(365139,116163,'117892','printshop','text','&nbsp;',0,''),(365140,116163,'117892','printshop','border-bottom-width','1',0,''),(365141,116163,'117892','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365142,116163,'117892','printshop','padding-top','5',0,''),(365143,116164,'117893','printshop','text','&nbsp;',0,''),(365144,116164,'117893','printshop','border-bottom-width','1',0,''),(365145,116164,'117893','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365146,116164,'117893','printshop','padding-top','5',0,''),(365147,116165,'117894','printshop','block_type','3',0,''),(365148,116165,'117894','printshop','padding-top','10',0,''),(365149,116165,'117894','printshop','padding-bottom','10',0,''),(365150,116165,'117894','printshop','padding-right','10',0,''),(365151,116166,'117895','printshop','font-size','11',0,''),(365152,116166,'117895','printshop','font-weight','bold',0,''),(365153,116166,'117895','printshop','text','Return Approval:',0,''),(365154,116166,'117895','printshop','padding-top','5',0,''),(365155,116166,'117895','printshop','padding-left','10',0,''),(365156,116167,'117896','printshop','border-bottom-width','1',0,''),(365157,116167,'117896','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365158,116167,'117896','printshop','text','&nbsp;',0,''),(365159,116168,'117897','printshop','block_type','5',0,''),(365160,116169,'117898','printshop','text','Date:',0,''),(365161,116169,'117898','printshop','padding-top','5',0,''),(365162,116169,'117898','printshop','font-size','11',0,''),(365163,116169,'117898','printshop','font-weight','bold',0,''),(365164,116169,'117898','printshop','padding-left','5',0,''),(365165,116170,'117899','printshop','text','&nbsp;',0,''),(365166,116170,'117899','printshop','border-bottom-width','1',0,''),(365167,116170,'117899','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365168,116171,'117900','printshop','block_type','3',0,''),(365169,116171,'117900','printshop','padding-right','10',0,''),(365170,116172,'117901','printshop','text','Customer Signature:',0,''),(365171,116172,'117901','printshop','font-weight','bold',0,''),(365172,116172,'117901','printshop','font-size','11',0,''),(365173,116172,'117901','printshop','padding-top','5',0,''),(365174,116172,'117901','printshop','padding-left','10',0,''),(365175,116173,'117902','printshop','text','&nbsp;',0,''),(365176,116173,'117902','printshop','border-bottom-width','1',0,''),(365177,116173,'117902','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365178,116174,'117903','printshop','block_type','5',0,''),(365179,116175,'117904','printshop','text','Date:',0,''),(365180,116175,'117904','printshop','padding-top','5',0,''),(365181,116175,'117904','printshop','font-size','11',0,''),(365182,116175,'117904','printshop','font-weight','bold',0,''),(365183,116175,'117904','printshop','padding-left','5',0,''),(365184,116176,'117905','printshop','text','&nbsp;',0,''),(365185,116176,'117905','printshop','border-bottom-width','1',0,''),(365186,116176,'117905','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365187,116177,'117906','printshop','block_type','1',0,''),(365188,116177,'117906','printshop','style_class','item-holder',0,''),(365189,116177,'117906','printshop','padding-top','25',0,''),(365190,116177,'117906','printshop','padding-bottom','25',0,''),(365191,116177,'117906','printshop','text-align','left',0,''),(365192,116177,'117906','printshop','border-top-width','1',0,''),(365193,116177,'117906','printshop','border-top-color','$content-border-3',0,''),(365194,116178,'117907','printshop','block_type','7',0,''),(365195,116178,'117907','printshop','schema','7-2',0,'5342'),(365196,116179,'117908','printshop','block_type','5',0,''),(365197,116179,'117908','printshop','schema','5-2',0,'5342'),(365198,116180,'117909','printshop','clear','none',0,''),(365199,116180,'117909','printshop','padding-right','20',0,''),(365200,116181,'117910','printshop','padding-right','20',0,''),(365201,116181,'117910','printshop','max-width','300',0,'5342'),(365202,116181,'117910','printshop','margin_left_measure','auto',0,'5342'),(365203,116181,'117910','printshop','margin_right_measure','auto',0,'5342'),(365204,116182,'117914','printshop','padding-right','20',0,''),(365205,116183,'117915','printshop','description_characters','200',0,''),(365206,116183,'117915','printshop','clear','none',0,''),(365207,116183,'117915','printshop','padding-right','20',0,''),(365208,116184,'117916','printshop','clear','none',0,''),(365209,116185,'117917','printshop','margin-bottom','20',0,''),(365210,116188,'117918','printshop','block_type','1',0,''),(365211,116188,'117918','printshop','padding-left','40',0,''),(365212,116188,'117918','printshop','style_class','right-aria',0,''),(365213,116188,'117918','printshop','padding-left','0',0,'5342'),(365214,116189,'117911','printshop','block_type','1',0,''),(365215,116189,'117911','printshop','text-align','center',0,''),(365216,116190,'117912','printshop','margin-top','4',0,''),(365217,116190,'117912','printshop','margin-bottom','7',0,''),(365218,116191,'117913','printshop','padding-top','6',0,''),(365219,116191,'117913','printshop','padding-left','5',0,''),(365220,116192,'117919','printshop','margin-bottom','15',0,''),(365221,116192,'117919','printshop','text-align','center',0,''),(365222,116193,'117920','printshop','margin-bottom','10',0,''),(365223,116193,'117920','printshop','text-align','center',0,''),(365224,116194,'117922','printshop','text-align','center',0,''),(365225,116194,'117922','printshop','margin-bottom','15',0,''),(365226,116195,'117924','printshop','text-align','center',0,''),(365227,116195,'117924','printshop','margin-bottom','10',0,''),(365228,116197,'120926','printshop','text-align','center',0,''),(365229,116197,'120926','printshop','margin-bottom','15',0,''),(365230,116198,'120927','printshop','text-align','center',0,''),(365231,116198,'120927','printshop','margin-bottom','15',0,''),(365232,116199,'117925','printshop','block_type','1',0,''),(365233,116199,'117925','printshop','padding-top','20',0,''),(365234,116199,'117925','printshop','padding-bottom','20',0,''),(365235,116199,'117925','printshop','background-color','$content-bg-2',0,''),(365236,116201,'117927','printshop','block_type','7',0,''),(365237,116201,'117927','printshop','schema','4-2',0,'5342'),(365238,116202,'117928','printshop','padding-bottom','20',0,''),(365239,116202,'117928','printshop','background-color','$content-bg-1',0,''),(365240,116203,'117929','printshop','style_class','order-summary',0,''),(365241,116203,'117929','printshop','padding-left','25',0,''),(365242,116203,'117929','printshop','block_type','1',0,''),(365243,116203,'117929','printshop','padding-left','0',0,'5342'),(365244,116203,'117929','printshop','margin-top','30',0,'5342'),(365245,116204,'117930','printshop','block_type','1',0,''),(365246,116204,'117930','printshop','padding-left','20',0,''),(365247,116204,'117930','printshop','padding-right','20',0,''),(365248,116204,'117930','printshop','padding-bottom','20',0,''),(365249,116204,'117930','printshop','padding-top','20',0,''),(365250,116205,'117931','printshop','max-width','300',0,'5342'),(365251,116205,'117931','printshop','margin_left_measure','auto',0,'5342'),(365252,116205,'117931','printshop','margin_right_measure','auto',0,'5342'),(365253,116206,'117932','printshop','block_type','1',0,''),(365254,116206,'117932','printshop','style_class','account-samples',0,''),(365255,116207,'117933','printshop','block_type','6',0,''),(365256,116207,'117933','printshop','schema','6-3',0,'5342'),(365257,116208,'117934','printshop','aria_name','account-menu',0,''),(365320,116228,'117935','printshop','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(365321,116229,'117936','printshop','show_pagenation','1',0,''),(365322,116229,'117936','printshop','link','Sample Info',0,''),(365323,116229,'117936','printshop','margin-bottom','20',0,''),(365324,116230,'117937','printshop','block_type','1',0,''),(365325,116230,'117937','printshop','style_class','account-sample-info',0,''),(365326,116231,'117938','printshop','block_type','6',0,''),(365327,116231,'117938','printshop','schema','6-3',0,'5342'),(365328,116232,'117939','printshop','aria_name','account-menu',0,''),(365391,116252,'117940','printshop','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(365392,116253,'117941','printshop','block_type','2',0,''),(365393,116253,'117941','printshop','padding-top','20',0,''),(365394,116253,'117941','printshop','margin-bottom','20',0,''),(365395,116254,'117942','printshop','like_button','1',0,''),(365396,116254,'117942','printshop','text','IMAGE_BUTTON_BACK',0,''),(365397,116254,'117942','printshop','link','Samples',0,''),(365398,116256,'117944','printshop','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(365399,116259,'117947','printshop','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(365400,116260,'117948','printshop','block_type','3',0,''),(365401,116261,'117949','printshop','block_type','1',0,''),(365402,116261,'117949','printshop','padding-right','20',0,''),(365403,116261,'117949','printshop','padding-bottom','20',0,''),(365404,116262,'117950','printshop','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(365405,116263,'117951','printshop','orders_data','telephone',0,''),(365406,116264,'117952','printshop','block_type','1',0,''),(365407,116264,'117952','printshop','padding-right','20',0,''),(365408,116264,'117952','printshop','padding-bottom','20',0,''),(365409,116265,'117953','printshop','orders_data','name',0,''),(365410,116266,'117954','printshop','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(365411,116267,'117955','printshop','block_type','1',0,''),(365412,116267,'117955','printshop','padding-right','20',0,''),(365413,116268,'117956','printshop','orders_data','shipping_method',0,''),(365414,116269,'117957','printshop','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(365415,116270,'117958','printshop','block_type','1',0,''),(365416,116270,'117958','printshop','padding-right','20',0,''),(365417,116270,'117958','printshop','padding-bottom','20',0,''),(365418,116271,'117959','printshop','orders_data','delivery_address',0,''),(365419,116272,'117960','printshop','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(365420,116273,'117961','printshop','block_type','1',0,''),(365421,116274,'117962','printshop','orders_data','payment_method',0,''),(365422,116275,'117963','printshop','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(365423,116276,'117964','printshop','block_type','1',0,''),(365424,116276,'117964','printshop','padding-bottom','20',0,''),(365425,116277,'117965','printshop','orders_data','billing_address',0,''),(365426,116278,'117966','printshop','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(365427,116279,'117967','printshop','block_type','1',0,''),(365428,116280,'117968','printshop','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(365429,116281,'117969','printshop','block_type','6',0,''),(365430,116282,'117970','printshop','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(365431,116283,'117971','printshop','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(365432,116284,'117972','printshop','text','<div class=\"heading-4\">Categories</div>',0,''),(365433,116287,'117975','printshop','class','menu-simple',0,''),(365434,116289,'117977','printshop','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(365435,116290,'120878','printshop','float','left',0,''),(365436,116290,'120878','printshop','margin-right','10',0,''),(365437,116291,'117978','printshop','block_type','1',0,''),(365438,116292,'117979','printshop','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(365439,116292,'117979','printshop','style_class','middle-form',0,''),(365440,116293,'117980','printshop','style_class','middle-form',0,''),(365441,116294,'117981','printshop','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(365442,116295,'117982','printshop','style_class','middle-form',0,''),(365443,116295,'117982','printshop','margin-bottom','30',0,''),(365444,116296,'117983','printshop','block_type','1',0,''),(365445,116297,'117984','printshop','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(365446,116297,'117984','printshop','padding-top','100',0,''),(365447,116297,'117984','printshop','margin-bottom','100',0,''),(365448,116297,'117984','printshop','text-align','center',0,''),(365449,116297,'117984','printshop','font-size','20',0,''),(365450,116298,'117985','printshop','block_type','1',0,''),(365451,116299,'117986','printshop','block_type','6',0,''),(365452,116299,'117986','printshop','schema','6-3',0,'5342'),(365453,116300,'117987','printshop','aria_name','account-menu',0,''),(365516,116320,'117988','printshop','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(365517,116321,'117989','printshop','text','##SUBSCRIPTION_TEXT##',0,''),(365518,116323,'1694162315.037980','printshop','block_type','1',0,''),(365519,116323,'1694162315.037980','printshop','background-color','$content-bg-2',0,''),(365520,116323,'1694162315.037980','printshop','padding-bottom','30',0,''),(365521,116323,'1694162315.037980','printshop','style_class','success-page',0,''),(365522,116323,'1694162315.037980','printshop','color','$content-color-2',0,''),(365523,116324,'1694162315.120936','printshop','block_type','12',0,''),(365524,116324,'1694162315.120936','printshop','schema','4-2',0,'5342'),(365525,116325,'1694162315.123135','printshop','block_type','1',0,''),(365526,116325,'1694162315.123135','printshop','padding-right','40',0,''),(365527,116325,'1694162315.123135','printshop','padding-right','0',0,'5342'),(365528,116326,'1694162315.12436','printshop','block_type','2',0,''),(365529,116326,'1694162315.12436','printshop','margin-bottom','20',0,''),(365530,116326,'1694162315.12436','printshop','schema','2-2',0,'5333'),(365531,116326,'1694162315.12436','printshop','background-color','$content-bg-1',0,''),(365532,116326,'1694162315.12436','printshop','color','$content-color-1',0,''),(365533,116327,'1694162315.125735','printshop','block_type','1',0,''),(365534,116327,'1694162315.125735','printshop','border-right-width','20',0,''),(365535,116327,'1694162315.125735','printshop','border-right-color','$content-bg-2',0,''),(365536,116327,'1694162315.125735','printshop','margin-right','-10',0,''),(365537,116327,'1694162315.125735','printshop','padding-right','30',0,''),(365538,116327,'1694162315.125735','printshop','padding-top','20',0,''),(365539,116327,'1694162315.125735','printshop','padding-left','30',0,''),(365540,116327,'1694162315.125735','printshop','padding-bottom','20',0,''),(365541,116327,'1694162315.125735','printshop','border-right-width','0',0,'5342'),(365542,116327,'1694162315.125735','printshop','margin-right','0',0,'5342'),(365543,116327,'1694162315.125735','printshop','margin-bottom','20',0,'5342'),(365544,116327,'1694162315.125735','printshop','padding-left','20',0,'5342'),(365545,116327,'1694162315.125735','printshop','padding-right','20',0,'5342'),(365546,116327,'1694162315.125735','printshop','background-color','$content-bg-1',0,''),(365547,116329,'1694162315.128991','printshop','margin-bottom','20',0,''),(365548,116330,'1694162315.136','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(365549,116330,'1694162315.136','printshop','padding-top','20',0,''),(365550,116331,'1694162315.143264','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(365551,116331,'1694162315.143264','printshop','clear','none',0,''),(365552,116332,'1694162315.14584','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(365553,116334,'1694162315.147338','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(365554,116334,'1694162315.147338','printshop','clear','none',0,''),(365555,116335,'1694162315.14989','printshop','block_type','1',0,''),(365556,116335,'1694162315.14989','printshop','padding-left','30',0,''),(365557,116335,'1694162315.14989','printshop','border-left-width','20',0,''),(365558,116335,'1694162315.14989','printshop','border-left-color','$content-bg-2',0,''),(365559,116335,'1694162315.14989','printshop','margin-left','-10',0,''),(365560,116335,'1694162315.14989','printshop','padding-right','30',0,''),(365561,116335,'1694162315.14989','printshop','padding-top','20',0,''),(365562,116335,'1694162315.14989','printshop','padding-bottom','20',0,''),(365563,116335,'1694162315.14989','printshop','border-left-width','0',0,'5342'),(365564,116335,'1694162315.14989','printshop','background-color','$content-bg-1',0,''),(365565,116337,'1694162315.151341','printshop','margin-bottom','20',0,''),(365566,116338,'1694162315.152381','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(365567,116338,'1694162315.152381','printshop','clear','none',0,''),(365568,116339,'1694162315.153514','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(365569,116340,'1694162315.154777','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(365570,116340,'1694162315.154777','printshop','clear','none',0,''),(365571,116341,'1694162315.155812','printshop','text','<div class=\"page-success\">\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>',0,''),(365572,116341,'1694162315.155812','printshop','background-color','$content-bg-1',0,''),(365573,116341,'1694162315.155812','printshop','margin-bottom','30',0,''),(365574,116341,'1694162315.155812','printshop','padding-top','30',0,''),(365575,116341,'1694162315.155812','printshop','padding-bottom','30',0,''),(365576,116341,'1694162315.155812','printshop','padding-left','30',0,''),(365577,116341,'1694162315.155812','printshop','padding-right','30',0,''),(365578,116341,'1694162315.155812','printshop','color','$content-color-1',0,''),(365579,116342,'1694162315.15769','printshop','block_type','1',0,''),(365580,116342,'1694162315.15769','printshop','style_class','order-summary2 hiding-box',0,''),(365581,116343,'1694162315.158534','printshop','text-align','center',0,''),(365582,116343,'1694162315.158534','printshop','margin-bottom','20',0,''),(365583,116344,'1694162315.1668','printshop','text-align','center',0,''),(365584,116347,'1694162315.163184','printshop','block_type','12',0,''),(365585,116348,'1694162315.16467','printshop','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n</div>\n',0,''),(365586,116348,'1694162315.16467','printshop','margin-bottom','20',0,''),(365587,116349,'1694162315.165266','printshop','text-align','center',0,''),(365588,116349,'1694162315.165266','printshop','padding-top','40',0,''),(365589,116350,'117997','printshop','block_type','1',0,''),(365590,116351,'117998','printshop','block_type','1',0,''),(365591,116351,'117998','printshop','font-weight','normal',0,''),(365592,116352,'117999','printshop','block_type','1',0,''),(365593,116352,'117999','printshop','text-align','center',0,''),(365594,116352,'117999','printshop','padding-top','30',0,''),(365595,116352,'117999','printshop','margin-bottom','200',0,''),(365596,116353,'118000','printshop','display','inline-block',0,''),(365597,116353,'118000','printshop','clear','none',0,''),(365598,116353,'118000','printshop','margin-left','20',0,''),(365599,116354,'118001','printshop','display','inline-block',0,''),(365600,116355,'118002','printshop','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(365605,116360,'118007','printshop','width','680',0,''),(365606,116360,'118007','printshop','font-weight','normal',0,''),(365607,116360,'118007','printshop','font-size','12',0,''),(365608,116360,'118007','printshop','padding-top','20',0,''),(365609,116360,'118007','printshop','padding-bottom','20',0,''),(365610,116360,'118007','printshop','color','$content-color-1',0,''),(365611,116361,'118008','printshop','block_type','5',0,''),(365612,116361,'118008','printshop','font-weight','normal',0,''),(365613,116361,'118008','printshop','border-bottom-width','1',0,''),(365614,116361,'118008','printshop','border-bottom-color','$content-border-3',0,''),(365615,116361,'118008','printshop','border-top-width','1',0,''),(365616,116361,'118008','printshop','border-top-color','$content-border-3',0,''),(365617,116361,'118008','printshop','border-left-color','$content-border-3',0,''),(365618,116361,'118008','printshop','border-left-width','1',0,''),(365619,116362,'118009','printshop','block_type','1',0,''),(365620,116362,'118009','printshop','font-weight','normal',0,''),(365621,116362,'118009','printshop','padding-top','10',0,''),(365622,116362,'118009','printshop','padding-left','10',0,''),(365623,116362,'118009','printshop','padding-right','10',0,''),(365624,116363,'118010','printshop','font-weight','400',0,''),(365625,116363,'118010','printshop','line-height','120',0,''),(365626,116363,'118010','printshop','line_height_measure','%',0,''),(365627,116363,'118010','printshop','font-size','12',0,''),(365628,116364,'118011','printshop','text','<p>SHIPPING ADDRESS:</p>',1,''),(365629,116364,'118011','printshop','font-size','14',0,''),(365630,116364,'118011','printshop','font-weight','bold',0,''),(365631,116364,'118011','printshop','padding-bottom','10',0,''),(365632,116364,'118011','printshop','text','<p>SHIPPING ADDRESS:</p>',2,''),(365633,116364,'118011','printshop','text','<p>SHIPPING ADDRESS:</p>',3,''),(365634,116364,'118011','printshop','text','<p>SHIPPING ADDRESS:</p>',4,''),(365635,116365,'118012','printshop','block_type','1',0,''),(365636,116365,'118012','printshop','background-color','$content-bg-2',0,''),(365637,116365,'118012','printshop','padding-top','20',0,''),(365638,116365,'118012','printshop','padding-left','10',0,''),(365639,116365,'118012','printshop','padding-right','10',0,''),(365640,116365,'118012','printshop','padding-bottom','20',0,''),(365641,116365,'118012','printshop','font-size','14',0,''),(365642,116366,'118013','printshop','font-weight','normal',0,''),(365643,116366,'118013','printshop','text-align','right',0,''),(365644,116366,'118013','printshop','font-size','14',0,''),(365645,116366,'118013','printshop','box_align','3',0,''),(365646,116367,'118014','printshop','block_type','3',0,''),(365647,116367,'118014','printshop','font-weight','normal',0,''),(365648,116367,'118014','printshop','padding-top','20',0,''),(365649,116368,'118015','printshop','text','<p>If undelivered please return to:</p>',1,''),(365650,116368,'118015','printshop','font-size','12',0,''),(365651,116368,'118015','printshop','font-weight','bold',0,''),(365652,116368,'118015','printshop','text','<p>If undelivered please return to:</p>',2,''),(365653,116368,'118015','printshop','text','<p>If undelivered please return to:</p>',3,''),(365654,116368,'118015','printshop','text','<p>If undelivered please return to:</p>',4,''),(365655,116369,'118016','printshop','font-size','12',0,''),(365656,116370,'118018','printshop','text','<p>Thank you for your order</p>',1,''),(365657,116370,'118018','printshop','color','$hileght-color-1',0,''),(365658,116370,'118018','printshop','font-size','13',0,''),(365659,116370,'118018','printshop','font-weight','bold',0,''),(365660,116370,'118018','printshop','padding-top','5',0,''),(365661,116370,'118018','printshop','text-align','center',0,''),(365662,116370,'118018','printshop','text','<p>Thank you for your order</p>',2,''),(365663,116370,'118018','printshop','text','<p>Thank you for your order</p>',3,''),(365664,116370,'118018','printshop','text','<p>Thank you for your order</p>',4,''),(365665,116371,'118019','printshop','text','<p>If something has gone wrong please contact us at:</p>',1,''),(365666,116371,'118019','printshop','font-size','12',0,''),(365667,116371,'118019','printshop','font-weight','bold',0,''),(365668,116371,'118019','printshop','text-align','right',0,''),(365669,116371,'118019','printshop','text','<p>If something has gone wrong please contact us at:</p>',2,''),(365670,116371,'118019','printshop','text','<p>If something has gone wrong please contact us at:</p>',3,''),(365671,116371,'118019','printshop','text','<p>If something has gone wrong please contact us at:</p>',4,''),(365672,116372,'118020','printshop','block_type','6',0,''),(365673,116372,'118020','printshop','font-weight','normal',0,''),(365674,116372,'118020','printshop','font-size','16',0,''),(365675,116373,'118021','printshop','text','<p>Email:</p>',1,''),(365676,116373,'118021','printshop','font-weight','normal',0,''),(365677,116373,'118021','printshop','text-align','right',0,''),(365678,116373,'118021','printshop','font-size','12',0,''),(365679,116373,'118021','printshop','text','<p>Email:</p>',2,''),(365680,116373,'118021','printshop','text','<p>Email:</p>',3,''),(365681,116373,'118021','printshop','text','<p>Email:</p>',4,''),(365682,116374,'118022','printshop','font-weight','normal',0,''),(365683,116374,'118022','printshop','text-align','right',0,''),(365684,116374,'118022','printshop','font-size','12',0,''),(365685,116375,'118023','printshop','block_type','6',0,''),(365686,116375,'118023','printshop','font-weight','normal',0,''),(365687,116375,'118023','printshop','font-size','16',0,''),(365688,116376,'118024','printshop','text','<p>Phone:</p>',1,''),(365689,116376,'118024','printshop','font-weight','normal',0,''),(365690,116376,'118024','printshop','text-align','right',0,''),(365691,116376,'118024','printshop','font-size','12',0,''),(365692,116376,'118024','printshop','text','<p>Phone:</p>',2,''),(365693,116376,'118024','printshop','text','<p>Phone:</p>',3,''),(365694,116376,'118024','printshop','text','<p>Phone:</p>',4,''),(365695,116377,'118025','printshop','font-weight','normal',0,''),(365696,116377,'118025','printshop','text-align','right',0,''),(365697,116377,'118025','printshop','font-size','12',0,''),(365698,116378,'118026','printshop','font-weight','400',0,''),(365699,116378,'118026','printshop','padding-top','20',0,''),(365700,116378,'118026','printshop','padding-bottom','0',0,''),(365701,116378,'118026','printshop','font-size','12',0,''),(365702,116379,'118027','printshop','block_type','2',0,''),(365703,116379,'118027','printshop','font-weight','normal',0,''),(365704,116379,'118027','printshop','padding-bottom','20',0,''),(365705,116380,'118028','printshop','block_type','11',0,''),(365706,116380,'118028','printshop','font-weight','normal',0,''),(365707,116381,'118029','printshop','text','<p>Email:</p>',1,''),(365708,116381,'118029','printshop','font-weight','normal',0,''),(365709,116381,'118029','printshop','text-align','right',0,''),(365710,116381,'118029','printshop','text','<p>Email:</p>',2,''),(365711,116381,'118029','printshop','text','<p>Email:</p>',3,''),(365712,116381,'118029','printshop','text','<p>Email:</p>',4,''),(365713,116382,'118030','printshop','font-weight','normal',0,''),(365714,116382,'118030','printshop','text-align','right',0,''),(365715,116383,'118031','printshop','block_type','11',0,''),(365716,116383,'118031','printshop','font-weight','normal',0,''),(365717,116384,'118032','printshop','text','<p>Web:</p>',1,''),(365718,116384,'118032','printshop','font-weight','normal',0,''),(365719,116384,'118032','printshop','text-align','right',0,''),(365720,116384,'118032','printshop','text','<p>Web:</p>',2,''),(365721,116384,'118032','printshop','text','<p>Web:</p>',3,''),(365722,116384,'118032','printshop','text','<p>Web:</p>',4,''),(365723,116385,'118033','printshop','font-weight','normal',0,''),(365724,116385,'118033','printshop','text-align','right',0,''),(365725,116386,'118034','printshop','block_type','1',0,''),(365726,116387,'118035','printshop','font-weight','normal',0,''),(365727,116387,'118035','printshop','text-align','right',0,''),(365728,116387,'118035','printshop','padding-bottom','10',0,''),(365729,116387,'118035','printshop','address_spacer',',',0,''),(365730,116387,'118035','printshop','font-size','12',0,''),(365731,116388,'118036','printshop','block_type','11',0,''),(365732,116388,'118036','printshop','font-weight','normal',0,''),(365733,116389,'118037','printshop','text','<p>Phone:</p>',1,''),(365734,116389,'118037','printshop','font-weight','normal',0,''),(365735,116389,'118037','printshop','text-align','right',0,''),(365736,116389,'118037','printshop','text','<p>Phone:</p>',2,''),(365737,116389,'118037','printshop','text','<p>Phone:</p>',3,''),(365738,116389,'118037','printshop','text','<p>Phone:</p>',4,''),(365739,116390,'118038','printshop','font-weight','normal',0,''),(365740,116390,'118038','printshop','text-align','right',0,''),(365741,116391,'118039','printshop','block_type','4',0,''),(365742,116391,'118039','printshop','font-weight','normal',0,''),(365743,116391,'118039','printshop','border-top-width','1',0,''),(365744,116391,'118039','printshop','border-top-color','$content-border-3',0,''),(365745,116391,'118039','printshop','border-left-width','1',0,''),(365746,116391,'118039','printshop','border-left-color','$content-border-3',0,''),(365747,116391,'118039','printshop','border-right-width','1',0,''),(365748,116391,'118039','printshop','border-right-color','$content-border-3',0,''),(365749,116391,'118039','printshop','border-bottom-width','1',0,''),(365750,116391,'118039','printshop','border-bottom-color','$content-border-3',0,''),(365751,116392,'118040','printshop','block_type','2',0,''),(365752,116392,'118040','printshop','font-weight','normal',0,''),(365753,116392,'118040','printshop','border-top-width','1',0,''),(365754,116392,'118040','printshop','border-top-color','$content-border-3',0,''),(365755,116392,'118040','printshop','border-right-width','1',0,''),(365756,116392,'118040','printshop','border-right-color','$content-border-3',0,''),(365757,116393,'118041','printshop','block_type','1',0,''),(365758,116393,'118041','printshop','font-weight','normal',0,''),(365759,116393,'118041','printshop','padding-top','10',0,''),(365760,116393,'118041','printshop','padding-left','10',0,''),(365761,116393,'118041','printshop','padding-right','10',0,''),(365762,116393,'118041','printshop','padding-bottom','10',0,''),(365763,116393,'118041','printshop','border-right-width','1',0,''),(365764,116393,'118041','printshop','border-right-color','$content-border-3',0,''),(365765,116394,'118042','printshop','text','<p>Shipping via</p>',1,''),(365766,116394,'118042','printshop','font-weight','bold',0,''),(365767,116394,'118042','printshop','font-size','14',0,''),(365768,116394,'118042','printshop','text','<p>Shipping via</p>',2,''),(365769,116394,'118042','printshop','text','<p>Shipping via</p>',3,''),(365770,116394,'118042','printshop','text','<p>Shipping via</p>',4,''),(365771,116396,'118044','printshop','block_type','1',0,''),(365772,116396,'118044','printshop','font-weight','normal',0,''),(365773,116396,'118044','printshop','padding-top','10',0,''),(365774,116396,'118044','printshop','padding-left','10',0,''),(365775,116396,'118044','printshop','padding-right','10',0,''),(365776,116396,'118044','printshop','padding-bottom','10',0,''),(365777,116397,'118045','printshop','text','<p>Shipping service</p>',1,''),(365778,116397,'118045','printshop','font-weight','bold',0,''),(365779,116397,'118045','printshop','font-size','14',0,''),(365780,116397,'118045','printshop','text','<p>Shipping service</p>',2,''),(365781,116397,'118045','printshop','text','<p>Shipping service</p>',3,''),(365782,116397,'118045','printshop','text','<p>Shipping service</p>',4,''),(365783,116399,'118047','printshop','block_type','2',0,''),(365784,116399,'118047','printshop','font-weight','normal',0,''),(365785,116399,'118047','printshop','border-right-width','1',0,''),(365786,116399,'118047','printshop','border-right-color','$content-border-3',0,''),(365787,116400,'118048','printshop','block_type','1',0,''),(365788,116400,'118048','printshop','font-weight','400',0,''),(365789,116400,'118048','printshop','background-color','$content-bg-2',0,''),(365790,116400,'118048','printshop','padding-top','10',0,''),(365791,116400,'118048','printshop','padding-left','10',0,''),(365792,116400,'118048','printshop','padding-right','10',0,''),(365793,116400,'118048','printshop','padding-bottom','30',0,''),(365794,116401,'118049','printshop','font-size','12',0,''),(365795,116402,'118050','printshop','text','<p>INVOICE ADDRESS:</p>',1,''),(365796,116402,'118050','printshop','font-size','14',0,''),(365797,116402,'118050','printshop','font-weight','bold',0,''),(365798,116402,'118050','printshop','text','<p>INVOICE ADDRESS:</p>',2,''),(365799,116402,'118050','printshop','text','<p>INVOICE ADDRESS:</p>',3,''),(365800,116402,'118050','printshop','text','<p>INVOICE ADDRESS:</p>',4,''),(365801,116403,'118051','printshop','block_type','1',0,''),(365802,116403,'118051','printshop','font-weight','normal',0,''),(365803,116403,'118051','printshop','padding-top','10',0,''),(365804,116403,'118051','printshop','padding-left','10',0,''),(365805,116403,'118051','printshop','padding-right','10',0,''),(365806,116403,'118051','printshop','padding-bottom','10',0,''),(365807,116404,'118052','printshop','font-weight','normal',0,''),(365808,116405,'118053','printshop','text','<p>PHONE NUMBER:</p>',1,''),(365809,116405,'118053','printshop','font-size','14',0,''),(365810,116405,'118053','printshop','font-weight','bold',0,''),(365811,116405,'118053','printshop','padding-top','10',0,''),(365812,116405,'118053','printshop','text','<p>PHONE NUMBER:</p>',2,''),(365813,116405,'118053','printshop','text','<p>PHONE NUMBER:</p>',3,''),(365814,116405,'118053','printshop','text','<p>PHONE NUMBER:</p>',4,''),(365815,116407,'118055','printshop','font-weight','normal',0,''),(365816,116408,'118056','printshop','text','<p>E-MAIL ADDRESS:</p>',1,''),(365817,116408,'118056','printshop','font-weight','bold',0,''),(365818,116408,'118056','printshop','font-size','14',0,''),(365819,116408,'118056','printshop','padding-top','10',0,''),(365820,116408,'118056','printshop','text','<p>E-MAIL ADDRESS:</p>',2,''),(365821,116408,'118056','printshop','text','<p>E-MAIL ADDRESS:</p>',3,''),(365822,116408,'118056','printshop','text','<p>E-MAIL ADDRESS:</p>',4,''),(365823,116409,'118057','printshop','text','<p>CUSTOMER:</p>',1,''),(365824,116409,'118057','printshop','font-size','13',0,''),(365825,116409,'118057','printshop','font-weight','bold',0,''),(365826,116409,'118057','printshop','text','<p>CUSTOMER:</p>',2,''),(365827,116409,'118057','printshop','text','<p>CUSTOMER:</p>',3,''),(365828,116409,'118057','printshop','text','<p>CUSTOMER:</p>',4,''),(365829,116410,'118058','printshop','font-weight','normal',0,''),(365830,116410,'118058','printshop','text-align','center',0,''),(365831,116410,'118058','printshop','padding-bottom','10',0,''),(365832,116411,'118059','printshop','text','<p>Payment date:</p>',1,''),(365833,116411,'118059','printshop','font-weight','bold',0,''),(365834,116411,'118059','printshop','text-align','center',0,''),(365835,116411,'118059','printshop','font-size','12',0,''),(365836,116411,'118059','printshop','text','<p>Payment date:</p>',2,''),(365837,116411,'118059','printshop','text','<p>Payment date:</p>',3,''),(365838,116411,'118059','printshop','text','<p>Payment date:</p>',4,''),(365839,116412,'118060','printshop','text','<p>Payment Method:</p>',1,''),(365840,116412,'118060','printshop','font-weight','bold',0,''),(365841,116412,'118060','printshop','text-align','center',0,''),(365842,116412,'118060','printshop','text','<p>Payment Method:</p>',2,''),(365843,116412,'118060','printshop','text','<p>Payment Method:</p>',3,''),(365844,116412,'118060','printshop','text','<p>Payment Method:</p>',4,''),(365845,116413,'118061','printshop','font-size','14',0,''),(365846,116413,'118061','printshop','font-weight','bold',0,''),(365847,116413,'118061','printshop','text-align','center',0,''),(365848,116413,'118061','printshop','padding-bottom','10',0,''),(365849,116413,'118061','printshop','padding-top','10',0,''),(365850,116414,'118062','printshop','font-weight','normal',0,''),(365851,116414,'118062','printshop','text-align','center',0,''),(365852,116414,'118062','printshop','padding-bottom','20',0,''),(365853,116415,'118063','printshop','font-weight','normal',0,''),(365854,116415,'118063','printshop','text-align','center',0,''),(365855,116416,'118094','printshop','block_type','1',0,''),(365856,116417,'118095','printshop','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(365857,116419,'118318','printshop','block_type','1',0,''),(365858,116420,'118319','printshop','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(365859,116420,'118319','printshop','padding-top','100',0,''),(365860,116420,'118319','printshop','margin-bottom','100',0,''),(365861,116420,'118319','printshop','text-align','center',0,''),(365862,116420,'118319','printshop','font-size','20',0,''),(365863,116421,'118320','printshop','block_type','1',0,''),(365864,116421,'118320','printshop','background-color','$content-bg-2',0,''),(365865,116421,'118320','printshop','padding-bottom','30',0,''),(365866,116422,'118321','printshop','block_type','4',0,''),(365867,116422,'118321','printshop','schema','4-2',0,'5342'),(365868,116423,'118322','printshop','block_type','1',0,''),(365869,116423,'118322','printshop','padding-right','40',0,''),(365870,116423,'118322','printshop','padding-right','0',0,'5342'),(365871,116424,'118323','printshop','block_type','2',0,''),(365872,116424,'118323','printshop','margin-bottom','20',0,''),(365873,116424,'118323','printshop','schema','2-2',0,'5333'),(365874,116424,'118323','printshop','background-color','$content-bg-1',0,''),(365875,116425,'118324','printshop','block_type','1',0,''),(365876,116425,'118324','printshop','border-right-width','20',0,''),(365877,116425,'118324','printshop','border-right-color','$content-border-3',0,''),(365878,116425,'118324','printshop','margin-right','-10',0,''),(365879,116425,'118324','printshop','padding-right','30',0,''),(365880,116425,'118324','printshop','padding-top','20',0,''),(365881,116425,'118324','printshop','padding-left','30',0,''),(365882,116425,'118324','printshop','padding-bottom','20',0,''),(365883,116425,'118324','printshop','border-right-width','0',0,'5342'),(365884,116425,'118324','printshop','margin-right','0',0,'5342'),(365885,116425,'118324','printshop','margin-bottom','20',0,'5342'),(365886,116425,'118324','printshop','padding-left','20',0,'5342'),(365887,116425,'118324','printshop','padding-right','20',0,'5342'),(365888,116427,'118326','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(365889,116427,'118326','printshop','clear','none',0,''),(365890,116428,'118327','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(365891,116428,'118327','printshop','clear','none',0,''),(365892,116429,'118328','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(365893,116431,'118330','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(365894,116431,'118330','printshop','padding-top','20',0,''),(365895,116434,'118333','printshop','margin-bottom','20',0,''),(365896,116435,'118334','printshop','block_type','1',0,''),(365897,116435,'118334','printshop','padding-left','30',0,''),(365898,116435,'118334','printshop','border-left-width','20',0,''),(365899,116435,'118334','printshop','border-left-color','$content-border-3',0,''),(365900,116435,'118334','printshop','margin-left','-10',0,''),(365901,116435,'118334','printshop','padding-right','30',0,''),(365902,116435,'118334','printshop','padding-top','20',0,''),(365903,116435,'118334','printshop','padding-bottom','20',0,''),(365904,116435,'118334','printshop','border-left-width','0',0,'5342'),(365905,116436,'118335','printshop','margin-bottom','20',0,''),(365906,116438,'118337','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(365907,116439,'118338','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(365908,116439,'118338','printshop','clear','none',0,''),(365909,116440,'118339','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(365910,116440,'118339','printshop','clear','none',0,''),(365911,116441,'118340','printshop','block_type','1',0,''),(365912,116441,'118340','printshop','padding-right','30',0,''),(365913,116441,'118340','printshop','background-color','$content-bg-1',0,''),(365914,116441,'118340','printshop','padding-top','20',0,''),(365915,116441,'118340','printshop','padding-left','30',0,''),(365916,116441,'118340','printshop','padding-bottom','20',0,''),(365917,116441,'118340','printshop','padding-left','20',0,'5342'),(365918,116441,'118340','printshop','padding-right','20',0,'5342'),(365919,116443,'118342','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(365920,116444,'118343','printshop','block_type','1',0,''),(365921,116444,'118343','printshop','padding-top','20',0,''),(365922,116444,'118343','printshop','padding-left','20',0,''),(365923,116444,'118343','printshop','padding-right','20',0,''),(365924,116444,'118343','printshop','padding-bottom','20',0,''),(365925,116444,'118343','printshop','background-color','$content-bg-1',0,''),(365926,116444,'118343','printshop','style_class','order-summary',0,''),(365927,116445,'118344','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(365928,116449,'118348','printshop','block_type','1',0,''),(365929,116449,'118348','printshop','background-color','$content-bg-2',0,''),(365930,116449,'118348','printshop','padding-bottom','30',0,''),(365931,116450,'118349','printshop','block_type','4',0,''),(365932,116450,'118349','printshop','schema','4-2',0,'5342'),(365933,116451,'118350','printshop','block_type','1',0,''),(365934,116451,'118350','printshop','padding-right','40',0,''),(365935,116451,'118350','printshop','padding-right','0',0,'5342'),(365936,116451,'118350','printshop','padding-bottom','20',0,'5342'),(365937,116452,'118351','printshop','block_type','2',0,''),(365938,116452,'118351','printshop','margin-bottom','20',0,''),(365939,116452,'118351','printshop','schema','2-2',0,'5333'),(365940,116452,'118351','printshop','background-color','$content-bg-1',0,''),(365941,116453,'118352','printshop','block_type','1',0,''),(365942,116453,'118352','printshop','border-right-width','20',0,''),(365943,116453,'118352','printshop','border-right-color','$content-border-3',0,''),(365944,116453,'118352','printshop','margin-right','-10',0,''),(365945,116453,'118352','printshop','padding-right','30',0,''),(365946,116453,'118352','printshop','padding-top','20',0,''),(365947,116453,'118352','printshop','padding-left','30',0,''),(365948,116453,'118352','printshop','padding-bottom','20',0,''),(365949,116453,'118352','printshop','border-right-width','0',0,'5342'),(365950,116453,'118352','printshop','margin-right','0',0,'5342'),(365951,116453,'118352','printshop','margin-bottom','20',0,'5342'),(365952,116453,'118352','printshop','padding-left','20',0,'5342'),(365953,116453,'118352','printshop','padding-right','20',0,'5342'),(365954,116454,'118353','printshop','margin-bottom','20',0,''),(365955,116457,'118356','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(365956,116457,'118356','printshop','padding-top','20',0,''),(365957,116459,'118358','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(365958,116459,'118358','printshop','clear','none',0,''),(365959,116461,'118360','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(365960,116462,'118361','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(365961,116462,'118361','printshop','clear','none',0,''),(365962,116464,'118362','printshop','block_type','1',0,''),(365963,116464,'118362','printshop','padding-left','30',0,''),(365964,116464,'118362','printshop','border-left-width','20',0,''),(365965,116464,'118362','printshop','border-left-color','$content-border-3',0,''),(365966,116464,'118362','printshop','margin-left','-10',0,''),(365967,116464,'118362','printshop','padding-right','30',0,''),(365968,116464,'118362','printshop','padding-top','20',0,''),(365969,116464,'118362','printshop','padding-bottom','20',0,''),(365970,116464,'118362','printshop','border-left-width','0',0,'5342'),(365971,116465,'118363','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(365972,116466,'118364','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(365973,116466,'118364','printshop','clear','none',0,''),(365974,116467,'118365','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(365975,116467,'118365','printshop','clear','none',0,''),(365976,116468,'118366','printshop','margin-bottom','20',0,''),(365977,116469,'118367','printshop','orders_data','name',0,''),(365978,116470,'118368','printshop','block_type','1',0,''),(365979,116470,'118368','printshop','padding-right','30',0,''),(365980,116470,'118368','printshop','background-color','$content-bg-1',0,''),(365981,116470,'118368','printshop','padding-top','20',0,''),(365982,116470,'118368','printshop','padding-left','30',0,''),(365983,116470,'118368','printshop','padding-bottom','20',0,''),(365984,116470,'118368','printshop','padding-left','20',0,'5342'),(365985,116470,'118368','printshop','padding-right','20',0,'5342'),(365986,116471,'118369','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(365987,116473,'118371','printshop','block_type','1',0,''),(365988,116473,'118371','printshop','padding-top','20',0,''),(365989,116473,'118371','printshop','padding-left','20',0,''),(365990,116473,'118371','printshop','padding-right','20',0,''),(365991,116473,'118371','printshop','padding-bottom','20',0,''),(365992,116473,'118371','printshop','background-color','$content-bg-1',0,''),(365993,116473,'118371','printshop','style_class','order-summary',0,''),(365994,116476,'118374','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(365995,116478,'118440','printshop','block_type','1',0,''),(365996,116479,'118441','printshop','block_type','6',0,''),(365997,116479,'118441','printshop','schema','6-3',0,'5342'),(365998,116480,'118442','printshop','aria_name','account-menu',0,''),(365999,116481,'116126','printshop','block_type','1',0,''),(366000,116481,'116126','printshop','padding-right','30',0,''),(366001,116481,'116126','printshop','padding-bottom','30',0,''),(366002,116481,'116126','printshop','padding-top','0',0,'5342'),(366003,116481,'116126','printshop','padding-left','0',0,'5342'),(366004,116481,'116126','printshop','padding-right','0',0,'5342'),(366005,116481,'116126','printshop','padding-bottom','0',0,'5342'),(366061,116500,'118443','printshop','margin-bottom','20',0,''),(366062,116501,'118444','printshop','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(366063,116502,'118445','printshop','block_type','1',0,''),(366064,116502,'118445','printshop','padding-top','20',0,''),(366065,116502,'118445','printshop','padding-bottom','20',0,''),(366066,116504,'118447','printshop','padding-top','20',0,''),(366067,116504,'118447','printshop','padding-bottom','20',0,''),(382940,121477,'116005','deals','text','##TEXT_PAGE_NOT_FOUND##',0,''),(382941,121477,'116005','deals','text-align','center',0,''),(382942,121477,'116005','deals','padding-top','100',0,''),(382943,121477,'116005','deals','padding-bottom','100',0,''),(382944,121478,'116006','deals','block_type','1',0,''),(383063,121494,'116022','deals','block_type','1',0,''),(383182,121510,'116038','deals','block_type','1',0,''),(383301,121526,'116054','deals','block_type','1',0,''),(383420,121542,'116070','deals','block_type','1',0,''),(383539,121558,'116086','deals','block_type','1',0,''),(383658,121574,'116102','deals','block_type','1',0,''),(383659,121574,'116102','deals','style_class','account-index',0,''),(383898,121632,'116145','deals','block_type','1',0,''),(383899,121632,'116145','deals','style_class','account-edit-wrap',0,''),(383967,121656,'116150','deals','block_type','1',0,''),(383968,121656,'116150','deals','style_class','account-address-book',0,''),(384046,121681,'116156','deals','block_type','1',0,''),(384047,121681,'116156','deals','style_class','account-address-book-process',0,''),(384115,121705,'117906','deals','block_type','1',0,''),(384116,121705,'117906','deals','style_class','item-holder',0,''),(384117,121705,'117906','deals','padding-top','25',0,''),(384118,121705,'117906','deals','padding-bottom','25',0,''),(384119,121705,'117906','deals','text-align','left',0,''),(384120,121705,'117906','deals','border-top-width','1',0,''),(384121,121705,'117906','deals','border-top-color','$content-border-1',0,''),(384122,121706,'117907','deals','block_type','7',0,''),(384123,121706,'117907','deals','schema','7-2',0,'5639'),(384124,121707,'117908','deals','block_type','5',0,''),(384125,121707,'117908','deals','schema','5-2',0,'5639'),(384126,121708,'117909','deals','clear','none',0,''),(384127,121708,'117909','deals','padding-right','20',0,''),(384128,121709,'117910','deals','padding-right','20',0,''),(384129,121709,'117910','deals','max-width','300',0,'5639'),(384130,121709,'117910','deals','margin_left_measure','auto',0,'5639'),(384131,121709,'117910','deals','margin_right_measure','auto',0,'5639'),(384132,121710,'117914','deals','padding-right','20',0,''),(384133,121711,'117915','deals','description_characters','200',0,''),(384134,121711,'117915','deals','clear','none',0,''),(384135,121711,'117915','deals','padding-right','20',0,''),(384136,121712,'117916','deals','clear','none',0,''),(384137,121713,'117917','deals','margin-bottom','20',0,''),(384138,121715,'117918','deals','block_type','1',0,''),(384139,121715,'117918','deals','padding-left','40',0,''),(384140,121715,'117918','deals','style_class','right-aria',0,''),(384141,121715,'117918','deals','padding-left','0',0,'5639'),(384142,121716,'117911','deals','block_type','1',0,''),(384143,121716,'117911','deals','text-align','center',0,''),(384144,121717,'117912','deals','margin-top','4',0,''),(384145,121717,'117912','deals','margin-bottom','7',0,''),(384146,121718,'117913','deals','padding-top','6',0,''),(384147,121718,'117913','deals','padding-left','5',0,''),(384148,121719,'117919','deals','margin-bottom','15',0,''),(384149,121719,'117919','deals','text-align','right',0,''),(384150,121720,'117920','deals','margin-bottom','10',0,''),(384151,121720,'117920','deals','text-align','center',0,''),(384152,121721,'117924','deals','text-align','center',0,''),(384153,121721,'117924','deals','margin-bottom','10',0,''),(384154,121722,'120924','deals','block_type','1',0,''),(384155,121722,'120924','deals','style_class','item-nav',0,''),(384156,121726,'116176','deals','block_type','1',0,''),(384157,121726,'116176','deals','style_class','item-holder',0,''),(384158,121726,'116176','deals','padding-top','25',0,''),(384159,121726,'116176','deals','padding-left','25',0,''),(384160,121726,'116176','deals','padding-right','25',0,''),(384161,121726,'116176','deals','padding-bottom','25',0,''),(384162,121726,'116176','deals','text-align','left',0,''),(384163,121728,'116178','deals','margin-bottom','7',0,''),(384164,121729,'116179','deals','clear','both',0,''),(384165,121732,'116182','deals','block_type','1',0,''),(384166,121732,'116182','deals','style_class','item-holder',0,''),(384167,121732,'116182','deals','padding-top','25',0,''),(384168,121732,'116182','deals','padding-left','25',0,''),(384169,121732,'116182','deals','padding-right','25',0,''),(384170,121732,'116182','deals','padding-bottom','25',0,''),(384171,121732,'116182','deals','text-align','left',0,''),(384172,121733,'116183','deals','block_type','5',0,''),(384173,121736,'116186','deals','margin-bottom','7',0,''),(384174,121737,'116187','deals','clear','both',0,''),(384175,121738,'116188','deals','block_type','1',0,''),(384176,121739,'116189','deals','block_type','6',0,''),(384177,121739,'116189','deals','font-weight','400',0,''),(384178,121739,'116189','deals','schema','6-2',0,'5660'),(384179,121739,'116189','deals','schema','6-2',0,'5639'),(384180,121740,'116190','deals','font-weight','400',0,''),(384181,121740,'116190','deals','padding-right','40',0,''),(384182,121740,'116190','deals','padding-right','0',0,'5660'),(384183,121740,'116190','deals','padding-right','0',0,'5639'),(384184,121741,'116191','deals','block_type','5',0,''),(384185,121741,'116191','deals','padding-top','10',0,''),(384186,121741,'116191','deals','padding-bottom','10',0,''),(384187,121741,'116191','deals','schema','5-2',0,'5660'),(384188,121741,'116191','deals','border-top-color','$content-border-1',0,''),(384189,121741,'116191','deals','border-top-width','1',0,''),(384190,121743,'116193','deals','float','right',0,''),(384191,121745,'116195','deals','col_in_row','3',0,''),(384192,121745,'116195','deals','products_align','left',0,''),(384193,121745,'116195','deals','font-weight','400',0,''),(384194,121745,'116195','deals','show_qty_input','0',0,''),(384195,121745,'116195','deals','listing_type','productListing',0,''),(384196,121745,'116195','deals','listing_type_rows','no',0,''),(384197,121745,'116195','deals','show_buy_button_b2b','on',0,''),(384198,121745,'116195','deals','show_wishlist_button_b2b','1',0,''),(384199,121745,'116195','deals','show_compare_b2b','1',0,''),(384200,121745,'116195','deals','show_stock','0',0,''),(384201,121745,'116195','deals','show_description','0',0,''),(384202,121745,'116195','deals','show_model','0',0,''),(384203,121745,'116195','deals','show_properties','0',0,''),(384204,121745,'116195','deals','show_rating','0',0,''),(384205,121745,'116195','deals','show_rating_counts','0',0,''),(384206,121745,'116195','deals','show_price','0',0,''),(384207,121745,'116195','deals','show_buy_button','0',0,''),(384208,121745,'116195','deals','show_view_button','0',0,''),(384209,121745,'116195','deals','show_wishlist_button','0',0,''),(384210,121745,'116195','deals','show_compare','0',0,''),(384211,121745,'116195','deals','show_name_rows','0',0,''),(384212,121745,'116195','deals','show_image_rows','0',0,''),(384213,121745,'116195','deals','show_stock_rows','0',0,''),(384214,121745,'116195','deals','show_description_rows','0',0,''),(384215,121745,'116195','deals','show_model_rows','0',0,''),(384216,121745,'116195','deals','show_properties_rows','0',0,''),(384217,121745,'116195','deals','show_rating_rows','0',0,''),(384218,121745,'116195','deals','show_rating_counts_rows','0',0,''),(384219,121745,'116195','deals','show_price_rows','0',0,''),(384220,121745,'116195','deals','show_buy_button_rows','0',0,''),(384221,121745,'116195','deals','show_qty_input_rows','0',0,''),(384222,121745,'116195','deals','show_view_button_rows','0',0,''),(384223,121745,'116195','deals','show_wishlist_button_rows','0',0,''),(384224,121745,'116195','deals','show_compare_rows','0',0,''),(384225,121745,'116195','deals','show_name_b2b','0',0,''),(384226,121745,'116195','deals','show_image_b2b','0',0,''),(384227,121745,'116195','deals','show_stock_b2b','0',0,''),(384228,121745,'116195','deals','show_description_b2b','0',0,''),(384229,121745,'116195','deals','show_model_b2b','0',0,''),(384230,121745,'116195','deals','show_properties_b2b','0',0,''),(384231,121745,'116195','deals','show_rating_b2b','0',0,''),(384232,121745,'116195','deals','show_rating_counts_b2b','0',0,''),(384233,121745,'116195','deals','show_price_b2b','0',0,''),(384234,121745,'116195','deals','show_qty_input_b2b','0',0,''),(384235,121745,'116195','deals','show_view_button_b2b','0',0,''),(384236,121745,'116195','deals','show_attributes_b2b','0',0,''),(384237,121745,'116195','deals','items_on_page','9',0,''),(384238,121745,'116195','deals','col_in_row','2',0,'5639'),(384239,121745,'116195','deals','col_in_row','1',0,'5660'),(384240,121745,'116195','deals','product_names_teg','h2',0,''),(384241,121746,'116196','deals','listing_type','productListing',0,''),(384242,121747,'116197','deals','block_type','1',0,''),(384243,121747,'116197','deals','padding-top','10',0,''),(384244,121747,'116197','deals','padding-bottom','10',0,''),(384245,121747,'116197','deals','border-bottom-width','1',0,''),(384246,121747,'116197','deals','border-bottom-color','$content-border-1',0,''),(384247,121747,'116197','deals','margin-left','0',0,''),(384248,121747,'116197','deals','margin-right','0',0,''),(384249,121748,'116198','deals','float','right',0,''),(384250,121748,'116198','deals','display','none',0,'5660'),(384251,121749,'116199','deals','margin-right','20',0,''),(384252,121749,'116199','deals','float','right',0,''),(384253,121749,'116199','deals','clear','none',0,''),(384254,121749,'116199','deals','display','none',0,'5639'),(384255,121750,'116200','deals','float','left',0,''),(384256,121750,'116200','deals','clear','none',0,''),(384257,121750,'116200','deals','margin-left','20',0,''),(384258,121750,'116200','deals','display','none',0,'5660'),(384259,121751,'116201','deals','float','left',0,''),(384260,121751,'116201','deals','clear','none',0,''),(384261,121751,'116201','deals','sort_pos_3','1',0,''),(384262,121751,'116201','deals','sort_pos_4','2',0,''),(384263,121751,'116201','deals','sort_pos_10','3',0,''),(384264,121751,'116201','deals','sort_pos_9','4',0,''),(384265,121751,'116201','deals','sort_pos_11','5',0,''),(384266,121751,'116201','deals','sort_pos_12','6',0,''),(384267,121751,'116201','deals','sort_pos_14','7',0,''),(384268,121751,'116201','deals','sort_pos_13','8',0,''),(384269,121751,'116201','deals','sort_pos_8','9',0,''),(384270,121751,'116201','deals','sort_pos_7','10',0,''),(384271,121751,'116201','deals','sort_pos_2','11',0,''),(384272,121751,'116201','deals','sort_pos_1','12',0,''),(384273,121751,'116201','deals','sort_pos_6','13',0,''),(384274,121751,'116201','deals','sort_pos_5','14',0,''),(384275,121751,'116201','deals','sort_pos_0','15',0,''),(384276,121751,'116201','deals','sort_hide_10','1',0,''),(384277,121751,'116201','deals','sort_hide_9','1',0,''),(384278,121751,'116201','deals','hide_icons','1',0,''),(384279,121751,'116201','deals','sort_hide_16','1',0,''),(384280,121751,'116201','deals','sort_hide_15','1',0,''),(384281,121751,'116201','deals','sort_hide_3','0',0,''),(384282,121751,'116201','deals','sort_hide_4','0',0,''),(384283,121751,'116201','deals','sort_hide_11','1',0,''),(384284,121751,'116201','deals','sort_hide_12','1',0,''),(384285,121751,'116201','deals','sort_hide_14','1',0,''),(384286,121751,'116201','deals','sort_hide_13','1',0,''),(384287,121751,'116201','deals','sort_hide_8','0',0,''),(384288,121751,'116201','deals','sort_hide_7','0',0,''),(384289,121751,'116201','deals','sort_hide_2','1',0,''),(384290,121751,'116201','deals','sort_hide_1','1',0,''),(384291,121751,'116201','deals','sort_hide_6','1',0,''),(384292,121751,'116201','deals','sort_hide_5','1',0,''),(384293,121751,'116201','deals','sort_hide_0','1',0,''),(384294,121754,'1683114704.562135','deals','block_type','1',0,''),(384295,121754,'1683114704.562135','deals','font-weight','normal',0,''),(384296,121754,'1683114704.562135','deals','padding-top','20',0,''),(384297,121754,'1683114704.562135','deals','style_class','shopping-cart-index',0,''),(384298,121755,'1683114704.57226','deals','block_type','4',0,''),(384299,121755,'1683114704.57226','deals','schema','4-1',0,'5644'),(384300,121755,'1683114704.57226','deals','schema','4-2',0,'5639'),(384301,121756,'1683114704.58194','deals','block_type','1',0,''),(384302,121756,'1683114704.58194','deals','margin-bottom','25',0,''),(384303,121757,'1683114704.582420','deals','padding-top','20',0,''),(384304,121757,'1683114704.582420','deals','padding-bottom','20',0,''),(384305,121758,'1683114704.583230','deals','block_type','2',0,''),(384306,121758,'1683114704.583230','deals','padding-bottom','20',0,''),(384307,121758,'1683114704.583230','deals','padding-top','20',0,''),(384308,121758,'1683114704.583230','deals','border-bottom-color','$content-border-1',0,''),(384309,121758,'1683114704.583230','deals','border-bottom-width','1',0,''),(384310,121758,'1683114704.583230','deals','schema','2-2',0,'5639'),(384311,121759,'1683114704.585598','deals','float','left',0,''),(384312,121759,'1683114704.585598','deals','float','none',0,'5639'),(384313,121760,'1683114704.586389','deals','text-align','right',0,''),(384314,121760,'1683114704.586389','deals','clear','none',0,''),(384315,121760,'1683114704.586389','deals','float','right',0,''),(384316,121760,'1683114704.586389','deals','padding-top','22',0,''),(384317,121760,'1683114704.586389','deals','float','none',0,'5639'),(384318,121760,'1683114704.586389','deals','text-align','left',0,'5639'),(384319,121761,'1683114704.587718','deals','float','right',0,''),(384320,121761,'1683114704.587718','deals','padding-top','26',0,''),(384321,121761,'1683114704.587718','deals','float','none',0,'5639'),(384322,121761,'1683114704.587718','deals','text-align','left',0,'5639'),(384323,121762,'1683114704.58974','deals','text','<div>##TEXT_YOUR_SHOPPING_CART##</div>',0,''),(384324,121762,'1683114704.58974','deals','style_class','cartTitle',0,''),(384325,121762,'1683114704.58974','deals','padding-top','20',0,''),(384326,121762,'1683114704.58974','deals','margin-bottom','20',0,''),(384327,121762,'1683114704.58974','deals','font-size','24',0,'5639'),(384328,121762,'1683114704.58974','deals','font-size','32',0,''),(384329,121762,'1683114704.58974','deals','font-weight','400',0,''),(384330,121763,'1683114704.594755','deals','font-weight','normal',0,''),(384331,121763,'1683114704.594755','deals','hide_parents','2',0,''),(384332,121763,'1683114704.594755','deals','style_class','closeable-content',0,''),(384333,121763,'1683114704.594755','deals','margin-bottom','30',0,''),(384334,121764,'1683114704.595625','deals','listing_type','productListing',0,''),(384335,121764,'1683114704.595625','deals','col_in_row','4',0,''),(384336,121764,'1683114704.595625','deals','show_popup','1',0,''),(384337,121764,'1683114704.595625','deals','col_in_row','3',0,'5639'),(384338,121764,'1683114704.595625','deals','col_in_row','2',0,'5630'),(384339,121764,'1683114704.595625','deals','col_in_row','1',0,'5660'),(384340,121764,'1683114704.595625','deals','padding-top','20',0,''),(384341,121764,'1683114704.595625','deals','padding-left','25',0,''),(384342,121764,'1683114704.595625','deals','padding-right','25',0,''),(384343,121764,'1683114704.595625','deals','padding-bottom','20',0,''),(384344,121764,'1683114704.595625','deals','background-color','$content-bg-1',0,''),(384345,121764,'1683114704.595625','deals','margin-bottom','25',0,''),(384346,121765,'1683114704.601126','deals','block_type','1',0,''),(384347,121765,'1683114704.601126','deals','style_class','closeable-content',0,''),(384348,121766,'1683114704.602943','deals','block_type','2',0,''),(384349,121766,'1683114704.602943','deals','schema','2-2',0,'5630'),(384350,121768,'1683114704.605124','deals','padding-right','24',0,''),(384351,121768,'1683114704.605124','deals','padding-right','0',0,'5630'),(384352,121768,'1683114704.605124','deals','padding-bottom','20',0,'5630'),(384353,121769,'1683114704.606118','deals','style_class','order-summary',0,''),(384354,121769,'1683114704.606118','deals','block_type','1',0,''),(384355,121769,'1683114704.606118','deals','margin-left','25',0,''),(384356,121769,'1683114704.606118','deals','margin-left','0',0,'5639'),(384357,121769,'1683114704.606118','deals','margin-bottom','30',0,'5639'),(384358,121769,'1683114704.606118','deals','padding-bottom','10',0,''),(384359,121769,'1683114704.606118','deals','background-color','$content-bg-1',0,''),(384360,121770,'1683114704.608683','deals','block_type','1',0,''),(384361,121771,'1683114704.609838','deals','font-weight','400',0,''),(384362,121771,'1683114704.609838','deals','padding-right','0',0,'5630'),(384363,121772,'1683114704.623818','deals','font-weight','400',0,''),(384364,121772,'1683114704.623818','deals','box_align','4',0,''),(384365,121772,'1683114704.623818','deals','text-align','center',0,'5630'),(384366,121772,'1683114704.623818','deals','float','none',0,'5630'),(384367,121772,'1683114704.623818','deals','width','100',0,'5630'),(384368,121772,'1683114704.623818','deals','width_measure','%',0,'5630'),(384369,121773,'1683114704.62578','deals','style_class','bottom-totals',0,''),(384370,121774,'1683114704.626342','deals','style_class','top-totals',0,''),(384371,121775,'1683114704.62755','deals','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(384372,121776,'116242','deals','block_type','1',0,''),(384373,121776,'116242','deals','font-weight','normal',0,''),(384374,121776,'116242','deals','padding-top','20',0,''),(384375,121776,'116242','deals','background-color','$content-bg-2',0,''),(384376,121778,'116244','deals','block_type','4',0,''),(384377,121778,'116244','deals','schema','4-1',0,'5644'),(384378,121778,'116244','deals','schema','4-2',0,'5639'),(384379,121779,'116245','deals','block_type','1',0,''),(384380,121779,'116245','deals','background-color','$content-bg-1',0,''),(384381,121779,'116245','deals','padding-top','20',0,''),(384382,121779,'116245','deals','padding-bottom','20',0,''),(384383,121779,'116245','deals','padding-left','25',0,''),(384384,121779,'116245','deals','padding-right','25',0,''),(384385,121779,'116245','deals','margin-bottom','30',0,''),(384386,121780,'116246','deals','col_in_row','3',0,''),(384387,121780,'116246','deals','show_description','1',0,''),(384388,121780,'116246','deals','show_model','1',0,''),(384389,121780,'116246','deals','show_properties','1',0,''),(384390,121780,'116246','deals','show_rating','1',0,''),(384391,121780,'116246','deals','show_rating_counts','1',0,''),(384392,121780,'116246','deals','show_qty_input','1',0,''),(384393,121780,'116246','deals','show_view_button','1',0,''),(384394,121780,'116246','deals','show_wishlist_button','1',0,''),(384395,121780,'116246','deals','show_compare','1',0,''),(384396,121780,'116246','deals','view_as','carousel',0,''),(384397,121780,'116246','deals','hide_parents','2',0,''),(384398,121781,'116247','deals','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(384399,121781,'116247','deals','style_class','bell-ico',0,''),(384400,121782,'116248','deals','block_type','1',0,''),(384401,121782,'116248','deals','background-color','$content-bg-1',0,''),(384402,121782,'116248','deals','margin-bottom','30',0,''),(384403,121783,'116249','deals','padding-top','20',0,''),(384404,121783,'116249','deals','padding-left','25',0,''),(384405,121783,'116249','deals','padding-right','25',0,''),(384406,121783,'116249','deals','padding-bottom','20',0,''),(384407,121784,'116250','deals','block_type','2',0,''),(384408,121784,'116250','deals','padding-bottom','20',0,''),(384409,121784,'116250','deals','padding-top','20',0,''),(384410,121784,'116250','deals','padding-left','25',0,''),(384411,121784,'116250','deals','padding-right','25',0,''),(384412,121784,'116250','deals','border-bottom-color','$content-border-1',0,''),(384413,121784,'116250','deals','border-bottom-width','1',0,''),(384414,121784,'116250','deals','schema','2-2',0,'5639'),(384415,121785,'116251','deals','float','left',0,''),(384416,121786,'116252','deals','text-align','right',0,''),(384417,121786,'116252','deals','clear','none',0,''),(384418,121786,'116252','deals','float','right',0,''),(384419,121786,'116252','deals','padding-top','22',0,''),(384420,121787,'116253','deals','float','right',0,''),(384421,121787,'116253','deals','padding-top','26',0,''),(384422,121788,'116254','deals','block_type','1',0,''),(384423,121788,'116254','deals','padding-top','20',0,''),(384424,121788,'116254','deals','padding-bottom','20',0,''),(384425,121788,'116254','deals','padding-left','25',0,''),(384426,121788,'116254','deals','padding-right','25',0,''),(384427,121788,'116254','deals','background-color','$content-bg-1',0,''),(384428,121788,'116254','deals','margin-bottom','30',0,''),(384429,121789,'116255','deals','hide_parents','2',0,''),(384430,121790,'116256','deals','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(384431,121791,'116257','deals','block_type','1',0,''),(384432,121791,'116257','deals','background-color','$content-bg-1',0,''),(384433,121791,'116257','deals','padding-top','20',0,''),(384434,121791,'116257','deals','padding-bottom','20',0,''),(384435,121791,'116257','deals','padding-left','25',0,''),(384436,121791,'116257','deals','padding-right','25',0,''),(384437,121791,'116257','deals','margin-bottom','30',0,''),(384438,121791,'116257','deals','style_class','closeable-box',0,''),(384439,121792,'116258','deals','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(384440,121792,'116258','deals','style_class','savings-ico closeable-heading closeable-event',0,''),(384441,121793,'116259','deals','block_type','3',0,''),(384442,121793,'116259','deals','font-weight','400',0,''),(384443,121793,'116259','deals','schema','2-2',0,'5630'),(384444,121793,'116259','deals','style_class','closeable-content',0,''),(384445,121793,'116259','deals','padding-top','10',0,''),(384446,121794,'116260','deals','font-weight','400',0,''),(384447,121794,'116260','deals','padding-top','12',0,'5630'),(384448,121794,'116260','deals','padding-left','0',0,'5630'),(384449,121797,'116263','deals','block_type','1',0,''),(384450,121797,'116263','deals','background-color','$content-bg-1',0,''),(384451,121797,'116263','deals','padding-top','20',0,''),(384452,121797,'116263','deals','padding-left','25',0,''),(384453,121797,'116263','deals','padding-right','25',0,''),(384454,121797,'116263','deals','padding-bottom','20',0,''),(384455,121797,'116263','deals','margin-bottom','30',0,''),(384456,121797,'116263','deals','style_class','closeable-box',0,''),(384457,121797,'116263','deals','display','none',0,'5639'),(384458,121798,'116264','deals','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(384459,121798,'116264','deals','style_class','shipping-ico closeable-heading closeable-event',0,''),(384460,121799,'116265','deals','font-weight','normal',0,''),(384461,121799,'116265','deals','style_class','closeable-content',0,''),(384462,121799,'116265','deals','padding-top','10',0,''),(384463,121799,'116265','deals','hide_parents','2',0,''),(384464,121800,'116266','deals','style_class','order-summary',0,''),(384465,121800,'116266','deals','block_type','1',0,''),(384466,121800,'116266','deals','margin-left','30',0,''),(384467,121800,'116266','deals','margin-left','0',0,'5639'),(384468,121800,'116266','deals','margin-bottom','30',0,'5639'),(384469,121801,'116267','deals','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(384470,121802,'116268','deals','block_type','1',0,''),(384471,121802,'116268','deals','padding-left','20',0,''),(384472,121802,'116268','deals','padding-right','20',0,''),(384473,121802,'116268','deals','padding-bottom','20',0,''),(384474,121803,'116269','deals','font-weight','400',0,''),(384475,121803,'116269','deals','logo','themes/deals/img/payicons.png',1,''),(384476,121803,'116269','deals','padding-top','20',0,''),(384477,121803,'116269','deals','padding-bottom','10',0,''),(384478,121803,'116269','deals','logo','themes/deals/img/payicons.png',2,''),(384479,121803,'116269','deals','logo','themes/deals/img/payicons.png',3,''),(384480,121803,'116269','deals','logo','themes/deals/img/payicons.png',4,''),(384481,121804,'116270','deals','font-weight','400',0,''),(384482,121804,'116270','deals','box_align','4',0,''),(384483,121804,'116270','deals','text-align','center',0,'5630'),(384484,121804,'116270','deals','float','none',0,'5630'),(384485,121804,'116270','deals','width','100',0,'5630'),(384486,121804,'116270','deals','width_measure','%',0,'5630'),(384491,121816,'116272','deals','block_type','1',0,''),(384492,121817,'116275','deals','col_in_row','5',0,''),(384493,121817,'116275','deals','products_align','left',0,''),(384494,121817,'116275','deals','font-weight','400',0,''),(384495,121817,'116275','deals','listing_type','productListing',0,''),(384496,121817,'116275','deals','listing_type_rows','Rows',0,''),(384497,121817,'116275','deals','show_buy_button_b2b','on',0,''),(384498,121817,'116275','deals','show_wishlist_button_b2b','1',0,''),(384499,121817,'116275','deals','show_compare_b2b','1',0,''),(384500,121817,'116275','deals','show_price','0',0,''),(384501,121817,'116275','deals','show_view_button','0',0,''),(384502,121817,'116275','deals','show_name_rows','0',0,''),(384503,121817,'116275','deals','show_image_rows','0',0,''),(384504,121817,'116275','deals','show_stock_rows','0',0,''),(384505,121817,'116275','deals','show_description_rows','0',0,''),(384506,121817,'116275','deals','show_model_rows','0',0,''),(384507,121817,'116275','deals','show_properties_rows','0',0,''),(384508,121817,'116275','deals','show_rating_rows','0',0,''),(384509,121817,'116275','deals','show_rating_counts_rows','0',0,''),(384510,121817,'116275','deals','show_price_rows','0',0,''),(384511,121817,'116275','deals','show_buy_button_rows','0',0,''),(384512,121817,'116275','deals','show_qty_input_rows','0',0,''),(384513,121817,'116275','deals','show_view_button_rows','0',0,''),(384514,121817,'116275','deals','show_wishlist_button_rows','0',0,''),(384515,121817,'116275','deals','show_compare_rows','0',0,''),(384516,121817,'116275','deals','show_name_b2b','0',0,''),(384517,121817,'116275','deals','show_image_b2b','0',0,''),(384518,121817,'116275','deals','show_stock_b2b','0',0,''),(384519,121817,'116275','deals','show_description_b2b','0',0,''),(384520,121817,'116275','deals','show_model_b2b','0',0,''),(384521,121817,'116275','deals','show_properties_b2b','0',0,''),(384522,121817,'116275','deals','show_rating_b2b','0',0,''),(384523,121817,'116275','deals','show_rating_counts_b2b','0',0,''),(384524,121817,'116275','deals','show_price_b2b','0',0,''),(384525,121817,'116275','deals','show_qty_input_b2b','0',0,''),(384526,121817,'116275','deals','show_view_button_b2b','0',0,''),(384527,121817,'116275','deals','show_attributes_b2b','0',0,''),(384528,121817,'116275','deals','items_on_page','15',0,''),(384529,121817,'116275','deals','col_in_row','3',0,'5639'),(384530,121817,'116275','deals','col_in_row','1',0,'5660'),(384531,121817,'116275','deals','product_names_teg','h2',0,''),(384532,121817,'116275','deals','col_in_row','4',0,'5644'),(384533,121818,'116277','deals','block_type','5',0,''),(384534,121818,'116277','deals','padding-top','10',0,''),(384535,121818,'116277','deals','padding-bottom','10',0,''),(384536,121818,'116277','deals','schema','5-2',0,'5660'),(384537,121818,'116277','deals','border-top-color','$content-border-1',0,''),(384538,121818,'116277','deals','border-top-width','1',0,''),(384539,121820,'116279','deals','float','right',0,''),(384540,121822,'116282','deals','block_type','1',0,''),(384541,121822,'116282','deals','padding-top','10',0,''),(384542,121822,'116282','deals','padding-bottom','10',0,''),(384543,121822,'116282','deals','border-bottom-width','1',0,''),(384544,121822,'116282','deals','border-bottom-color','$content-border-1',0,''),(384545,121822,'116282','deals','margin-left','0',0,''),(384546,121822,'116282','deals','margin-right','0',0,''),(384547,121823,'116283','deals','float','right',0,''),(384548,121823,'116283','deals','display','none',0,'5660'),(384549,121825,'1641809968','deals','block_type','1',0,''),(384550,121825,'1641809968','deals','style_class','filterLine',0,''),(384551,121826,'116286','deals','float','left',0,''),(384552,121826,'116286','deals','clear','none',0,''),(384553,121826,'116286','deals','sort_pos_3','2',0,''),(384554,121826,'116286','deals','sort_pos_4','3',0,''),(384555,121826,'116286','deals','sort_pos_10','11',0,''),(384556,121826,'116286','deals','sort_pos_9','10',0,''),(384557,121826,'116286','deals','sort_pos_11','12',0,''),(384558,121826,'116286','deals','sort_pos_12','13',0,''),(384559,121826,'116286','deals','sort_pos_14','15',0,''),(384560,121826,'116286','deals','sort_pos_13','14',0,''),(384561,121826,'116286','deals','sort_pos_8','4',0,''),(384562,121826,'116286','deals','sort_pos_7','5',0,''),(384563,121826,'116286','deals','sort_pos_2','7',0,''),(384564,121826,'116286','deals','sort_pos_1','6',0,''),(384565,121826,'116286','deals','sort_pos_6','9',0,''),(384566,121826,'116286','deals','sort_pos_5','8',0,''),(384567,121826,'116286','deals','sort_pos_0','1',0,''),(384568,121826,'116286','deals','sort_hide_10','1',0,''),(384569,121826,'116286','deals','sort_hide_9','1',0,''),(384570,121826,'116286','deals','hide_icons','1',0,''),(384571,121826,'116286','deals','sort_hide_16','1',0,''),(384572,121826,'116286','deals','sort_hide_15','1',0,''),(384573,121826,'116286','deals','sort_hide_3','0',0,''),(384574,121826,'116286','deals','sort_hide_4','0',0,''),(384575,121826,'116286','deals','sort_hide_11','1',0,''),(384576,121826,'116286','deals','sort_hide_12','1',0,''),(384577,121826,'116286','deals','sort_hide_14','1',0,''),(384578,121826,'116286','deals','sort_hide_13','1',0,''),(384579,121826,'116286','deals','sort_hide_8','0',0,''),(384580,121826,'116286','deals','sort_hide_7','0',0,''),(384581,121826,'116286','deals','sort_hide_2','1',0,''),(384582,121826,'116286','deals','sort_hide_1','1',0,''),(384583,121826,'116286','deals','sort_hide_6','1',0,''),(384584,121826,'116286','deals','sort_hide_5','1',0,''),(384585,121826,'116286','deals','sort_hide_0','0',0,''),(384586,121826,'116286','deals','sort_pos_15','16',0,''),(384587,121826,'116286','deals','sort_pos_16','17',0,''),(384588,121827,'1641810239','deals','align_position','horizontal',0,''),(384589,121827,'1641810239','deals','open_filter','closed',0,''),(384590,121833,'116293','deals','block_type','1',0,''),(384591,121835,'116295','deals','block_type','6',0,''),(384592,121835,'116295','deals','font-weight','400',0,''),(384593,121835,'116295','deals','schema','6-2',0,'5660'),(384594,121835,'116295','deals','schema','6-2',0,'5639'),(384595,121836,'116296','deals','font-weight','400',0,''),(384596,121836,'116296','deals','padding-right','40',0,''),(384597,121836,'116296','deals','padding-right','0',0,'5660'),(384598,121836,'116296','deals','padding-right','0',0,'5639'),(384599,121838,'116298','deals','col_in_row','3',0,''),(384600,121838,'116298','deals','products_align','left',0,''),(384601,121838,'116298','deals','font-weight','400',0,''),(384602,121838,'116298','deals','show_qty_input','0',0,''),(384603,121838,'116298','deals','listing_type','productListing',0,''),(384604,121838,'116298','deals','listing_type_rows','no',0,''),(384605,121838,'116298','deals','show_buy_button_b2b','on',0,''),(384606,121838,'116298','deals','show_wishlist_button_b2b','1',0,''),(384607,121838,'116298','deals','show_compare_b2b','1',0,''),(384608,121838,'116298','deals','show_stock','0',0,''),(384609,121838,'116298','deals','show_description','0',0,''),(384610,121838,'116298','deals','show_model','0',0,''),(384611,121838,'116298','deals','show_properties','0',0,''),(384612,121838,'116298','deals','show_rating','0',0,''),(384613,121838,'116298','deals','show_rating_counts','0',0,''),(384614,121838,'116298','deals','show_price','0',0,''),(384615,121838,'116298','deals','show_buy_button','0',0,''),(384616,121838,'116298','deals','show_view_button','0',0,''),(384617,121838,'116298','deals','show_wishlist_button','0',0,''),(384618,121838,'116298','deals','show_compare','0',0,''),(384619,121838,'116298','deals','show_name_rows','0',0,''),(384620,121838,'116298','deals','show_image_rows','0',0,''),(384621,121838,'116298','deals','show_stock_rows','0',0,''),(384622,121838,'116298','deals','show_description_rows','0',0,''),(384623,121838,'116298','deals','show_model_rows','0',0,''),(384624,121838,'116298','deals','show_properties_rows','0',0,''),(384625,121838,'116298','deals','show_rating_rows','0',0,''),(384626,121838,'116298','deals','show_rating_counts_rows','0',0,''),(384627,121838,'116298','deals','show_price_rows','0',0,''),(384628,121838,'116298','deals','show_buy_button_rows','0',0,''),(384629,121838,'116298','deals','show_qty_input_rows','0',0,''),(384630,121838,'116298','deals','show_view_button_rows','0',0,''),(384631,121838,'116298','deals','show_wishlist_button_rows','0',0,''),(384632,121838,'116298','deals','show_compare_rows','0',0,''),(384633,121838,'116298','deals','show_name_b2b','0',0,''),(384634,121838,'116298','deals','show_image_b2b','0',0,''),(384635,121838,'116298','deals','show_stock_b2b','0',0,''),(384636,121838,'116298','deals','show_description_b2b','0',0,''),(384637,121838,'116298','deals','show_model_b2b','0',0,''),(384638,121838,'116298','deals','show_properties_b2b','0',0,''),(384639,121838,'116298','deals','show_rating_b2b','0',0,''),(384640,121838,'116298','deals','show_rating_counts_b2b','0',0,''),(384641,121838,'116298','deals','show_price_b2b','0',0,''),(384642,121838,'116298','deals','show_qty_input_b2b','0',0,''),(384643,121838,'116298','deals','show_view_button_b2b','0',0,''),(384644,121838,'116298','deals','show_attributes_b2b','0',0,''),(384645,121838,'116298','deals','items_on_page','9',0,''),(384646,121838,'116298','deals','col_in_row','2',0,'5639'),(384647,121838,'116298','deals','col_in_row','1',0,'5660'),(384648,121838,'116298','deals','product_names_teg','h2',0,''),(384649,121839,'116299','deals','block_type','1',0,''),(384650,121839,'116299','deals','padding-top','10',0,''),(384651,121839,'116299','deals','padding-bottom','10',0,''),(384652,121839,'116299','deals','border-bottom-width','1',0,''),(384653,121839,'116299','deals','border-bottom-color','$content-border-1',0,''),(384654,121839,'116299','deals','margin-left','0',0,''),(384655,121839,'116299','deals','margin-right','0',0,''),(384656,121840,'116300','deals','float','left',0,''),(384657,121840,'116300','deals','clear','none',0,''),(384658,121840,'116300','deals','sort_pos_3','1',0,''),(384659,121840,'116300','deals','sort_pos_4','2',0,''),(384660,121840,'116300','deals','sort_pos_10','3',0,''),(384661,121840,'116300','deals','sort_pos_9','4',0,''),(384662,121840,'116300','deals','sort_pos_11','5',0,''),(384663,121840,'116300','deals','sort_pos_12','6',0,''),(384664,121840,'116300','deals','sort_pos_14','7',0,''),(384665,121840,'116300','deals','sort_pos_13','8',0,''),(384666,121840,'116300','deals','sort_pos_8','9',0,''),(384667,121840,'116300','deals','sort_pos_7','10',0,''),(384668,121840,'116300','deals','sort_pos_2','11',0,''),(384669,121840,'116300','deals','sort_pos_1','12',0,''),(384670,121840,'116300','deals','sort_pos_6','13',0,''),(384671,121840,'116300','deals','sort_pos_5','14',0,''),(384672,121840,'116300','deals','sort_pos_0','15',0,''),(384673,121840,'116300','deals','sort_hide_10','1',0,''),(384674,121840,'116300','deals','sort_hide_9','1',0,''),(384675,121840,'116300','deals','hide_icons','1',0,''),(384676,121840,'116300','deals','sort_hide_16','1',0,''),(384677,121840,'116300','deals','sort_hide_15','1',0,''),(384678,121840,'116300','deals','sort_hide_3','0',0,''),(384679,121840,'116300','deals','sort_hide_4','0',0,''),(384680,121840,'116300','deals','sort_hide_11','1',0,''),(384681,121840,'116300','deals','sort_hide_12','1',0,''),(384682,121840,'116300','deals','sort_hide_14','1',0,''),(384683,121840,'116300','deals','sort_hide_13','1',0,''),(384684,121840,'116300','deals','sort_hide_8','0',0,''),(384685,121840,'116300','deals','sort_hide_7','0',0,''),(384686,121840,'116300','deals','sort_hide_2','1',0,''),(384687,121840,'116300','deals','sort_hide_1','1',0,''),(384688,121840,'116300','deals','sort_hide_6','1',0,''),(384689,121840,'116300','deals','sort_hide_5','1',0,''),(384690,121840,'116300','deals','sort_hide_0','1',0,''),(384691,121841,'116301','deals','float','left',0,''),(384692,121841,'116301','deals','clear','none',0,''),(384693,121841,'116301','deals','margin-left','20',0,''),(384694,121841,'116301','deals','display','none',0,'5660'),(384695,121842,'116302','deals','margin-right','20',0,''),(384696,121842,'116302','deals','float','right',0,''),(384697,121842,'116302','deals','clear','none',0,''),(384698,121842,'116302','deals','display','none',0,'5639'),(384699,121843,'116303','deals','float','right',0,''),(384700,121843,'116303','deals','display','none',0,'5660'),(384701,121844,'116304','deals','listing_type','productListing',0,''),(384702,121846,'116306','deals','block_type','5',0,''),(384703,121846,'116306','deals','padding-top','10',0,''),(384704,121846,'116306','deals','padding-bottom','10',0,''),(384705,121846,'116306','deals','schema','5-2',0,'5660'),(384706,121846,'116306','deals','border-top-color','$content-border-1',0,''),(384707,121846,'116306','deals','border-top-width','1',0,''),(384708,121848,'116308','deals','float','right',0,''),(384709,121849,'116309','deals','block_type','1',0,''),(384710,121852,'116312','deals','block_type','1',0,''),(384711,121852,'116312','deals','padding-top','10',0,''),(384712,121852,'116312','deals','padding-bottom','10',0,''),(384713,121852,'116312','deals','border-bottom-width','1',0,''),(384714,121852,'116312','deals','border-bottom-color','$content-border-1',0,''),(384715,121852,'116312','deals','margin-left','0',0,''),(384716,121852,'116312','deals','margin-right','0',0,''),(384717,121853,'116313','deals','float','left',0,''),(384718,121853,'116313','deals','clear','none',0,''),(384719,121853,'116313','deals','margin-left','20',0,''),(384720,121853,'116313','deals','display','none',0,'5660'),(384721,121853,'116313','deals','display_none','1',0,'5630'),(384722,121854,'116314','deals','float','left',0,''),(384723,121854,'116314','deals','clear','none',0,''),(384724,121854,'116314','deals','sort_pos_3','2',0,''),(384725,121854,'116314','deals','sort_pos_4','3',0,''),(384726,121854,'116314','deals','sort_pos_10','11',0,''),(384727,121854,'116314','deals','sort_pos_9','10',0,''),(384728,121854,'116314','deals','sort_pos_11','12',0,''),(384729,121854,'116314','deals','sort_pos_12','13',0,''),(384730,121854,'116314','deals','sort_pos_14','15',0,''),(384731,121854,'116314','deals','sort_pos_13','14',0,''),(384732,121854,'116314','deals','sort_pos_8','4',0,''),(384733,121854,'116314','deals','sort_pos_7','5',0,''),(384734,121854,'116314','deals','sort_pos_2','7',0,''),(384735,121854,'116314','deals','sort_pos_1','6',0,''),(384736,121854,'116314','deals','sort_pos_6','9',0,''),(384737,121854,'116314','deals','sort_pos_5','8',0,''),(384738,121854,'116314','deals','sort_pos_0','1',0,''),(384739,121854,'116314','deals','sort_hide_10','1',0,''),(384740,121854,'116314','deals','sort_hide_9','1',0,''),(384741,121854,'116314','deals','hide_icons','1',0,''),(384742,121854,'116314','deals','sort_hide_16','1',0,''),(384743,121854,'116314','deals','sort_hide_15','1',0,''),(384744,121854,'116314','deals','sort_hide_3','0',0,''),(384745,121854,'116314','deals','sort_hide_4','0',0,''),(384746,121854,'116314','deals','sort_hide_11','1',0,''),(384747,121854,'116314','deals','sort_hide_12','1',0,''),(384748,121854,'116314','deals','sort_hide_14','1',0,''),(384749,121854,'116314','deals','sort_hide_13','1',0,''),(384750,121854,'116314','deals','sort_hide_8','0',0,''),(384751,121854,'116314','deals','sort_hide_7','0',0,''),(384752,121854,'116314','deals','sort_hide_2','1',0,''),(384753,121854,'116314','deals','sort_hide_1','1',0,''),(384754,121854,'116314','deals','sort_hide_6','1',0,''),(384755,121854,'116314','deals','sort_hide_5','1',0,''),(384756,121854,'116314','deals','sort_hide_0','0',0,''),(384757,121854,'116314','deals','sort_pos_15','16',0,''),(384758,121854,'116314','deals','sort_pos_16','17',0,''),(384759,121855,'116315','deals','margin-right','20',0,''),(384760,121855,'116315','deals','float','right',0,''),(384761,121855,'116315','deals','clear','none',0,''),(384762,121855,'116315','deals','display','none',0,'5639'),(384763,121856,'116316','deals','float','right',0,''),(384764,121856,'116316','deals','display','none',0,'5660'),(384765,121857,'116318','deals','block_type','5',0,''),(384766,121857,'116318','deals','padding-top','10',0,''),(384767,121857,'116318','deals','padding-bottom','10',0,''),(384768,121857,'116318','deals','schema','5-2',0,'5660'),(384769,121857,'116318','deals','border-top-color','$content-border-1',0,''),(384770,121857,'116318','deals','border-top-width','1',0,''),(384771,121859,'116320','deals','float','right',0,''),(384772,121860,'116321','deals','col_in_row','4',0,''),(384773,121860,'116321','deals','products_align','left',0,''),(384774,121860,'116321','deals','font-weight','400',0,''),(384775,121860,'116321','deals','show_qty_input','0',0,''),(384776,121860,'116321','deals','listing_type','productListing',0,''),(384777,121860,'116321','deals','listing_type_rows','Rows',0,''),(384778,121860,'116321','deals','show_buy_button_b2b','on',0,''),(384779,121860,'116321','deals','show_wishlist_button_b2b','1',0,''),(384780,121860,'116321','deals','show_compare_b2b','1',0,''),(384781,121860,'116321','deals','listing_type_b2b','b2b',0,''),(384782,121860,'116321','deals','show_image','0',0,''),(384783,121860,'116321','deals','show_stock','0',0,''),(384784,121860,'116321','deals','show_description','0',0,''),(384785,121860,'116321','deals','show_model','0',0,''),(384786,121860,'116321','deals','show_properties','0',0,''),(384787,121860,'116321','deals','show_rating','0',0,''),(384788,121860,'116321','deals','show_rating_counts','0',0,''),(384789,121860,'116321','deals','show_price','0',0,''),(384790,121860,'116321','deals','show_buy_button','0',0,''),(384791,121860,'116321','deals','show_view_button','0',0,''),(384792,121860,'116321','deals','show_wishlist_button','0',0,''),(384793,121860,'116321','deals','show_compare','0',0,''),(384794,121860,'116321','deals','show_name_rows','0',0,''),(384795,121860,'116321','deals','show_image_rows','0',0,''),(384796,121860,'116321','deals','show_stock_rows','0',0,''),(384797,121860,'116321','deals','show_description_rows','0',0,''),(384798,121860,'116321','deals','show_model_rows','0',0,''),(384799,121860,'116321','deals','show_properties_rows','0',0,''),(384800,121860,'116321','deals','show_rating_rows','0',0,''),(384801,121860,'116321','deals','show_rating_counts_rows','0',0,''),(384802,121860,'116321','deals','show_price_rows','0',0,''),(384803,121860,'116321','deals','show_buy_button_rows','0',0,''),(384804,121860,'116321','deals','show_qty_input_rows','0',0,''),(384805,121860,'116321','deals','show_view_button_rows','0',0,''),(384806,121860,'116321','deals','show_wishlist_button_rows','0',0,''),(384807,121860,'116321','deals','show_compare_rows','0',0,''),(384808,121860,'116321','deals','show_name_b2b','0',0,''),(384809,121860,'116321','deals','show_image_b2b','0',0,''),(384810,121860,'116321','deals','show_stock_b2b','0',0,''),(384811,121860,'116321','deals','show_description_b2b','0',0,''),(384812,121860,'116321','deals','show_model_b2b','0',0,''),(384813,121860,'116321','deals','show_properties_b2b','0',0,''),(384814,121860,'116321','deals','show_rating_b2b','0',0,''),(384815,121860,'116321','deals','show_rating_counts_b2b','0',0,''),(384816,121860,'116321','deals','show_price_b2b','0',0,''),(384817,121860,'116321','deals','show_qty_input_b2b','0',0,''),(384818,121860,'116321','deals','show_view_button_b2b','0',0,''),(384819,121860,'116321','deals','show_attributes_b2b','0',0,''),(384820,121860,'116321','deals','items_on_page','12',0,''),(384821,121860,'116321','deals','col_in_row','2',0,'5639'),(384822,121860,'116321','deals','col_in_row','1',0,'5660'),(384823,121860,'116321','deals','product_names_teg','h2',0,''),(384824,121863,'1683116708.492798','deals','block_type','1',0,''),(384825,121863,'1683116708.492798','deals','padding-top','30',0,''),(384826,121863,'1683116708.492798','deals','padding-bottom','30',0,''),(384827,121863,'1683116708.492798','deals','style_class','checkout-index-wrap',0,''),(384828,121864,'1683116708.500294','deals','block_type','4',0,''),(384829,121864,'1683116708.500294','deals','schema','4-2',0,'5639'),(384830,121865,'1683116708.502483','deals','block_type','1',0,''),(384831,121865,'1683116708.502483','deals','padding-right','0',0,'5639'),(384832,121866,'1683116708.503841','deals','block_type','1',0,''),(384833,121866,'1683116708.503841','deals','background-color','$content-bg-1',0,''),(384834,121866,'1683116708.503841','deals','padding-top','30',0,''),(384835,121866,'1683116708.503841','deals','padding-left','30',0,''),(384836,121866,'1683116708.503841','deals','padding-right','30',0,''),(384837,121866,'1683116708.503841','deals','padding-bottom','30',0,''),(384838,121866,'1683116708.503841','deals','margin-bottom','20',0,''),(384839,121866,'1683116708.503841','deals','style_class','hiding-box closeable-box',0,''),(384840,121866,'1683116708.503841','deals','border-top-width','1',0,''),(384841,121866,'1683116708.503841','deals','border-left-width','1',0,''),(384842,121866,'1683116708.503841','deals','border-right-width','1',0,''),(384843,121866,'1683116708.503841','deals','border-bottom-width','1',0,''),(384844,121866,'1683116708.503841','deals','border-top-color','$content-border-1',0,''),(384845,121866,'1683116708.503841','deals','border-left-color','$content-border-1',0,''),(384846,121866,'1683116708.503841','deals','border-right-color','$content-border-1',0,''),(384847,121866,'1683116708.503841','deals','border-bottom-color','$content-border-1',0,''),(384848,121866,'1683116708.503841','deals','padding-top','15',0,'5639'),(384849,121866,'1683116708.503841','deals','padding-left','15',0,'5639'),(384850,121866,'1683116708.503841','deals','padding-right','15',0,'5639'),(384851,121866,'1683116708.503841','deals','padding-bottom','15',0,'5639'),(384852,121867,'1683116708.507547','deals','style_class','closeable-content',0,''),(384853,121867,'1683116708.507547','deals','padding-bottom','20',0,''),(384854,121868,'1683116708.50914','deals','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(384855,121868,'1683116708.50914','deals','style_class','closeable-heading closeable-event closed',0,''),(384856,121869,'1683116708.511660','deals','block_type','1',0,''),(384857,121869,'1683116708.511660','deals','padding-top','30',0,''),(384858,121869,'1683116708.511660','deals','padding-left','30',0,''),(384859,121869,'1683116708.511660','deals','padding-right','30',0,''),(384860,121869,'1683116708.511660','deals','padding-bottom','30',0,''),(384861,121869,'1683116708.511660','deals','margin-bottom','20',0,''),(384862,121869,'1683116708.511660','deals','background-color','$content-bg-1',0,''),(384863,121869,'1683116708.511660','deals','style_class','hiding-box closeable-box',0,''),(384864,121869,'1683116708.511660','deals','border-top-width','1',0,''),(384865,121869,'1683116708.511660','deals','border-left-width','1',0,''),(384866,121869,'1683116708.511660','deals','border-right-width','1',0,''),(384867,121869,'1683116708.511660','deals','border-bottom-width','1',0,''),(384868,121869,'1683116708.511660','deals','border-top-color','$content-border-1',0,''),(384869,121869,'1683116708.511660','deals','border-left-color','$content-border-1',0,''),(384870,121869,'1683116708.511660','deals','border-right-color','$content-border-1',0,''),(384871,121869,'1683116708.511660','deals','border-bottom-color','$content-border-1',0,''),(384872,121869,'1683116708.511660','deals','padding-top','15',0,'5639'),(384873,121869,'1683116708.511660','deals','padding-left','15',0,'5639'),(384874,121869,'1683116708.511660','deals','padding-right','15',0,'5639'),(384875,121869,'1683116708.511660','deals','padding-bottom','15',0,'5639'),(384876,121870,'1683116708.515882','deals','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(384877,121870,'1683116708.515882','deals','style_class','closeable-heading closeable-event closed',0,''),(384878,121871,'1683116708.517470','deals','block_type','2',0,''),(384879,121871,'1683116708.517470','deals','style_class','closeable-content',0,''),(384880,121871,'1683116708.517470','deals','schema','2-2',0,'5639'),(384881,121872,'1683116708.518949','deals','padding-right','20',0,''),(384882,121872,'1683116708.518949','deals','padding-bottom','20',0,''),(384883,121872,'1683116708.518949','deals','padding-right','0',0,'5639'),(384884,121873,'1683116708.519823','deals','padding-left','20',0,''),(384885,121873,'1683116708.519823','deals','padding-bottom','20',0,''),(384886,121873,'1683116708.519823','deals','padding-left','0',0,'5639'),(384887,121874,'1683116708.52078','deals','padding-left','20',0,''),(384888,121874,'1683116708.52078','deals','padding-bottom','20',0,''),(384889,121874,'1683116708.52078','deals','padding-left','0',0,'5639'),(384890,121875,'1683116708.521619','deals','background-color','$content-bg-1',0,''),(384891,121875,'1683116708.521619','deals','block_type','1',0,''),(384892,121875,'1683116708.521619','deals','padding-top','30',0,''),(384893,121875,'1683116708.521619','deals','padding-left','30',0,''),(384894,121875,'1683116708.521619','deals','padding-right','30',0,''),(384895,121875,'1683116708.521619','deals','padding-bottom','30',0,''),(384896,121875,'1683116708.521619','deals','margin-bottom','20',0,''),(384897,121875,'1683116708.521619','deals','style_class','hiding-box',0,''),(384898,121875,'1683116708.521619','deals','border-top-width','1',0,''),(384899,121875,'1683116708.521619','deals','border-left-width','1',0,''),(384900,121875,'1683116708.521619','deals','border-right-width','1',0,''),(384901,121875,'1683116708.521619','deals','border-bottom-width','1',0,''),(384902,121875,'1683116708.521619','deals','border-top-color','$content-border-1',0,''),(384903,121875,'1683116708.521619','deals','border-left-color','$content-border-1',0,''),(384904,121875,'1683116708.521619','deals','border-right-color','$content-border-1',0,''),(384905,121875,'1683116708.521619','deals','border-bottom-color','$content-border-1',0,''),(384906,121875,'1683116708.521619','deals','padding-top','15',0,'5639'),(384907,121875,'1683116708.521619','deals','padding-left','15',0,'5639'),(384908,121875,'1683116708.521619','deals','padding-right','15',0,'5639'),(384909,121875,'1683116708.521619','deals','padding-bottom','15',0,'5639'),(384910,121876,'1683116708.52521','deals','block_type','1',0,''),(384911,121876,'1683116708.52521','deals','content','\\_',0,'3'),(384912,121876,'1683116708.52521','deals','border-top-width','1',0,'3'),(384913,121876,'1683116708.52521','deals','border-top-color','$content-border-1',0,'3'),(384914,121876,'1683116708.52521','deals','display','block',0,'3'),(384915,121876,'1683116708.52521','deals','position','absolute',0,'3'),(384916,121876,'1683116708.52521','deals','top','19',0,'3'),(384917,121876,'1683116708.52521','deals','left','0',0,'3'),(384918,121876,'1683116708.52521','deals','right','0',0,'3'),(384919,121876,'1683116708.52521','deals','margin-top','-2',0,'3'),(384920,121876,'1683116708.52521','deals','position','relative',0,''),(384921,121877,'1683116708.527559','deals','box_align','2',0,''),(384922,121877,'1683116708.527559','deals','margin-bottom','10',0,''),(384923,121877,'1683116708.527559','deals','background-color','$content-bg-1',0,''),(384924,121877,'1683116708.527559','deals','position','relative',0,''),(384925,121878,'1683116708.528597','deals','background-color','$content-bg-2',0,''),(384926,121878,'1683116708.528597','deals','padding-top','10',0,''),(384927,121878,'1683116708.528597','deals','padding-left','10',0,''),(384928,121878,'1683116708.528597','deals','padding-right','10',0,''),(384929,121878,'1683116708.528597','deals','padding-bottom','10',0,''),(384930,121878,'1683116708.528597','deals','margin-top','10',0,''),(384931,121879,'1683116708.529860','deals','block_type','2',0,''),(384932,121879,'1683116708.529860','deals','schema','2-2',0,'5639'),(384933,121880,'1683116708.531118','deals','block_type','1',0,''),(384934,121880,'1683116708.531118','deals','padding-right','20',0,''),(384935,121880,'1683116708.531118','deals','padding-left','0',0,'5639'),(384936,121880,'1683116708.531118','deals','margin-bottom','20',0,'5639'),(384937,121880,'1683116708.531118','deals','padding-right','0',0,'5639'),(384938,121881,'1683116708.532686','deals','address_in','popup',0,''),(384939,121882,'1683116708.533279','deals','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(384940,121885,'1683116708.535390','deals','block_type','1',0,''),(384941,121885,'1683116708.535390','deals','padding-left','20',0,''),(384942,121885,'1683116708.535390','deals','padding-left','0',0,'5639'),(384943,121887,'1683116708.537397','deals','border-top-width','1',0,''),(384944,121887,'1683116708.537397','deals','border-top-color','$content-border-1',0,''),(384945,121887,'1683116708.537397','deals','padding-top','13',0,''),(384946,121887,'1683116708.537397','deals','padding-bottom','10',0,''),(384947,121888,'1683116708.538283','deals','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(384948,121889,'1683116708.539729','deals','show_day','next_day',0,''),(384949,121890,'1683116708.540444','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(384950,121891,'1683116708.541679','deals','block_type','1',0,''),(384951,121891,'1683116708.541679','deals','background-color','$content-bg-1',0,''),(384952,121891,'1683116708.541679','deals','padding-top','30',0,''),(384953,121891,'1683116708.541679','deals','padding-left','30',0,''),(384954,121891,'1683116708.541679','deals','padding-right','30',0,''),(384955,121891,'1683116708.541679','deals','padding-bottom','30',0,''),(384956,121891,'1683116708.541679','deals','margin-bottom','20',0,''),(384957,121891,'1683116708.541679','deals','style_class','hiding-box',0,''),(384958,121891,'1683116708.541679','deals','border-top-width','1',0,''),(384959,121891,'1683116708.541679','deals','border-left-width','1',0,''),(384960,121891,'1683116708.541679','deals','border-right-width','1',0,''),(384961,121891,'1683116708.541679','deals','border-bottom-width','1',0,''),(384962,121891,'1683116708.541679','deals','border-top-color','$content-border-1',0,''),(384963,121891,'1683116708.541679','deals','border-left-color','$content-border-1',0,''),(384964,121891,'1683116708.541679','deals','border-right-color','$content-border-1',0,''),(384965,121891,'1683116708.541679','deals','border-bottom-color','$content-border-1',0,''),(384966,121891,'1683116708.541679','deals','padding-top','15',0,'5639'),(384967,121891,'1683116708.541679','deals','padding-left','15',0,'5639'),(384968,121891,'1683116708.541679','deals','padding-right','15',0,'5639'),(384969,121891,'1683116708.541679','deals','padding-bottom','15',0,'5639'),(384970,121893,'1683116708.545373','deals','margin-bottom','20',0,''),(384971,121893,'1683116708.545373','deals','style_class','hiding-box',0,''),(384972,121893,'1683116708.545373','deals','padding-top','0',0,'5639'),(384973,121893,'1683116708.545373','deals','padding-left','0',0,'5639'),(384974,121893,'1683116708.545373','deals','padding-right','0',0,'5639'),(384975,121893,'1683116708.545373','deals','padding-bottom','0',0,'5639'),(384976,121893,'1683116708.545373','deals','border-top-width','0',0,'5639'),(384977,121893,'1683116708.545373','deals','border-left-width','0',0,'5639'),(384978,121893,'1683116708.545373','deals','border-right-width','0',0,'5639'),(384979,121893,'1683116708.545373','deals','border-bottom-width','0',0,'5639'),(384980,121894,'1683116708.547120','deals','padding-top','10',0,''),(384981,121894,'1683116708.547120','deals','padding-left','20',0,''),(384982,121894,'1683116708.547120','deals','padding-right','20',0,''),(384983,121894,'1683116708.547120','deals','margin-top','20',0,''),(384984,121894,'1683116708.547120','deals','background-color','$content-bg-2',0,''),(384985,121894,'1683116708.547120','deals','padding-bottom','8',0,''),(384986,121895,'1683116708.548247','deals','block_type','1',0,''),(384987,121895,'1683116708.548247','deals','padding-top','30',0,''),(384988,121895,'1683116708.548247','deals','padding-left','30',0,''),(384989,121895,'1683116708.548247','deals','padding-right','30',0,''),(384990,121895,'1683116708.548247','deals','padding-bottom','23',0,''),(384991,121895,'1683116708.548247','deals','margin-bottom','20',0,''),(384992,121895,'1683116708.548247','deals','background-color','$content-bg-1',0,''),(384993,121895,'1683116708.548247','deals','style_class','hiding-box',0,''),(384994,121895,'1683116708.548247','deals','border-top-width','1',0,''),(384995,121895,'1683116708.548247','deals','border-left-width','1',0,''),(384996,121895,'1683116708.548247','deals','border-right-width','1',0,''),(384997,121895,'1683116708.548247','deals','border-bottom-width','1',0,''),(384998,121895,'1683116708.548247','deals','border-top-color','$content-border-1',0,''),(384999,121895,'1683116708.548247','deals','border-left-color','$content-border-1',0,''),(385000,121895,'1683116708.548247','deals','border-right-color','$content-border-1',0,''),(385001,121895,'1683116708.548247','deals','border-bottom-color','$content-border-1',0,''),(385002,121895,'1683116708.548247','deals','padding-top','15',0,'5639'),(385003,121895,'1683116708.548247','deals','padding-left','15',0,'5639'),(385004,121895,'1683116708.548247','deals','padding-right','15',0,'5639'),(385005,121895,'1683116708.548247','deals','padding-bottom','8',0,'5639'),(385006,121896,'1683116708.551273','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(385007,121897,'1683116708.552428','deals','block_type','2',0,''),(385008,121897,'1683116708.552428','deals','schema','2-2',0,'5639'),(385009,121898,'1683116708.553758','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385010,121899,'1683116708.55521','deals','padding-right','20',0,''),(385011,121899,'1683116708.55521','deals','padding-right','0',0,'5639'),(385012,121899,'1683116708.55521','deals','padding-bottom','20',0,'5639'),(385013,121899,'1683116708.55521','deals','address_in','popup',0,''),(385014,121900,'1683116708.5566','deals','block_type','1',0,''),(385015,121900,'1683116708.5566','deals','padding-left','20',0,''),(385016,121900,'1683116708.5566','deals','padding-left','0',0,'5639'),(385017,121902,'1683116708.558367','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385018,121903,'1683116708.559513','deals','block_type','1',0,''),(385019,121903,'1683116708.559513','deals','padding-top','30',0,''),(385020,121903,'1683116708.559513','deals','padding-left','30',0,''),(385021,121903,'1683116708.559513','deals','padding-right','30',0,''),(385022,121903,'1683116708.559513','deals','padding-bottom','30',0,''),(385023,121903,'1683116708.559513','deals','margin-bottom','20',0,''),(385024,121903,'1683116708.559513','deals','border-top-width','1',0,''),(385025,121903,'1683116708.559513','deals','border-left-width','1',0,''),(385026,121903,'1683116708.559513','deals','border-right-width','1',0,''),(385027,121903,'1683116708.559513','deals','border-bottom-width','1',0,''),(385028,121903,'1683116708.559513','deals','border-top-color','$content-border-1',0,''),(385029,121903,'1683116708.559513','deals','border-left-color','$content-border-1',0,''),(385030,121903,'1683116708.559513','deals','border-right-color','$content-border-1',0,''),(385031,121903,'1683116708.559513','deals','border-bottom-color','$content-border-1',0,''),(385032,121903,'1683116708.559513','deals','style_class','hiding-box',0,''),(385033,121905,'1683116708.563392','deals','block_type','1',0,''),(385034,121905,'1683116708.563392','deals','background-color','$content-bg-1',0,''),(385035,121905,'1683116708.563392','deals','style_class','order-summary',0,''),(385036,121905,'1683116708.563392','deals','margin-left','25',0,''),(385037,121905,'1683116708.563392','deals','margin-left','0',0,'5639'),(385038,121905,'1683116708.563392','deals','margin-top','30',0,'5639'),(385039,121906,'1683116708.56533','deals','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(385040,121906,'1683116708.56533','deals','text-align','center',0,''),(385041,121906,'1683116708.56533','deals','font-size','14',0,''),(385042,121906,'1683116708.56533','deals','color','$fade-color-1',0,''),(385043,121906,'1683116708.56533','deals','padding-top','10',0,''),(385044,121907,'1683116708.56713','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(385045,121908,'1683116708.568362','deals','hide_page','1',0,''),(385046,121908,'1683116708.568362','deals','hide_continue_button','1',0,''),(385047,121909,'1683116708.568971','deals','margin-bottom','10',0,''),(385048,121912,'116368','deals','block_type','1',0,''),(385049,121913,'116369','deals','margin-top','20',0,''),(385050,121914,'116370','deals','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(385051,121915,'116371','deals','link','products',0,''),(385052,121915,'116371','deals','margin-top','-33',0,''),(385053,121915,'116371','deals','float','right',0,''),(385054,121916,'116372','deals','block_type','2',0,''),(385055,121916,'116372','deals','margin-bottom','20',0,''),(385056,121916,'116372','deals','schema','2-2',0,'5630'),(385057,121917,'116373','deals','block_type','1',0,''),(385058,121917,'116373','deals','padding-right','20',0,''),(385059,121917,'116373','deals','padding-right','0',0,'5630'),(385060,121918,'116374','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(385061,121918,'116374','deals','clear','none',0,''),(385062,121920,'116376','deals','padding-left','20',0,''),(385063,121920,'116376','deals','block_type','1',0,''),(385064,121920,'116376','deals','padding-left','0',0,'5630'),(385065,121922,'116378','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385066,121922,'116378','deals','clear','none',0,''),(385067,121923,'116379','deals','text-align','right',0,''),(385068,121923,'116379','deals','margin-bottom','20',0,''),(385069,121923,'116379','deals','margin-top','20',0,''),(385070,121924,'116380','deals','block_type','2',0,''),(385071,121924,'116380','deals','margin-bottom','20',0,''),(385072,121924,'116380','deals','schema','2-2',0,'5630'),(385073,121925,'116381','deals','block_type','1',0,''),(385074,121925,'116381','deals','padding-right','20',0,''),(385075,121925,'116381','deals','padding-right','0',0,'5630'),(385076,121927,'116383','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(385077,121927,'116383','deals','clear','none',0,''),(385078,121928,'116384','deals','block_type','1',0,''),(385079,121928,'116384','deals','padding-left','20',0,''),(385080,121928,'116384','deals','padding-left','0',0,'5630'),(385081,121929,'116385','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385082,121929,'116385','deals','clear','none',0,''),(385083,121931,'116387','deals','margin-bottom','20',0,''),(385084,121931,'116387','deals','text-align','right',0,''),(385085,121933,'116402','deals','block_type','1',0,''),(385086,121934,'116403','deals','text-align','right',0,''),(385087,121934,'116403','deals','margin-bottom','20',0,''),(385088,121935,'116404','deals','block_type','2',0,''),(385089,121935,'116404','deals','margin-bottom','20',0,''),(385090,121935,'116404','deals','schema','2-2',0,'5630'),(385091,121936,'116405','deals','block_type','1',0,''),(385092,121936,'116405','deals','padding-right','20',0,''),(385093,121936,'116405','deals','padding-right','0',0,'5630'),(385094,121937,'116406','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385095,121937,'116406','deals','clear','none',0,''),(385096,121939,'116408','deals','block_type','1',0,''),(385097,121939,'116408','deals','padding-left','20',0,''),(385098,121939,'116408','deals','padding-left','0',0,'5630'),(385099,121940,'116409','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385100,121940,'116409','deals','clear','none',0,''),(385101,121942,'116411','deals','margin-bottom','20',0,''),(385102,121942,'116411','deals','text-align','right',0,''),(385103,121945,'116414','deals','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(385104,121946,'116389','deals','block_type','1',0,''),(385105,121947,'116390','deals','margin-bottom','20',0,''),(385106,121948,'116391','deals','margin-bottom','20',0,''),(385107,121948,'116391','deals','text-align','right',0,''),(385108,121949,'116392','deals','text-align','right',0,''),(385109,121949,'116392','deals','margin-bottom','20',0,''),(385110,121950,'116393','deals','block_type','2',0,''),(385111,121950,'116393','deals','margin-bottom','20',0,''),(385112,121950,'116393','deals','schema','2-2',0,'5630'),(385113,121951,'116394','deals','block_type','1',0,''),(385114,121951,'116394','deals','padding-right','20',0,''),(385115,121951,'116394','deals','padding-right','0',0,'5630'),(385116,121953,'116396','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385117,121953,'116396','deals','clear','none',0,''),(385118,121954,'116397','deals','block_type','1',0,''),(385119,121954,'116397','deals','padding-left','20',0,''),(385120,121954,'116397','deals','padding-left','0',0,'5630'),(385121,121956,'116399','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385122,121956,'116399','deals','clear','none',0,''),(385123,121957,'116400','deals','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(385124,121958,'116401','deals','margin-bottom','20',0,''),(385125,121959,'116415','deals','block_type','1',0,''),(385126,121960,'116416','deals','block_type','2',0,''),(385127,121960,'116416','deals','margin-bottom','20',0,''),(385128,121960,'116416','deals','schema','2-2',0,'5630'),(385129,121961,'116417','deals','block_type','1',0,''),(385130,121961,'116417','deals','padding-right','20',0,''),(385131,121961,'116417','deals','padding-right','0',0,'5630'),(385132,121963,'116419','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(385133,121963,'116419','deals','clear','none',0,''),(385134,121964,'116420','deals','block_type','1',0,''),(385135,121964,'116420','deals','padding-left','20',0,''),(385136,121964,'116420','deals','padding-left','0',0,'5630'),(385137,121966,'116422','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385138,121966,'116422','deals','clear','none',0,''),(385139,121967,'116423','deals','margin-bottom','20',0,''),(385140,121968,'116424','deals','margin-bottom','20',0,''),(385141,121969,'116425','deals','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(385142,121970,'116426','deals','link','products',0,''),(385143,121970,'116426','deals','margin-top','-33',0,''),(385144,121970,'116426','deals','float','right',0,''),(385145,121971,'116427','deals','text-align','right',0,''),(385146,121971,'116427','deals','margin-bottom','20',0,''),(385147,121972,'116428','deals','margin-bottom','20',0,''),(385148,121972,'116428','deals','text-align','right',0,''),(385149,121973,'116429','deals','block_type','2',0,''),(385150,121973,'116429','deals','margin-bottom','20',0,''),(385151,121973,'116429','deals','schema','2-2',0,'5630'),(385152,121974,'116430','deals','block_type','1',0,''),(385153,121974,'116430','deals','padding-right','20',0,''),(385154,121974,'116430','deals','padding-right','0',0,'5630'),(385155,121975,'116431','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(385156,121975,'116431','deals','clear','none',0,''),(385157,121977,'116433','deals','padding-left','20',0,''),(385158,121977,'116433','deals','block_type','1',0,''),(385159,121977,'116433','deals','padding-left','0',0,'5630'),(385160,121978,'116434','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385161,121978,'116434','deals','clear','none',0,''),(385162,121980,'116436','deals','text','##TEXT_CONFIRMATION##',0,''),(385163,121981,'116437','deals','text','##TEXT_CONFIRMATION##',0,''),(385164,121982,'116439','deals','text','##TEXT_CONFIRMATION##',0,''),(385165,121983,'116438','deals','text','##TEXT_CONFIRMATION##',0,''),(385166,121984,'116440','deals','text','##TEXT_CONFIRMATION##',0,''),(385167,121985,'116441','deals','text','##TEXT_CONFIRMATION##',0,''),(385168,121986,'116442','deals','block_type','2',0,''),(385169,121986,'116442','deals','schema','2-2',0,'5630'),(385170,121987,'116443','deals','block_type','1',0,''),(385171,121987,'116443','deals','padding-right','20',0,''),(385172,121988,'116444','deals','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(385173,121990,'116446','deals','block_type','1',0,''),(385174,121990,'116446','deals','padding-left','20',0,''),(385175,121990,'116446','deals','padding-left','0',0,'5639'),(385176,121991,'116447','deals','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(385177,121993,'116449','deals','block_type','4',0,''),(385178,121993,'116449','deals','schema','4-2',0,'5660'),(385179,121993,'116449','deals','padding-top','20',0,''),(385180,121994,'116450','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385181,121994,'116450','deals','text-align','right',0,''),(385182,121994,'116450','deals','padding-top','10',0,''),(385183,121994,'116450','deals','font_size_measure','em',0,''),(385184,121994,'116450','deals','font-size','1.2',0,''),(385185,121994,'116450','deals','text-align','center',0,'5630'),(385186,121995,'116451','deals','text-align','right',0,''),(385187,121995,'116451','deals','text-align','center',0,'5630'),(385188,121996,'116452','deals','block_type','2',0,''),(385189,121996,'116452','deals','schema','2-2',0,'5630'),(385190,121997,'116453','deals','block_type','1',0,''),(385191,121997,'116453','deals','padding-right','20',0,''),(385192,121997,'116453','deals','padding-right','0',0,'5639'),(385193,121999,'116456','deals','block_type','1',0,''),(385194,121999,'116456','deals','padding-right','0',0,'5639'),(385195,121999,'116456','deals','padding-left','20',0,''),(385196,121999,'116456','deals','padding-left','0',0,'5630'),(385197,122002,'116459','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(385198,122004,'116461','deals','block_type','2',0,''),(385199,122005,'116462','deals','block_type','1',0,''),(385200,122005,'116462','deals','padding-right','20',0,''),(385201,122007,'116464','deals','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(385202,122008,'116465','deals','block_type','1',0,''),(385203,122008,'116465','deals','padding-left','20',0,''),(385204,122008,'116465','deals','padding-left','0',0,'5639'),(385205,122009,'116466','deals','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(385206,122011,'116468','deals','block_type','4',0,''),(385207,122011,'116468','deals','schema','4-2',0,'5660'),(385208,122012,'116469','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385209,122012,'116469','deals','text-align','right',0,''),(385210,122012,'116469','deals','padding-top','10',0,''),(385211,122012,'116469','deals','font_size_measure','em',0,''),(385212,122012,'116469','deals','font-size','1.2',0,''),(385213,122013,'116470','deals','text-align','right',0,''),(385214,122014,'116471','deals','block_type','2',0,''),(385215,122015,'116472','deals','block_type','1',0,''),(385216,122015,'116472','deals','padding-right','20',0,''),(385217,122015,'116472','deals','padding-right','0',0,'5639'),(385218,122017,'116474','deals','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(385219,122018,'116475','deals','block_type','1',0,''),(385220,122018,'116475','deals','padding-right','0',0,'5639'),(385221,122018,'116475','deals','padding-left','20',0,''),(385222,122020,'116477','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(385223,122023,'116480','deals','block_type','4',0,''),(385224,122023,'116480','deals','schema','4-2',0,'5660'),(385225,122024,'116481','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385226,122024,'116481','deals','text-align','right',0,''),(385227,122024,'116481','deals','padding-top','10',0,''),(385228,122024,'116481','deals','font_size_measure','em',0,''),(385229,122024,'116481','deals','font-size','1.2',0,''),(385230,122025,'116482','deals','text-align','right',0,''),(385231,122026,'116483','deals','block_type','2',0,''),(385232,122027,'116484','deals','block_type','1',0,''),(385233,122027,'116484','deals','padding-right','20',0,''),(385234,122029,'116486','deals','block_type','1',0,''),(385235,122029,'116486','deals','padding-left','20',0,''),(385236,122029,'116486','deals','padding-left','0',0,'5639'),(385237,122030,'116487','deals','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(385238,122032,'116489','deals','block_type','4',0,''),(385239,122032,'116489','deals','schema','4-2',0,'5660'),(385240,122033,'116490','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385241,122033,'116490','deals','text-align','right',0,''),(385242,122033,'116490','deals','padding-top','10',0,''),(385243,122033,'116490','deals','font_size_measure','em',0,''),(385244,122033,'116490','deals','font-size','1.2',0,''),(385245,122034,'116491','deals','text-align','right',0,''),(385246,122035,'116492','deals','block_type','2',0,''),(385247,122036,'116493','deals','block_type','1',0,''),(385248,122036,'116493','deals','padding-right','20',0,''),(385249,122038,'116495','deals','block_type','1',0,''),(385250,122038,'116495','deals','padding-left','20',0,''),(385251,122038,'116495','deals','padding-left','0',0,'5639'),(385252,122040,'116497','deals','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(385253,122041,'116498','deals','text','##DELIVERY_DETAILS##',0,''),(385254,122042,'116499','deals','text','##DELIVERY_DETAILS##',0,''),(385255,122043,'116501','deals','text','##CONTACT_INFORMATION##',0,''),(385256,122044,'116500','deals','text','##CONTACT_INFORMATION##',0,''),(385257,122045,'116502','deals','text','##DELIVERY_DETAILS##',0,''),(385258,122046,'116503','deals','text','##DELIVERY_DETAILS##',0,''),(385259,122047,'116504','deals','block_type','1',0,''),(385260,122047,'116504','deals','background-color','$content-bg-2',0,''),(385261,122047,'116504','deals','padding-top','30',0,''),(385262,122047,'116504','deals','padding-bottom','30',0,''),(385263,122048,'116505','deals','block_type','7',0,''),(385264,122048,'116505','deals','schema','4-2',0,'5639'),(385265,122049,'116506','deals','block_type','1',0,''),(385266,122049,'116506','deals','padding-right','0',0,'5639'),(385267,122050,'116508','deals','block_type','1',0,''),(385268,122050,'116508','deals','background-color','$content-bg-1',0,''),(385269,122050,'116508','deals','padding-top','30',0,''),(385270,122050,'116508','deals','padding-left','30',0,''),(385271,122050,'116508','deals','padding-right','30',0,''),(385272,122050,'116508','deals','padding-bottom','30',0,''),(385273,122050,'116508','deals','margin-bottom','20',0,''),(385274,122050,'116508','deals','style_class','hiding-box',0,''),(385275,122051,'116509','deals','margin-bottom','20',0,''),(385276,122052,'116510','deals','padding-top','10',0,''),(385277,122052,'116510','deals','padding-left','20',0,''),(385278,122052,'116510','deals','padding-right','20',0,''),(385279,122052,'116510','deals','margin-top','20',0,''),(385280,122052,'116510','deals','background-color','$content-bg-2',0,''),(385281,122052,'116510','deals','padding-bottom','8',0,''),(385282,122053,'116511','deals','block_type','1',0,''),(385283,122053,'116511','deals','background-color','$content-bg-1',0,''),(385284,122053,'116511','deals','padding-top','30',0,''),(385285,122053,'116511','deals','padding-left','30',0,''),(385286,122053,'116511','deals','padding-right','30',0,''),(385287,122053,'116511','deals','padding-bottom','14',0,''),(385288,122053,'116511','deals','margin-bottom','20',0,''),(385289,122053,'116511','deals','style_class','hiding-box closeable-box',0,''),(385290,122054,'116512','deals','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(385291,122054,'116512','deals','style_class','closeable-heading closeable-event closed',0,''),(385292,122055,'116513','deals','style_class','closeable-content',0,''),(385293,122055,'116513','deals','padding-bottom','20',0,''),(385294,122056,'116514','deals','background-color','$content-bg-1',0,''),(385295,122056,'116514','deals','block_type','1',0,''),(385296,122056,'116514','deals','padding-top','30',0,''),(385297,122056,'116514','deals','padding-left','30',0,''),(385298,122056,'116514','deals','padding-right','30',0,''),(385299,122056,'116514','deals','padding-bottom','30',0,''),(385300,122056,'116514','deals','margin-bottom','20',0,''),(385301,122056,'116514','deals','style_class','hiding-box',0,''),(385302,122057,'116515','deals','block_type','1',0,''),(385303,122057,'116515','deals','content','\\_',0,'3'),(385304,122057,'116515','deals','border-top-width','1',0,'3'),(385305,122057,'116515','deals','border-top-color','$content-border-1',0,'3'),(385306,122057,'116515','deals','display','block',0,'3'),(385307,122057,'116515','deals','position','absolute',0,'3'),(385308,122057,'116515','deals','top','19',0,'3'),(385309,122057,'116515','deals','left','0',0,'3'),(385310,122057,'116515','deals','right','0',0,'3'),(385311,122057,'116515','deals','margin-top','-2',0,'3'),(385312,122057,'116515','deals','position','relative',0,''),(385313,122058,'116516','deals','box_align','2',0,''),(385314,122058,'116516','deals','margin-bottom','10',0,''),(385315,122058,'116516','deals','background-color','$content-bg-1',0,''),(385316,122058,'116516','deals','position','relative',0,''),(385317,122059,'116517','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(385318,122060,'116518','deals','block_type','2',0,''),(385319,122060,'116518','deals','schema','2-2',0,'5639'),(385320,122061,'116519','deals','block_type','1',0,''),(385321,122061,'116519','deals','padding-right','20',0,''),(385322,122061,'116519','deals','padding-left','0',0,'5639'),(385323,122061,'116519','deals','margin-bottom','20',0,'5639'),(385324,122061,'116519','deals','padding-right','0',0,'5639'),(385325,122064,'116522','deals','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(385326,122065,'116523','deals','block_type','1',0,''),(385327,122065,'116523','deals','padding-left','20',0,''),(385328,122065,'116523','deals','padding-left','0',0,'5639'),(385329,122066,'116524','deals','padding-bottom','10',0,''),(385330,122067,'116525','deals','background-color','$content-bg-2',0,''),(385331,122067,'116525','deals','padding-top','10',0,''),(385332,122067,'116525','deals','padding-left','10',0,''),(385333,122067,'116525','deals','padding-right','10',0,''),(385334,122067,'116525','deals','padding-bottom','10',0,''),(385335,122067,'116525','deals','margin-top','10',0,''),(385336,122068,'116526','deals','block_type','1',0,''),(385337,122068,'116526','deals','padding-top','10',0,''),(385338,122068,'116526','deals','padding-left','10',0,''),(385339,122068,'116526','deals','padding-right','10',0,''),(385340,122068,'116526','deals','padding-bottom','10',0,''),(385341,122068,'116526','deals','background-color','$content-bg-1',0,''),(385342,122068,'116526','deals','style_class','order-summary',0,''),(385343,122068,'116526','deals','margin-left','25',0,''),(385344,122068,'116526','deals','margin-left','0',0,'5639'),(385345,122069,'116527','deals','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(385346,122069,'116527','deals','text-align','center',0,''),(385347,122069,'116527','deals','font-size','14',0,''),(385348,122069,'116527','deals','color','$fade-color-1',0,''),(385349,122069,'116527','deals','padding-top','10',0,''),(385350,122072,'1638957135','deals','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(385351,122073,'116529','deals','block_type','1',0,''),(385352,122073,'116529','deals','background-color','$content-bg-2',0,''),(385353,122073,'116529','deals','padding-top','30',0,''),(385354,122073,'116529','deals','padding-bottom','30',0,''),(385355,122074,'116530','deals','block_type','7',0,''),(385356,122075,'116531','deals','block_type','1',0,''),(385357,122076,'116532','deals','block_type','1',0,''),(385358,122076,'116532','deals','background-color','$content-bg-1',0,''),(385359,122076,'116532','deals','padding-top','30',0,''),(385360,122076,'116532','deals','padding-left','30',0,''),(385361,122076,'116532','deals','padding-right','30',0,''),(385362,122076,'116532','deals','padding-bottom','30',0,''),(385363,122076,'116532','deals','margin-bottom','20',0,''),(385364,122076,'116532','deals','style_class','hiding-box',0,''),(385365,122077,'116533','deals','padding-top','10',0,''),(385366,122077,'116533','deals','padding-left','20',0,''),(385367,122077,'116533','deals','padding-right','20',0,''),(385368,122077,'116533','deals','margin-top','20',0,''),(385369,122077,'116533','deals','background-color','$content-bg-2',0,''),(385370,122077,'116533','deals','padding-bottom','8',0,''),(385371,122078,'116534','deals','margin-bottom','20',0,''),(385372,122079,'116535','deals','block_type','1',0,''),(385373,122079,'116535','deals','padding-top','30',0,''),(385374,122079,'116535','deals','padding-left','30',0,''),(385375,122079,'116535','deals','padding-right','30',0,''),(385376,122079,'116535','deals','padding-bottom','23',0,''),(385377,122079,'116535','deals','margin-bottom','20',0,''),(385378,122079,'116535','deals','background-color','$content-bg-1',0,''),(385379,122079,'116535','deals','style_class','hiding-box',0,''),(385380,122080,'116536','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(385381,122081,'116537','deals','block_type','2',0,''),(385382,122082,'116538','deals','padding-right','20',0,''),(385383,122083,'116539','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385384,122084,'116540','deals','block_type','1',0,''),(385385,122084,'116540','deals','padding-left','20',0,''),(385386,122085,'116541','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385387,122087,'116543','deals','block_type','1',0,''),(385388,122087,'116543','deals','padding-top','30',0,''),(385389,122087,'116543','deals','padding-left','30',0,''),(385390,122087,'116543','deals','padding-right','30',0,''),(385391,122087,'116543','deals','padding-bottom','14',0,''),(385392,122087,'116543','deals','margin-bottom','20',0,''),(385393,122087,'116543','deals','background-color','$content-bg-1',0,''),(385394,122087,'116543','deals','style_class','hiding-box closeable-box',0,''),(385395,122088,'116544','deals','block_type','2',0,''),(385396,122088,'116544','deals','style_class','closeable-content',0,''),(385397,122089,'116545','deals','padding-right','20',0,''),(385398,122089,'116545','deals','padding-bottom','20',0,''),(385399,122090,'116546','deals','padding-left','20',0,''),(385400,122090,'116546','deals','padding-bottom','20',0,''),(385401,122091,'116547','deals','padding-left','20',0,''),(385402,122091,'116547','deals','padding-bottom','20',0,''),(385403,122092,'116548','deals','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(385404,122092,'116548','deals','style_class','closeable-heading closeable-event closed',0,''),(385405,122093,'116549','deals','block_type','1',0,''),(385406,122093,'116549','deals','background-color','$content-bg-1',0,''),(385407,122093,'116549','deals','padding-top','30',0,''),(385408,122093,'116549','deals','padding-left','30',0,''),(385409,122093,'116549','deals','padding-right','30',0,''),(385410,122093,'116549','deals','padding-bottom','14',0,''),(385411,122093,'116549','deals','margin-bottom','20',0,''),(385412,122093,'116549','deals','style_class','hiding-box closeable-box',0,''),(385413,122094,'116550','deals','style_class','closeable-content',0,''),(385414,122094,'116550','deals','padding-bottom','20',0,''),(385415,122095,'116551','deals','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(385416,122095,'116551','deals','style_class','closeable-heading closeable-event closed',0,''),(385417,122096,'116552','deals','block_type','1',0,''),(385418,122096,'116552','deals','padding-top','10',0,''),(385419,122096,'116552','deals','padding-left','10',0,''),(385420,122096,'116552','deals','padding-right','10',0,''),(385421,122096,'116552','deals','padding-bottom','10',0,''),(385422,122096,'116552','deals','background-color','$content-bg-1',0,''),(385423,122096,'116552','deals','style_class','order-summary hiding-box',0,''),(385424,122096,'116552','deals','margin-left','25',0,''),(385425,122097,'116553','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(385426,122098,'116554','deals','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(385427,122098,'116554','deals','text-align','center',0,''),(385428,122098,'116554','deals','font-size','14',0,''),(385429,122098,'116554','deals','color','$fade-color-1',0,''),(385430,122098,'116554','deals','padding-top','10',0,''),(385431,122099,'116555','deals','margin-bottom','10',0,''),(385432,122101,'116557','deals','hide_page','1',0,''),(385433,122101,'116557','deals','hide_continue_button','1',0,''),(385434,122102,'116558','deals','block_type','1',0,''),(385435,122104,'116560','deals','block_type','4',0,''),(385436,122104,'116560','deals','schema','4-2',0,'5660'),(385437,122105,'116561','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385438,122105,'116561','deals','text-align','right',0,''),(385439,122105,'116561','deals','padding-top','10',0,''),(385440,122105,'116561','deals','font_size_measure','em',0,''),(385441,122105,'116561','deals','font-size','1.2',0,''),(385442,122106,'116562','deals','text-align','right',0,''),(385443,122107,'116563','deals','block_type','2',0,''),(385444,122107,'116563','deals','schema','2-2',0,'5639'),(385445,122108,'116564','deals','block_type','1',0,''),(385446,122108,'116564','deals','padding-right','20',0,''),(385447,122108,'116564','deals','padding-right','0',0,'5639'),(385448,122110,'116566','deals','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(385449,122111,'116567','deals','block_type','1',0,''),(385450,122111,'116567','deals','padding-left','20',0,''),(385451,122111,'116567','deals','padding-left','0',0,'5639'),(385452,122113,'116569','deals','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(385453,122114,'116570','deals','block_type','2',0,''),(385454,122114,'116570','deals','schema','2-2',0,'5639'),(385455,122115,'116571','deals','block_type','1',0,''),(385456,122115,'116571','deals','padding-right','20',0,''),(385457,122115,'116571','deals','padding-right','0',0,'5639'),(385458,122116,'116572','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385459,122118,'116574','deals','block_type','1',0,''),(385460,122118,'116574','deals','padding-left','20',0,''),(385461,122118,'116574','deals','padding-left','0',0,'5639'),(385462,122123,'116579','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385463,122124,'116580','deals','margin-bottom','20',0,''),(385464,122125,'116581','deals','block_type','1',0,''),(385465,122125,'116581','deals','background-color','$content-bg-2',0,''),(385466,122125,'116581','deals','padding-top','30',0,''),(385467,122125,'116581','deals','padding-bottom','30',0,''),(385468,122126,'116582','deals','block_type','7',0,''),(385469,122126,'116582','deals','schema','4-2',0,'5639'),(385470,122126,'116582','deals','margin-bottom','30',0,''),(385471,122127,'116583','deals','block_type','1',0,''),(385472,122127,'116583','deals','padding-right','0',0,'5639'),(385473,122128,'116585','deals','block_type','1',0,''),(385474,122128,'116585','deals','background-color','$content-bg-1',0,''),(385475,122128,'116585','deals','padding-top','30',0,''),(385476,122128,'116585','deals','padding-left','30',0,''),(385477,122128,'116585','deals','padding-right','30',0,''),(385478,122128,'116585','deals','padding-bottom','14',0,''),(385479,122128,'116585','deals','margin-bottom','20',0,''),(385480,122128,'116585','deals','style_class','hiding-box closeable-box',0,''),(385481,122129,'116586','deals','style_class','closeable-content',0,''),(385482,122129,'116586','deals','padding-bottom','20',0,''),(385483,122130,'116587','deals','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(385484,122130,'116587','deals','style_class','closeable-heading closeable-event closed',0,''),(385485,122131,'116588','deals','block_type','1',0,''),(385486,122131,'116588','deals','background-color','$content-bg-1',0,''),(385487,122131,'116588','deals','padding-top','30',0,''),(385488,122131,'116588','deals','padding-left','30',0,''),(385489,122131,'116588','deals','padding-right','30',0,''),(385490,122131,'116588','deals','padding-bottom','30',0,''),(385491,122131,'116588','deals','margin-bottom','20',0,''),(385492,122131,'116588','deals','style_class','hiding-box',0,''),(385493,122132,'116589','deals','padding-top','10',0,''),(385494,122132,'116589','deals','padding-left','20',0,''),(385495,122132,'116589','deals','padding-right','20',0,''),(385496,122132,'116589','deals','margin-top','20',0,''),(385497,122132,'116589','deals','background-color','$content-bg-2',0,''),(385498,122132,'116589','deals','padding-bottom','8',0,''),(385499,122133,'116590','deals','margin-bottom','20',0,''),(385500,122134,'116591','deals','block_type','1',0,''),(385501,122134,'116591','deals','padding-top','30',0,''),(385502,122134,'116591','deals','padding-left','30',0,''),(385503,122134,'116591','deals','padding-right','30',0,''),(385504,122134,'116591','deals','padding-bottom','23',0,''),(385505,122134,'116591','deals','margin-bottom','20',0,''),(385506,122134,'116591','deals','background-color','$content-bg-1',0,''),(385507,122134,'116591','deals','style_class','hiding-box',0,''),(385508,122135,'116592','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(385509,122136,'116593','deals','block_type','2',0,''),(385510,122136,'116593','deals','schema','2-2',0,'5639'),(385511,122137,'116594','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385512,122138,'116595','deals','padding-right','20',0,''),(385513,122138,'116595','deals','padding-right','0',0,'5639'),(385514,122138,'116595','deals','padding-bottom','20',0,'5639'),(385515,122139,'116596','deals','block_type','1',0,''),(385516,122139,'116596','deals','padding-left','20',0,''),(385517,122139,'116596','deals','padding-left','0',0,'5639'),(385518,122141,'116598','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385519,122142,'116599','deals','block_type','1',0,''),(385520,122142,'116599','deals','padding-top','10',0,''),(385521,122142,'116599','deals','padding-left','10',0,''),(385522,122142,'116599','deals','padding-right','10',0,''),(385523,122142,'116599','deals','padding-bottom','10',0,''),(385524,122142,'116599','deals','background-color','$content-bg-1',0,''),(385525,122142,'116599','deals','style_class','order-summary',0,''),(385526,122142,'116599','deals','margin-left','25',0,''),(385527,122144,'116601','deals','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(385528,122144,'116601','deals','text-align','center',0,''),(385529,122144,'116601','deals','font-size','14',0,''),(385530,122144,'116601','deals','color','$fade-color-1',0,''),(385531,122144,'116601','deals','padding-top','10',0,''),(385532,122145,'116602','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(385533,122146,'116603','deals','margin-bottom','10',0,''),(385534,122148,'116604','deals','block_type','2',0,''),(385535,122148,'116604','deals','schema','2-2',0,'5630'),(385536,122149,'116605','deals','block_type','1',0,''),(385537,122149,'116605','deals','padding-left','0',0,'5639'),(385538,122149,'116605','deals','padding-right','20',0,''),(385539,122151,'116607','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385540,122152,'116608','deals','block_type','1',0,''),(385541,122152,'116608','deals','padding-left','20',0,''),(385542,122152,'116608','deals','padding-left','0',0,'5639'),(385543,122157,'116613','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385544,122158,'116614','deals','block_type','4',0,''),(385545,122158,'116614','deals','schema','4-2',0,'5660'),(385546,122158,'116614','deals','padding-top','20',0,''),(385547,122159,'116615','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385548,122159,'116615','deals','text-align','right',0,''),(385549,122159,'116615','deals','padding-top','10',0,''),(385550,122159,'116615','deals','font_size_measure','em',0,''),(385551,122159,'116615','deals','font-size','1.2',0,''),(385552,122159,'116615','deals','text-align','center',0,'5630'),(385553,122160,'116616','deals','text-align','right',0,''),(385554,122160,'116616','deals','text-align','center',0,'5630'),(385555,122161,'116617','deals','block_type','2',0,''),(385556,122162,'116618','deals','block_type','1',0,''),(385557,122162,'116618','deals','padding-left','0',0,'5639'),(385558,122162,'116618','deals','padding-right','20',0,''),(385559,122164,'116620','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385560,122165,'116621','deals','block_type','1',0,''),(385561,122165,'116621','deals','padding-left','20',0,''),(385562,122165,'116621','deals','padding-left','0',0,'5639'),(385563,122167,'116623','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385564,122171,'116627','deals','block_type','4',0,''),(385565,122171,'116627','deals','schema','4-2',0,'5660'),(385566,122172,'116628','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385567,122172,'116628','deals','text-align','right',0,''),(385568,122172,'116628','deals','padding-top','10',0,''),(385569,122172,'116628','deals','font_size_measure','em',0,''),(385570,122172,'116628','deals','font-size','1.2',0,''),(385571,122173,'116629','deals','text-align','right',0,''),(385572,122174,'116630','deals','block_type','4',0,''),(385573,122174,'116630','deals','schema','4-2',0,'5660'),(385574,122175,'116631','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385575,122175,'116631','deals','text-align','right',0,''),(385576,122175,'116631','deals','padding-top','10',0,''),(385577,122175,'116631','deals','font_size_measure','em',0,''),(385578,122175,'116631','deals','font-size','1.2',0,''),(385579,122176,'116632','deals','text-align','right',0,''),(385580,122177,'116633','deals','block_type','2',0,''),(385581,122178,'116634','deals','block_type','1',0,''),(385582,122178,'116634','deals','padding-left','0',0,'5639'),(385583,122178,'116634','deals','padding-right','20',0,''),(385584,122179,'116635','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385585,122181,'116637','deals','block_type','1',0,''),(385586,122181,'116637','deals','padding-left','20',0,''),(385587,122181,'116637','deals','padding-left','0',0,'5639'),(385588,122186,'116642','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385589,122187,'116643','deals','block_type','4',0,''),(385590,122187,'116643','deals','schema','4-2',0,'5660'),(385591,122188,'116644','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385592,122188,'116644','deals','text-align','right',0,''),(385593,122188,'116644','deals','padding-top','10',0,''),(385594,122188,'116644','deals','font_size_measure','em',0,''),(385595,122188,'116644','deals','font-size','1.2',0,''),(385596,122189,'116645','deals','text-align','right',0,''),(385597,122190,'116646','deals','block_type','2',0,''),(385598,122191,'116647','deals','block_type','1',0,''),(385599,122191,'116647','deals','padding-left','0',0,'5639'),(385600,122191,'116647','deals','padding-right','20',0,''),(385601,122193,'116649','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385602,122194,'116650','deals','block_type','1',0,''),(385603,122194,'116650','deals','padding-left','20',0,''),(385604,122194,'116650','deals','padding-left','0',0,'5639'),(385605,122198,'116654','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385606,122200,'116656','deals','text','##PAYMENT_DETAILS##',0,''),(385607,122201,'116657','deals','text','##PAYMENT_DETAILS##',0,''),(385608,122202,'116658','deals','text','##PAYMENT_DETAILS##',0,''),(385609,122203,'116659','deals','text','##PAYMENT_DETAILS##',0,''),(385610,122204,'116660','deals','text','##PAYMENT_DETAILS##',0,''),(385611,122205,'116661','deals','text','##PAYMENT_DETAILS##',0,''),(385612,122206,'120947','deals','block_type','1',0,''),(385613,122206,'120947','deals','background-color','$content-bg-2',0,''),(385614,122206,'120947','deals','padding-top','30',0,''),(385615,122206,'120947','deals','padding-bottom','30',0,''),(385616,122207,'120948','deals','block_type','7',0,''),(385617,122207,'120948','deals','schema','4-2',0,'5639'),(385618,122208,'120949','deals','block_type','1',0,''),(385619,122208,'120949','deals','padding-right','0',0,'5639'),(385620,122209,'120950','deals','block_type','1',0,''),(385621,122209,'120950','deals','background-color','$content-bg-1',0,''),(385622,122209,'120950','deals','padding-top','30',0,''),(385623,122209,'120950','deals','padding-left','30',0,''),(385624,122209,'120950','deals','padding-right','30',0,''),(385625,122209,'120950','deals','padding-bottom','30',0,''),(385626,122209,'120950','deals','margin-bottom','20',0,''),(385627,122209,'120950','deals','style_class','hiding-box',0,''),(385628,122210,'120951','deals','padding-top','10',0,''),(385629,122210,'120951','deals','padding-left','20',0,''),(385630,122210,'120951','deals','padding-right','20',0,''),(385631,122210,'120951','deals','margin-top','20',0,''),(385632,122210,'120951','deals','background-color','$content-bg-2',0,''),(385633,122210,'120951','deals','padding-bottom','8',0,''),(385634,122211,'120952','deals','margin-bottom','20',0,''),(385635,122212,'120953','deals','background-color','$content-bg-1',0,''),(385636,122212,'120953','deals','block_type','1',0,''),(385637,122212,'120953','deals','padding-top','30',0,''),(385638,122212,'120953','deals','padding-left','30',0,''),(385639,122212,'120953','deals','padding-right','30',0,''),(385640,122212,'120953','deals','padding-bottom','30',0,''),(385641,122212,'120953','deals','margin-bottom','20',0,''),(385642,122212,'120953','deals','style_class','hiding-box',0,''),(385643,122213,'120954','deals','block_type','1',0,''),(385644,122213,'120954','deals','content','\\_',0,'3'),(385645,122213,'120954','deals','border-top-width','1',0,'3'),(385646,122213,'120954','deals','border-top-color','$content-border-1',0,'3'),(385647,122213,'120954','deals','display','block',0,'3'),(385648,122213,'120954','deals','position','absolute',0,'3'),(385649,122213,'120954','deals','top','19',0,'3'),(385650,122213,'120954','deals','left','0',0,'3'),(385651,122213,'120954','deals','right','0',0,'3'),(385652,122213,'120954','deals','margin-top','-2',0,'3'),(385653,122213,'120954','deals','position','relative',0,''),(385654,122214,'120955','deals','box_align','2',0,''),(385655,122214,'120955','deals','margin-bottom','10',0,''),(385656,122214,'120955','deals','background-color','$content-bg-1',0,''),(385657,122214,'120955','deals','position','relative',0,''),(385658,122215,'120956','deals','background-color','$content-bg-2',0,''),(385659,122215,'120956','deals','padding-top','10',0,''),(385660,122215,'120956','deals','padding-left','10',0,''),(385661,122215,'120956','deals','padding-right','10',0,''),(385662,122215,'120956','deals','padding-bottom','10',0,''),(385663,122215,'120956','deals','margin-top','10',0,''),(385664,122216,'120957','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(385665,122217,'120958','deals','block_type','2',0,''),(385666,122217,'120958','deals','schema','2-2',0,'5639'),(385667,122218,'120959','deals','block_type','1',0,''),(385668,122218,'120959','deals','padding-right','20',0,''),(385669,122218,'120959','deals','padding-left','0',0,'5639'),(385670,122218,'120959','deals','margin-bottom','20',0,'5639'),(385671,122218,'120959','deals','padding-right','0',0,'5639'),(385672,122221,'120962','deals','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(385673,122222,'120963','deals','block_type','1',0,''),(385674,122222,'120963','deals','padding-left','20',0,''),(385675,122222,'120963','deals','padding-left','0',0,'5639'),(385676,122224,'120965','deals','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(385677,122225,'120966','deals','border-top-width','1',0,''),(385678,122225,'120966','deals','border-top-color','$content-border-1',0,''),(385679,122225,'120966','deals','padding-top','13',0,''),(385680,122225,'120966','deals','padding-bottom','10',0,''),(385681,122226,'120967','deals','block_type','1',0,''),(385682,122226,'120967','deals','background-color','$content-bg-1',0,''),(385683,122226,'120967','deals','padding-top','30',0,''),(385684,122226,'120967','deals','padding-left','30',0,''),(385685,122226,'120967','deals','padding-right','30',0,''),(385686,122226,'120967','deals','padding-bottom','14',0,''),(385687,122226,'120967','deals','margin-bottom','20',0,''),(385688,122226,'120967','deals','style_class','hiding-box closeable-box',0,''),(385689,122227,'120968','deals','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(385690,122227,'120968','deals','style_class','closeable-heading closeable-event closed',0,''),(385691,122228,'120969','deals','style_class','closeable-content',0,''),(385692,122228,'120969','deals','padding-bottom','20',0,''),(385693,122229,'120970','deals','block_type','1',0,''),(385694,122229,'120970','deals','padding-top','30',0,''),(385695,122229,'120970','deals','padding-left','30',0,''),(385696,122229,'120970','deals','padding-right','30',0,''),(385697,122229,'120970','deals','padding-bottom','23',0,''),(385698,122229,'120970','deals','margin-bottom','20',0,''),(385699,122229,'120970','deals','background-color','$content-bg-1',0,''),(385700,122229,'120970','deals','style_class','hiding-box',0,''),(385701,122230,'120971','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(385702,122231,'120972','deals','block_type','2',0,''),(385703,122231,'120972','deals','schema','2-2',0,'5639'),(385704,122232,'120973','deals','padding-right','20',0,''),(385705,122232,'120973','deals','padding-right','0',0,'5639'),(385706,122232,'120973','deals','padding-bottom','20',0,'5639'),(385707,122233,'120974','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385708,122234,'120975','deals','block_type','1',0,''),(385709,122234,'120975','deals','padding-left','20',0,''),(385710,122234,'120975','deals','padding-left','0',0,'5639'),(385711,122236,'120977','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385712,122237,'120978','deals','block_type','1',0,''),(385713,122237,'120978','deals','padding-left','10',0,''),(385714,122237,'120978','deals','padding-right','10',0,''),(385715,122237,'120978','deals','padding-bottom','10',0,''),(385716,122237,'120978','deals','background-color','$content-bg-1',0,''),(385717,122237,'120978','deals','style_class','order-summary',0,''),(385718,122237,'120978','deals','margin-left','25',0,''),(385719,122237,'120978','deals','margin-left','0',0,'5639'),(385720,122238,'120979','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(385721,122239,'120980','deals','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(385722,122239,'120980','deals','text-align','center',0,''),(385723,122239,'120980','deals','font-size','14',0,''),(385724,122239,'120980','deals','color','$fade-color-1',0,''),(385725,122239,'120980','deals','padding-top','10',0,''),(385726,122240,'120981','deals','margin-bottom','10',0,''),(385727,122242,'120983','deals','hide_continue_button','1',0,''),(385728,122243,'116699','deals','block_type','1',0,''),(385729,122243,'116699','deals','background-color','$content-bg-2',0,''),(385730,122243,'116699','deals','padding-top','30',0,''),(385731,122243,'116699','deals','padding-bottom','30',0,''),(385732,122244,'116700','deals','block_type','7',0,''),(385733,122244,'116700','deals','schema','7-2',0,'5639'),(385734,122245,'116701','deals','block_type','1',0,''),(385735,122245,'116701','deals','padding-right','0',0,'5639'),(385736,122246,'116703','deals','block_type','1',0,''),(385737,122246,'116703','deals','background-color','$content-bg-1',0,''),(385738,122246,'116703','deals','padding-top','30',0,''),(385739,122246,'116703','deals','padding-left','30',0,''),(385740,122246,'116703','deals','padding-right','30',0,''),(385741,122246,'116703','deals','padding-bottom','30',0,''),(385742,122246,'116703','deals','margin-bottom','20',0,''),(385743,122246,'116703','deals','style_class','hiding-box',0,''),(385744,122247,'116704','deals','margin-bottom','20',0,''),(385745,122248,'116705','deals','padding-top','10',0,''),(385746,122248,'116705','deals','padding-left','20',0,''),(385747,122248,'116705','deals','padding-right','20',0,''),(385748,122248,'116705','deals','margin-top','20',0,''),(385749,122248,'116705','deals','background-color','$content-bg-2',0,''),(385750,122248,'116705','deals','padding-bottom','8',0,''),(385751,122249,'116706','deals','background-color','$content-bg-1',0,''),(385752,122249,'116706','deals','block_type','1',0,''),(385753,122249,'116706','deals','padding-top','30',0,''),(385754,122249,'116706','deals','padding-left','30',0,''),(385755,122249,'116706','deals','padding-right','30',0,''),(385756,122249,'116706','deals','padding-bottom','30',0,''),(385757,122249,'116706','deals','margin-bottom','20',0,''),(385758,122249,'116706','deals','style_class','hiding-box',0,''),(385759,122250,'116707','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(385760,122251,'116708','deals','background-color','$content-bg-2',0,''),(385761,122251,'116708','deals','padding-top','10',0,''),(385762,122251,'116708','deals','padding-left','10',0,''),(385763,122251,'116708','deals','padding-right','10',0,''),(385764,122251,'116708','deals','padding-bottom','10',0,''),(385765,122251,'116708','deals','margin-top','10',0,''),(385766,122252,'116709','deals','block_type','1',0,''),(385767,122252,'116709','deals','content','\\_',0,'3'),(385768,122252,'116709','deals','border-top-width','1',0,'3'),(385769,122252,'116709','deals','border-top-color','$content-border-1',0,'3'),(385770,122252,'116709','deals','display','block',0,'3'),(385771,122252,'116709','deals','position','absolute',0,'3'),(385772,122252,'116709','deals','top','19',0,'3'),(385773,122252,'116709','deals','left','0',0,'3'),(385774,122252,'116709','deals','right','0',0,'3'),(385775,122252,'116709','deals','margin-top','-2',0,'3'),(385776,122252,'116709','deals','position','relative',0,''),(385777,122253,'116710','deals','box_align','2',0,''),(385778,122253,'116710','deals','margin-bottom','10',0,''),(385779,122253,'116710','deals','background-color','$content-bg-1',0,''),(385780,122253,'116710','deals','position','relative',0,''),(385781,122254,'116711','deals','block_type','2',0,''),(385782,122254,'116711','deals','schema','2-2',0,'5639'),(385783,122255,'116712','deals','block_type','1',0,''),(385784,122255,'116712','deals','padding-right','20',0,''),(385785,122255,'116712','deals','padding-left','0',0,'5639'),(385786,122255,'116712','deals','margin-bottom','20',0,'5639'),(385787,122255,'116712','deals','padding-right','0',0,'5639'),(385788,122258,'116715','deals','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(385789,122259,'116716','deals','block_type','1',0,''),(385790,122259,'116716','deals','padding-left','20',0,''),(385791,122259,'116716','deals','padding-left','0',0,'5639'),(385792,122261,'116718','deals','border-top-width','1',0,''),(385793,122261,'116718','deals','border-top-color','$content-border-1',0,''),(385794,122261,'116718','deals','padding-top','13',0,''),(385795,122261,'116718','deals','padding-bottom','10',0,''),(385796,122262,'116719','deals','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(385797,122263,'116720','deals','block_type','1',0,''),(385798,122263,'116720','deals','padding-top','30',0,''),(385799,122263,'116720','deals','padding-left','30',0,''),(385800,122263,'116720','deals','padding-right','30',0,''),(385801,122263,'116720','deals','padding-bottom','23',0,''),(385802,122263,'116720','deals','margin-bottom','20',0,''),(385803,122263,'116720','deals','background-color','$content-bg-1',0,''),(385804,122263,'116720','deals','style_class','hiding-box',0,''),(385805,122264,'116721','deals','block_type','2',0,''),(385806,122264,'116721','deals','schema','2-2',0,'5639'),(385807,122265,'116722','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385808,122266,'116723','deals','padding-right','20',0,''),(385809,122266,'116723','deals','padding-right','0',0,'5639'),(385810,122266,'116723','deals','padding-bottom','20',0,'5639'),(385811,122267,'116724','deals','block_type','1',0,''),(385812,122267,'116724','deals','padding-left','20',0,''),(385813,122267,'116724','deals','padding-left','0',0,'5639'),(385814,122268,'116725','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385815,122270,'116727','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(385816,122271,'116728','deals','block_type','1',0,''),(385817,122271,'116728','deals','background-color','$content-bg-1',0,''),(385818,122271,'116728','deals','padding-top','30',0,''),(385819,122271,'116728','deals','padding-left','30',0,''),(385820,122271,'116728','deals','padding-right','30',0,''),(385821,122271,'116728','deals','padding-bottom','14',0,''),(385822,122271,'116728','deals','margin-bottom','20',0,''),(385823,122271,'116728','deals','style_class','hiding-box closeable-box',0,''),(385824,122272,'116729','deals','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(385825,122272,'116729','deals','style_class','closeable-heading closeable-event closed',0,''),(385826,122273,'116730','deals','style_class','closeable-content',0,''),(385827,122273,'116730','deals','padding-bottom','20',0,''),(385828,122274,'116731','deals','block_type','1',0,''),(385829,122274,'116731','deals','padding-top','30',0,''),(385830,122274,'116731','deals','padding-left','30',0,''),(385831,122274,'116731','deals','padding-right','30',0,''),(385832,122274,'116731','deals','padding-bottom','14',0,''),(385833,122274,'116731','deals','margin-bottom','20',0,''),(385834,122274,'116731','deals','background-color','$content-bg-1',0,''),(385835,122274,'116731','deals','style_class','hiding-box closeable-box',0,''),(385836,122275,'116732','deals','block_type','2',0,''),(385837,122275,'116732','deals','style_class','closeable-content',0,''),(385838,122275,'116732','deals','schema','2-2',0,'5639'),(385839,122276,'116733','deals','padding-right','20',0,''),(385840,122276,'116733','deals','padding-bottom','20',0,''),(385841,122276,'116733','deals','padding-right','0',0,'5639'),(385842,122277,'116734','deals','padding-left','20',0,''),(385843,122277,'116734','deals','padding-bottom','20',0,''),(385844,122277,'116734','deals','padding-left','0',0,'5639'),(385845,122278,'116735','deals','padding-left','20',0,''),(385846,122278,'116735','deals','padding-bottom','20',0,''),(385847,122278,'116735','deals','padding-left','0',0,'5639'),(385848,122279,'116736','deals','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(385849,122279,'116736','deals','style_class','closeable-heading closeable-event closed',0,''),(385850,122280,'116737','deals','block_type','1',0,''),(385851,122280,'116737','deals','padding-top','20',0,''),(385852,122280,'116737','deals','padding-left','20',0,''),(385853,122280,'116737','deals','padding-right','20',0,''),(385854,122280,'116737','deals','padding-bottom','20',0,''),(385855,122280,'116737','deals','background-color','$content-bg-1',0,''),(385856,122280,'116737','deals','style_class','order-summary',0,''),(385857,122280,'116737','deals','margin-left','25',0,''),(385858,122280,'116737','deals','padding-left','0',0,'5639'),(385859,122281,'116738','deals','margin-bottom','10',0,''),(385860,122282,'116739','deals','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(385861,122282,'116739','deals','text-align','center',0,''),(385862,122282,'116739','deals','font-size','14',0,''),(385863,122282,'116739','deals','color','$fade-color-1',0,''),(385864,122282,'116739','deals','padding-top','10',0,''),(385865,122283,'116740','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(385866,122285,'120986','deals','hide_continue_button','1',0,''),(385867,122286,'116742','deals','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(385868,122291,'116747','deals','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(385869,122292,'116749','deals','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(385870,122293,'116750','deals','style_class','order-summary',0,''),(385871,122293,'116750','deals','box_align','3',0,''),(385872,122293,'116750','deals','width','400',0,''),(385873,122295,'116748','deals','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(385874,122298,'116754','deals','block_type','1',0,''),(385875,122299,'116755','deals','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(385876,122300,'116756','deals','float','right',0,''),(385877,122300,'116756','deals','position','relative',0,''),(385878,122300,'116756','deals','z-index','1',0,''),(385879,122300,'116756','deals','top','30',0,''),(385880,122300,'116756','deals','margin-bottom','-10',0,''),(385881,122301,'116757','deals','margin-bottom','30',0,''),(385882,122302,'116758','deals','block_type','1',0,''),(385883,122303,'116759','deals','listing_type','CompareProduct',0,''),(385884,122304,'117665','deals','block_type','1',0,''),(385885,122304,'117665','deals','style_class','item-holder',0,''),(385886,122304,'117665','deals','padding-top','25',0,''),(385887,122304,'117665','deals','padding-left','25',0,''),(385888,122304,'117665','deals','padding-right','25',0,''),(385889,122304,'117665','deals','padding-bottom','25',0,''),(385890,122304,'117665','deals','text-align','left',0,''),(385891,122305,'120921','deals','block_type','1',0,''),(385892,122305,'120921','deals','style_class','item-wrapper',0,''),(385893,122306,'120919','deals','block_type','1',0,''),(385894,122306,'120919','deals','style_class','item-content',0,''),(385895,122307,'1638872990','deals','block_type','5',0,''),(385896,122309,'117677','deals','float','right',0,''),(385897,122310,'117675','deals','clear','none',0,''),(385898,122311,'117676','deals','margin-bottom','10',0,''),(385899,122312,'1638873112','deals','block_type','2',0,''),(385900,122314,'117673','deals','margin-bottom','7',0,''),(385901,122314,'117673','deals','text-align','right',0,''),(385902,122315,'116760','deals','block_type','1',0,''),(385903,122315,'116760','deals','style_class','item-holder',0,''),(385904,122315,'116760','deals','padding-top','10',0,''),(385905,122315,'116760','deals','padding-left','20',0,''),(385906,122315,'116760','deals','padding-right','20',0,''),(385907,122315,'116760','deals','padding-bottom','10',0,''),(385908,122315,'116760','deals','text-align','left',0,''),(385909,122318,'116763','deals','margin-bottom','10',0,''),(385910,122319,'116764','deals','block_type','5',0,''),(385911,122321,'116766','deals','clear','both',0,''),(385912,122322,'116767','deals','block_type','2',0,''),(385913,122323,'116768','deals','margin-bottom','7',0,''),(385914,122324,'116769','deals','text-align','right',0,''),(385915,122324,'116769','deals','margin-bottom','10',0,''),(385916,122324,'116769','deals','float','right',0,''),(385917,122325,'116770','deals','block_type','1',0,''),(385918,122325,'116770','deals','padding-bottom','30',0,''),(385919,122325,'116770','deals','style_class','checkout-order-confirmation',0,''),(385920,122326,'116771','deals','block_type','4',0,''),(385921,122326,'116771','deals','schema','4-2',0,'5639'),(385922,122327,'116772','deals','block_type','1',0,''),(385923,122327,'116772','deals','padding-right','0',0,'5639'),(385924,122327,'116772','deals','margin-bottom','30',0,''),(385925,122328,'116773','deals','block_type','1',0,''),(385926,122328,'116773','deals','padding-right','20',0,''),(385927,122328,'116773','deals','background-color','$content-bg-1',0,''),(385928,122328,'116773','deals','padding-top','20',0,''),(385929,122328,'116773','deals','padding-left','20',0,''),(385930,122328,'116773','deals','padding-bottom','20',0,''),(385931,122328,'116773','deals','padding-left','15',0,'5639'),(385932,122328,'116773','deals','padding-right','15',0,'5639'),(385933,122328,'116773','deals','border-top-width','1',0,''),(385934,122328,'116773','deals','border-left-width','1',0,''),(385935,122328,'116773','deals','border-right-width','1',0,''),(385936,122328,'116773','deals','border-bottom-width','1',0,''),(385937,122328,'116773','deals','border-top-color','$content-border-1',0,''),(385938,122328,'116773','deals','border-left-color','$content-border-1',0,''),(385939,122328,'116773','deals','border-right-color','$content-border-1',0,''),(385940,122328,'116773','deals','border-bottom-color','$content-border-1',0,''),(385941,122328,'116773','deals','padding-top','15',0,'5639'),(385942,122328,'116773','deals','padding-bottom','15',0,'5639'),(385943,122329,'116774','deals','link','products',0,''),(385944,122329,'116774','deals','float','right',0,''),(385945,122329,'116774','deals','margin-top','-37',0,''),(385946,122331,'116776','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(385947,122332,'116777','deals','block_type','1',0,''),(385948,122332,'116777','deals','background-color','$content-bg-1',0,''),(385949,122332,'116777','deals','padding-top','20',0,''),(385950,122332,'116777','deals','padding-bottom','20',0,''),(385951,122332,'116777','deals','padding-left','20',0,''),(385952,122332,'116777','deals','padding-right','20',0,''),(385953,122332,'116777','deals','margin-bottom','20',0,''),(385954,122332,'116777','deals','border-top-width','1',0,''),(385955,122332,'116777','deals','border-left-width','1',0,''),(385956,122332,'116777','deals','border-right-width','1',0,''),(385957,122332,'116777','deals','border-bottom-width','1',0,''),(385958,122332,'116777','deals','border-top-color','$content-border-1',0,''),(385959,122332,'116777','deals','border-left-color','$content-border-1',0,''),(385960,122332,'116777','deals','border-right-color','$content-border-1',0,''),(385961,122332,'116777','deals','border-bottom-color','$content-border-1',0,''),(385962,122332,'116777','deals','padding-top','15',0,'5639'),(385963,122332,'116777','deals','padding-left','15',0,'5639'),(385964,122332,'116777','deals','padding-right','15',0,'5639'),(385965,122332,'116777','deals','padding-bottom','15',0,'5639'),(385966,122333,'116778','deals','float','right',0,''),(385967,122333,'116778','deals','margin-top','-37',0,''),(385968,122333,'116778','deals','link','comments',0,''),(385969,122334,'116779','deals','text',' <div class=\"heading-2\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(385970,122335,'116780','deals','hide_parents','2',0,''),(385971,122336,'116782','deals','block_type','1',0,''),(385972,122336,'116782','deals','padding-right','20',0,''),(385973,122336,'116782','deals','padding-top','20',0,''),(385974,122336,'116782','deals','padding-left','20',0,''),(385975,122336,'116782','deals','padding-bottom','20',0,''),(385976,122336,'116782','deals','margin-right','0',0,'5639'),(385977,122336,'116782','deals','margin-bottom','20',0,'5639'),(385978,122336,'116782','deals','padding-left','15',0,'5639'),(385979,122336,'116782','deals','padding-right','15',0,'5639'),(385980,122336,'116782','deals','border-top-width','1',0,''),(385981,122336,'116782','deals','border-left-width','1',0,''),(385982,122336,'116782','deals','border-right-width','1',0,''),(385983,122336,'116782','deals','border-bottom-width','1',0,''),(385984,122336,'116782','deals','border-top-color','$content-border-1',0,''),(385985,122336,'116782','deals','border-left-color','$content-border-1',0,''),(385986,122336,'116782','deals','border-right-color','$content-border-1',0,''),(385987,122336,'116782','deals','border-bottom-color','$content-border-1',0,''),(385988,122336,'116782','deals','margin-bottom','30',0,''),(385989,122337,'116789','deals','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(385990,122338,'1643301641','deals','block_type','2',0,''),(385991,122338,'1643301641','deals','schema','2-2',0,'5660'),(385992,122339,'116785','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(385993,122339,'116785','deals','padding-top','20',0,''),(385994,122339,'116785','deals','padding-top','0',0,'5660'),(385995,122340,'116786','deals','link','contact_information',0,''),(385996,122340,'116786','deals','margin-top','-31',0,''),(385997,122340,'116786','deals','float','right',0,''),(385998,122341,'116790','deals','link','shipping_address',0,''),(385999,122341,'116790','deals','float','right',0,''),(386000,122341,'116790','deals','margin-top','-31',0,''),(386001,122342,'116791','deals','padding-bottom','20',0,'5660'),(386002,122343,'116792','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(386003,122343,'116792','deals','clear','none',0,''),(386004,122344,'116793','deals','margin-bottom','20',0,''),(386005,122345,'116783','deals','link','shipping_method',0,''),(386006,122345,'116783','deals','float','right',0,''),(386007,122345,'116783','deals','margin-top','-31',0,''),(386008,122347,'116787','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(386009,122347,'116787','deals','clear','none',0,''),(386010,122349,'116794','deals','block_type','1',0,''),(386011,122349,'116794','deals','padding-left','20',0,''),(386012,122349,'116794','deals','border-left-width','1',0,''),(386013,122349,'116794','deals','border-left-color','$content-border-1',0,''),(386014,122349,'116794','deals','padding-right','20',0,''),(386015,122349,'116794','deals','padding-top','20',0,''),(386016,122349,'116794','deals','padding-bottom','20',0,''),(386017,122349,'116794','deals','border-top-width','1',0,''),(386018,122349,'116794','deals','border-right-width','1',0,''),(386019,122349,'116794','deals','border-bottom-width','1',0,''),(386020,122349,'116794','deals','border-top-color','$content-border-1',0,''),(386021,122349,'116794','deals','border-right-color','$content-border-1',0,''),(386022,122349,'116794','deals','border-bottom-color','$content-border-1',0,''),(386023,122349,'116794','deals','margin-bottom','30',0,''),(386024,122349,'116794','deals','padding-top','15',0,'5639'),(386025,122349,'116794','deals','padding-left','15',0,'5639'),(386026,122349,'116794','deals','padding-right','15',0,'5639'),(386027,122349,'116794','deals','padding-bottom','15',0,'5639'),(386028,122350,'116799','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(386029,122351,'1643301813','deals','block_type','2',0,''),(386030,122351,'1643301813','deals','schema','2-2',0,'5660'),(386031,122352,'116796','deals','link','billing_address',0,''),(386032,122352,'116796','deals','float','right',0,''),(386033,122352,'116796','deals','margin-top','-31',0,''),(386034,122353,'116800','deals','margin-bottom','20',0,''),(386035,122354,'116801','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(386036,122354,'116801','deals','clear','none',0,''),(386037,122355,'116795','deals','link','payment_method',0,''),(386038,122355,'116795','deals','float','right',0,''),(386039,122355,'116795','deals','margin-top','-31',0,''),(386040,122357,'116798','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(386041,122357,'116798','deals','clear','none',0,''),(386042,122359,'116803','deals','block_type','1',0,''),(386043,122359,'116803','deals','padding-left','30',0,''),(386044,122359,'116803','deals','background-color','$content-bg-1',0,''),(386045,122359,'116803','deals','style_class','order-summary',0,''),(386046,122359,'116803','deals','padding-left','0',0,'5639'),(386047,122360,'116804','deals','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(386048,122361,'116805','deals','margin-bottom','20',0,''),(386049,122361,'116805','deals','text-align','right',0,''),(386050,122363,'116807','deals','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(386051,122364,'116808','deals','block_type','1',0,''),(386052,122364,'116808','deals','background-color','$content-bg-2',0,''),(386053,122364,'116808','deals','padding-bottom','30',0,''),(386054,122365,'116809','deals','block_type','4',0,''),(386055,122365,'116809','deals','schema','4-2',0,'5639'),(386056,122366,'116810','deals','block_type','1',0,''),(386057,122366,'116810','deals','padding-right','40',0,''),(386058,122366,'116810','deals','padding-right','0',0,'5639'),(386059,122367,'116811','deals','block_type','1',0,''),(386060,122367,'116811','deals','background-color','$content-bg-1',0,''),(386061,122367,'116811','deals','padding-top','20',0,''),(386062,122367,'116811','deals','padding-bottom','20',0,''),(386063,122367,'116811','deals','padding-left','30',0,''),(386064,122367,'116811','deals','padding-right','30',0,''),(386065,122367,'116811','deals','margin-bottom','20',0,''),(386066,122368,'116812','deals','hide_parents','2',0,''),(386067,122369,'116813','deals','float','right',0,''),(386068,122369,'116813','deals','margin-top','-37',0,''),(386069,122369,'116813','deals','link','comments',0,''),(386070,122370,'116814','deals','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(386071,122371,'116815','deals','block_type','1',0,''),(386072,122371,'116815','deals','padding-right','30',0,''),(386073,122371,'116815','deals','background-color','$content-bg-1',0,''),(386074,122371,'116815','deals','padding-top','20',0,''),(386075,122371,'116815','deals','padding-left','30',0,''),(386076,122371,'116815','deals','padding-bottom','20',0,''),(386077,122371,'116815','deals','padding-left','20',0,'5639'),(386078,122371,'116815','deals','padding-right','20',0,'5639'),(386079,122372,'116816','deals','link','products',0,''),(386080,122372,'116816','deals','float','right',0,''),(386081,122372,'116816','deals','margin-top','-37',0,''),(386082,122373,'116817','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(386083,122375,'116819','deals','block_type','2',0,''),(386084,122375,'116819','deals','margin-bottom','20',0,''),(386085,122375,'116819','deals','schema','2-2',0,'5630'),(386086,122375,'116819','deals','background-color','$content-bg-1',0,''),(386087,122376,'116820','deals','block_type','1',0,''),(386088,122376,'116820','deals','border-right-width','20',0,''),(386089,122376,'116820','deals','border-right-color','$content-border-1',0,''),(386090,122376,'116820','deals','margin-right','-10',0,''),(386091,122376,'116820','deals','padding-right','30',0,''),(386092,122376,'116820','deals','padding-top','20',0,''),(386093,122376,'116820','deals','padding-left','30',0,''),(386094,122376,'116820','deals','padding-bottom','20',0,''),(386095,122376,'116820','deals','border-right-width','0',0,'5639'),(386096,122376,'116820','deals','margin-right','0',0,'5639'),(386097,122376,'116820','deals','margin-bottom','20',0,'5639'),(386098,122376,'116820','deals','padding-left','20',0,'5639'),(386099,122376,'116820','deals','padding-right','20',0,'5639'),(386100,122377,'116821','deals','link','shipping_address',0,''),(386101,122377,'116821','deals','float','right',0,''),(386102,122377,'116821','deals','margin-top','-31',0,''),(386103,122379,'116823','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(386104,122379,'116823','deals','clear','none',0,''),(386105,122380,'116824','deals','link','shipping_method',0,''),(386106,122380,'116824','deals','float','right',0,''),(386107,122380,'116824','deals','margin-top','-31',0,''),(386108,122381,'116825','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(386109,122381,'116825','deals','clear','none',0,''),(386110,122382,'116826','deals','margin-bottom','20',0,''),(386111,122383,'116827','deals','block_type','1',0,''),(386112,122383,'116827','deals','padding-left','30',0,''),(386113,122383,'116827','deals','border-left-width','20',0,''),(386114,122383,'116827','deals','border-left-color','$content-border-1',0,''),(386115,122383,'116827','deals','margin-left','-10',0,''),(386116,122383,'116827','deals','padding-right','30',0,''),(386117,122383,'116827','deals','padding-top','20',0,''),(386118,122383,'116827','deals','padding-bottom','20',0,''),(386119,122383,'116827','deals','border-left-width','0',0,'5639'),(386120,122386,'116830','deals','link','contact_information',0,''),(386121,122386,'116830','deals','margin-top','-31',0,''),(386122,122386,'116830','deals','float','right',0,''),(386123,122387,'116831','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(386124,122388,'116832','deals','block_type','1',0,''),(386125,122388,'116832','deals','padding-top','20',0,''),(386126,122388,'116832','deals','padding-left','20',0,''),(386127,122388,'116832','deals','padding-right','20',0,''),(386128,122388,'116832','deals','padding-bottom','20',0,''),(386129,122388,'116832','deals','background-color','$content-bg-1',0,''),(386130,122388,'116832','deals','style_class','order-summary',0,''),(386131,122389,'116833','deals','margin-bottom','20',0,''),(386132,122389,'116833','deals','text-align','right',0,''),(386133,122390,'116834','deals','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(386134,122391,'116835','deals','block_type','1',0,''),(386135,122391,'116835','deals','background-color','$content-bg-2',0,''),(386136,122391,'116835','deals','padding-bottom','30',0,''),(386137,122392,'116836','deals','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(386138,122393,'116837','deals','block_type','4',0,''),(386139,122394,'116838','deals','block_type','1',0,''),(386140,122394,'116838','deals','padding-right','40',0,''),(386141,122395,'116839','deals','block_type','2',0,''),(386142,122395,'116839','deals','margin-bottom','20',0,''),(386143,122395,'116839','deals','schema','2-2',0,'5630'),(386144,122395,'116839','deals','background-color','$content-bg-1',0,''),(386145,122396,'116840','deals','block_type','1',0,''),(386146,122396,'116840','deals','padding-right','0',0,'5630'),(386147,122396,'116840','deals','border-right-width','20',0,''),(386148,122396,'116840','deals','border-right-color','$content-border-1',0,''),(386149,122396,'116840','deals','margin-right','-10',0,''),(386150,122396,'116840','deals','padding-right','30',0,''),(386151,122396,'116840','deals','padding-top','20',0,''),(386152,122396,'116840','deals','padding-left','30',0,''),(386153,122396,'116840','deals','padding-bottom','20',0,''),(386154,122397,'116841','deals','link','contact_information',0,''),(386155,122397,'116841','deals','float','right',0,''),(386156,122398,'116842','deals','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(386157,122400,'116844','deals','block_type','1',0,''),(386158,122400,'116844','deals','padding-left','30',0,''),(386159,122400,'116844','deals','padding-left','0',0,'5630'),(386160,122400,'116844','deals','border-left-width','20',0,''),(386161,122400,'116844','deals','border-left-color','$content-border-1',0,''),(386162,122400,'116844','deals','margin-left','-10',0,''),(386163,122400,'116844','deals','padding-right','30',0,''),(386164,122400,'116844','deals','padding-top','20',0,''),(386165,122400,'116844','deals','padding-bottom','20',0,''),(386166,122402,'116846','deals','link','payment_method',0,''),(386167,122402,'116846','deals','float','right',0,''),(386168,122402,'116846','deals','margin-top','-31',0,''),(386169,122403,'116847','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(386170,122403,'116847','deals','clear','none',0,''),(386171,122404,'116848','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(386172,122405,'116849','deals','link','billing_address',0,''),(386173,122405,'116849','deals','float','right',0,''),(386174,122405,'116849','deals','margin-top','-31',0,''),(386175,122406,'116850','deals','margin-bottom','20',0,''),(386176,122407,'116851','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(386177,122407,'116851','deals','clear','none',0,''),(386178,122408,'116852','deals','block_type','1',0,''),(386179,122408,'116852','deals','background-color','$content-bg-1',0,''),(386180,122408,'116852','deals','padding-top','20',0,''),(386181,122408,'116852','deals','padding-bottom','20',0,''),(386182,122408,'116852','deals','padding-left','30',0,''),(386183,122408,'116852','deals','padding-right','30',0,''),(386184,122408,'116852','deals','margin-bottom','20',0,''),(386185,122409,'116853','deals','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(386186,122410,'116854','deals','hide_parents','2',0,''),(386187,122411,'116855','deals','float','right',0,''),(386188,122411,'116855','deals','margin-top','-37',0,''),(386189,122411,'116855','deals','link','comments',0,''),(386190,122412,'116856','deals','block_type','1',0,''),(386191,122412,'116856','deals','padding-right','30',0,''),(386192,122412,'116856','deals','padding-right','0',0,'5630'),(386193,122412,'116856','deals','background-color','$content-bg-1',0,''),(386194,122412,'116856','deals','padding-top','20',0,''),(386195,122412,'116856','deals','padding-left','30',0,''),(386196,122412,'116856','deals','padding-bottom','20',0,''),(386197,122413,'116857','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(386198,122414,'116858','deals','link','products',0,''),(386199,122414,'116858','deals','float','right',0,''),(386200,122414,'116858','deals','margin-top','-37',0,''),(386201,122416,'116860','deals','block_type','1',0,''),(386202,122416,'116860','deals','padding-top','20',0,''),(386203,122416,'116860','deals','padding-left','20',0,''),(386204,122416,'116860','deals','padding-right','20',0,''),(386205,122416,'116860','deals','padding-bottom','20',0,''),(386206,122416,'116860','deals','background-color','$content-bg-1',0,''),(386207,122416,'116860','deals','style_class','order-summary2 hiding-box',0,''),(386208,122417,'116861','deals','margin-bottom','20',0,''),(386209,122417,'116861','deals','text-align','right',0,''),(386210,122418,'116862','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(386211,122420,'116864','deals','block_type','1',0,''),(386212,122420,'116864','deals','background-color','$content-bg-2',0,''),(386213,122420,'116864','deals','padding-bottom','30',0,''),(386214,122421,'116865','deals','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(386215,122422,'116866','deals','block_type','4',0,''),(386216,122422,'116866','deals','schema','4-2',0,'5639'),(386217,122423,'116867','deals','block_type','1',0,''),(386218,122423,'116867','deals','padding-right','40',0,''),(386219,122423,'116867','deals','padding-right','0',0,'5639'),(386220,122424,'116868','deals','block_type','1',0,''),(386221,122424,'116868','deals','background-color','$content-bg-1',0,''),(386222,122424,'116868','deals','padding-top','20',0,''),(386223,122424,'116868','deals','padding-bottom','20',0,''),(386224,122424,'116868','deals','padding-left','30',0,''),(386225,122424,'116868','deals','padding-right','30',0,''),(386226,122424,'116868','deals','margin-bottom','20',0,''),(386227,122425,'116869','deals','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(386228,122426,'116870','deals','hide_parents','2',0,''),(386229,122427,'116871','deals','float','right',0,''),(386230,122427,'116871','deals','margin-top','-37',0,''),(386231,122427,'116871','deals','link','comments',0,''),(386232,122428,'116872','deals','block_type','2',0,''),(386233,122428,'116872','deals','margin-bottom','20',0,''),(386234,122428,'116872','deals','schema','2-2',0,'5630'),(386235,122428,'116872','deals','background-color','$content-bg-1',0,''),(386236,122429,'116873','deals','block_type','1',0,''),(386237,122429,'116873','deals','border-right-width','20',0,''),(386238,122429,'116873','deals','border-right-color','$content-border-1',0,''),(386239,122429,'116873','deals','margin-right','-10',0,''),(386240,122429,'116873','deals','padding-right','30',0,''),(386241,122429,'116873','deals','padding-top','20',0,''),(386242,122429,'116873','deals','padding-left','30',0,''),(386243,122429,'116873','deals','padding-bottom','20',0,''),(386244,122429,'116873','deals','border-right-width','0',0,'5639'),(386245,122429,'116873','deals','margin-right','0',0,'5639'),(386246,122429,'116873','deals','margin-bottom','20',0,'5639'),(386247,122429,'116873','deals','padding-left','20',0,'5639'),(386248,122429,'116873','deals','padding-right','20',0,'5639'),(386249,122430,'116874','deals','link','contact_information',0,''),(386250,122430,'116874','deals','margin-top','-31',0,''),(386251,122430,'116874','deals','float','right',0,''),(386252,122433,'116877','deals','link','payment_method',0,''),(386253,122433,'116877','deals','float','right',0,''),(386254,122433,'116877','deals','margin-top','-31',0,''),(386255,122434,'116878','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(386256,122434,'116878','deals','padding-top','20',0,''),(386257,122435,'116879','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(386258,122435,'116879','deals','clear','none',0,''),(386259,122436,'116880','deals','block_type','1',0,''),(386260,122436,'116880','deals','padding-left','30',0,''),(386261,122436,'116880','deals','border-left-width','20',0,''),(386262,122436,'116880','deals','border-left-color','$content-border-1',0,''),(386263,122436,'116880','deals','margin-left','-10',0,''),(386264,122436,'116880','deals','padding-right','30',0,''),(386265,122436,'116880','deals','padding-top','20',0,''),(386266,122436,'116880','deals','padding-bottom','20',0,''),(386267,122436,'116880','deals','border-left-width','0',0,'5639'),(386268,122437,'116881','deals','margin-bottom','20',0,''),(386269,122438,'116882','deals','link','billing_address',0,''),(386270,122438,'116882','deals','float','right',0,''),(386271,122438,'116882','deals','margin-top','-31',0,''),(386272,122439,'116883','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(386273,122439,'116883','deals','clear','none',0,''),(386274,122440,'116884','deals','block_type','1',0,''),(386275,122440,'116884','deals','padding-right','30',0,''),(386276,122440,'116884','deals','background-color','$content-bg-1',0,''),(386277,122440,'116884','deals','padding-top','20',0,''),(386278,122440,'116884','deals','padding-left','30',0,''),(386279,122440,'116884','deals','padding-bottom','20',0,''),(386280,122440,'116884','deals','padding-left','20',0,'5639'),(386281,122440,'116884','deals','padding-right','20',0,'5639'),(386282,122441,'116885','deals','link','products',0,''),(386283,122441,'116885','deals','float','right',0,''),(386284,122441,'116885','deals','margin-top','-37',0,''),(386285,122442,'116886','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(386286,122443,'116887','deals','margin-bottom','20',0,''),(386287,122444,'116888','deals','block_type','1',0,''),(386288,122444,'116888','deals','padding-top','20',0,''),(386289,122444,'116888','deals','padding-left','20',0,''),(386290,122444,'116888','deals','padding-right','20',0,''),(386291,122444,'116888','deals','padding-bottom','20',0,''),(386292,122444,'116888','deals','background-color','$content-bg-1',0,''),(386293,122444,'116888','deals','style_class','order-summary',0,''),(386294,122445,'116889','deals','margin-bottom','20',0,''),(386295,122445,'116889','deals','text-align','right',0,''),(386296,122447,'116891','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(386297,122448,'116892','deals','block_type','1',0,''),(386298,122448,'116892','deals','background-color','$content-bg-2',0,''),(386299,122448,'116892','deals','padding-bottom','30',0,''),(386300,122449,'116893','deals','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(386301,122450,'116894','deals','block_type','4',0,''),(386302,122450,'116894','deals','schema','4-2',0,'5639'),(386303,122451,'116895','deals','block_type','1',0,''),(386304,122451,'116895','deals','padding-right','40',0,''),(386305,122451,'116895','deals','padding-right','0',0,'5639'),(386306,122452,'116896','deals','block_type','1',0,''),(386307,122452,'116896','deals','padding-right','30',0,''),(386308,122452,'116896','deals','background-color','$content-bg-1',0,''),(386309,122452,'116896','deals','padding-top','20',0,''),(386310,122452,'116896','deals','padding-left','30',0,''),(386311,122452,'116896','deals','padding-bottom','20',0,''),(386312,122452,'116896','deals','padding-left','20',0,'5639'),(386313,122452,'116896','deals','padding-right','20',0,'5639'),(386314,122454,'116898','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(386315,122455,'116899','deals','link','products',0,''),(386316,122455,'116899','deals','float','right',0,''),(386317,122455,'116899','deals','margin-top','-37',0,''),(386318,122456,'116900','deals','block_type','2',0,''),(386319,122456,'116900','deals','margin-bottom','20',0,''),(386320,122456,'116900','deals','schema','2-2',0,'5630'),(386321,122456,'116900','deals','background-color','$content-bg-1',0,''),(386322,122457,'116901','deals','block_type','1',0,''),(386323,122457,'116901','deals','border-right-width','20',0,''),(386324,122457,'116901','deals','border-right-color','$content-border-1',0,''),(386325,122457,'116901','deals','margin-right','-10',0,''),(386326,122457,'116901','deals','padding-right','30',0,''),(386327,122457,'116901','deals','padding-top','20',0,''),(386328,122457,'116901','deals','padding-left','30',0,''),(386329,122457,'116901','deals','padding-bottom','20',0,''),(386330,122457,'116901','deals','border-right-width','0',0,'5639'),(386331,122457,'116901','deals','margin-right','0',0,'5639'),(386332,122457,'116901','deals','margin-bottom','20',0,'5639'),(386333,122457,'116901','deals','padding-left','20',0,'5639'),(386334,122457,'116901','deals','padding-right','20',0,'5639'),(386335,122458,'116902','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(386336,122459,'116903','deals','link','contact_information',0,''),(386337,122459,'116903','deals','margin-top','-31',0,''),(386338,122459,'116903','deals','float','right',0,''),(386339,122460,'116904','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(386340,122460,'116904','deals','clear','none',0,''),(386341,122462,'116906','deals','margin-bottom','20',0,''),(386342,122464,'116908','deals','link','shipping_address',0,''),(386343,122464,'116908','deals','float','right',0,''),(386344,122464,'116908','deals','margin-top','-31',0,''),(386345,122466,'116910','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(386346,122466,'116910','deals','padding-top','20',0,''),(386347,122467,'116911','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(386348,122467,'116911','deals','clear','none',0,''),(386349,122468,'116912','deals','link','shipping_method',0,''),(386350,122468,'116912','deals','float','right',0,''),(386351,122468,'116912','deals','margin-top','-31',0,''),(386352,122469,'116913','deals','block_type','1',0,''),(386353,122469,'116913','deals','padding-left','30',0,''),(386354,122469,'116913','deals','border-left-width','20',0,''),(386355,122469,'116913','deals','border-left-color','$content-border-1',0,''),(386356,122469,'116913','deals','margin-left','-10',0,''),(386357,122469,'116913','deals','padding-right','30',0,''),(386358,122469,'116913','deals','padding-top','20',0,''),(386359,122469,'116913','deals','padding-bottom','20',0,''),(386360,122469,'116913','deals','border-left-width','0',0,'5639'),(386361,122470,'116914','deals','link','billing_address',0,''),(386362,122470,'116914','deals','float','right',0,''),(386363,122470,'116914','deals','margin-top','-31',0,''),(386364,122471,'116915','deals','margin-bottom','20',0,''),(386365,122473,'116917','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(386366,122474,'116918','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(386367,122474,'116918','deals','clear','none',0,''),(386368,122475,'116919','deals','link','payment_method',0,''),(386369,122475,'116919','deals','float','right',0,''),(386370,122475,'116919','deals','margin-top','-31',0,''),(386371,122476,'116920','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(386372,122476,'116920','deals','clear','none',0,''),(386373,122477,'116921','deals','block_type','1',0,''),(386374,122477,'116921','deals','background-color','$content-bg-1',0,''),(386375,122477,'116921','deals','padding-top','20',0,''),(386376,122477,'116921','deals','padding-bottom','20',0,''),(386377,122477,'116921','deals','padding-left','30',0,''),(386378,122477,'116921','deals','padding-right','30',0,''),(386379,122477,'116921','deals','margin-bottom','20',0,''),(386380,122478,'116922','deals','hide_parents','2',0,''),(386381,122479,'116923','deals','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(386382,122480,'116924','deals','float','right',0,''),(386383,122480,'116924','deals','margin-top','-37',0,''),(386384,122480,'116924','deals','link','comments',0,''),(386385,122481,'116925','deals','block_type','1',0,''),(386386,122481,'116925','deals','padding-top','20',0,''),(386387,122481,'116925','deals','padding-left','20',0,''),(386388,122481,'116925','deals','padding-right','20',0,''),(386389,122481,'116925','deals','padding-bottom','20',0,''),(386390,122481,'116925','deals','background-color','$content-bg-1',0,''),(386391,122481,'116925','deals','style_class','order-summary',0,''),(386392,122482,'116926','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(386393,122484,'116928','deals','margin-bottom','20',0,''),(386394,122484,'116928','deals','text-align','right',0,''),(386395,122485,'116929','deals','block_type','1',0,''),(386396,122485,'116929','deals','background-color','$content-bg-2',0,''),(386397,122485,'116929','deals','padding-bottom','30',0,''),(386398,122486,'116930','deals','block_type','4',0,''),(386399,122486,'116930','deals','schema','4-2',0,'5639'),(386400,122487,'116931','deals','block_type','1',0,''),(386401,122487,'116931','deals','padding-right','40',0,''),(386402,122487,'116931','deals','padding-right','0',0,'5639'),(386403,122488,'116932','deals','block_type','2',0,''),(386404,122488,'116932','deals','margin-bottom','20',0,''),(386405,122488,'116932','deals','schema','2-2',0,'5630'),(386406,122488,'116932','deals','background-color','$content-bg-1',0,''),(386407,122489,'116933','deals','block_type','1',0,''),(386408,122489,'116933','deals','border-right-width','20',0,''),(386409,122489,'116933','deals','border-right-color','$content-border-1',0,''),(386410,122489,'116933','deals','margin-right','-10',0,''),(386411,122489,'116933','deals','padding-right','30',0,''),(386412,122489,'116933','deals','padding-top','20',0,''),(386413,122489,'116933','deals','padding-left','30',0,''),(386414,122489,'116933','deals','padding-bottom','20',0,''),(386415,122489,'116933','deals','border-right-width','0',0,'5639'),(386416,122489,'116933','deals','margin-right','0',0,'5639'),(386417,122489,'116933','deals','margin-bottom','20',0,'5639'),(386418,122489,'116933','deals','padding-left','20',0,'5639'),(386419,122489,'116933','deals','padding-right','20',0,'5639'),(386420,122490,'116934','deals','margin-bottom','20',0,''),(386421,122491,'116935','deals','link','shipping_address',0,''),(386422,122491,'116935','deals','float','right',0,''),(386423,122491,'116935','deals','margin-top','-31',0,''),(386424,122492,'116936','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(386425,122492,'116936','deals','clear','none',0,''),(386426,122495,'116939','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(386427,122496,'116940','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(386428,122496,'116940','deals','clear','none',0,''),(386429,122497,'116941','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(386430,122497,'116941','deals','padding-top','20',0,''),(386431,122499,'116943','deals','link','shipping_method',0,''),(386432,122499,'116943','deals','float','right',0,''),(386433,122499,'116943','deals','margin-top','-31',0,''),(386434,122500,'116944','deals','link','contact_information',0,''),(386435,122500,'116944','deals','margin-top','-31',0,''),(386436,122500,'116944','deals','float','right',0,''),(386437,122501,'116945','deals','block_type','1',0,''),(386438,122501,'116945','deals','padding-left','30',0,''),(386439,122501,'116945','deals','border-left-width','20',0,''),(386440,122501,'116945','deals','border-left-color','$content-border-1',0,''),(386441,122501,'116945','deals','margin-left','-10',0,''),(386442,122501,'116945','deals','padding-right','30',0,''),(386443,122501,'116945','deals','padding-top','20',0,''),(386444,122501,'116945','deals','padding-bottom','20',0,''),(386445,122501,'116945','deals','border-left-width','0',0,'5639'),(386446,122502,'116946','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(386447,122502,'116946','deals','clear','none',0,''),(386448,122503,'116947','deals','margin-bottom','20',0,''),(386449,122504,'116948','deals','link','billing_address',0,''),(386450,122504,'116948','deals','float','right',0,''),(386451,122504,'116948','deals','margin-top','-31',0,''),(386452,122506,'116950','deals','link','payment_method',0,''),(386453,122506,'116950','deals','float','right',0,''),(386454,122506,'116950','deals','margin-top','-31',0,''),(386455,122507,'116951','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(386456,122508,'116952','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(386457,122508,'116952','deals','clear','none',0,''),(386458,122509,'116953','deals','block_type','1',0,''),(386459,122509,'116953','deals','padding-right','30',0,''),(386460,122509,'116953','deals','background-color','$content-bg-1',0,''),(386461,122509,'116953','deals','padding-top','20',0,''),(386462,122509,'116953','deals','padding-left','30',0,''),(386463,122509,'116953','deals','padding-bottom','20',0,''),(386464,122509,'116953','deals','padding-left','20',0,'5639'),(386465,122509,'116953','deals','padding-right','20',0,'5639'),(386466,122510,'116954','deals','link','products',0,''),(386467,122510,'116954','deals','float','right',0,''),(386468,122510,'116954','deals','margin-top','-37',0,''),(386469,122511,'116955','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(386470,122513,'116957','deals','block_type','1',0,''),(386471,122513,'116957','deals','background-color','$content-bg-1',0,''),(386472,122513,'116957','deals','padding-top','20',0,''),(386473,122513,'116957','deals','padding-bottom','20',0,''),(386474,122513,'116957','deals','padding-left','30',0,''),(386475,122513,'116957','deals','padding-right','30',0,''),(386476,122513,'116957','deals','margin-bottom','20',0,''),(386477,122514,'116958','deals','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(386478,122515,'116959','deals','float','right',0,''),(386479,122515,'116959','deals','margin-top','-37',0,''),(386480,122515,'116959','deals','link','comments',0,''),(386481,122516,'116960','deals','hide_parents','2',0,''),(386482,122517,'116961','deals','block_type','1',0,''),(386483,122517,'116961','deals','padding-top','20',0,''),(386484,122517,'116961','deals','padding-left','20',0,''),(386485,122517,'116961','deals','padding-right','20',0,''),(386486,122517,'116961','deals','padding-bottom','20',0,''),(386487,122517,'116961','deals','background-color','$content-bg-1',0,''),(386488,122517,'116961','deals','style_class','order-summary',0,''),(386489,122519,'116963','deals','margin-bottom','20',0,''),(386490,122519,'116963','deals','text-align','right',0,''),(386491,122520,'116964','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(386492,122521,'116965','deals','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(386493,122522,'116966','deals','block_type','1',0,''),(386494,122524,'116968','deals','block_type','2',0,''),(386495,122524,'116968','deals','font-weight','400',0,''),(386496,122524,'116968','deals','padding-bottom','20',0,''),(386497,122524,'116968','deals','schema','2-2',0,'5639'),(386498,122525,'116969','deals','show_captcha','on',0,''),(386499,122526,'116970','deals','font-weight','400',0,''),(386500,122526,'116970','deals','padding-left','40',0,''),(386501,122526,'116970','deals','time_format','24',0,''),(386502,122526,'116970','deals','show_icons','on',0,''),(386503,122526,'116970','deals','padding-left','0',0,'5639'),(386504,122527,'116971','deals','block_type','1',0,''),(386505,122528,'116972','deals','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(386506,122529,'116973','deals','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(386507,122529,'116973','deals','margin-bottom','40',0,''),(386508,122530,'116102.000001','deals','block_type','1',0,''),(386509,122531,'116103.000001','deals','block_type','6',0,''),(386510,122531,'116103.000001','deals','schema','6-3',0,'5639'),(386511,122532,'116104.000001','deals','aria_name','account-menu',0,''),(386575,122552,'116109.000001','deals','text','<h1>##CREDIT_AMOUNT_HISTORY##</h1>',0,''),(386576,122553,'1638895944','deals','margin-bottom','20',0,''),(386577,122554,'116974','deals','width','680',0,''),(386578,122554,'116974','deals','font-weight','normal',0,''),(386579,122554,'116974','deals','font-size','12',0,''),(386580,122554,'116974','deals','padding-top','20',0,''),(386581,122554,'116974','deals','padding-bottom','20',0,''),(386582,122554,'116974','deals','color','$content-color-1',0,''),(386583,122555,'116975','deals','block_type','3',0,''),(386584,122555,'116975','deals','font-weight','normal',0,''),(386585,122555,'116975','deals','padding-top','20',0,''),(386586,122556,'116976','deals','font-size','12',0,''),(386587,122557,'116977','deals','text','<p>If undelivered please return to:</p>',1,''),(386588,122557,'116977','deals','font-size','12',0,''),(386589,122557,'116977','deals','font-weight','bold',0,''),(386590,122557,'116977','deals','text','<p>If undelivered please return to:</p>',2,''),(386591,122557,'116977','deals','text','<p>If undelivered please return to:</p>',3,''),(386592,122557,'116977','deals','text','<p>If undelivered please return to:</p>',4,''),(386593,122558,'116978','deals','text','<p>Thank you for your order</p>',1,''),(386594,122558,'116978','deals','color','$hileght-color-1',0,''),(386595,122558,'116978','deals','font-size','13',0,''),(386596,122558,'116978','deals','font-weight','bold',0,''),(386597,122558,'116978','deals','padding-top','5',0,''),(386598,122558,'116978','deals','text-align','center',0,''),(386599,122558,'116978','deals','text','<p>Thank you for your order</p>',2,''),(386600,122558,'116978','deals','text','<p>Thank you for your order</p>',3,''),(386601,122558,'116978','deals','text','<p>Thank you for your order</p>',4,''),(386602,122559,'116979','deals','font-weight','400',0,''),(386603,122559,'116979','deals','text-align','center',0,''),(386604,122559,'116979','deals','padding-top','0',0,''),(386606,122559,'116979','deals','padding-left','20',0,''),(386607,122559,'116979','deals','padding-right','20',0,''),(386611,122560,'116980','deals','text','<p>If something has gone wrong please contact us at:</p>',1,''),(386612,122560,'116980','deals','font-size','12',0,''),(386613,122560,'116980','deals','font-weight','bold',0,''),(386614,122560,'116980','deals','text-align','right',0,''),(386615,122560,'116980','deals','text','<p>If something has gone wrong please contact us at:</p>',2,''),(386616,122560,'116980','deals','text','<p>If something has gone wrong please contact us at:</p>',3,''),(386617,122560,'116980','deals','text','<p>If something has gone wrong please contact us at:</p>',4,''),(386618,122561,'116981','deals','block_type','6',0,''),(386619,122561,'116981','deals','font-weight','normal',0,''),(386620,122561,'116981','deals','font-size','16',0,''),(386621,122562,'116982','deals','text','<p>Email:</p>',1,''),(386622,122562,'116982','deals','font-weight','normal',0,''),(386623,122562,'116982','deals','text-align','right',0,''),(386624,122562,'116982','deals','font-size','12',0,''),(386625,122562,'116982','deals','text','<p>Email:</p>',2,''),(386626,122562,'116982','deals','text','<p>Email:</p>',3,''),(386627,122562,'116982','deals','text','<p>Email:</p>',4,''),(386628,122563,'116983','deals','font-weight','normal',0,''),(386629,122563,'116983','deals','text-align','right',0,''),(386630,122563,'116983','deals','font-size','12',0,''),(386631,122564,'116984','deals','block_type','6',0,''),(386632,122564,'116984','deals','font-weight','normal',0,''),(386633,122564,'116984','deals','font-size','16',0,''),(386634,122565,'116985','deals','text','<p>Phone:</p>',1,''),(386635,122565,'116985','deals','font-weight','normal',0,''),(386636,122565,'116985','deals','text-align','right',0,''),(386637,122565,'116985','deals','font-size','12',0,''),(386638,122565,'116985','deals','text','<p>Phone:</p>',2,''),(386639,122565,'116985','deals','text','<p>Phone:</p>',3,''),(386640,122565,'116985','deals','text','<p>Phone:</p>',4,''),(386641,122566,'116986','deals','font-weight','normal',0,''),(386642,122566,'116986','deals','text-align','right',0,''),(386643,122566,'116986','deals','font-size','12',0,''),(386644,122567,'116987','deals','font-weight','400',0,''),(386645,122567,'116987','deals','padding-top','20',0,''),(386646,122567,'116987','deals','padding-bottom','0',0,''),(386647,122567,'116987','deals','font-size','12',0,''),(386648,122568,'116988','deals','block_type','2',0,''),(386649,122568,'116988','deals','font-weight','normal',0,''),(386650,122568,'116988','deals','padding-bottom','20',0,''),(386651,122569,'116989','deals','font-weight','400',0,''),(386652,122569,'116989','deals','padding-top','20',0,''),(386657,122570,'116990','deals','block_type','11',0,''),(386658,122570,'116990','deals','font-weight','normal',0,''),(386659,122571,'116991','deals','text','<p>Web:</p>',1,''),(386660,122571,'116991','deals','font-weight','normal',0,''),(386661,122571,'116991','deals','text-align','right',0,''),(386662,122571,'116991','deals','text','<p>Web:</p>',2,''),(386663,122571,'116991','deals','text','<p>Web:</p>',3,''),(386664,122571,'116991','deals','text','<p>Web:</p>',4,''),(386665,122572,'116992','deals','font-weight','normal',0,''),(386666,122572,'116992','deals','text-align','right',0,''),(386667,122573,'116993','deals','block_type','11',0,''),(386668,122573,'116993','deals','font-weight','normal',0,''),(386669,122574,'116994','deals','text','<p>Phone:</p>',1,''),(386670,122574,'116994','deals','font-weight','normal',0,''),(386671,122574,'116994','deals','text-align','right',0,''),(386672,122574,'116994','deals','text','<p>Phone:</p>',2,''),(386673,122574,'116994','deals','text','<p>Phone:</p>',3,''),(386674,122574,'116994','deals','text','<p>Phone:</p>',4,''),(386675,122575,'116995','deals','font-weight','normal',0,''),(386676,122575,'116995','deals','text-align','right',0,''),(386677,122576,'116996','deals','block_type','11',0,''),(386678,122576,'116996','deals','font-weight','normal',0,''),(386679,122577,'116997','deals','text','<p>Email:</p>',1,''),(386680,122577,'116997','deals','font-weight','normal',0,''),(386681,122577,'116997','deals','text-align','right',0,''),(386682,122577,'116997','deals','text','<p>Email:</p>',2,''),(386683,122577,'116997','deals','text','<p>Email:</p>',3,''),(386684,122577,'116997','deals','text','<p>Email:</p>',4,''),(386685,122578,'116998','deals','font-weight','normal',0,''),(386686,122578,'116998','deals','text-align','right',0,''),(386687,122579,'116999','deals','block_type','1',0,''),(386688,122580,'117000','deals','font-weight','normal',0,''),(386689,122580,'117000','deals','text-align','right',0,''),(386690,122580,'117000','deals','padding-bottom','10',0,''),(386691,122580,'117000','deals','address_spacer',',',0,''),(386692,122580,'117000','deals','font-size','12',0,''),(386693,122581,'117001','deals','block_type','5',0,''),(386694,122581,'117001','deals','font-weight','normal',0,''),(386695,122581,'117001','deals','border-bottom-width','1',0,''),(386696,122581,'117001','deals','border-bottom-color','$content-border-1',0,''),(386697,122581,'117001','deals','border-top-width','1',0,''),(386698,122581,'117001','deals','border-top-color','$content-border-1',0,''),(386699,122581,'117001','deals','border-left-color','$content-border-1',0,''),(386700,122581,'117001','deals','border-left-width','1',0,''),(386701,122582,'117002','deals','block_type','1',0,''),(386702,122582,'117002','deals','font-weight','normal',0,''),(386703,122582,'117002','deals','padding-top','10',0,''),(386704,122582,'117002','deals','padding-left','10',0,''),(386705,122582,'117002','deals','padding-right','10',0,''),(386706,122583,'117003','deals','font-weight','400',0,''),(386707,122583,'117003','deals','line-height','120',0,''),(386708,122583,'117003','deals','line_height_measure','%',0,''),(386709,122583,'117003','deals','font-size','12',0,''),(386710,122584,'117004','deals','text','<p>SHIPPING ADDRESS:</p>',1,''),(386711,122584,'117004','deals','font-size','14',0,''),(386712,122584,'117004','deals','font-weight','bold',0,''),(386713,122584,'117004','deals','padding-bottom','10',0,''),(386714,122584,'117004','deals','text','<p>SHIPPING ADDRESS:</p>',2,''),(386715,122584,'117004','deals','text','<p>SHIPPING ADDRESS:</p>',3,''),(386716,122584,'117004','deals','text','<p>SHIPPING ADDRESS:</p>',4,''),(386717,122585,'117005','deals','block_type','1',0,''),(386718,122585,'117005','deals','background-color','$content-bg-2',0,''),(386719,122585,'117005','deals','padding-top','20',0,''),(386720,122585,'117005','deals','padding-left','10',0,''),(386721,122585,'117005','deals','padding-right','10',0,''),(386722,122585,'117005','deals','padding-bottom','20',0,''),(386723,122585,'117005','deals','font-size','14',0,''),(386724,122586,'117006','deals','block_type','4',0,''),(386725,122586,'117006','deals','font-weight','normal',0,''),(386726,122586,'117006','deals','border-top-width','1',0,''),(386727,122586,'117006','deals','border-top-color','$content-border-1',0,''),(386728,122586,'117006','deals','border-left-width','1',0,''),(386729,122586,'117006','deals','border-left-color','$content-border-1',0,''),(386730,122586,'117006','deals','border-right-width','1',0,''),(386731,122586,'117006','deals','border-right-color','$content-border-1',0,''),(386732,122586,'117006','deals','border-bottom-width','1',0,''),(386733,122586,'117006','deals','border-bottom-color','$content-border-1',0,''),(386734,122587,'117007','deals','block_type','2',0,''),(386735,122587,'117007','deals','font-weight','normal',0,''),(386736,122587,'117007','deals','border-right-width','1',0,''),(386737,122587,'117007','deals','border-right-color','$content-border-1',0,''),(386738,122588,'117008','deals','block_type','1',0,''),(386739,122588,'117008','deals','font-weight','400',0,''),(386740,122588,'117008','deals','background-color','$content-bg-2',0,''),(386741,122588,'117008','deals','padding-top','10',0,''),(386742,122588,'117008','deals','padding-left','10',0,''),(386743,122588,'117008','deals','padding-right','10',0,''),(386744,122588,'117008','deals','padding-bottom','30',0,''),(386745,122589,'117009','deals','text','<p>INVOICE ADDRESS:</p>',1,''),(386746,122589,'117009','deals','font-size','14',0,''),(386747,122589,'117009','deals','font-weight','bold',0,''),(386748,122589,'117009','deals','text','<p>INVOICE ADDRESS:</p>',2,''),(386749,122589,'117009','deals','text','<p>INVOICE ADDRESS:</p>',3,''),(386750,122589,'117009','deals','text','<p>INVOICE ADDRESS:</p>',4,''),(386751,122590,'117010','deals','font-size','12',0,''),(386752,122591,'117011','deals','block_type','1',0,''),(386753,122591,'117011','deals','font-weight','normal',0,''),(386754,122591,'117011','deals','padding-top','10',0,''),(386755,122591,'117011','deals','padding-left','10',0,''),(386756,122591,'117011','deals','padding-right','10',0,''),(386757,122591,'117011','deals','padding-bottom','10',0,''),(386758,122592,'117012','deals','font-weight','normal',0,''),(386759,122593,'117013','deals','text','<p>CUSTOMER:</p>',1,''),(386760,122593,'117013','deals','font-size','13',0,''),(386761,122593,'117013','deals','font-weight','bold',0,''),(386762,122593,'117013','deals','text','<p>CUSTOMER:</p>',2,''),(386763,122593,'117013','deals','text','<p>CUSTOMER:</p>',3,''),(386764,122593,'117013','deals','text','<p>CUSTOMER:</p>',4,''),(386765,122594,'117014','deals','text','<p>PHONE NUMBER:</p>',1,''),(386766,122594,'117014','deals','font-size','14',0,''),(386767,122594,'117014','deals','font-weight','bold',0,''),(386768,122594,'117014','deals','padding-top','10',0,''),(386769,122594,'117014','deals','text','<p>PHONE NUMBER:</p>',2,''),(386770,122594,'117014','deals','text','<p>PHONE NUMBER:</p>',3,''),(386771,122594,'117014','deals','text','<p>PHONE NUMBER:</p>',4,''),(386772,122595,'117015','deals','font-weight','normal',0,''),(386773,122597,'117017','deals','text','<p>E-MAIL ADDRESS:</p>',1,''),(386774,122597,'117017','deals','font-weight','bold',0,''),(386775,122597,'117017','deals','font-size','14',0,''),(386776,122597,'117017','deals','padding-top','10',0,''),(386777,122597,'117017','deals','text','<p>E-MAIL ADDRESS:</p>',2,''),(386778,122597,'117017','deals','text','<p>E-MAIL ADDRESS:</p>',3,''),(386779,122597,'117017','deals','text','<p>E-MAIL ADDRESS:</p>',4,''),(386780,122598,'117018','deals','block_type','2',0,''),(386781,122598,'117018','deals','font-weight','normal',0,''),(386782,122598,'117018','deals','border-top-width','1',0,''),(386783,122598,'117018','deals','border-top-color','$content-border-1',0,''),(386784,122598,'117018','deals','border-right-width','1',0,''),(386785,122598,'117018','deals','border-right-color','$content-border-1',0,''),(386786,122599,'117019','deals','block_type','1',0,''),(386787,122599,'117019','deals','font-weight','normal',0,''),(386788,122599,'117019','deals','padding-top','10',0,''),(386789,122599,'117019','deals','padding-left','10',0,''),(386790,122599,'117019','deals','padding-right','10',0,''),(386791,122599,'117019','deals','padding-bottom','10',0,''),(386792,122599,'117019','deals','border-right-width','1',0,''),(386793,122599,'117019','deals','border-right-color','$content-border-1',0,''),(386794,122601,'117021','deals','text','<p>Shipping via</p>',1,''),(386795,122601,'117021','deals','font-weight','bold',0,''),(386796,122601,'117021','deals','font-size','14',0,''),(386797,122601,'117021','deals','text','<p>Shipping via</p>',2,''),(386798,122601,'117021','deals','text','<p>Shipping via</p>',3,''),(386799,122601,'117021','deals','text','<p>Shipping via</p>',4,''),(386800,122602,'117022','deals','block_type','1',0,''),(386801,122602,'117022','deals','font-weight','normal',0,''),(386802,122602,'117022','deals','padding-top','10',0,''),(386803,122602,'117022','deals','padding-left','10',0,''),(386804,122602,'117022','deals','padding-right','10',0,''),(386805,122602,'117022','deals','padding-bottom','10',0,''),(386806,122603,'117023','deals','text','<p>Shipping service</p>',1,''),(386807,122603,'117023','deals','font-weight','bold',0,''),(386808,122603,'117023','deals','font-size','14',0,''),(386809,122603,'117023','deals','text','<p>Shipping service</p>',2,''),(386810,122603,'117023','deals','text','<p>Shipping service</p>',3,''),(386811,122603,'117023','deals','text','<p>Shipping service</p>',4,''),(386812,122605,'117025','deals','font-size','14',0,''),(386813,122605,'117025','deals','font-weight','bold',0,''),(386814,122605,'117025','deals','text-align','center',0,''),(386815,122605,'117025','deals','padding-bottom','10',0,''),(386816,122605,'117025','deals','padding-top','10',0,''),(386817,122606,'117026','deals','text','<p>Payment date:</p>',1,''),(386818,122606,'117026','deals','font-weight','bold',0,''),(386819,122606,'117026','deals','text-align','center',0,''),(386820,122606,'117026','deals','font-size','12',0,''),(386821,122606,'117026','deals','text','<p>Payment date:</p>',2,''),(386822,122606,'117026','deals','text','<p>Payment date:</p>',3,''),(386823,122606,'117026','deals','text','<p>Payment date:</p>',4,''),(386824,122607,'117027','deals','font-weight','normal',0,''),(386825,122607,'117027','deals','text-align','center',0,''),(386826,122607,'117027','deals','padding-bottom','10',0,''),(386827,122608,'117034','deals','text-align','center',0,''),(386828,122608,'117034','deals','padding-top','10',0,''),(386829,122609,'1639155816','deals','block_type','1',0,''),(386830,122610,'117028','deals','padding-top','30',0,''),(386831,122610,'117028','deals','padding-bottom','30',0,''),(386832,122614,'117032','deals','col_in_row','4',0,''),(386833,122614,'117032','deals','listing_type','productListing',0,''),(386834,122614,'117032','deals','view_as','carousel',0,''),(386835,122614,'117032','deals','col_in_row','3',0,'5639'),(386836,122614,'117032','deals','col_in_row','2',0,'5630'),(386837,122614,'117032','deals','col_in_row','1',0,'5660'),(386838,122616,'1639485067','deals','padding-top','30',0,''),(386839,122616,'1639485067','deals','padding-bottom','30',0,''),(386840,122618,'1639154415','deals','block_type','1',0,''),(386841,122620,'117036','deals','heading_type','h1',0,''),(386842,122621,'1639419797','deals','page_id','4',0,''),(386843,122621,'1639419797','deals','padding-top','30',0,''),(386844,122621,'1639419797','deals','padding-bottom','30',0,''),(386845,122624,'117039','deals','text-align','center',0,''),(386846,122624,'117039','deals','padding-top','10',0,''),(386847,122629,'117044','deals','block_type','1',0,''),(386848,122630,'117045','deals','block_type','1',0,''),(386849,122630,'117045','deals','max-width','800',0,''),(386850,122630,'117045','deals','margin','0 auto',0,''),(386851,122630,'117045','deals','background-color','$content-bg-1',0,''),(386852,122631,'117046','deals','color','$content-color-1',0,''),(386853,122631,'117046','deals','font-size','12',0,''),(386854,122631,'117046','deals','padding-top','20',0,''),(386855,122631,'117046','deals','padding-bottom','20',0,''),(386856,122631,'117046','deals','border-top-width','1',0,''),(386857,122631,'117046','deals','border-top-color','$content-border-1',0,''),(386858,122632,'117047','deals','font-weight','normal',0,''),(386859,122632,'117047','deals','padding-top','20',0,''),(386860,122632,'117047','deals','padding-left','10',0,''),(386861,122632,'117047','deals','padding-right','10',0,''),(386862,122632,'117047','deals','padding-bottom','20',0,''),(386863,122632,'117047','deals','color','$content-color-1',0,''),(386864,122632,'117047','deals','font-size','14',0,''),(386865,122633,'117048','deals','block_type','7',0,''),(386866,122633,'117048','deals','font-weight','normal',0,''),(386867,122633,'117048','deals','background-color','$highlight-box-bg-2',0,''),(386868,122633,'117048','deals','padding-top','5',0,''),(386869,122633,'117048','deals','padding-left','10',0,''),(386870,122633,'117048','deals','padding-right','10',0,''),(386871,122633,'117048','deals','padding-bottom','5',0,''),(386872,122634,'117049','deals','color','$highlight-box-color-2',0,''),(386873,122634,'117049','deals','font-size','14',0,''),(386874,122634,'117049','deals','font-weight','normal',0,''),(386875,122635,'117050','deals','font-weight','normal',0,''),(386876,122635,'117050','deals','text-align','right',0,''),(386877,122635,'117050','deals','color','$highlight-box-color-2',0,''),(386878,122635,'117050','deals','font-size','12',0,''),(386879,122636,'117051','deals','font-weight','normal',0,''),(386880,122636,'117051','deals','padding-bottom','10',0,''),(386881,122636,'117051','deals','padding-top','10',0,''),(386882,122636,'117051','deals','logo_from','theme',0,''),(386883,122636,'117051','deals','padding-left','20',0,''),(386884,122637,'117052','deals','block_type','1',0,''),(386885,122638,'117053','deals','block_type','1',0,''),(386886,122638,'117053','deals','max-width','800',0,''),(386887,122638,'117053','deals','margin','0 auto',0,''),(386888,122638,'117053','deals','background-color','$content-bg-1',0,''),(386889,122639,'117054','deals','color','$content-color-1',0,''),(386890,122639,'117054','deals','font-size','12',0,''),(386891,122639,'117054','deals','padding-top','20',0,''),(386892,122639,'117054','deals','padding-bottom','20',0,''),(386893,122639,'117054','deals','border-top-width','1',0,''),(386894,122639,'117054','deals','border-top-color','$content-border-1',0,''),(386895,122640,'117055','deals','font-weight','normal',0,''),(386896,122640,'117055','deals','padding-bottom','10',0,''),(386897,122640,'117055','deals','logo','themes/deals/img/logo-2.png',1,''),(386898,122640,'117055','deals','padding-left','20',0,''),(386899,122640,'117055','deals','padding-top','10',0,''),(386900,122640,'117055','deals','logo','themes/deals/img/logo-2.png',2,''),(386901,122640,'117055','deals','logo','themes/deals/img/logo-2.png',3,''),(386902,122640,'117055','deals','logo','themes/deals/img/logo-2.png',4,''),(386903,122641,'117056','deals','font-weight','normal',0,''),(386904,122641,'117056','deals','padding-top','20',0,''),(386905,122641,'117056','deals','padding-left','10',0,''),(386906,122641,'117056','deals','padding-right','10',0,''),(386907,122641,'117056','deals','padding-bottom','20',0,''),(386908,122641,'117056','deals','color','$content-color-1',0,''),(386909,122641,'117056','deals','font-size','14',0,''),(386910,122642,'117057','deals','block_type','7',0,''),(386911,122642,'117057','deals','font-weight','normal',0,''),(386912,122642,'117057','deals','background-color','$highlight-box-bg-1',0,''),(386913,122642,'117057','deals','padding-top','5',0,''),(386914,122642,'117057','deals','padding-left','10',0,''),(386915,122642,'117057','deals','padding-right','10',0,''),(386916,122642,'117057','deals','padding-bottom','5',0,''),(386917,122643,'117058','deals','color','$highlight-box-color-1',0,''),(386918,122643,'117058','deals','font-size','15',0,''),(386919,122643,'117058','deals','font-weight','700',0,''),(386920,122644,'117059','deals','font-weight','normal',0,''),(386921,122644,'117059','deals','text-align','right',0,''),(386922,122644,'117059','deals','color','$highlight-box-color-1',0,''),(386923,122644,'117059','deals','font-size','12',0,''),(386924,122645,'117060','deals','block_type','1',0,''),(386925,122645,'117060','deals','background-color','$content-bg-2',0,''),(386926,122646,'117061','deals','block_type','1',0,''),(386927,122646,'117061','deals','max-width','800',0,''),(386928,122646,'117061','deals','margin','0 auto',0,''),(386929,122647,'117062','deals','block_type','1',0,''),(386930,122647,'117062','deals','background-color','$content-bg-1',0,''),(386931,122647,'117062','deals','padding-top','20',0,''),(386932,122647,'117062','deals','padding-left','20',0,''),(386933,122647,'117062','deals','padding-right','20',0,''),(386934,122647,'117062','deals','padding-bottom','20',0,''),(386935,122648,'117063','deals','font-weight','normal',0,''),(386936,122648,'117063','deals','padding-top','20',0,''),(386937,122648,'117063','deals','padding-bottom','20',0,''),(386938,122648,'117063','deals','color','$content-color-1',0,''),(386939,122648,'117063','deals','font-size','14',0,''),(386940,122649,'117064','deals','block_type','7',0,''),(386941,122649,'117064','deals','font-weight','normal',0,''),(386942,122649,'117064','deals','padding-left','10',0,''),(386943,122649,'117064','deals','padding-right','10',0,''),(386944,122649,'117064','deals','padding-bottom','15',0,''),(386945,122649,'117064','deals','border-bottom-width','1',0,''),(386946,122649,'117064','deals','border-bottom-color','$content-border-1',0,''),(386947,122650,'117065','deals','color','$content-color-1',0,''),(386948,122650,'117065','deals','font-size','14',0,''),(386949,122650,'117065','deals','font-weight','700',0,''),(386950,122651,'117066','deals','font-weight','normal',0,''),(386951,122651,'117066','deals','text-align','right',0,''),(386952,122651,'117066','deals','color','$fade-color-1',0,''),(386953,122651,'117066','deals','font-size','11',0,''),(386954,122651,'117066','deals','text-transform','uppercase',0,''),(386955,122652,'117067','deals','color','$fade-color-1',0,''),(386956,122652,'117067','deals','font-size','12',0,''),(386957,122652,'117067','deals','padding-top','20',0,''),(386958,122652,'117067','deals','padding-bottom','20',0,''),(386959,122652,'117067','deals','text-align','center',0,''),(386960,122653,'117068','deals','font-weight','normal',0,''),(386961,122653,'117068','deals','padding-bottom','10',0,''),(386962,122653,'117068','deals','padding-top','10',0,''),(386963,122653,'117068','deals','text-align','center',0,''),(386964,122653,'117068','deals','logo_from','theme',0,''),(386965,122654,'117069','deals','block_type','1',0,''),(386966,122654,'117069','deals','background-color','$content-bg-2',0,''),(386967,122654,'117069','deals','padding-top','20',0,''),(386968,122654,'117069','deals','padding-bottom','20',0,''),(386969,122655,'117070','deals','block_type','1',0,''),(386970,122655,'117070','deals','max-width','800',0,''),(386971,122655,'117070','deals','margin','0 auto',0,''),(386972,122656,'117071','deals','color','$fade-color-1',0,''),(386973,122656,'117071','deals','font-size','12',0,''),(386974,122656,'117071','deals','padding-top','20',0,''),(386975,122656,'117071','deals','padding-bottom','20',0,''),(386976,122656,'117071','deals','text-align','left',0,''),(386977,122657,'117072','deals','block_type','1',0,''),(386978,122657,'117072','deals','background-color','$content-bg-1',0,''),(386979,122657,'117072','deals','padding-top','20',0,''),(386980,122657,'117072','deals','padding-left','20',0,''),(386981,122657,'117072','deals','padding-right','20',0,''),(386982,122657,'117072','deals','padding-bottom','20',0,''),(386983,122657,'117072','deals','border-top-width','1',0,''),(386984,122657,'117072','deals','border-left-width','1',0,''),(386985,122657,'117072','deals','border-right-width','1',0,''),(386986,122657,'117072','deals','border-bottom-width','1',0,''),(386987,122657,'117072','deals','border-top-color','$content-border-1',0,''),(386988,122657,'117072','deals','border-left-color','$content-border-1',0,''),(386989,122657,'117072','deals','border-bottom-color','$content-border-1',0,''),(386990,122657,'117072','deals','border-right-color','$content-border-1',0,''),(386991,122658,'117073','deals','block_type','2',0,''),(386992,122659,'117074','deals','font-weight','normal',0,''),(386993,122659,'117074','deals','padding-bottom','10',0,''),(386994,122659,'117074','deals','padding-top','10',0,''),(386995,122659,'117074','deals','logo_from','theme',0,''),(386996,122660,'117075','deals','font-weight','normal',0,''),(386997,122660,'117075','deals','text-align','right',0,''),(386998,122660,'117075','deals','color','$fade-color-1',0,''),(386999,122660,'117075','deals','font-size','11',0,''),(387000,122660,'117075','deals','text-transform','uppercase',0,''),(387001,122661,'117076','deals','color','$content-color-1',0,''),(387002,122661,'117076','deals','font-size','14',0,''),(387003,122661,'117076','deals','font-weight','700',0,''),(387004,122661,'117076','deals','text-align','right',0,''),(387005,122662,'117077','deals','font-weight','normal',0,''),(387006,122662,'117077','deals','padding-top','20',0,''),(387007,122662,'117077','deals','padding-bottom','20',0,''),(387008,122662,'117077','deals','color','$content-color-1',0,''),(387009,122662,'117077','deals','font-size','14',0,''),(387010,122663,'121029','deals','block_type','1',0,''),(387011,122666,'121032','deals','margin-bottom','30',0,''),(387012,122667,'121025','deals','block_type','1',0,''),(387013,122668,'121026','deals','text','<h1>CATALOGUE</h1>',0,''),(387014,122670,'117078','deals','block_type','1',0,''),(387015,122670,'117078','deals','font-weight','normal',0,''),(387016,122670,'117078','deals','padding-top','20',0,''),(387017,122670,'117078','deals','style_class','preFooter',0,''),(387018,122670,'117078','deals','padding-bottom','25',0,''),(387019,122670,'117078','deals','background-color','$footer-bg-1',0,''),(387020,122670,'117078','deals','color','$footer-color-1',0,''),(387021,122671,'120872','deals','banners_group','payment',0,''),(387022,122671,'120872','deals','float','none',0,''),(387023,122671,'120872','deals','padding-top','15',0,''),(387024,122671,'120872','deals','clear','none',0,''),(387025,122671,'120872','deals','margin-bottom','20',0,''),(387026,122671,'120872','deals','text-align','center',0,''),(387027,122672,'117094','deals','color','$footer-color-3',0,''),(387028,122672,'117094','deals','text-align','center',0,''),(387029,122672,'117094','deals','font-size','14',0,''),(387030,122673,'1641484988','deals','block_type','2',0,''),(387031,122673,'1641484988','deals','schema','2-2',0,'5639'),(387032,122674,'117085','deals','class','menu-style-2',0,''),(387033,122674,'117085','deals','type','builder',0,''),(387034,122674,'117085','deals','style','3',0,''),(387035,122674,'117085','deals','lev2_vis','click',0,'5630'),(387036,122674,'117085','deals','style_class','footer-menu',0,''),(387037,122675,'117091','deals','view_item','data_format',0,''),(387038,122675,'117091','deals','address_spacer',',<span> </span>',0,''),(387039,122675,'117091','deals','color','$footer-color-2',0,''),(387040,122675,'117091','deals','add_link_on_phone','1',0,''),(387041,122675,'117091','deals','data_format_content','<div>Registered address</div>\n##COMPANY##\n##STREET_ADDRESS##\n##CITY##\n##STATE##\n\n',0,''),(387042,122675,'117091','deals','margin-top','20',0,'5630'),(387043,122675,'117091','deals','float','right',0,''),(387044,122675,'117091','deals','max-width','170',0,''),(387045,122675,'117091','deals','margin-bottom','20',0,''),(387046,122675,'117091','deals','float','none',0,'5639'),(387047,122675,'117091','deals','padding-top','20',0,'5639'),(387048,122676,'120868','deals','logo_from','theme',0,''),(387049,122676,'120868','deals','margin-bottom','25',0,''),(387050,122676,'120868','deals','padding-right','20',0,''),(387051,122676,'120868','deals','display_none','1',0,'5630'),(387052,122676,'120868','deals','text-align','right',0,''),(387053,122676,'120868','deals','clear','both',0,''),(387054,122676,'120868','deals','text-align','left',0,'5639'),(387055,122677,'117096','deals','block_type','5',0,''),(387056,122678,'117097','deals','text','##TEXT_LANGUAGE##',0,''),(387057,122680,'117099','deals','block_type','5',0,''),(387058,122681,'117100','deals','text','##TEXT_CURRENCY##',0,''),(387059,122683,'117102','deals','block_type','1',0,''),(387060,122683,'117102','deals','font-weight','normal',0,''),(387061,122684,'117103','deals','block_type','2',0,''),(387062,122684,'117103','deals','font-weight','normal',0,''),(387063,122684,'117103','deals','padding-bottom','20',0,''),(387064,122685,'117104','deals','block_type','1',0,''),(387065,122685,'117104','deals','margin-right','20',0,''),(387066,122688,'117107','deals','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(387067,122688,'117107','deals','font-weight','normal',0,''),(387068,122688,'117107','deals','padding-bottom','20',0,''),(387069,122688,'117107','deals','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(387070,122688,'117107','deals','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(387071,122688,'117107','deals','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(387072,122690,'117109','deals','block_type','1',0,''),(387073,122690,'117109','deals','font-weight','normal',0,''),(387074,122690,'117109','deals','style_class','gift-card-view',0,''),(387075,122690,'117109','deals','text-align','center',0,''),(387076,122690,'117109','deals','padding-bottom','20',0,''),(387077,122690,'117109','deals','padding-left','20',0,''),(387078,122690,'117109','deals','padding-right','20',0,''),(387079,122691,'117110','deals','block_type','1',0,''),(387080,122691,'117110','deals','font-weight','normal',0,''),(387081,122691,'117110','deals','padding-top','10',0,''),(387082,122692,'117111','deals','font-size','12',0,''),(387083,122692,'117111','deals','font-weight','bold',0,''),(387084,122692,'117111','deals','text-align','center',0,''),(387085,122692,'117111','deals','style_class','email',0,''),(387086,122693,'117112','deals','text','<p>If you require further assistance please contact us</p>',1,''),(387087,122693,'117112','deals','font-weight','normal',0,''),(387088,122693,'117112','deals','text-align','center',0,''),(387089,122693,'117112','deals','font-size','12',0,''),(387090,122693,'117112','deals','padding-top','10',0,''),(387091,122693,'117112','deals','padding-bottom','5',0,''),(387092,122693,'117112','deals','border-top-width','1',0,''),(387093,122693,'117112','deals','border-top-color','$content-border-1',0,''),(387094,122693,'117112','deals','text','<p>If you require further assistance please contact us</p>',2,''),(387095,122693,'117112','deals','text','<p>If you require further assistance please contact us</p>',3,''),(387096,122693,'117112','deals','text','<p>If you require further assistance please contact us</p>',4,''),(387097,122694,'117113','deals','font-size','12',0,''),(387098,122694,'117113','deals','font-weight','bold',0,''),(387099,122694,'117113','deals','text-align','center',0,''),(387100,122694,'117113','deals','style_class','phone',0,''),(387101,122694,'117113','deals','padding-bottom','5',0,''),(387102,122695,'117114','deals','text','<p>WHAT TO DO NEXT:</p>',1,''),(387103,122695,'117114','deals','font-weight','normal',0,''),(387104,122695,'117114','deals','text-align','center',0,''),(387105,122695,'117114','deals','padding-top','20',0,''),(387106,122695,'117114','deals','padding-bottom','10',0,''),(387107,122695,'117114','deals','style_class','question-ico',0,''),(387108,122695,'117114','deals','border-top-width','1',0,''),(387109,122695,'117114','deals','border-top-color','$content-border-1',0,''),(387110,122695,'117114','deals','font-size','18',0,''),(387111,122695,'117114','deals','text','<p>WHAT TO DO NEXT:</p>',2,''),(387112,122695,'117114','deals','text','<p>WHAT TO DO NEXT:</p>',3,''),(387113,122695,'117114','deals','text','<p>WHAT TO DO NEXT:</p>',4,''),(387114,122696,'117115','deals','text','<p>osCommerce</p>\n',1,''),(387115,122696,'117115','deals','font-family','$font-2',0,''),(387116,122696,'117115','deals','font-size','24',0,''),(387117,122696,'117115','deals','font-weight','normal',0,''),(387118,122696,'117115','deals','text-align','center',0,''),(387119,122696,'117115','deals','padding-top','10',0,''),(387120,122696,'117115','deals','padding-bottom','20',0,''),(387121,122696,'117115','deals','text','<p>osCommerce</p>\n',2,''),(387122,122696,'117115','deals','text','<p>osCommerce</p>\n',3,''),(387123,122696,'117115','deals','text','<p>osCommerce</p>\n',4,''),(387124,122697,'117116','deals','block_type','4',0,''),(387125,122697,'117116','deals','font-size','30',0,''),(387126,122697,'117116','deals','font-weight','normal',0,''),(387127,122697,'117116','deals','padding-top','5',0,''),(387128,122697,'117116','deals','padding-left','10',0,''),(387129,122697,'117116','deals','padding-right','10',0,''),(387130,122697,'117116','deals','padding-bottom','5',0,''),(387131,122697,'117116','deals','border-top-width','2',0,''),(387132,122697,'117116','deals','border-left-width','2',0,''),(387133,122697,'117116','deals','border-right-width','2',0,''),(387134,122697,'117116','deals','border-bottom-width','2',0,''),(387135,122697,'117116','deals','border-top-color','$highlight-box-border-2',0,''),(387136,122697,'117116','deals','border-left-color','$highlight-box-border-2',0,''),(387137,122697,'117116','deals','border-right-color','$highlight-box-border-2',0,''),(387138,122697,'117116','deals','border-bottom-color','$highlight-box-border-2',0,''),(387139,122698,'117117','deals','text','<p>Your code is:</p>',1,''),(387140,122698,'117117','deals','font-weight','normal',0,''),(387141,122698,'117117','deals','text','<p>Your code is:</p>',2,''),(387142,122698,'117117','deals','text','<p>Your code is:</p>',3,''),(387143,122698,'117117','deals','text','<p>Your code is:</p>',4,''),(387144,122700,'117119','deals','font-weight','normal',0,''),(387145,122700,'117119','deals','text-align','center',0,''),(387146,122700,'117119','deals','padding-bottom','20',0,''),(387147,122701,'117120','deals','font-size','60',0,''),(387148,122701,'117120','deals','font-weight','bold',0,''),(387149,122701,'117120','deals','text-align','center',0,''),(387150,122701,'117120','deals','line-height','100',0,''),(387151,122701,'117120','deals','padding-bottom','20',0,''),(387152,122701,'117120','deals','line_height_measure','px',0,''),(387153,122702,'117121','deals','text','<p>PERSONAL MESSAGE</p>',1,''),(387154,122702,'117121','deals','font-size','18',0,''),(387155,122702,'117121','deals','font-weight','normal',0,''),(387156,122702,'117121','deals','text-align','center',0,''),(387157,122702,'117121','deals','padding-top','20',0,''),(387158,122702,'117121','deals','padding-bottom','10',0,''),(387159,122702,'117121','deals','border-top-width','1',0,''),(387160,122702,'117121','deals','border-top-color','$content-border-1',0,''),(387161,122702,'117121','deals','text','<p>PERSONAL MESSAGE</p>',2,''),(387162,122702,'117121','deals','text','<p>PERSONAL MESSAGE</p>',3,''),(387163,122702,'117121','deals','text','<p>PERSONAL MESSAGE</p>',4,''),(387164,122703,'117123','deals','logo','themes/deals/img/Logo.jpg',1,''),(387165,122703,'117123','deals','logo_from','theme',0,''),(387166,122703,'117123','deals','padding-top','20',0,''),(387167,122703,'117123','deals','text-align','center',0,''),(387168,122703,'117123','deals','logo','themes/deals/img/Logo.jpg',2,''),(387169,122703,'117123','deals','logo','themes/deals/img/Logo.jpg',3,''),(387170,122703,'117123','deals','logo','themes/deals/img/Logo.jpg',4,''),(387171,122704,'117124','deals','text','<p>GIFT CARD</p>',1,''),(387172,122704,'117124','deals','font-size','30',0,''),(387173,122704,'117124','deals','font-weight','normal',0,''),(387174,122704,'117124','deals','border-top-width','1',0,''),(387175,122704,'117124','deals','border-top-color','$content-border-1',0,''),(387176,122704,'117124','deals','style_class','gift-ico',0,''),(387177,122704,'117124','deals','text-align','center',0,''),(387178,122704,'117124','deals','padding-top','15',0,''),(387179,122704,'117124','deals','text','<p>GIFT CARD</p>',2,''),(387180,122704,'117124','deals','text','<p>GIFT CARD</p>',3,''),(387181,122704,'117124','deals','text','<p>GIFT CARD</p>',4,''),(387182,122705,'117125','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(387183,122705,'117125','deals','font-weight','normal',0,''),(387184,122705,'117125','deals','text-align','center',0,''),(387185,122705,'117125','deals','padding-bottom','10',0,''),(387186,122705,'117125','deals','font-size','14',0,''),(387187,122705,'117125','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(387188,122705,'117125','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(387189,122705,'117125','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(387190,122706,'117126','deals','block_type','1',0,''),(387191,122706,'117126','deals','font-weight','normal',0,''),(387192,122706,'117126','deals','style_class','gift-card-view',0,''),(387193,122706,'117126','deals','text-align','center',0,''),(387194,122706,'117126','deals','padding-bottom','20',0,''),(387195,122706,'117126','deals','background-color','$highlight-box-bg-1',0,''),(387196,122706,'117126','deals','padding-left','20',0,''),(387197,122706,'117126','deals','padding-right','20',0,''),(387198,122706,'117126','deals','color','$highlight-box-color-1',0,''),(387199,122707,'117127','deals','font-size','60',0,''),(387200,122707,'117127','deals','font-weight','bold',0,''),(387201,122707,'117127','deals','text-align','center',0,''),(387202,122707,'117127','deals','line-height','100',0,''),(387203,122707,'117127','deals','padding-bottom','20',0,''),(387204,122707,'117127','deals','line_height_measure','px',0,''),(387205,122708,'117128','deals','block_type','4',0,''),(387206,122708,'117128','deals','color','$highlight-box-color-2',0,''),(387207,122708,'117128','deals','font-size','30',0,''),(387208,122708,'117128','deals','font-weight','normal',0,''),(387209,122708,'117128','deals','background-color','$highlight-box-bg-2',0,''),(387210,122708,'117128','deals','padding-top','5',0,''),(387211,122708,'117128','deals','padding-left','10',0,''),(387212,122708,'117128','deals','padding-right','10',0,''),(387213,122708,'117128','deals','padding-bottom','5',0,''),(387214,122709,'117129','deals','text','<p>Your code is:</p>',1,''),(387215,122709,'117129','deals','font-weight','normal',0,''),(387216,122709,'117129','deals','text','<p>Your code is:</p>',2,''),(387217,122709,'117129','deals','text','<p>Your code is:</p>',3,''),(387218,122709,'117129','deals','text','<p>Your code is:</p>',4,''),(387219,122711,'117131','deals','block_type','1',0,''),(387220,122711,'117131','deals','font-weight','normal',0,''),(387221,122711,'117131','deals','padding-top','10',0,''),(387222,122712,'117132','deals','font-size','12',0,''),(387223,122712,'117132','deals','font-weight','bold',0,''),(387224,122712,'117132','deals','text-align','center',0,''),(387225,122712,'117132','deals','style_class','email',0,''),(387226,122713,'117133','deals','text','<p>If you require further assistance please contact us</p>',1,''),(387227,122713,'117133','deals','font-weight','normal',0,''),(387228,122713,'117133','deals','text-align','center',0,''),(387229,122713,'117133','deals','font-size','12',0,''),(387230,122713,'117133','deals','padding-top','10',0,''),(387231,122713,'117133','deals','padding-bottom','5',0,''),(387232,122713,'117133','deals','border-top-width','1',0,''),(387233,122713,'117133','deals','border-top-color','$warning-border',0,''),(387234,122713,'117133','deals','text','<p>If you require further assistance please contact us</p>',2,''),(387235,122713,'117133','deals','text','<p>If you require further assistance please contact us</p>',3,''),(387236,122713,'117133','deals','text','<p>If you require further assistance please contact us</p>',4,''),(387237,122714,'117134','deals','font-size','12',0,''),(387238,122714,'117134','deals','font-weight','bold',0,''),(387239,122714,'117134','deals','text-align','center',0,''),(387240,122714,'117134','deals','style_class','phone',0,''),(387241,122714,'117134','deals','padding-bottom','5',0,''),(387242,122715,'117135','deals','font-weight','normal',0,''),(387243,122715,'117135','deals','text-align','center',0,''),(387244,122715,'117135','deals','padding-bottom','20',0,''),(387245,122716,'117136','deals','text','<p>PERSONAL MESSAGE</p>',1,''),(387246,122716,'117136','deals','font-size','18',0,''),(387247,122716,'117136','deals','font-weight','normal',0,''),(387248,122716,'117136','deals','text-align','center',0,''),(387249,122716,'117136','deals','padding-top','20',0,''),(387250,122716,'117136','deals','padding-bottom','10',0,''),(387251,122716,'117136','deals','border-top-width','1',0,''),(387252,122716,'117136','deals','border-top-color','$warning-border',0,''),(387253,122716,'117136','deals','text','<p>PERSONAL MESSAGE</p>',2,''),(387254,122716,'117136','deals','text','<p>PERSONAL MESSAGE</p>',3,''),(387255,122716,'117136','deals','text','<p>PERSONAL MESSAGE</p>',4,''),(387256,122717,'117137','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(387257,122717,'117137','deals','font-weight','normal',0,''),(387258,122717,'117137','deals','text-align','center',0,''),(387259,122717,'117137','deals','padding-bottom','10',0,''),(387260,122717,'117137','deals','font-size','14',0,''),(387261,122717,'117137','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(387262,122717,'117137','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(387263,122717,'117137','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(387264,122718,'117138','deals','text','<p>GIFT CARD</p>',1,''),(387265,122718,'117138','deals','font-size','30',0,''),(387266,122718,'117138','deals','font-weight','normal',0,''),(387267,122718,'117138','deals','border-top-width','1',0,''),(387268,122718,'117138','deals','border-top-color','$warning-border',0,''),(387269,122718,'117138','deals','style_class','gift-ico',0,''),(387270,122718,'117138','deals','text-align','center',0,''),(387271,122718,'117138','deals','padding-top','15',0,''),(387272,122718,'117138','deals','text','<p>GIFT CARD</p>',2,''),(387273,122718,'117138','deals','text','<p>GIFT CARD</p>',3,''),(387274,122718,'117138','deals','text','<p>GIFT CARD</p>',4,''),(387275,122719,'117139','deals','text','<p>WHAT TO DO NEXT:</p>',1,''),(387276,122719,'117139','deals','font-weight','normal',0,''),(387277,122719,'117139','deals','text-align','center',0,''),(387278,122719,'117139','deals','padding-top','20',0,''),(387279,122719,'117139','deals','padding-bottom','10',0,''),(387280,122719,'117139','deals','style_class','question-ico',0,''),(387281,122719,'117139','deals','border-top-width','1',0,''),(387282,122719,'117139','deals','border-top-color','$warning-border',0,''),(387283,122719,'117139','deals','font-size','18',0,''),(387284,122719,'117139','deals','text','<p>WHAT TO DO NEXT:</p>',2,''),(387285,122719,'117139','deals','text','<p>WHAT TO DO NEXT:</p>',3,''),(387286,122719,'117139','deals','text','<p>WHAT TO DO NEXT:</p>',4,''),(387287,122720,'1638804282','deals','logo_from','theme',0,''),(387288,122720,'1638804282','deals','padding-top','20',0,''),(387289,122720,'1638804282','deals','text-align','center',0,''),(387290,122720,'1638804282','deals','padding-bottom','20',0,''),(387291,122721,'117141','deals','block_type','1',0,''),(387292,122721,'117141','deals','font-weight','normal',0,''),(387293,122721,'117141','deals','style_class','gift-card-view',0,''),(387294,122721,'117141','deals','text-align','center',0,''),(387295,122721,'117141','deals','padding-bottom','20',0,''),(387296,122721,'117141','deals','background-color','$highlight-box-bg-1',0,''),(387297,122721,'117141','deals','padding-left','20',0,''),(387298,122721,'117141','deals','padding-right','20',0,''),(387299,122721,'117141','deals','color','$highlight-box-color-1',0,''),(387300,122722,'117142','deals','block_type','1',0,''),(387301,122722,'117142','deals','font-weight','normal',0,''),(387302,122722,'117142','deals','padding-top','10',0,''),(387303,122723,'117143','deals','font-size','12',0,''),(387304,122723,'117143','deals','font-weight','bold',0,''),(387305,122723,'117143','deals','text-align','center',0,''),(387306,122723,'117143','deals','style_class','email',0,''),(387307,122723,'117143','deals','color','$highlight-box-color-1',0,''),(387308,122724,'117144','deals','font-size','12',0,''),(387309,122724,'117144','deals','font-weight','bold',0,''),(387310,122724,'117144','deals','text-align','center',0,''),(387311,122724,'117144','deals','style_class','phone',0,''),(387312,122724,'117144','deals','padding-bottom','5',0,''),(387313,122724,'117144','deals','color','$highlight-box-color-1',0,''),(387314,122725,'117145','deals','text','If you require further assistance please contact us',0,''),(387315,122725,'117145','deals','font-size','12',0,''),(387316,122725,'117145','deals','color','$highlight-box-color-1',0,''),(387317,122725,'117145','deals','text-align','center',0,''),(387318,122725,'117145','deals','padding-top','10',0,''),(387319,122726,'117146','deals','block_type','4',0,''),(387320,122726,'117146','deals','color','$highlight-box-color-2',0,''),(387321,122726,'117146','deals','font-size','30',0,''),(387322,122726,'117146','deals','font-weight','normal',0,''),(387323,122726,'117146','deals','background-color','$highlight-box-bg-2',0,''),(387324,122726,'117146','deals','padding-top','5',0,''),(387325,122726,'117146','deals','padding-left','10',0,''),(387326,122726,'117146','deals','padding-right','10',0,''),(387327,122726,'117146','deals','padding-bottom','5',0,''),(387328,122727,'117147','deals','text','Your code is:',0,''),(387329,122727,'117147','deals','font-size','30',0,''),(387330,122727,'117147','deals','color','$highlight-box-color-2',0,''),(387331,122728,'117148','deals','color','$highlight-box-color-2',0,''),(387332,122728,'117148','deals','font-size','30',0,''),(387333,122729,'117149','deals','block_type','1',0,''),(387334,122730,'117150','deals','text','<p>PERSONAL MESSAGE</p>',1,''),(387335,122730,'117150','deals','font-size','18',0,''),(387336,122730,'117150','deals','font-weight','normal',0,''),(387337,122730,'117150','deals','text-align','center',0,''),(387338,122730,'117150','deals','padding-top','20',0,''),(387339,122730,'117150','deals','padding-bottom','10',0,''),(387340,122730,'117150','deals','border-top-width','1',0,''),(387341,122730,'117150','deals','border-top-color','$warning-border',0,''),(387342,122730,'117150','deals','text','<p>PERSONAL MESSAGE</p>',2,''),(387343,122730,'117150','deals','text','<p>PERSONAL MESSAGE</p>',3,''),(387344,122730,'117150','deals','text','<p>PERSONAL MESSAGE</p>',4,''),(387345,122730,'117150','deals','color','$highlight-box-color-1',0,''),(387346,122731,'117151','deals','text','HOLBI',0,''),(387347,122731,'117151','deals','color','$highlight-box-color-1',0,''),(387348,122731,'117151','deals','font-size','24',0,''),(387349,122731,'117151','deals','padding-top','20',0,''),(387350,122731,'117151','deals','text-align','center',0,''),(387351,122731,'117151','deals','padding-bottom','20',0,''),(387352,122732,'117152','deals','border-top-color','$warning-border',0,''),(387353,122732,'117152','deals','border-top-width','1',0,''),(387354,122732,'117152','deals','padding-top','20',0,''),(387355,122732,'117152','deals','font-size','30',0,''),(387356,122732,'117152','deals','text-align','center',0,''),(387357,122732,'117152','deals','color','$highlight-box-color-1',0,''),(387358,122732,'117152','deals','text','GIFT CARD',0,''),(387359,122733,'117153','deals','text-align','center',0,''),(387360,122733,'117153','deals','font-weight','bold',0,''),(387361,122733,'117153','deals','font-size','60',0,''),(387362,122733,'117153','deals','color','$highlight-box-color-1',0,''),(387363,122734,'117154','deals','font-size','20',0,''),(387364,122734,'117154','deals','text-align','center',0,''),(387365,122734,'117154','deals','color','$highlight-box-color-1',0,''),(387366,122734,'117154','deals','padding-top','20',0,''),(387367,122734,'117154','deals','padding-bottom','20',0,''),(387368,122735,'117155','deals','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(387369,122735,'117155','deals','text-align','center',0,''),(387370,122735,'117155','deals','color','$highlight-box-color-1',0,''),(387371,122735,'117155','deals','font-size','14',0,''),(387372,122735,'117155','deals','padding-bottom','20',0,''),(387373,122736,'117156','deals','text','WHAT TO DO NEXT:',0,''),(387374,122736,'117156','deals','font-size','18',0,''),(387375,122736,'117156','deals','text-align','center',0,''),(387376,122736,'117156','deals','color','$highlight-box-color-1',0,''),(387377,122736,'117156','deals','padding-top','20',0,''),(387378,122736,'117156','deals','padding-bottom','10',0,''),(387379,122736,'117156','deals','border-top-width','1',0,''),(387380,122736,'117156','deals','border-top-color','$warning-border',0,''),(387381,122737,'117158','deals','block_type','1',0,''),(387382,122737,'117158','deals','font-weight','normal',0,''),(387383,122737,'117158','deals','style_class','gift-card-view',0,''),(387384,122737,'117158','deals','text-align','center',0,''),(387385,122737,'117158','deals','padding-bottom','20',0,''),(387386,122737,'117158','deals','padding-left','20',0,''),(387387,122737,'117158','deals','padding-right','20',0,''),(387388,122737,'117158','deals','color','$fade-color-2',0,''),(387389,122738,'117159','deals','block_type','1',0,''),(387390,122738,'117159','deals','font-weight','normal',0,''),(387391,122738,'117159','deals','padding-top','10',0,''),(387392,122739,'117160','deals','font-size','12',0,''),(387393,122739,'117160','deals','font-weight','bold',0,''),(387394,122739,'117160','deals','text-align','center',0,''),(387395,122739,'117160','deals','style_class','email',0,''),(387396,122739,'117160','deals','color','$content-color-1',0,''),(387397,122740,'117161','deals','font-size','12',0,''),(387398,122740,'117161','deals','font-weight','bold',0,''),(387399,122740,'117161','deals','text-align','center',0,''),(387400,122740,'117161','deals','style_class','phone',0,''),(387401,122740,'117161','deals','padding-bottom','5',0,''),(387402,122740,'117161','deals','color','$content-color-1',0,''),(387403,122741,'117162','deals','text','If you require further assistance please contact us',0,''),(387404,122741,'117162','deals','font-size','12',0,''),(387405,122741,'117162','deals','color','$content-color-1',0,''),(387406,122741,'117162','deals','text-align','center',0,''),(387407,122741,'117162','deals','padding-top','10',0,''),(387408,122742,'117163','deals','block_type','2',0,''),(387409,122742,'117163','deals','color','$highlight-box-color-2',0,''),(387410,122742,'117163','deals','font-size','30',0,''),(387411,122742,'117163','deals','font-weight','normal',0,''),(387412,122742,'117163','deals','background-color','$highlight-box-bg-2',0,''),(387413,122742,'117163','deals','padding-top','5',0,''),(387414,122742,'117163','deals','padding-left','10',0,''),(387415,122742,'117163','deals','padding-right','10',0,''),(387416,122742,'117163','deals','padding-bottom','5',0,''),(387417,122743,'117164','deals','text','Your code is:',0,''),(387418,122743,'117164','deals','font-size','30',0,''),(387419,122743,'117164','deals','color','$highlight-box-color-2',0,''),(387420,122744,'117165','deals','color','$highlight-box-color-2',0,''),(387421,122744,'117165','deals','font-size','30',0,''),(387422,122745,'117166','deals','block_type','1',0,''),(387423,122746,'117167','deals','text','<p>PERSONAL MESSAGE</p>',1,''),(387424,122746,'117167','deals','font-size','18',0,''),(387425,122746,'117167','deals','font-weight','normal',0,''),(387426,122746,'117167','deals','text-align','center',0,''),(387427,122746,'117167','deals','padding-top','20',0,''),(387428,122746,'117167','deals','padding-bottom','10',0,''),(387429,122746,'117167','deals','border-top-width','1',0,''),(387430,122746,'117167','deals','border-top-color','$content-border-1',0,''),(387431,122746,'117167','deals','color','$content-color-1',0,''),(387432,122746,'117167','deals','text','<p>PERSONAL MESSAGE</p>',2,''),(387433,122746,'117167','deals','text','<p>PERSONAL MESSAGE</p>',3,''),(387434,122746,'117167','deals','text','<p>PERSONAL MESSAGE</p>',4,''),(387435,122747,'117169','deals','border-top-color','$content-border-1',0,''),(387436,122747,'117169','deals','border-top-width','1',0,''),(387437,122747,'117169','deals','padding-top','20',0,''),(387438,122747,'117169','deals','font-size','30',0,''),(387439,122747,'117169','deals','text-align','center',0,''),(387440,122747,'117169','deals','color','$content-color-1',0,''),(387441,122747,'117169','deals','text','GIFT CARD',0,''),(387442,122748,'117170','deals','text-align','center',0,''),(387443,122748,'117170','deals','font-weight','bold',0,''),(387444,122748,'117170','deals','font-size','60',0,''),(387445,122748,'117170','deals','color','$content-color-1',0,''),(387446,122749,'117171','deals','font-size','20',0,''),(387447,122749,'117171','deals','text-align','center',0,''),(387448,122749,'117171','deals','color','$content-color-1',0,''),(387449,122749,'117171','deals','padding-top','20',0,''),(387450,122749,'117171','deals','padding-bottom','20',0,''),(387451,122750,'117172','deals','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(387452,122750,'117172','deals','text-align','center',0,''),(387453,122750,'117172','deals','color','$content-color-1',0,''),(387454,122750,'117172','deals','font-size','14',0,''),(387455,122750,'117172','deals','padding-bottom','20',0,''),(387456,122751,'117173','deals','text','WHAT TO DO NEXT:',0,''),(387457,122751,'117173','deals','font-size','18',0,''),(387458,122751,'117173','deals','text-align','center',0,''),(387459,122751,'117173','deals','color','$content-color-1',0,''),(387460,122751,'117173','deals','padding-top','20',0,''),(387461,122751,'117173','deals','padding-bottom','10',0,''),(387462,122751,'117173','deals','border-top-width','1',0,''),(387463,122751,'117173','deals','border-top-color','$content-border-1',0,''),(387464,122752,'1638978695','deals','logo_from','theme',0,''),(387465,122752,'1638978695','deals','text-align','center',0,''),(387466,122752,'1638978695','deals','padding-top','20',0,''),(387467,122752,'1638978695','deals','padding-bottom','20',0,''),(387468,122753,'117175','deals','block_type','1',0,''),(387469,122753,'117175','deals','padding-left','20',0,''),(387470,122753,'117175','deals','padding-right','20',0,''),(387471,122753,'117175','deals','padding-bottom','20',0,''),(387472,122755,'117177','deals','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(387473,122755,'117177','deals','text-align','center',0,''),(387474,122756,'117178','deals','block_type','1',0,''),(387475,122756,'117178','deals','font-weight','normal',0,''),(387476,122756,'117178','deals','style_class','gift-card-view',0,''),(387477,122756,'117178','deals','text-align','center',0,''),(387478,122756,'117178','deals','padding-bottom','20',0,''),(387479,122756,'117178','deals','background-color','$highlight-box-bg-4',0,''),(387480,122756,'117178','deals','padding-left','20',0,''),(387481,122756,'117178','deals','padding-right','20',0,''),(387482,122756,'117178','deals','color','$highlight-box-color-4',0,''),(387483,122757,'117179','deals','block_type','4',0,''),(387484,122757,'117179','deals','color','$highlight-box-color-2',0,''),(387485,122757,'117179','deals','font-size','30',0,''),(387486,122757,'117179','deals','font-weight','normal',0,''),(387487,122757,'117179','deals','background-color','$highlight-box-bg-2',0,''),(387488,122757,'117179','deals','padding-top','5',0,''),(387489,122757,'117179','deals','padding-left','10',0,''),(387490,122757,'117179','deals','padding-right','10',0,''),(387491,122757,'117179','deals','padding-bottom','5',0,''),(387492,122758,'117180','deals','text','<p>Your code is:</p>',1,''),(387493,122758,'117180','deals','font-weight','normal',0,''),(387494,122758,'117180','deals','text','<p>Your code is:</p>',2,''),(387495,122758,'117180','deals','text','<p>Your code is:</p>',3,''),(387496,122758,'117180','deals','text','<p>Your code is:</p>',4,''),(387497,122760,'117182','deals','text','<p>WHAT TO DO NEXT:</p>',1,''),(387498,122760,'117182','deals','font-weight','normal',0,''),(387499,122760,'117182','deals','text-align','center',0,''),(387500,122760,'117182','deals','padding-top','20',0,''),(387501,122760,'117182','deals','padding-bottom','10',0,''),(387502,122760,'117182','deals','style_class','question-ico',0,''),(387503,122760,'117182','deals','border-top-width','1',0,''),(387504,122760,'117182','deals','border-top-color','$warning-border',0,''),(387505,122760,'117182','deals','font-size','18',0,''),(387506,122760,'117182','deals','text','<p>WHAT TO DO NEXT:</p>',2,''),(387507,122760,'117182','deals','text','<p>WHAT TO DO NEXT:</p>',3,''),(387508,122760,'117182','deals','text','<p>WHAT TO DO NEXT:</p>',4,''),(387509,122761,'117184','deals','block_type','1',0,''),(387510,122761,'117184','deals','font-weight','normal',0,''),(387511,122761,'117184','deals','padding-top','10',0,''),(387512,122762,'117185','deals','text','<p>If you require further assistance please contact us</p>',1,''),(387513,122762,'117185','deals','font-weight','normal',0,''),(387514,122762,'117185','deals','text-align','center',0,''),(387515,122762,'117185','deals','font-size','12',0,''),(387516,122762,'117185','deals','padding-top','10',0,''),(387517,122762,'117185','deals','padding-bottom','5',0,''),(387518,122762,'117185','deals','border-top-width','1',0,''),(387519,122762,'117185','deals','border-top-color','$warning-border',0,''),(387520,122762,'117185','deals','text','<p>If you require further assistance please contact us</p>',2,''),(387521,122762,'117185','deals','text','<p>If you require further assistance please contact us</p>',3,''),(387522,122762,'117185','deals','text','<p>If you require further assistance please contact us</p>',4,''),(387523,122763,'117186','deals','font-size','12',0,''),(387524,122763,'117186','deals','font-weight','bold',0,''),(387525,122763,'117186','deals','text-align','center',0,''),(387526,122763,'117186','deals','style_class','email',0,''),(387527,122764,'117187','deals','font-size','12',0,''),(387528,122764,'117187','deals','font-weight','bold',0,''),(387529,122764,'117187','deals','text-align','center',0,''),(387530,122764,'117187','deals','style_class','phone',0,''),(387531,122764,'117187','deals','padding-bottom','5',0,''),(387532,122765,'117188','deals','font-weight','normal',0,''),(387533,122765,'117188','deals','text-align','center',0,''),(387534,122765,'117188','deals','padding-bottom','20',0,''),(387535,122766,'117189','deals','text','<p>GIFT CARD</p>',1,''),(387536,122766,'117189','deals','font-size','30',0,''),(387537,122766,'117189','deals','font-weight','normal',0,''),(387538,122766,'117189','deals','border-top-width','1',0,''),(387539,122766,'117189','deals','border-top-color','$warning-border',0,''),(387540,122766,'117189','deals','style_class','gift-ico',0,''),(387541,122766,'117189','deals','text-align','center',0,''),(387542,122766,'117189','deals','padding-top','15',0,''),(387543,122766,'117189','deals','text','<p>GIFT CARD</p>',2,''),(387544,122766,'117189','deals','text','<p>GIFT CARD</p>',3,''),(387545,122766,'117189','deals','text','<p>GIFT CARD</p>',4,''),(387546,122767,'117190','deals','text','<p>PERSONAL MESSAGE</p>',1,''),(387547,122767,'117190','deals','font-size','18',0,''),(387548,122767,'117190','deals','font-weight','normal',0,''),(387549,122767,'117190','deals','text-align','center',0,''),(387550,122767,'117190','deals','padding-top','20',0,''),(387551,122767,'117190','deals','padding-bottom','10',0,''),(387552,122767,'117190','deals','border-top-width','1',0,''),(387553,122767,'117190','deals','border-top-color','$warning-border',0,''),(387554,122767,'117190','deals','text','<p>PERSONAL MESSAGE</p>',2,''),(387555,122767,'117190','deals','text','<p>PERSONAL MESSAGE</p>',3,''),(387556,122767,'117190','deals','text','<p>PERSONAL MESSAGE</p>',4,''),(387557,122768,'117191','deals','font-size','60',0,''),(387558,122768,'117191','deals','font-weight','bold',0,''),(387559,122768,'117191','deals','text-align','center',0,''),(387560,122768,'117191','deals','line-height','100',0,''),(387561,122768,'117191','deals','padding-bottom','20',0,''),(387562,122768,'117191','deals','line_height_measure','px',0,''),(387563,122769,'117192','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(387564,122769,'117192','deals','font-weight','normal',0,''),(387565,122769,'117192','deals','text-align','center',0,''),(387566,122769,'117192','deals','padding-bottom','10',0,''),(387567,122769,'117192','deals','font-size','14',0,''),(387568,122769,'117192','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(387569,122769,'117192','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(387570,122769,'117192','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(387571,122770,'1638804328','deals','logo_from','theme',0,''),(387572,122770,'1638804328','deals','padding-top','20',0,''),(387573,122770,'1638804328','deals','text-align','center',0,''),(387574,122770,'1638804328','deals','padding-bottom','20',0,''),(387575,122771,'117193','deals','block_type','1',0,''),(387576,122771,'117193','deals','font-weight','normal',0,''),(387577,122771,'117193','deals','style_class','gift-card-view',0,''),(387578,122771,'117193','deals','text-align','center',0,''),(387579,122771,'117193','deals','padding-bottom','20',0,''),(387580,122771,'117193','deals','background-color','$highlight-box-bg-4',0,''),(387581,122771,'117193','deals','padding-left','20',0,''),(387582,122771,'117193','deals','padding-right','20',0,''),(387583,122771,'117193','deals','color','$highlight-box-color-4',0,''),(387584,122772,'117194','deals','block_type','1',0,''),(387585,122772,'117194','deals','font-weight','normal',0,''),(387586,122772,'117194','deals','padding-top','10',0,''),(387587,122773,'117195','deals','font-size','12',0,''),(387588,122773,'117195','deals','font-weight','bold',0,''),(387589,122773,'117195','deals','text-align','center',0,''),(387590,122773,'117195','deals','style_class','email',0,''),(387591,122773,'117195','deals','color','$highlight-box-color-4',0,''),(387592,122774,'117196','deals','font-size','12',0,''),(387593,122774,'117196','deals','font-weight','bold',0,''),(387594,122774,'117196','deals','text-align','center',0,''),(387595,122774,'117196','deals','style_class','phone',0,''),(387596,122774,'117196','deals','padding-bottom','5',0,''),(387597,122774,'117196','deals','color','$highlight-box-color-4',0,''),(387598,122775,'117197','deals','text','If you require further assistance please contact us',0,''),(387599,122775,'117197','deals','font-size','12',0,''),(387600,122775,'117197','deals','color','$highlight-box-color-4',0,''),(387601,122775,'117197','deals','text-align','center',0,''),(387602,122775,'117197','deals','padding-top','10',0,''),(387603,122776,'117198','deals','block_type','4',0,''),(387604,122776,'117198','deals','color','$highlight-box-color-2',0,''),(387605,122776,'117198','deals','font-size','30',0,''),(387606,122776,'117198','deals','font-weight','normal',0,''),(387607,122776,'117198','deals','background-color','$highlight-box-bg-2',0,''),(387608,122776,'117198','deals','padding-top','5',0,''),(387609,122776,'117198','deals','padding-left','10',0,''),(387610,122776,'117198','deals','padding-right','10',0,''),(387611,122776,'117198','deals','padding-bottom','5',0,''),(387612,122777,'117199','deals','text','Your code is:',0,''),(387613,122777,'117199','deals','font-size','30',0,''),(387614,122777,'117199','deals','color','$highlight-box-color-2',0,''),(387615,122778,'117200','deals','color','$highlight-box-color-2',0,''),(387616,122778,'117200','deals','font-size','30',0,''),(387617,122779,'117201','deals','block_type','1',0,''),(387618,122780,'117202','deals','text','<p>PERSONAL MESSAGE</p>',1,''),(387619,122780,'117202','deals','font-size','18',0,''),(387620,122780,'117202','deals','font-weight','normal',0,''),(387621,122780,'117202','deals','text-align','center',0,''),(387622,122780,'117202','deals','padding-top','20',0,''),(387623,122780,'117202','deals','padding-bottom','10',0,''),(387624,122780,'117202','deals','border-top-width','1',0,''),(387625,122780,'117202','deals','border-top-color','$warning-border',0,''),(387626,122780,'117202','deals','text','<p>PERSONAL MESSAGE</p>',2,''),(387627,122780,'117202','deals','text','<p>PERSONAL MESSAGE</p>',3,''),(387628,122780,'117202','deals','text','<p>PERSONAL MESSAGE</p>',4,''),(387629,122780,'117202','deals','color','$highlight-box-color-2',0,''),(387630,122781,'117203','deals','text','HOLBI',0,''),(387631,122781,'117203','deals','color','$highlight-box-color-2',0,''),(387632,122781,'117203','deals','font-size','24',0,''),(387633,122781,'117203','deals','padding-top','20',0,''),(387634,122781,'117203','deals','text-align','center',0,''),(387635,122781,'117203','deals','padding-bottom','20',0,''),(387636,122782,'117204','deals','border-top-color','$warning-border',0,''),(387637,122782,'117204','deals','border-top-width','1',0,''),(387638,122782,'117204','deals','padding-top','20',0,''),(387639,122782,'117204','deals','font-size','30',0,''),(387640,122782,'117204','deals','text-align','center',0,''),(387641,122782,'117204','deals','color','$highlight-box-color-4',0,''),(387642,122782,'117204','deals','text','GIFT CARD',0,''),(387643,122783,'117205','deals','text-align','center',0,''),(387644,122783,'117205','deals','font-weight','bold',0,''),(387645,122783,'117205','deals','font-size','60',0,''),(387646,122783,'117205','deals','color','$highlight-box-color-4',0,''),(387647,122784,'117206','deals','font-size','20',0,''),(387648,122784,'117206','deals','text-align','center',0,''),(387649,122784,'117206','deals','color','$highlight-box-color-2',0,''),(387650,122784,'117206','deals','padding-top','20',0,''),(387651,122784,'117206','deals','padding-bottom','20',0,''),(387652,122785,'117207','deals','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(387653,122785,'117207','deals','text-align','center',0,''),(387654,122785,'117207','deals','color','$highlight-box-color-2',0,''),(387655,122785,'117207','deals','font-size','14',0,''),(387656,122785,'117207','deals','padding-bottom','20',0,''),(387657,122786,'117208','deals','text','WHAT TO DO NEXT:',0,''),(387658,122786,'117208','deals','font-size','18',0,''),(387659,122786,'117208','deals','text-align','center',0,''),(387660,122786,'117208','deals','color','$highlight-box-color-2',0,''),(387661,122786,'117208','deals','padding-top','20',0,''),(387662,122786,'117208','deals','padding-bottom','10',0,''),(387663,122786,'117208','deals','border-top-width','1',0,''),(387664,122786,'117208','deals','border-top-color','$warning-border',0,''),(387665,122788,'0','deals','block_type','1',0,''),(387666,122788,'0','deals','style_class','headerWrap fixed-header-1',0,''),(387667,122788,'0','deals','padding-top','10',0,'5630'),(387668,122788,'0','deals','padding-top','5',0,'5660'),(387669,122788,'0','deals','background-color','$header-bg-1',0,''),(387670,122788,'0','deals','color','$header-color-1',0,''),(387728,122798,'1683115085.234893','deals','block_type','1',0,''),(387729,122798,'1683115085.234893','deals','style_class','breadcrumb-box',0,''),(387730,122798,'1683115085.234893','deals','visibility_home','1',0,''),(387731,122800,'117224.000001','deals','block_type','1',0,''),(387732,122806,'117229','deals','width','680',0,''),(387733,122806,'117229','deals','font-weight','normal',0,''),(387734,122806,'117229','deals','font-size','12',0,''),(387735,122806,'117229','deals','padding-top','20',0,''),(387736,122806,'117229','deals','padding-bottom','20',0,''),(387737,122806,'117229','deals','color','$content-color-1',0,''),(387738,122807,'117230','deals','block_type','4',0,''),(387739,122807,'117230','deals','font-weight','normal',0,''),(387740,122807,'117230','deals','border-top-width','1',0,''),(387741,122807,'117230','deals','border-top-color','$content-border-1',0,''),(387742,122807,'117230','deals','border-left-width','1',0,''),(387743,122807,'117230','deals','border-left-color','$content-border-1',0,''),(387744,122807,'117230','deals','border-right-width','1',0,''),(387745,122807,'117230','deals','border-right-color','$content-border-1',0,''),(387746,122807,'117230','deals','border-bottom-width','1',0,''),(387747,122807,'117230','deals','border-bottom-color','$content-border-1',0,''),(387748,122808,'117231','deals','block_type','2',0,''),(387749,122808,'117231','deals','font-weight','normal',0,''),(387750,122808,'117231','deals','border-top-width','1',0,''),(387751,122808,'117231','deals','border-top-color','$content-border-1',0,''),(387752,122808,'117231','deals','border-right-width','1',0,''),(387753,122808,'117231','deals','border-right-color','$content-border-1',0,''),(387754,122809,'117232','deals','block_type','1',0,''),(387755,122809,'117232','deals','font-weight','normal',0,''),(387756,122809,'117232','deals','padding-top','10',0,''),(387757,122809,'117232','deals','padding-left','10',0,''),(387758,122809,'117232','deals','padding-right','10',0,''),(387759,122809,'117232','deals','padding-bottom','10',0,''),(387760,122809,'117232','deals','border-right-width','1',0,''),(387761,122809,'117232','deals','border-right-color','$content-border-1',0,''),(387762,122811,'117234','deals','text','<p>Shipping via</p>',1,''),(387763,122811,'117234','deals','font-weight','bold',0,''),(387764,122811,'117234','deals','font-size','14',0,''),(387765,122811,'117234','deals','text','<p>Shipping via</p>',2,''),(387766,122811,'117234','deals','text','<p>Shipping via</p>',3,''),(387767,122811,'117234','deals','text','<p>Shipping via</p>',4,''),(387768,122812,'117235','deals','block_type','1',0,''),(387769,122812,'117235','deals','font-weight','normal',0,''),(387770,122812,'117235','deals','padding-top','10',0,''),(387771,122812,'117235','deals','padding-left','10',0,''),(387772,122812,'117235','deals','padding-right','10',0,''),(387773,122812,'117235','deals','padding-bottom','10',0,''),(387774,122813,'117236','deals','text','<p>Shipping service</p>',1,''),(387775,122813,'117236','deals','font-weight','bold',0,''),(387776,122813,'117236','deals','font-size','14',0,''),(387777,122813,'117236','deals','text','<p>Shipping service</p>',2,''),(387778,122813,'117236','deals','text','<p>Shipping service</p>',3,''),(387779,122813,'117236','deals','text','<p>Shipping service</p>',4,''),(387780,122815,'117238','deals','block_type','2',0,''),(387781,122815,'117238','deals','font-weight','normal',0,''),(387782,122815,'117238','deals','border-right-width','1',0,''),(387783,122815,'117238','deals','border-right-color','$content-border-1',0,''),(387784,122816,'117239','deals','block_type','1',0,''),(387785,122816,'117239','deals','font-weight','400',0,''),(387786,122816,'117239','deals','background-color','$content-bg-2',0,''),(387787,122816,'117239','deals','padding-top','10',0,''),(387788,122816,'117239','deals','padding-left','10',0,''),(387789,122816,'117239','deals','padding-right','10',0,''),(387790,122816,'117239','deals','padding-bottom','30',0,''),(387791,122817,'117240','deals','text','<p>INVOICE ADDRESS:</p>',1,''),(387792,122817,'117240','deals','font-size','14',0,''),(387793,122817,'117240','deals','font-weight','bold',0,''),(387794,122817,'117240','deals','text','<p>INVOICE ADDRESS:</p>',2,''),(387795,122817,'117240','deals','text','<p>INVOICE ADDRESS:</p>',3,''),(387796,122817,'117240','deals','text','<p>INVOICE ADDRESS:</p>',4,''),(387797,122818,'117241','deals','font-size','12',0,''),(387798,122820,'117242','deals','block_type','1',0,''),(387799,122820,'117242','deals','font-weight','normal',0,''),(387800,122820,'117242','deals','padding-top','10',0,''),(387801,122820,'117242','deals','padding-left','10',0,''),(387802,122820,'117242','deals','padding-right','10',0,''),(387803,122820,'117242','deals','padding-bottom','10',0,''),(387804,122821,'117243','deals','text','<p>E-MAIL ADDRESS:</p>',1,''),(387805,122821,'117243','deals','font-weight','bold',0,''),(387806,122821,'117243','deals','font-size','14',0,''),(387807,122821,'117243','deals','padding-top','10',0,''),(387808,122821,'117243','deals','text','<p>E-MAIL ADDRESS:</p>',2,''),(387809,122821,'117243','deals','text','<p>E-MAIL ADDRESS:</p>',3,''),(387810,122821,'117243','deals','text','<p>E-MAIL ADDRESS:</p>',4,''),(387811,122822,'117244','deals','font-weight','normal',0,''),(387812,122823,'117245','deals','font-weight','normal',0,''),(387813,122824,'117246','deals','text','<p>CUSTOMER:</p>',1,''),(387814,122824,'117246','deals','font-size','13',0,''),(387815,122824,'117246','deals','font-weight','bold',0,''),(387816,122824,'117246','deals','text','<p>CUSTOMER:</p>',2,''),(387817,122824,'117246','deals','text','<p>CUSTOMER:</p>',3,''),(387818,122824,'117246','deals','text','<p>CUSTOMER:</p>',4,''),(387819,122825,'117247','deals','text','<p>PHONE NUMBER:</p>',1,''),(387820,122825,'117247','deals','font-size','14',0,''),(387821,122825,'117247','deals','font-weight','bold',0,''),(387822,122825,'117247','deals','padding-top','10',0,''),(387823,122825,'117247','deals','text','<p>PHONE NUMBER:</p>',2,''),(387824,122825,'117247','deals','text','<p>PHONE NUMBER:</p>',3,''),(387825,122825,'117247','deals','text','<p>PHONE NUMBER:</p>',4,''),(387826,122827,'117249','deals','font-weight','normal',0,''),(387827,122827,'117249','deals','text-align','center',0,''),(387828,122827,'117249','deals','padding-bottom','20',0,''),(387829,122828,'117250','deals','text','<p>Payment Method:</p>',1,''),(387830,122828,'117250','deals','font-weight','bold',0,''),(387831,122828,'117250','deals','text-align','center',0,''),(387832,122828,'117250','deals','text','<p>Payment Method:</p>',2,''),(387833,122828,'117250','deals','text','<p>Payment Method:</p>',3,''),(387834,122828,'117250','deals','text','<p>Payment Method:</p>',4,''),(387835,122829,'117251','deals','text','<p>Payment date:</p>',1,''),(387836,122829,'117251','deals','font-weight','bold',0,''),(387837,122829,'117251','deals','text-align','center',0,''),(387838,122829,'117251','deals','font-size','12',0,''),(387839,122829,'117251','deals','text','<p>Payment date:</p>',2,''),(387840,122829,'117251','deals','text','<p>Payment date:</p>',3,''),(387841,122829,'117251','deals','text','<p>Payment date:</p>',4,''),(387842,122830,'117252','deals','font-size','14',0,''),(387843,122830,'117252','deals','font-weight','bold',0,''),(387844,122830,'117252','deals','text-align','center',0,''),(387845,122830,'117252','deals','padding-bottom','10',0,''),(387846,122830,'117252','deals','padding-top','10',0,''),(387847,122831,'117253','deals','font-weight','normal',0,''),(387848,122831,'117253','deals','text-align','center',0,''),(387849,122831,'117253','deals','padding-bottom','10',0,''),(387850,122832,'117254','deals','font-weight','normal',0,''),(387851,122832,'117254','deals','text-align','center',0,''),(387852,122833,'117255','deals','block_type','3',0,''),(387853,122833,'117255','deals','font-weight','normal',0,''),(387854,122833,'117255','deals','padding-top','20',0,''),(387855,122834,'117256','deals','font-size','12',0,''),(387856,122835,'117257','deals','text','<p>If undelivered please return to:</p>',1,''),(387857,122835,'117257','deals','font-size','12',0,''),(387858,122835,'117257','deals','font-weight','bold',0,''),(387859,122835,'117257','deals','text','<p>If undelivered please return to:</p>',2,''),(387860,122835,'117257','deals','text','<p>If undelivered please return to:</p>',3,''),(387861,122835,'117257','deals','text','<p>If undelivered please return to:</p>',4,''),(387862,122836,'117258','deals','text','<p>Thank you for your order</p>',1,''),(387863,122836,'117258','deals','color','$hileght-color-1',0,''),(387864,122836,'117258','deals','font-size','13',0,''),(387865,122836,'117258','deals','font-weight','bold',0,''),(387866,122836,'117258','deals','padding-top','5',0,''),(387867,122836,'117258','deals','text-align','center',0,''),(387868,122836,'117258','deals','text','<p>Thank you for your order</p>',2,''),(387869,122836,'117258','deals','text','<p>Thank you for your order</p>',3,''),(387870,122836,'117258','deals','text','<p>Thank you for your order</p>',4,''),(387871,122837,'117260','deals','block_type','6',0,''),(387872,122837,'117260','deals','font-weight','normal',0,''),(387873,122837,'117260','deals','font-size','16',0,''),(387874,122838,'117261','deals','text','<p>Email:</p>',1,''),(387875,122838,'117261','deals','font-weight','normal',0,''),(387876,122838,'117261','deals','text-align','right',0,''),(387877,122838,'117261','deals','font-size','12',0,''),(387878,122838,'117261','deals','text','<p>Email:</p>',2,''),(387879,122838,'117261','deals','text','<p>Email:</p>',3,''),(387880,122838,'117261','deals','text','<p>Email:</p>',4,''),(387881,122839,'117262','deals','font-weight','normal',0,''),(387882,122839,'117262','deals','text-align','right',0,''),(387883,122839,'117262','deals','font-size','12',0,''),(387884,122840,'117263','deals','block_type','6',0,''),(387885,122840,'117263','deals','font-weight','normal',0,''),(387886,122840,'117263','deals','font-size','16',0,''),(387887,122841,'117264','deals','text','<p>Phone:</p>',1,''),(387888,122841,'117264','deals','font-weight','normal',0,''),(387889,122841,'117264','deals','text-align','right',0,''),(387890,122841,'117264','deals','font-size','12',0,''),(387891,122841,'117264','deals','text','<p>Phone:</p>',2,''),(387892,122841,'117264','deals','text','<p>Phone:</p>',3,''),(387893,122841,'117264','deals','text','<p>Phone:</p>',4,''),(387894,122842,'117265','deals','font-weight','normal',0,''),(387895,122842,'117265','deals','text-align','right',0,''),(387896,122842,'117265','deals','font-size','12',0,''),(387897,122843,'117266','deals','text','<p>If something has gone wrong please contact us at:</p>',1,''),(387898,122843,'117266','deals','font-size','12',0,''),(387899,122843,'117266','deals','font-weight','bold',0,''),(387900,122843,'117266','deals','text-align','right',0,''),(387901,122843,'117266','deals','text','<p>If something has gone wrong please contact us at:</p>',2,''),(387902,122843,'117266','deals','text','<p>If something has gone wrong please contact us at:</p>',3,''),(387903,122843,'117266','deals','text','<p>If something has gone wrong please contact us at:</p>',4,''),(387904,122844,'117267','deals','font-weight','400',0,''),(387905,122844,'117267','deals','padding-top','20',0,''),(387906,122844,'117267','deals','padding-bottom','0',0,''),(387907,122844,'117267','deals','font-size','12',0,''),(387908,122845,'117268','deals','block_type','5',0,''),(387909,122845,'117268','deals','font-weight','normal',0,''),(387910,122845,'117268','deals','border-bottom-width','1',0,''),(387911,122845,'117268','deals','border-bottom-color','$content-border-1',0,''),(387912,122845,'117268','deals','border-top-width','1',0,''),(387913,122845,'117268','deals','border-top-color','$content-border-1',0,''),(387914,122845,'117268','deals','border-left-color','$content-border-1',0,''),(387915,122845,'117268','deals','border-left-width','1',0,''),(387916,122846,'117269','deals','block_type','1',0,''),(387917,122846,'117269','deals','font-weight','normal',0,''),(387918,122846,'117269','deals','padding-top','10',0,''),(387919,122846,'117269','deals','padding-left','10',0,''),(387920,122846,'117269','deals','padding-right','10',0,''),(387921,122847,'117270','deals','font-weight','400',0,''),(387922,122847,'117270','deals','line-height','120',0,''),(387923,122847,'117270','deals','line_height_measure','%',0,''),(387924,122847,'117270','deals','font-size','12',0,''),(387925,122848,'117271','deals','text','<p>SHIPPING ADDRESS:</p>',1,''),(387926,122848,'117271','deals','font-size','14',0,''),(387927,122848,'117271','deals','font-weight','bold',0,''),(387928,122848,'117271','deals','padding-bottom','10',0,''),(387929,122848,'117271','deals','text','<p>SHIPPING ADDRESS:</p>',2,''),(387930,122848,'117271','deals','text','<p>SHIPPING ADDRESS:</p>',3,''),(387931,122848,'117271','deals','text','<p>SHIPPING ADDRESS:</p>',4,''),(387932,122849,'117272','deals','block_type','1',0,''),(387933,122849,'117272','deals','background-color','$content-bg-2',0,''),(387934,122849,'117272','deals','padding-top','20',0,''),(387935,122849,'117272','deals','padding-left','10',0,''),(387936,122849,'117272','deals','padding-right','10',0,''),(387937,122849,'117272','deals','padding-bottom','20',0,''),(387938,122849,'117272','deals','font-size','14',0,''),(387939,122850,'117273','deals','font-weight','normal',0,''),(387940,122850,'117273','deals','text-align','right',0,''),(387941,122850,'117273','deals','font-size','12',0,''),(387942,122850,'117273','deals','box_align','3',0,''),(387943,122851,'117274','deals','block_type','2',0,''),(387944,122851,'117274','deals','font-weight','normal',0,''),(387945,122851,'117274','deals','padding-bottom','20',0,''),(387946,122852,'117275','deals','font-weight','400',0,''),(387947,122852,'117275','deals','padding-top','20',0,''),(387948,122852,'117275','deals','logo','themes/deals/img/logo-2.png',1,''),(387949,122852,'117275','deals','padding-bottom','20',0,''),(387950,122852,'117275','deals','logo','themes/deals/img/logo-2.png',2,''),(387951,122852,'117275','deals','logo','themes/deals/img/logo-2.png',3,''),(387952,122852,'117275','deals','logo','themes/deals/img/logo-2.png',4,''),(387953,122853,'117276','deals','block_type','11',0,''),(387954,122853,'117276','deals','font-weight','normal',0,''),(387955,122854,'117277','deals','text','<p>Web:</p>',1,''),(387956,122854,'117277','deals','font-weight','normal',0,''),(387957,122854,'117277','deals','text-align','right',0,''),(387958,122854,'117277','deals','text','<p>Web:</p>',2,''),(387959,122854,'117277','deals','text','<p>Web:</p>',3,''),(387960,122854,'117277','deals','text','<p>Web:</p>',4,''),(387961,122855,'117278','deals','font-weight','normal',0,''),(387962,122855,'117278','deals','text-align','right',0,''),(387963,122856,'117279','deals','block_type','11',0,''),(387964,122856,'117279','deals','font-weight','normal',0,''),(387965,122857,'117280','deals','text','<p>Email:</p>',1,''),(387966,122857,'117280','deals','font-weight','normal',0,''),(387967,122857,'117280','deals','text-align','right',0,''),(387968,122857,'117280','deals','text','<p>Email:</p>',2,''),(387969,122857,'117280','deals','text','<p>Email:</p>',3,''),(387970,122857,'117280','deals','text','<p>Email:</p>',4,''),(387971,122858,'117281','deals','font-weight','normal',0,''),(387972,122858,'117281','deals','text-align','right',0,''),(387973,122859,'117282','deals','block_type','1',0,''),(387974,122860,'117283','deals','font-weight','normal',0,''),(387975,122860,'117283','deals','text-align','right',0,''),(387976,122860,'117283','deals','padding-bottom','10',0,''),(387977,122860,'117283','deals','address_spacer',',',0,''),(387978,122860,'117283','deals','font-size','12',0,''),(387979,122861,'117284','deals','block_type','11',0,''),(387980,122861,'117284','deals','font-weight','normal',0,''),(387981,122862,'117285','deals','text','<p>Phone:</p>',1,''),(387982,122862,'117285','deals','font-weight','normal',0,''),(387983,122862,'117285','deals','text-align','right',0,''),(387984,122862,'117285','deals','text','<p>Phone:</p>',2,''),(387985,122862,'117285','deals','text','<p>Phone:</p>',3,''),(387986,122862,'117285','deals','text','<p>Phone:</p>',4,''),(387987,122863,'117286','deals','font-weight','normal',0,''),(387988,122863,'117286','deals','text-align','right',0,''),(387989,122864,'1640103567','deals','column_qty','1',0,''),(387990,122864,'1640103567','deals','column_name','1',0,''),(387991,122864,'1640103567','deals','column_model','1',0,''),(387992,122865,'117287','deals','block_type','1',0,''),(387993,122865,'117287','deals','padding-top','20',0,''),(387994,122866,'117288','deals','tab_1','RETURNING CUSTOMER',1,''),(387995,122866,'117288','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(387996,122866,'117288','deals','tab_1','RETURNING CUSTOMER',2,''),(387997,122866,'117288','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(387998,122866,'117288','deals','tab_1','RETURNING CUSTOMER',3,''),(387999,122866,'117288','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(388000,122866,'117288','deals','tab_1','RETURNING CUSTOMER',4,''),(388001,122866,'117288','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(388002,122867,'117289','deals','max-width','600',0,''),(388003,122867,'117289','deals','margin_left_measure','auto',0,''),(388004,122867,'117289','deals','margin_right_measure','auto',0,''),(388005,122868,'117292','deals','block_type','1',0,''),(388006,122868,'117292','deals','padding-left','20',0,''),(388007,122868,'117292','deals','padding-right','20',0,''),(388008,122868,'117292','deals','style_class','loginWrapper',0,''),(388009,122869,'117293','deals','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(388010,122871,'117295','deals','block_type','1',0,''),(388011,122872,'117296','deals','text','##TEXT_OR##',0,''),(388012,122872,'117296','deals','font-size','18',0,''),(388013,122872,'117296','deals','font-weight','700',0,''),(388014,122872,'117296','deals','padding-top','15',0,''),(388015,122872,'117296','deals','text-align','center',0,''),(388016,122872,'117296','deals','content','\\_',0,'3'),(388017,122872,'117296','deals','height','5',0,'3'),(388018,122872,'117296','deals','width','70',0,'3'),(388019,122872,'117296','deals','display','inline-block',0,'3'),(388020,122872,'117296','deals','border-top-width','1',0,'3'),(388021,122872,'117296','deals','border-top-color','$content-border-1',0,'3'),(388022,122872,'117296','deals','margin-left','10',0,'3'),(388023,122872,'117296','deals','margin-right','10',0,'3'),(388024,122872,'117296','deals','content','\\_',0,'4'),(388025,122872,'117296','deals','display','inline-block',0,'4'),(388026,122872,'117296','deals','width','70',0,'4'),(388027,122872,'117296','deals','height','5',0,'4'),(388028,122872,'117296','deals','border-top-width','1',0,'4'),(388029,122872,'117296','deals','border-top-color','$content-border-1',0,'4'),(388030,122872,'117296','deals','margin-left','10',0,'4'),(388031,122872,'117296','deals','margin-right','10',0,'4'),(388032,122872,'117296','deals','position','relative',0,''),(388033,122872,'117296','deals','top','-10',0,''),(388034,122873,'117297','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388035,122873,'117297','deals','font-size','26',0,''),(388036,122873,'117297','deals','font-family','$font-1',0,''),(388037,122873,'117297','deals','padding-top','15',0,''),(388038,122873,'117297','deals','padding-bottom','15',0,''),(388039,122873,'117297','deals','text-align','center',0,''),(388040,122874,'117298','deals','text-align','center',0,''),(388041,122874,'117298','deals','hide_parents','2',0,''),(388042,122875,'117299','deals','block_type','1',0,''),(388043,122875,'117299','deals','padding-top','40',0,''),(388044,122875,'117299','deals','padding-bottom','40',0,''),(388045,122875,'117299','deals','style_class','checkout-login-wrap',0,''),(388046,122876,'117300','deals','block_type','2',0,''),(388047,122876,'117300','deals','background-color','$content-bg-1',0,''),(388048,122876,'117300','deals','max-width','830',0,''),(388049,122876,'117300','deals','margin_left_measure','auto',0,''),(388050,122876,'117300','deals','margin_right_measure','auto',0,''),(388051,122876,'117300','deals','padding-top','40',0,''),(388052,122876,'117300','deals','padding-bottom','40',0,''),(388053,122876,'117300','deals','schema','2-3',0,'5639'),(388054,122876,'117300','deals','border-top-width','1',0,''),(388055,122876,'117300','deals','border-left-width','1',0,''),(388056,122876,'117300','deals','border-right-width','1',0,''),(388057,122876,'117300','deals','border-bottom-width','1',0,''),(388058,122876,'117300','deals','border-top-color','$content-border-1',0,''),(388059,122876,'117300','deals','border-left-color','$content-border-1',0,''),(388060,122876,'117300','deals','border-right-color','$content-border-1',0,''),(388061,122876,'117300','deals','border-bottom-color','$content-border-1',0,''),(388062,122877,'117301','deals','text-align','center',0,''),(388063,122877,'117301','deals','margin-bottom','40',0,''),(388064,122878,'117302','deals','text-align','center',0,''),(388065,122879,'117303','deals','text','##TEXT_OR##',0,''),(388066,122879,'117303','deals','font-size','18',0,''),(388067,122879,'117303','deals','font-weight','700',0,''),(388068,122879,'117303','deals','text-align','center',0,''),(388069,122879,'117303','deals','content','\\_',0,'3'),(388070,122879,'117303','deals','height','5',0,'3'),(388071,122879,'117303','deals','width','70',0,'3'),(388072,122879,'117303','deals','display','inline-block',0,'3'),(388073,122879,'117303','deals','border-top-width','1',0,'3'),(388074,122879,'117303','deals','border-top-color','$content-border-1',0,'3'),(388075,122879,'117303','deals','margin-left','10',0,'3'),(388076,122879,'117303','deals','margin-right','10',0,'3'),(388077,122879,'117303','deals','content','\\_',0,'4'),(388078,122879,'117303','deals','display','inline-block',0,'4'),(388079,122879,'117303','deals','width','70',0,'4'),(388080,122879,'117303','deals','height','5',0,'4'),(388081,122879,'117303','deals','border-top-width','1',0,'4'),(388082,122879,'117303','deals','border-top-color','$content-border-1',0,'4'),(388083,122879,'117303','deals','margin-left','10',0,'4'),(388084,122879,'117303','deals','margin-right','10',0,'4'),(388085,122879,'117303','deals','position','relative',0,''),(388086,122879,'117303','deals','padding-top','10',0,''),(388087,122879,'117303','deals','padding-bottom','10',0,''),(388088,122880,'117304','deals','block_type','1',0,''),(388089,122881,'117305','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388090,122881,'117305','deals','font-size','18',0,''),(388091,122881,'117305','deals','padding-top','15',0,''),(388092,122881,'117305','deals','padding-bottom','15',0,''),(388093,122881,'117305','deals','text-align','center',0,''),(388094,122881,'117305','deals','text-transform','uppercase',0,''),(388095,122882,'117306','deals','text-align','center',0,''),(388096,122882,'117306','deals','hide_parents','2',0,''),(388097,122883,'117307','deals','text','##NEW_CUSTOMER##',0,''),(388098,122883,'117307','deals','font-size','18',0,''),(388099,122883,'117307','deals','text-align','center',0,''),(388100,122883,'117307','deals','text-transform','uppercase',0,''),(388101,122883,'117307','deals','margin-bottom','10',0,''),(388102,122884,'117308','deals','max-width','230',0,''),(388103,122884,'117308','deals','margin_left_measure','auto',0,''),(388104,122884,'117308','deals','margin_right_measure','auto',0,''),(388105,122885,'117309','deals','text','##RETURNING_CUSTOMER##',0,''),(388106,122885,'117309','deals','font-size','18',0,''),(388107,122885,'117309','deals','text-transform','uppercase',0,''),(388108,122885,'117309','deals','text-align','center',0,''),(388109,122886,'117310','deals','block_type','1',0,''),(388110,122886,'117310','deals','padding-top','20',0,''),(388111,122887,'117311','deals','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(388112,122887,'117311','deals','tab_2','RETURNING CUSTOMER',1,''),(388113,122887,'117311','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(388114,122887,'117311','deals','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(388115,122887,'117311','deals','tab_2','RETURNING CUSTOMER',2,''),(388116,122887,'117311','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(388117,122887,'117311','deals','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(388118,122887,'117311','deals','tab_2','RETURNING CUSTOMER',3,''),(388119,122887,'117311','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(388120,122887,'117311','deals','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(388121,122887,'117311','deals','tab_2','RETURNING CUSTOMER',4,''),(388122,122887,'117311','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(388123,122888,'117312','deals','block_type','8',0,''),(388124,122889,'117313','deals','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(388125,122890,'117314','deals','block_type','1',0,''),(388126,122890,'117314','deals','padding-left','20',0,''),(388127,122890,'117314','deals','padding-right','20',0,''),(388128,122892,'117316','deals','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(388129,122892,'117316','deals','border-top-width','1',0,''),(388130,122892,'117316','deals','border-top-color','$content-border-1',0,''),(388131,122894,'117318','deals','block_type','8',0,''),(388132,122895,'117319','deals','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(388133,122896,'117320','deals','block_type','1',0,''),(388134,122896,'117320','deals','padding-left','20',0,''),(388135,122896,'117320','deals','padding-right','20',0,''),(388136,122897,'117321','deals','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(388137,122899,'117323','deals','text-align','center',0,''),(388138,122900,'117324','deals','text','##TEXT_OR##',0,''),(388139,122900,'117324','deals','font-size','18',0,''),(388140,122900,'117324','deals','font-weight','700',0,''),(388141,122900,'117324','deals','padding-top','15',0,''),(388142,122900,'117324','deals','text-align','center',0,''),(388143,122900,'117324','deals','content','\\_',0,'3'),(388144,122900,'117324','deals','height','5',0,'3'),(388145,122900,'117324','deals','width','70',0,'3'),(388146,122900,'117324','deals','display','inline-block',0,'3'),(388147,122900,'117324','deals','border-top-width','1',0,'3'),(388148,122900,'117324','deals','border-top-color','$content-border-1',0,'3'),(388149,122900,'117324','deals','margin-left','10',0,'3'),(388150,122900,'117324','deals','margin-right','10',0,'3'),(388151,122900,'117324','deals','content','\\_',0,'4'),(388152,122900,'117324','deals','display','inline-block',0,'4'),(388153,122900,'117324','deals','width','70',0,'4'),(388154,122900,'117324','deals','height','5',0,'4'),(388155,122900,'117324','deals','border-top-width','1',0,'4'),(388156,122900,'117324','deals','border-top-color','$content-border-1',0,'4'),(388157,122900,'117324','deals','margin-left','10',0,'4'),(388158,122900,'117324','deals','margin-right','10',0,'4'),(388159,122900,'117324','deals','position','relative',0,''),(388160,122900,'117324','deals','top','-10',0,''),(388161,122901,'117325','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388162,122901,'117325','deals','font-size','26',0,''),(388163,122901,'117325','deals','font-family','$font-1',0,''),(388164,122901,'117325','deals','padding-top','15',0,''),(388165,122901,'117325','deals','padding-bottom','15',0,''),(388166,122901,'117325','deals','text-align','center',0,''),(388167,122902,'117326','deals','block_type','1',0,''),(388168,122902,'117326','deals','padding-top','20',0,''),(388169,122903,'117327','deals','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(388170,122903,'117327','deals','tab_2','RETURNING CUSTOMER',1,''),(388171,122903,'117327','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(388172,122903,'117327','deals','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(388173,122903,'117327','deals','tab_2','RETURNING CUSTOMER',2,''),(388174,122903,'117327','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(388175,122903,'117327','deals','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(388176,122903,'117327','deals','tab_2','RETURNING CUSTOMER',3,''),(388177,122903,'117327','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(388178,122903,'117327','deals','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(388179,122903,'117327','deals','tab_2','RETURNING CUSTOMER',4,''),(388180,122903,'117327','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(388181,122904,'117328','deals','block_type','8',0,''),(388182,122905,'117329','deals','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(388183,122908,'117332','deals','block_type','8',0,''),(388184,122909,'117333','deals','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(388185,122911,'117335','deals','block_type','1',0,''),(388186,122911,'117335','deals','padding-left','20',0,''),(388187,122911,'117335','deals','padding-right','20',0,''),(388188,122913,'117337','deals','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(388189,122914,'117338','deals','text','##TEXT_OR##',0,''),(388190,122914,'117338','deals','font-size','18',0,''),(388191,122914,'117338','deals','font-weight','700',0,''),(388192,122914,'117338','deals','padding-top','15',0,''),(388193,122914,'117338','deals','text-align','center',0,''),(388194,122914,'117338','deals','content','\\_',0,'3'),(388195,122914,'117338','deals','height','5',0,'3'),(388196,122914,'117338','deals','width','70',0,'3'),(388197,122914,'117338','deals','display','inline-block',0,'3'),(388198,122914,'117338','deals','border-top-width','1',0,'3'),(388199,122914,'117338','deals','border-top-color','$content-border-1',0,'3'),(388200,122914,'117338','deals','margin-left','10',0,'3'),(388201,122914,'117338','deals','margin-right','10',0,'3'),(388202,122914,'117338','deals','content','\\_',0,'4'),(388203,122914,'117338','deals','display','inline-block',0,'4'),(388204,122914,'117338','deals','width','70',0,'4'),(388205,122914,'117338','deals','height','5',0,'4'),(388206,122914,'117338','deals','border-top-width','1',0,'4'),(388207,122914,'117338','deals','border-top-color','$content-border-1',0,'4'),(388208,122914,'117338','deals','margin-left','10',0,'4'),(388209,122914,'117338','deals','margin-right','10',0,'4'),(388210,122914,'117338','deals','position','relative',0,''),(388211,122914,'117338','deals','top','-10',0,''),(388212,122915,'117339','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388213,122915,'117339','deals','font-size','26',0,''),(388214,122915,'117339','deals','font-family','$font-1',0,''),(388215,122915,'117339','deals','padding-top','15',0,''),(388216,122915,'117339','deals','padding-bottom','15',0,''),(388217,122915,'117339','deals','text-align','center',0,''),(388218,122916,'117340','deals','text-align','center',0,''),(388219,122917,'117341','deals','block_type','1',0,''),(388220,122917,'117341','deals','padding-top','20',0,''),(388221,122918,'117342','deals','text-align','center',0,''),(388222,122919,'117343','deals','text','##TEXT_OR##',0,''),(388223,122919,'117343','deals','font-size','18',0,''),(388224,122919,'117343','deals','font-weight','700',0,''),(388225,122919,'117343','deals','padding-top','15',0,''),(388226,122919,'117343','deals','text-align','center',0,''),(388227,122919,'117343','deals','content','\\_',0,'3'),(388228,122919,'117343','deals','height','5',0,'3'),(388229,122919,'117343','deals','width','70',0,'3'),(388230,122919,'117343','deals','display','inline-block',0,'3'),(388231,122919,'117343','deals','border-top-width','1',0,'3'),(388232,122919,'117343','deals','border-top-color','$content-border-1',0,'3'),(388233,122919,'117343','deals','margin-left','10',0,'3'),(388234,122919,'117343','deals','margin-right','10',0,'3'),(388235,122919,'117343','deals','content','\\_',0,'4'),(388236,122919,'117343','deals','display','inline-block',0,'4'),(388237,122919,'117343','deals','width','70',0,'4'),(388238,122919,'117343','deals','height','5',0,'4'),(388239,122919,'117343','deals','border-top-width','1',0,'4'),(388240,122919,'117343','deals','border-top-color','$content-border-1',0,'4'),(388241,122919,'117343','deals','margin-left','10',0,'4'),(388242,122919,'117343','deals','margin-right','10',0,'4'),(388243,122919,'117343','deals','position','relative',0,''),(388244,122919,'117343','deals','top','-10',0,''),(388245,122920,'117344','deals','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(388246,122920,'117344','deals','tab_2','RETURNING CUSTOMER',1,''),(388247,122920,'117344','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(388248,122920,'117344','deals','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(388249,122920,'117344','deals','tab_2','RETURNING CUSTOMER',2,''),(388250,122920,'117344','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(388251,122920,'117344','deals','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(388252,122920,'117344','deals','tab_2','RETURNING CUSTOMER',3,''),(388253,122920,'117344','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(388254,122920,'117344','deals','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(388255,122920,'117344','deals','tab_2','RETURNING CUSTOMER',4,''),(388256,122920,'117344','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(388257,122921,'117345','deals','block_type','8',0,''),(388258,122922,'117346','deals','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(388259,122925,'117349','deals','block_type','8',0,''),(388260,122926,'117350','deals','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(388261,122927,'117351','deals','block_type','1',0,''),(388262,122927,'117351','deals','padding-left','20',0,''),(388263,122927,'117351','deals','padding-right','20',0,''),(388264,122929,'117353','deals','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(388265,122930,'117354','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388266,122930,'117354','deals','font-size','26',0,''),(388267,122930,'117354','deals','font-family','$font-1',0,''),(388268,122930,'117354','deals','padding-top','15',0,''),(388269,122930,'117354','deals','padding-bottom','15',0,''),(388270,122930,'117354','deals','text-align','center',0,''),(388271,122931,'117355','deals','block_type','1',0,''),(388272,122931,'117355','deals','padding-top','40',0,''),(388273,122931,'117355','deals','background-color','$content-bg-2',0,''),(388274,122931,'117355','deals','padding-bottom','40',0,''),(388275,122932,'117356','deals','block_type','2',0,''),(388276,122932,'117356','deals','background-color','$content-bg-1',0,''),(388277,122932,'117356','deals','max-width','830',0,''),(388278,122932,'117356','deals','margin_left_measure','auto',0,''),(388279,122932,'117356','deals','margin_right_measure','auto',0,''),(388280,122932,'117356','deals','padding-top','40',0,''),(388281,122932,'117356','deals','padding-bottom','40',0,''),(388282,122932,'117356','deals','schema','2-3',0,'5639'),(388283,122933,'117357','deals','block_type','1',0,''),(388284,122934,'117358','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388285,122934,'117358','deals','font-size','18',0,''),(388286,122934,'117358','deals','font-family','$font-1',0,''),(388287,122934,'117358','deals','padding-top','15',0,''),(388288,122934,'117358','deals','padding-bottom','15',0,''),(388289,122934,'117358','deals','text-align','center',0,''),(388290,122934,'117358','deals','text-transform','uppercase',0,''),(388291,122935,'117359','deals','text-align','center',0,''),(388292,122935,'117359','deals','hide_parents','2',0,''),(388293,122936,'117360','deals','text-align','center',0,''),(388294,122937,'117361','deals','text-align','center',0,''),(388295,122937,'117361','deals','margin-bottom','40',0,''),(388296,122938,'117362','deals','text','##TEXT_OR##',0,''),(388297,122938,'117362','deals','font-size','18',0,''),(388298,122938,'117362','deals','font-weight','700',0,''),(388299,122938,'117362','deals','text-align','center',0,''),(388300,122938,'117362','deals','content','\\_',0,'3'),(388301,122938,'117362','deals','height','5',0,'3'),(388302,122938,'117362','deals','width','70',0,'3'),(388303,122938,'117362','deals','display','inline-block',0,'3'),(388304,122938,'117362','deals','border-top-width','1',0,'3'),(388305,122938,'117362','deals','border-top-color','$content-border-1',0,'3'),(388306,122938,'117362','deals','margin-left','10',0,'3'),(388307,122938,'117362','deals','margin-right','10',0,'3'),(388308,122938,'117362','deals','content','\\_',0,'4'),(388309,122938,'117362','deals','display','inline-block',0,'4'),(388310,122938,'117362','deals','width','70',0,'4'),(388311,122938,'117362','deals','height','5',0,'4'),(388312,122938,'117362','deals','border-top-width','1',0,'4'),(388313,122938,'117362','deals','border-top-color','$content-border-1',0,'4'),(388314,122938,'117362','deals','margin-left','10',0,'4'),(388315,122938,'117362','deals','margin-right','10',0,'4'),(388316,122938,'117362','deals','position','relative',0,''),(388317,122938,'117362','deals','padding-top','10',0,''),(388318,122938,'117362','deals','padding-bottom','10',0,''),(388319,122939,'117363','deals','text','##NEW_CUSTOMER##',0,''),(388320,122939,'117363','deals','font-size','18',0,''),(388321,122939,'117363','deals','font-family','$font-1',0,''),(388322,122939,'117363','deals','text-align','center',0,''),(388323,122939,'117363','deals','text-transform','uppercase',0,''),(388324,122939,'117363','deals','margin-bottom','10',0,''),(388325,122940,'117364','deals','text','##RETURNING_CUSTOMER##',0,''),(388326,122940,'117364','deals','font-size','18',0,''),(388327,122940,'117364','deals','font-family','$font-1',0,''),(388328,122940,'117364','deals','text-transform','uppercase',0,''),(388329,122940,'117364','deals','text-align','center',0,''),(388330,122941,'117365','deals','max-width','230',0,''),(388331,122941,'117365','deals','margin_left_measure','auto',0,''),(388332,122941,'117365','deals','margin_right_measure','auto',0,''),(388333,122942,'117366','deals','block_type','1',0,''),(388334,122942,'117366','deals','padding-top','40',0,''),(388335,122942,'117366','deals','background-color','$content-bg-2',0,''),(388336,122942,'117366','deals','padding-bottom','40',0,''),(388337,122943,'117367','deals','block_type','2',0,''),(388338,122943,'117367','deals','background-color','$content-bg-1',0,''),(388339,122943,'117367','deals','max-width','830',0,''),(388340,122943,'117367','deals','margin_left_measure','auto',0,''),(388341,122943,'117367','deals','margin_right_measure','auto',0,''),(388342,122943,'117367','deals','padding-top','40',0,''),(388343,122943,'117367','deals','padding-bottom','40',0,''),(388344,122943,'117367','deals','schema','2-3',0,'5639'),(388345,122944,'117368','deals','text','##NEW_CUSTOMER##',0,''),(388346,122944,'117368','deals','font-size','18',0,''),(388347,122944,'117368','deals','font-family','$font-1',0,''),(388348,122944,'117368','deals','text-align','center',0,''),(388349,122944,'117368','deals','text-transform','uppercase',0,''),(388350,122944,'117368','deals','margin-bottom','10',0,''),(388351,122945,'117369','deals','text-align','center',0,''),(388352,122946,'117370','deals','text-align','center',0,''),(388353,122946,'117370','deals','margin-bottom','40',0,''),(388354,122947,'117371','deals','text','##TEXT_OR##',0,''),(388355,122947,'117371','deals','font-size','18',0,''),(388356,122947,'117371','deals','font-weight','700',0,''),(388357,122947,'117371','deals','text-align','center',0,''),(388358,122947,'117371','deals','content','\\_',0,'3'),(388359,122947,'117371','deals','height','5',0,'3'),(388360,122947,'117371','deals','width','70',0,'3'),(388361,122947,'117371','deals','display','inline-block',0,'3'),(388362,122947,'117371','deals','border-top-width','1',0,'3'),(388363,122947,'117371','deals','border-top-color','$content-border-1',0,'3'),(388364,122947,'117371','deals','margin-left','10',0,'3'),(388365,122947,'117371','deals','margin-right','10',0,'3'),(388366,122947,'117371','deals','content','\\_',0,'4'),(388367,122947,'117371','deals','display','inline-block',0,'4'),(388368,122947,'117371','deals','width','70',0,'4'),(388369,122947,'117371','deals','height','5',0,'4'),(388370,122947,'117371','deals','border-top-width','1',0,'4'),(388371,122947,'117371','deals','border-top-color','$content-border-1',0,'4'),(388372,122947,'117371','deals','margin-left','10',0,'4'),(388373,122947,'117371','deals','margin-right','10',0,'4'),(388374,122947,'117371','deals','position','relative',0,''),(388375,122947,'117371','deals','padding-top','10',0,''),(388376,122947,'117371','deals','padding-bottom','10',0,''),(388377,122948,'117372','deals','block_type','1',0,''),(388378,122949,'117373','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388379,122949,'117373','deals','font-size','18',0,''),(388380,122949,'117373','deals','font-family','$font-1',0,''),(388381,122949,'117373','deals','padding-top','15',0,''),(388382,122949,'117373','deals','padding-bottom','15',0,''),(388383,122949,'117373','deals','text-align','center',0,''),(388384,122949,'117373','deals','text-transform','uppercase',0,''),(388385,122950,'117374','deals','text-align','center',0,''),(388386,122950,'117374','deals','hide_parents','2',0,''),(388387,122951,'117375','deals','text','##RETURNING_CUSTOMER##',0,''),(388388,122951,'117375','deals','font-size','18',0,''),(388389,122951,'117375','deals','font-family','$font-1',0,''),(388390,122951,'117375','deals','text-transform','uppercase',0,''),(388391,122951,'117375','deals','text-align','center',0,''),(388392,122952,'117376','deals','max-width','230',0,''),(388393,122952,'117376','deals','margin_left_measure','auto',0,''),(388394,122952,'117376','deals','margin_right_measure','auto',0,''),(388395,122953,'117377','deals','block_type','1',0,''),(388396,122954,'117378','deals','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(388397,122954,'117378','deals','margin-bottom','30',0,''),(388398,122955,'117379','deals','block_type','1',0,''),(388399,122956,'117380','deals','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(388400,122956,'117380','deals','margin-bottom','30',0,''),(388401,122957,'1641480784','deals','block_type','1',0,''),(388402,122957,'1641480784','deals','style_class','parallaxWrap',0,''),(388403,122957,'1641480784','deals','background_image','themes/deals/img/grey-bg.jpg',0,''),(388404,122957,'1641480784','deals','background-position','center',0,''),(388405,122957,'1641480784','deals','background-repeat','no-repeat',0,''),(388406,122957,'1641480784','deals','margin-bottom','30',0,''),(388407,122958,'1641480810','deals','info_page','40',0,''),(388408,122959,'1641549359','deals','block_type','1',0,''),(388409,122959,'1641549359','deals','padding-top','60',0,''),(388410,122959,'1641549359','deals','padding-bottom','70',0,''),(388411,122959,'1641549359','deals','style_class','bannersWrap',0,''),(388412,122959,'1641549359','deals','padding-top','30',0,'5639'),(388413,122959,'1641549359','deals','padding-bottom','30',0,'5639'),(388414,122960,'1641549444','deals','block_type','12',0,''),(388415,122961,'1641549385','deals','banners_group','horizontal',0,''),(388416,122961,'1641549385','deals','style_class','leftBanner',0,''),(388417,122961,'1641549385','deals','banners_type','banner',0,''),(388418,122961,'1641549385','deals','template','1',0,''),(388419,122962,'1641549553','deals','banners_group','vertical',0,''),(388420,122962,'1641549553','deals','style_class','rightBanner',0,''),(388421,122962,'1641549553','deals','banners_type','banner',0,''),(388422,122962,'1641549553','deals','template','1',0,''),(388423,122963,'1641570125','deals','block_type','1',0,''),(388424,122964,'1641570075','deals','padding-top','75',0,''),(388425,122964,'1641570075','deals','padding-bottom','70',0,''),(388426,122964,'1641570075','deals','border-top-color','$content-border-1',0,''),(388427,122964,'1641570075','deals','border-top-width','1',0,''),(388428,122964,'1641570075','deals','padding-top','30',0,'5639'),(388429,122964,'1641570075','deals','padding-bottom','30',0,'5639'),(388430,122965,'1683024814.1915','deals','banners_group','18',0,''),(388431,122965,'1683024814.1915','deals','style_class','homeBanner',0,''),(388432,122967,'117394','deals','block_type','1',0,''),(388433,122968,'117395','deals','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(388434,122970,'117397','deals','block_type','1',0,''),(388435,122970,'117397','deals','padding-top','40',0,''),(388436,122970,'117397','deals','padding-bottom','80',0,''),(388437,122971,'117398','deals','block_type','6',0,''),(388438,122972,'117399','deals','block_type','1',0,''),(388439,122972,'117399','deals','padding-top','20',0,''),(388440,122972,'117399','deals','padding-left','20',0,''),(388441,122972,'117399','deals','padding-right','20',0,''),(388442,122972,'117399','deals','padding-bottom','20',0,''),(388443,122972,'117399','deals','border-top-width','1',0,''),(388444,122972,'117399','deals','border-left-width','1',0,''),(388445,122972,'117399','deals','border-right-width','1',0,''),(388446,122972,'117399','deals','border-bottom-width','1',0,''),(388447,122972,'117399','deals','border-top-color','$content-border-1',0,''),(388448,122972,'117399','deals','border-left-color','$content-border-1',0,''),(388449,122972,'117399','deals','border-right-color','$content-border-1',0,''),(388450,122972,'117399','deals','border-bottom-color','$content-border-1',0,''),(388451,122972,'117399','deals','margin-right','20',0,''),(388452,122975,'117402','deals','block_type','1',0,''),(388453,122975,'117402','deals','padding-top','20',0,''),(388454,122976,'117403','deals','block_type','6',0,''),(388455,122977,'117404','deals','padding-right','20',0,''),(388456,122979,'117406','deals','block_type','1',0,''),(388457,122979,'117406','deals','padding-top','20',0,''),(388458,122980,'117407','deals','block_type','6',0,''),(388459,122981,'117408','deals','padding-right','20',0,''),(388460,122983,'117410','deals','block_type','1',0,''),(388461,122983,'117410','deals','style_class','account-password-wrap',0,''),(388462,122984,'117411','deals','block_type','6',0,''),(388463,122984,'117411','deals','schema','6-3',0,'5639'),(388464,122985,'117412','deals','aria_name','account-menu',0,''),(388528,123006,'117414','deals','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(388529,123007,'117415','deals','block_type','1',0,''),(388530,123007,'117415','deals','padding-top','20',0,''),(388531,123008,'117416','deals','tab_1','RETURNING CUSTOMER',1,''),(388532,123008,'117416','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(388533,123008,'117416','deals','tab_1','RETURNING CUSTOMER',2,''),(388534,123008,'117416','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(388535,123008,'117416','deals','tab_1','RETURNING CUSTOMER',3,''),(388536,123008,'117416','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(388537,123008,'117416','deals','tab_1','RETURNING CUSTOMER',4,''),(388538,123008,'117416','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(388539,123009,'117417','deals','max-width','800',0,''),(388540,123009,'117417','deals','margin_left_measure','auto',0,''),(388541,123009,'117417','deals','margin_right_measure','auto',0,''),(388542,123010,'117418','deals','block_type','8',0,''),(388543,123011,'117419','deals','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(388544,123012,'117420','deals','block_type','1',0,''),(388545,123012,'117420','deals','padding-left','20',0,''),(388546,123012,'117420','deals','padding-right','20',0,''),(388547,123014,'117422','deals','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(388548,123015,'117423','deals','block_type','1',0,''),(388549,123016,'117424','deals','block_type','1',0,''),(388550,123017,'117425','deals','margin-left','0',0,''),(388551,123017,'117425','deals','margin-right','0',0,''),(388552,123017,'117425','deals','margin-bottom','20',0,''),(388553,123018,'117426','deals','margin-bottom','30',0,''),(388554,123019,'117427','deals','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(388555,123020,'117428','deals','block_type','1',0,''),(388556,123022,'117430','deals','block_type','6',0,''),(388557,123022,'117430','deals','font-weight','400',0,''),(388558,123022,'117430','deals','schema','6-2',0,'5660'),(388559,123022,'117430','deals','schema','6-2',0,'5639'),(388560,123023,'117431','deals','font-weight','400',0,''),(388561,123023,'117431','deals','padding-right','40',0,''),(388562,123023,'117431','deals','padding-right','0',0,'5660'),(388563,123023,'117431','deals','padding-right','0',0,'5639'),(388564,123024,'117432','deals','col_in_row','3',0,''),(388565,123024,'117432','deals','products_align','left',0,''),(388566,123024,'117432','deals','font-weight','400',0,''),(388567,123024,'117432','deals','show_qty_input','0',0,''),(388568,123024,'117432','deals','listing_type','productListing',0,''),(388569,123024,'117432','deals','listing_type_rows','no',0,''),(388570,123024,'117432','deals','show_buy_button_b2b','on',0,''),(388571,123024,'117432','deals','show_wishlist_button_b2b','1',0,''),(388572,123024,'117432','deals','show_compare_b2b','1',0,''),(388573,123024,'117432','deals','show_stock','0',0,''),(388574,123024,'117432','deals','show_description','0',0,''),(388575,123024,'117432','deals','show_model','0',0,''),(388576,123024,'117432','deals','show_properties','0',0,''),(388577,123024,'117432','deals','show_rating','0',0,''),(388578,123024,'117432','deals','show_rating_counts','0',0,''),(388579,123024,'117432','deals','show_price','0',0,''),(388580,123024,'117432','deals','show_buy_button','0',0,''),(388581,123024,'117432','deals','show_view_button','0',0,''),(388582,123024,'117432','deals','show_wishlist_button','0',0,''),(388583,123024,'117432','deals','show_compare','0',0,''),(388584,123024,'117432','deals','show_name_rows','0',0,''),(388585,123024,'117432','deals','show_image_rows','0',0,''),(388586,123024,'117432','deals','show_stock_rows','0',0,''),(388587,123024,'117432','deals','show_description_rows','0',0,''),(388588,123024,'117432','deals','show_model_rows','0',0,''),(388589,123024,'117432','deals','show_properties_rows','0',0,''),(388590,123024,'117432','deals','show_rating_rows','0',0,''),(388591,123024,'117432','deals','show_rating_counts_rows','0',0,''),(388592,123024,'117432','deals','show_price_rows','0',0,''),(388593,123024,'117432','deals','show_buy_button_rows','0',0,''),(388594,123024,'117432','deals','show_qty_input_rows','0',0,''),(388595,123024,'117432','deals','show_view_button_rows','0',0,''),(388596,123024,'117432','deals','show_wishlist_button_rows','0',0,''),(388597,123024,'117432','deals','show_compare_rows','0',0,''),(388598,123024,'117432','deals','show_name_b2b','0',0,''),(388599,123024,'117432','deals','show_image_b2b','0',0,''),(388600,123024,'117432','deals','show_stock_b2b','0',0,''),(388601,123024,'117432','deals','show_description_b2b','0',0,''),(388602,123024,'117432','deals','show_model_b2b','0',0,''),(388603,123024,'117432','deals','show_properties_b2b','0',0,''),(388604,123024,'117432','deals','show_rating_b2b','0',0,''),(388605,123024,'117432','deals','show_rating_counts_b2b','0',0,''),(388606,123024,'117432','deals','show_price_b2b','0',0,''),(388607,123024,'117432','deals','show_qty_input_b2b','0',0,''),(388608,123024,'117432','deals','show_view_button_b2b','0',0,''),(388609,123024,'117432','deals','show_attributes_b2b','0',0,''),(388610,123024,'117432','deals','items_on_page','9',0,''),(388611,123024,'117432','deals','col_in_row','2',0,'5639'),(388612,123024,'117432','deals','col_in_row','1',0,'5660'),(388613,123024,'117432','deals','product_names_teg','h2',0,''),(388614,123026,'117434','deals','block_type','5',0,''),(388615,123026,'117434','deals','padding-top','10',0,''),(388616,123026,'117434','deals','padding-bottom','10',0,''),(388617,123026,'117434','deals','schema','5-2',0,'5660'),(388618,123026,'117434','deals','border-top-color','$content-border-1',0,''),(388619,123026,'117434','deals','border-top-width','1',0,''),(388620,123028,'117436','deals','float','right',0,''),(388621,123029,'117437','deals','listing_type','productListing',0,''),(388622,123031,'117439','deals','block_type','1',0,''),(388623,123031,'117439','deals','padding-top','10',0,''),(388624,123031,'117439','deals','padding-bottom','10',0,''),(388625,123031,'117439','deals','border-bottom-width','1',0,''),(388626,123031,'117439','deals','border-bottom-color','$content-border-1',0,''),(388627,123031,'117439','deals','margin-left','0',0,''),(388628,123031,'117439','deals','margin-right','0',0,''),(388629,123032,'117440','deals','float','right',0,''),(388630,123032,'117440','deals','display','none',0,'5660'),(388631,123033,'117441','deals','float','left',0,''),(388632,123033,'117441','deals','clear','none',0,''),(388633,123033,'117441','deals','margin-left','20',0,''),(388634,123033,'117441','deals','display','none',0,'5660'),(388635,123034,'117442','deals','margin-right','20',0,''),(388636,123034,'117442','deals','float','right',0,''),(388637,123034,'117442','deals','clear','none',0,''),(388638,123034,'117442','deals','display','none',0,'5639'),(388639,123035,'117443','deals','float','left',0,''),(388640,123035,'117443','deals','clear','none',0,''),(388641,123035,'117443','deals','sort_pos_3','1',0,''),(388642,123035,'117443','deals','sort_pos_4','2',0,''),(388643,123035,'117443','deals','sort_pos_10','3',0,''),(388644,123035,'117443','deals','sort_pos_9','4',0,''),(388645,123035,'117443','deals','sort_pos_11','5',0,''),(388646,123035,'117443','deals','sort_pos_12','6',0,''),(388647,123035,'117443','deals','sort_pos_14','7',0,''),(388648,123035,'117443','deals','sort_pos_13','8',0,''),(388649,123035,'117443','deals','sort_pos_8','9',0,''),(388650,123035,'117443','deals','sort_pos_7','10',0,''),(388651,123035,'117443','deals','sort_pos_2','11',0,''),(388652,123035,'117443','deals','sort_pos_1','12',0,''),(388653,123035,'117443','deals','sort_pos_6','13',0,''),(388654,123035,'117443','deals','sort_pos_5','14',0,''),(388655,123035,'117443','deals','sort_pos_0','15',0,''),(388656,123035,'117443','deals','sort_hide_10','1',0,''),(388657,123035,'117443','deals','sort_hide_9','1',0,''),(388658,123035,'117443','deals','hide_icons','1',0,''),(388659,123035,'117443','deals','sort_hide_16','1',0,''),(388660,123035,'117443','deals','sort_hide_15','1',0,''),(388661,123035,'117443','deals','sort_hide_3','0',0,''),(388662,123035,'117443','deals','sort_hide_4','0',0,''),(388663,123035,'117443','deals','sort_hide_11','1',0,''),(388664,123035,'117443','deals','sort_hide_12','1',0,''),(388665,123035,'117443','deals','sort_hide_14','1',0,''),(388666,123035,'117443','deals','sort_hide_13','1',0,''),(388667,123035,'117443','deals','sort_hide_8','0',0,''),(388668,123035,'117443','deals','sort_hide_7','0',0,''),(388669,123035,'117443','deals','sort_hide_2','1',0,''),(388670,123035,'117443','deals','sort_hide_1','1',0,''),(388671,123035,'117443','deals','sort_hide_6','1',0,''),(388672,123035,'117443','deals','sort_hide_5','1',0,''),(388673,123035,'117443','deals','sort_hide_0','1',0,''),(388674,123036,'117444','deals','block_type','1',0,''),(388675,123037,'117445','deals','margin-bottom','30',0,''),(388676,123038,'117446','deals','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(388677,123039,'117447','deals','block_type','1',0,''),(388678,123040,'117448','deals','block_type','5',0,''),(388679,123040,'117448','deals','padding-top','10',0,''),(388680,123040,'117448','deals','padding-bottom','10',0,''),(388681,123040,'117448','deals','schema','5-2',0,'5660'),(388682,123040,'117448','deals','border-top-color','$content-border-1',0,''),(388683,123040,'117448','deals','border-top-width','1',0,''),(388684,123041,'117449','deals','padding-top','3',0,''),(388685,123042,'117450','deals','float','right',0,''),(388686,123042,'117450','deals','height','31',0,''),(388687,123043,'117451','deals','col_in_row','4',0,''),(388688,123043,'117451','deals','products_align','left',0,''),(388689,123043,'117451','deals','font-weight','400',0,''),(388690,123043,'117451','deals','listing_type','productListing',0,''),(388691,123043,'117451','deals','listing_type_rows','Rows',0,''),(388692,123043,'117451','deals','show_buy_button_b2b','on',0,''),(388693,123043,'117451','deals','show_wishlist_button_b2b','1',0,''),(388694,123043,'117451','deals','show_compare_b2b','1',0,''),(388695,123043,'117451','deals','show_image','0',0,''),(388696,123043,'117451','deals','show_stock','0',0,''),(388697,123043,'117451','deals','show_description','0',0,''),(388698,123043,'117451','deals','show_model','0',0,''),(388699,123043,'117451','deals','show_properties','0',0,''),(388700,123043,'117451','deals','show_rating','0',0,''),(388701,123043,'117451','deals','show_rating_counts','0',0,''),(388702,123043,'117451','deals','show_price','0',0,''),(388703,123043,'117451','deals','show_buy_button','0',0,''),(388704,123043,'117451','deals','show_view_button','0',0,''),(388705,123043,'117451','deals','show_wishlist_button','0',0,''),(388706,123043,'117451','deals','show_compare','0',0,''),(388707,123043,'117451','deals','show_name_rows','0',0,''),(388708,123043,'117451','deals','show_image_rows','0',0,''),(388709,123043,'117451','deals','show_stock_rows','0',0,''),(388710,123043,'117451','deals','show_description_rows','0',0,''),(388711,123043,'117451','deals','show_model_rows','0',0,''),(388712,123043,'117451','deals','show_properties_rows','0',0,''),(388713,123043,'117451','deals','show_rating_rows','0',0,''),(388714,123043,'117451','deals','show_rating_counts_rows','0',0,''),(388715,123043,'117451','deals','show_price_rows','0',0,''),(388716,123043,'117451','deals','show_buy_button_rows','0',0,''),(388717,123043,'117451','deals','show_qty_input_rows','0',0,''),(388718,123043,'117451','deals','show_view_button_rows','0',0,''),(388719,123043,'117451','deals','show_wishlist_button_rows','0',0,''),(388720,123043,'117451','deals','show_compare_rows','0',0,''),(388721,123043,'117451','deals','show_name_b2b','0',0,''),(388722,123043,'117451','deals','show_image_b2b','0',0,''),(388723,123043,'117451','deals','show_stock_b2b','0',0,''),(388724,123043,'117451','deals','show_description_b2b','0',0,''),(388725,123043,'117451','deals','show_model_b2b','0',0,''),(388726,123043,'117451','deals','show_properties_b2b','0',0,''),(388727,123043,'117451','deals','show_rating_b2b','0',0,''),(388728,123043,'117451','deals','show_rating_counts_b2b','0',0,''),(388729,123043,'117451','deals','show_price_b2b','0',0,''),(388730,123043,'117451','deals','show_qty_input_b2b','0',0,''),(388731,123043,'117451','deals','show_view_button_b2b','0',0,''),(388732,123043,'117451','deals','show_attributes_b2b','0',0,''),(388733,123043,'117451','deals','items_on_page','12',0,''),(388734,123043,'117451','deals','col_in_row','2',0,'5639'),(388735,123043,'117451','deals','col_in_row','1',0,'5660'),(388736,123043,'117451','deals','product_names_teg','h2',0,''),(388737,123046,'117454','deals','block_type','1',0,''),(388738,123047,'117455','deals','block_type','1',0,''),(388739,123047,'117455','deals','padding-top','10',0,''),(388740,123047,'117455','deals','padding-bottom','10',0,''),(388741,123047,'117455','deals','border-bottom-width','1',0,''),(388742,123047,'117455','deals','border-bottom-color','$content-border-1',0,''),(388743,123047,'117455','deals','margin-left','0',0,''),(388744,123047,'117455','deals','margin-right','0',0,''),(388745,123048,'117456','deals','clear','none',0,''),(388746,123048,'117456','deals','float','left',0,''),(388747,123048,'117456','deals','padding-top','3',0,''),(388748,123048,'117456','deals','margin-left','20',0,''),(388749,123048,'117456','deals','display_none','1',0,'5639'),(388750,123049,'117457','deals','float','right',0,''),(388751,123049,'117457','deals','display','none',0,'5660'),(388752,123050,'117458','deals','margin-right','20',0,''),(388753,123050,'117458','deals','float','right',0,''),(388754,123050,'117458','deals','clear','none',0,''),(388755,123050,'117458','deals','display','none',0,'5639'),(388756,123051,'117459','deals','float','left',0,''),(388757,123051,'117459','deals','clear','none',0,''),(388758,123051,'117459','deals','margin-left','20',0,''),(388759,123051,'117459','deals','display','none',0,'5660'),(388760,123051,'117459','deals','display_none','1',0,'5630'),(388761,123052,'117460','deals','float','left',0,''),(388762,123052,'117460','deals','clear','none',0,''),(388763,123052,'117460','deals','sort_pos_3','2',0,''),(388764,123052,'117460','deals','sort_pos_4','3',0,''),(388765,123052,'117460','deals','sort_pos_10','11',0,''),(388766,123052,'117460','deals','sort_pos_9','10',0,''),(388767,123052,'117460','deals','sort_pos_11','12',0,''),(388768,123052,'117460','deals','sort_pos_12','13',0,''),(388769,123052,'117460','deals','sort_pos_14','15',0,''),(388770,123052,'117460','deals','sort_pos_13','14',0,''),(388771,123052,'117460','deals','sort_pos_8','4',0,''),(388772,123052,'117460','deals','sort_pos_7','5',0,''),(388773,123052,'117460','deals','sort_pos_2','7',0,''),(388774,123052,'117460','deals','sort_pos_1','6',0,''),(388775,123052,'117460','deals','sort_pos_6','9',0,''),(388776,123052,'117460','deals','sort_pos_5','8',0,''),(388777,123052,'117460','deals','sort_pos_0','1',0,''),(388778,123052,'117460','deals','sort_hide_10','1',0,''),(388779,123052,'117460','deals','sort_hide_9','1',0,''),(388780,123052,'117460','deals','sort_pos_15','16',0,''),(388781,123052,'117460','deals','sort_pos_16','17',0,''),(388782,123052,'117460','deals','sort_hide_4','0',0,''),(388783,123052,'117460','deals','sort_hide_3','0',0,''),(388784,123052,'117460','deals','sort_hide_16','1',0,''),(388785,123052,'117460','deals','sort_hide_15','1',0,''),(388786,123052,'117460','deals','sort_hide_11','1',0,''),(388787,123052,'117460','deals','sort_hide_12','1',0,''),(388788,123052,'117460','deals','sort_hide_14','1',0,''),(388789,123052,'117460','deals','sort_hide_13','1',0,''),(388790,123052,'117460','deals','sort_hide_8','0',0,''),(388791,123052,'117460','deals','sort_hide_7','0',0,''),(388792,123052,'117460','deals','sort_hide_2','1',0,''),(388793,123052,'117460','deals','sort_hide_1','1',0,''),(388794,123052,'117460','deals','sort_hide_6','1',0,''),(388795,123052,'117460','deals','sort_hide_5','1',0,''),(388796,123052,'117460','deals','sort_hide_0','0',0,''),(388797,123052,'117460','deals','hide_icons','1',0,''),(388798,123053,'117461','deals','margin-bottom','20',0,''),(388799,123055,'117462','deals','block_type','1',0,''),(388800,123055,'117462','deals','style_class','account-order-history',0,''),(388873,123079,'117467','deals','block_type','1',0,''),(388874,123079,'117467','deals','style_class','account-order-history-info',0,''),(389041,123138,'117507','deals','block_type','1',0,''),(389042,123138,'117507','deals','style_class','account-order-pay',0,''),(389043,123139,'117508','deals','block_type','6',0,''),(389044,123139,'117508','deals','schema','6-3',0,'5639'),(389045,123140,'117509','deals','aria_name','account-menu',0,''),(389109,123161,'117511','deals','block_type','3',0,''),(389110,123162,'117512','deals','block_type','1',0,''),(389111,123162,'117512','deals','padding-right','20',0,''),(389112,123162,'117512','deals','padding-bottom','20',0,''),(389113,123163,'117513','deals','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(389114,123164,'117514','deals','orders_data','name',0,''),(389115,123164,'117514','deals','padding-left','30',0,''),(389116,123165,'117515','deals','block_type','1',0,''),(389117,123166,'117516','deals','padding-left','30',0,''),(389118,123167,'117517','deals','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(389119,123168,'117518','deals','block_type','1',0,''),(389120,123168,'117518','deals','padding-right','20',0,''),(389121,123168,'117518','deals','padding-bottom','20',0,''),(389122,123169,'117519','deals','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(389123,123170,'117520','deals','orders_data','delivery_address',0,''),(389124,123170,'117520','deals','padding-left','30',0,''),(389125,123171,'117521','deals','block_type','1',0,''),(389126,123171,'117521','deals','padding-right','20',0,''),(389127,123172,'117522','deals','orders_data','shipping_method',0,''),(389128,123172,'117522','deals','padding-left','30',0,''),(389129,123173,'117523','deals','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(389130,123174,'117524','deals','block_type','1',0,''),(389131,123175,'117525','deals','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(389132,123176,'117526','deals','orders_data','payment_method',0,''),(389133,123176,'117526','deals','padding-left','30',0,''),(389134,123177,'117527','deals','block_type','1',0,''),(389135,123177,'117527','deals','padding-bottom','20',0,''),(389136,123178,'117528','deals','orders_data','billing_address',0,''),(389137,123178,'117528','deals','padding-left','30',0,''),(389138,123179,'117529','deals','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(389139,123180,'117530','deals','margin-bottom','20',0,''),(389140,123180,'117530','deals','orders_data','name',0,''),(389141,123181,'117531','deals','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(389142,123184,'117534','deals','width','680',0,''),(389143,123184,'117534','deals','font-weight','400',0,''),(389144,123184,'117534','deals','font-size','12',0,''),(389145,123184,'117534','deals','padding-top','20',0,''),(389146,123184,'117534','deals','padding-bottom','20',0,''),(389147,123185,'117535','deals','block_type','2',0,''),(389148,123185,'117535','deals','font-weight','normal',0,''),(389149,123185,'117535','deals','padding-bottom','20',0,''),(389150,123186,'117536','deals','font-weight','400',0,''),(389151,123186,'117536','deals','padding-top','10',0,''),(389152,123186,'117536','deals','logo','themes/deals/img/logo-2.png',1,''),(389153,123186,'117536','deals','logo','themes/deals/img/logo-2.png',2,''),(389154,123186,'117536','deals','logo','themes/deals/img/logo-2.png',3,''),(389155,123186,'117536','deals','logo','themes/deals/img/logo-2.png',4,''),(389156,123187,'117537','deals','block_type','11',0,''),(389157,123187,'117537','deals','font-weight','normal',0,''),(389158,123188,'117538','deals','text','<p>Email:</p>',1,''),(389159,123188,'117538','deals','font-weight','normal',0,''),(389160,123188,'117538','deals','text-align','right',0,''),(389161,123188,'117538','deals','text','<p>Email:</p>',2,''),(389162,123188,'117538','deals','text','<p>Email:</p>',3,''),(389163,123188,'117538','deals','text','<p>Email:</p>',4,''),(389164,123189,'117539','deals','font-weight','normal',0,''),(389165,123189,'117539','deals','text-align','right',0,''),(389166,123190,'117540','deals','block_type','11',0,''),(389167,123190,'117540','deals','font-weight','normal',0,''),(389168,123191,'117541','deals','text','<p>Phone:</p>',1,''),(389169,123191,'117541','deals','font-weight','normal',0,''),(389170,123191,'117541','deals','text-align','right',0,''),(389171,123191,'117541','deals','text','<p>Phone:</p>',2,''),(389172,123191,'117541','deals','text','<p>Phone:</p>',3,''),(389173,123191,'117541','deals','text','<p>Phone:</p>',4,''),(389174,123192,'117542','deals','font-weight','normal',0,''),(389175,123192,'117542','deals','text-align','right',0,''),(389176,123193,'117543','deals','block_type','1',0,''),(389177,123194,'117544','deals','font-weight','400',0,''),(389178,123194,'117544','deals','text-align','right',0,''),(389179,123194,'117544','deals','padding-bottom','10',0,''),(389180,123194,'117544','deals','address_spacer',',',0,''),(389181,123194,'117544','deals','font-size','12',0,''),(389182,123195,'117545','deals','block_type','11',0,''),(389183,123195,'117545','deals','font-weight','400',0,''),(389184,123196,'117546','deals','text','<p>Web:</p>',1,''),(389185,123196,'117546','deals','font-weight','400',0,''),(389186,123196,'117546','deals','text-align','right',0,''),(389187,123196,'117546','deals','text','<p>Web:</p>',2,''),(389188,123196,'117546','deals','text','<p>Web:</p>',3,''),(389189,123196,'117546','deals','text','<p>Web:</p>',4,''),(389190,123197,'117547','deals','font-weight','normal',0,''),(389191,123197,'117547','deals','text-align','right',0,''),(389192,123198,'117548','deals','font-weight','normal',0,''),(389193,123198,'117548','deals','padding-top','20',0,''),(389194,123198,'117548','deals','font-size','12',0,''),(389195,123199,'117549','deals','block_type','1',0,''),(389196,123199,'117549','deals','font-weight','normal',0,''),(389197,123199,'117549','deals','padding-top','10',0,''),(389198,123199,'117549','deals','padding-bottom','10',0,''),(389199,123201,'117551','deals','text','<p>If undelivered please return to:</p>',1,''),(389200,123201,'117551','deals','font-weight','bold',0,''),(389201,123201,'117551','deals','text','<p>If undelivered please return to:</p>',2,''),(389202,123201,'117551','deals','text','<p>If undelivered please return to:</p>',3,''),(389203,123201,'117551','deals','text','<p>If undelivered please return to:</p>',4,''),(389204,123202,'117552','deals','block_type','4',0,''),(389205,123202,'117552','deals','font-weight','400',0,''),(389206,123202,'117552','deals','border-top-width','1',0,''),(389207,123202,'117552','deals','border-top-color','$content-border-1',0,''),(389208,123202,'117552','deals','border-left-width','1',0,''),(389209,123202,'117552','deals','border-left-color','$content-border-1',0,''),(389210,123202,'117552','deals','border-right-width','1',0,''),(389211,123202,'117552','deals','border-right-color','$content-border-1',0,''),(389212,123202,'117552','deals','border-bottom-width','1',0,''),(389213,123202,'117552','deals','border-bottom-color','$content-border-1',0,''),(389214,123203,'117553','deals','block_type','2',0,''),(389215,123203,'117553','deals','font-weight','normal',0,''),(389216,123203,'117553','deals','border-right-width','1',0,''),(389217,123203,'117553','deals','border-right-color','$content-border-1',0,''),(389218,123204,'117554','deals','block_type','1',0,''),(389219,123204,'117554','deals','font-weight','normal',0,''),(389220,123204,'117554','deals','border-right-width','1',0,''),(389221,123204,'117554','deals','border-right-color','$content-border-1',0,''),(389222,123204,'117554','deals','background-color','$content-bg-2',0,''),(389223,123204,'117554','deals','padding-top','10',0,''),(389224,123204,'117554','deals','padding-left','10',0,''),(389225,123204,'117554','deals','padding-right','10',0,''),(389226,123204,'117554','deals','padding-bottom','10',0,''),(389227,123205,'117555','deals','font-size','12',0,''),(389228,123205,'117555','deals','font-weight','normal',0,''),(389229,123206,'117556','deals','text','<p>SHIPPING ADDRESS:</p>',1,''),(389230,123206,'117556','deals','font-size','13',0,''),(389231,123206,'117556','deals','font-weight','bold',0,''),(389232,123206,'117556','deals','padding-bottom','10',0,''),(389233,123206,'117556','deals','text','<p>SHIPPING ADDRESS:</p>',2,''),(389234,123206,'117556','deals','text','<p>SHIPPING ADDRESS:</p>',3,''),(389235,123206,'117556','deals','text','<p>SHIPPING ADDRESS:</p>',4,''),(389236,123207,'117557','deals','block_type','1',0,''),(389237,123207,'117557','deals','font-weight','normal',0,''),(389238,123207,'117557','deals','padding-top','10',0,''),(389239,123207,'117557','deals','padding-left','10',0,''),(389240,123207,'117557','deals','padding-right','10',0,''),(389241,123207,'117557','deals','padding-bottom','10',0,''),(389242,123208,'117558','deals','text','<p>CUSTOMER:</p>',1,''),(389243,123208,'117558','deals','font-size','13',0,''),(389244,123208,'117558','deals','font-weight','bold',0,''),(389245,123208,'117558','deals','text','<p>CUSTOMER:</p>',2,''),(389246,123208,'117558','deals','text','<p>CUSTOMER:</p>',3,''),(389247,123208,'117558','deals','text','<p>CUSTOMER:</p>',4,''),(389248,123209,'117559','deals','font-size','12',0,''),(389249,123211,'117561','deals','text','<p>PHONE NUMBER:</p>',1,''),(389250,123211,'117561','deals','font-size','13',0,''),(389251,123211,'117561','deals','font-weight','bold',0,''),(389252,123211,'117561','deals','padding-top','10',0,''),(389253,123211,'117561','deals','text','<p>PHONE NUMBER:</p>',2,''),(389254,123211,'117561','deals','text','<p>PHONE NUMBER:</p>',3,''),(389255,123211,'117561','deals','text','<p>PHONE NUMBER:</p>',4,''),(389256,123212,'117562','deals','font-size','12',0,''),(389257,123213,'117563','deals','text','<p>E-MAIL ADDRESS:</p>',1,''),(389258,123213,'117563','deals','font-size','13',0,''),(389259,123213,'117563','deals','font-weight','bold',0,''),(389260,123213,'117563','deals','padding-top','10',0,''),(389261,123213,'117563','deals','text','<p>E-MAIL ADDRESS:</p>',2,''),(389262,123213,'117563','deals','text','<p>E-MAIL ADDRESS:</p>',3,''),(389263,123213,'117563','deals','text','<p>E-MAIL ADDRESS:</p>',4,''),(389264,123214,'117564','deals','block_type','2',0,''),(389265,123214,'117564','deals','font-weight','normal',0,''),(389266,123214,'117564','deals','border-right-width','1',0,''),(389267,123214,'117564','deals','border-right-color','$content-border-1',0,''),(389268,123214,'117564','deals','border-top-width','1',0,''),(389269,123214,'117564','deals','border-top-color','$content-border-1',0,''),(389270,123215,'117565','deals','block_type','1',0,''),(389271,123215,'117565','deals','font-weight','normal',0,''),(389272,123215,'117565','deals','padding-top','10',0,''),(389273,123215,'117565','deals','padding-left','10',0,''),(389274,123215,'117565','deals','padding-right','10',0,''),(389275,123215,'117565','deals','padding-bottom','10',0,''),(389276,123215,'117565','deals','border-right-width','1',0,''),(389277,123215,'117565','deals','border-right-color','$content-border-1',0,''),(389278,123217,'117567','deals','text','<p>Shipping via</p>',1,''),(389279,123217,'117567','deals','font-weight','bold',0,''),(389280,123217,'117567','deals','text','<p>Shipping via</p>',2,''),(389281,123217,'117567','deals','text','<p>Shipping via</p>',3,''),(389282,123217,'117567','deals','text','<p>Shipping via</p>',4,''),(389283,123218,'117568','deals','block_type','1',0,''),(389284,123218,'117568','deals','font-weight','normal',0,''),(389285,123218,'117568','deals','padding-top','10',0,''),(389286,123218,'117568','deals','padding-left','10',0,''),(389287,123218,'117568','deals','padding-right','10',0,''),(389288,123218,'117568','deals','padding-bottom','10',0,''),(389289,123220,'117570','deals','text','<p>Shipping service</p>',1,''),(389290,123220,'117570','deals','font-weight','bold',0,''),(389291,123220,'117570','deals','text','<p>Shipping service</p>',2,''),(389292,123220,'117570','deals','text','<p>Shipping service</p>',3,''),(389293,123220,'117570','deals','text','<p>Shipping service</p>',4,''),(389294,123221,'117571','deals','font-weight','normal',0,''),(389295,123221,'117571','deals','text-align','center',0,''),(389296,123221,'117571','deals','padding-top','40',0,''),(389297,123223,'1639661081','deals','padding-top','15',0,''),(389298,123224,'117572','deals','block_type','1',0,''),(389299,123225,'117573','deals','block_type','8',0,''),(389300,123226,'1638807246','deals','text','<span></span>',0,''),(389301,123227,'117574','deals','text','##TEXT_MAIN##',0,''),(389302,123227,'117574','deals','margin-bottom','20',0,''),(389303,123227,'117574','deals','text-align','center',0,''),(389304,123228,'117575','deals','margin-bottom','20',0,''),(389305,123229,'117576','deals','text','<h1>##HEADING_TITLE##</h1>',0,''),(389306,123231,'117578','deals','block_type','2',0,''),(389307,123232,'117579','deals','block_type','1',0,''),(389308,123232,'117579','deals','style_class','product',0,''),(389309,123232,'117579','deals','padding-right','10',0,''),(389310,123232,'117579','deals','padding-bottom','20',0,''),(389311,123233,'117580','deals','block_type','1',0,''),(389312,123234,'117581','deals','product_element','products_name',0,''),(389313,123234,'117581','deals','font-family','$font-1',0,''),(389314,123234,'117581','deals','padding-bottom','10',0,''),(389315,123234,'117581','deals','font-size','16',0,''),(389316,123235,'117582','deals','block_type','2',0,''),(389317,123236,'117583','deals','product_element','image',0,''),(389318,123236,'117583','deals','padding-right','10',0,''),(389319,123237,'117584','deals','product_element','products_price_old',0,''),(389320,123237,'117584','deals','font-family','$font-1',0,''),(389321,123237,'117584','deals','font-size','14',0,''),(389322,123237,'117584','deals','text-decoration','line-through',0,''),(389323,123238,'117585','deals','product_element','products_price',0,''),(389324,123238,'117585','deals','font-family','$font-1',0,''),(389325,123238,'117585','deals','font-size','20',0,''),(389326,123238,'117585','deals','padding-top','20',0,''),(389327,123239,'117586','deals','block_type','1',0,''),(389328,123239,'117586','deals','style_class','product',0,''),(389329,123239,'117586','deals','padding-left','10',0,''),(389330,123239,'117586','deals','padding-bottom','20',0,''),(389331,123240,'117587','deals','block_type','2',0,''),(389332,123241,'117588','deals','product_element','image',0,''),(389333,123241,'117588','deals','padding-right','10',0,''),(389334,123242,'117589','deals','font-size','14',0,''),(389335,123242,'117589','deals','font-family','$font-1',0,''),(389336,123242,'117589','deals','text-decoration','line-through',0,''),(389337,123242,'117589','deals','product_element','products_price_old',0,''),(389338,123243,'117590','deals','product_element','products_price',0,''),(389339,123243,'117590','deals','font-family','$font-1',0,''),(389340,123243,'117590','deals','font-size','20',0,''),(389341,123243,'117590','deals','padding-top','20',0,''),(389342,123244,'117591','deals','block_type','1',0,''),(389343,123245,'117592','deals','product_element','products_name',0,''),(389344,123245,'117592','deals','font-family','$font-1',0,''),(389345,123245,'117592','deals','font-size','16',0,''),(389346,123245,'117592','deals','padding-bottom','10',0,''),(389347,123246,'117593','deals','font-size','30',0,''),(389348,123246,'117593','deals','font-family','$font-1',0,''),(389349,123246,'117593','deals','text-align','center',0,''),(389350,123246,'117593','deals','padding-bottom','50',0,''),(389351,123247,'117594','deals','padding-bottom','20',0,''),(389352,123247,'117594','deals','text-align','center',0,''),(389353,123248,'117595','deals','width','680',0,''),(389354,123249,'117596','deals','padding-top','200',0,''),(389355,123249,'117596','deals','padding-left','200',0,''),(389356,123249,'117596','deals','logo','themes/deals/img/oscommerce_logo.jpg',1,''),(389357,123249,'117596','deals','logo','themes/deals/img/oscommerce_logo.jpg',2,''),(389358,123249,'117596','deals','logo','themes/deals/img/oscommerce_logo.jpg',3,''),(389359,123249,'117596','deals','logo','themes/deals/img/oscommerce_logo.jpg',4,''),(389360,123250,'117597','deals','text','osCommerce 4',1,''),(389361,123250,'117597','deals','font-family','$font-1',0,''),(389362,123250,'117597','deals','font-size','40',0,''),(389363,123250,'117597','deals','padding-top','50',0,''),(389364,123250,'117597','deals','text-align','center',0,''),(389365,123250,'117597','deals','text','osCommerce 4',2,''),(389366,123250,'117597','deals','text','osCommerce 4',3,''),(389367,123250,'117597','deals','text','osCommerce 4',4,''),(389368,123251,'117598','deals','block_type','2',0,''),(389369,123251,'117598','deals','border-top-width','1',0,''),(389370,123251,'117598','deals','border-top-color','$content-border-1',0,''),(389371,123252,'117599','deals','text-align','right',0,''),(389372,123252,'117599','deals','padding-top','15',0,''),(389373,123252,'117599','deals','padding-bottom','15',0,''),(389374,123252,'117599','deals','font-size','14',0,''),(389375,123253,'117600','deals','font-family','$font-1',0,''),(389376,123253,'117600','deals','text-align','center',0,''),(389377,123253,'117600','deals','font-size','20',0,''),(389378,123253,'117600','deals','color','$content-color-1',0,''),(389379,123253,'117600','deals','border-bottom-width','1',0,''),(389380,123253,'117600','deals','border-bottom-color','$content-border-1',0,''),(389381,123253,'117600','deals','padding-top','10',0,''),(389382,123253,'117600','deals','padding-bottom','10',0,''),(389383,123254,'117601','deals','block_type','1',0,''),(389384,123255,'117602','deals','block_type','6',0,''),(389385,123255,'117602','deals','schema','6-3',0,'5639'),(389386,123256,'117603','deals','aria_name','account-menu',0,''),(389450,123276,'117604','deals','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(389451,123277,'117606','deals','max_items','10',0,''),(389452,123277,'117606','deals','padding-bottom','20',0,''),(389453,123278,'117607','deals','block_type','1',0,''),(389454,123278,'117607','deals','padding-top','20',0,''),(389455,123278,'117607','deals','padding-left','20',0,''),(389456,123278,'117607','deals','padding-right','20',0,''),(389457,123278,'117607','deals','padding-bottom','20',0,''),(389458,123279,'117608','deals','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(389459,123281,'117610','deals','block_type','1',0,''),(389460,123282,'117611','deals','margin_left_measure','auto',0,''),(389461,123282,'117611','deals','margin_right_measure','auto',0,''),(389462,123282,'117611','deals','max-width','560',0,''),(389463,123283,'117612','deals','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(389464,123284,'117613','deals','margin-bottom','30',0,''),(389465,123285,'1683114469.26259','deals','block_type','1',0,''),(389466,123286,'1683114469.295895','deals','font-weight','400',0,''),(389467,123287,'1683114469.29722','deals','block_type','11',0,''),(389468,123287,'1683114469.29722','deals','padding-bottom','30',0,''),(389469,123287,'1683114469.29722','deals','schema','11-2',0,'5630'),(389470,123287,'1683114469.29722','deals','padding-bottom','20',0,'5639'),(389471,123288,'1683114469.299773','deals','font-weight','400',0,''),(389472,123288,'1683114469.299773','deals','padding-top','20',0,''),(389473,123288,'1683114469.299773','deals','padding-right','20',0,''),(389474,123288,'1683114469.299773','deals','box_align','4',0,''),(389475,123288,'1683114469.299773','deals','margin-bottom','50',0,''),(389476,123288,'1683114469.299773','deals','align_position','horizontal',0,''),(389477,123289,'1683114469.301198','deals','float','left',0,''),(389478,123291,'1683114469.30314','deals','block_type','2',0,''),(389479,123292,'1683114469.304286','deals','margin-bottom','10',0,''),(389480,123293,'1683114469.304862','deals','reviews_count','right',0,''),(389481,123293,'1683114469.304862','deals','padding-bottom','15',0,''),(389482,123294,'1683114469.306253','deals','text-align','right',0,''),(389483,123295,'1683114469.307492','deals','text-align','right',0,''),(389484,123296,'1683114469.3081','deals','block_type','2',0,''),(389485,123296,'1683114469.3081','deals','schema','2-2',0,'5660'),(389486,123297,'1683114469.309625','deals','padding-right','20',0,''),(389487,123297,'1683114469.309625','deals','margin-bottom','20',0,''),(389488,123297,'1683114469.309625','deals','padding-right','0',0,'5660'),(389489,123298,'1683114469.310518','deals','text','&nbsp;',0,''),(389490,123299,'1683114469.31285','deals','padding-right','20',0,''),(389491,123299,'1683114469.31285','deals','padding-right','0',0,'5660'),(389492,123300,'1683114469.313585','deals','margin-bottom','20',0,''),(389493,123300,'1683114469.313585','deals','max-width','500',0,''),(389494,123300,'1683114469.313585','deals','padding-right','20',0,''),(389495,123300,'1683114469.313585','deals','padding-right','0',0,'5660'),(389496,123301,'1683114469.319743','deals','padding-right','20',0,''),(389497,123301,'1683114469.319743','deals','padding-right','0',0,'5660'),(389498,123302,'1683114469.328177','deals','padding-right','20',0,''),(389499,123302,'1683114469.328177','deals','padding-right','0',0,'5660'),(389500,123302,'1683114469.328177','deals','padding-bottom','15',0,''),(389501,123303,'1683114469.329314','deals','padding-right','20',0,''),(389502,123303,'1683114469.329314','deals','padding-right','0',0,'5660'),(389503,123303,'1683114469.329314','deals','padding-bottom','15',0,'5660'),(389504,123304,'1683114469.33265','deals','block_type','1',0,''),(389505,123304,'1683114469.33265','deals','float','right',0,''),(389506,123304,'1683114469.33265','deals','float','none',0,'5660'),(389507,123305,'1683114469.333690','deals','font-weight','400',0,''),(389508,123305,'1683114469.333690','deals','line_height_measure','px',0,''),(389509,123305,'1683114469.333690','deals','text-align','right',0,''),(389510,123305,'1683114469.333690','deals','float','right',0,''),(389511,123306,'1683114469.334771','deals','box_align','2',0,''),(389512,123306,'1683114469.334771','deals','margin-bottom','15',0,'5639'),(389513,123306,'1683114469.334771','deals','text-align','right',0,'5639'),(389514,123306,'1683114469.334771','deals','text-align','center',0,''),(389515,123306,'1683114469.334771','deals','float','right',0,''),(389516,123306,'1683114469.334771','deals','padding-right','10',0,''),(389517,123306,'1683114469.334771','deals','float','left',0,'5660'),(389518,123306,'1683114469.334771','deals','text-align','left',0,'5660'),(389519,123307,'1683114469.34343','deals','text-align','right',0,''),(389520,123307,'1683114469.34343','deals','width','100',0,'5630'),(389521,123307,'1683114469.34343','deals','width_measure','%',0,'5630'),(389522,123307,'1683114469.34343','deals','float','none',0,'5630'),(389523,123307,'1683114469.34343','deals','margin-bottom','15',0,''),(389524,123307,'1683114469.34343','deals','padding-top','10',0,''),(389525,123307,'1683114469.34343','deals','clear','both',0,''),(389526,123308,'1683114469.347391','deals','text-align','right',0,''),(389527,123308,'1683114469.347391','deals','margin-bottom','15',0,''),(389528,123309,'1683114469.351242','deals','cat_description','1',0,''),(389529,123309,'1683114469.351242','deals','link_description','1',0,''),(389530,123309,'1683114469.351242','deals','length_description','300',0,''),(389531,123309,'1683114469.351242','deals','margin-bottom','20',0,''),(389532,123310,'1683114493.817723','deals','block_type','1',0,''),(389533,123310,'1683114493.817723','deals','padding-top','25',0,''),(389534,123310,'1683114493.817723','deals','padding-bottom','25',0,''),(389535,123310,'1683114493.817723','deals','padding-top','0',0,'5639'),(389536,123310,'1683114493.817723','deals','style_class','catalog-product-wrap',0,''),(389537,123311,'1683114493.851867','deals','hTagsInline','block',0,''),(389538,123311,'1683114493.851867','deals','padding-bottom','30',0,''),(389539,123312,'1683114493.853236','deals','padding-bottom','10',0,''),(389540,123312,'1683114493.853236','deals','padding-top','5',0,''),(389541,123313,'1683114493.85674','deals','block_type','1',0,''),(389542,123314,'1683114493.857344','deals','font-weight','400',0,''),(389543,123314,'1683114493.857344','deals','padding-bottom','20',0,''),(389544,123314,'1683114493.857344','deals','show_compare','1',0,''),(389545,123314,'1683114493.857344','deals','show_name','0',0,''),(389546,123314,'1683114493.857344','deals','show_image','0',0,''),(389547,123314,'1683114493.857344','deals','show_stock','0',0,''),(389548,123314,'1683114493.857344','deals','show_description','0',0,''),(389549,123314,'1683114493.857344','deals','show_model','1',0,''),(389550,123314,'1683114493.857344','deals','show_properties','1',0,''),(389551,123314,'1683114493.857344','deals','show_rating','0',0,''),(389552,123314,'1683114493.857344','deals','show_rating_counts','0',0,''),(389553,123314,'1683114493.857344','deals','show_price','0',0,''),(389554,123314,'1683114493.857344','deals','show_buy_button','1',0,''),(389555,123314,'1683114493.857344','deals','show_view_button','1',0,''),(389556,123314,'1683114493.857344','deals','show_wishlist_button','1',0,''),(389557,123314,'1683114493.857344','deals','listing_type','productListing',0,''),(389558,123314,'1683114493.857344','deals','col_in_row','2',0,'5639'),(389559,123314,'1683114493.857344','deals','col_in_row','1',0,'5660'),(389560,123314,'1683114493.857344','deals','col_in_row','4',0,''),(389561,123314,'1683114493.857344','deals','view_as','carousel',0,''),(389562,123314,'1683114493.857344','deals','show_bonus_points','1',0,''),(389563,123314,'1683114493.857344','deals','show_qty_input','1',0,''),(389564,123314,'1683114493.857344','deals','show_attributes','1',0,''),(389565,123314,'1683114493.857344','deals','hide_parents','2',0,''),(389566,123315,'1683114493.861475','deals','text','<h2>##VIEWED_PRODUCTS##</h2>',0,''),(389567,123316,'1683114493.86940','deals','block_type','1',0,''),(389568,123316,'1683114493.86940','deals','margin-bottom','30',0,''),(389569,123329,'120919.000001','deals','block_type','1',0,''),(389570,123329,'120919.000001','deals','style_class','item-holder',0,''),(389571,123329,'120919.000001','deals','padding-top','25',0,''),(389572,123329,'120919.000001','deals','padding-left','25',0,''),(389573,123329,'120919.000001','deals','padding-right','25',0,''),(389574,123329,'120919.000001','deals','padding-bottom','25',0,''),(389575,123332,'117668','deals','description_characters','90',0,''),(389576,123335,'117673.000001','deals','margin-bottom','7',0,''),(389577,123336,'117675.000001','deals','clear','both',0,''),(389578,123337,'117676.000001','deals','margin-bottom','10',0,''),(389579,123346,'117678','deals','block_type','1',0,''),(389580,123346,'117678','deals','padding-bottom','30',0,''),(389581,123347,'117683','deals','block_type','1',0,''),(389582,123347,'117683','deals','padding-top','10',0,''),(389583,123347,'117683','deals','padding-bottom','10',0,''),(389584,123347,'117683','deals','border-bottom-width','1',0,''),(389585,123347,'117683','deals','border-bottom-color','$content-border-1',0,''),(389586,123347,'117683','deals','margin-left','0',0,''),(389587,123347,'117683','deals','margin-right','0',0,''),(389588,123348,'117685','deals','float','right',0,''),(389589,123348,'117685','deals','display','none',0,'5660'),(389590,123349,'117687','deals','margin-right','20',0,''),(389591,123349,'117687','deals','float','right',0,''),(389592,123349,'117687','deals','clear','none',0,''),(389593,123349,'117687','deals','display','none',0,'5639'),(389594,123350,'117691','deals','col_in_row','5',0,''),(389595,123350,'117691','deals','products_align','left',0,''),(389596,123350,'117691','deals','font-weight','400',0,''),(389597,123350,'117691','deals','listing_type','productListing',0,''),(389598,123350,'117691','deals','listing_type_rows','Rows',0,''),(389599,123350,'117691','deals','show_buy_button_b2b','on',0,''),(389600,123350,'117691','deals','show_wishlist_button_b2b','1',0,''),(389601,123350,'117691','deals','show_compare_b2b','1',0,''),(389602,123350,'117691','deals','show_image','0',0,''),(389603,123350,'117691','deals','show_price','0',0,''),(389604,123350,'117691','deals','show_view_button','0',0,''),(389605,123350,'117691','deals','show_name_rows','0',0,''),(389606,123350,'117691','deals','show_image_rows','0',0,''),(389607,123350,'117691','deals','show_stock_rows','0',0,''),(389608,123350,'117691','deals','show_description_rows','0',0,''),(389609,123350,'117691','deals','show_model_rows','0',0,''),(389610,123350,'117691','deals','show_properties_rows','0',0,''),(389611,123350,'117691','deals','show_rating_rows','0',0,''),(389612,123350,'117691','deals','show_rating_counts_rows','0',0,''),(389613,123350,'117691','deals','show_price_rows','0',0,''),(389614,123350,'117691','deals','show_buy_button_rows','0',0,''),(389615,123350,'117691','deals','show_qty_input_rows','0',0,''),(389616,123350,'117691','deals','show_view_button_rows','0',0,''),(389617,123350,'117691','deals','show_wishlist_button_rows','0',0,''),(389618,123350,'117691','deals','show_compare_rows','0',0,''),(389619,123350,'117691','deals','show_name_b2b','0',0,''),(389620,123350,'117691','deals','show_image_b2b','0',0,''),(389621,123350,'117691','deals','show_stock_b2b','0',0,''),(389622,123350,'117691','deals','show_description_b2b','0',0,''),(389623,123350,'117691','deals','show_model_b2b','0',0,''),(389624,123350,'117691','deals','show_properties_b2b','0',0,''),(389625,123350,'117691','deals','show_rating_b2b','0',0,''),(389626,123350,'117691','deals','show_rating_counts_b2b','0',0,''),(389627,123350,'117691','deals','show_price_b2b','0',0,''),(389628,123350,'117691','deals','show_qty_input_b2b','0',0,''),(389629,123350,'117691','deals','show_view_button_b2b','0',0,''),(389630,123350,'117691','deals','show_attributes_b2b','0',0,''),(389631,123350,'117691','deals','items_on_page','10',0,''),(389632,123350,'117691','deals','col_in_row','3',0,'5639'),(389633,123350,'117691','deals','col_in_row','1',0,'5660'),(389634,123350,'117691','deals','product_names_teg','h2',0,''),(389635,123350,'117691','deals','padding-top','20',0,''),(389636,123350,'117691','deals','padding-bottom','20',0,''),(389637,123350,'117691','deals','col_in_row','4',0,'5644'),(389638,123350,'117691','deals','col_in_row','2',0,'5630'),(389639,123351,'120912','deals','block_type','5',0,''),(389640,123351,'120912','deals','padding-top','10',0,''),(389641,123351,'120912','deals','schema','5-2',0,'5660'),(389642,123352,'120913','deals','padding-top','3',0,''),(389643,123353,'120914','deals','float','right',0,''),(389644,123353,'120914','deals','height','31',0,''),(389645,123354,'117692','deals','show_heading','h1',0,''),(389646,123355,'117693','deals','block_type','1',0,''),(389647,123356,'117694','deals','margin-bottom','20',0,''),(389648,123357,'1641894402','deals','block_type','1',0,''),(389649,123358,'1641809968.0001','deals','block_type','1',0,''),(389650,123358,'1641809968.0001','deals','style_class','filterLine',0,''),(389651,123359,'116286.000001','deals','float','left',0,''),(389652,123359,'116286.000001','deals','clear','none',0,''),(389653,123359,'116286.000001','deals','sort_pos_3','2',0,''),(389654,123359,'116286.000001','deals','sort_pos_4','3',0,''),(389655,123359,'116286.000001','deals','sort_pos_10','11',0,''),(389656,123359,'116286.000001','deals','sort_pos_9','10',0,''),(389657,123359,'116286.000001','deals','sort_pos_11','12',0,''),(389658,123359,'116286.000001','deals','sort_pos_12','13',0,''),(389659,123359,'116286.000001','deals','sort_pos_14','15',0,''),(389660,123359,'116286.000001','deals','sort_pos_13','14',0,''),(389661,123359,'116286.000001','deals','sort_pos_8','4',0,''),(389662,123359,'116286.000001','deals','sort_pos_7','5',0,''),(389663,123359,'116286.000001','deals','sort_pos_2','7',0,''),(389664,123359,'116286.000001','deals','sort_pos_1','6',0,''),(389665,123359,'116286.000001','deals','sort_pos_6','9',0,''),(389666,123359,'116286.000001','deals','sort_pos_5','8',0,''),(389667,123359,'116286.000001','deals','sort_pos_0','1',0,''),(389668,123359,'116286.000001','deals','sort_hide_10','1',0,''),(389669,123359,'116286.000001','deals','sort_hide_9','1',0,''),(389670,123359,'116286.000001','deals','hide_icons','1',0,''),(389671,123359,'116286.000001','deals','sort_hide_16','1',0,''),(389672,123359,'116286.000001','deals','sort_hide_15','1',0,''),(389673,123359,'116286.000001','deals','sort_hide_3','0',0,''),(389674,123359,'116286.000001','deals','sort_hide_4','0',0,''),(389675,123359,'116286.000001','deals','sort_hide_11','1',0,''),(389676,123359,'116286.000001','deals','sort_hide_12','1',0,''),(389677,123359,'116286.000001','deals','sort_hide_14','1',0,''),(389678,123359,'116286.000001','deals','sort_hide_13','1',0,''),(389679,123359,'116286.000001','deals','sort_hide_8','0',0,''),(389680,123359,'116286.000001','deals','sort_hide_7','0',0,''),(389681,123359,'116286.000001','deals','sort_hide_2','1',0,''),(389682,123359,'116286.000001','deals','sort_hide_1','1',0,''),(389683,123359,'116286.000001','deals','sort_hide_6','1',0,''),(389684,123359,'116286.000001','deals','sort_hide_5','1',0,''),(389685,123359,'116286.000001','deals','sort_hide_0','0',0,''),(389686,123359,'116286.000001','deals','sort_pos_15','16',0,''),(389687,123359,'116286.000001','deals','sort_pos_16','17',0,''),(389688,123360,'1641810239.0001','deals','align_position','horizontal',0,''),(389689,123360,'1641810239.0001','deals','open_filter','closed',0,''),(389690,123363,'117696','deals','block_type','1',0,''),(389691,123365,'117698','deals','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(389692,123366,'117699','deals','width','680',0,''),(389693,123366,'117699','deals','font-weight','normal',0,''),(389694,123366,'117699','deals','font-size','12',0,''),(389695,123366,'117699','deals','padding-top','20',0,''),(389696,123366,'117699','deals','padding-bottom','20',0,''),(389697,123366,'117699','deals','color','$content-color-1',0,''),(389698,123367,'117700','deals','font-weight','400',0,''),(389699,123367,'117700','deals','padding-top','20',0,''),(389700,123367,'117700','deals','padding-bottom','0',0,''),(389701,123367,'117700','deals','font-size','12',0,''),(389702,123368,'117701','deals','block_type','3',0,''),(389703,123368,'117701','deals','font-weight','normal',0,''),(389704,123368,'117701','deals','padding-top','20',0,''),(389705,123369,'117702','deals','text','<p>If undelivered please return to:</p>',1,''),(389706,123369,'117702','deals','font-size','12',0,''),(389707,123369,'117702','deals','font-weight','bold',0,''),(389708,123369,'117702','deals','text','<p>If undelivered please return to:</p>',2,''),(389709,123369,'117702','deals','text','<p>If undelivered please return to:</p>',3,''),(389710,123369,'117702','deals','text','<p>If undelivered please return to:</p>',4,''),(389711,123370,'117703','deals','font-size','12',0,''),(389712,123371,'117704','deals','text','<p>Thank you for your order</p>',1,''),(389713,123371,'117704','deals','color','$hileght-color-1',0,''),(389714,123371,'117704','deals','font-size','13',0,''),(389715,123371,'117704','deals','font-weight','bold',0,''),(389716,123371,'117704','deals','padding-top','5',0,''),(389717,123371,'117704','deals','text-align','center',0,''),(389718,123371,'117704','deals','text','<p>Thank you for your order</p>',2,''),(389719,123371,'117704','deals','text','<p>Thank you for your order</p>',3,''),(389720,123371,'117704','deals','text','<p>Thank you for your order</p>',4,''),(389721,123372,'117705','deals','font-weight','400',0,''),(389722,123372,'117705','deals','text-align','center',0,''),(389723,123372,'117705','deals','padding-top','0',0,''),(389725,123372,'117705','deals','padding-left','20',0,''),(389726,123372,'117705','deals','padding-right','20',0,''),(389730,123373,'117706','deals','block_type','6',0,''),(389731,123373,'117706','deals','font-weight','normal',0,''),(389732,123373,'117706','deals','font-size','16',0,''),(389733,123374,'117707','deals','text','<p>Email:</p>',1,''),(389734,123374,'117707','deals','font-weight','normal',0,''),(389735,123374,'117707','deals','text-align','right',0,''),(389736,123374,'117707','deals','font-size','12',0,''),(389737,123374,'117707','deals','text','<p>Email:</p>',2,''),(389738,123374,'117707','deals','text','<p>Email:</p>',3,''),(389739,123374,'117707','deals','text','<p>Email:</p>',4,''),(389740,123375,'117708','deals','font-weight','normal',0,''),(389741,123375,'117708','deals','text-align','right',0,''),(389742,123375,'117708','deals','font-size','12',0,''),(389743,123376,'117709','deals','text','<p>If something has gone wrong please contact us at:</p>',1,''),(389744,123376,'117709','deals','font-size','12',0,''),(389745,123376,'117709','deals','font-weight','bold',0,''),(389746,123376,'117709','deals','text-align','right',0,''),(389747,123376,'117709','deals','text','<p>If something has gone wrong please contact us at:</p>',2,''),(389748,123376,'117709','deals','text','<p>If something has gone wrong please contact us at:</p>',3,''),(389749,123376,'117709','deals','text','<p>If something has gone wrong please contact us at:</p>',4,''),(389750,123377,'117710','deals','block_type','6',0,''),(389751,123377,'117710','deals','font-weight','normal',0,''),(389752,123377,'117710','deals','font-size','16',0,''),(389753,123378,'117711','deals','text','<p>Phone:</p>',1,''),(389754,123378,'117711','deals','font-weight','normal',0,''),(389755,123378,'117711','deals','text-align','right',0,''),(389756,123378,'117711','deals','font-size','12',0,''),(389757,123378,'117711','deals','text','<p>Phone:</p>',2,''),(389758,123378,'117711','deals','text','<p>Phone:</p>',3,''),(389759,123378,'117711','deals','text','<p>Phone:</p>',4,''),(389760,123379,'117712','deals','font-weight','normal',0,''),(389761,123379,'117712','deals','text-align','right',0,''),(389762,123379,'117712','deals','font-size','12',0,''),(389763,123380,'117713','deals','block_type','2',0,''),(389764,123380,'117713','deals','font-weight','normal',0,''),(389765,123380,'117713','deals','padding-bottom','20',0,''),(389766,123381,'117714','deals','font-weight','400',0,''),(389767,123381,'117714','deals','padding-top','20',0,''),(389772,123382,'117715','deals','block_type','11',0,''),(389773,123382,'117715','deals','font-weight','normal',0,''),(389774,123383,'117716','deals','text','<p>Phone:</p>',1,''),(389775,123383,'117716','deals','font-weight','normal',0,''),(389776,123383,'117716','deals','text-align','right',0,''),(389777,123383,'117716','deals','text','<p>Phone:</p>',2,''),(389778,123383,'117716','deals','text','<p>Phone:</p>',3,''),(389779,123383,'117716','deals','text','<p>Phone:</p>',4,''),(389780,123384,'117717','deals','font-weight','normal',0,''),(389781,123384,'117717','deals','text-align','right',0,''),(389782,123385,'117718','deals','block_type','11',0,''),(389783,123385,'117718','deals','font-weight','normal',0,''),(389784,123386,'117719','deals','text','<p>Web:</p>',1,''),(389785,123386,'117719','deals','font-weight','normal',0,''),(389786,123386,'117719','deals','text-align','right',0,''),(389787,123386,'117719','deals','text','<p>Web:</p>',2,''),(389788,123386,'117719','deals','text','<p>Web:</p>',3,''),(389789,123386,'117719','deals','text','<p>Web:</p>',4,''),(389790,123387,'117720','deals','font-weight','normal',0,''),(389791,123387,'117720','deals','text-align','right',0,''),(389792,123388,'117721','deals','block_type','1',0,''),(389793,123389,'117722','deals','font-weight','normal',0,''),(389794,123389,'117722','deals','text-align','right',0,''),(389795,123389,'117722','deals','padding-bottom','10',0,''),(389796,123389,'117722','deals','address_spacer',',',0,''),(389797,123389,'117722','deals','font-size','12',0,''),(389798,123390,'117723','deals','block_type','11',0,''),(389799,123390,'117723','deals','font-weight','normal',0,''),(389800,123391,'117724','deals','text','<p>Email:</p>',1,''),(389801,123391,'117724','deals','font-weight','normal',0,''),(389802,123391,'117724','deals','text-align','right',0,''),(389803,123391,'117724','deals','text','<p>Email:</p>',2,''),(389804,123391,'117724','deals','text','<p>Email:</p>',3,''),(389805,123391,'117724','deals','text','<p>Email:</p>',4,''),(389806,123392,'117725','deals','font-weight','normal',0,''),(389807,123392,'117725','deals','text-align','right',0,''),(389808,123393,'117726','deals','block_type','4',0,''),(389809,123393,'117726','deals','font-weight','normal',0,''),(389810,123393,'117726','deals','border-top-width','1',0,''),(389811,123393,'117726','deals','border-top-color','$content-border-1',0,''),(389812,123393,'117726','deals','border-left-width','1',0,''),(389813,123393,'117726','deals','border-left-color','$content-border-1',0,''),(389814,123393,'117726','deals','border-right-width','1',0,''),(389815,123393,'117726','deals','border-right-color','$content-border-1',0,''),(389816,123393,'117726','deals','border-bottom-width','1',0,''),(389817,123393,'117726','deals','border-bottom-color','$content-border-1',0,''),(389818,123394,'117727','deals','block_type','2',0,''),(389819,123394,'117727','deals','font-weight','normal',0,''),(389820,123394,'117727','deals','border-right-width','1',0,''),(389821,123394,'117727','deals','border-right-color','$content-border-1',0,''),(389822,123395,'117728','deals','block_type','1',0,''),(389823,123395,'117728','deals','font-weight','400',0,''),(389824,123395,'117728','deals','background-color','$content-bg-2',0,''),(389825,123395,'117728','deals','padding-top','10',0,''),(389826,123395,'117728','deals','padding-left','10',0,''),(389827,123395,'117728','deals','padding-right','10',0,''),(389828,123395,'117728','deals','padding-bottom','30',0,''),(389829,123396,'117729','deals','font-size','12',0,''),(389830,123397,'117730','deals','text','<p>ADDRESS:</p>\n',1,''),(389831,123397,'117730','deals','font-size','14',0,''),(389832,123397,'117730','deals','font-weight','bold',0,''),(389833,123397,'117730','deals','text','<p>ADDRESS:</p>\n',2,''),(389834,123397,'117730','deals','text','<p>ADDRESS:</p>\n',3,''),(389835,123397,'117730','deals','text','<p>ADDRESS:</p>\n',4,''),(389836,123398,'117731','deals','block_type','1',0,''),(389837,123398,'117731','deals','font-weight','normal',0,''),(389838,123398,'117731','deals','padding-top','10',0,''),(389839,123398,'117731','deals','padding-left','10',0,''),(389840,123398,'117731','deals','padding-right','10',0,''),(389841,123398,'117731','deals','padding-bottom','10',0,''),(389842,123400,'117733','deals','text','<p>E-MAIL ADDRESS:</p>',1,''),(389843,123400,'117733','deals','font-weight','bold',0,''),(389844,123400,'117733','deals','font-size','14',0,''),(389845,123400,'117733','deals','padding-top','10',0,''),(389846,123400,'117733','deals','text','<p>E-MAIL ADDRESS:</p>',2,''),(389847,123400,'117733','deals','text','<p>E-MAIL ADDRESS:</p>',3,''),(389848,123400,'117733','deals','text','<p>E-MAIL ADDRESS:</p>',4,''),(389849,123401,'117734','deals','font-weight','normal',0,''),(389850,123402,'117735','deals','font-weight','normal',0,''),(389851,123403,'117736','deals','text','<p>PHONE NUMBER:</p>',1,''),(389852,123403,'117736','deals','font-size','14',0,''),(389853,123403,'117736','deals','font-weight','bold',0,''),(389854,123403,'117736','deals','padding-top','10',0,''),(389855,123403,'117736','deals','text','<p>PHONE NUMBER:</p>',2,''),(389856,123403,'117736','deals','text','<p>PHONE NUMBER:</p>',3,''),(389857,123403,'117736','deals','text','<p>PHONE NUMBER:</p>',4,''),(389858,123404,'117737','deals','text','<p>CUSTOMER:</p>',1,''),(389859,123404,'117737','deals','font-size','13',0,''),(389860,123404,'117737','deals','font-weight','bold',0,''),(389861,123404,'117737','deals','text','<p>CUSTOMER:</p>',2,''),(389862,123404,'117737','deals','text','<p>CUSTOMER:</p>',3,''),(389863,123404,'117737','deals','text','<p>CUSTOMER:</p>',4,''),(389864,123405,'117738','deals','font-size','14',0,''),(389865,123405,'117738','deals','font-weight','bold',0,''),(389866,123405,'117738','deals','text-align','center',0,''),(389867,123405,'117738','deals','padding-bottom','10',0,''),(389868,123405,'117738','deals','padding-top','10',0,''),(389869,123406,'117739','deals','text','<p>Order date:</p>\n',1,''),(389870,123406,'117739','deals','font-weight','bold',0,''),(389871,123406,'117739','deals','text-align','center',0,''),(389872,123406,'117739','deals','font-size','12',0,''),(389873,123406,'117739','deals','text','<p>Order date:</p>\n',2,''),(389874,123406,'117739','deals','text','<p>Order date:</p>\n',3,''),(389875,123406,'117739','deals','text','<p>Order date:</p>\n',4,''),(389876,123407,'117740','deals','font-weight','normal',0,''),(389877,123407,'117740','deals','text-align','center',0,''),(389878,123407,'117740','deals','padding-bottom','10',0,''),(389879,123408,'117741','deals','block_type','5',0,''),(389880,123408,'117741','deals','font-weight','normal',0,''),(389881,123408,'117741','deals','border-bottom-width','1',0,''),(389882,123408,'117741','deals','border-bottom-color','$content-border-1',0,''),(389883,123408,'117741','deals','border-top-width','1',0,''),(389884,123408,'117741','deals','border-top-color','$content-border-1',0,''),(389885,123408,'117741','deals','border-left-color','$content-border-1',0,''),(389886,123408,'117741','deals','border-left-width','1',0,''),(389887,123409,'117742','deals','block_type','1',0,''),(389888,123409,'117742','deals','font-weight','normal',0,''),(389889,123409,'117742','deals','padding-top','10',0,''),(389890,123409,'117742','deals','padding-left','10',0,''),(389891,123409,'117742','deals','padding-right','10',0,''),(389892,123410,'117743','deals','font-weight','400',0,''),(389893,123410,'117743','deals','line-height','120',0,''),(389894,123410,'117743','deals','line_height_measure','%',0,''),(389895,123410,'117743','deals','font-size','12',0,''),(389896,123411,'117744','deals','text','<p>SHIPPING ADDRESS:</p>',1,''),(389897,123411,'117744','deals','font-size','14',0,''),(389898,123411,'117744','deals','font-weight','bold',0,''),(389899,123411,'117744','deals','padding-bottom','10',0,''),(389900,123411,'117744','deals','text','<p>SHIPPING ADDRESS:</p>',2,''),(389901,123411,'117744','deals','text','<p>SHIPPING ADDRESS:</p>',3,''),(389902,123411,'117744','deals','text','<p>SHIPPING ADDRESS:</p>',4,''),(389905,123415,'117745','deals','block_type','1',0,''),(389906,123416,'117746','deals','block_type','6',0,''),(389907,123416,'117746','deals','schema','6-3',0,'5639'),(389908,123417,'117747','deals','aria_name','account-menu',0,''),(389972,123437,'117748','deals','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(389973,123438,'117749','deals','link','Quotation Info',0,''),(389974,123438,'117749','deals','margin-bottom','20',0,''),(389975,123439,'117750','deals','block_type','1',0,''),(389976,123440,'117751','deals','block_type','6',0,''),(389977,123440,'117751','deals','schema','6-3',0,'5639'),(389978,123441,'117752','deals','aria_name','account-menu',0,''),(390042,123461,'117753','deals','block_type','3',0,''),(390043,123462,'117754','deals','block_type','1',0,''),(390044,123462,'117754','deals','padding-right','20',0,''),(390045,123462,'117754','deals','padding-bottom','20',0,''),(390046,123463,'117755','deals','orders_data','name',0,''),(390047,123464,'117756','deals','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(390048,123465,'117757','deals','block_type','1',0,''),(390049,123465,'117757','deals','padding-right','20',0,''),(390050,123465,'117757','deals','padding-bottom','20',0,''),(390051,123466,'117758','deals','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(390052,123467,'117759','deals','orders_data','telephone',0,''),(390053,123468,'117760','deals','block_type','1',0,''),(390054,123468,'117760','deals','padding-right','20',0,''),(390055,123469,'117761','deals','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(390056,123470,'117762','deals','orders_data','shipping_method',0,''),(390057,123471,'117763','deals','block_type','1',0,''),(390058,123471,'117763','deals','padding-right','20',0,''),(390059,123471,'117763','deals','padding-bottom','20',0,''),(390060,123472,'117764','deals','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(390061,123473,'117765','deals','orders_data','delivery_address',0,''),(390062,123474,'117766','deals','block_type','1',0,''),(390063,123474,'117766','deals','padding-bottom','20',0,''),(390064,123475,'117767','deals','orders_data','billing_address',0,''),(390065,123476,'117768','deals','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(390066,123477,'117769','deals','block_type','1',0,''),(390067,123478,'117770','deals','orders_data','payment_method',0,''),(390068,123479,'117771','deals','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(390069,123480,'117772','deals','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(390070,123482,'117774','deals','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(390071,123485,'117777','deals','block_type','2',0,''),(390072,123485,'117777','deals','padding-top','20',0,''),(390073,123485,'117777','deals','margin-bottom','20',0,''),(390074,123486,'117778','deals','like_button','1',0,''),(390075,123486,'117778','deals','text','IMAGE_BUTTON_BACK',0,''),(390076,123486,'117778','deals','link','Quotations',0,''),(390077,123487,'117779','deals','text','<h1>##HEADING_TITLE##</h1>',0,''),(390078,123488,'117780','deals','padding-top','20',0,''),(390079,123488,'117780','deals','padding-bottom','20',0,''),(390080,123488,'117780','deals','block_type','1',0,''),(390081,123490,'117782','deals','block_type','4',0,''),(390082,123490,'117782','deals','schema','4-2',0,'5639'),(390083,123490,'117782','deals','schema','4-2',0,'5630'),(390084,123491,'117783','deals','background-color','$content-bg-1',0,''),(390085,123492,'117784','deals','block_type','1',0,''),(390086,123492,'117784','deals','style_class','order-summary',0,''),(390087,123492,'117784','deals','margin-left','30',0,''),(390088,123492,'117784','deals','margin-left','0',0,'5639'),(390089,123493,'117785','deals','block_type','1',0,''),(390090,123493,'117785','deals','padding-left','20',0,''),(390091,123493,'117785','deals','padding-right','20',0,''),(390092,123493,'117785','deals','padding-bottom','30',0,''),(390093,123494,'117786','deals','max-width','300',0,'5639'),(390094,123494,'117786','deals','margin_left_measure','auto',0,'5639'),(390095,123494,'117786','deals','margin_right_measure','auto',0,'5639'),(390096,123494,'117786','deals','margin-bottom','0',0,''),(390097,123496,'117788','deals','block_type','1',0,''),(390166,123520,'117793','deals','block_type','1',0,''),(390167,123522,'117795','deals','pagination','bottom',0,''),(390168,123523,'117796','deals','width','800',0,''),(390169,123524,'117797','deals','block_type','11',0,''),(390170,123524,'117797','deals','border-top-width','1',0,''),(390171,123524,'117797','deals','border-left-width','1',0,''),(390172,123524,'117797','deals','border-right-width','1',0,''),(390173,123524,'117797','deals','border-bottom-width','1',0,''),(390174,123524,'117797','deals','border-top-color','$highlight-box-border-1',0,''),(390175,123524,'117797','deals','border-left-color','$highlight-box-border-1',0,''),(390176,123524,'117797','deals','border-right-color','$highlight-box-border-1',0,''),(390177,123524,'117797','deals','border-bottom-color','$highlight-box-border-1',0,''),(390178,123525,'117798','deals','block_type','1',0,''),(390179,123525,'117798','deals','border-right-width','1',0,''),(390180,123525,'117798','deals','border-right-color','$highlight-box-border-1',0,''),(390181,123525,'117798','deals','padding-top','10',0,''),(390182,123525,'117798','deals','padding-right','10',0,''),(390183,123525,'117798','deals','padding-bottom','10',0,''),(390184,123526,'117799','deals','block_type','9',0,''),(390185,123527,'117800','deals','text','1.',0,''),(390186,123527,'117800','deals','font-size','12',0,''),(390187,123527,'117800','deals','text-align','right',0,''),(390188,123527,'117800','deals','padding-right','5',0,''),(390189,123528,'117801','deals','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(390190,123528,'117801','deals','font-size','12',0,''),(390191,123528,'117801','deals','padding-bottom','5',0,''),(390192,123529,'117802','deals','block_type','9',0,''),(390193,123530,'117803','deals','text','4.',0,''),(390194,123530,'117803','deals','font-size','12',0,''),(390195,123530,'117803','deals','text-align','right',0,''),(390196,123530,'117803','deals','margin-right','5',0,''),(390197,123531,'117804','deals','text','Our Replacement Department will process your request.',0,''),(390198,123531,'117804','deals','font-size','12',0,''),(390199,123531,'117804','deals','padding-bottom','5',0,''),(390200,123532,'117805','deals','block_type','9',0,''),(390201,123533,'117806','deals','text','3.',0,''),(390202,123533,'117806','deals','font-size','12',0,''),(390203,123533,'117806','deals','text-align','right',0,''),(390204,123533,'117806','deals','margin-right','5',0,''),(390205,123534,'117807','deals','text','Return the authorized item(s) per shipping instructions.',0,''),(390206,123534,'117807','deals','font-size','12',0,''),(390207,123534,'117807','deals','padding-bottom','5',0,''),(390208,123535,'117808','deals','block_type','9',0,''),(390209,123536,'117809','deals','text','2.',0,''),(390210,123536,'117809','deals','font-size','12',0,''),(390211,123536,'117809','deals','text-align','right',0,''),(390212,123536,'117809','deals','margin-right','5',0,''),(390213,123537,'117810','deals','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(390214,123537,'117810','deals','font-size','12',0,''),(390215,123537,'117810','deals','padding-bottom','5',0,''),(390216,123538,'117811','deals','block_type','1',0,''),(390217,123538,'117811','deals','padding-left','15',0,''),(390218,123539,'117812','deals','text','Replacement Policy:',0,''),(390219,123539,'117812','deals','font-size','14',0,''),(390220,123539,'117812','deals','padding-bottom','5',0,''),(390221,123539,'117812','deals','font-weight','bold',0,''),(390222,123540,'117813','deals','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(390223,123540,'117813','deals','font-size','11',0,''),(390224,123540,'117813','deals','font-style','italic',0,''),(390225,123540,'117813','deals','padding-bottom','5',0,''),(390226,123541,'117814','deals','block_type','1',0,''),(390227,123541,'117814','deals','border-bottom-width','1',0,''),(390228,123541,'117814','deals','border-bottom-color','$highlight-box-border-1',0,''),(390229,123542,'117815','deals','text','Return Material Authorization (RMA) Form',0,''),(390230,123542,'117815','deals','text-align','center',0,''),(390231,123542,'117815','deals','font-size','16',0,''),(390232,123542,'117815','deals','font-weight','bold',0,''),(390233,123543,'117816','deals','text-align','center',0,''),(390234,123543,'117816','deals','logo','themes/deals/img/logo-2.png',1,''),(390235,123543,'117816','deals','padding-top','10',0,''),(390236,123543,'117816','deals','padding-bottom','10',0,''),(390237,123543,'117816','deals','logo','themes/deals/img/logo-2.png',2,''),(390238,123543,'117816','deals','logo','themes/deals/img/logo-2.png',3,''),(390239,123543,'117816','deals','logo','themes/deals/img/logo-2.png',4,''),(390240,123544,'117817','deals','block_type','1',0,''),(390241,123544,'117817','deals','padding-top','10',0,''),(390242,123544,'117817','deals','padding-left','10',0,''),(390243,123544,'117817','deals','padding-right','10',0,''),(390244,123544,'117817','deals','padding-bottom','20',0,''),(390245,123545,'117818','deals','block_type','2',0,''),(390246,123545,'117818','deals','padding-top','5',0,''),(390247,123546,'117819','deals','block_type','11',0,''),(390248,123547,'117820','deals','text','Email:',0,''),(390249,123547,'117820','deals','font-size','12',0,''),(390250,123548,'117821','deals','data','rrDelivery_email_address',0,''),(390251,123548,'117821','deals','font-size','12',0,''),(390252,123549,'117822','deals','block_type','11',0,''),(390253,123550,'117823','deals','text','Phone:',0,''),(390254,123550,'117823','deals','font-size','12',0,''),(390255,123551,'117824','deals','data','rrDelivery_telephone',0,''),(390256,123551,'117824','deals','font-size','12',0,''),(390257,123552,'117825','deals','block_type','2',0,''),(390258,123552,'117825','deals','padding-top','5',0,''),(390259,123553,'117826','deals','block_type','11',0,''),(390260,123554,'117827','deals','text','Country:',0,''),(390261,123554,'117827','deals','font-size','12',0,''),(390262,123555,'117828','deals','data','rrDelivery_country',0,''),(390263,123555,'117828','deals','font-size','12',0,''),(390264,123556,'117829','deals','block_type','11',0,''),(390265,123557,'117830','deals','text','Postcode:',0,''),(390266,123557,'117830','deals','font-size','12',0,''),(390267,123558,'117831','deals','data','rrDelivery_postcode',0,''),(390268,123558,'117831','deals','font-size','12',0,''),(390269,123559,'117832','deals','block_type','2',0,''),(390270,123559,'117832','deals','padding-top','5',0,''),(390271,123560,'117833','deals','block_type','11',0,''),(390272,123561,'117834','deals','text','City:',0,''),(390273,123561,'117834','deals','font-size','12',0,''),(390274,123562,'117835','deals','data','rrDelivery_city',0,''),(390275,123562,'117835','deals','font-size','12',0,''),(390276,123563,'117836','deals','block_type','11',0,''),(390277,123564,'117837','deals','text','State:',0,''),(390278,123564,'117837','deals','font-size','12',0,''),(390279,123565,'117838','deals','data','rrDelivery_state',0,''),(390280,123565,'117838','deals','font-size','12',0,''),(390281,123566,'117839','deals','block_type','9',0,''),(390282,123566,'117839','deals','padding-top','5',0,''),(390283,123567,'117840','deals','text','Address:',0,''),(390284,123567,'117840','deals','font-size','12',0,''),(390285,123568,'117841','deals','data','rrDelivery_street_address',0,''),(390286,123568,'117841','deals','font-size','12',0,''),(390287,123569,'117842','deals','block_type','2',0,''),(390288,123570,'117843','deals','block_type','11',0,''),(390289,123571,'117844','deals','text','Company:',0,''),(390290,123571,'117844','deals','font-size','12',0,''),(390291,123572,'117845','deals','data','rrDelivery_company',0,''),(390292,123572,'117845','deals','font-size','12',0,''),(390293,123573,'117846','deals','block_type','2',0,''),(390294,123574,'117847','deals','text','Contact Name:',0,''),(390295,123574,'117847','deals','font-size','12',0,''),(390296,123575,'117848','deals','data','rrDelivery_name',0,''),(390297,123575,'117848','deals','font-size','12',0,''),(390298,123576,'117849','deals','block_type','2',0,''),(390299,123576,'117849','deals','padding-left','10',0,''),(390300,123576,'117849','deals','padding-top','20',0,''),(390301,123576,'117849','deals','padding-right','10',0,''),(390302,123577,'117850','deals','block_type','5',0,''),(390303,123578,'117851','deals','text','RMA No:',0,''),(390304,123578,'117851','deals','font-size','12',0,''),(390305,123578,'117851','deals','font-weight','bold',0,''),(390306,123579,'117852','deals','data','rrNumber',0,''),(390307,123579,'117852','deals','font-size','12',0,''),(390308,123579,'117852','deals','font-weight','bold',0,''),(390309,123580,'117853','deals','block_type','2',0,''),(390310,123581,'117854','deals','text','Date Issued:',0,''),(390311,123581,'117854','deals','font-size','12',0,''),(390312,123581,'117854','deals','font-weight','bold',0,''),(390313,123582,'117855','deals','data','rrDateCreate',0,''),(390314,123582,'117855','deals','font-size','12',0,''),(390315,123582,'117855','deals','font-weight','bold',0,''),(390316,123583,'117856','deals','block_type','1',0,''),(390317,123584,'117857','deals','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(390318,123584,'117857','deals','font-size','12',0,''),(390319,123584,'117857','deals','font-style','italic',0,''),(390320,123584,'117857','deals','padding-bottom','20',0,''),(390321,123586,'117859','deals','block_type','1',0,''),(390322,123586,'117859','deals','border-top-width','1',0,''),(390323,123586,'117859','deals','border-left-width','1',0,''),(390324,123586,'117859','deals','border-right-width','1',0,''),(390325,123586,'117859','deals','border-bottom-width','1',0,''),(390326,123586,'117859','deals','border-top-color','$highlight-box-border-1',0,''),(390327,123586,'117859','deals','border-left-color','$highlight-box-border-1',0,''),(390328,123586,'117859','deals','border-right-color','$highlight-box-border-1',0,''),(390329,123586,'117859','deals','border-bottom-color','$highlight-box-border-1',0,''),(390330,123587,'117860','deals','block_type','11',0,''),(390331,123588,'117861','deals','block_type','1',0,''),(390332,123588,'117861','deals','padding-top','10',0,''),(390333,123588,'117861','deals','padding-right','10',0,''),(390334,123588,'117861','deals','padding-bottom','10',0,''),(390335,123588,'117861','deals','border-right-width','1',0,''),(390336,123588,'117861','deals','border-right-color','$highlight-box-border-1',0,''),(390337,123589,'117862','deals','block_type','9',0,''),(390338,123590,'117863','deals','text','4.',0,''),(390339,123590,'117863','deals','font-size','12',0,''),(390340,123590,'117863','deals','text-align','right',0,''),(390341,123590,'117863','deals','padding-right','5',0,''),(390342,123591,'117864','deals','font-size','11',0,''),(390343,123591,'117864','deals','font-style','italic',0,''),(390344,123591,'117864','deals','padding-bottom','5',0,''),(390345,123592,'117865','deals','text','Ship returned items to:',0,''),(390346,123592,'117865','deals','font-size','12',0,''),(390347,123592,'117865','deals','padding-bottom','5',0,''),(390348,123593,'117866','deals','block_type','9',0,''),(390349,123594,'117867','deals','text','3.',0,''),(390350,123594,'117867','deals','font-size','12',0,''),(390351,123594,'117867','deals','text-align','right',0,''),(390352,123594,'117867','deals','padding-right','5',0,''),(390353,123595,'117868','deals','text','Ship only the items that are authorized.',0,''),(390354,123595,'117868','deals','font-size','12',0,''),(390355,123595,'117868','deals','padding-bottom','10',0,''),(390356,123596,'117869','deals','block_type','9',0,''),(390357,123597,'117870','deals','text','1.',0,''),(390358,123597,'117870','deals','font-size','12',0,''),(390359,123597,'117870','deals','text-align','right',0,''),(390360,123597,'117870','deals','padding-right','5',0,''),(390361,123598,'117871','deals','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(390362,123598,'117871','deals','font-size','12',0,''),(390363,123598,'117871','deals','padding-bottom','10',0,''),(390364,123599,'117872','deals','block_type','1',0,''),(390365,123600,'117873','deals','text','Shipping Instructions:',0,''),(390366,123600,'117873','deals','font-weight','bold',0,''),(390367,123600,'117873','deals','font-size','14',0,''),(390368,123600,'117873','deals','padding-bottom','5',0,''),(390369,123600,'117873','deals','padding-left','10',0,''),(390370,123601,'117874','deals','block_type','9',0,''),(390371,123602,'117875','deals','text','2.',0,''),(390372,123602,'117875','deals','font-size','12',0,''),(390373,123602,'117875','deals','text-align','right',0,''),(390374,123602,'117875','deals','padding-right','5',0,''),(390375,123603,'117876','deals','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(390376,123603,'117876','deals','font-size','12',0,''),(390377,123603,'117876','deals','padding-bottom','10',0,''),(390378,123604,'117877','deals','block_type','1',0,''),(390379,123604,'117877','deals','padding-left','10',0,''),(390380,123604,'117877','deals','padding-right','10',0,''),(390381,123604,'117877','deals','padding-bottom','10',0,''),(390382,123605,'117878','deals','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(390383,123605,'117878','deals','font-size','11',0,''),(390384,123605,'117878','deals','font-style','italic',0,''),(390385,123606,'117879','deals','block_type','1',0,''),(390386,123606,'117879','deals','padding-top','10',0,''),(390387,123606,'117879','deals','padding-left','40',0,''),(390388,123606,'117879','deals','padding-right','40',0,''),(390389,123606,'117879','deals','padding-bottom','10',0,''),(390390,123607,'117880','deals','block_type','1',0,''),(390391,123607,'117880','deals','padding-top','10',0,''),(390392,123607,'117880','deals','padding-left','10',0,''),(390393,123607,'117880','deals','padding-right','10',0,''),(390394,123607,'117880','deals','padding-bottom','10',0,''),(390395,123607,'117880','deals','border-top-width','1',0,''),(390396,123607,'117880','deals','border-left-width','1',0,''),(390397,123607,'117880','deals','border-right-width','1',0,''),(390398,123607,'117880','deals','border-bottom-width','1',0,''),(390399,123607,'117880','deals','border-top-color','$highlight-box-border-1',0,''),(390400,123607,'117880','deals','border-left-color','$highlight-box-border-1',0,''),(390401,123607,'117880','deals','border-right-color','$highlight-box-border-1',0,''),(390402,123607,'117880','deals','border-bottom-color','$highlight-box-border-1',0,''),(390403,123608,'117881','deals','block_type','3',0,''),(390404,123609,'117882','deals','data','rrDelivery_name',0,''),(390405,123609,'117882','deals','font-size','9',0,''),(390406,123610,'117883','deals','block_type','2',0,''),(390407,123611,'117884','deals','text','RMA#:',0,''),(390408,123611,'117884','deals','font-size','10',0,''),(390409,123612,'117885','deals','data','rrNumber',0,''),(390410,123612,'117885','deals','font-size','9',0,''),(390411,123613,'117886','deals','block_type','5',0,''),(390412,123614,'117887','deals','font-size','9',0,''),(390413,123615,'117888','deals','block_type','1',0,''),(390414,123615,'117888','deals','padding-left','10',0,''),(390415,123615,'117888','deals','padding-right','10',0,''),(390416,123615,'117888','deals','padding-bottom','10',0,''),(390417,123616,'117889','deals','text','Use this space for additional Comments:',0,''),(390418,123616,'117889','deals','font-size','11',0,''),(390419,123616,'117889','deals','font-style','italic',0,''),(390420,123617,'117890','deals','text','&nbsp;',0,''),(390421,123617,'117890','deals','border-bottom-width','1',0,''),(390422,123617,'117890','deals','border-bottom-color','$highlight-box-border-1',0,''),(390423,123618,'117891','deals','text','&nbsp;',0,''),(390424,123618,'117891','deals','border-bottom-width','1',0,''),(390425,123618,'117891','deals','border-bottom-color','$highlight-box-border-1',0,''),(390426,123618,'117891','deals','padding-top','5',0,''),(390427,123619,'117892','deals','text','&nbsp;',0,''),(390428,123619,'117892','deals','border-bottom-width','1',0,''),(390429,123619,'117892','deals','border-bottom-color','$highlight-box-border-1',0,''),(390430,123619,'117892','deals','padding-top','5',0,''),(390431,123620,'117893','deals','text','&nbsp;',0,''),(390432,123620,'117893','deals','border-bottom-width','1',0,''),(390433,123620,'117893','deals','border-bottom-color','$highlight-box-border-1',0,''),(390434,123620,'117893','deals','padding-top','5',0,''),(390435,123621,'117894','deals','block_type','3',0,''),(390436,123621,'117894','deals','padding-top','10',0,''),(390437,123621,'117894','deals','padding-bottom','10',0,''),(390438,123621,'117894','deals','padding-right','10',0,''),(390439,123622,'117895','deals','font-size','11',0,''),(390440,123622,'117895','deals','font-weight','bold',0,''),(390441,123622,'117895','deals','text','Return Approval:',0,''),(390442,123622,'117895','deals','padding-top','5',0,''),(390443,123622,'117895','deals','padding-left','10',0,''),(390444,123623,'117896','deals','border-bottom-width','1',0,''),(390445,123623,'117896','deals','border-bottom-color','$highlight-box-border-1',0,''),(390446,123623,'117896','deals','text','&nbsp;',0,''),(390447,123624,'117897','deals','block_type','5',0,''),(390448,123625,'117898','deals','text','Date:',0,''),(390449,123625,'117898','deals','padding-top','5',0,''),(390450,123625,'117898','deals','font-size','11',0,''),(390451,123625,'117898','deals','font-weight','bold',0,''),(390452,123625,'117898','deals','padding-left','5',0,''),(390453,123626,'117899','deals','text','&nbsp;',0,''),(390454,123626,'117899','deals','border-bottom-width','1',0,''),(390455,123626,'117899','deals','border-bottom-color','$highlight-box-border-1',0,''),(390456,123627,'117900','deals','block_type','3',0,''),(390457,123627,'117900','deals','padding-right','10',0,''),(390458,123628,'117901','deals','text','Customer Signature:',0,''),(390459,123628,'117901','deals','font-weight','bold',0,''),(390460,123628,'117901','deals','font-size','11',0,''),(390461,123628,'117901','deals','padding-top','5',0,''),(390462,123628,'117901','deals','padding-left','10',0,''),(390463,123629,'117902','deals','text','&nbsp;',0,''),(390464,123629,'117902','deals','border-bottom-width','1',0,''),(390465,123629,'117902','deals','border-bottom-color','$highlight-box-border-1',0,''),(390466,123630,'117903','deals','block_type','5',0,''),(390467,123631,'117904','deals','text','Date:',0,''),(390468,123631,'117904','deals','padding-top','5',0,''),(390469,123631,'117904','deals','font-size','11',0,''),(390470,123631,'117904','deals','font-weight','bold',0,''),(390471,123631,'117904','deals','padding-left','5',0,''),(390472,123632,'117905','deals','text','&nbsp;',0,''),(390473,123632,'117905','deals','border-bottom-width','1',0,''),(390474,123632,'117905','deals','border-bottom-color','$highlight-box-border-1',0,''),(390475,123633,'117906.000001','deals','block_type','1',0,''),(390476,123633,'117906.000001','deals','style_class','item-holder',0,''),(390477,123633,'117906.000001','deals','padding-top','25',0,''),(390478,123633,'117906.000001','deals','padding-bottom','25',0,''),(390479,123633,'117906.000001','deals','text-align','left',0,''),(390480,123633,'117906.000001','deals','border-top-width','1',0,''),(390481,123633,'117906.000001','deals','border-top-color','$content-border-1',0,''),(390482,123634,'117907.000001','deals','block_type','7',0,''),(390483,123634,'117907.000001','deals','schema','7-2',0,'5639'),(390484,123635,'117908.000001','deals','block_type','5',0,''),(390485,123635,'117908.000001','deals','schema','5-2',0,'5639'),(390486,123636,'117909.000001','deals','clear','none',0,''),(390487,123636,'117909.000001','deals','padding-right','20',0,''),(390488,123637,'117910.000001','deals','padding-right','20',0,''),(390489,123637,'117910.000001','deals','max-width','300',0,'5639'),(390490,123637,'117910.000001','deals','margin_left_measure','auto',0,'5639'),(390491,123637,'117910.000001','deals','margin_right_measure','auto',0,'5639'),(390492,123638,'117914.000001','deals','padding-right','20',0,''),(390493,123639,'117915.000001','deals','description_characters','200',0,''),(390494,123639,'117915.000001','deals','clear','none',0,''),(390495,123639,'117915.000001','deals','padding-right','20',0,''),(390496,123640,'117916.000001','deals','clear','none',0,''),(390497,123641,'117917.000001','deals','margin-bottom','20',0,''),(390498,123644,'117918.000001','deals','block_type','1',0,''),(390499,123644,'117918.000001','deals','padding-left','40',0,''),(390500,123644,'117918.000001','deals','style_class','right-aria',0,''),(390501,123644,'117918.000001','deals','padding-left','0',0,'5639'),(390502,123645,'117911.000001','deals','block_type','1',0,''),(390503,123645,'117911.000001','deals','text-align','center',0,''),(390504,123646,'117912.000001','deals','margin-top','4',0,''),(390505,123646,'117912.000001','deals','margin-bottom','7',0,''),(390506,123647,'117913.000001','deals','padding-top','6',0,''),(390507,123647,'117913.000001','deals','padding-left','5',0,''),(390508,123648,'117919.000001','deals','margin-bottom','15',0,''),(390509,123648,'117919.000001','deals','text-align','right',0,''),(390510,123649,'117920.000001','deals','margin-bottom','10',0,''),(390511,123649,'117920.000001','deals','text-align','center',0,''),(390512,123650,'117922.000001','deals','text-align','right',0,''),(390513,123650,'117922.000001','deals','margin-bottom','15',0,''),(390514,123651,'117924.000001','deals','text-align','center',0,''),(390515,123651,'117924.000001','deals','margin-bottom','10',0,''),(390516,123652,'120924.000001','deals','block_type','1',0,''),(390517,123652,'120924.000001','deals','style_class','item-nav',0,''),(390518,123656,'117925','deals','block_type','1',0,''),(390519,123656,'117925','deals','padding-top','20',0,''),(390520,123656,'117925','deals','padding-bottom','20',0,''),(390521,123658,'117927','deals','block_type','7',0,''),(390522,123658,'117927','deals','schema','4-2',0,'5639'),(390523,123659,'117928','deals','padding-bottom','20',0,''),(390524,123659,'117928','deals','background-color','$content-bg-1',0,''),(390525,123660,'117929','deals','style_class','order-summary',0,''),(390526,123660,'117929','deals','padding-left','25',0,''),(390527,123660,'117929','deals','block_type','1',0,''),(390528,123660,'117929','deals','padding-left','0',0,'5639'),(390529,123660,'117929','deals','margin-top','30',0,'5639'),(390530,123661,'117930','deals','block_type','1',0,''),(390531,123661,'117930','deals','padding-left','20',0,''),(390532,123661,'117930','deals','padding-right','20',0,''),(390533,123661,'117930','deals','padding-bottom','20',0,''),(390534,123661,'117930','deals','padding-top','20',0,''),(390535,123662,'117931','deals','max-width','300',0,'5639'),(390536,123662,'117931','deals','margin_left_measure','auto',0,'5639'),(390537,123662,'117931','deals','margin_right_measure','auto',0,'5639'),(390538,123663,'117932','deals','block_type','1',0,''),(390539,123663,'117932','deals','style_class','account-samples',0,''),(390540,123664,'117933','deals','block_type','6',0,''),(390541,123664,'117933','deals','schema','6-3',0,'5639'),(390542,123665,'117934','deals','aria_name','account-menu',0,''),(390606,123685,'117935','deals','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(390607,123686,'117936','deals','show_pagenation','1',0,''),(390608,123686,'117936','deals','link','Sample Info',0,''),(390609,123686,'117936','deals','margin-bottom','20',0,''),(390610,123687,'117937','deals','block_type','1',0,''),(390611,123687,'117937','deals','style_class','account-sample-info',0,''),(390612,123688,'117938','deals','block_type','6',0,''),(390613,123688,'117938','deals','schema','6-3',0,'5639'),(390614,123689,'117939','deals','aria_name','account-menu',0,''),(390678,123709,'117940','deals','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(390679,123710,'117941','deals','block_type','2',0,''),(390680,123710,'117941','deals','padding-top','20',0,''),(390681,123710,'117941','deals','margin-bottom','20',0,''),(390682,123711,'117942','deals','like_button','1',0,''),(390683,123711,'117942','deals','text','IMAGE_BUTTON_BACK',0,''),(390684,123711,'117942','deals','link','Samples',0,''),(390685,123713,'117944','deals','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(390686,123716,'117947','deals','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(390687,123717,'117948','deals','block_type','3',0,''),(390688,123718,'117949','deals','block_type','1',0,''),(390689,123718,'117949','deals','padding-right','20',0,''),(390690,123718,'117949','deals','padding-bottom','20',0,''),(390691,123719,'117950','deals','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(390692,123720,'117951','deals','orders_data','telephone',0,''),(390693,123721,'117952','deals','block_type','1',0,''),(390694,123721,'117952','deals','padding-right','20',0,''),(390695,123721,'117952','deals','padding-bottom','20',0,''),(390696,123722,'117953','deals','orders_data','name',0,''),(390697,123723,'117954','deals','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(390698,123724,'117955','deals','block_type','1',0,''),(390699,123724,'117955','deals','padding-right','20',0,''),(390700,123725,'117956','deals','orders_data','shipping_method',0,''),(390701,123726,'117957','deals','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(390702,123727,'117958','deals','block_type','1',0,''),(390703,123727,'117958','deals','padding-right','20',0,''),(390704,123727,'117958','deals','padding-bottom','20',0,''),(390705,123728,'117959','deals','orders_data','delivery_address',0,''),(390706,123729,'117960','deals','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(390707,123730,'117961','deals','block_type','1',0,''),(390708,123731,'117962','deals','orders_data','payment_method',0,''),(390709,123732,'117963','deals','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(390710,123733,'117964','deals','block_type','1',0,''),(390711,123733,'117964','deals','padding-bottom','20',0,''),(390712,123734,'117965','deals','orders_data','billing_address',0,''),(390713,123735,'117966','deals','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(390714,123736,'117967','deals','block_type','1',0,''),(390715,123737,'117968','deals','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(390716,123738,'117969','deals','block_type','6',0,''),(390717,123739,'117970','deals','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(390718,123740,'117971','deals','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(390719,123741,'117972','deals','text','<div class=\"heading-4\">Categories</div>',0,''),(390720,123744,'117975','deals','class','menu-simple',0,''),(390721,123746,'117977','deals','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(390722,123747,'120878','deals','float','left',0,''),(390723,123747,'120878','deals','margin-right','10',0,''),(390724,123748,'117978','deals','block_type','1',0,''),(390725,123749,'117979','deals','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(390726,123749,'117979','deals','style_class','middle-form',0,''),(390727,123750,'117980','deals','style_class','middle-form',0,''),(390728,123751,'117981','deals','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(390729,123752,'117982','deals','style_class','middle-form',0,''),(390730,123752,'117982','deals','margin-bottom','30',0,''),(390731,123753,'117983','deals','block_type','1',0,''),(390732,123754,'117984','deals','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(390733,123754,'117984','deals','padding-top','100',0,''),(390734,123754,'117984','deals','margin-bottom','100',0,''),(390735,123754,'117984','deals','text-align','center',0,''),(390736,123754,'117984','deals','font-size','20',0,''),(390737,123755,'117985','deals','block_type','1',0,''),(390738,123756,'117986','deals','block_type','6',0,''),(390739,123756,'117986','deals','schema','6-3',0,'5639'),(390740,123757,'117987','deals','aria_name','account-menu',0,''),(390804,123777,'117988','deals','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(390805,123778,'117989','deals','text','##SUBSCRIPTION_TEXT##',0,''),(390806,123780,'1694163942.487488','deals','block_type','1',0,''),(390807,123780,'1694163942.487488','deals','background-color','$content-bg-1',0,''),(390808,123780,'1694163942.487488','deals','padding-bottom','30',0,''),(390809,123780,'1694163942.487488','deals','style_class','success-page',0,''),(390810,123781,'1694163942.571966','deals','block_type','12',0,''),(390811,123781,'1694163942.571966','deals','schema','4-2',0,'5639'),(390812,123782,'1694163942.574743','deals','block_type','1',0,''),(390813,123782,'1694163942.574743','deals','padding-right','40',0,''),(390814,123782,'1694163942.574743','deals','padding-right','0',0,'5639'),(390815,123783,'1694163942.57618','deals','block_type','2',0,''),(390816,123783,'1694163942.57618','deals','margin-bottom','20',0,''),(390817,123783,'1694163942.57618','deals','schema','2-2',0,'5630'),(390818,123783,'1694163942.57618','deals','border-top-width','1',0,''),(390819,123783,'1694163942.57618','deals','border-left-width','1',0,''),(390820,123783,'1694163942.57618','deals','border-right-width','1',0,''),(390821,123783,'1694163942.57618','deals','border-bottom-width','1',0,''),(390822,123783,'1694163942.57618','deals','border-top-color','$content-border-1',0,''),(390823,123783,'1694163942.57618','deals','border-left-color','$content-border-1',0,''),(390824,123783,'1694163942.57618','deals','border-right-color','$content-border-1',0,''),(390825,123783,'1694163942.57618','deals','border-bottom-color','$content-border-1',0,''),(390826,123784,'1694163942.578938','deals','block_type','1',0,''),(390827,123784,'1694163942.578938','deals','margin-right','-10',0,''),(390828,123784,'1694163942.578938','deals','padding-right','30',0,''),(390829,123784,'1694163942.578938','deals','padding-top','20',0,''),(390830,123784,'1694163942.578938','deals','padding-left','30',0,''),(390831,123784,'1694163942.578938','deals','padding-bottom','20',0,''),(390832,123784,'1694163942.578938','deals','border-right-width','0',0,'5639'),(390833,123784,'1694163942.578938','deals','margin-right','0',0,'5639'),(390834,123784,'1694163942.578938','deals','margin-bottom','20',0,'5639'),(390835,123784,'1694163942.578938','deals','padding-left','20',0,'5639'),(390836,123784,'1694163942.578938','deals','padding-right','20',0,'5639'),(390837,123786,'1694163942.582929','deals','margin-bottom','20',0,''),(390838,123787,'1694163942.58424','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(390839,123787,'1694163942.58424','deals','padding-top','20',0,''),(390840,123788,'1694163942.58813','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(390841,123788,'1694163942.58813','deals','clear','none',0,''),(390842,123789,'1694163942.590','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(390843,123791,'1694163942.592641','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(390844,123791,'1694163942.592641','deals','clear','none',0,''),(390845,123792,'1694163942.594491','deals','block_type','1',0,''),(390846,123792,'1694163942.594491','deals','padding-left','30',0,''),(390847,123792,'1694163942.594491','deals','margin-left','-10',0,''),(390848,123792,'1694163942.594491','deals','padding-right','30',0,''),(390849,123792,'1694163942.594491','deals','padding-top','20',0,''),(390850,123792,'1694163942.594491','deals','padding-bottom','20',0,''),(390851,123792,'1694163942.594491','deals','border-left-width','0',0,'5639'),(390852,123794,'1694163942.59754','deals','margin-bottom','20',0,''),(390853,123795,'1694163942.598173','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(390854,123795,'1694163942.598173','deals','clear','none',0,''),(390855,123796,'1694163942.599378','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(390856,123797,'1694163942.600432','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(390857,123797,'1694163942.600432','deals','clear','none',0,''),(390858,123798,'1694163942.601780','deals','text','<div class=\"page-success\">\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>',0,''),(390859,123798,'1694163942.601780','deals','margin-bottom','30',0,''),(390860,123798,'1694163942.601780','deals','padding-top','30',0,''),(390861,123798,'1694163942.601780','deals','padding-bottom','30',0,''),(390862,123798,'1694163942.601780','deals','padding-left','30',0,''),(390863,123798,'1694163942.601780','deals','padding-right','30',0,''),(390864,123798,'1694163942.601780','deals','border-top-width','1',0,''),(390865,123798,'1694163942.601780','deals','border-left-width','1',0,''),(390866,123798,'1694163942.601780','deals','border-right-width','1',0,''),(390867,123798,'1694163942.601780','deals','border-bottom-width','1',0,''),(390868,123798,'1694163942.601780','deals','border-top-color','$content-border-1',0,''),(390869,123798,'1694163942.601780','deals','border-left-color','$content-border-1',0,''),(390870,123798,'1694163942.601780','deals','border-right-color','$content-border-1',0,''),(390871,123798,'1694163942.601780','deals','border-bottom-color','$content-border-1',0,''),(390872,123799,'1694163942.604213','deals','block_type','1',0,''),(390873,123799,'1694163942.604213','deals','style_class','order-summary2 hiding-box',0,''),(390874,123800,'1694163942.605131','deals','text-align','center',0,''),(390875,123800,'1694163942.605131','deals','margin-bottom','20',0,''),(390876,123801,'1694163942.606115','deals','text-align','center',0,''),(390877,123804,'1694163942.609249','deals','block_type','12',0,''),(390878,123805,'1694163942.610273','deals','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n</div>\n',0,''),(390879,123805,'1694163942.610273','deals','margin-bottom','20',0,''),(390880,123806,'1694163942.611982','deals','text-align','center',0,''),(390881,123806,'1694163942.611982','deals','padding-top','40',0,''),(390882,123807,'117997','deals','block_type','1',0,''),(390883,123808,'117998','deals','block_type','1',0,''),(390884,123808,'117998','deals','font-weight','normal',0,''),(390885,123809,'117999','deals','block_type','1',0,''),(390886,123809,'117999','deals','text-align','center',0,''),(390887,123809,'117999','deals','padding-top','30',0,''),(390888,123809,'117999','deals','margin-bottom','200',0,''),(390889,123810,'118000','deals','display','inline-block',0,''),(390890,123810,'118000','deals','clear','none',0,''),(390891,123810,'118000','deals','margin-left','20',0,''),(390892,123811,'118001','deals','display','inline-block',0,''),(390893,123812,'118002','deals','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(390898,123817,'118007','deals','width','680',0,''),(390899,123817,'118007','deals','font-weight','normal',0,''),(390900,123817,'118007','deals','font-size','12',0,''),(390901,123817,'118007','deals','padding-top','20',0,''),(390902,123817,'118007','deals','padding-bottom','20',0,''),(390903,123817,'118007','deals','color','$content-color-1',0,''),(390904,123818,'118008','deals','block_type','5',0,''),(390905,123818,'118008','deals','font-weight','normal',0,''),(390906,123818,'118008','deals','border-bottom-width','1',0,''),(390907,123818,'118008','deals','border-bottom-color','$content-border-1',0,''),(390908,123818,'118008','deals','border-top-width','1',0,''),(390909,123818,'118008','deals','border-top-color','$content-border-1',0,''),(390910,123818,'118008','deals','border-left-color','$content-border-1',0,''),(390911,123818,'118008','deals','border-left-width','1',0,''),(390912,123819,'118009','deals','block_type','1',0,''),(390913,123819,'118009','deals','font-weight','normal',0,''),(390914,123819,'118009','deals','padding-top','10',0,''),(390915,123819,'118009','deals','padding-left','10',0,''),(390916,123819,'118009','deals','padding-right','10',0,''),(390917,123820,'118010','deals','font-weight','400',0,''),(390918,123820,'118010','deals','line-height','120',0,''),(390919,123820,'118010','deals','line_height_measure','%',0,''),(390920,123820,'118010','deals','font-size','12',0,''),(390921,123821,'118011','deals','text','<p>SHIPPING ADDRESS:</p>',1,''),(390922,123821,'118011','deals','font-size','14',0,''),(390923,123821,'118011','deals','font-weight','bold',0,''),(390924,123821,'118011','deals','padding-bottom','10',0,''),(390925,123821,'118011','deals','text','<p>SHIPPING ADDRESS:</p>',2,''),(390926,123821,'118011','deals','text','<p>SHIPPING ADDRESS:</p>',3,''),(390927,123821,'118011','deals','text','<p>SHIPPING ADDRESS:</p>',4,''),(390928,123822,'118012','deals','block_type','1',0,''),(390929,123822,'118012','deals','background-color','$content-bg-2',0,''),(390930,123822,'118012','deals','padding-top','20',0,''),(390931,123822,'118012','deals','padding-left','10',0,''),(390932,123822,'118012','deals','padding-right','10',0,''),(390933,123822,'118012','deals','padding-bottom','20',0,''),(390934,123822,'118012','deals','font-size','14',0,''),(390935,123823,'118013','deals','font-weight','normal',0,''),(390936,123823,'118013','deals','text-align','right',0,''),(390937,123823,'118013','deals','font-size','14',0,''),(390938,123823,'118013','deals','box_align','3',0,''),(390939,123824,'118014','deals','block_type','3',0,''),(390940,123824,'118014','deals','font-weight','normal',0,''),(390941,123824,'118014','deals','padding-top','20',0,''),(390942,123825,'118015','deals','text','<p>If undelivered please return to:</p>',1,''),(390943,123825,'118015','deals','font-size','12',0,''),(390944,123825,'118015','deals','font-weight','bold',0,''),(390945,123825,'118015','deals','text','<p>If undelivered please return to:</p>',2,''),(390946,123825,'118015','deals','text','<p>If undelivered please return to:</p>',3,''),(390947,123825,'118015','deals','text','<p>If undelivered please return to:</p>',4,''),(390948,123826,'118016','deals','font-size','12',0,''),(390949,123827,'118018','deals','text','<p>Thank you for your order</p>',1,''),(390950,123827,'118018','deals','color','$hileght-color-1',0,''),(390951,123827,'118018','deals','font-size','13',0,''),(390952,123827,'118018','deals','font-weight','bold',0,''),(390953,123827,'118018','deals','padding-top','5',0,''),(390954,123827,'118018','deals','text-align','center',0,''),(390955,123827,'118018','deals','text','<p>Thank you for your order</p>',2,''),(390956,123827,'118018','deals','text','<p>Thank you for your order</p>',3,''),(390957,123827,'118018','deals','text','<p>Thank you for your order</p>',4,''),(390958,123828,'118019','deals','text','<p>If something has gone wrong please contact us at:</p>',1,''),(390959,123828,'118019','deals','font-size','12',0,''),(390960,123828,'118019','deals','font-weight','bold',0,''),(390961,123828,'118019','deals','text-align','right',0,''),(390962,123828,'118019','deals','text','<p>If something has gone wrong please contact us at:</p>',2,''),(390963,123828,'118019','deals','text','<p>If something has gone wrong please contact us at:</p>',3,''),(390964,123828,'118019','deals','text','<p>If something has gone wrong please contact us at:</p>',4,''),(390965,123829,'118020','deals','block_type','6',0,''),(390966,123829,'118020','deals','font-weight','normal',0,''),(390967,123829,'118020','deals','font-size','16',0,''),(390968,123830,'118021','deals','text','<p>Email:</p>',1,''),(390969,123830,'118021','deals','font-weight','normal',0,''),(390970,123830,'118021','deals','text-align','right',0,''),(390971,123830,'118021','deals','font-size','12',0,''),(390972,123830,'118021','deals','text','<p>Email:</p>',2,''),(390973,123830,'118021','deals','text','<p>Email:</p>',3,''),(390974,123830,'118021','deals','text','<p>Email:</p>',4,''),(390975,123831,'118022','deals','font-weight','normal',0,''),(390976,123831,'118022','deals','text-align','right',0,''),(390977,123831,'118022','deals','font-size','12',0,''),(390978,123832,'118023','deals','block_type','6',0,''),(390979,123832,'118023','deals','font-weight','normal',0,''),(390980,123832,'118023','deals','font-size','16',0,''),(390981,123833,'118024','deals','text','<p>Phone:</p>',1,''),(390982,123833,'118024','deals','font-weight','normal',0,''),(390983,123833,'118024','deals','text-align','right',0,''),(390984,123833,'118024','deals','font-size','12',0,''),(390985,123833,'118024','deals','text','<p>Phone:</p>',2,''),(390986,123833,'118024','deals','text','<p>Phone:</p>',3,''),(390987,123833,'118024','deals','text','<p>Phone:</p>',4,''),(390988,123834,'118025','deals','font-weight','normal',0,''),(390989,123834,'118025','deals','text-align','right',0,''),(390990,123834,'118025','deals','font-size','12',0,''),(390991,123835,'118026','deals','font-weight','400',0,''),(390992,123835,'118026','deals','padding-top','20',0,''),(390993,123835,'118026','deals','padding-bottom','0',0,''),(390994,123835,'118026','deals','font-size','12',0,''),(390995,123836,'118027','deals','block_type','2',0,''),(390996,123836,'118027','deals','font-weight','normal',0,''),(390997,123836,'118027','deals','padding-bottom','20',0,''),(390998,123837,'1643890423','deals','logo','themes/deals/img/logo-2.png',1,''),(390999,123837,'1643890423','deals','logo','themes/deals/img/logo-2.png',2,''),(391000,123837,'1643890423','deals','logo','themes/deals/img/logo-2.png',3,''),(391001,123837,'1643890423','deals','logo','themes/deals/img/logo-2.png',4,''),(391002,123838,'118028','deals','block_type','11',0,''),(391003,123838,'118028','deals','font-weight','normal',0,''),(391004,123839,'118029','deals','text','<p>Email:</p>',1,''),(391005,123839,'118029','deals','font-weight','normal',0,''),(391006,123839,'118029','deals','text-align','right',0,''),(391007,123839,'118029','deals','text','<p>Email:</p>',2,''),(391008,123839,'118029','deals','text','<p>Email:</p>',3,''),(391009,123839,'118029','deals','text','<p>Email:</p>',4,''),(391010,123840,'118030','deals','font-weight','normal',0,''),(391011,123840,'118030','deals','text-align','right',0,''),(391012,123841,'118031','deals','block_type','11',0,''),(391013,123841,'118031','deals','font-weight','normal',0,''),(391014,123842,'118032','deals','text','<p>Web:</p>',1,''),(391015,123842,'118032','deals','font-weight','normal',0,''),(391016,123842,'118032','deals','text-align','right',0,''),(391017,123842,'118032','deals','text','<p>Web:</p>',2,''),(391018,123842,'118032','deals','text','<p>Web:</p>',3,''),(391019,123842,'118032','deals','text','<p>Web:</p>',4,''),(391020,123843,'118033','deals','font-weight','normal',0,''),(391021,123843,'118033','deals','text-align','right',0,''),(391022,123844,'118034','deals','block_type','1',0,''),(391023,123845,'118035','deals','font-weight','normal',0,''),(391024,123845,'118035','deals','text-align','right',0,''),(391025,123845,'118035','deals','padding-bottom','10',0,''),(391026,123845,'118035','deals','address_spacer',',',0,''),(391027,123845,'118035','deals','font-size','12',0,''),(391028,123846,'118036','deals','block_type','11',0,''),(391029,123846,'118036','deals','font-weight','normal',0,''),(391030,123847,'118037','deals','text','<p>Phone:</p>',1,''),(391031,123847,'118037','deals','font-weight','normal',0,''),(391032,123847,'118037','deals','text-align','right',0,''),(391033,123847,'118037','deals','text','<p>Phone:</p>',2,''),(391034,123847,'118037','deals','text','<p>Phone:</p>',3,''),(391035,123847,'118037','deals','text','<p>Phone:</p>',4,''),(391036,123848,'118038','deals','font-weight','normal',0,''),(391037,123848,'118038','deals','text-align','right',0,''),(391038,123849,'118039','deals','block_type','4',0,''),(391039,123849,'118039','deals','font-weight','normal',0,''),(391040,123849,'118039','deals','border-top-width','1',0,''),(391041,123849,'118039','deals','border-top-color','$content-border-1',0,''),(391042,123849,'118039','deals','border-left-width','1',0,''),(391043,123849,'118039','deals','border-left-color','$content-border-1',0,''),(391044,123849,'118039','deals','border-right-width','1',0,''),(391045,123849,'118039','deals','border-right-color','$content-border-1',0,''),(391046,123849,'118039','deals','border-bottom-width','1',0,''),(391047,123849,'118039','deals','border-bottom-color','$content-border-1',0,''),(391048,123850,'118040','deals','block_type','2',0,''),(391049,123850,'118040','deals','font-weight','normal',0,''),(391050,123850,'118040','deals','border-top-width','1',0,''),(391051,123850,'118040','deals','border-top-color','$content-border-1',0,''),(391052,123850,'118040','deals','border-right-width','1',0,''),(391053,123850,'118040','deals','border-right-color','$content-border-1',0,''),(391054,123851,'118041','deals','block_type','1',0,''),(391055,123851,'118041','deals','font-weight','normal',0,''),(391056,123851,'118041','deals','padding-top','10',0,''),(391057,123851,'118041','deals','padding-left','10',0,''),(391058,123851,'118041','deals','padding-right','10',0,''),(391059,123851,'118041','deals','padding-bottom','10',0,''),(391060,123851,'118041','deals','border-right-width','1',0,''),(391061,123851,'118041','deals','border-right-color','$content-border-1',0,''),(391062,123852,'118042','deals','text','<p>Shipping via</p>',1,''),(391063,123852,'118042','deals','font-weight','bold',0,''),(391064,123852,'118042','deals','font-size','14',0,''),(391065,123852,'118042','deals','text','<p>Shipping via</p>',2,''),(391066,123852,'118042','deals','text','<p>Shipping via</p>',3,''),(391067,123852,'118042','deals','text','<p>Shipping via</p>',4,''),(391068,123854,'118044','deals','block_type','1',0,''),(391069,123854,'118044','deals','font-weight','normal',0,''),(391070,123854,'118044','deals','padding-top','10',0,''),(391071,123854,'118044','deals','padding-left','10',0,''),(391072,123854,'118044','deals','padding-right','10',0,''),(391073,123854,'118044','deals','padding-bottom','10',0,''),(391074,123855,'118045','deals','text','<p>Shipping service</p>',1,''),(391075,123855,'118045','deals','font-weight','bold',0,''),(391076,123855,'118045','deals','font-size','14',0,''),(391077,123855,'118045','deals','text','<p>Shipping service</p>',2,''),(391078,123855,'118045','deals','text','<p>Shipping service</p>',3,''),(391079,123855,'118045','deals','text','<p>Shipping service</p>',4,''),(391080,123857,'118047','deals','block_type','2',0,''),(391081,123857,'118047','deals','font-weight','normal',0,''),(391082,123857,'118047','deals','border-right-width','1',0,''),(391083,123857,'118047','deals','border-right-color','$content-border-1',0,''),(391084,123858,'118048','deals','block_type','1',0,''),(391085,123858,'118048','deals','font-weight','400',0,''),(391086,123858,'118048','deals','background-color','$content-bg-2',0,''),(391087,123858,'118048','deals','padding-top','10',0,''),(391088,123858,'118048','deals','padding-left','10',0,''),(391089,123858,'118048','deals','padding-right','10',0,''),(391090,123858,'118048','deals','padding-bottom','30',0,''),(391091,123859,'118049','deals','font-size','12',0,''),(391092,123860,'118050','deals','text','<p>INVOICE ADDRESS:</p>',1,''),(391093,123860,'118050','deals','font-size','14',0,''),(391094,123860,'118050','deals','font-weight','bold',0,''),(391095,123860,'118050','deals','text','<p>INVOICE ADDRESS:</p>',2,''),(391096,123860,'118050','deals','text','<p>INVOICE ADDRESS:</p>',3,''),(391097,123860,'118050','deals','text','<p>INVOICE ADDRESS:</p>',4,''),(391098,123861,'118051','deals','block_type','1',0,''),(391099,123861,'118051','deals','font-weight','normal',0,''),(391100,123861,'118051','deals','padding-top','10',0,''),(391101,123861,'118051','deals','padding-left','10',0,''),(391102,123861,'118051','deals','padding-right','10',0,''),(391103,123861,'118051','deals','padding-bottom','10',0,''),(391104,123862,'118052','deals','font-weight','normal',0,''),(391105,123863,'118053','deals','text','<p>PHONE NUMBER:</p>',1,''),(391106,123863,'118053','deals','font-size','14',0,''),(391107,123863,'118053','deals','font-weight','bold',0,''),(391108,123863,'118053','deals','padding-top','10',0,''),(391109,123863,'118053','deals','text','<p>PHONE NUMBER:</p>',2,''),(391110,123863,'118053','deals','text','<p>PHONE NUMBER:</p>',3,''),(391111,123863,'118053','deals','text','<p>PHONE NUMBER:</p>',4,''),(391112,123865,'118055','deals','font-weight','normal',0,''),(391113,123866,'118056','deals','text','<p>E-MAIL ADDRESS:</p>',1,''),(391114,123866,'118056','deals','font-weight','bold',0,''),(391115,123866,'118056','deals','font-size','14',0,''),(391116,123866,'118056','deals','padding-top','10',0,''),(391117,123866,'118056','deals','text','<p>E-MAIL ADDRESS:</p>',2,''),(391118,123866,'118056','deals','text','<p>E-MAIL ADDRESS:</p>',3,''),(391119,123866,'118056','deals','text','<p>E-MAIL ADDRESS:</p>',4,''),(391120,123867,'118057','deals','text','<p>CUSTOMER:</p>',1,''),(391121,123867,'118057','deals','font-size','13',0,''),(391122,123867,'118057','deals','font-weight','bold',0,''),(391123,123867,'118057','deals','text','<p>CUSTOMER:</p>',2,''),(391124,123867,'118057','deals','text','<p>CUSTOMER:</p>',3,''),(391125,123867,'118057','deals','text','<p>CUSTOMER:</p>',4,''),(391126,123868,'118058','deals','font-weight','normal',0,''),(391127,123868,'118058','deals','text-align','center',0,''),(391128,123868,'118058','deals','padding-bottom','10',0,''),(391129,123869,'118059','deals','text','<p>Payment date:</p>',1,''),(391130,123869,'118059','deals','font-weight','bold',0,''),(391131,123869,'118059','deals','text-align','center',0,''),(391132,123869,'118059','deals','font-size','12',0,''),(391133,123869,'118059','deals','text','<p>Payment date:</p>',2,''),(391134,123869,'118059','deals','text','<p>Payment date:</p>',3,''),(391135,123869,'118059','deals','text','<p>Payment date:</p>',4,''),(391136,123870,'118060','deals','text','<p>Payment Method:</p>',1,''),(391137,123870,'118060','deals','font-weight','bold',0,''),(391138,123870,'118060','deals','text-align','center',0,''),(391139,123870,'118060','deals','text','<p>Payment Method:</p>',2,''),(391140,123870,'118060','deals','text','<p>Payment Method:</p>',3,''),(391141,123870,'118060','deals','text','<p>Payment Method:</p>',4,''),(391142,123871,'118061','deals','font-size','14',0,''),(391143,123871,'118061','deals','font-weight','bold',0,''),(391144,123871,'118061','deals','text-align','center',0,''),(391145,123871,'118061','deals','padding-bottom','10',0,''),(391146,123871,'118061','deals','padding-top','10',0,''),(391147,123872,'118062','deals','font-weight','normal',0,''),(391148,123872,'118062','deals','text-align','center',0,''),(391149,123872,'118062','deals','padding-bottom','20',0,''),(391150,123873,'118063','deals','font-weight','normal',0,''),(391151,123873,'118063','deals','text-align','center',0,''),(391152,123874,'118094','deals','block_type','1',0,''),(391153,123875,'118095','deals','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(391154,123877,'118318','deals','block_type','1',0,''),(391155,123878,'118319','deals','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(391156,123878,'118319','deals','padding-top','100',0,''),(391157,123878,'118319','deals','margin-bottom','100',0,''),(391158,123878,'118319','deals','text-align','center',0,''),(391159,123878,'118319','deals','font-size','20',0,''),(391160,123879,'118320','deals','block_type','1',0,''),(391161,123879,'118320','deals','background-color','$content-bg-2',0,''),(391162,123879,'118320','deals','padding-bottom','30',0,''),(391163,123880,'118321','deals','block_type','4',0,''),(391164,123880,'118321','deals','schema','4-2',0,'5639'),(391165,123881,'118322','deals','block_type','1',0,''),(391166,123881,'118322','deals','padding-right','40',0,''),(391167,123881,'118322','deals','padding-right','0',0,'5639'),(391168,123882,'118323','deals','block_type','2',0,''),(391169,123882,'118323','deals','margin-bottom','20',0,''),(391170,123882,'118323','deals','schema','2-2',0,'5630'),(391171,123882,'118323','deals','background-color','$content-bg-1',0,''),(391172,123883,'118324','deals','block_type','1',0,''),(391173,123883,'118324','deals','border-right-width','20',0,''),(391174,123883,'118324','deals','border-right-color','$content-border-1',0,''),(391175,123883,'118324','deals','margin-right','-10',0,''),(391176,123883,'118324','deals','padding-right','30',0,''),(391177,123883,'118324','deals','padding-top','20',0,''),(391178,123883,'118324','deals','padding-left','30',0,''),(391179,123883,'118324','deals','padding-bottom','20',0,''),(391180,123883,'118324','deals','border-right-width','0',0,'5639'),(391181,123883,'118324','deals','margin-right','0',0,'5639'),(391182,123883,'118324','deals','margin-bottom','20',0,'5639'),(391183,123883,'118324','deals','padding-left','20',0,'5639'),(391184,123883,'118324','deals','padding-right','20',0,'5639'),(391185,123885,'118326','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(391186,123885,'118326','deals','clear','none',0,''),(391187,123886,'118327','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(391188,123886,'118327','deals','clear','none',0,''),(391189,123887,'118328','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(391190,123889,'118330','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(391191,123889,'118330','deals','padding-top','20',0,''),(391192,123892,'118333','deals','margin-bottom','20',0,''),(391193,123893,'118334','deals','block_type','1',0,''),(391194,123893,'118334','deals','padding-left','30',0,''),(391195,123893,'118334','deals','border-left-width','20',0,''),(391196,123893,'118334','deals','border-left-color','$content-border-1',0,''),(391197,123893,'118334','deals','margin-left','-10',0,''),(391198,123893,'118334','deals','padding-right','30',0,''),(391199,123893,'118334','deals','padding-top','20',0,''),(391200,123893,'118334','deals','padding-bottom','20',0,''),(391201,123893,'118334','deals','border-left-width','0',0,'5639'),(391202,123894,'118335','deals','margin-bottom','20',0,''),(391203,123896,'118337','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(391204,123897,'118338','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(391205,123897,'118338','deals','clear','none',0,''),(391206,123898,'118339','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(391207,123898,'118339','deals','clear','none',0,''),(391208,123899,'118340','deals','block_type','1',0,''),(391209,123899,'118340','deals','padding-right','30',0,''),(391210,123899,'118340','deals','background-color','$content-bg-1',0,''),(391211,123899,'118340','deals','padding-top','20',0,''),(391212,123899,'118340','deals','padding-left','30',0,''),(391213,123899,'118340','deals','padding-bottom','20',0,''),(391214,123899,'118340','deals','padding-left','20',0,'5639'),(391215,123899,'118340','deals','padding-right','20',0,'5639'),(391216,123901,'118342','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(391217,123902,'118343','deals','block_type','1',0,''),(391218,123902,'118343','deals','padding-top','20',0,''),(391219,123902,'118343','deals','padding-left','20',0,''),(391220,123902,'118343','deals','padding-right','20',0,''),(391221,123902,'118343','deals','padding-bottom','20',0,''),(391222,123902,'118343','deals','background-color','$content-bg-1',0,''),(391223,123902,'118343','deals','style_class','order-summary',0,''),(391224,123903,'118344','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(391225,123907,'118348','deals','block_type','1',0,''),(391226,123907,'118348','deals','padding-bottom','30',0,''),(391227,123908,'118349','deals','block_type','4',0,''),(391228,123908,'118349','deals','schema','4-2',0,'5639'),(391229,123909,'118350','deals','block_type','1',0,''),(391230,123909,'118350','deals','padding-right','20',0,''),(391231,123909,'118350','deals','padding-top','20',0,''),(391232,123909,'118350','deals','padding-left','20',0,''),(391233,123909,'118350','deals','padding-bottom','20',0,''),(391234,123909,'118350','deals','border-top-width','1',0,''),(391235,123909,'118350','deals','border-left-width','1',0,''),(391236,123909,'118350','deals','border-right-width','1',0,''),(391237,123909,'118350','deals','border-bottom-width','1',0,''),(391238,123909,'118350','deals','border-top-color','$content-border-1',0,''),(391239,123909,'118350','deals','border-left-color','$content-border-1',0,''),(391240,123909,'118350','deals','border-right-color','$content-border-1',0,''),(391241,123909,'118350','deals','border-bottom-color','$content-border-1',0,''),(391242,123909,'118350','deals','margin-bottom','30',0,''),(391243,123909,'118350','deals','padding-top','15',0,'5639'),(391244,123909,'118350','deals','padding-left','15',0,'5639'),(391245,123909,'118350','deals','padding-right','15',0,'5639'),(391246,123909,'118350','deals','padding-bottom','15',0,'5639'),(391247,123910,'118351','deals','block_type','2',0,''),(391248,123910,'118351','deals','margin-bottom','20',0,''),(391249,123910,'118351','deals','schema','2-1',0,'5630'),(391250,123910,'118351','deals','background-color','$content-bg-1',0,''),(391251,123910,'118351','deals','schema','2-2',0,'5660'),(391252,123911,'118352','deals','block_type','1',0,''),(391253,123911,'118352','deals','border-right-width','0',0,'5639'),(391254,123911,'118352','deals','margin-right','0',0,'5639'),(391255,123911,'118352','deals','padding-right','20',0,''),(391256,123911,'118352','deals','margin-bottom','20',0,'5660'),(391257,123912,'118353','deals','margin-bottom','20',0,''),(391258,123915,'118356','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(391259,123915,'118356','deals','padding-top','20',0,''),(391260,123917,'118358','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(391261,123917,'118358','deals','clear','none',0,''),(391262,123919,'118360','deals','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(391263,123920,'118361','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(391264,123920,'118361','deals','clear','none',0,''),(391265,123922,'118362','deals','block_type','1',0,''),(391266,123922,'118362','deals','padding-left','20',0,''),(391267,123922,'118362','deals','border-left-width','0',0,'5639'),(391268,123922,'118362','deals','padding-left','0',0,'5660'),(391269,123923,'118363','deals','text','<div class=\"heading-2\">##TEXT_PAYMENT##</div>',0,''),(391270,123924,'118364','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(391271,123924,'118364','deals','clear','none',0,''),(391272,123925,'118365','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(391273,123925,'118365','deals','clear','none',0,''),(391274,123926,'118366','deals','margin-bottom','20',0,''),(391275,123927,'118367','deals','orders_data','name',0,''),(391276,123928,'118368','deals','block_type','1',0,''),(391277,123928,'118368','deals','padding-right','20',0,''),(391278,123928,'118368','deals','background-color','$content-bg-1',0,''),(391279,123928,'118368','deals','padding-top','20',0,''),(391280,123928,'118368','deals','padding-left','20',0,''),(391281,123928,'118368','deals','padding-bottom','20',0,''),(391282,123928,'118368','deals','padding-left','15',0,'5639'),(391283,123928,'118368','deals','padding-right','15',0,'5639'),(391284,123928,'118368','deals','border-top-width','1',0,''),(391285,123928,'118368','deals','border-left-width','1',0,''),(391286,123928,'118368','deals','border-right-width','1',0,''),(391287,123928,'118368','deals','border-bottom-width','1',0,''),(391288,123928,'118368','deals','border-top-color','$content-border-1',0,''),(391289,123928,'118368','deals','border-left-color','$content-border-1',0,''),(391290,123928,'118368','deals','border-right-color','$content-border-1',0,''),(391291,123928,'118368','deals','border-bottom-color','$content-border-1',0,''),(391292,123928,'118368','deals','padding-top','15',0,'5639'),(391293,123928,'118368','deals','padding-bottom','15',0,'5639'),(391294,123928,'118368','deals','margin-bottom','30',0,'5639'),(391295,123929,'118369','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(391296,123931,'118371','deals','block_type','1',0,''),(391297,123931,'118371','deals','padding-left','30',0,''),(391298,123931,'118371','deals','background-color','$content-bg-1',0,''),(391299,123931,'118371','deals','style_class','order-summary',0,''),(391300,123931,'118371','deals','padding-left','0',0,'5639'),(391301,123934,'118374','deals','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(391302,123936,'118440','deals','block_type','1',0,''),(391303,123937,'118441','deals','block_type','6',0,''),(391304,123937,'118441','deals','schema','6-3',0,'5639'),(391305,123938,'118442','deals','aria_name','account-menu',0,''),(391306,123939,'116126','deals','block_type','1',0,''),(391307,123939,'116126','deals','padding-top','80',0,''),(391308,123939,'116126','deals','padding-right','30',0,''),(391309,123939,'116126','deals','padding-bottom','30',0,''),(391310,123939,'116126','deals','padding-top','0',0,'5639'),(391311,123939,'116126','deals','padding-left','0',0,'5639'),(391312,123939,'116126','deals','padding-right','0',0,'5639'),(391313,123939,'116126','deals','padding-bottom','0',0,'5639'),(391369,123958,'118443','deals','margin-bottom','20',0,''),(391370,123959,'118444','deals','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(391371,123960,'118445','deals','block_type','1',0,''),(391372,123960,'118445','deals','padding-top','20',0,''),(391373,123960,'118445','deals','padding-bottom','20',0,''),(391374,123962,'118447','deals','padding-top','20',0,''),(391375,123962,'118447','deals','padding-bottom','20',0,''),(570622,179319,'1712569858.457560','furniture','from_file','header_2.zip',0,''),(570623,179320,'1712569858.46511','furniture','block_type','1',0,''),(570624,179320,'1712569858.46511','furniture','border-bottom-width','1',0,''),(570625,179320,'1712569858.46511','furniture','border-bottom-color','$header-border-1',0,''),(570626,179320,'1712569858.46511','furniture','font-weight','normal',0,''),(570627,179320,'1712569858.46511','furniture','visibility_checkout','1',0,''),(570628,179320,'1712569858.46511','furniture','background-color','$header-bg-1',0,''),(570629,179320,'1712569858.46511','furniture','color','$header-color-1',0,''),(570630,179320,'1712569858.46511','furniture','from_file','header_2.zip',0,''),(570652,179326,'1712569858.628847','furniture','block_type','1',0,''),(570653,179326,'1712569858.628847','furniture','padding-top','3',0,''),(570654,179326,'1712569858.628847','furniture','padding-top','0',0,'5161'),(570655,179326,'1712569858.628847','furniture','padding-bottom','0',0,'5161'),(570656,179326,'1712569858.628847','furniture','background-color','$header-bg-1',0,''),(570657,179326,'1712569858.628847','furniture','color','$header-color-1',0,''),(570658,179326,'1712569858.628847','furniture','style_class','header-middle',0,''),(570659,179326,'1712569858.628847','furniture','from_file','header_2.zip',0,''),(570687,179332,'1712569858.854422','furniture','block_type','1',0,''),(570688,179332,'1712569858.854422','furniture','font-weight','400',0,''),(570689,179332,'1712569858.854422','furniture','background-color','$header-menu-bg-1',0,''),(570690,179332,'1712569858.854422','furniture','visibility_checkout','1',0,''),(570691,179332,'1712569858.854422','furniture','style_class','header-menu-holder',0,''),(570692,179332,'1712569858.854422','furniture','from_file','header_2.zip',0,''),(570727,179334,'1712672669.73341','furniture','from_file','header_2.zip',0,''),(570728,179335,'1712672669.737451','furniture','block_type','1',0,''),(570729,179335,'1712672669.737451','furniture','border-bottom-width','1',0,''),(570730,179335,'1712672669.737451','furniture','border-bottom-color','$header-border-1',0,''),(570731,179335,'1712672669.737451','furniture','font-weight','normal',0,''),(570732,179335,'1712672669.737451','furniture','visibility_checkout','1',0,''),(570733,179335,'1712672669.737451','furniture','background-color','$header-bg-1',0,''),(570734,179335,'1712672669.737451','furniture','color','$header-color-1',0,''),(570735,179335,'1712672669.737451','furniture','from_file','header_2.zip',0,''),(570757,179341,'1712672669.895430','furniture','block_type','1',0,''),(570758,179341,'1712672669.895430','furniture','padding-top','3',0,''),(570759,179341,'1712672669.895430','furniture','padding-top','0',0,'5161'),(570760,179341,'1712672669.895430','furniture','padding-bottom','0',0,'5161'),(570761,179341,'1712672669.895430','furniture','background-color','$header-bg-1',0,''),(570762,179341,'1712672669.895430','furniture','color','$header-color-1',0,''),(570763,179341,'1712672669.895430','furniture','style_class','header-middle',0,''),(570764,179341,'1712672669.895430','furniture','from_file','header_2.zip',0,''),(570792,179347,'1712672670.192374','furniture','block_type','1',0,''),(570793,179347,'1712672670.192374','furniture','font-weight','400',0,''),(570794,179347,'1712672670.192374','furniture','background-color','$header-menu-bg-1',0,''),(570795,179347,'1712672670.192374','furniture','visibility_checkout','1',0,''),(570796,179347,'1712672670.192374','furniture','style_class','header-menu-holder',0,''),(570797,179347,'1712672670.192374','furniture','from_file','header_2.zip',0,''),(570832,179349,'1712673366.442350','furniture','from_file','header_2.zip',0,''),(570833,179350,'1712673366.452464','furniture','block_type','1',0,''),(570834,179350,'1712673366.452464','furniture','border-bottom-width','1',0,''),(570835,179350,'1712673366.452464','furniture','border-bottom-color','$header-border-1',0,''),(570836,179350,'1712673366.452464','furniture','font-weight','normal',0,''),(570837,179350,'1712673366.452464','furniture','visibility_checkout','1',0,''),(570838,179350,'1712673366.452464','furniture','background-color','$header-bg-1',0,''),(570839,179350,'1712673366.452464','furniture','color','$header-color-1',0,''),(570840,179350,'1712673366.452464','furniture','from_file','header_2.zip',0,''),(570862,179356,'1712673366.616449','furniture','block_type','1',0,''),(570863,179356,'1712673366.616449','furniture','padding-top','3',0,''),(570864,179356,'1712673366.616449','furniture','padding-top','0',0,'5161'),(570865,179356,'1712673366.616449','furniture','padding-bottom','0',0,'5161'),(570866,179356,'1712673366.616449','furniture','background-color','$header-bg-1',0,''),(570867,179356,'1712673366.616449','furniture','color','$header-color-1',0,''),(570868,179356,'1712673366.616449','furniture','style_class','header-middle',0,''),(570869,179356,'1712673366.616449','furniture','from_file','header_2.zip',0,''),(570897,179362,'1712673366.847874','furniture','block_type','1',0,''),(570898,179362,'1712673366.847874','furniture','font-weight','400',0,''),(570899,179362,'1712673366.847874','furniture','background-color','$header-menu-bg-1',0,''),(570900,179362,'1712673366.847874','furniture','visibility_checkout','1',0,''),(570901,179362,'1712673366.847874','furniture','style_class','header-menu-holder',0,''),(570902,179362,'1712673366.847874','furniture','from_file','header_2.zip',0,''),(570937,179364,'1712674966.930853','furniture','from_file','header_2.zip',0,''),(570938,179365,'1712674966.934154','furniture','block_type','1',0,''),(570939,179365,'1712674966.934154','furniture','border-bottom-width','1',0,''),(570940,179365,'1712674966.934154','furniture','border-bottom-color','$header-border-1',0,''),(570941,179365,'1712674966.934154','furniture','font-weight','normal',0,''),(570942,179365,'1712674966.934154','furniture','visibility_checkout','1',0,''),(570943,179365,'1712674966.934154','furniture','background-color','$header-bg-1',0,''),(570944,179365,'1712674966.934154','furniture','color','$header-color-1',0,''),(570945,179365,'1712674966.934154','furniture','from_file','header_2.zip',0,''),(570946,179366,'1712674966.936778','furniture','block_type','2',0,''),(570947,179366,'1712674966.936778','furniture','font-weight','400',0,''),(570948,179366,'1712674966.936778','furniture','schema','2-2',0,''),(570949,179366,'1712674966.936778','furniture','schema','5-1',0,'5140'),(570950,179366,'1712674966.936778','furniture','schema','2-2',0,'5131'),(570951,179367,'1712674966.939493','furniture','class','menu-horizontal',0,''),(570952,179367,'1712674966.939493','furniture','box_align','1',0,''),(570953,179367,'1712674966.939493','furniture','font-weight','400',0,''),(570954,179367,'1712674966.939493','furniture','float','left',0,''),(570955,179367,'1712674966.939493','furniture','display_none','1',0,'5161'),(570956,179367,'1712674966.939493','furniture','display','none',0,'5140'),(570957,179368,'1712674967.04388','furniture','block_type','1',0,''),(570958,179369,'1712674967.045458','furniture','box_align','3',0,''),(570959,179369,'1712674967.045458','furniture','font-weight','normal',0,''),(570960,179369,'1712674967.045458','furniture','show_symbol_left','1',0,''),(570961,179369,'1712674967.045458','furniture','show_symbol_right','1',0,''),(570962,179370,'1712674967.072331','furniture','box_align','3',0,''),(570963,179370,'1712674967.072331','furniture','font-weight','normal',0,''),(570964,179370,'1712674967.072331','furniture','border-left-width','1',0,''),(570965,179370,'1712674967.072331','furniture','border-left-color','$content-border-1',0,''),(570966,179370,'1712674967.072331','furniture','show_title','1',0,''),(570967,179371,'1712674967.095974','furniture','block_type','1',0,''),(570968,179371,'1712674967.095974','furniture','padding-top','3',0,''),(570969,179371,'1712674967.095974','furniture','padding-top','0',0,'5161'),(570970,179371,'1712674967.095974','furniture','padding-bottom','0',0,'5161'),(570971,179371,'1712674967.095974','furniture','background-color','$header-bg-1',0,''),(570972,179371,'1712674967.095974','furniture','color','$header-color-1',0,''),(570973,179371,'1712674967.095974','furniture','style_class','header-middle',0,''),(570974,179371,'1712674967.095974','furniture','from_file','header_2.zip',0,''),(570975,179372,'1712674967.104961','furniture','font-weight','400',0,''),(570976,179372,'1712674967.104961','furniture','box_align','1',0,''),(570978,179372,'1712674967.104961','furniture','float','left',0,''),(570979,179372,'1712674967.104961','furniture','clear','both',0,''),(570980,179372,'1712674967.104961','furniture','margin-top','22',0,''),(570981,179372,'1712674967.104961','furniture','margin-bottom','22',0,''),(570982,179372,'1712674967.104961','furniture','max-width','250',0,''),(570983,179372,'1712674967.104961','furniture','margin-top','10',0,'5140'),(570984,179372,'1712674967.104961','furniture','margin-bottom','10',0,'5140'),(570985,179373,'1712674967.10848','furniture','visibility_checkout','1',0,''),(570986,179373,'1712674967.10848','furniture','search_history','1',0,''),(570987,179373,'1712674967.10848','furniture','padding-left','20',0,''),(570988,179374,'1712674967.177380','furniture','box_align','3',0,''),(570989,179374,'1712674967.177380','furniture','only_icon','on',0,''),(570990,179374,'1712674967.177380','furniture','items','1',0,''),(570991,179374,'1712674967.177380','furniture','total','1',0,''),(570992,179374,'1712674967.177380','furniture','show_products','dropdown',0,''),(570993,179374,'1712674967.177380','furniture','margin-left','20',0,''),(570994,179375,'1712674967.300450','furniture','box_align','3',0,''),(570995,179375,'1712674967.300450','furniture','only_icon','on',0,''),(570996,179375,'1712674967.300450','furniture','margin-left','20',0,''),(570997,179375,'1712674967.300450','furniture','link_or_dropdown','1',0,''),(570998,179376,'1712674967.356553','furniture','float','left',0,''),(570999,179376,'1712674967.356553','furniture','clear','none',0,''),(571000,179376,'1712674967.356553','furniture','display_none','1',0,'5145'),(571001,179376,'1712674967.356553','furniture','logo','themes/furniture/img/header-img.png',1,''),(571002,179377,'1712674967.37028','furniture','block_type','1',0,''),(571003,179377,'1712674967.37028','furniture','font-weight','400',0,''),(571004,179377,'1712674967.37028','furniture','background-color','$header-menu-bg-1',0,''),(571005,179377,'1712674967.37028','furniture','visibility_checkout','1',0,''),(571006,179377,'1712674967.37028','furniture','style_class','header-menu-holder',0,''),(571007,179377,'1712674967.37028','furniture','from_file','header_2.zip',0,''),(571008,179378,'1712674967.380976','furniture','class','menu-style-1',0,''),(571009,179378,'1712674967.380976','furniture','box_align','4',0,''),(571010,179378,'1712674967.380976','furniture','font-weight','400',0,''),(571011,179378,'1712674967.380976','furniture','hide_menu','on',0,''),(571012,179378,'1712674967.380976','furniture','color','$highlight-box-color-2',0,''),(571013,179378,'1712674967.380976','furniture','hide_menu','1',0,'5140'),(571014,179378,'1712674967.380976','furniture','show_new','1',0,''),(571015,179378,'1712674967.380976','furniture','type','builder',0,''),(571016,179378,'1712674967.380976','furniture','burger_icon','1',0,'5140'),(571017,179378,'1712674967.380976','furniture','style','2',0,'5140'),(571018,179378,'1712674967.380976','furniture','open_from','left',0,'5140'),(571019,179378,'1712674967.380976','furniture','lev2_vis','click',0,'5140'),(571020,179378,'1712674967.380976','furniture','style','1',0,'5198'),(571021,179378,'1712674967.380976','furniture','position','horizontal_flex',0,'5198'),(571022,179378,'1712674967.380976','furniture','lev2_vis','over',0,'5198'),(571023,179378,'1712674967.380976','furniture','lev3_vis','over',0,'5198'),(571024,179378,'1712674967.380976','furniture','lev4_vis','over',0,'5198'),(571025,179378,'1712674967.380976','furniture','lev5_vis','over',0,'5198'),(571026,179378,'1712674967.380976','furniture','lev6_vis','over',0,'5198'),(571027,179378,'1712674967.380976','furniture','lev2_display','down',0,'5198'),(571028,179378,'1712674967.380976','furniture','lev3_display','lra',0,'5198'),(571029,179378,'1712674967.380976','furniture','lev4_display','lra',0,'5198'),(571030,179378,'1712674967.380976','furniture','lev5_display','lra',0,'5198'),(571031,179378,'1712674967.380976','furniture','lev6_display','lra',0,'5198'),(571032,179378,'1712674967.380976','furniture','lev2_display','slide',0,'5140'),(571033,179378,'1712674967.380976','furniture','lev3_display','slide',0,'5140'),(571034,179378,'1712674967.380976','furniture','lev3_vis','click',0,'5140'),(571035,179378,'1712674967.380976','furniture','lev4_vis','click',0,'5140'),(571036,179378,'1712674967.380976','furniture','lev4_display','slide',0,'5140'),(571037,179378,'1712674967.380976','furniture','lev5_vis','click',0,'5140'),(571038,179378,'1712674967.380976','furniture','lev5_display','slide',0,'5140'),(571039,179378,'1712674967.380976','furniture','lev6_vis','click',0,'5140'),(571040,179378,'1712674967.380976','furniture','lev6_display','slide',0,'5140'),(571041,179378,'1712674967.380976','furniture','style_class','header-menu',0,''),(571042,179379,'1712679985.656435','watch','from_file','header_1.zip',0,''),(571043,179380,'1712679985.659674','watch','block_type','1',0,''),(571044,179380,'1712679985.659674','watch','border-bottom-width','1',0,''),(571045,179380,'1712679985.659674','watch','border-bottom-color','$header-border-1',0,''),(571046,179380,'1712679985.659674','watch','font-weight','normal',0,''),(571047,179380,'1712679985.659674','watch','visibility_checkout','1',0,''),(571048,179380,'1712679985.659674','watch','background-color','$header-bg-1',0,''),(571049,179380,'1712679985.659674','watch','color','$header-color-1',0,''),(571050,179380,'1712679985.659674','watch','from_file','header_1.zip',0,''),(571051,179381,'1712679985.661821','watch','block_type','5',0,''),(571052,179381,'1712679985.661821','watch','font-weight','400',0,''),(571053,179381,'1712679985.661821','watch','schema','2-2',0,''),(571054,179381,'1712679985.661821','watch','schema','5-2',0,'5240'),(571055,179381,'1712679985.661821','watch','schema','5-1',0,'5261'),(571056,179382,'1712679985.663776','watch','class','menu-horizontal',0,''),(571057,179382,'1712679985.663776','watch','box_align','1',0,''),(571058,179382,'1712679985.663776','watch','font-weight','400',0,''),(571059,179382,'1712679985.663776','watch','border-top-width','1',0,'5240'),(571060,179382,'1712679985.663776','watch','border-top-color','$content-border-1',0,'5240'),(571061,179382,'1712679985.663776','watch','display','none',0,'5240'),(571062,179383,'1712679985.705953','watch','block_type','1',0,''),(571063,179384,'1712679985.707292','watch','font-weight','400',0,''),(571064,179384,'1712679985.707292','watch','box_align','3',0,''),(571065,179384,'1712679985.707292','watch','show_products','dropdown',0,''),(571066,179384,'1712679985.707292','watch','only_icon','on',0,''),(571067,179385,'1712679985.760839','watch','font-weight','normal',0,''),(571068,179385,'1712679985.760839','watch','box_align','3',0,''),(571069,179385,'1712679985.760839','watch','border-left-width','1',0,''),(571070,179385,'1712679985.760839','watch','border-left-color','$header-border-1',0,''),(571071,179385,'1712679985.760839','watch','only_icon','on',0,''),(571072,179386,'1712679985.804792','watch','box_align','3',0,''),(571073,179386,'1712679985.804792','watch','font-weight','normal',0,''),(571074,179386,'1712679985.804792','watch','padding-top','0',0,'5240'),(571075,179386,'1712679985.804792','watch','padding-right','0',0,'5240'),(571076,179386,'1712679985.804792','watch','padding-bottom','0',0,'5240'),(571077,179386,'1712679985.804792','watch','padding-left','0',0,'5240'),(571078,179386,'1712679985.804792','watch','show_symbol_left','1',0,''),(571079,179386,'1712679985.804792','watch','show_symbol_right','1',0,''),(571080,179387,'1712679985.832720','watch','box_align','3',0,''),(571081,179387,'1712679985.832720','watch','font-weight','normal',0,''),(571082,179387,'1712679985.832720','watch','border-left-width','1',0,''),(571083,179387,'1712679985.832720','watch','border-left-color','$header-border-1',0,''),(571084,179387,'1712679985.832720','watch','padding-top','0',0,'5240'),(571085,179387,'1712679985.832720','watch','padding-right','0',0,'5240'),(571086,179387,'1712679985.832720','watch','padding-bottom','0',0,'5240'),(571087,179387,'1712679985.832720','watch','padding-left','0',0,'5240'),(571088,179387,'1712679985.832720','watch','show_title','1',0,''),(571089,179388,'1712679985.861268','watch','block_type','1',0,''),(571090,179388,'1712679985.861268','watch','padding-top','20',0,''),(571091,179388,'1712679985.861268','watch','padding-bottom','20',0,''),(571092,179388,'1712679985.861268','watch','style_class','header-content',0,''),(571093,179388,'1712679985.861268','watch','color','$header-color-1',0,''),(571094,179388,'1712679985.861268','watch','background-color','$header-bg-1',0,''),(571095,179388,'1712679985.861268','watch','from_file','header_1.zip',0,''),(571096,179388,'1712679985.861268','watch','padding-top','12',0,'5232'),(571097,179388,'1712679985.861268','watch','padding-bottom','12',0,'5232'),(571098,179389,'1712679985.873114','watch','font-weight','400',0,''),(571099,179389,'1712679985.873114','watch','box_align','1',0,''),(571100,179389,'1712679985.873114','watch','text-align','center',0,'5261'),(571101,179389,'1712679985.873114','watch','width','100',0,'5261'),(571102,179389,'1712679985.873114','watch','width_measure','%',0,'5261'),(571103,179389,'1712679985.873114','watch','logo_from','theme',0,''),(571104,179389,'1712679985.873114','watch','padding-right','20',0,''),(571105,179390,'1712679985.87751','watch','visibility_checkout','1',0,''),(571106,179390,'1712679985.87751','watch','search_history','1',0,''),(571107,179390,'1712679985.87751','watch','history_items','5',0,''),(571108,179390,'1712679985.87751','watch','margin-left','20',0,''),(571109,179391,'1712679985.999727','watch','text','<p class=\"customer-service\">Customer service <b>08000112569</b></p>',1,''),(571110,179391,'1712679985.999727','watch','float','right',0,''),(571111,179391,'1712679985.999727','watch','display_none','1',0,'5261'),(571112,179391,'1712679985.999727','watch','text','<p class=\"customer-service\">Customer service <b>08000112569</b></p>',0,''),(571113,179391,'1712679985.999727','watch','display','none',0,'5240'),(571114,179391,'1712679985.999727','watch','margin-left','20',0,''),(571115,179392,'1712679986.031228','watch','block_type','1',0,''),(571116,179392,'1712679986.031228','watch','font-weight','400',0,''),(571117,179392,'1712679986.031228','watch','background-color','$header-menu-bg-1',0,''),(571118,179392,'1712679986.031228','watch','visibility_checkout','1',0,''),(571119,179392,'1712679986.031228','watch','color','$header-menu-color-1',0,''),(571120,179392,'1712679986.031228','watch','from_file','header_1.zip',0,''),(571121,179392,'1712679986.031228','watch','style_class','header-menu-holder',0,''),(571122,179393,'1712679986.036538','watch','class','menu-style-1',0,''),(571123,179393,'1712679986.036538','watch','box_align','4',0,''),(571124,179393,'1712679986.036538','watch','font-weight','400',0,''),(571125,179393,'1712679986.036538','watch','hide_menu','on',0,''),(571126,179393,'1712679986.036538','watch','color','$header-menu-color-1',0,''),(571127,179393,'1712679986.036538','watch','hide_menu','1',0,'5240'),(571128,179393,'1712679986.036538','watch','show_new','1',0,''),(571129,179393,'1712679986.036538','watch','style_class','header-menu',0,''),(571130,179393,'1712679986.036538','watch','type','builder',0,''),(571131,179393,'1712679986.036538','watch','position','horizontal_center',0,'7918'),(571132,179393,'1712679986.036538','watch','style','1',0,'7918'),(571133,179393,'1712679986.036538','watch','lev2_vis','over',0,'7918'),(571134,179393,'1712679986.036538','watch','lev2_display','down',0,'7918'),(571135,179393,'1712679986.036538','watch','lev3_vis','over',0,'7918'),(571136,179393,'1712679986.036538','watch','lev4_vis','over',0,'7918'),(571137,179393,'1712679986.036538','watch','lev5_vis','over',0,'7918'),(571138,179393,'1712679986.036538','watch','lev6_vis','over',0,'7918'),(571139,179393,'1712679986.036538','watch','lev3_display','lra',0,'7918'),(571140,179393,'1712679986.036538','watch','lev4_display','lra',0,'7918'),(571141,179393,'1712679986.036538','watch','lev5_display','lra',0,'7918'),(571142,179393,'1712679986.036538','watch','lev6_display','lra',0,'7918'),(571143,179393,'1712679986.036538','watch','style','2',0,'5240'),(571144,179393,'1712679986.036538','watch','burger_icon','1',0,'5240'),(571145,179393,'1712679986.036538','watch','open_from','top',0,'5240'),(571146,179393,'1712679986.036538','watch','lev2_vis','click',0,'5240'),(571147,179393,'1712679986.036538','watch','lev3_vis','click',0,'5240'),(571148,179393,'1712679986.036538','watch','lev4_vis','click',0,'5240'),(571149,179393,'1712679986.036538','watch','lev5_vis','click',0,'5240'),(571150,179393,'1712679986.036538','watch','lev6_vis','click',0,'5240'),(571151,179393,'1712679986.036538','watch','from_file','menu_1.zip',0,''),(571152,179394,'1712755911.507134','printshop','from_file','h.zip',0,''),(571153,179395,'1712755911.510718','printshop','block_type','1',0,''),(571154,179395,'1712755911.510718','printshop','border-bottom-width','1',0,''),(571155,179395,'1712755911.510718','printshop','border-bottom-color','$header-border-1',0,''),(571156,179395,'1712755911.510718','printshop','font-weight','normal',0,''),(571157,179395,'1712755911.510718','printshop','visibility_checkout','1',0,''),(571158,179395,'1712755911.510718','printshop','display_none','1',0,'5342'),(571159,179395,'1712755911.510718','printshop','style_class','topHeader',0,''),(571160,179395,'1712755911.510718','printshop','padding-top','10',0,''),(571161,179395,'1712755911.510718','printshop','padding-bottom','10',0,''),(571162,179395,'1712755911.510718','printshop','background-color','$header-bg-1',0,''),(571163,179395,'1712755911.510718','printshop','color','$header-color-1',0,''),(571164,179395,'1712755911.510718','printshop','from_file','h.zip',0,''),(571202,179404,'1712755911.735376','printshop','block_type','1',0,''),(571203,179404,'1712755911.735376','printshop','padding-top','3',0,''),(571204,179404,'1712755911.735376','printshop','padding-top','0',0,'5363'),(571205,179404,'1712755911.735376','printshop','padding-bottom','0',0,'5363'),(571206,179404,'1712755911.735376','printshop','style_class','header-middle',0,''),(571207,179404,'1712755911.735376','printshop','position','relative',0,''),(571208,179404,'1712755911.735376','printshop','background-color','$header-bg-1',0,''),(571209,179404,'1712755911.735376','printshop','border-bottom-width','1',0,''),(571210,179404,'1712755911.735376','printshop','border-bottom-color','$header-border-1',0,''),(571211,179404,'1712755911.735376','printshop','color','$header-color-1',0,''),(571212,179404,'1712755911.735376','printshop','from_file','h.zip',0,''),(571276,179411,'1712756000.134372','printshop','from_file','header_1.zip',0,''),(571277,179412,'1712756000.136830','printshop','block_type','1',0,''),(571278,179412,'1712756000.136830','printshop','border-bottom-width','1',0,''),(571279,179412,'1712756000.136830','printshop','border-bottom-color','$header-border-1',0,''),(571280,179412,'1712756000.136830','printshop','font-weight','normal',0,''),(571281,179412,'1712756000.136830','printshop','visibility_checkout','1',0,''),(571282,179412,'1712756000.136830','printshop','background-color','$header-bg-1',0,''),(571283,179412,'1712756000.136830','printshop','color','$header-color-1',0,''),(571284,179412,'1712756000.136830','printshop','from_file','header_1.zip',0,''),(571323,179420,'1712756000.37386','printshop','block_type','1',0,''),(571324,179420,'1712756000.37386','printshop','padding-top','20',0,''),(571325,179420,'1712756000.37386','printshop','padding-bottom','20',0,''),(571326,179420,'1712756000.37386','printshop','style_class','header-content',0,''),(571327,179420,'1712756000.37386','printshop','color','$header-color-1',0,''),(571328,179420,'1712756000.37386','printshop','background-color','$header-bg-1',0,''),(571329,179420,'1712756000.37386','printshop','from_file','header_1.zip',0,''),(571330,179420,'1712756000.37386','printshop','padding-top','12',0,'5333'),(571331,179420,'1712756000.37386','printshop','padding-bottom','12',0,'5333'),(571349,179424,'1712756000.489135','printshop','block_type','1',0,''),(571350,179424,'1712756000.489135','printshop','font-weight','400',0,''),(571351,179424,'1712756000.489135','printshop','background-color','$header-menu-bg-1',0,''),(571352,179424,'1712756000.489135','printshop','visibility_checkout','1',0,''),(571353,179424,'1712756000.489135','printshop','color','$header-menu-color-1',0,''),(571354,179424,'1712756000.489135','printshop','from_file','header_1.zip',0,''),(571355,179424,'1712756000.489135','printshop','style_class','header-menu-holder',0,''),(571386,179426,'1712756007.569966','printshop','from_file','h.zip',0,''),(571387,179427,'1712756007.57315','printshop','block_type','1',0,''),(571388,179427,'1712756007.57315','printshop','border-bottom-width','1',0,''),(571389,179427,'1712756007.57315','printshop','border-bottom-color','$header-border-1',0,''),(571390,179427,'1712756007.57315','printshop','font-weight','normal',0,''),(571391,179427,'1712756007.57315','printshop','visibility_checkout','1',0,''),(571392,179427,'1712756007.57315','printshop','display_none','1',0,'5342'),(571393,179427,'1712756007.57315','printshop','style_class','topHeader',0,''),(571394,179427,'1712756007.57315','printshop','padding-top','10',0,''),(571395,179427,'1712756007.57315','printshop','padding-bottom','10',0,''),(571396,179427,'1712756007.57315','printshop','background-color','$header-bg-1',0,''),(571397,179427,'1712756007.57315','printshop','color','$header-color-1',0,''),(571398,179427,'1712756007.57315','printshop','from_file','h.zip',0,''),(571399,179428,'1712756007.585982','printshop','block_type','5',0,''),(571400,179428,'1712756007.585982','printshop','font-weight','400',0,''),(571401,179428,'1712756007.585982','printshop','schema','2-2',0,''),(571402,179428,'1712756007.585982','printshop','schema','5-1',0,'5342'),(571403,179429,'1712756007.5885','printshop','view_item','phone_number',0,''),(571404,179429,'1712756007.5885','printshop','font-size','15',0,''),(571405,179430,'1712756007.589787','printshop','text','<span class=\"phone-title\">Phone:</span>',1,''),(571406,179430,'1712756007.589787','printshop','display','inline-block',0,''),(571407,179430,'1712756007.589787','printshop','float','left',0,''),(571408,179430,'1712756007.589787','printshop','font-size','15',0,''),(571409,179430,'1712756007.589787','printshop','color','$fade-color-1',0,''),(571410,179430,'1712756007.589787','printshop','text','<span class=\"phone-title\">Phone:</span>',0,''),(571411,179431,'1712756007.62595','printshop','block_type','1',0,''),(571412,179432,'1712756007.627579','printshop','class','menu-horizontal',0,''),(571413,179432,'1712756007.627579','printshop','box_align','2',0,''),(571414,179432,'1712756007.627579','printshop','font-weight','400',0,''),(571415,179432,'1712756007.627579','printshop','float','right',0,''),(571416,179432,'1712756007.627579','printshop','display_none','1',0,'5363'),(571417,179432,'1712756007.627579','printshop','padding-right','5',0,''),(571418,179432,'1712756007.627579','printshop','line-height','1.4',0,''),(571419,179432,'1712756007.627579','printshop','padding-top','2',0,''),(571420,179433,'1712756007.729922','printshop','float','right',0,''),(571421,179434,'1712756007.738185','printshop','text','<span class=\"email-title\">E-mail:</span>',1,''),(571422,179434,'1712756007.738185','printshop','font-size','15',0,''),(571423,179434,'1712756007.738185','printshop','color','$fade-color-1',0,''),(571424,179434,'1712756007.738185','printshop','float','right',0,''),(571425,179434,'1712756007.738185','printshop','margin-right','7',0,'3'),(571426,179434,'1712756007.738185','printshop','line-height','1',0,''),(571427,179434,'1712756007.738185','printshop','padding-left','15',0,''),(571428,179434,'1712756007.738185','printshop','border-left-width','1',0,''),(571429,179434,'1712756007.738185','printshop','border-left-color','$content-border-1',0,''),(571430,179434,'1712756007.738185','printshop','padding-top','3',0,''),(571431,179434,'1712756007.738185','printshop','text','<span class=\"email-title\">E-mail:</span>',0,''),(571432,179435,'1712756007.772518','printshop','view_item','email',0,''),(571433,179435,'1712756007.772518','printshop','float','right',0,''),(571434,179435,'1712756007.772518','printshop','add_link_on_email','1',0,''),(571435,179435,'1712756007.772518','printshop','font-size','15',0,''),(571436,179436,'1712756007.774661','printshop','block_type','1',0,''),(571437,179436,'1712756007.774661','printshop','padding-top','3',0,''),(571438,179436,'1712756007.774661','printshop','padding-top','0',0,'5363'),(571439,179436,'1712756007.774661','printshop','padding-bottom','0',0,'5363'),(571440,179436,'1712756007.774661','printshop','style_class','header-middle',0,''),(571441,179436,'1712756007.774661','printshop','position','relative',0,''),(571442,179436,'1712756007.774661','printshop','background-color','$header-bg-1',0,''),(571443,179436,'1712756007.774661','printshop','border-bottom-width','1',0,''),(571444,179436,'1712756007.774661','printshop','border-bottom-color','$header-border-1',0,''),(571445,179436,'1712756007.774661','printshop','color','$header-color-1',0,''),(571446,179436,'1712756007.774661','printshop','from_file','h.zip',0,''),(571447,179437,'1712756007.779822','printshop','font-weight','400',0,''),(571448,179437,'1712756007.779822','printshop','box_align','1',0,''),(571449,179437,'1712756007.779822','printshop','width_measure','%',0,'5363'),(571450,179437,'1712756007.779822','printshop','logo_from','theme',0,''),(571451,179437,'1712756007.779822','printshop','float','left',0,''),(571452,179437,'1712756007.779822','printshop','clear','both',0,''),(571453,179437,'1712756007.779822','printshop','margin-top','22',0,''),(571454,179437,'1712756007.779822','printshop','margin-bottom','22',0,''),(571455,179437,'1712756007.779822','printshop','width','130',0,'5342'),(571456,179437,'1712756007.779822','printshop','padding-right','40',0,''),(571457,179437,'1712756007.779822','printshop','margin-right','70',0,''),(571458,179437,'1712756007.779822','printshop','border-right-width','1',0,''),(571459,179437,'1712756007.779822','printshop','border-right-color','$header-border-1',0,''),(571460,179437,'1712756007.779822','printshop','width','130',0,'5333'),(571461,179437,'1712756007.779822','printshop','padding-right','10',0,'5333'),(571462,179437,'1712756007.779822','printshop','margin-right','10',0,'5333'),(571463,179437,'1712756007.779822','printshop','margin-top','10',0,'5342'),(571464,179437,'1712756007.779822','printshop','margin-bottom','10',0,'5342'),(571465,179438,'1712756007.783714','printshop','font-weight','400',0,''),(571466,179438,'1712756007.783714','printshop','visibility_checkout','1',0,''),(571467,179438,'1712756007.783714','printshop','float','right',0,''),(571468,179438,'1712756007.783714','printshop','clear','none',0,''),(571469,179438,'1712756007.783714','printshop','margin-top','7',0,'5342'),(571470,179438,'1712756007.783714','printshop','color','$content-color-1',0,''),(571471,179438,'1712756007.783714','printshop','search_history','1',0,''),(571472,179439,'1712756007.85127','printshop','font-weight','400',0,''),(571473,179439,'1712756007.85127','printshop','box_align','3',0,''),(571474,179439,'1712756007.85127','printshop','only_icon','on',0,''),(571475,179439,'1712756007.85127','printshop','items','1',0,''),(571476,179439,'1712756007.85127','printshop','show_products','dropdown',0,''),(571477,179440,'1712756007.912178','printshop','font-weight','normal',0,''),(571478,179440,'1712756007.912178','printshop','box_align','3',0,''),(571479,179440,'1712756007.912178','printshop','only_icon','on',0,''),(571480,179440,'1712756007.912178','printshop','margin-left','20',0,''),(571481,179440,'1712756007.912178','printshop','margin-left','10',0,'5342'),(571482,179440,'1712756007.912178','printshop','link_or_dropdown','1',0,''),(571483,179440,'1712756007.912178','printshop','margin-left','0',0,'5333'),(571484,179441,'1712756007.950557','printshop','block_type','1',0,''),(571485,179441,'1712756007.950557','printshop','float','left',0,''),(571486,179441,'1712756007.950557','printshop','style_class','header-menu-holder',0,''),(571487,179442,'1712756007.953578','printshop','class','menu-style-1',0,''),(571488,179442,'1712756007.953578','printshop','box_align','4',0,''),(571489,179442,'1712756007.953578','printshop','hide_menu','on',0,''),(571490,179442,'1712756007.953578','printshop','hide_menu','1',0,'5342'),(571491,179442,'1712756007.953578','printshop','show_new','1',0,''),(571492,179442,'1712756007.953578','printshop','type','builder',0,''),(571493,179442,'1712756007.953578','printshop','open_from','top',0,'5342'),(571494,179442,'1712756007.953578','printshop','lev2_vis','click',0,'5342'),(571495,179442,'1712756007.953578','printshop','lev3_vis','click',0,'5400'),(571496,179442,'1712756007.953578','printshop','style','1',0,'5408'),(571497,179442,'1712756007.953578','printshop','position','horizontal_left',0,'5408'),(571498,179442,'1712756007.953578','printshop','lev2_vis','over',0,'5408'),(571499,179442,'1712756007.953578','printshop','lev2_display','width',0,'5408'),(571500,179442,'1712756007.953578','printshop','open_from','top',0,'5347'),(571501,179442,'1712756007.953578','printshop','lev2_vis','click',0,'5347'),(571502,179442,'1712756007.953578','printshop','lev4_vis','click',0,'5347'),(571503,179442,'1712756007.953578','printshop','burger_icon','1',0,'5347'),(571504,179442,'1712756007.953578','printshop','style','2',0,'5347'),(571505,179442,'1712756007.953578','printshop','lev3_vis','click',0,'5347'),(571506,179442,'1712756007.953578','printshop','lev3_vis','click',0,'5342'),(571507,179442,'1712756007.953578','printshop','style','2',0,'5342'),(571508,179442,'1712756007.953578','printshop','burger_icon','1',0,'5342'),(571509,179442,'1712756007.953578','printshop','style_class','header-menu',0,''),(571510,179443,'1712823796.145167','deals','from_file','header_1.zip',0,''),(571511,179444,'1712823796.149115','deals','block_type','1',0,''),(571512,179444,'1712823796.149115','deals','border-bottom-width','1',0,''),(571513,179444,'1712823796.149115','deals','border-bottom-color','$header-border-1',0,''),(571514,179444,'1712823796.149115','deals','font-weight','normal',0,''),(571515,179444,'1712823796.149115','deals','visibility_checkout','1',0,''),(571516,179444,'1712823796.149115','deals','background-color','$header-bg-1',0,''),(571517,179444,'1712823796.149115','deals','color','$header-color-1',0,''),(571518,179444,'1712823796.149115','deals','from_file','header_1.zip',0,''),(571557,179452,'1712823796.44032','deals','block_type','1',0,''),(571558,179452,'1712823796.44032','deals','padding-top','20',0,''),(571559,179452,'1712823796.44032','deals','padding-bottom','20',0,''),(571560,179452,'1712823796.44032','deals','style_class','header-content',0,''),(571561,179452,'1712823796.44032','deals','color','$header-color-1',0,''),(571562,179452,'1712823796.44032','deals','background-color','$header-bg-1',0,''),(571563,179452,'1712823796.44032','deals','from_file','header_1.zip',0,''),(571564,179452,'1712823796.44032','deals','padding-top','12',0,'5630'),(571565,179452,'1712823796.44032','deals','padding-bottom','12',0,'5630'),(571583,179456,'1712823796.566882','deals','block_type','1',0,''),(571584,179456,'1712823796.566882','deals','font-weight','400',0,''),(571585,179456,'1712823796.566882','deals','background-color','$header-menu-bg-1',0,''),(571586,179456,'1712823796.566882','deals','visibility_checkout','1',0,''),(571587,179456,'1712823796.566882','deals','color','$header-menu-color-1',0,''),(571588,179456,'1712823796.566882','deals','from_file','header_1.zip',0,''),(571589,179456,'1712823796.566882','deals','style_class','header-menu-holder',0,''),(571620,179458,'1712823935.978146','deals','block_type','1',0,''),(571621,179458,'1712823935.978146','deals','style_class','fixed-header',0,''),(571622,179458,'1712823935.978146','deals','from_file','header_4.zip',0,''),(571623,179459,'1712823935.987731','deals','block_type','1',0,''),(571624,179459,'1712823935.987731','deals','style_class','header-content',0,''),(571625,179460,'1712823935.994767','deals','font-weight','400',0,''),(571626,179460,'1712823935.994767','deals','box_align','1',0,''),(571627,179460,'1712823935.994767','deals','logo','themes/deals/img/Logo-TPD-orange-2.jpg',1,''),(571628,179460,'1712823935.994767','deals','text-align','left',0,'5660'),(571629,179460,'1712823935.994767','deals','width_measure','%',0,'5660'),(571630,179460,'1712823935.994767','deals','margin-right','40',0,''),(571631,179460,'1712823935.994767','deals','logo_from','theme',0,''),(571632,179460,'1712823935.994767','deals','logo','themes/deals/img/Logo-TPD-orange-2.jpg',0,''),(571633,179461,'1712823935.997331','deals','font-weight','400',0,''),(571634,179461,'1712823935.997331','deals','search_history','1',0,''),(571635,179462,'1712823936.133379','deals','font-weight','400',0,''),(571636,179462,'1712823936.133379','deals','box_align','3',0,''),(571637,179462,'1712823936.133379','deals','show_products','dropdown',0,''),(571638,179462,'1712823936.133379','deals','only_icon','on',0,''),(571639,179462,'1712823936.133379','deals','items','1',0,''),(571640,179463,'1712823936.18733','deals','font-weight','normal',0,''),(571641,179463,'1712823936.18733','deals','box_align','3',0,''),(571642,179463,'1712823936.18733','deals','only_icon','on',0,''),(571643,179463,'1712823936.18733','deals','link_or_dropdown','1',0,''),(571644,179464,'1712823936.243618','deals','block_type','1',0,''),(571645,179465,'1712823936.245254','deals','box_align','4',0,''),(571646,179465,'1712823936.245254','deals','hide_menu','on',0,''),(571647,179465,'1712823936.245254','deals','style_class','topMenu',0,''),(571648,179465,'1712823936.245254','deals','show_images','10',0,''),(571649,179465,'1712823936.245254','deals','type','builder',0,''),(571650,179465,'1712823936.245254','deals','lev2_vis','click',0,'5630'),(571651,179465,'1712823936.245254','deals','style','1',0,'5705'),(571652,179465,'1712823936.245254','deals','style','2',0,'5630'),(571653,179465,'1712823936.245254','deals','lev2_vis','over',0,'5705'),(571654,179465,'1712823936.245254','deals','lev3_vis','over',0,'5705'),(571655,179465,'1712823936.245254','deals','lev3_display','lra',0,'5705'),(571656,179465,'1712823936.245254','deals','lev3_vis','click',0,'5630'),(571657,179465,'1712823936.245254','deals','lev3_display','slide',0,'5630'),(571658,179465,'1712823936.245254','deals','visibility_checkout','1',0,''),(571659,179465,'1712823936.245254','deals','lev2_display','down',0,''),(571660,179465,'1712823936.245254','deals','lev2_vis','over',0,''),(571661,179465,'1712823936.245254','deals','burger_icon','1',0,''),(571662,179465,'1712823936.245254','deals','lev2_display','lra',0,'5705'),(571663,179465,'1712823936.245254','deals','lev4_display','lra',0,'5705'),(571664,179465,'1712823936.245254','deals','lev5_display','lra',0,'5705'),(571665,179465,'1712823936.245254','deals','lev6_display','lra',0,'5705'),(571666,179465,'1712823936.245254','deals','lev4_vis','over',0,'5705'),(571667,179465,'1712823936.245254','deals','lev5_vis','over',0,'5705'),(571668,179465,'1712823936.245254','deals','lev6_vis','over',0,'5705'),(571669,179465,'1712823936.245254','deals','burger_icon','1',0,'5630'),(571670,179465,'1712823936.245254','deals','open_from','left',0,'5630'),(571671,179465,'1712823936.245254','deals','lev2_display','slide',0,'5630'),(600618,188838,'1713773685.115477','watch','block_type','1',0,''),(600619,188838,'1713773685.115477','watch','style_class','account-index',0,''),(600620,188838,'1713773685.115477','watch','from_file','account_main_pages.zip',0,''),(600624,188841,'73374','watch','block_type','1',0,''),(600625,188841,'73374','watch','padding-top','70',0,''),(600626,188841,'73374','watch','padding-right','30',0,''),(600627,188841,'73374','watch','padding-bottom','30',0,''),(600628,188841,'73374','watch','padding-top','0',0,'5240'),(600629,188841,'73374','watch','padding-left','0',0,'5240'),(600630,188841,'73374','watch','padding-right','0',0,'5240'),(600631,188841,'73374','watch','padding-bottom','0',0,'5240'),(600801,188883,'1713773685.730386','watch','block_type','1',0,''),(600802,188883,'1713773685.730386','watch','from_file','account_main_pages.zip',0,''),(600806,188886,'73374','watch','block_type','1',0,''),(600807,188886,'73374','watch','padding-top','70',0,''),(600808,188886,'73374','watch','padding-right','30',0,''),(600809,188886,'73374','watch','padding-bottom','30',0,''),(600810,188886,'73374','watch','padding-top','0',0,'5240'),(600811,188886,'73374','watch','padding-left','0',0,'5240'),(600812,188886,'73374','watch','padding-right','0',0,'5240'),(600813,188886,'73374','watch','padding-bottom','0',0,'5240'),(600865,188907,'1713773686.073331','watch','block_type','1',0,''),(600866,188907,'1713773686.073331','watch','style_class','account-order-history-info',0,''),(600867,188907,'1713773686.073331','watch','from_file','account_main_pages.zip',0,''),(600871,188910,'73374','watch','block_type','1',0,''),(600872,188910,'73374','watch','padding-top','70',0,''),(600873,188910,'73374','watch','padding-right','30',0,''),(600874,188910,'73374','watch','padding-bottom','30',0,''),(600875,188910,'73374','watch','padding-top','0',0,'5240'),(600876,188910,'73374','watch','padding-left','0',0,'5240'),(600877,188910,'73374','watch','padding-right','0',0,'5240'),(600878,188910,'73374','watch','padding-bottom','0',0,'5240'),(600999,188966,'1713773686.551292','watch','block_type','1',0,''),(601000,188966,'1713773686.551292','watch','style_class','account-edit-wrap',0,''),(601001,188966,'1713773686.551292','watch','from_file','account_main_pages.zip',0,''),(601005,188969,'73374','watch','block_type','1',0,''),(601006,188969,'73374','watch','padding-top','70',0,''),(601007,188969,'73374','watch','padding-right','30',0,''),(601008,188969,'73374','watch','padding-bottom','30',0,''),(601009,188969,'73374','watch','padding-top','0',0,'5240'),(601010,188969,'73374','watch','padding-left','0',0,'5240'),(601011,188969,'73374','watch','padding-right','0',0,'5240'),(601012,188969,'73374','watch','padding-bottom','0',0,'5240'),(601063,188990,'1713773686.886195','watch','block_type','1',0,''),(601064,188990,'1713773686.886195','watch','style_class','account-order-history',0,''),(601065,188990,'1713773686.886195','watch','from_file','account_main_pages.zip',0,''),(601069,188993,'73374','watch','block_type','1',0,''),(601070,188993,'73374','watch','padding-top','70',0,''),(601071,188993,'73374','watch','padding-right','30',0,''),(601072,188993,'73374','watch','padding-bottom','30',0,''),(601073,188993,'73374','watch','padding-top','0',0,'5240'),(601074,188993,'73374','watch','padding-left','0',0,'5240'),(601075,188993,'73374','watch','padding-right','0',0,'5240'),(601076,188993,'73374','watch','padding-bottom','0',0,'5240'),(601132,189014,'1713774131.524999','watch','block_type','1',0,''),(601133,189014,'1713774131.524999','watch','style_class','account-index',0,''),(601134,189014,'1713774131.524999','watch','from_file','account-2.zip',0,''),(601135,189015,'1713774131.631466','watch','block_type','6',0,''),(601136,189015,'1713774131.631466','watch','schema','6-3',0,'5240'),(601137,189016,'1713774131.633419','watch','aria_name','account-menu',0,''),(601138,189017,'73374','watch','block_type','1',0,''),(601139,189017,'73374','watch','padding-top','70',0,''),(601140,189017,'73374','watch','padding-right','30',0,''),(601141,189017,'73374','watch','padding-bottom','30',0,''),(601142,189017,'73374','watch','padding-top','0',0,'5240'),(601143,189017,'73374','watch','padding-left','0',0,'5240'),(601144,189017,'73374','watch','padding-right','0',0,'5240'),(601145,189017,'73374','watch','padding-bottom','0',0,'5240'),(601188,189036,'1713774131.989231','watch','block_type','1',0,''),(601189,189037,'1713774131.990525','watch','link','Order History Info',0,''),(601190,189037,'1713774131.990525','watch','text','TEXT_VIEW',0,''),(601191,189037,'1713774131.990525','watch','max_orders','3',0,''),(601192,189037,'1713774131.990525','watch','link_pay','Order pay',0,''),(601193,189037,'1713774131.990525','watch','margin-bottom','30',0,''),(601194,189037,'1713774131.990525','watch','text_pay','ORDER_PAY',0,''),(601195,189038,'1713774131.992548','watch','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(601196,189039,'1713774131.995359','watch','text','<h1>##HEADING_TITLE##</h1>',0,''),(601197,189040,'1713774132.011364','watch','block_type','1',0,''),(601198,189040,'1713774132.011364','watch','padding-top','20',0,''),(601199,189040,'1713774132.011364','watch','padding-left','20',0,''),(601200,189040,'1713774132.011364','watch','padding-right','20',0,''),(601201,189040,'1713774132.011364','watch','padding-bottom','20',0,''),(601202,189040,'1713774132.011364','watch','margin-bottom','30',0,''),(601203,189040,'1713774132.011364','watch','border-top-width','1',0,''),(601204,189040,'1713774132.011364','watch','border-left-width','1',0,''),(601205,189040,'1713774132.011364','watch','border-right-width','1',0,''),(601206,189040,'1713774132.011364','watch','border-bottom-width','1',0,''),(601207,189040,'1713774132.011364','watch','border-top-color','$content-border-1',0,''),(601208,189040,'1713774132.011364','watch','border-left-color','$content-border-1',0,''),(601209,189040,'1713774132.011364','watch','border-right-color','$content-border-1',0,''),(601210,189040,'1713774132.011364','watch','border-bottom-color','$content-border-1',0,''),(601211,189040,'1713774132.011364','watch','style_class','account-content-top',0,''),(601212,189041,'1713774132.020828','watch','block_type','1',0,''),(601213,189042,'1713774132.02226','watch','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(601214,189042,'1713774132.02226','watch','font-family','trueloaded',0,'3'),(601215,189042,'1713774132.02226','watch','content','\\e920',0,'3'),(601216,189042,'1713774132.02226','watch','color','$highlight-color-3',0,'3'),(601217,189042,'1713774132.02226','watch','font-size','30',0,'3'),(601218,189042,'1713774132.02226','watch','text-align','center',0,'3'),(601219,189042,'1713774132.02226','watch','margin-bottom','10',0,'3'),(601220,189042,'1713774132.02226','watch','text-align','center',0,''),(601221,189042,'1713774132.02226','watch','font-size','16',0,''),(601222,189042,'1713774132.02226','watch','text-transform','uppercase',0,''),(601223,189042,'1713774132.02226','watch','line-height','1',0,'3'),(601224,189042,'1713774132.02226','watch','font-size','14',0,'5232'),(601225,189043,'1713774132.02710','watch','font-family','$font-1',0,''),(601226,189043,'1713774132.02710','watch','color','$highlight-color-3',0,''),(601227,189043,'1713774132.02710','watch','font-size','14',0,''),(601228,189043,'1713774132.02710','watch','text-align','center',0,''),(601229,189044,'1713774132.037763','watch','block_type','1',0,''),(601230,189045,'1713774132.039110','watch','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(601231,189045,'1713774132.039110','watch','font-family','trueloaded',0,'3'),(601232,189045,'1713774132.039110','watch','content','\\e928',0,'3'),(601233,189045,'1713774132.039110','watch','color','$highlight-color-3',0,'3'),(601234,189045,'1713774132.039110','watch','font-size','30',0,'3'),(601235,189045,'1713774132.039110','watch','text-align','center',0,'3'),(601236,189045,'1713774132.039110','watch','text-align','center',0,''),(601237,189045,'1713774132.039110','watch','font-size','16',0,''),(601238,189045,'1713774132.039110','watch','text-transform','uppercase',0,''),(601239,189045,'1713774132.039110','watch','line-height','1',0,'3'),(601240,189045,'1713774132.039110','watch','font-size','14',0,'5232'),(601241,189046,'1713774132.04388','watch','font-family','$font-1',0,''),(601242,189046,'1713774132.04388','watch','color','$highlight-color-3',0,''),(601243,189046,'1713774132.04388','watch','font-size','14',0,''),(601244,189046,'1713774132.04388','watch','text-align','center',0,''),(601245,189047,'1713774132.045662','watch','link','download_orders',0,''),(601246,189047,'1713774132.045662','watch','text','TEXT_DOWNLOAD_ORDERS',0,''),(601247,189047,'1713774132.045662','watch','hide_link','orders',0,''),(601248,189047,'1713774132.045662','watch','text-align','center',0,''),(601249,189047,'1713774132.045662','watch','popup','2',0,''),(601250,189047,'1713774132.045662','watch','font-size','14',0,''),(601251,189048,'1713774132.047643','watch','block_type','1',0,''),(601252,189049,'1713774132.048770','watch','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(601253,189049,'1713774132.048770','watch','font-family','trueloaded',0,'3'),(601254,189049,'1713774132.048770','watch','content','\\e922',0,'3'),(601255,189049,'1713774132.048770','watch','color','$highlight-color-3',0,'3'),(601256,189049,'1713774132.048770','watch','font-size','30',0,'3'),(601257,189049,'1713774132.048770','watch','line-height','1',0,'3'),(601258,189049,'1713774132.048770','watch','font-size','16',0,''),(601259,189049,'1713774132.048770','watch','text-align','center',0,''),(601260,189049,'1713774132.048770','watch','text-transform','uppercase',0,''),(601261,189049,'1713774132.048770','watch','font-size','14',0,'5232'),(601262,189050,'1713774132.053414','watch','font-family','$font-1',0,''),(601263,189050,'1713774132.053414','watch','color','$highlight-color-3',0,''),(601264,189050,'1713774132.053414','watch','line-height','1',0,''),(601265,189050,'1713774132.053414','watch','text-align','center',0,''),(601266,189050,'1713774132.053414','watch','font-size','14',0,''),(601267,189051,'1713774132.055889','watch','block_type','1',0,''),(601268,189052,'1713774132.05740','watch','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(601269,189052,'1713774132.05740','watch','content','\\e994',0,'3'),(601270,189052,'1713774132.05740','watch','font-family','trueloaded',0,'3'),(601271,189052,'1713774132.05740','watch','color','$highlight-color-3',0,'3'),(601272,189052,'1713774132.05740','watch','font-size','30',0,'3'),(601273,189052,'1713774132.05740','watch','line-height','1',0,'3'),(601274,189052,'1713774132.05740','watch','font-size','16',0,''),(601275,189052,'1713774132.05740','watch','text-align','center',0,''),(601276,189052,'1713774132.05740','watch','text-transform','uppercase',0,''),(601277,189052,'1713774132.05740','watch','font-size','14',0,'5232'),(601278,189053,'1713774132.061556','watch','font-family','$font-1',0,''),(601279,189053,'1713774132.061556','watch','color','$highlight-color-3',0,''),(601280,189053,'1713774132.061556','watch','font-size','14',0,''),(601281,189053,'1713774132.061556','watch','text-align','center',0,''),(601282,189054,'1713774132.127825','watch','link','Gift Certificate',0,''),(601283,189054,'1713774132.127825','watch','text','GIFT_CERTIFICATE',0,''),(601284,189054,'1713774132.127825','watch','popup','1',0,''),(601285,189054,'1713774132.127825','watch','text-align','center',0,''),(601286,189054,'1713774132.127825','watch','font-size','14',0,''),(601287,189055,'1713774132.130117','watch','block_type','1',0,''),(601288,189056,'1713774132.131332','watch','text','TEXT_VIEW_HISTORY',0,''),(601289,189056,'1713774132.131332','watch','popup','1',0,''),(601290,189056,'1713774132.131332','watch','text-align','center',0,''),(601291,189056,'1713774132.131332','watch','link','Points Earnt History',0,''),(601292,189056,'1713774132.131332','watch','font-size','14',0,''),(601293,189057,'1713774132.133341','watch','font-family','$font-1',0,''),(601294,189057,'1713774132.133341','watch','color','$highlight-color-3',0,''),(601295,189057,'1713774132.133341','watch','font-size','14',0,''),(601296,189057,'1713774132.133341','watch','text-align','center',0,''),(601297,189058,'1713774132.13514','watch','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(601298,189058,'1713774132.13514','watch','content','\\e990',0,'3'),(601299,189058,'1713774132.13514','watch','font-family','trueloaded',0,'3'),(601300,189058,'1713774132.13514','watch','font-size','30',0,'3'),(601301,189058,'1713774132.13514','watch','text-align','center',0,'3'),(601302,189058,'1713774132.13514','watch','line-height','1',0,'3'),(601303,189058,'1713774132.13514','watch','color','$highlight-color-3',0,'3'),(601304,189058,'1713774132.13514','watch','font-size','16',0,''),(601305,189058,'1713774132.13514','watch','text-align','center',0,''),(601306,189058,'1713774132.13514','watch','text-transform','uppercase',0,''),(601307,189058,'1713774132.13514','watch','font-size','14',0,'5232'),(601308,189059,'1713774132.139570','watch','block_type','1',0,''),(601309,189059,'1713774132.139570','watch','from_file','account-2.zip',0,''),(601310,189060,'1713774132.140834','watch','block_type','6',0,''),(601311,189060,'1713774132.140834','watch','schema','6-3',0,'5240'),(601312,189061,'1713774132.141911','watch','aria_name','account-menu',0,''),(601313,189062,'73374','watch','block_type','1',0,''),(601314,189062,'73374','watch','padding-top','70',0,''),(601315,189062,'73374','watch','padding-right','30',0,''),(601316,189062,'73374','watch','padding-bottom','30',0,''),(601317,189062,'73374','watch','padding-top','0',0,'5240'),(601318,189062,'73374','watch','padding-left','0',0,'5240'),(601319,189062,'73374','watch','padding-right','0',0,'5240'),(601320,189062,'73374','watch','padding-bottom','0',0,'5240'),(601363,189081,'1713774132.504954','watch','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(601364,189082,'1713774132.508462','watch','margin-bottom','20',0,''),(601365,189083,'1713774132.514786','watch','block_type','1',0,''),(601366,189083,'1713774132.514786','watch','style_class','account-order-history-info',0,''),(601367,189083,'1713774132.514786','watch','from_file','account-2.zip',0,''),(601368,189084,'1713774132.550697','watch','block_type','6',0,''),(601369,189084,'1713774132.550697','watch','schema','6-3',0,'5240'),(601370,189085,'1713774132.552317','watch','aria_name','account-menu',0,''),(601371,189086,'73374','watch','block_type','1',0,''),(601372,189086,'73374','watch','padding-top','70',0,''),(601373,189086,'73374','watch','padding-right','30',0,''),(601374,189086,'73374','watch','padding-bottom','30',0,''),(601375,189086,'73374','watch','padding-top','0',0,'5240'),(601376,189086,'73374','watch','padding-left','0',0,'5240'),(601377,189086,'73374','watch','padding-right','0',0,'5240'),(601378,189086,'73374','watch','padding-bottom','0',0,'5240'),(601421,189105,'1713774132.898941','watch','float','right',0,''),(601422,189105,'1713774132.898941','watch','clear','none',0,''),(601423,189105,'1713774132.898941','watch','margin-left','20',0,''),(601424,189107,'1713774132.901231','watch','float','right',0,''),(601425,189107,'1713774132.901231','watch','clear','none',0,''),(601426,189107,'1713774132.901231','watch','like_button','2',0,''),(601427,189107,'1713774132.901231','watch','link','Order pay',0,''),(601428,189108,'1713774132.902540','watch','block_type','2',0,''),(601429,189108,'1713774132.902540','watch','padding-top','20',0,''),(601430,189108,'1713774132.902540','watch','margin-bottom','20',0,''),(601431,189109,'1713774132.903770','watch','like_button','1',0,''),(601432,189109,'1713774132.903770','watch','text','IMAGE_BUTTON_BACK',0,''),(601433,189109,'1713774132.903770','watch','link','Order History',0,''),(601434,189110,'1713774132.90524','watch','text-align','right',0,''),(601435,189111,'1713774132.905816','watch','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(601436,189113,'1713774132.910483','watch','float','right',0,''),(601437,189113,'1713774132.910483','watch','clear','none',0,''),(601438,189113,'1713774132.910483','watch','margin-left','20',0,''),(601439,189115,'1713774132.913316','watch','float','right',0,''),(601440,189116,'1713774132.915188','watch','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(601441,189118,'1713774132.918550','watch','float','left',0,''),(601442,189119,'1713774132.919848','watch','block_type','3',0,''),(601443,189119,'1713774132.919848','watch','clear','both',0,''),(601444,189119,'1713774132.919848','watch','padding-top','20',0,''),(601445,189119,'1713774132.919848','watch','schema','3-4',0,'5232'),(601446,189120,'1713774132.921595','watch','block_type','1',0,''),(601447,189120,'1713774132.921595','watch','margin-bottom','20',0,''),(601448,189120,'1713774132.921595','watch','padding-right','20',0,''),(601449,189121,'1713774132.92285','watch','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(601450,189122,'1713774132.92519','watch','padding-left','30',0,''),(601451,189122,'1713774132.92519','watch','orders_data','telephone',0,''),(601452,189122,'1713774132.92519','watch','hide_parents','2',0,''),(601453,189123,'1713774132.92663','watch','block_type','1',0,''),(601454,189123,'1713774132.92663','watch','padding-right','20',0,''),(601455,189123,'1713774132.92663','watch','padding-bottom','20',0,''),(601456,189124,'1713774132.9280','watch','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(601457,189125,'1713774132.932360','watch','orders_data','name',0,''),(601458,189125,'1713774132.932360','watch','padding-left','30',0,''),(601459,189126,'1713774132.933540','watch','block_type','1',0,''),(601460,189126,'1713774132.933540','watch','padding-right','20',0,''),(601461,189126,'1713774132.933540','watch','margin-bottom','20',0,''),(601462,189127,'1713774132.93487','watch','short_view','1',0,''),(601463,189127,'1713774132.93487','watch','hide_parents','2',0,''),(601464,189128,'1713774132.936634','watch','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(601465,189129,'1713774132.938818','watch','link','Tracking numbers',0,''),(601466,189129,'1713774132.938818','watch','text','MORE_TRACKING_NUMBER',0,''),(601467,189129,'1713774132.938818','watch','popup','1',0,''),(601468,189129,'1713774132.938818','watch','order_id','1',0,''),(601469,189129,'1713774132.938818','watch','popup_class','tracking-numbers-popup',0,''),(601470,189129,'1713774132.938818','watch','font-weight','700',0,''),(601471,189129,'1713774132.938818','watch','font-size','18',0,''),(601472,189130,'1713774132.940770','watch','block_type','1',0,''),(601473,189130,'1713774132.940770','watch','padding-right','20',0,''),(601474,189131,'1713774132.941988','watch','orders_data','shipping_method',0,''),(601475,189131,'1713774132.941988','watch','padding-left','30',0,''),(601476,189132,'1713774132.94319','watch','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(601477,189133,'1713774132.945272','watch','block_type','1',0,''),(601478,189133,'1713774132.945272','watch','padding-right','20',0,''),(601479,189133,'1713774132.945272','watch','padding-bottom','20',0,''),(601480,189134,'1713774132.946358','watch','orders_data','delivery_address',0,''),(601481,189134,'1713774132.946358','watch','padding-left','30',0,''),(601482,189135,'1713774132.947328','watch','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(601483,189136,'1713774132.949323','watch','block_type','1',0,''),(601484,189137,'1713774132.950533','watch','orders_data','payment_method',0,''),(601485,189137,'1713774132.950533','watch','padding-left','30',0,''),(601486,189138,'1713774132.951838','watch','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(601487,189139,'1713774132.953990','watch','block_type','1',0,''),(601488,189139,'1713774132.953990','watch','padding-bottom','20',0,''),(601489,189140,'1713774132.955210','watch','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(601490,189141,'1713774132.957413','watch','orders_data','billing_address',0,''),(601491,189141,'1713774132.957413','watch','padding-left','30',0,''),(601492,189142,'1713774132.958422','watch','block_type','1',0,''),(601493,189142,'1713774132.958422','watch','style_class','account-address-book',0,''),(601494,189142,'1713774132.958422','watch','from_file','account-2.zip',0,''),(601495,189143,'1713774132.959666','watch','block_type','6',0,''),(601496,189143,'1713774132.959666','watch','schema','6-3',0,'5240'),(601497,189144,'1713774132.960615','watch','aria_name','account-menu',0,''),(601498,189145,'73374','watch','block_type','1',0,''),(601499,189145,'73374','watch','padding-top','70',0,''),(601500,189145,'73374','watch','padding-right','30',0,''),(601501,189145,'73374','watch','padding-bottom','30',0,''),(601502,189145,'73374','watch','padding-top','0',0,'5240'),(601503,189145,'73374','watch','padding-left','0',0,'5240'),(601504,189145,'73374','watch','padding-right','0',0,'5240'),(601505,189145,'73374','watch','padding-bottom','0',0,'5240'),(601548,189164,'1713774133.357999','watch','padding-top','15',0,''),(601549,189164,'1713774133.357999','watch','padding-bottom','15',0,''),(601550,189164,'1713774133.357999','watch','link','Address Book Process',0,''),(601551,189164,'1713774133.357999','watch','text','EDIT',0,''),(601552,189164,'1713774133.357999','watch','link_add','Address Book Process',0,''),(601553,189164,'1713774133.357999','watch','like_button_add','2',0,''),(601554,189164,'1713774133.357999','watch','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(601555,189165,'1713774133.369549','watch','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(601556,189166,'1713774133.371715','watch','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(601557,189167,'1713774133.3740','watch','block_type','1',0,''),(601558,189167,'1713774133.3740','watch','style_class','account-edit-wrap',0,''),(601559,189167,'1713774133.3740','watch','from_file','account-2.zip',0,''),(601560,189168,'1713774133.377154','watch','block_type','6',0,''),(601561,189168,'1713774133.377154','watch','schema','6-3',0,'5240'),(601562,189169,'1713774133.37823','watch','aria_name','account-menu',0,''),(601563,189170,'73374','watch','block_type','1',0,''),(601564,189170,'73374','watch','padding-top','70',0,''),(601565,189170,'73374','watch','padding-right','30',0,''),(601566,189170,'73374','watch','padding-bottom','30',0,''),(601567,189170,'73374','watch','padding-top','0',0,'5240'),(601568,189170,'73374','watch','padding-left','0',0,'5240'),(601569,189170,'73374','watch','padding-right','0',0,'5240'),(601570,189170,'73374','watch','padding-bottom','0',0,'5240'),(601613,189190,'1713774133.710153','watch','text','<h1>##HEADING_TITLE##</h1>',0,''),(601614,189191,'1713774133.722971','watch','block_type','1',0,''),(601615,189191,'1713774133.722971','watch','style_class','account-order-history',0,''),(601616,189191,'1713774133.722971','watch','from_file','account-2.zip',0,''),(601617,189192,'1713774133.772271','watch','block_type','6',0,''),(601618,189192,'1713774133.772271','watch','schema','6-3',0,'5240'),(601619,189193,'1713774133.773863','watch','aria_name','account-menu',0,''),(601620,189194,'73374','watch','block_type','1',0,''),(601621,189194,'73374','watch','padding-top','70',0,''),(601622,189194,'73374','watch','padding-right','30',0,''),(601623,189194,'73374','watch','padding-bottom','30',0,''),(601624,189194,'73374','watch','padding-top','0',0,'5240'),(601625,189194,'73374','watch','padding-left','0',0,'5240'),(601626,189194,'73374','watch','padding-right','0',0,'5240'),(601627,189194,'73374','watch','padding-bottom','0',0,'5240'),(601670,189213,'1713774134.186274','watch','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(601671,189214,'1713774134.188218','watch','link','Order History Info',0,''),(601672,189214,'1713774134.188218','watch','text','TEXT_VIEW',0,''),(601673,189214,'1713774134.188218','watch','show_pagenation','1',0,''),(601674,189214,'1713774134.188218','watch','link_pay','Order pay',0,''),(601675,189214,'1713774134.188218','watch','margin-bottom','20',0,''),(601676,189215,'1713774134.189849','watch','block_type','1',0,''),(601677,189215,'1713774134.189849','watch','style_class','account-address-book-process',0,''),(601678,189215,'1713774134.189849','watch','from_file','account-2.zip',0,''),(601679,189216,'1713774134.19293','watch','block_type','6',0,''),(601680,189216,'1713774134.19293','watch','schema','6-3',0,'5240'),(601681,189217,'1713774134.194197','watch','aria_name','account-menu',0,''),(601682,189218,'73374','watch','block_type','1',0,''),(601683,189218,'73374','watch','padding-top','70',0,''),(601684,189218,'73374','watch','padding-right','30',0,''),(601685,189218,'73374','watch','padding-bottom','30',0,''),(601686,189218,'73374','watch','padding-top','0',0,'5240'),(601687,189218,'73374','watch','padding-left','0',0,'5240'),(601688,189218,'73374','watch','padding-right','0',0,'5240'),(601689,189218,'73374','watch','padding-bottom','0',0,'5240'),(601690,189219,'73375','watch','block_type','1',0,''),(601691,189219,'73375','watch','style_class','account-menu',0,''),(601692,189220,'73376','watch','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(601693,189220,'73376','watch','style_class','heading-settings',0,''),(601694,189221,'73377','watch','link','logoff',0,''),(601695,189222,'73378','watch','link','delete',0,''),(601696,189222,'73378','watch','text','DELETE_ACCOUNT',0,''),(601697,189223,'73379','watch','text','TEXT_DASHBOARD',0,''),(601698,189223,'73379','watch','font-family','$font-1',0,''),(601699,189223,'73379','watch','font-size','18',0,''),(601700,189223,'73379','watch','text-transform','uppercase',0,''),(601701,189224,'73380','watch','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(601702,189224,'73380','watch','style_class','heading-saved-lists',0,''),(601703,189225,'73381','watch','link','Personal Catalog',0,''),(601704,189225,'73381','watch','text','TEXT_PERSONAL_CATALOG',0,''),(601705,189225,'73381','watch','hide_link','personal_catalog',0,''),(601706,189226,'73382','watch','link','Order History',0,''),(601707,189226,'73382','watch','text','HEADING_ORDER_HISTORY',0,''),(601708,189226,'73382','watch','active_link','Order History Info,Order pay',0,''),(601709,189227,'73383','watch','link','Address Book',0,''),(601710,189227,'73383','watch','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(601711,189228,'73384','watch','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(601712,189228,'73384','watch','style_class','heading-ordered-items',0,''),(601713,189229,'73385','watch','link','Wishlist',0,''),(601714,189229,'73385','watch','hide_link','wishlist',0,''),(601715,189229,'73385','watch','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(601716,189230,'73386','watch','link','My password',0,''),(601717,189230,'73386','watch','text','TEXT_MY_PASSWORD',0,''),(601718,189231,'73387','watch','link','Samples',0,''),(601719,189231,'73387','watch','text','TEXT_HEADING_SAMPLE_CART',0,''),(601720,189231,'73387','watch','hide_link','samples',0,''),(601721,189232,'73388','watch','link','Review',0,''),(601722,189232,'73388','watch','text','REVIEWS',0,''),(601723,189233,'73389','watch','link','Quotations',0,''),(601724,189233,'73389','watch','hide_link','quotations',0,''),(601725,189233,'73389','watch','text','TEXT_HEADING_QUOTE_CART',0,''),(601726,189234,'73390','watch','link','Account edit',0,''),(601727,189234,'73390','watch','text','ACCOUNT_EDIT',0,''),(601728,189235,'73391','watch','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(601729,189235,'73391','watch','style_class','heading-settings',0,''),(601730,189236,'73392','watch','link','trade_form',0,''),(601731,189236,'73392','watch','text','TRADE_FORM',0,''),(601732,189237,'1713774134.555525','watch','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(601733,189239,'1713774279.864294','furniture','block_type','1',0,''),(601734,189239,'1713774279.864294','furniture','style_class','account-index',0,''),(601735,189239,'1713774279.864294','furniture','from_file','account-2.zip',0,''),(601736,189240,'1713774279.969680','furniture','block_type','6',0,''),(601737,189240,'1713774279.969680','furniture','schema','6-3',0,'5140'),(601738,189241,'1713774279.971753','furniture','aria_name','account-menu',0,''),(601739,189242,'73374','furniture','block_type','1',0,''),(601740,189242,'73374','furniture','padding-top','70',0,''),(601741,189242,'73374','furniture','padding-right','30',0,''),(601742,189242,'73374','furniture','padding-bottom','30',0,''),(601743,189242,'73374','furniture','padding-top','0',0,'5140'),(601744,189242,'73374','furniture','padding-left','0',0,'5140'),(601745,189242,'73374','furniture','padding-right','0',0,'5140'),(601746,189242,'73374','furniture','padding-bottom','0',0,'5140'),(601789,189261,'1713774280.297397','furniture','block_type','1',0,''),(601790,189262,'1713774280.298583','furniture','link','Order History Info',0,''),(601791,189262,'1713774280.298583','furniture','text','TEXT_VIEW',0,''),(601792,189262,'1713774280.298583','furniture','max_orders','3',0,''),(601793,189262,'1713774280.298583','furniture','link_pay','Order pay',0,''),(601794,189262,'1713774280.298583','furniture','margin-bottom','30',0,''),(601795,189262,'1713774280.298583','furniture','text_pay','ORDER_PAY',0,''),(601796,189263,'1713774280.300742','furniture','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(601797,189264,'1713774280.304538','furniture','text','<h1>##HEADING_TITLE##</h1>',0,''),(601798,189265,'1713774280.32165','furniture','block_type','1',0,''),(601799,189265,'1713774280.32165','furniture','padding-top','20',0,''),(601800,189265,'1713774280.32165','furniture','padding-left','20',0,''),(601801,189265,'1713774280.32165','furniture','padding-right','20',0,''),(601802,189265,'1713774280.32165','furniture','padding-bottom','20',0,''),(601803,189265,'1713774280.32165','furniture','margin-bottom','30',0,''),(601804,189265,'1713774280.32165','furniture','border-top-width','1',0,''),(601805,189265,'1713774280.32165','furniture','border-left-width','1',0,''),(601806,189265,'1713774280.32165','furniture','border-right-width','1',0,''),(601807,189265,'1713774280.32165','furniture','border-bottom-width','1',0,''),(601808,189265,'1713774280.32165','furniture','border-top-color','$content-border-1',0,''),(601809,189265,'1713774280.32165','furniture','border-left-color','$content-border-1',0,''),(601810,189265,'1713774280.32165','furniture','border-right-color','$content-border-1',0,''),(601811,189265,'1713774280.32165','furniture','border-bottom-color','$content-border-1',0,''),(601812,189265,'1713774280.32165','furniture','style_class','account-content-top',0,''),(601813,189266,'1713774280.334674','furniture','block_type','1',0,''),(601814,189267,'1713774280.336154','furniture','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(601815,189267,'1713774280.336154','furniture','font-family','trueloaded',0,'3'),(601816,189267,'1713774280.336154','furniture','content','\\e920',0,'3'),(601817,189267,'1713774280.336154','furniture','color','$highlight-color-3',0,'3'),(601818,189267,'1713774280.336154','furniture','font-size','30',0,'3'),(601819,189267,'1713774280.336154','furniture','text-align','center',0,'3'),(601820,189267,'1713774280.336154','furniture','margin-bottom','10',0,'3'),(601821,189267,'1713774280.336154','furniture','text-align','center',0,''),(601822,189267,'1713774280.336154','furniture','font-size','16',0,''),(601823,189267,'1713774280.336154','furniture','text-transform','uppercase',0,''),(601824,189267,'1713774280.336154','furniture','line-height','1',0,'3'),(601825,189267,'1713774280.336154','furniture','font-size','14',0,'5131'),(601826,189268,'1713774280.341288','furniture','font-family','$font-1',0,''),(601827,189268,'1713774280.341288','furniture','color','$highlight-color-3',0,''),(601828,189268,'1713774280.341288','furniture','font-size','14',0,''),(601829,189268,'1713774280.341288','furniture','text-align','center',0,''),(601830,189269,'1713774280.35188','furniture','block_type','1',0,''),(601831,189270,'1713774280.352867','furniture','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(601832,189270,'1713774280.352867','furniture','font-family','trueloaded',0,'3'),(601833,189270,'1713774280.352867','furniture','content','\\e928',0,'3'),(601834,189270,'1713774280.352867','furniture','color','$highlight-color-3',0,'3'),(601835,189270,'1713774280.352867','furniture','font-size','30',0,'3'),(601836,189270,'1713774280.352867','furniture','text-align','center',0,'3'),(601837,189270,'1713774280.352867','furniture','text-align','center',0,''),(601838,189270,'1713774280.352867','furniture','font-size','16',0,''),(601839,189270,'1713774280.352867','furniture','text-transform','uppercase',0,''),(601840,189270,'1713774280.352867','furniture','line-height','1',0,'3'),(601841,189270,'1713774280.352867','furniture','font-size','14',0,'5131'),(601842,189271,'1713774280.356398','furniture','font-family','$font-1',0,''),(601843,189271,'1713774280.356398','furniture','color','$highlight-color-3',0,''),(601844,189271,'1713774280.356398','furniture','font-size','14',0,''),(601845,189271,'1713774280.356398','furniture','text-align','center',0,''),(601846,189272,'1713774280.357628','furniture','link','download_orders',0,''),(601847,189272,'1713774280.357628','furniture','text','TEXT_DOWNLOAD_ORDERS',0,''),(601848,189272,'1713774280.357628','furniture','hide_link','orders',0,''),(601849,189272,'1713774280.357628','furniture','text-align','center',0,''),(601850,189272,'1713774280.357628','furniture','popup','2',0,''),(601851,189272,'1713774280.357628','furniture','font-size','14',0,''),(601852,189273,'1713774280.359356','furniture','block_type','1',0,''),(601853,189274,'1713774280.360175','furniture','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(601854,189274,'1713774280.360175','furniture','font-family','trueloaded',0,'3'),(601855,189274,'1713774280.360175','furniture','content','\\e922',0,'3'),(601856,189274,'1713774280.360175','furniture','color','$highlight-color-3',0,'3'),(601857,189274,'1713774280.360175','furniture','font-size','30',0,'3'),(601858,189274,'1713774280.360175','furniture','line-height','1',0,'3'),(601859,189274,'1713774280.360175','furniture','font-size','16',0,''),(601860,189274,'1713774280.360175','furniture','text-align','center',0,''),(601861,189274,'1713774280.360175','furniture','text-transform','uppercase',0,''),(601862,189274,'1713774280.360175','furniture','font-size','14',0,'5131'),(601863,189275,'1713774280.362861','furniture','font-family','$font-1',0,''),(601864,189275,'1713774280.362861','furniture','color','$highlight-color-3',0,''),(601865,189275,'1713774280.362861','furniture','line-height','1',0,''),(601866,189275,'1713774280.362861','furniture','text-align','center',0,''),(601867,189275,'1713774280.362861','furniture','font-size','14',0,''),(601868,189276,'1713774280.364168','furniture','block_type','1',0,''),(601869,189277,'1713774280.36559','furniture','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(601870,189277,'1713774280.36559','furniture','content','\\e994',0,'3'),(601871,189277,'1713774280.36559','furniture','font-family','trueloaded',0,'3'),(601872,189277,'1713774280.36559','furniture','color','$highlight-color-3',0,'3'),(601873,189277,'1713774280.36559','furniture','font-size','30',0,'3'),(601874,189277,'1713774280.36559','furniture','line-height','1',0,'3'),(601875,189277,'1713774280.36559','furniture','font-size','16',0,''),(601876,189277,'1713774280.36559','furniture','text-align','center',0,''),(601877,189277,'1713774280.36559','furniture','text-transform','uppercase',0,''),(601878,189277,'1713774280.36559','furniture','font-size','14',0,'5131'),(601879,189278,'1713774280.367684','furniture','font-family','$font-1',0,''),(601880,189278,'1713774280.367684','furniture','color','$highlight-color-3',0,''),(601881,189278,'1713774280.367684','furniture','font-size','14',0,''),(601882,189278,'1713774280.367684','furniture','text-align','center',0,''),(601883,189279,'1713774280.368994','furniture','link','Gift Certificate',0,''),(601884,189279,'1713774280.368994','furniture','text','GIFT_CERTIFICATE',0,''),(601885,189279,'1713774280.368994','furniture','popup','1',0,''),(601886,189279,'1713774280.368994','furniture','text-align','center',0,''),(601887,189279,'1713774280.368994','furniture','font-size','14',0,''),(601888,189280,'1713774280.370288','furniture','block_type','1',0,''),(601889,189281,'1713774280.3715','furniture','text','TEXT_VIEW_HISTORY',0,''),(601890,189281,'1713774280.3715','furniture','popup','1',0,''),(601891,189281,'1713774280.3715','furniture','text-align','center',0,''),(601892,189281,'1713774280.3715','furniture','link','Points Earnt History',0,''),(601893,189281,'1713774280.3715','furniture','font-size','14',0,''),(601894,189282,'1713774280.372214','furniture','font-family','$font-1',0,''),(601895,189282,'1713774280.372214','furniture','color','$highlight-color-3',0,''),(601896,189282,'1713774280.372214','furniture','font-size','14',0,''),(601897,189282,'1713774280.372214','furniture','text-align','center',0,''),(601898,189283,'1713774280.373397','furniture','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(601899,189283,'1713774280.373397','furniture','content','\\e990',0,'3'),(601900,189283,'1713774280.373397','furniture','font-family','trueloaded',0,'3'),(601901,189283,'1713774280.373397','furniture','font-size','30',0,'3'),(601902,189283,'1713774280.373397','furniture','text-align','center',0,'3'),(601903,189283,'1713774280.373397','furniture','line-height','1',0,'3'),(601904,189283,'1713774280.373397','furniture','color','$highlight-color-3',0,'3'),(601905,189283,'1713774280.373397','furniture','font-size','16',0,''),(601906,189283,'1713774280.373397','furniture','text-align','center',0,''),(601907,189283,'1713774280.373397','furniture','text-transform','uppercase',0,''),(601908,189283,'1713774280.373397','furniture','font-size','14',0,'5131'),(601909,189284,'1713774280.375920','furniture','block_type','1',0,''),(601910,189284,'1713774280.375920','furniture','from_file','account-2.zip',0,''),(601911,189285,'1713774280.37681','furniture','block_type','6',0,''),(601912,189285,'1713774280.37681','furniture','schema','6-3',0,'5140'),(601913,189286,'1713774280.377779','furniture','aria_name','account-menu',0,''),(601914,189287,'73374','furniture','block_type','1',0,''),(601915,189287,'73374','furniture','padding-top','70',0,''),(601916,189287,'73374','furniture','padding-right','30',0,''),(601917,189287,'73374','furniture','padding-bottom','30',0,''),(601918,189287,'73374','furniture','padding-top','0',0,'5140'),(601919,189287,'73374','furniture','padding-left','0',0,'5140'),(601920,189287,'73374','furniture','padding-right','0',0,'5140'),(601921,189287,'73374','furniture','padding-bottom','0',0,'5140'),(601964,189306,'1713774280.725312','furniture','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(601965,189307,'1713774280.727712','furniture','margin-bottom','20',0,''),(601966,189308,'1713774280.733870','furniture','block_type','1',0,''),(601967,189308,'1713774280.733870','furniture','style_class','account-order-history-info',0,''),(601968,189308,'1713774280.733870','furniture','from_file','account-2.zip',0,''),(601969,189309,'1713774280.76691','furniture','block_type','6',0,''),(601970,189309,'1713774280.76691','furniture','schema','6-3',0,'5140'),(601971,189310,'1713774280.768459','furniture','aria_name','account-menu',0,''),(601972,189311,'73374','furniture','block_type','1',0,''),(601973,189311,'73374','furniture','padding-top','70',0,''),(601974,189311,'73374','furniture','padding-right','30',0,''),(601975,189311,'73374','furniture','padding-bottom','30',0,''),(601976,189311,'73374','furniture','padding-top','0',0,'5140'),(601977,189311,'73374','furniture','padding-left','0',0,'5140'),(601978,189311,'73374','furniture','padding-right','0',0,'5140'),(601979,189311,'73374','furniture','padding-bottom','0',0,'5140'),(602022,189330,'1713774281.071110','furniture','float','right',0,''),(602023,189330,'1713774281.071110','furniture','clear','none',0,''),(602024,189330,'1713774281.071110','furniture','margin-left','20',0,''),(602025,189332,'1713774281.073313','furniture','float','right',0,''),(602026,189332,'1713774281.073313','furniture','clear','none',0,''),(602027,189332,'1713774281.073313','furniture','like_button','2',0,''),(602028,189332,'1713774281.073313','furniture','link','Order pay',0,''),(602029,189333,'1713774281.074856','furniture','block_type','2',0,''),(602030,189333,'1713774281.074856','furniture','padding-top','20',0,''),(602031,189333,'1713774281.074856','furniture','margin-bottom','20',0,''),(602032,189334,'1713774281.076345','furniture','like_button','1',0,''),(602033,189334,'1713774281.076345','furniture','text','IMAGE_BUTTON_BACK',0,''),(602034,189334,'1713774281.076345','furniture','link','Order History',0,''),(602035,189335,'1713774281.07759','furniture','text-align','right',0,''),(602036,189336,'1713774281.078437','furniture','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(602037,189338,'1713774281.08131','furniture','float','right',0,''),(602038,189338,'1713774281.08131','furniture','clear','none',0,''),(602039,189338,'1713774281.08131','furniture','margin-left','20',0,''),(602040,189340,'1713774281.083285','furniture','float','right',0,''),(602041,189341,'1713774281.086740','furniture','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(602042,189343,'1713774281.089731','furniture','float','left',0,''),(602043,189344,'1713774281.090797','furniture','block_type','3',0,''),(602044,189344,'1713774281.090797','furniture','clear','both',0,''),(602045,189344,'1713774281.090797','furniture','padding-top','20',0,''),(602046,189344,'1713774281.090797','furniture','schema','3-4',0,'5131'),(602047,189345,'1713774281.092211','furniture','block_type','1',0,''),(602048,189345,'1713774281.092211','furniture','margin-bottom','20',0,''),(602049,189345,'1713774281.092211','furniture','padding-right','20',0,''),(602050,189346,'1713774281.093966','furniture','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(602051,189347,'1713774281.096334','furniture','padding-left','30',0,''),(602052,189347,'1713774281.096334','furniture','orders_data','telephone',0,''),(602053,189347,'1713774281.096334','furniture','hide_parents','2',0,''),(602054,189348,'1713774281.097991','furniture','block_type','1',0,''),(602055,189348,'1713774281.097991','furniture','padding-right','20',0,''),(602056,189348,'1713774281.097991','furniture','padding-bottom','20',0,''),(602057,189349,'1713774281.09931','furniture','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(602058,189350,'1713774281.104376','furniture','orders_data','name',0,''),(602059,189350,'1713774281.104376','furniture','padding-left','30',0,''),(602060,189351,'1713774281.105683','furniture','block_type','1',0,''),(602061,189351,'1713774281.105683','furniture','padding-right','20',0,''),(602062,189351,'1713774281.105683','furniture','margin-bottom','20',0,''),(602063,189352,'1713774281.10733','furniture','short_view','1',0,''),(602064,189352,'1713774281.10733','furniture','hide_parents','2',0,''),(602065,189353,'1713774281.108498','furniture','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(602066,189354,'1713774281.11113','furniture','link','Tracking numbers',0,''),(602067,189354,'1713774281.11113','furniture','text','MORE_TRACKING_NUMBER',0,''),(602068,189354,'1713774281.11113','furniture','popup','1',0,''),(602069,189354,'1713774281.11113','furniture','order_id','1',0,''),(602070,189354,'1713774281.11113','furniture','popup_class','tracking-numbers-popup',0,''),(602071,189354,'1713774281.11113','furniture','font-weight','700',0,''),(602072,189354,'1713774281.11113','furniture','font-size','18',0,''),(602073,189355,'1713774281.113595','furniture','block_type','1',0,''),(602074,189355,'1713774281.113595','furniture','padding-right','20',0,''),(602075,189356,'1713774281.114856','furniture','orders_data','shipping_method',0,''),(602076,189356,'1713774281.114856','furniture','padding-left','30',0,''),(602077,189357,'1713774281.116185','furniture','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(602078,189358,'1713774281.118622','furniture','block_type','1',0,''),(602079,189358,'1713774281.118622','furniture','padding-right','20',0,''),(602080,189358,'1713774281.118622','furniture','padding-bottom','20',0,''),(602081,189359,'1713774281.120129','furniture','orders_data','delivery_address',0,''),(602082,189359,'1713774281.120129','furniture','padding-left','30',0,''),(602083,189360,'1713774281.121493','furniture','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(602084,189361,'1713774281.123873','furniture','block_type','1',0,''),(602085,189362,'1713774281.124980','furniture','orders_data','payment_method',0,''),(602086,189362,'1713774281.124980','furniture','padding-left','30',0,''),(602087,189363,'1713774281.126172','furniture','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(602088,189364,'1713774281.128587','furniture','block_type','1',0,''),(602089,189364,'1713774281.128587','furniture','padding-bottom','20',0,''),(602090,189365,'1713774281.129973','furniture','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(602091,189366,'1713774281.132385','furniture','orders_data','billing_address',0,''),(602092,189366,'1713774281.132385','furniture','padding-left','30',0,''),(602093,189367,'1713774281.133667','furniture','block_type','1',0,''),(602094,189367,'1713774281.133667','furniture','style_class','account-address-book',0,''),(602095,189367,'1713774281.133667','furniture','from_file','account-2.zip',0,''),(602096,189368,'1713774281.13597','furniture','block_type','6',0,''),(602097,189368,'1713774281.13597','furniture','schema','6-3',0,'5140'),(602098,189369,'1713774281.136347','furniture','aria_name','account-menu',0,''),(602099,189370,'73374','furniture','block_type','1',0,''),(602100,189370,'73374','furniture','padding-top','70',0,''),(602101,189370,'73374','furniture','padding-right','30',0,''),(602102,189370,'73374','furniture','padding-bottom','30',0,''),(602103,189370,'73374','furniture','padding-top','0',0,'5140'),(602104,189370,'73374','furniture','padding-left','0',0,'5140'),(602105,189370,'73374','furniture','padding-right','0',0,'5140'),(602106,189370,'73374','furniture','padding-bottom','0',0,'5140'),(602149,189389,'1713774281.475435','furniture','padding-top','15',0,''),(602150,189389,'1713774281.475435','furniture','padding-bottom','15',0,''),(602151,189389,'1713774281.475435','furniture','link','Address Book Process',0,''),(602152,189389,'1713774281.475435','furniture','text','EDIT',0,''),(602153,189389,'1713774281.475435','furniture','link_add','Address Book Process',0,''),(602154,189389,'1713774281.475435','furniture','like_button_add','2',0,''),(602155,189389,'1713774281.475435','furniture','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(602156,189390,'1713774281.489799','furniture','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(602157,189391,'1713774281.493151','furniture','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(602158,189392,'1713774281.496820','furniture','block_type','1',0,''),(602159,189392,'1713774281.496820','furniture','style_class','account-edit-wrap',0,''),(602160,189392,'1713774281.496820','furniture','from_file','account-2.zip',0,''),(602161,189393,'1713774281.501632','furniture','block_type','6',0,''),(602162,189393,'1713774281.501632','furniture','schema','6-3',0,'5140'),(602163,189394,'1713774281.503794','furniture','aria_name','account-menu',0,''),(602164,189395,'73374','furniture','block_type','1',0,''),(602165,189395,'73374','furniture','padding-top','70',0,''),(602166,189395,'73374','furniture','padding-right','30',0,''),(602167,189395,'73374','furniture','padding-bottom','30',0,''),(602168,189395,'73374','furniture','padding-top','0',0,'5140'),(602169,189395,'73374','furniture','padding-left','0',0,'5140'),(602170,189395,'73374','furniture','padding-right','0',0,'5140'),(602171,189395,'73374','furniture','padding-bottom','0',0,'5140'),(602214,189415,'1713774281.890686','furniture','text','<h1>##HEADING_TITLE##</h1>',0,''),(602215,189416,'1713774281.907128','furniture','block_type','1',0,''),(602216,189416,'1713774281.907128','furniture','style_class','account-order-history',0,''),(602217,189416,'1713774281.907128','furniture','from_file','account-2.zip',0,''),(602218,189417,'1713774281.953936','furniture','block_type','6',0,''),(602219,189417,'1713774281.953936','furniture','schema','6-3',0,'5140'),(602220,189418,'1713774281.955250','furniture','aria_name','account-menu',0,''),(602221,189419,'73374','furniture','block_type','1',0,''),(602222,189419,'73374','furniture','padding-top','70',0,''),(602223,189419,'73374','furniture','padding-right','30',0,''),(602224,189419,'73374','furniture','padding-bottom','30',0,''),(602225,189419,'73374','furniture','padding-top','0',0,'5140'),(602226,189419,'73374','furniture','padding-left','0',0,'5140'),(602227,189419,'73374','furniture','padding-right','0',0,'5140'),(602228,189419,'73374','furniture','padding-bottom','0',0,'5140'),(602271,189438,'1713774282.25493','furniture','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(602272,189439,'1713774282.257271','furniture','link','Order History Info',0,''),(602273,189439,'1713774282.257271','furniture','text','TEXT_VIEW',0,''),(602274,189439,'1713774282.257271','furniture','show_pagenation','1',0,''),(602275,189439,'1713774282.257271','furniture','link_pay','Order pay',0,''),(602276,189439,'1713774282.257271','furniture','margin-bottom','20',0,''),(602277,189440,'1713774282.2593','furniture','block_type','1',0,''),(602278,189440,'1713774282.2593','furniture','style_class','account-address-book-process',0,''),(602279,189440,'1713774282.2593','furniture','from_file','account-2.zip',0,''),(602280,189441,'1713774282.263247','furniture','block_type','6',0,''),(602281,189441,'1713774282.263247','furniture','schema','6-3',0,'5140'),(602282,189442,'1713774282.264620','furniture','aria_name','account-menu',0,''),(602283,189443,'73374','furniture','block_type','1',0,''),(602284,189443,'73374','furniture','padding-top','70',0,''),(602285,189443,'73374','furniture','padding-right','30',0,''),(602286,189443,'73374','furniture','padding-bottom','30',0,''),(602287,189443,'73374','furniture','padding-top','0',0,'5140'),(602288,189443,'73374','furniture','padding-left','0',0,'5140'),(602289,189443,'73374','furniture','padding-right','0',0,'5140'),(602290,189443,'73374','furniture','padding-bottom','0',0,'5140'),(602291,189444,'73375','furniture','block_type','1',0,''),(602292,189444,'73375','furniture','style_class','account-menu',0,''),(602293,189445,'73376','furniture','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(602294,189445,'73376','furniture','style_class','heading-settings',0,''),(602295,189446,'73377','furniture','link','logoff',0,''),(602296,189447,'73378','furniture','link','delete',0,''),(602297,189447,'73378','furniture','text','DELETE_ACCOUNT',0,''),(602298,189448,'73379','furniture','text','TEXT_DASHBOARD',0,''),(602299,189448,'73379','furniture','font-family','$font-1',0,''),(602300,189448,'73379','furniture','font-size','18',0,''),(602301,189448,'73379','furniture','text-transform','uppercase',0,''),(602302,189449,'73380','furniture','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(602303,189449,'73380','furniture','style_class','heading-saved-lists',0,''),(602304,189450,'73381','furniture','link','Personal Catalog',0,''),(602305,189450,'73381','furniture','text','TEXT_PERSONAL_CATALOG',0,''),(602306,189450,'73381','furniture','hide_link','personal_catalog',0,''),(602307,189451,'73382','furniture','link','Order History',0,''),(602308,189451,'73382','furniture','text','HEADING_ORDER_HISTORY',0,''),(602309,189451,'73382','furniture','active_link','Order History Info,Order pay',0,''),(602310,189452,'73383','furniture','link','Address Book',0,''),(602311,189452,'73383','furniture','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(602312,189453,'73384','furniture','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(602313,189453,'73384','furniture','style_class','heading-ordered-items',0,''),(602314,189454,'73385','furniture','link','Wishlist',0,''),(602315,189454,'73385','furniture','hide_link','wishlist',0,''),(602316,189454,'73385','furniture','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(602317,189455,'73386','furniture','link','My password',0,''),(602318,189455,'73386','furniture','text','TEXT_MY_PASSWORD',0,''),(602319,189456,'73387','furniture','link','Samples',0,''),(602320,189456,'73387','furniture','text','TEXT_HEADING_SAMPLE_CART',0,''),(602321,189456,'73387','furniture','hide_link','samples',0,''),(602322,189457,'73388','furniture','link','Review',0,''),(602323,189457,'73388','furniture','text','REVIEWS',0,''),(602324,189458,'73389','furniture','link','Quotations',0,''),(602325,189458,'73389','furniture','hide_link','quotations',0,''),(602326,189458,'73389','furniture','text','TEXT_HEADING_QUOTE_CART',0,''),(602327,189459,'73390','furniture','link','Account edit',0,''),(602328,189459,'73390','furniture','text','ACCOUNT_EDIT',0,''),(602329,189460,'73391','furniture','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(602330,189460,'73391','furniture','style_class','heading-settings',0,''),(602331,189461,'73392','furniture','link','trade_form',0,''),(602332,189461,'73392','furniture','text','TRADE_FORM',0,''),(602333,189462,'1713774282.668269','furniture','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(602334,189464,'1713774291.283818','printshop','block_type','1',0,''),(602335,189464,'1713774291.283818','printshop','style_class','account-index',0,''),(602336,189464,'1713774291.283818','printshop','from_file','account-2.zip',0,''),(602337,189465,'1713774291.388533','printshop','block_type','6',0,''),(602338,189465,'1713774291.388533','printshop','schema','6-3',0,'5342'),(602339,189466,'1713774291.390348','printshop','aria_name','account-menu',0,''),(602340,189467,'73374','printshop','block_type','1',0,''),(602341,189467,'73374','printshop','padding-top','70',0,''),(602342,189467,'73374','printshop','padding-right','30',0,''),(602343,189467,'73374','printshop','padding-bottom','30',0,''),(602344,189467,'73374','printshop','padding-top','0',0,'5342'),(602345,189467,'73374','printshop','padding-left','0',0,'5342'),(602346,189467,'73374','printshop','padding-right','0',0,'5342'),(602347,189467,'73374','printshop','padding-bottom','0',0,'5342'),(602390,189486,'1713774291.784653','printshop','block_type','1',0,''),(602391,189487,'1713774291.785492','printshop','link','Order History Info',0,''),(602392,189487,'1713774291.785492','printshop','text','TEXT_VIEW',0,''),(602393,189487,'1713774291.785492','printshop','max_orders','3',0,''),(602394,189487,'1713774291.785492','printshop','link_pay','Order pay',0,''),(602395,189487,'1713774291.785492','printshop','margin-bottom','30',0,''),(602396,189487,'1713774291.785492','printshop','text_pay','ORDER_PAY',0,''),(602397,189488,'1713774291.78762','printshop','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(602398,189489,'1713774291.78938','printshop','text','<h1>##HEADING_TITLE##</h1>',0,''),(602399,189490,'1713774291.799772','printshop','block_type','1',0,''),(602400,189490,'1713774291.799772','printshop','padding-top','20',0,''),(602401,189490,'1713774291.799772','printshop','padding-left','20',0,''),(602402,189490,'1713774291.799772','printshop','padding-right','20',0,''),(602403,189490,'1713774291.799772','printshop','padding-bottom','20',0,''),(602404,189490,'1713774291.799772','printshop','margin-bottom','30',0,''),(602405,189490,'1713774291.799772','printshop','border-top-width','1',0,''),(602406,189490,'1713774291.799772','printshop','border-left-width','1',0,''),(602407,189490,'1713774291.799772','printshop','border-right-width','1',0,''),(602408,189490,'1713774291.799772','printshop','border-bottom-width','1',0,''),(602409,189490,'1713774291.799772','printshop','border-top-color','$content-border-1',0,''),(602410,189490,'1713774291.799772','printshop','border-left-color','$content-border-1',0,''),(602411,189490,'1713774291.799772','printshop','border-right-color','$content-border-1',0,''),(602412,189490,'1713774291.799772','printshop','border-bottom-color','$content-border-1',0,''),(602413,189490,'1713774291.799772','printshop','style_class','account-content-top',0,''),(602414,189491,'1713774291.806860','printshop','block_type','1',0,''),(602415,189492,'1713774291.807965','printshop','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(602416,189492,'1713774291.807965','printshop','font-family','trueloaded',0,'3'),(602417,189492,'1713774291.807965','printshop','content','\\e920',0,'3'),(602418,189492,'1713774291.807965','printshop','color','#EE4225',0,'3'),(602419,189492,'1713774291.807965','printshop','font-size','30',0,'3'),(602420,189492,'1713774291.807965','printshop','text-align','center',0,'3'),(602421,189492,'1713774291.807965','printshop','margin-bottom','10',0,'3'),(602422,189492,'1713774291.807965','printshop','text-align','center',0,''),(602423,189492,'1713774291.807965','printshop','font-size','16',0,''),(602424,189492,'1713774291.807965','printshop','text-transform','uppercase',0,''),(602425,189492,'1713774291.807965','printshop','line-height','1',0,'3'),(602426,189492,'1713774291.807965','printshop','font-size','14',0,'5333'),(602427,189493,'1713774291.811922','printshop','font-family','$font-1',0,''),(602428,189493,'1713774291.811922','printshop','color','#EE4225',0,''),(602429,189493,'1713774291.811922','printshop','font-size','14',0,''),(602430,189493,'1713774291.811922','printshop','text-align','center',0,''),(602431,189494,'1713774291.821577','printshop','block_type','1',0,''),(602432,189495,'1713774291.822426','printshop','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(602433,189495,'1713774291.822426','printshop','font-family','trueloaded',0,'3'),(602434,189495,'1713774291.822426','printshop','content','\\e928',0,'3'),(602435,189495,'1713774291.822426','printshop','color','#EE4225',0,'3'),(602436,189495,'1713774291.822426','printshop','font-size','30',0,'3'),(602437,189495,'1713774291.822426','printshop','text-align','center',0,'3'),(602438,189495,'1713774291.822426','printshop','text-align','center',0,''),(602439,189495,'1713774291.822426','printshop','font-size','16',0,''),(602440,189495,'1713774291.822426','printshop','text-transform','uppercase',0,''),(602441,189495,'1713774291.822426','printshop','line-height','1',0,'3'),(602442,189495,'1713774291.822426','printshop','font-size','14',0,'5333'),(602443,189496,'1713774291.82580','printshop','font-family','$font-1',0,''),(602444,189496,'1713774291.82580','printshop','color','#EE4225',0,''),(602445,189496,'1713774291.82580','printshop','font-size','14',0,''),(602446,189496,'1713774291.82580','printshop','text-align','center',0,''),(602447,189497,'1713774291.82723','printshop','link','download_orders',0,''),(602448,189497,'1713774291.82723','printshop','text','TEXT_DOWNLOAD_ORDERS',0,''),(602449,189497,'1713774291.82723','printshop','hide_link','orders',0,''),(602450,189497,'1713774291.82723','printshop','text-align','center',0,''),(602451,189497,'1713774291.82723','printshop','popup','2',0,''),(602452,189497,'1713774291.82723','printshop','font-size','14',0,''),(602453,189498,'1713774291.829143','printshop','block_type','1',0,''),(602454,189499,'1713774291.829944','printshop','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(602455,189499,'1713774291.829944','printshop','font-family','trueloaded',0,'3'),(602456,189499,'1713774291.829944','printshop','content','\\e922',0,'3'),(602457,189499,'1713774291.829944','printshop','color','#EE4225',0,'3'),(602458,189499,'1713774291.829944','printshop','font-size','30',0,'3'),(602459,189499,'1713774291.829944','printshop','line-height','1',0,'3'),(602460,189499,'1713774291.829944','printshop','font-size','16',0,''),(602461,189499,'1713774291.829944','printshop','text-align','center',0,''),(602462,189499,'1713774291.829944','printshop','text-transform','uppercase',0,''),(602463,189499,'1713774291.829944','printshop','font-size','14',0,'5333'),(602464,189500,'1713774291.833740','printshop','font-family','$font-1',0,''),(602465,189500,'1713774291.833740','printshop','color','#EE4225',0,''),(602466,189500,'1713774291.833740','printshop','line-height','1',0,''),(602467,189500,'1713774291.833740','printshop','text-align','center',0,''),(602468,189500,'1713774291.833740','printshop','font-size','14',0,''),(602469,189501,'1713774291.836366','printshop','block_type','1',0,''),(602470,189502,'1713774291.837352','printshop','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(602471,189502,'1713774291.837352','printshop','content','\\e994',0,'3'),(602472,189502,'1713774291.837352','printshop','font-family','trueloaded',0,'3'),(602473,189502,'1713774291.837352','printshop','color','#EE4225',0,'3'),(602474,189502,'1713774291.837352','printshop','font-size','30',0,'3'),(602475,189502,'1713774291.837352','printshop','line-height','1',0,'3'),(602476,189502,'1713774291.837352','printshop','font-size','16',0,''),(602477,189502,'1713774291.837352','printshop','text-align','center',0,''),(602478,189502,'1713774291.837352','printshop','text-transform','uppercase',0,''),(602479,189502,'1713774291.837352','printshop','font-size','14',0,'5333'),(602480,189503,'1713774291.840267','printshop','font-family','$font-1',0,''),(602481,189503,'1713774291.840267','printshop','color','#EE4225',0,''),(602482,189503,'1713774291.840267','printshop','font-size','14',0,''),(602483,189503,'1713774291.840267','printshop','text-align','center',0,''),(602484,189504,'1713774291.841825','printshop','link','Gift Certificate',0,''),(602485,189504,'1713774291.841825','printshop','text','GIFT_CERTIFICATE',0,''),(602486,189504,'1713774291.841825','printshop','popup','1',0,''),(602487,189504,'1713774291.841825','printshop','text-align','center',0,''),(602488,189504,'1713774291.841825','printshop','font-size','14',0,''),(602489,189505,'1713774291.843244','printshop','block_type','1',0,''),(602490,189506,'1713774291.844151','printshop','text','TEXT_VIEW_HISTORY',0,''),(602491,189506,'1713774291.844151','printshop','popup','1',0,''),(602492,189506,'1713774291.844151','printshop','text-align','center',0,''),(602493,189506,'1713774291.844151','printshop','link','Points Earnt History',0,''),(602494,189506,'1713774291.844151','printshop','font-size','14',0,''),(602495,189507,'1713774291.84543','printshop','font-family','$font-1',0,''),(602496,189507,'1713774291.84543','printshop','color','#EE4225',0,''),(602497,189507,'1713774291.84543','printshop','font-size','14',0,''),(602498,189507,'1713774291.84543','printshop','text-align','center',0,''),(602499,189508,'1713774291.846868','printshop','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(602500,189508,'1713774291.846868','printshop','content','\\e990',0,'3'),(602501,189508,'1713774291.846868','printshop','font-family','trueloaded',0,'3'),(602502,189508,'1713774291.846868','printshop','font-size','30',0,'3'),(602503,189508,'1713774291.846868','printshop','text-align','center',0,'3'),(602504,189508,'1713774291.846868','printshop','line-height','1',0,'3'),(602505,189508,'1713774291.846868','printshop','color','#EE4225',0,'3'),(602506,189508,'1713774291.846868','printshop','font-size','16',0,''),(602507,189508,'1713774291.846868','printshop','text-align','center',0,''),(602508,189508,'1713774291.846868','printshop','text-transform','uppercase',0,''),(602509,189508,'1713774291.846868','printshop','font-size','14',0,'5333'),(602510,189509,'1713774291.849925','printshop','block_type','1',0,''),(602511,189509,'1713774291.849925','printshop','from_file','account-2.zip',0,''),(602512,189510,'1713774291.850917','printshop','block_type','6',0,''),(602513,189510,'1713774291.850917','printshop','schema','6-3',0,'5342'),(602514,189511,'1713774291.851973','printshop','aria_name','account-menu',0,''),(602515,189512,'73374','printshop','block_type','1',0,''),(602516,189512,'73374','printshop','padding-top','70',0,''),(602517,189512,'73374','printshop','padding-right','30',0,''),(602518,189512,'73374','printshop','padding-bottom','30',0,''),(602519,189512,'73374','printshop','padding-top','0',0,'5342'),(602520,189512,'73374','printshop','padding-left','0',0,'5342'),(602521,189512,'73374','printshop','padding-right','0',0,'5342'),(602522,189512,'73374','printshop','padding-bottom','0',0,'5342'),(602565,189531,'1713774292.245647','printshop','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(602566,189532,'1713774292.247937','printshop','margin-bottom','20',0,''),(602567,189533,'1713774292.252957','printshop','block_type','1',0,''),(602568,189533,'1713774292.252957','printshop','style_class','account-order-history-info',0,''),(602569,189533,'1713774292.252957','printshop','from_file','account-2.zip',0,''),(602570,189534,'1713774292.285450','printshop','block_type','6',0,''),(602571,189534,'1713774292.285450','printshop','schema','6-3',0,'5342'),(602572,189535,'1713774292.286894','printshop','aria_name','account-menu',0,''),(602573,189536,'73374','printshop','block_type','1',0,''),(602574,189536,'73374','printshop','padding-top','70',0,''),(602575,189536,'73374','printshop','padding-right','30',0,''),(602576,189536,'73374','printshop','padding-bottom','30',0,''),(602577,189536,'73374','printshop','padding-top','0',0,'5342'),(602578,189536,'73374','printshop','padding-left','0',0,'5342'),(602579,189536,'73374','printshop','padding-right','0',0,'5342'),(602580,189536,'73374','printshop','padding-bottom','0',0,'5342'),(602623,189555,'1713774292.692796','printshop','float','right',0,''),(602624,189555,'1713774292.692796','printshop','clear','none',0,''),(602625,189555,'1713774292.692796','printshop','margin-left','20',0,''),(602626,189557,'1713774292.69476','printshop','float','right',0,''),(602627,189557,'1713774292.69476','printshop','clear','none',0,''),(602628,189557,'1713774292.69476','printshop','like_button','2',0,''),(602629,189557,'1713774292.69476','printshop','link','Order pay',0,''),(602630,189558,'1713774292.695987','printshop','block_type','2',0,''),(602631,189558,'1713774292.695987','printshop','padding-top','20',0,''),(602632,189558,'1713774292.695987','printshop','margin-bottom','20',0,''),(602633,189559,'1713774292.697287','printshop','like_button','1',0,''),(602634,189559,'1713774292.697287','printshop','text','IMAGE_BUTTON_BACK',0,''),(602635,189559,'1713774292.697287','printshop','link','Order History',0,''),(602636,189560,'1713774292.698396','printshop','text-align','right',0,''),(602637,189561,'1713774292.699239','printshop','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(602638,189563,'1713774292.702227','printshop','float','right',0,''),(602639,189563,'1713774292.702227','printshop','clear','none',0,''),(602640,189563,'1713774292.702227','printshop','margin-left','20',0,''),(602641,189565,'1713774292.70446','printshop','float','right',0,''),(602642,189566,'1713774292.707596','printshop','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(602643,189568,'1713774292.71080','printshop','float','left',0,''),(602644,189569,'1713774292.711955','printshop','block_type','3',0,''),(602645,189569,'1713774292.711955','printshop','clear','both',0,''),(602646,189569,'1713774292.711955','printshop','padding-top','20',0,''),(602647,189569,'1713774292.711955','printshop','schema','3-4',0,'5333'),(602648,189570,'1713774292.713627','printshop','block_type','1',0,''),(602649,189570,'1713774292.713627','printshop','margin-bottom','20',0,''),(602650,189570,'1713774292.713627','printshop','padding-right','20',0,''),(602651,189571,'1713774292.71538','printshop','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(602652,189572,'1713774292.717332','printshop','padding-left','30',0,''),(602653,189572,'1713774292.717332','printshop','orders_data','telephone',0,''),(602654,189572,'1713774292.717332','printshop','hide_parents','2',0,''),(602655,189573,'1713774292.718650','printshop','block_type','1',0,''),(602656,189573,'1713774292.718650','printshop','padding-right','20',0,''),(602657,189573,'1713774292.718650','printshop','padding-bottom','20',0,''),(602658,189574,'1713774292.719949','printshop','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(602659,189575,'1713774292.724311','printshop','orders_data','name',0,''),(602660,189575,'1713774292.724311','printshop','padding-left','30',0,''),(602661,189576,'1713774292.725380','printshop','block_type','1',0,''),(602662,189576,'1713774292.725380','printshop','padding-right','20',0,''),(602663,189576,'1713774292.725380','printshop','margin-bottom','20',0,''),(602664,189577,'1713774292.726372','printshop','short_view','1',0,''),(602665,189577,'1713774292.726372','printshop','hide_parents','2',0,''),(602666,189578,'1713774292.727511','printshop','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(602667,189579,'1713774292.729492','printshop','link','Tracking numbers',0,''),(602668,189579,'1713774292.729492','printshop','text','MORE_TRACKING_NUMBER',0,''),(602669,189579,'1713774292.729492','printshop','popup','1',0,''),(602670,189579,'1713774292.729492','printshop','order_id','1',0,''),(602671,189579,'1713774292.729492','printshop','popup_class','tracking-numbers-popup',0,''),(602672,189579,'1713774292.729492','printshop','font-weight','700',0,''),(602673,189579,'1713774292.729492','printshop','font-size','18',0,''),(602674,189580,'1713774292.731181','printshop','block_type','1',0,''),(602675,189580,'1713774292.731181','printshop','padding-right','20',0,''),(602676,189581,'1713774292.73246','printshop','orders_data','shipping_method',0,''),(602677,189581,'1713774292.73246','printshop','padding-left','30',0,''),(602678,189582,'1713774292.733650','printshop','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(602679,189583,'1713774292.735925','printshop','block_type','1',0,''),(602680,189583,'1713774292.735925','printshop','padding-right','20',0,''),(602681,189583,'1713774292.735925','printshop','padding-bottom','20',0,''),(602682,189584,'1713774292.737241','printshop','orders_data','delivery_address',0,''),(602683,189584,'1713774292.737241','printshop','padding-left','30',0,''),(602684,189585,'1713774292.73836','printshop','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(602685,189586,'1713774292.740656','printshop','block_type','1',0,''),(602686,189587,'1713774292.741632','printshop','orders_data','payment_method',0,''),(602687,189587,'1713774292.741632','printshop','padding-left','30',0,''),(602688,189588,'1713774292.742836','printshop','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(602689,189589,'1713774292.744670','printshop','block_type','1',0,''),(602690,189589,'1713774292.744670','printshop','padding-bottom','20',0,''),(602691,189590,'1713774292.745537','printshop','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(602692,189591,'1713774292.747421','printshop','orders_data','billing_address',0,''),(602693,189591,'1713774292.747421','printshop','padding-left','30',0,''),(602694,189592,'1713774292.748453','printshop','block_type','1',0,''),(602695,189592,'1713774292.748453','printshop','style_class','account-address-book',0,''),(602696,189592,'1713774292.748453','printshop','from_file','account-2.zip',0,''),(602697,189593,'1713774292.749515','printshop','block_type','6',0,''),(602698,189593,'1713774292.749515','printshop','schema','6-3',0,'5342'),(602699,189594,'1713774292.750418','printshop','aria_name','account-menu',0,''),(602700,189595,'73374','printshop','block_type','1',0,''),(602701,189595,'73374','printshop','padding-top','70',0,''),(602702,189595,'73374','printshop','padding-right','30',0,''),(602703,189595,'73374','printshop','padding-bottom','30',0,''),(602704,189595,'73374','printshop','padding-top','0',0,'5342'),(602705,189595,'73374','printshop','padding-left','0',0,'5342'),(602706,189595,'73374','printshop','padding-right','0',0,'5342'),(602707,189595,'73374','printshop','padding-bottom','0',0,'5342'),(602750,189614,'1713774293.082159','printshop','padding-top','15',0,''),(602751,189614,'1713774293.082159','printshop','padding-bottom','15',0,''),(602752,189614,'1713774293.082159','printshop','link','Address Book Process',0,''),(602753,189614,'1713774293.082159','printshop','text','EDIT',0,''),(602754,189614,'1713774293.082159','printshop','link_add','Address Book Process',0,''),(602755,189614,'1713774293.082159','printshop','like_button_add','2',0,''),(602756,189614,'1713774293.082159','printshop','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(602757,189615,'1713774293.096223','printshop','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(602758,189616,'1713774293.098979','printshop','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(602759,189617,'1713774293.102593','printshop','block_type','1',0,''),(602760,189617,'1713774293.102593','printshop','style_class','account-edit-wrap',0,''),(602761,189617,'1713774293.102593','printshop','from_file','account-2.zip',0,''),(602762,189618,'1713774293.10637','printshop','block_type','6',0,''),(602763,189618,'1713774293.10637','printshop','schema','6-3',0,'5342'),(602764,189619,'1713774293.107979','printshop','aria_name','account-menu',0,''),(602765,189620,'73374','printshop','block_type','1',0,''),(602766,189620,'73374','printshop','padding-top','70',0,''),(602767,189620,'73374','printshop','padding-right','30',0,''),(602768,189620,'73374','printshop','padding-bottom','30',0,''),(602769,189620,'73374','printshop','padding-top','0',0,'5342'),(602770,189620,'73374','printshop','padding-left','0',0,'5342'),(602771,189620,'73374','printshop','padding-right','0',0,'5342'),(602772,189620,'73374','printshop','padding-bottom','0',0,'5342'),(602815,189640,'1713774293.507399','printshop','text','<h1>##HEADING_TITLE##</h1>',0,''),(602816,189641,'1713774293.523882','printshop','block_type','1',0,''),(602817,189641,'1713774293.523882','printshop','style_class','account-order-history',0,''),(602818,189641,'1713774293.523882','printshop','from_file','account-2.zip',0,''),(602819,189642,'1713774293.577891','printshop','block_type','6',0,''),(602820,189642,'1713774293.577891','printshop','schema','6-3',0,'5342'),(602821,189643,'1713774293.579253','printshop','aria_name','account-menu',0,''),(602822,189644,'73374','printshop','block_type','1',0,''),(602823,189644,'73374','printshop','padding-top','70',0,''),(602824,189644,'73374','printshop','padding-right','30',0,''),(602825,189644,'73374','printshop','padding-bottom','30',0,''),(602826,189644,'73374','printshop','padding-top','0',0,'5342'),(602827,189644,'73374','printshop','padding-left','0',0,'5342'),(602828,189644,'73374','printshop','padding-right','0',0,'5342'),(602829,189644,'73374','printshop','padding-bottom','0',0,'5342'),(602872,189663,'1713774293.893565','printshop','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(602873,189664,'1713774293.895793','printshop','link','Order History Info',0,''),(602874,189664,'1713774293.895793','printshop','text','TEXT_VIEW',0,''),(602875,189664,'1713774293.895793','printshop','show_pagenation','1',0,''),(602876,189664,'1713774293.895793','printshop','link_pay','Order pay',0,''),(602877,189664,'1713774293.895793','printshop','margin-bottom','20',0,''),(602878,189665,'1713774293.897327','printshop','block_type','1',0,''),(602879,189665,'1713774293.897327','printshop','style_class','account-address-book-process',0,''),(602880,189665,'1713774293.897327','printshop','from_file','account-2.zip',0,''),(602881,189666,'1713774293.900863','printshop','block_type','6',0,''),(602882,189666,'1713774293.900863','printshop','schema','6-3',0,'5342'),(602883,189667,'1713774293.90289','printshop','aria_name','account-menu',0,''),(602884,189668,'73374','printshop','block_type','1',0,''),(602885,189668,'73374','printshop','padding-top','70',0,''),(602886,189668,'73374','printshop','padding-right','30',0,''),(602887,189668,'73374','printshop','padding-bottom','30',0,''),(602888,189668,'73374','printshop','padding-top','0',0,'5342'),(602889,189668,'73374','printshop','padding-left','0',0,'5342'),(602890,189668,'73374','printshop','padding-right','0',0,'5342'),(602891,189668,'73374','printshop','padding-bottom','0',0,'5342'),(602892,189669,'73375','printshop','block_type','1',0,''),(602893,189669,'73375','printshop','style_class','account-menu',0,''),(602894,189670,'73376','printshop','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(602895,189670,'73376','printshop','style_class','heading-settings',0,''),(602896,189671,'73377','printshop','link','logoff',0,''),(602897,189672,'73378','printshop','link','delete',0,''),(602898,189672,'73378','printshop','text','DELETE_ACCOUNT',0,''),(602899,189673,'73379','printshop','text','TEXT_DASHBOARD',0,''),(602900,189673,'73379','printshop','font-family','$font-1',0,''),(602901,189673,'73379','printshop','font-size','18',0,''),(602902,189673,'73379','printshop','text-transform','uppercase',0,''),(602903,189674,'73380','printshop','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(602904,189674,'73380','printshop','style_class','heading-saved-lists',0,''),(602905,189675,'73381','printshop','link','Personal Catalog',0,''),(602906,189675,'73381','printshop','text','TEXT_PERSONAL_CATALOG',0,''),(602907,189675,'73381','printshop','hide_link','personal_catalog',0,''),(602908,189676,'73382','printshop','link','Order History',0,''),(602909,189676,'73382','printshop','text','HEADING_ORDER_HISTORY',0,''),(602910,189676,'73382','printshop','active_link','Order History Info,Order pay',0,''),(602911,189677,'73383','printshop','link','Address Book',0,''),(602912,189677,'73383','printshop','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(602913,189678,'73384','printshop','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(602914,189678,'73384','printshop','style_class','heading-ordered-items',0,''),(602915,189679,'73385','printshop','link','Wishlist',0,''),(602916,189679,'73385','printshop','hide_link','wishlist',0,''),(602917,189679,'73385','printshop','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(602918,189680,'73386','printshop','link','My password',0,''),(602919,189680,'73386','printshop','text','TEXT_MY_PASSWORD',0,''),(602920,189681,'73387','printshop','link','Samples',0,''),(602921,189681,'73387','printshop','text','TEXT_HEADING_SAMPLE_CART',0,''),(602922,189681,'73387','printshop','hide_link','samples',0,''),(602923,189682,'73388','printshop','link','Review',0,''),(602924,189682,'73388','printshop','text','REVIEWS',0,''),(602925,189683,'73389','printshop','link','Quotations',0,''),(602926,189683,'73389','printshop','hide_link','quotations',0,''),(602927,189683,'73389','printshop','text','TEXT_HEADING_QUOTE_CART',0,''),(602928,189684,'73390','printshop','link','Account edit',0,''),(602929,189684,'73390','printshop','text','ACCOUNT_EDIT',0,''),(602930,189685,'73391','printshop','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(602931,189685,'73391','printshop','style_class','heading-settings',0,''),(602932,189686,'73392','printshop','link','trade_form',0,''),(602933,189686,'73392','printshop','text','TRADE_FORM',0,''),(602934,189687,'1713774294.238947','printshop','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(602935,189689,'1713774302.070365','deals','block_type','1',0,''),(602936,189689,'1713774302.070365','deals','style_class','account-index',0,''),(602937,189689,'1713774302.070365','deals','from_file','account-2.zip',0,''),(602938,189690,'1713774302.241660','deals','block_type','6',0,''),(602939,189690,'1713774302.241660','deals','schema','6-3',0,'5639'),(602940,189691,'1713774302.243252','deals','aria_name','account-menu',0,''),(602941,189692,'73374','deals','block_type','1',0,''),(602942,189692,'73374','deals','padding-top','70',0,''),(602943,189692,'73374','deals','padding-right','30',0,''),(602944,189692,'73374','deals','padding-bottom','30',0,''),(602945,189692,'73374','deals','padding-top','0',0,'5639'),(602946,189692,'73374','deals','padding-left','0',0,'5639'),(602947,189692,'73374','deals','padding-right','0',0,'5639'),(602948,189692,'73374','deals','padding-bottom','0',0,'5639'),(602991,189711,'1713774302.55728','deals','block_type','1',0,''),(602992,189712,'1713774302.558125','deals','link','Order History Info',0,''),(602993,189712,'1713774302.558125','deals','text','TEXT_VIEW',0,''),(602994,189712,'1713774302.558125','deals','max_orders','3',0,''),(602995,189712,'1713774302.558125','deals','link_pay','Order pay',0,''),(602996,189712,'1713774302.558125','deals','margin-bottom','30',0,''),(602997,189712,'1713774302.558125','deals','text_pay','ORDER_PAY',0,''),(602998,189713,'1713774302.559810','deals','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(602999,189714,'1713774302.562282','deals','text','<h1>##HEADING_TITLE##</h1>',0,''),(603000,189715,'1713774302.575318','deals','block_type','1',0,''),(603001,189715,'1713774302.575318','deals','padding-top','20',0,''),(603002,189715,'1713774302.575318','deals','padding-left','20',0,''),(603003,189715,'1713774302.575318','deals','padding-right','20',0,''),(603004,189715,'1713774302.575318','deals','padding-bottom','20',0,''),(603005,189715,'1713774302.575318','deals','margin-bottom','30',0,''),(603006,189715,'1713774302.575318','deals','border-top-width','1',0,''),(603007,189715,'1713774302.575318','deals','border-left-width','1',0,''),(603008,189715,'1713774302.575318','deals','border-right-width','1',0,''),(603009,189715,'1713774302.575318','deals','border-bottom-width','1',0,''),(603010,189715,'1713774302.575318','deals','border-top-color','$content-border-1',0,''),(603011,189715,'1713774302.575318','deals','border-left-color','$content-border-1',0,''),(603012,189715,'1713774302.575318','deals','border-right-color','$content-border-1',0,''),(603013,189715,'1713774302.575318','deals','border-bottom-color','$content-border-1',0,''),(603014,189715,'1713774302.575318','deals','style_class','account-content-top',0,''),(603015,189716,'1713774302.583346','deals','block_type','1',0,''),(603016,189717,'1713774302.584585','deals','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(603017,189717,'1713774302.584585','deals','font-family','trueloaded',0,'3'),(603018,189717,'1713774302.584585','deals','content','\\e920',0,'3'),(603019,189717,'1713774302.584585','deals','color','#EE4225',0,'3'),(603020,189717,'1713774302.584585','deals','font-size','30',0,'3'),(603021,189717,'1713774302.584585','deals','text-align','center',0,'3'),(603022,189717,'1713774302.584585','deals','margin-bottom','10',0,'3'),(603023,189717,'1713774302.584585','deals','text-align','center',0,''),(603024,189717,'1713774302.584585','deals','font-size','16',0,''),(603025,189717,'1713774302.584585','deals','text-transform','uppercase',0,''),(603026,189717,'1713774302.584585','deals','line-height','1',0,'3'),(603027,189717,'1713774302.584585','deals','font-size','14',0,'5630'),(603028,189718,'1713774302.588956','deals','font-family','$font-1',0,''),(603029,189718,'1713774302.588956','deals','color','#EE4225',0,''),(603030,189718,'1713774302.588956','deals','font-size','14',0,''),(603031,189718,'1713774302.588956','deals','text-align','center',0,''),(603032,189719,'1713774302.599185','deals','block_type','1',0,''),(603033,189720,'1713774302.600332','deals','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(603034,189720,'1713774302.600332','deals','font-family','trueloaded',0,'3'),(603035,189720,'1713774302.600332','deals','content','\\e928',0,'3'),(603036,189720,'1713774302.600332','deals','color','#EE4225',0,'3'),(603037,189720,'1713774302.600332','deals','font-size','30',0,'3'),(603038,189720,'1713774302.600332','deals','text-align','center',0,'3'),(603039,189720,'1713774302.600332','deals','text-align','center',0,''),(603040,189720,'1713774302.600332','deals','font-size','16',0,''),(603041,189720,'1713774302.600332','deals','text-transform','uppercase',0,''),(603042,189720,'1713774302.600332','deals','line-height','1',0,'3'),(603043,189720,'1713774302.600332','deals','font-size','14',0,'5630'),(603044,189721,'1713774302.604146','deals','font-family','$font-1',0,''),(603045,189721,'1713774302.604146','deals','color','#EE4225',0,''),(603046,189721,'1713774302.604146','deals','font-size','14',0,''),(603047,189721,'1713774302.604146','deals','text-align','center',0,''),(603048,189722,'1713774302.605686','deals','link','download_orders',0,''),(603049,189722,'1713774302.605686','deals','text','TEXT_DOWNLOAD_ORDERS',0,''),(603050,189722,'1713774302.605686','deals','hide_link','orders',0,''),(603051,189722,'1713774302.605686','deals','text-align','center',0,''),(603052,189722,'1713774302.605686','deals','popup','2',0,''),(603053,189722,'1713774302.605686','deals','font-size','14',0,''),(603054,189723,'1713774302.607525','deals','block_type','1',0,''),(603055,189724,'1713774302.608552','deals','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(603056,189724,'1713774302.608552','deals','font-family','trueloaded',0,'3'),(603057,189724,'1713774302.608552','deals','content','\\e922',0,'3'),(603058,189724,'1713774302.608552','deals','color','#EE4225',0,'3'),(603059,189724,'1713774302.608552','deals','font-size','30',0,'3'),(603060,189724,'1713774302.608552','deals','line-height','1',0,'3'),(603061,189724,'1713774302.608552','deals','font-size','16',0,''),(603062,189724,'1713774302.608552','deals','text-align','center',0,''),(603063,189724,'1713774302.608552','deals','text-transform','uppercase',0,''),(603064,189724,'1713774302.608552','deals','font-size','14',0,'5630'),(603065,189725,'1713774302.611730','deals','font-family','$font-1',0,''),(603066,189725,'1713774302.611730','deals','color','#EE4225',0,''),(603067,189725,'1713774302.611730','deals','line-height','1',0,''),(603068,189725,'1713774302.611730','deals','text-align','center',0,''),(603069,189725,'1713774302.611730','deals','font-size','14',0,''),(603070,189726,'1713774302.613318','deals','block_type','1',0,''),(603071,189727,'1713774302.614257','deals','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(603072,189727,'1713774302.614257','deals','content','\\e994',0,'3'),(603073,189727,'1713774302.614257','deals','font-family','trueloaded',0,'3'),(603074,189727,'1713774302.614257','deals','color','#EE4225',0,'3'),(603075,189727,'1713774302.614257','deals','font-size','30',0,'3'),(603076,189727,'1713774302.614257','deals','line-height','1',0,'3'),(603077,189727,'1713774302.614257','deals','font-size','16',0,''),(603078,189727,'1713774302.614257','deals','text-align','center',0,''),(603079,189727,'1713774302.614257','deals','text-transform','uppercase',0,''),(603080,189727,'1713774302.614257','deals','font-size','14',0,'5630'),(603081,189728,'1713774302.618189','deals','font-family','$font-1',0,''),(603082,189728,'1713774302.618189','deals','color','#EE4225',0,''),(603083,189728,'1713774302.618189','deals','font-size','14',0,''),(603084,189728,'1713774302.618189','deals','text-align','center',0,''),(603085,189729,'1713774302.619664','deals','link','Gift Certificate',0,''),(603086,189729,'1713774302.619664','deals','text','GIFT_CERTIFICATE',0,''),(603087,189729,'1713774302.619664','deals','popup','1',0,''),(603088,189729,'1713774302.619664','deals','text-align','center',0,''),(603089,189729,'1713774302.619664','deals','font-size','14',0,''),(603090,189730,'1713774302.620964','deals','block_type','1',0,''),(603091,189731,'1713774302.62216','deals','text','TEXT_VIEW_HISTORY',0,''),(603092,189731,'1713774302.62216','deals','popup','1',0,''),(603093,189731,'1713774302.62216','deals','text-align','center',0,''),(603094,189731,'1713774302.62216','deals','link','Points Earnt History',0,''),(603095,189731,'1713774302.62216','deals','font-size','14',0,''),(603096,189732,'1713774302.623592','deals','font-family','$font-1',0,''),(603097,189732,'1713774302.623592','deals','color','#EE4225',0,''),(603098,189732,'1713774302.623592','deals','font-size','14',0,''),(603099,189732,'1713774302.623592','deals','text-align','center',0,''),(603100,189733,'1713774302.625189','deals','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(603101,189733,'1713774302.625189','deals','content','\\e990',0,'3'),(603102,189733,'1713774302.625189','deals','font-family','trueloaded',0,'3'),(603103,189733,'1713774302.625189','deals','font-size','30',0,'3'),(603104,189733,'1713774302.625189','deals','text-align','center',0,'3'),(603105,189733,'1713774302.625189','deals','line-height','1',0,'3'),(603106,189733,'1713774302.625189','deals','color','#EE4225',0,'3'),(603107,189733,'1713774302.625189','deals','font-size','16',0,''),(603108,189733,'1713774302.625189','deals','text-align','center',0,''),(603109,189733,'1713774302.625189','deals','text-transform','uppercase',0,''),(603110,189733,'1713774302.625189','deals','font-size','14',0,'5630'),(603111,189734,'1713774302.628368','deals','block_type','1',0,''),(603112,189734,'1713774302.628368','deals','from_file','account-2.zip',0,''),(603113,189735,'1713774302.629597','deals','block_type','6',0,''),(603114,189735,'1713774302.629597','deals','schema','6-3',0,'5639'),(603115,189736,'1713774302.630510','deals','aria_name','account-menu',0,''),(603116,189737,'73374','deals','block_type','1',0,''),(603117,189737,'73374','deals','padding-top','70',0,''),(603118,189737,'73374','deals','padding-right','30',0,''),(603119,189737,'73374','deals','padding-bottom','30',0,''),(603120,189737,'73374','deals','padding-top','0',0,'5639'),(603121,189737,'73374','deals','padding-left','0',0,'5639'),(603122,189737,'73374','deals','padding-right','0',0,'5639'),(603123,189737,'73374','deals','padding-bottom','0',0,'5639'),(603166,189756,'1713774302.942945','deals','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(603167,189757,'1713774302.94546','deals','margin-bottom','20',0,''),(603168,189758,'1713774302.951148','deals','block_type','1',0,''),(603169,189758,'1713774302.951148','deals','style_class','account-order-history-info',0,''),(603170,189758,'1713774302.951148','deals','from_file','account-2.zip',0,''),(603171,189759,'1713774302.98691','deals','block_type','6',0,''),(603172,189759,'1713774302.98691','deals','schema','6-3',0,'5639'),(603173,189760,'1713774302.987797','deals','aria_name','account-menu',0,''),(603174,189761,'73374','deals','block_type','1',0,''),(603175,189761,'73374','deals','padding-top','70',0,''),(603176,189761,'73374','deals','padding-right','30',0,''),(603177,189761,'73374','deals','padding-bottom','30',0,''),(603178,189761,'73374','deals','padding-top','0',0,'5639'),(603179,189761,'73374','deals','padding-left','0',0,'5639'),(603180,189761,'73374','deals','padding-right','0',0,'5639'),(603181,189761,'73374','deals','padding-bottom','0',0,'5639'),(603224,189780,'1713774303.355589','deals','float','right',0,''),(603225,189780,'1713774303.355589','deals','clear','none',0,''),(603226,189780,'1713774303.355589','deals','margin-left','20',0,''),(603227,189782,'1713774303.357736','deals','float','right',0,''),(603228,189782,'1713774303.357736','deals','clear','none',0,''),(603229,189782,'1713774303.357736','deals','like_button','2',0,''),(603230,189782,'1713774303.357736','deals','link','Order pay',0,''),(603231,189783,'1713774303.358932','deals','block_type','2',0,''),(603232,189783,'1713774303.358932','deals','padding-top','20',0,''),(603233,189783,'1713774303.358932','deals','margin-bottom','20',0,''),(603234,189784,'1713774303.362185','deals','like_button','1',0,''),(603235,189784,'1713774303.362185','deals','text','IMAGE_BUTTON_BACK',0,''),(603236,189784,'1713774303.362185','deals','link','Order History',0,''),(603237,189785,'1713774303.365122','deals','text-align','right',0,''),(603238,189786,'1713774303.366232','deals','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(603239,189788,'1713774303.36967','deals','float','right',0,''),(603240,189788,'1713774303.36967','deals','clear','none',0,''),(603241,189788,'1713774303.36967','deals','margin-left','20',0,''),(603242,189790,'1713774303.372180','deals','float','right',0,''),(603243,189791,'1713774303.374982','deals','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(603244,189793,'1713774303.378529','deals','float','left',0,''),(603245,189794,'1713774303.379873','deals','block_type','3',0,''),(603246,189794,'1713774303.379873','deals','clear','both',0,''),(603247,189794,'1713774303.379873','deals','padding-top','20',0,''),(603248,189794,'1713774303.379873','deals','schema','3-4',0,'5630'),(603249,189795,'1713774303.38143','deals','block_type','1',0,''),(603250,189795,'1713774303.38143','deals','margin-bottom','20',0,''),(603251,189795,'1713774303.38143','deals','padding-right','20',0,''),(603252,189796,'1713774303.383169','deals','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(603253,189797,'1713774303.385376','deals','padding-left','30',0,''),(603254,189797,'1713774303.385376','deals','orders_data','telephone',0,''),(603255,189797,'1713774303.385376','deals','hide_parents','2',0,''),(603256,189798,'1713774303.386781','deals','block_type','1',0,''),(603257,189798,'1713774303.386781','deals','padding-right','20',0,''),(603258,189798,'1713774303.386781','deals','padding-bottom','20',0,''),(603259,189799,'1713774303.387715','deals','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(603260,189800,'1713774303.392348','deals','orders_data','name',0,''),(603261,189800,'1713774303.392348','deals','padding-left','30',0,''),(603262,189801,'1713774303.393461','deals','block_type','1',0,''),(603263,189801,'1713774303.393461','deals','padding-right','20',0,''),(603264,189801,'1713774303.393461','deals','margin-bottom','20',0,''),(603265,189802,'1713774303.394715','deals','short_view','1',0,''),(603266,189802,'1713774303.394715','deals','hide_parents','2',0,''),(603267,189803,'1713774303.3963','deals','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(603268,189804,'1713774303.39839','deals','link','Tracking numbers',0,''),(603269,189804,'1713774303.39839','deals','text','MORE_TRACKING_NUMBER',0,''),(603270,189804,'1713774303.39839','deals','popup','1',0,''),(603271,189804,'1713774303.39839','deals','order_id','1',0,''),(603272,189804,'1713774303.39839','deals','popup_class','tracking-numbers-popup',0,''),(603273,189804,'1713774303.39839','deals','font-weight','700',0,''),(603274,189804,'1713774303.39839','deals','font-size','18',0,''),(603275,189805,'1713774303.479','deals','block_type','1',0,''),(603276,189805,'1713774303.479','deals','padding-right','20',0,''),(603277,189806,'1713774303.401260','deals','orders_data','shipping_method',0,''),(603278,189806,'1713774303.401260','deals','padding-left','30',0,''),(603279,189807,'1713774303.402194','deals','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(603280,189808,'1713774303.403789','deals','block_type','1',0,''),(603281,189808,'1713774303.403789','deals','padding-right','20',0,''),(603282,189808,'1713774303.403789','deals','padding-bottom','20',0,''),(603283,189809,'1713774303.404787','deals','orders_data','delivery_address',0,''),(603284,189809,'1713774303.404787','deals','padding-left','30',0,''),(603285,189810,'1713774303.405697','deals','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(603286,189811,'1713774303.407397','deals','block_type','1',0,''),(603287,189812,'1713774303.408152','deals','orders_data','payment_method',0,''),(603288,189812,'1713774303.408152','deals','padding-left','30',0,''),(603289,189813,'1713774303.409138','deals','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(603290,189814,'1713774303.41090','deals','block_type','1',0,''),(603291,189814,'1713774303.41090','deals','padding-bottom','20',0,''),(603292,189815,'1713774303.411821','deals','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(603293,189816,'1713774303.413853','deals','orders_data','billing_address',0,''),(603294,189816,'1713774303.413853','deals','padding-left','30',0,''),(603295,189817,'1713774303.414793','deals','block_type','1',0,''),(603296,189817,'1713774303.414793','deals','style_class','account-address-book',0,''),(603297,189817,'1713774303.414793','deals','from_file','account-2.zip',0,''),(603298,189818,'1713774303.415755','deals','block_type','6',0,''),(603299,189818,'1713774303.415755','deals','schema','6-3',0,'5639'),(603300,189819,'1713774303.416744','deals','aria_name','account-menu',0,''),(603301,189820,'73374','deals','block_type','1',0,''),(603302,189820,'73374','deals','padding-top','70',0,''),(603303,189820,'73374','deals','padding-right','30',0,''),(603304,189820,'73374','deals','padding-bottom','30',0,''),(603305,189820,'73374','deals','padding-top','0',0,'5639'),(603306,189820,'73374','deals','padding-left','0',0,'5639'),(603307,189820,'73374','deals','padding-right','0',0,'5639'),(603308,189820,'73374','deals','padding-bottom','0',0,'5639'),(603351,189839,'1713774303.748485','deals','padding-top','15',0,''),(603352,189839,'1713774303.748485','deals','padding-bottom','15',0,''),(603353,189839,'1713774303.748485','deals','link','Address Book Process',0,''),(603354,189839,'1713774303.748485','deals','text','EDIT',0,''),(603355,189839,'1713774303.748485','deals','link_add','Address Book Process',0,''),(603356,189839,'1713774303.748485','deals','like_button_add','2',0,''),(603357,189839,'1713774303.748485','deals','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(603358,189840,'1713774303.759421','deals','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(603359,189841,'1713774303.7624','deals','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(603360,189842,'1713774303.76450','deals','block_type','1',0,''),(603361,189842,'1713774303.76450','deals','style_class','account-edit-wrap',0,''),(603362,189842,'1713774303.76450','deals','from_file','account-2.zip',0,''),(603363,189843,'1713774303.768552','deals','block_type','6',0,''),(603364,189843,'1713774303.768552','deals','schema','6-3',0,'5639'),(603365,189844,'1713774303.770899','deals','aria_name','account-menu',0,''),(603366,189845,'73374','deals','block_type','1',0,''),(603367,189845,'73374','deals','padding-top','70',0,''),(603368,189845,'73374','deals','padding-right','30',0,''),(603369,189845,'73374','deals','padding-bottom','30',0,''),(603370,189845,'73374','deals','padding-top','0',0,'5639'),(603371,189845,'73374','deals','padding-left','0',0,'5639'),(603372,189845,'73374','deals','padding-right','0',0,'5639'),(603373,189845,'73374','deals','padding-bottom','0',0,'5639'),(603416,189865,'1713774304.061861','deals','text','<h1>##HEADING_TITLE##</h1>',0,''),(603417,189866,'1713774304.077962','deals','block_type','1',0,''),(603418,189866,'1713774304.077962','deals','style_class','account-order-history',0,''),(603419,189866,'1713774304.077962','deals','from_file','account-2.zip',0,''),(603420,189867,'1713774304.184488','deals','block_type','6',0,''),(603421,189867,'1713774304.184488','deals','schema','6-3',0,'5639'),(603422,189868,'1713774304.186275','deals','aria_name','account-menu',0,''),(603423,189869,'73374','deals','block_type','1',0,''),(603424,189869,'73374','deals','padding-top','70',0,''),(603425,189869,'73374','deals','padding-right','30',0,''),(603426,189869,'73374','deals','padding-bottom','30',0,''),(603427,189869,'73374','deals','padding-top','0',0,'5639'),(603428,189869,'73374','deals','padding-left','0',0,'5639'),(603429,189869,'73374','deals','padding-right','0',0,'5639'),(603430,189869,'73374','deals','padding-bottom','0',0,'5639'),(603473,189888,'1713774304.463836','deals','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(603474,189889,'1713774304.465929','deals','link','Order History Info',0,''),(603475,189889,'1713774304.465929','deals','text','TEXT_VIEW',0,''),(603476,189889,'1713774304.465929','deals','show_pagenation','1',0,''),(603477,189889,'1713774304.465929','deals','link_pay','Order pay',0,''),(603478,189889,'1713774304.465929','deals','margin-bottom','20',0,''),(603479,189890,'1713774304.467962','deals','block_type','1',0,''),(603480,189890,'1713774304.467962','deals','style_class','account-address-book-process',0,''),(603481,189890,'1713774304.467962','deals','from_file','account-2.zip',0,''),(603482,189891,'1713774304.471135','deals','block_type','6',0,''),(603483,189891,'1713774304.471135','deals','schema','6-3',0,'5639'),(603484,189892,'1713774304.472570','deals','aria_name','account-menu',0,''),(603485,189893,'73374','deals','block_type','1',0,''),(603486,189893,'73374','deals','padding-top','70',0,''),(603487,189893,'73374','deals','padding-right','30',0,''),(603488,189893,'73374','deals','padding-bottom','30',0,''),(603489,189893,'73374','deals','padding-top','0',0,'5639'),(603490,189893,'73374','deals','padding-left','0',0,'5639'),(603491,189893,'73374','deals','padding-right','0',0,'5639'),(603492,189893,'73374','deals','padding-bottom','0',0,'5639'),(603493,189894,'73375','deals','block_type','1',0,''),(603494,189894,'73375','deals','style_class','account-menu',0,''),(603495,189895,'73376','deals','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(603496,189895,'73376','deals','style_class','heading-settings',0,''),(603497,189896,'73377','deals','link','logoff',0,''),(603498,189897,'73378','deals','link','delete',0,''),(603499,189897,'73378','deals','text','DELETE_ACCOUNT',0,''),(603500,189898,'73379','deals','text','TEXT_DASHBOARD',0,''),(603501,189898,'73379','deals','font-family','$font-1',0,''),(603502,189898,'73379','deals','font-size','18',0,''),(603503,189898,'73379','deals','text-transform','uppercase',0,''),(603504,189899,'73380','deals','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(603505,189899,'73380','deals','style_class','heading-saved-lists',0,''),(603506,189900,'73381','deals','link','Personal Catalog',0,''),(603507,189900,'73381','deals','text','TEXT_PERSONAL_CATALOG',0,''),(603508,189900,'73381','deals','hide_link','personal_catalog',0,''),(603509,189901,'73382','deals','link','Order History',0,''),(603510,189901,'73382','deals','text','HEADING_ORDER_HISTORY',0,''),(603511,189901,'73382','deals','active_link','Order History Info,Order pay',0,''),(603512,189902,'73383','deals','link','Address Book',0,''),(603513,189902,'73383','deals','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(603514,189903,'73384','deals','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(603515,189903,'73384','deals','style_class','heading-ordered-items',0,''),(603516,189904,'73385','deals','link','Wishlist',0,''),(603517,189904,'73385','deals','hide_link','wishlist',0,''),(603518,189904,'73385','deals','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(603519,189905,'73386','deals','link','My password',0,''),(603520,189905,'73386','deals','text','TEXT_MY_PASSWORD',0,''),(603521,189906,'73387','deals','link','Samples',0,''),(603522,189906,'73387','deals','text','TEXT_HEADING_SAMPLE_CART',0,''),(603523,189906,'73387','deals','hide_link','samples',0,''),(603524,189907,'73388','deals','link','Review',0,''),(603525,189907,'73388','deals','text','REVIEWS',0,''),(603526,189908,'73389','deals','link','Quotations',0,''),(603527,189908,'73389','deals','hide_link','quotations',0,''),(603528,189908,'73389','deals','text','TEXT_HEADING_QUOTE_CART',0,''),(603529,189909,'73390','deals','link','Account edit',0,''),(603530,189909,'73390','deals','text','ACCOUNT_EDIT',0,''),(603531,189910,'73391','deals','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(603532,189910,'73391','deals','style_class','heading-settings',0,''),(603533,189911,'73392','deals','link','trade_form',0,''),(603534,189911,'73392','deals','text','TRADE_FORM',0,''),(603535,189912,'1713774304.752267','deals','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(603536,189914,'73349','origin','text','##TEXT_PAGE_NOT_FOUND##',0,''),(603537,189914,'73349','origin','text-align','center',0,''),(603538,189914,'73349','origin','padding-top','100',0,''),(603539,189914,'73349','origin','padding-bottom','100',0,''),(603540,189915,'73350','origin','block_type','1',0,''),(603541,189915,'73350','origin','style_class','account-index',0,''),(603542,189916,'73351','origin','block_type','6',0,''),(603543,189916,'73351','origin','schema','6-3',0,'8356'),(603544,189917,'73352','origin','aria_name','account-menu',0,''),(603545,189918,'73374','origin','block_type','1',0,''),(603546,189918,'73374','origin','padding-top','70',0,''),(603547,189918,'73374','origin','padding-right','30',0,''),(603548,189918,'73374','origin','padding-bottom','30',0,''),(603549,189918,'73374','origin','padding-top','0',0,'8356'),(603550,189918,'73374','origin','padding-left','0',0,'8356'),(603551,189918,'73374','origin','padding-right','0',0,'8356'),(603552,189918,'73374','origin','padding-bottom','0',0,'8356'),(603595,189937,'1704978704.8413','origin','block_type','1',0,''),(603596,189938,'73353','origin','link','Order History Info',0,''),(603597,189938,'73353','origin','text','TEXT_VIEW',0,''),(603598,189938,'73353','origin','max_orders','3',0,''),(603599,189938,'73353','origin','link_pay','Order pay',0,''),(603600,189938,'73353','origin','margin-bottom','30',0,''),(603601,189938,'73353','origin','text_pay','ORDER_PAY',0,''),(603602,189939,'73354','origin','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(603603,189940,'73357','origin','text','<h1>##HEADING_TITLE##</h1>',0,''),(603604,189941,'1705060269.3517','origin','block_type','1',0,''),(603605,189941,'1705060269.3517','origin','padding-top','20',0,''),(603606,189941,'1705060269.3517','origin','padding-left','20',0,''),(603607,189941,'1705060269.3517','origin','padding-right','20',0,''),(603608,189941,'1705060269.3517','origin','padding-bottom','20',0,''),(603609,189941,'1705060269.3517','origin','margin-bottom','30',0,''),(603610,189941,'1705060269.3517','origin','border-top-width','1',0,''),(603611,189941,'1705060269.3517','origin','border-left-width','1',0,''),(603612,189941,'1705060269.3517','origin','border-right-width','1',0,''),(603613,189941,'1705060269.3517','origin','border-bottom-width','1',0,''),(603614,189941,'1705060269.3517','origin','border-top-color','$content-border-1',0,''),(603615,189941,'1705060269.3517','origin','border-left-color','$content-border-1',0,''),(603616,189941,'1705060269.3517','origin','border-right-color','$content-border-1',0,''),(603617,189941,'1705060269.3517','origin','border-bottom-color','$content-border-1',0,''),(603618,189941,'1705060269.3517','origin','style_class','account-content-top',0,''),(603619,189942,'1705060551.6998','origin','block_type','1',0,''),(603620,189943,'73361','origin','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(603621,189943,'73361','origin','font-family','trueloaded',0,'3'),(603622,189943,'73361','origin','content','\\e920',0,'3'),(603623,189943,'73361','origin','color','$highlight-color-3',0,'3'),(603624,189943,'73361','origin','font-size','30',0,'3'),(603625,189943,'73361','origin','text-align','center',0,'3'),(603626,189943,'73361','origin','margin-bottom','10',0,'3'),(603627,189943,'73361','origin','text-align','center',0,''),(603628,189943,'73361','origin','font-size','16',0,''),(603629,189943,'73361','origin','text-transform','uppercase',0,''),(603630,189943,'73361','origin','line-height','1',0,'3'),(603631,189943,'73361','origin','font-size','14',0,'8349'),(603632,189944,'73362','origin','font-family','$font-1',0,''),(603633,189944,'73362','origin','color','$highlight-color-3',0,''),(603634,189944,'73362','origin','font-size','14',0,''),(603635,189944,'73362','origin','text-align','center',0,''),(603636,189945,'1705060566.121','origin','block_type','1',0,''),(603637,189946,'73363','origin','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(603638,189946,'73363','origin','font-family','trueloaded',0,'3'),(603639,189946,'73363','origin','content','\\e928',0,'3'),(603640,189946,'73363','origin','color','$highlight-color-3',0,'3'),(603641,189946,'73363','origin','font-size','30',0,'3'),(603642,189946,'73363','origin','text-align','center',0,'3'),(603643,189946,'73363','origin','text-align','center',0,''),(603644,189946,'73363','origin','font-size','16',0,''),(603645,189946,'73363','origin','text-transform','uppercase',0,''),(603646,189946,'73363','origin','line-height','1',0,'3'),(603647,189946,'73363','origin','font-size','14',0,'8349'),(603648,189947,'73364','origin','font-family','$font-1',0,''),(603649,189947,'73364','origin','color','$highlight-color-3',0,''),(603650,189947,'73364','origin','font-size','14',0,''),(603651,189947,'73364','origin','text-align','center',0,''),(603652,189948,'73365','origin','link','download_orders',0,''),(603653,189948,'73365','origin','text','TEXT_DOWNLOAD_ORDERS',0,''),(603654,189948,'73365','origin','hide_link','orders',0,''),(603655,189948,'73365','origin','text-align','center',0,''),(603656,189948,'73365','origin','popup','2',0,''),(603657,189948,'73365','origin','font-size','14',0,''),(603658,189949,'1705060582.9285','origin','block_type','1',0,''),(603659,189950,'73366','origin','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(603660,189950,'73366','origin','font-family','trueloaded',0,'3'),(603661,189950,'73366','origin','content','\\e922',0,'3'),(603662,189950,'73366','origin','color','$highlight-color-3',0,'3'),(603663,189950,'73366','origin','font-size','30',0,'3'),(603664,189950,'73366','origin','line-height','1',0,'3'),(603665,189950,'73366','origin','font-size','16',0,''),(603666,189950,'73366','origin','text-align','center',0,''),(603667,189950,'73366','origin','text-transform','uppercase',0,''),(603668,189950,'73366','origin','font-size','14',0,'8349'),(603669,189951,'73367','origin','font-family','$font-1',0,''),(603670,189951,'73367','origin','color','$highlight-color-3',0,''),(603671,189951,'73367','origin','line-height','1',0,''),(603672,189951,'73367','origin','text-align','center',0,''),(603673,189951,'73367','origin','font-size','14',0,''),(603674,189952,'1705060591.4402','origin','block_type','1',0,''),(603675,189953,'73368','origin','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(603676,189953,'73368','origin','content','\\e994',0,'3'),(603677,189953,'73368','origin','font-family','trueloaded',0,'3'),(603678,189953,'73368','origin','color','$highlight-color-3',0,'3'),(603679,189953,'73368','origin','font-size','30',0,'3'),(603680,189953,'73368','origin','line-height','1',0,'3'),(603681,189953,'73368','origin','font-size','16',0,''),(603682,189953,'73368','origin','text-align','center',0,''),(603683,189953,'73368','origin','text-transform','uppercase',0,''),(603684,189953,'73368','origin','font-size','14',0,'8349'),(603685,189954,'73369','origin','font-family','$font-1',0,''),(603686,189954,'73369','origin','color','$highlight-color-3',0,''),(603687,189954,'73369','origin','font-size','14',0,''),(603688,189954,'73369','origin','text-align','center',0,''),(603689,189955,'73370','origin','link','Gift Certificate',0,''),(603690,189955,'73370','origin','text','GIFT_CERTIFICATE',0,''),(603691,189955,'73370','origin','popup','1',0,''),(603692,189955,'73370','origin','text-align','center',0,''),(603693,189955,'73370','origin','font-size','14',0,''),(603694,189956,'1705060602.1936','origin','block_type','1',0,''),(603695,189957,'73371','origin','text','TEXT_VIEW_HISTORY',0,''),(603696,189957,'73371','origin','popup','1',0,''),(603697,189957,'73371','origin','text-align','center',0,''),(603698,189957,'73371','origin','link','Points Earnt History',0,''),(603699,189957,'73371','origin','font-size','14',0,''),(603700,189958,'73372','origin','font-family','$font-1',0,''),(603701,189958,'73372','origin','color','$highlight-color-3',0,''),(603702,189958,'73372','origin','font-size','14',0,''),(603703,189958,'73372','origin','text-align','center',0,''),(603704,189959,'73373','origin','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(603705,189959,'73373','origin','content','\\e990',0,'3'),(603706,189959,'73373','origin','font-family','trueloaded',0,'3'),(603707,189959,'73373','origin','font-size','30',0,'3'),(603708,189959,'73373','origin','text-align','center',0,'3'),(603709,189959,'73373','origin','line-height','1',0,'3'),(603710,189959,'73373','origin','color','$highlight-color-3',0,'3'),(603711,189959,'73373','origin','font-size','16',0,''),(603712,189959,'73373','origin','text-align','center',0,''),(603713,189959,'73373','origin','text-transform','uppercase',0,''),(603714,189959,'73373','origin','font-size','14',0,'8349'),(603715,189960,'73374','origin','block_type','1',0,''),(603716,189960,'73374','origin','padding-top','70',0,''),(603717,189960,'73374','origin','padding-right','30',0,''),(603718,189960,'73374','origin','padding-bottom','30',0,''),(603719,189960,'73374','origin','padding-top','0',0,'8356'),(603720,189960,'73374','origin','padding-left','0',0,'8356'),(603721,189960,'73374','origin','padding-right','0',0,'8356'),(603722,189960,'73374','origin','padding-bottom','0',0,'8356'),(603765,189979,'73393','origin','block_type','1',0,''),(603766,189979,'73393','origin','style_class','account-edit-wrap',0,''),(603767,189980,'73394','origin','block_type','6',0,''),(603768,189980,'73394','origin','schema','6-3',0,'8356'),(603769,189981,'73395','origin','aria_name','account-menu',0,''),(603770,189982,'73374','origin','block_type','1',0,''),(603771,189982,'73374','origin','padding-top','70',0,''),(603772,189982,'73374','origin','padding-right','30',0,''),(603773,189982,'73374','origin','padding-bottom','30',0,''),(603774,189982,'73374','origin','padding-top','0',0,'8356'),(603775,189982,'73374','origin','padding-left','0',0,'8356'),(603776,189982,'73374','origin','padding-right','0',0,'8356'),(603777,189982,'73374','origin','padding-bottom','0',0,'8356'),(603820,190002,'73397','origin','text','<h1>##HEADING_TITLE##</h1>',0,''),(603821,190003,'73398','origin','block_type','1',0,''),(603822,190003,'73398','origin','style_class','account-address-book',0,''),(603823,190004,'73399','origin','block_type','6',0,''),(603824,190004,'73399','origin','schema','6-3',0,'8356'),(603825,190005,'73400','origin','aria_name','account-menu',0,''),(603826,190006,'73374','origin','block_type','1',0,''),(603827,190006,'73374','origin','padding-top','70',0,''),(603828,190006,'73374','origin','padding-right','30',0,''),(603829,190006,'73374','origin','padding-bottom','30',0,''),(603830,190006,'73374','origin','padding-top','0',0,'8356'),(603831,190006,'73374','origin','padding-left','0',0,'8356'),(603832,190006,'73374','origin','padding-right','0',0,'8356'),(603833,190006,'73374','origin','padding-bottom','0',0,'8356'),(603876,190025,'73401','origin','padding-top','15',0,''),(603877,190025,'73401','origin','padding-bottom','15',0,''),(603878,190025,'73401','origin','link','Address Book Process',0,''),(603879,190025,'73401','origin','text','EDIT',0,''),(603880,190025,'73401','origin','link_add','Address Book Process',0,''),(603881,190025,'73401','origin','like_button_add','2',0,''),(603882,190025,'73401','origin','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(603883,190026,'73402','origin','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(603884,190027,'73403','origin','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(603885,190028,'73404','origin','block_type','1',0,''),(603886,190028,'73404','origin','style_class','account-address-book-process',0,''),(603887,190029,'73405','origin','block_type','6',0,''),(603888,190029,'73405','origin','schema','6-3',0,'8356'),(603889,190030,'73406','origin','aria_name','account-menu',0,''),(603890,190031,'73374','origin','block_type','1',0,''),(603891,190031,'73374','origin','padding-top','70',0,''),(603892,190031,'73374','origin','padding-right','30',0,''),(603893,190031,'73374','origin','padding-bottom','30',0,''),(603894,190031,'73374','origin','padding-top','0',0,'8356'),(603895,190031,'73374','origin','padding-left','0',0,'8356'),(603896,190031,'73374','origin','padding-right','0',0,'8356'),(603897,190031,'73374','origin','padding-bottom','0',0,'8356'),(603940,190050,'73407','origin','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(603941,190052,'73409','origin','block_type','1',0,''),(603942,190052,'73409','origin','style_class','item-holder',0,''),(603943,190052,'73409','origin','padding-top','25',0,''),(603944,190052,'73409','origin','padding-bottom','25',0,''),(603945,190052,'73409','origin','text-align','left',0,''),(603946,190052,'73409','origin','border-top-color','$content-border-1',0,''),(603947,190052,'73409','origin','border-top-width','1',0,''),(603948,190053,'73410','origin','block_type','6',0,''),(603949,190054,'73411','origin','padding-right','20',0,''),(603950,190055,'73412','origin','description_characters','200',0,''),(603951,190055,'73412','origin','clear','none',0,''),(603952,190055,'73412','origin','padding-right','20',0,''),(603953,190056,'73413','origin','clear','none',0,''),(603954,190058,'73415','origin','block_type','4',0,''),(603955,190059,'73416','origin','block_type','2',0,''),(603956,190060,'73417','origin','margin-bottom','7',0,''),(603957,190061,'73418','origin','clear','none',0,''),(603958,190062,'73419','origin','margin-bottom','20',0,''),(603959,190062,'73419','origin','text-align','right',0,''),(603960,190063,'73420','origin','padding-right','20',0,''),(603961,190064,'73421','origin','block_type','2',0,''),(603962,190065,'73422','origin','clear','none',0,''),(603963,190067,'76000','origin','block_type','1',0,''),(603964,190067,'76000','origin','style_class','item-holder',0,''),(603965,190067,'76000','origin','padding-top','25',0,''),(603966,190067,'76000','origin','padding-left','25',0,''),(603967,190067,'76000','origin','padding-right','25',0,''),(603968,190067,'76000','origin','padding-bottom','25',0,''),(603969,190067,'76000','origin','text-align','left',0,''),(603970,190069,'76002','origin','margin-bottom','7',0,''),(603971,190070,'76003','origin','clear','both',0,''),(603972,190073,'76006','origin','block_type','1',0,''),(603973,190073,'76006','origin','style_class','item-holder',0,''),(603974,190073,'76006','origin','padding-top','25',0,''),(603975,190073,'76006','origin','padding-left','25',0,''),(603976,190073,'76006','origin','padding-right','25',0,''),(603977,190073,'76006','origin','padding-bottom','25',0,''),(603978,190073,'76006','origin','text-align','left',0,''),(603979,190074,'76007','origin','block_type','5',0,''),(603980,190077,'76010','origin','margin-bottom','7',0,''),(603981,190078,'76011','origin','clear','both',0,''),(603982,190079,'76012','origin','block_type','1',0,''),(603983,190080,'76013','origin','block_type','6',0,''),(603984,190080,'76013','origin','font-weight','400',0,''),(603985,190080,'76013','origin','schema','6-2',0,'8377'),(603986,190080,'76013','origin','schema','6-2',0,'8356'),(603987,190081,'76014','origin','font-weight','400',0,''),(603988,190081,'76014','origin','padding-right','40',0,''),(603989,190081,'76014','origin','padding-right','0',0,'8377'),(603990,190081,'76014','origin','padding-right','0',0,'8356'),(603991,190082,'76015','origin','block_type','5',0,''),(603992,190082,'76015','origin','padding-top','10',0,''),(603993,190082,'76015','origin','padding-bottom','10',0,''),(603994,190082,'76015','origin','schema','5-2',0,'8377'),(603995,190082,'76015','origin','border-top-color','$content-border-1',0,''),(603996,190082,'76015','origin','border-top-width','1',0,''),(603997,190084,'76017','origin','float','right',0,''),(603998,190086,'76019','origin','col_in_row','3',0,''),(603999,190086,'76019','origin','products_align','left',0,''),(604000,190086,'76019','origin','font-weight','400',0,''),(604001,190086,'76019','origin','show_qty_input','0',0,''),(604002,190086,'76019','origin','listing_type','productListing',0,''),(604003,190086,'76019','origin','listing_type_rows','no',0,''),(604004,190086,'76019','origin','show_buy_button_b2b','on',0,''),(604005,190086,'76019','origin','show_wishlist_button_b2b','1',0,''),(604006,190086,'76019','origin','show_compare_b2b','1',0,''),(604007,190086,'76019','origin','show_stock','0',0,''),(604008,190086,'76019','origin','show_description','0',0,''),(604009,190086,'76019','origin','show_model','0',0,''),(604010,190086,'76019','origin','show_properties','0',0,''),(604011,190086,'76019','origin','show_rating','0',0,''),(604012,190086,'76019','origin','show_rating_counts','0',0,''),(604013,190086,'76019','origin','show_price','0',0,''),(604014,190086,'76019','origin','show_buy_button','0',0,''),(604015,190086,'76019','origin','show_view_button','0',0,''),(604016,190086,'76019','origin','show_wishlist_button','0',0,''),(604017,190086,'76019','origin','show_compare','0',0,''),(604018,190086,'76019','origin','show_name_rows','0',0,''),(604019,190086,'76019','origin','show_image_rows','0',0,''),(604020,190086,'76019','origin','show_stock_rows','0',0,''),(604021,190086,'76019','origin','show_description_rows','0',0,''),(604022,190086,'76019','origin','show_model_rows','0',0,''),(604023,190086,'76019','origin','show_properties_rows','0',0,''),(604024,190086,'76019','origin','show_rating_rows','0',0,''),(604025,190086,'76019','origin','show_rating_counts_rows','0',0,''),(604026,190086,'76019','origin','show_price_rows','0',0,''),(604027,190086,'76019','origin','show_buy_button_rows','0',0,''),(604028,190086,'76019','origin','show_qty_input_rows','0',0,''),(604029,190086,'76019','origin','show_view_button_rows','0',0,''),(604030,190086,'76019','origin','show_wishlist_button_rows','0',0,''),(604031,190086,'76019','origin','show_compare_rows','0',0,''),(604032,190086,'76019','origin','show_name_b2b','0',0,''),(604033,190086,'76019','origin','show_image_b2b','0',0,''),(604034,190086,'76019','origin','show_stock_b2b','0',0,''),(604035,190086,'76019','origin','show_description_b2b','0',0,''),(604036,190086,'76019','origin','show_model_b2b','0',0,''),(604037,190086,'76019','origin','show_properties_b2b','0',0,''),(604038,190086,'76019','origin','show_rating_b2b','0',0,''),(604039,190086,'76019','origin','show_rating_counts_b2b','0',0,''),(604040,190086,'76019','origin','show_price_b2b','0',0,''),(604041,190086,'76019','origin','show_qty_input_b2b','0',0,''),(604042,190086,'76019','origin','show_view_button_b2b','0',0,''),(604043,190086,'76019','origin','show_attributes_b2b','0',0,''),(604044,190086,'76019','origin','items_on_page','9',0,''),(604045,190086,'76019','origin','col_in_row','2',0,'8356'),(604046,190086,'76019','origin','col_in_row','1',0,'8377'),(604047,190086,'76019','origin','product_names_teg','h2',0,''),(604048,190087,'76020','origin','listing_type','productListing',0,''),(604049,190088,'76021','origin','block_type','1',0,''),(604050,190088,'76021','origin','padding-top','10',0,''),(604051,190088,'76021','origin','padding-bottom','10',0,''),(604052,190088,'76021','origin','border-bottom-width','1',0,''),(604053,190088,'76021','origin','border-bottom-color','$content-border-1',0,''),(604054,190088,'76021','origin','margin-left','0',0,''),(604055,190088,'76021','origin','margin-right','0',0,''),(604056,190089,'76022','origin','float','right',0,''),(604057,190089,'76022','origin','display','none',0,'8377'),(604058,190090,'76023','origin','margin-right','20',0,''),(604059,190090,'76023','origin','float','right',0,''),(604060,190090,'76023','origin','clear','none',0,''),(604061,190090,'76023','origin','display','none',0,'8356'),(604062,190091,'76024','origin','float','left',0,''),(604063,190091,'76024','origin','clear','none',0,''),(604064,190091,'76024','origin','margin-left','20',0,''),(604065,190091,'76024','origin','display','none',0,'8377'),(604066,190092,'76025','origin','float','left',0,''),(604067,190092,'76025','origin','clear','none',0,''),(604068,190092,'76025','origin','sort_pos_3','1',0,''),(604069,190092,'76025','origin','sort_pos_4','2',0,''),(604070,190092,'76025','origin','sort_pos_10','3',0,''),(604071,190092,'76025','origin','sort_pos_9','4',0,''),(604072,190092,'76025','origin','sort_pos_11','5',0,''),(604073,190092,'76025','origin','sort_pos_12','6',0,''),(604074,190092,'76025','origin','sort_pos_14','7',0,''),(604075,190092,'76025','origin','sort_pos_13','8',0,''),(604076,190092,'76025','origin','sort_pos_8','9',0,''),(604077,190092,'76025','origin','sort_pos_7','10',0,''),(604078,190092,'76025','origin','sort_pos_2','11',0,''),(604079,190092,'76025','origin','sort_pos_1','12',0,''),(604080,190092,'76025','origin','sort_pos_6','13',0,''),(604081,190092,'76025','origin','sort_pos_5','14',0,''),(604082,190092,'76025','origin','sort_pos_0','15',0,''),(604083,190092,'76025','origin','sort_hide_10','1',0,''),(604084,190092,'76025','origin','sort_hide_9','1',0,''),(604085,190092,'76025','origin','hide_icons','1',0,''),(604086,190092,'76025','origin','sort_hide_16','1',0,''),(604087,190092,'76025','origin','sort_hide_15','1',0,''),(604088,190092,'76025','origin','sort_hide_3','0',0,''),(604089,190092,'76025','origin','sort_hide_4','0',0,''),(604090,190092,'76025','origin','sort_hide_11','1',0,''),(604091,190092,'76025','origin','sort_hide_12','1',0,''),(604092,190092,'76025','origin','sort_hide_14','1',0,''),(604093,190092,'76025','origin','sort_hide_13','1',0,''),(604094,190092,'76025','origin','sort_hide_8','0',0,''),(604095,190092,'76025','origin','sort_hide_7','0',0,''),(604096,190092,'76025','origin','sort_hide_2','1',0,''),(604097,190092,'76025','origin','sort_hide_1','1',0,''),(604098,190092,'76025','origin','sort_hide_6','1',0,''),(604099,190092,'76025','origin','sort_hide_5','1',0,''),(604100,190092,'76025','origin','sort_hide_0','1',0,''),(604101,190095,'1683124632.767746','origin','block_type','1',0,''),(604102,190095,'1683124632.767746','origin','font-weight','normal',0,''),(604103,190095,'1683124632.767746','origin','padding-top','20',0,''),(604104,190095,'1683124632.767746','origin','background-color','$content-bg-2',0,''),(604105,190095,'1683124632.767746','origin','style_class','shopping-cart-index',0,''),(604106,190095,'1683124632.767746','origin','color','$content-color-2',0,''),(604107,190096,'1683124632.80670','origin','block_type','4',0,''),(604108,190096,'1683124632.80670','origin','schema','4-1',0,'8361'),(604109,190096,'1683124632.80670','origin','schema','4-2',0,'8356'),(604110,190097,'1683124632.809680','origin','block_type','1',0,''),(604111,190097,'1683124632.809680','origin','background-color','$content-bg-1',0,''),(604112,190097,'1683124632.809680','origin','padding-top','20',0,''),(604113,190097,'1683124632.809680','origin','padding-bottom','20',0,''),(604114,190097,'1683124632.809680','origin','padding-left','25',0,''),(604115,190097,'1683124632.809680','origin','padding-right','25',0,''),(604116,190097,'1683124632.809680','origin','margin-bottom','30',0,''),(604117,190097,'1683124632.809680','origin','color','$content-color-1',0,''),(604118,190098,'1683124632.816335','origin','block_type','1',0,''),(604119,190098,'1683124632.816335','origin','background-color','$content-bg-1',0,''),(604120,190098,'1683124632.816335','origin','margin-bottom','30',0,''),(604121,190098,'1683124632.816335','origin','color','$content-color-1',0,''),(604122,190099,'1683124632.817623','origin','padding-top','20',0,''),(604123,190099,'1683124632.817623','origin','padding-left','25',0,''),(604124,190099,'1683124632.817623','origin','padding-right','25',0,''),(604125,190099,'1683124632.817623','origin','padding-bottom','20',0,''),(604126,190100,'1683124632.818551','origin','block_type','2',0,''),(604127,190100,'1683124632.818551','origin','padding-bottom','20',0,''),(604128,190100,'1683124632.818551','origin','padding-top','20',0,''),(604129,190100,'1683124632.818551','origin','padding-left','25',0,''),(604130,190100,'1683124632.818551','origin','padding-right','25',0,''),(604131,190100,'1683124632.818551','origin','border-bottom-color','#e0e0e0',0,''),(604132,190100,'1683124632.818551','origin','border-bottom-width','1',0,''),(604133,190100,'1683124632.818551','origin','schema','2-2',0,'8356'),(604134,190101,'1683124632.820317','origin','float','left',0,''),(604135,190102,'1683124632.820914','origin','text-align','right',0,''),(604136,190102,'1683124632.820914','origin','clear','none',0,''),(604137,190102,'1683124632.820914','origin','float','right',0,''),(604138,190102,'1683124632.820914','origin','padding-top','22',0,''),(604139,190103,'1683124632.822588','origin','float','right',0,''),(604140,190103,'1683124632.822588','origin','padding-top','26',0,''),(604141,190104,'1683124632.823175','origin','block_type','3',0,''),(604142,190104,'1683124632.823175','origin','font-weight','400',0,''),(604143,190104,'1683124632.823175','origin','schema','2-2',0,'8349'),(604144,190104,'1683124632.823175','origin','style_class','closeable-content',0,''),(604145,190104,'1683124632.823175','origin','padding-top','10',0,''),(604146,190104,'1683124632.823175','origin','padding-left','25',0,''),(604147,190104,'1683124632.823175','origin','padding-right','25',0,''),(604148,190104,'1683124632.823175','origin','padding-bottom','20',0,''),(604149,190107,'1683124632.82683','origin','block_type','1',0,''),(604150,190107,'1683124632.82683','origin','padding-top','20',0,''),(604151,190107,'1683124632.82683','origin','padding-bottom','20',0,''),(604152,190107,'1683124632.82683','origin','padding-left','25',0,''),(604153,190107,'1683124632.82683','origin','padding-right','25',0,''),(604154,190107,'1683124632.82683','origin','background-color','$content-bg-1',0,''),(604155,190107,'1683124632.82683','origin','margin-bottom','30',0,''),(604156,190107,'1683124632.82683','origin','color','$content-color-1',0,''),(604157,190108,'1683124632.827413','origin','hide_parents','2',0,''),(604158,190109,'1683124632.828374','origin','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(604159,190110,'1683124632.829840','origin','block_type','1',0,''),(604160,190110,'1683124632.829840','origin','background-color','$content-bg-1',0,''),(604161,190110,'1683124632.829840','origin','padding-top','20',0,''),(604162,190110,'1683124632.829840','origin','padding-left','25',0,''),(604163,190110,'1683124632.829840','origin','padding-right','25',0,''),(604164,190110,'1683124632.829840','origin','padding-bottom','20',0,''),(604165,190110,'1683124632.829840','origin','margin-bottom','30',0,''),(604166,190110,'1683124632.829840','origin','style_class','closeable-box',0,''),(604167,190110,'1683124632.829840','origin','display','none',0,'8356'),(604168,190111,'1683124632.831459','origin','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(604169,190111,'1683124632.831459','origin','style_class','shipping-ico closeable-heading closeable-event',0,''),(604170,190112,'1683124632.832592','origin','font-weight','normal',0,''),(604171,190112,'1683124632.832592','origin','style_class','closeable-content',0,''),(604172,190112,'1683124632.832592','origin','padding-top','10',0,''),(604173,190112,'1683124632.832592','origin','hide_parents','2',0,''),(604174,190113,'1683124632.833353','origin','style_class','order-summary',0,''),(604175,190113,'1683124632.833353','origin','block_type','1',0,''),(604176,190113,'1683124632.833353','origin','margin-left','30',0,''),(604177,190113,'1683124632.833353','origin','margin-left','0',0,'8356'),(604178,190113,'1683124632.833353','origin','margin-bottom','30',0,'8356'),(604179,190114,'1683124632.834715','origin','block_type','1',0,''),(604180,190114,'1683124632.834715','origin','padding-left','20',0,''),(604181,190114,'1683124632.834715','origin','padding-right','20',0,''),(604182,190114,'1683124632.834715','origin','padding-bottom','20',0,''),(604183,190115,'1683124632.835884','origin','font-weight','400',0,''),(604184,190115,'1683124632.835884','origin','padding-top','12',0,'8349'),(604185,190115,'1683124632.835884','origin','padding-left','0',0,'8349'),(604186,190116,'1683124632.836532','origin','font-weight','400',0,''),(604187,190116,'1683124632.836532','origin','logo','themes/origin/img/themes/basic/img/payment.png',1,''),(604188,190116,'1683124632.836532','origin','padding-top','20',0,''),(604189,190116,'1683124632.836532','origin','padding-bottom','10',0,''),(604190,190116,'1683124632.836532','origin','logo','themes/origin/img/themes/basic/img/payment.png',0,''),(604191,190117,'1683124632.844829','origin','font-weight','400',0,''),(604192,190117,'1683124632.844829','origin','box_align','4',0,''),(604193,190117,'1683124632.844829','origin','text-align','center',0,'8349'),(604194,190117,'1683124632.844829','origin','float','none',0,'8349'),(604195,190117,'1683124632.844829','origin','width','100',0,'8349'),(604196,190117,'1683124632.844829','origin','width_measure','%',0,'8349'),(604197,190118,'1683124632.84681','origin','style_class','bottom-totals',0,''),(604198,190119,'1683124632.846538','origin','style_class','top-totals',0,''),(604199,190120,'1683124632.84726','origin','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(604200,190121,'94658','origin','block_type','1',0,''),(604201,190121,'94658','origin','font-weight','normal',0,''),(604202,190121,'94658','origin','padding-top','20',0,''),(604203,190121,'94658','origin','background-color','$content-bg-2',0,''),(604204,190123,'94660','origin','block_type','4',0,''),(604205,190123,'94660','origin','schema','4-1',0,'8361'),(604206,190123,'94660','origin','schema','4-2',0,'8356'),(604207,190124,'94661','origin','block_type','1',0,''),(604208,190124,'94661','origin','background-color','$content-bg-1',0,''),(604209,190124,'94661','origin','padding-top','20',0,''),(604210,190124,'94661','origin','padding-bottom','20',0,''),(604211,190124,'94661','origin','padding-left','25',0,''),(604212,190124,'94661','origin','padding-right','25',0,''),(604213,190124,'94661','origin','margin-bottom','30',0,''),(604214,190125,'94662','origin','col_in_row','3',0,''),(604215,190125,'94662','origin','show_description','1',0,''),(604216,190125,'94662','origin','show_model','1',0,''),(604217,190125,'94662','origin','show_properties','1',0,''),(604218,190125,'94662','origin','show_rating','1',0,''),(604219,190125,'94662','origin','show_rating_counts','1',0,''),(604220,190125,'94662','origin','show_qty_input','1',0,''),(604221,190125,'94662','origin','show_view_button','1',0,''),(604222,190125,'94662','origin','show_wishlist_button','1',0,''),(604223,190125,'94662','origin','show_compare','1',0,''),(604224,190125,'94662','origin','view_as','carousel',0,''),(604225,190125,'94662','origin','hide_parents','2',0,''),(604226,190126,'94663','origin','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(604227,190126,'94663','origin','style_class','bell-ico',0,''),(604228,190127,'94664','origin','block_type','1',0,''),(604229,190127,'94664','origin','background-color','$content-bg-1',0,''),(604230,190127,'94664','origin','margin-bottom','30',0,''),(604231,190128,'94665','origin','padding-top','20',0,''),(604232,190128,'94665','origin','padding-left','25',0,''),(604233,190128,'94665','origin','padding-right','25',0,''),(604234,190128,'94665','origin','padding-bottom','20',0,''),(604235,190129,'94666','origin','block_type','2',0,''),(604236,190129,'94666','origin','padding-bottom','20',0,''),(604237,190129,'94666','origin','padding-top','20',0,''),(604238,190129,'94666','origin','padding-left','25',0,''),(604239,190129,'94666','origin','padding-right','25',0,''),(604240,190129,'94666','origin','border-bottom-color','$content-border-1',0,''),(604241,190129,'94666','origin','border-bottom-width','1',0,''),(604242,190129,'94666','origin','schema','2-2',0,'8356'),(604243,190130,'94667','origin','float','left',0,''),(604244,190131,'94668','origin','text-align','right',0,''),(604245,190131,'94668','origin','clear','none',0,''),(604246,190131,'94668','origin','float','right',0,''),(604247,190131,'94668','origin','padding-top','22',0,''),(604248,190132,'94669','origin','float','right',0,''),(604249,190132,'94669','origin','padding-top','26',0,''),(604250,190133,'94670','origin','block_type','1',0,''),(604251,190133,'94670','origin','padding-top','20',0,''),(604252,190133,'94670','origin','padding-bottom','20',0,''),(604253,190133,'94670','origin','padding-left','25',0,''),(604254,190133,'94670','origin','padding-right','25',0,''),(604255,190133,'94670','origin','background-color','$content-bg-1',0,''),(604256,190133,'94670','origin','margin-bottom','30',0,''),(604257,190134,'94671','origin','hide_parents','2',0,''),(604258,190135,'94672','origin','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(604259,190136,'94673','origin','block_type','1',0,''),(604260,190136,'94673','origin','background-color','$content-bg-1',0,''),(604261,190136,'94673','origin','padding-top','20',0,''),(604262,190136,'94673','origin','padding-bottom','20',0,''),(604263,190136,'94673','origin','padding-left','25',0,''),(604264,190136,'94673','origin','padding-right','25',0,''),(604265,190136,'94673','origin','margin-bottom','30',0,''),(604266,190136,'94673','origin','style_class','closeable-box',0,''),(604267,190137,'94674','origin','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(604268,190137,'94674','origin','style_class','savings-ico closeable-heading closeable-event',0,''),(604269,190138,'94675','origin','block_type','3',0,''),(604270,190138,'94675','origin','font-weight','400',0,''),(604271,190138,'94675','origin','schema','2-2',0,'8349'),(604272,190138,'94675','origin','style_class','closeable-content',0,''),(604273,190138,'94675','origin','padding-top','10',0,''),(604274,190139,'94676','origin','font-weight','400',0,''),(604275,190139,'94676','origin','padding-top','12',0,'8349'),(604276,190139,'94676','origin','padding-left','0',0,'8349'),(604277,190142,'94679','origin','block_type','1',0,''),(604278,190142,'94679','origin','background-color','$content-bg-1',0,''),(604279,190142,'94679','origin','padding-top','20',0,''),(604280,190142,'94679','origin','padding-left','25',0,''),(604281,190142,'94679','origin','padding-right','25',0,''),(604282,190142,'94679','origin','padding-bottom','20',0,''),(604283,190142,'94679','origin','margin-bottom','30',0,''),(604284,190142,'94679','origin','style_class','closeable-box',0,''),(604285,190142,'94679','origin','display','none',0,'8356'),(604286,190143,'94680','origin','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(604287,190143,'94680','origin','style_class','shipping-ico closeable-heading closeable-event',0,''),(604288,190144,'94681','origin','font-weight','normal',0,''),(604289,190144,'94681','origin','style_class','closeable-content',0,''),(604290,190144,'94681','origin','padding-top','10',0,''),(604291,190144,'94681','origin','hide_parents','2',0,''),(604292,190145,'94682','origin','style_class','order-summary',0,''),(604293,190145,'94682','origin','block_type','1',0,''),(604294,190145,'94682','origin','margin-left','30',0,''),(604295,190145,'94682','origin','margin-left','0',0,'8356'),(604296,190145,'94682','origin','margin-bottom','30',0,'8356'),(604297,190146,'94683','origin','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(604298,190147,'94684','origin','block_type','1',0,''),(604299,190147,'94684','origin','padding-left','20',0,''),(604300,190147,'94684','origin','padding-right','20',0,''),(604301,190147,'94684','origin','padding-bottom','20',0,''),(604302,190148,'94685','origin','font-weight','400',0,''),(604303,190148,'94685','origin','logo','themes/origin/img/themes/basic/img/payment.png',1,''),(604304,190148,'94685','origin','padding-top','20',0,''),(604305,190148,'94685','origin','padding-bottom','10',0,''),(604306,190148,'94685','origin','logo','themes/origin/img/themes/basic/img/payment.png',0,''),(604307,190149,'94686','origin','font-weight','400',0,''),(604308,190149,'94686','origin','box_align','4',0,''),(604309,190149,'94686','origin','text-align','center',0,'8349'),(604310,190149,'94686','origin','float','none',0,'8349'),(604311,190149,'94686','origin','width','100',0,'8349'),(604312,190149,'94686','origin','width_measure','%',0,'8349'),(604313,190151,'73462','origin','block_type','1',0,''),(604314,190152,'73463','origin','block_type','6',0,''),(604315,190152,'73463','origin','font-weight','400',0,''),(604316,190152,'73463','origin','schema','6-2',0,'8377'),(604317,190152,'73463','origin','schema','6-2',0,'8356'),(604318,190153,'73464','origin','font-weight','400',0,''),(604319,190153,'73464','origin','padding-right','40',0,''),(604320,190153,'73464','origin','padding-right','0',0,'8377'),(604321,190153,'73464','origin','padding-right','0',0,'8356'),(604322,190154,'73465','origin','col_in_row','3',0,''),(604323,190154,'73465','origin','products_align','left',0,''),(604324,190154,'73465','origin','font-weight','400',0,''),(604325,190154,'73465','origin','show_qty_input','0',0,''),(604326,190154,'73465','origin','listing_type','productListing',0,''),(604327,190154,'73465','origin','listing_type_rows','Rows',0,''),(604328,190154,'73465','origin','show_buy_button_b2b','on',0,''),(604329,190154,'73465','origin','show_wishlist_button_b2b','1',0,''),(604330,190154,'73465','origin','show_compare_b2b','1',0,''),(604331,190154,'73465','origin','show_stock','0',0,''),(604332,190154,'73465','origin','show_description','0',0,''),(604333,190154,'73465','origin','show_model','0',0,''),(604334,190154,'73465','origin','show_properties','0',0,''),(604335,190154,'73465','origin','show_rating','0',0,''),(604336,190154,'73465','origin','show_rating_counts','0',0,''),(604337,190154,'73465','origin','show_price','0',0,''),(604338,190154,'73465','origin','show_buy_button','0',0,''),(604339,190154,'73465','origin','show_view_button','0',0,''),(604340,190154,'73465','origin','show_wishlist_button','0',0,''),(604341,190154,'73465','origin','show_compare','0',0,''),(604342,190154,'73465','origin','show_name_rows','0',0,''),(604343,190154,'73465','origin','show_image_rows','0',0,''),(604344,190154,'73465','origin','show_stock_rows','0',0,''),(604345,190154,'73465','origin','show_description_rows','0',0,''),(604346,190154,'73465','origin','show_model_rows','0',0,''),(604347,190154,'73465','origin','show_properties_rows','0',0,''),(604348,190154,'73465','origin','show_rating_rows','0',0,''),(604349,190154,'73465','origin','show_rating_counts_rows','0',0,''),(604350,190154,'73465','origin','show_price_rows','0',0,''),(604351,190154,'73465','origin','show_buy_button_rows','0',0,''),(604352,190154,'73465','origin','show_qty_input_rows','0',0,''),(604353,190154,'73465','origin','show_view_button_rows','0',0,''),(604354,190154,'73465','origin','show_wishlist_button_rows','0',0,''),(604355,190154,'73465','origin','show_compare_rows','0',0,''),(604356,190154,'73465','origin','show_name_b2b','0',0,''),(604357,190154,'73465','origin','show_image_b2b','0',0,''),(604358,190154,'73465','origin','show_stock_b2b','0',0,''),(604359,190154,'73465','origin','show_description_b2b','0',0,''),(604360,190154,'73465','origin','show_model_b2b','0',0,''),(604361,190154,'73465','origin','show_properties_b2b','0',0,''),(604362,190154,'73465','origin','show_rating_b2b','0',0,''),(604363,190154,'73465','origin','show_rating_counts_b2b','0',0,''),(604364,190154,'73465','origin','show_price_b2b','0',0,''),(604365,190154,'73465','origin','show_qty_input_b2b','0',0,''),(604366,190154,'73465','origin','show_view_button_b2b','0',0,''),(604367,190154,'73465','origin','show_attributes_b2b','0',0,''),(604368,190154,'73465','origin','items_on_page','9',0,''),(604369,190154,'73465','origin','col_in_row','2',0,'8356'),(604370,190154,'73465','origin','col_in_row','1',0,'8377'),(604371,190154,'73465','origin','product_names_teg','h2',0,''),(604372,190156,'73467','origin','block_type','5',0,''),(604373,190156,'73467','origin','padding-top','10',0,''),(604374,190156,'73467','origin','padding-bottom','10',0,''),(604375,190156,'73467','origin','schema','5-2',0,'8377'),(604376,190156,'73467','origin','border-top-color','$content-border-1',0,''),(604377,190156,'73467','origin','border-top-width','1',0,''),(604378,190158,'73469','origin','float','right',0,''),(604379,190159,'73470','origin','listing_type','productListing',0,''),(604380,190161,'73472','origin','block_type','1',0,''),(604381,190161,'73472','origin','padding-top','10',0,''),(604382,190161,'73472','origin','padding-bottom','10',0,''),(604383,190161,'73472','origin','border-bottom-width','1',0,''),(604384,190161,'73472','origin','border-bottom-color','$content-border-1',0,''),(604385,190161,'73472','origin','margin-left','0',0,''),(604386,190161,'73472','origin','margin-right','0',0,''),(604387,190162,'73473','origin','float','right',0,''),(604388,190162,'73473','origin','display','none',0,'8377'),(604389,190163,'73474','origin','margin-right','20',0,''),(604390,190163,'73474','origin','float','right',0,''),(604391,190163,'73474','origin','clear','none',0,''),(604392,190163,'73474','origin','display','none',0,'8356'),(604393,190164,'73475','origin','float','left',0,''),(604394,190164,'73475','origin','clear','none',0,''),(604395,190164,'73475','origin','margin-left','20',0,''),(604396,190164,'73475','origin','display','none',0,'8377'),(604397,190165,'73476','origin','float','left',0,''),(604398,190165,'73476','origin','clear','none',0,''),(604399,190165,'73476','origin','sort_pos_3','2',0,''),(604400,190165,'73476','origin','sort_pos_4','3',0,''),(604401,190165,'73476','origin','sort_pos_10','11',0,''),(604402,190165,'73476','origin','sort_pos_9','10',0,''),(604403,190165,'73476','origin','sort_pos_11','12',0,''),(604404,190165,'73476','origin','sort_pos_12','13',0,''),(604405,190165,'73476','origin','sort_pos_14','15',0,''),(604406,190165,'73476','origin','sort_pos_13','14',0,''),(604407,190165,'73476','origin','sort_pos_8','4',0,''),(604408,190165,'73476','origin','sort_pos_7','5',0,''),(604409,190165,'73476','origin','sort_pos_2','7',0,''),(604410,190165,'73476','origin','sort_pos_1','6',0,''),(604411,190165,'73476','origin','sort_pos_6','9',0,''),(604412,190165,'73476','origin','sort_pos_5','8',0,''),(604413,190165,'73476','origin','sort_pos_0','1',0,''),(604414,190165,'73476','origin','sort_hide_10','1',0,''),(604415,190165,'73476','origin','sort_hide_9','1',0,''),(604416,190165,'73476','origin','hide_icons','1',0,''),(604417,190165,'73476','origin','sort_hide_16','1',0,''),(604418,190165,'73476','origin','sort_hide_15','1',0,''),(604419,190165,'73476','origin','sort_hide_3','0',0,''),(604420,190165,'73476','origin','sort_hide_4','0',0,''),(604421,190165,'73476','origin','sort_hide_11','1',0,''),(604422,190165,'73476','origin','sort_hide_12','1',0,''),(604423,190165,'73476','origin','sort_hide_14','1',0,''),(604424,190165,'73476','origin','sort_hide_13','1',0,''),(604425,190165,'73476','origin','sort_hide_8','0',0,''),(604426,190165,'73476','origin','sort_hide_7','0',0,''),(604427,190165,'73476','origin','sort_hide_2','1',0,''),(604428,190165,'73476','origin','sort_hide_1','1',0,''),(604429,190165,'73476','origin','sort_hide_6','1',0,''),(604430,190165,'73476','origin','sort_hide_5','1',0,''),(604431,190165,'73476','origin','sort_hide_0','0',0,''),(604432,190165,'73476','origin','sort_pos_15','16',0,''),(604433,190165,'73476','origin','sort_pos_16','17',0,''),(604434,190172,'94688','origin','block_type','1',0,''),(604435,190174,'94690','origin','block_type','6',0,''),(604436,190174,'94690','origin','font-weight','400',0,''),(604437,190174,'94690','origin','schema','6-2',0,'8377'),(604438,190174,'94690','origin','schema','6-2',0,'8356'),(604439,190175,'94691','origin','font-weight','400',0,''),(604440,190175,'94691','origin','padding-right','40',0,''),(604441,190175,'94691','origin','padding-right','0',0,'8377'),(604442,190175,'94691','origin','padding-right','0',0,'8356'),(604443,190177,'94693','origin','col_in_row','3',0,''),(604444,190177,'94693','origin','products_align','left',0,''),(604445,190177,'94693','origin','font-weight','400',0,''),(604446,190177,'94693','origin','show_qty_input','0',0,''),(604447,190177,'94693','origin','listing_type','productListing',0,''),(604448,190177,'94693','origin','listing_type_rows','no',0,''),(604449,190177,'94693','origin','show_buy_button_b2b','on',0,''),(604450,190177,'94693','origin','show_wishlist_button_b2b','1',0,''),(604451,190177,'94693','origin','show_compare_b2b','1',0,''),(604452,190177,'94693','origin','show_stock','0',0,''),(604453,190177,'94693','origin','show_description','0',0,''),(604454,190177,'94693','origin','show_model','0',0,''),(604455,190177,'94693','origin','show_properties','0',0,''),(604456,190177,'94693','origin','show_rating','0',0,''),(604457,190177,'94693','origin','show_rating_counts','0',0,''),(604458,190177,'94693','origin','show_price','0',0,''),(604459,190177,'94693','origin','show_buy_button','0',0,''),(604460,190177,'94693','origin','show_view_button','0',0,''),(604461,190177,'94693','origin','show_wishlist_button','0',0,''),(604462,190177,'94693','origin','show_compare','0',0,''),(604463,190177,'94693','origin','show_name_rows','0',0,''),(604464,190177,'94693','origin','show_image_rows','0',0,''),(604465,190177,'94693','origin','show_stock_rows','0',0,''),(604466,190177,'94693','origin','show_description_rows','0',0,''),(604467,190177,'94693','origin','show_model_rows','0',0,''),(604468,190177,'94693','origin','show_properties_rows','0',0,''),(604469,190177,'94693','origin','show_rating_rows','0',0,''),(604470,190177,'94693','origin','show_rating_counts_rows','0',0,''),(604471,190177,'94693','origin','show_price_rows','0',0,''),(604472,190177,'94693','origin','show_buy_button_rows','0',0,''),(604473,190177,'94693','origin','show_qty_input_rows','0',0,''),(604474,190177,'94693','origin','show_view_button_rows','0',0,''),(604475,190177,'94693','origin','show_wishlist_button_rows','0',0,''),(604476,190177,'94693','origin','show_compare_rows','0',0,''),(604477,190177,'94693','origin','show_name_b2b','0',0,''),(604478,190177,'94693','origin','show_image_b2b','0',0,''),(604479,190177,'94693','origin','show_stock_b2b','0',0,''),(604480,190177,'94693','origin','show_description_b2b','0',0,''),(604481,190177,'94693','origin','show_model_b2b','0',0,''),(604482,190177,'94693','origin','show_properties_b2b','0',0,''),(604483,190177,'94693','origin','show_rating_b2b','0',0,''),(604484,190177,'94693','origin','show_rating_counts_b2b','0',0,''),(604485,190177,'94693','origin','show_price_b2b','0',0,''),(604486,190177,'94693','origin','show_qty_input_b2b','0',0,''),(604487,190177,'94693','origin','show_view_button_b2b','0',0,''),(604488,190177,'94693','origin','show_attributes_b2b','0',0,''),(604489,190177,'94693','origin','items_on_page','9',0,''),(604490,190177,'94693','origin','col_in_row','2',0,'8356'),(604491,190177,'94693','origin','col_in_row','1',0,'8377'),(604492,190177,'94693','origin','product_names_teg','h2',0,''),(604493,190178,'94694','origin','block_type','1',0,''),(604494,190178,'94694','origin','padding-top','10',0,''),(604495,190178,'94694','origin','padding-bottom','10',0,''),(604496,190178,'94694','origin','border-bottom-width','1',0,''),(604497,190178,'94694','origin','border-bottom-color','$content-border-1',0,''),(604498,190178,'94694','origin','margin-left','0',0,''),(604499,190178,'94694','origin','margin-right','0',0,''),(604500,190179,'94695','origin','float','left',0,''),(604501,190179,'94695','origin','clear','none',0,''),(604502,190179,'94695','origin','sort_pos_3','1',0,''),(604503,190179,'94695','origin','sort_pos_4','2',0,''),(604504,190179,'94695','origin','sort_pos_10','3',0,''),(604505,190179,'94695','origin','sort_pos_9','4',0,''),(604506,190179,'94695','origin','sort_pos_11','5',0,''),(604507,190179,'94695','origin','sort_pos_12','6',0,''),(604508,190179,'94695','origin','sort_pos_14','7',0,''),(604509,190179,'94695','origin','sort_pos_13','8',0,''),(604510,190179,'94695','origin','sort_pos_8','9',0,''),(604511,190179,'94695','origin','sort_pos_7','10',0,''),(604512,190179,'94695','origin','sort_pos_2','11',0,''),(604513,190179,'94695','origin','sort_pos_1','12',0,''),(604514,190179,'94695','origin','sort_pos_6','13',0,''),(604515,190179,'94695','origin','sort_pos_5','14',0,''),(604516,190179,'94695','origin','sort_pos_0','15',0,''),(604517,190179,'94695','origin','sort_hide_10','1',0,''),(604518,190179,'94695','origin','sort_hide_9','1',0,''),(604519,190179,'94695','origin','hide_icons','1',0,''),(604520,190179,'94695','origin','sort_hide_16','1',0,''),(604521,190179,'94695','origin','sort_hide_15','1',0,''),(604522,190179,'94695','origin','sort_hide_3','0',0,''),(604523,190179,'94695','origin','sort_hide_4','0',0,''),(604524,190179,'94695','origin','sort_hide_11','1',0,''),(604525,190179,'94695','origin','sort_hide_12','1',0,''),(604526,190179,'94695','origin','sort_hide_14','1',0,''),(604527,190179,'94695','origin','sort_hide_13','1',0,''),(604528,190179,'94695','origin','sort_hide_8','0',0,''),(604529,190179,'94695','origin','sort_hide_7','0',0,''),(604530,190179,'94695','origin','sort_hide_2','1',0,''),(604531,190179,'94695','origin','sort_hide_1','1',0,''),(604532,190179,'94695','origin','sort_hide_6','1',0,''),(604533,190179,'94695','origin','sort_hide_5','1',0,''),(604534,190179,'94695','origin','sort_hide_0','1',0,''),(604535,190180,'94696','origin','float','left',0,''),(604536,190180,'94696','origin','clear','none',0,''),(604537,190180,'94696','origin','margin-left','20',0,''),(604538,190180,'94696','origin','display','none',0,'8377'),(604539,190181,'94697','origin','margin-right','20',0,''),(604540,190181,'94697','origin','float','right',0,''),(604541,190181,'94697','origin','clear','none',0,''),(604542,190181,'94697','origin','display','none',0,'8356'),(604543,190182,'94698','origin','float','right',0,''),(604544,190182,'94698','origin','display','none',0,'8377'),(604545,190183,'94699','origin','listing_type','productListing',0,''),(604546,190185,'94701','origin','block_type','5',0,''),(604547,190185,'94701','origin','padding-top','10',0,''),(604548,190185,'94701','origin','padding-bottom','10',0,''),(604549,190185,'94701','origin','schema','5-2',0,'8377'),(604550,190185,'94701','origin','border-top-color','$content-border-1',0,''),(604551,190185,'94701','origin','border-top-width','1',0,''),(604552,190187,'94703','origin','float','right',0,''),(604553,190188,'73483','origin','block_type','1',0,''),(604554,190191,'73486','origin','block_type','1',0,''),(604555,190191,'73486','origin','padding-top','10',0,''),(604556,190191,'73486','origin','padding-bottom','10',0,''),(604557,190191,'73486','origin','border-bottom-width','1',0,''),(604558,190191,'73486','origin','border-bottom-color','$content-border-1',0,''),(604559,190191,'73486','origin','margin-left','0',0,''),(604560,190191,'73486','origin','margin-right','0',0,''),(604561,190192,'73487','origin','float','left',0,''),(604562,190192,'73487','origin','clear','none',0,''),(604563,190192,'73487','origin','margin-left','20',0,''),(604564,190192,'73487','origin','display','none',0,'8377'),(604565,190193,'73488','origin','float','left',0,''),(604566,190193,'73488','origin','clear','none',0,''),(604567,190193,'73488','origin','sort_pos_3','2',0,''),(604568,190193,'73488','origin','sort_pos_4','3',0,''),(604569,190193,'73488','origin','sort_pos_10','11',0,''),(604570,190193,'73488','origin','sort_pos_9','10',0,''),(604571,190193,'73488','origin','sort_pos_11','12',0,''),(604572,190193,'73488','origin','sort_pos_12','13',0,''),(604573,190193,'73488','origin','sort_pos_14','15',0,''),(604574,190193,'73488','origin','sort_pos_13','14',0,''),(604575,190193,'73488','origin','sort_pos_8','4',0,''),(604576,190193,'73488','origin','sort_pos_7','5',0,''),(604577,190193,'73488','origin','sort_pos_2','7',0,''),(604578,190193,'73488','origin','sort_pos_1','6',0,''),(604579,190193,'73488','origin','sort_pos_6','9',0,''),(604580,190193,'73488','origin','sort_pos_5','8',0,''),(604581,190193,'73488','origin','sort_pos_0','1',0,''),(604582,190193,'73488','origin','sort_hide_10','1',0,''),(604583,190193,'73488','origin','sort_hide_9','1',0,''),(604584,190193,'73488','origin','hide_icons','1',0,''),(604585,190193,'73488','origin','sort_hide_16','1',0,''),(604586,190193,'73488','origin','sort_hide_15','1',0,''),(604587,190193,'73488','origin','sort_hide_3','0',0,''),(604588,190193,'73488','origin','sort_hide_4','0',0,''),(604589,190193,'73488','origin','sort_hide_11','1',0,''),(604590,190193,'73488','origin','sort_hide_12','1',0,''),(604591,190193,'73488','origin','sort_hide_14','1',0,''),(604592,190193,'73488','origin','sort_hide_13','1',0,''),(604593,190193,'73488','origin','sort_hide_8','0',0,''),(604594,190193,'73488','origin','sort_hide_7','0',0,''),(604595,190193,'73488','origin','sort_hide_2','1',0,''),(604596,190193,'73488','origin','sort_hide_1','1',0,''),(604597,190193,'73488','origin','sort_hide_6','1',0,''),(604598,190193,'73488','origin','sort_hide_5','1',0,''),(604599,190193,'73488','origin','sort_hide_0','0',0,''),(604600,190193,'73488','origin','sort_pos_15','16',0,''),(604601,190193,'73488','origin','sort_pos_16','17',0,''),(604602,190194,'73489','origin','margin-right','20',0,''),(604603,190194,'73489','origin','float','right',0,''),(604604,190194,'73489','origin','clear','none',0,''),(604605,190194,'73489','origin','display','none',0,'8356'),(604606,190195,'73490','origin','float','right',0,''),(604607,190195,'73490','origin','display','none',0,'8377'),(604608,190196,'73491','origin','clear','none',0,''),(604609,190196,'73491','origin','float','left',0,''),(604610,190196,'73491','origin','padding-top','3',0,''),(604611,190196,'73491','origin','padding-left','20',0,''),(604612,190197,'73492','origin','block_type','5',0,''),(604613,190197,'73492','origin','padding-top','10',0,''),(604614,190197,'73492','origin','padding-bottom','10',0,''),(604615,190197,'73492','origin','schema','5-2',0,'8377'),(604616,190197,'73492','origin','border-top-color','$content-border-1',0,''),(604617,190197,'73492','origin','border-top-width','1',0,''),(604618,190199,'73494','origin','float','right',0,''),(604619,190200,'73495','origin','col_in_row','4',0,''),(604620,190200,'73495','origin','products_align','left',0,''),(604621,190200,'73495','origin','font-weight','400',0,''),(604622,190200,'73495','origin','show_qty_input','0',0,''),(604623,190200,'73495','origin','listing_type','productListing',0,''),(604624,190200,'73495','origin','listing_type_rows','Rows',0,''),(604625,190200,'73495','origin','show_buy_button_b2b','on',0,''),(604626,190200,'73495','origin','show_wishlist_button_b2b','1',0,''),(604627,190200,'73495','origin','show_compare_b2b','1',0,''),(604628,190200,'73495','origin','show_image','0',0,''),(604629,190200,'73495','origin','show_stock','0',0,''),(604630,190200,'73495','origin','show_description','0',0,''),(604631,190200,'73495','origin','show_model','0',0,''),(604632,190200,'73495','origin','show_properties','0',0,''),(604633,190200,'73495','origin','show_rating','0',0,''),(604634,190200,'73495','origin','show_rating_counts','0',0,''),(604635,190200,'73495','origin','show_price','0',0,''),(604636,190200,'73495','origin','show_buy_button','0',0,''),(604637,190200,'73495','origin','show_view_button','0',0,''),(604638,190200,'73495','origin','show_wishlist_button','0',0,''),(604639,190200,'73495','origin','show_compare','0',0,''),(604640,190200,'73495','origin','show_name_rows','0',0,''),(604641,190200,'73495','origin','show_image_rows','0',0,''),(604642,190200,'73495','origin','show_stock_rows','0',0,''),(604643,190200,'73495','origin','show_description_rows','0',0,''),(604644,190200,'73495','origin','show_model_rows','0',0,''),(604645,190200,'73495','origin','show_properties_rows','0',0,''),(604646,190200,'73495','origin','show_rating_rows','0',0,''),(604647,190200,'73495','origin','show_rating_counts_rows','0',0,''),(604648,190200,'73495','origin','show_price_rows','0',0,''),(604649,190200,'73495','origin','show_buy_button_rows','0',0,''),(604650,190200,'73495','origin','show_qty_input_rows','0',0,''),(604651,190200,'73495','origin','show_view_button_rows','0',0,''),(604652,190200,'73495','origin','show_wishlist_button_rows','0',0,''),(604653,190200,'73495','origin','show_compare_rows','0',0,''),(604654,190200,'73495','origin','show_name_b2b','0',0,''),(604655,190200,'73495','origin','show_image_b2b','0',0,''),(604656,190200,'73495','origin','show_stock_b2b','0',0,''),(604657,190200,'73495','origin','show_description_b2b','0',0,''),(604658,190200,'73495','origin','show_model_b2b','0',0,''),(604659,190200,'73495','origin','show_properties_b2b','0',0,''),(604660,190200,'73495','origin','show_rating_b2b','0',0,''),(604661,190200,'73495','origin','show_rating_counts_b2b','0',0,''),(604662,190200,'73495','origin','show_price_b2b','0',0,''),(604663,190200,'73495','origin','show_qty_input_b2b','0',0,''),(604664,190200,'73495','origin','show_view_button_b2b','0',0,''),(604665,190200,'73495','origin','show_attributes_b2b','0',0,''),(604666,190200,'73495','origin','items_on_page','12',0,''),(604667,190200,'73495','origin','col_in_row','2',0,'8356'),(604668,190200,'73495','origin','col_in_row','1',0,'8377'),(604669,190200,'73495','origin','product_names_teg','h2',0,''),(604670,190203,'1683125852.345798','origin','block_type','1',0,''),(604671,190203,'1683125852.345798','origin','background-color','$content-bg-2',0,''),(604672,190203,'1683125852.345798','origin','padding-top','30',0,''),(604673,190203,'1683125852.345798','origin','padding-bottom','30',0,''),(604674,190203,'1683125852.345798','origin','style_class','checkout-index-wrap',0,''),(604675,190203,'1683125852.345798','origin','color','$content-color-2',0,''),(604676,190204,'1683125852.356555','origin','block_type','4',0,''),(604677,190204,'1683125852.356555','origin','schema','4-2',0,'8356'),(604678,190204,'1683125852.356555','origin','style_class','checkoutDoubleBox',0,''),(604679,190205,'1683125852.358412','origin','block_type','1',0,''),(604680,190205,'1683125852.358412','origin','padding-right','40',0,''),(604681,190205,'1683125852.358412','origin','padding-right','0',0,'8356'),(604682,190206,'1683125852.35982','origin','block_type','1',0,''),(604683,190206,'1683125852.35982','origin','background-color','$content-bg-1',0,''),(604684,190206,'1683125852.35982','origin','padding-top','30',0,''),(604685,190206,'1683125852.35982','origin','padding-left','30',0,''),(604686,190206,'1683125852.35982','origin','padding-right','30',0,''),(604687,190206,'1683125852.35982','origin','padding-bottom','30',0,''),(604688,190206,'1683125852.35982','origin','margin-bottom','20',0,''),(604689,190206,'1683125852.35982','origin','style_class','hiding-box closeable-box',0,''),(604690,190206,'1683125852.35982','origin','color','$content-color-1',0,''),(604691,190207,'1683125852.361569','origin','style_class','closeable-content',0,''),(604692,190207,'1683125852.361569','origin','padding-bottom','20',0,''),(604693,190208,'1683125852.362847','origin','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(604694,190208,'1683125852.362847','origin','style_class','closeable-heading closeable-event closed',0,''),(604695,190209,'1683125852.36485','origin','block_type','1',0,''),(604696,190209,'1683125852.36485','origin','padding-top','30',0,''),(604697,190209,'1683125852.36485','origin','padding-left','30',0,''),(604698,190209,'1683125852.36485','origin','padding-right','30',0,''),(604699,190209,'1683125852.36485','origin','padding-bottom','30',0,''),(604700,190209,'1683125852.36485','origin','margin-bottom','20',0,''),(604701,190209,'1683125852.36485','origin','background-color','$content-bg-1',0,''),(604702,190209,'1683125852.36485','origin','style_class','hiding-box closeable-box',0,''),(604703,190209,'1683125852.36485','origin','color','$content-color-1',0,''),(604704,190210,'1683125852.366422','origin','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(604705,190210,'1683125852.366422','origin','style_class','closeable-heading closeable-event closed',0,''),(604706,190211,'1683125852.367732','origin','block_type','2',0,''),(604707,190211,'1683125852.367732','origin','style_class','closeable-content',0,''),(604708,190211,'1683125852.367732','origin','schema','2-2',0,'8356'),(604709,190212,'1683125852.36968','origin','padding-right','20',0,''),(604710,190212,'1683125852.36968','origin','padding-bottom','20',0,''),(604711,190212,'1683125852.36968','origin','padding-right','0',0,'8356'),(604712,190213,'1683125852.369745','origin','padding-left','20',0,''),(604713,190213,'1683125852.369745','origin','padding-bottom','20',0,''),(604714,190213,'1683125852.369745','origin','padding-left','0',0,'8356'),(604715,190214,'1683125852.37045','origin','padding-left','20',0,''),(604716,190214,'1683125852.37045','origin','padding-bottom','20',0,''),(604717,190214,'1683125852.37045','origin','padding-left','0',0,'8356'),(604718,190215,'1683125852.371233','origin','background-color','$content-bg-1',0,''),(604719,190215,'1683125852.371233','origin','block_type','1',0,''),(604720,190215,'1683125852.371233','origin','padding-top','30',0,''),(604721,190215,'1683125852.371233','origin','padding-left','30',0,''),(604722,190215,'1683125852.371233','origin','padding-right','30',0,''),(604723,190215,'1683125852.371233','origin','padding-bottom','30',0,''),(604724,190215,'1683125852.371233','origin','margin-bottom','20',0,''),(604725,190215,'1683125852.371233','origin','style_class','hiding-box',0,''),(604726,190215,'1683125852.371233','origin','color','$content-color-1',0,''),(604727,190216,'1683125852.37350','origin','block_type','1',0,''),(604728,190216,'1683125852.37350','origin','content','\\_',0,'3'),(604729,190216,'1683125852.37350','origin','border-top-width','1',0,'3'),(604730,190216,'1683125852.37350','origin','border-top-color','#e0e0e0',0,'3'),(604731,190216,'1683125852.37350','origin','display','block',0,'3'),(604732,190216,'1683125852.37350','origin','position','absolute',0,'3'),(604733,190216,'1683125852.37350','origin','top','19',0,'3'),(604734,190216,'1683125852.37350','origin','left','0',0,'3'),(604735,190216,'1683125852.37350','origin','right','0',0,'3'),(604736,190216,'1683125852.37350','origin','margin-top','-2',0,'3'),(604737,190216,'1683125852.37350','origin','position','relative',0,''),(604738,190217,'1683125852.374899','origin','box_align','2',0,''),(604739,190217,'1683125852.374899','origin','margin-bottom','10',0,''),(604740,190217,'1683125852.374899','origin','background-color','$content-bg-1',0,''),(604741,190217,'1683125852.374899','origin','position','relative',0,''),(604742,190218,'1683125852.375685','origin','background-color','$content-bg-2',0,''),(604743,190218,'1683125852.375685','origin','padding-top','10',0,''),(604744,190218,'1683125852.375685','origin','padding-left','10',0,''),(604745,190218,'1683125852.375685','origin','padding-right','10',0,''),(604746,190218,'1683125852.375685','origin','padding-bottom','10',0,''),(604747,190218,'1683125852.375685','origin','margin-top','10',0,''),(604748,190219,'1683125852.376557','origin','block_type','2',0,''),(604749,190219,'1683125852.376557','origin','schema','2-2',0,'8356'),(604750,190220,'1683125852.377637','origin','block_type','1',0,''),(604751,190220,'1683125852.377637','origin','padding-right','20',0,''),(604752,190220,'1683125852.377637','origin','padding-left','0',0,'8356'),(604753,190220,'1683125852.377637','origin','margin-bottom','20',0,'8356'),(604754,190220,'1683125852.377637','origin','padding-right','0',0,'8356'),(604755,190221,'1683125852.378829','origin','address_in','popup',0,''),(604756,190222,'1683125852.379375','origin','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(604757,190225,'1683125852.381183','origin','block_type','1',0,''),(604758,190225,'1683125852.381183','origin','padding-left','20',0,''),(604759,190225,'1683125852.381183','origin','padding-left','0',0,'8356'),(604760,190227,'1683125852.382635','origin','border-top-width','1',0,''),(604761,190227,'1683125852.382635','origin','border-top-color','#e0e0e0',0,''),(604762,190227,'1683125852.382635','origin','padding-top','13',0,''),(604763,190227,'1683125852.382635','origin','padding-bottom','10',0,''),(604764,190228,'1683125852.383516','origin','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(604765,190229,'1683125852.385278','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(604766,190230,'1683125852.386397','origin','margin-bottom','20',0,''),(604767,190230,'1683125852.386397','origin','style_class','hiding-box',0,''),(604768,190231,'1683125852.386970','origin','padding-top','30',0,''),(604769,190231,'1683125852.386970','origin','padding-left','30',0,''),(604770,190231,'1683125852.386970','origin','padding-right','30',0,''),(604771,190231,'1683125852.386970','origin','margin-top','20',0,''),(604772,190231,'1683125852.386970','origin','background-color','$content-bg-1',0,''),(604773,190231,'1683125852.386970','origin','padding-bottom','30',0,''),(604774,190231,'1683125852.386970','origin','margin-bottom','20',0,''),(604775,190231,'1683125852.386970','origin','color','$content-color-1',0,''),(604776,190232,'1683125852.38820','origin','block_type','1',0,''),(604777,190232,'1683125852.38820','origin','padding-top','30',0,''),(604778,190232,'1683125852.38820','origin','padding-left','30',0,''),(604779,190232,'1683125852.38820','origin','padding-right','30',0,''),(604780,190232,'1683125852.38820','origin','padding-bottom','23',0,''),(604781,190232,'1683125852.38820','origin','margin-bottom','20',0,''),(604782,190232,'1683125852.38820','origin','background-color','$content-bg-1',0,''),(604783,190232,'1683125852.38820','origin','style_class','hiding-box',0,''),(604784,190232,'1683125852.38820','origin','color','$content-color-1',0,''),(604785,190233,'1683125852.390244','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(604786,190234,'1683125852.391810','origin','block_type','2',0,''),(604787,190234,'1683125852.391810','origin','schema','2-2',0,'8356'),(604788,190235,'1683125852.393320','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(604789,190236,'1683125852.394747','origin','padding-right','20',0,''),(604790,190236,'1683125852.394747','origin','padding-right','0',0,'8356'),(604791,190236,'1683125852.394747','origin','padding-bottom','20',0,'8356'),(604792,190236,'1683125852.394747','origin','address_in','popup',0,''),(604793,190237,'1683125852.395767','origin','block_type','1',0,''),(604794,190237,'1683125852.395767','origin','padding-left','20',0,''),(604795,190237,'1683125852.395767','origin','padding-left','0',0,'8356'),(604796,190239,'1683125852.398588','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(604797,190240,'1683125852.400291','origin','block_type','1',0,''),(604798,190240,'1683125852.400291','origin','padding-top','30',0,''),(604799,190240,'1683125852.400291','origin','padding-left','30',0,''),(604800,190240,'1683125852.400291','origin','padding-right','30',0,''),(604801,190240,'1683125852.400291','origin','padding-bottom','30',0,''),(604802,190240,'1683125852.400291','origin','margin-bottom','20',0,''),(604803,190240,'1683125852.400291','origin','background-color','$content-bg-1',0,''),(604804,190240,'1683125852.400291','origin','color','$content-color-1',0,''),(604805,190243,'1683125852.403563','origin','block_type','1',0,''),(604806,190243,'1683125852.403563','origin','padding-top','20',0,''),(604807,190243,'1683125852.403563','origin','padding-left','20',0,''),(604808,190243,'1683125852.403563','origin','padding-right','20',0,''),(604809,190243,'1683125852.403563','origin','padding-bottom','20',0,''),(604810,190243,'1683125852.403563','origin','background-color','$content-bg-1',0,''),(604811,190243,'1683125852.403563','origin','style_class','order-summary',0,''),(604812,190243,'1683125852.403563','origin','color','$content-color-1',0,''),(604813,190244,'1683125852.405625','origin','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(604814,190244,'1683125852.405625','origin','text-align','center',0,''),(604815,190244,'1683125852.405625','origin','font-size','14',0,''),(604816,190244,'1683125852.405625','origin','color','$fade-color-1',0,''),(604817,190244,'1683125852.405625','origin','padding-top','10',0,''),(604818,190245,'1683125852.407666','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(604819,190246,'1683125852.40885','origin','hide_page','1',0,''),(604820,190246,'1683125852.40885','origin','hide_continue_button','1',0,''),(604821,190247,'1683125852.409688','origin','margin-bottom','10',0,''),(604822,190250,'73542','origin','block_type','1',0,''),(604823,190251,'73543','origin','margin-top','20',0,''),(604824,190252,'73544','origin','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(604825,190253,'73545','origin','link','products',0,''),(604826,190253,'73545','origin','margin-top','-33',0,''),(604827,190253,'73545','origin','float','right',0,''),(604828,190254,'73546','origin','block_type','2',0,''),(604829,190254,'73546','origin','margin-bottom','20',0,''),(604830,190254,'73546','origin','schema','2-2',0,'8349'),(604831,190255,'73547','origin','block_type','1',0,''),(604832,190255,'73547','origin','padding-right','20',0,''),(604833,190255,'73547','origin','padding-right','0',0,'8349'),(604834,190256,'73548','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(604835,190256,'73548','origin','clear','none',0,''),(604836,190258,'73550','origin','padding-left','20',0,''),(604837,190258,'73550','origin','block_type','1',0,''),(604838,190258,'73550','origin','padding-left','0',0,'8349'),(604839,190260,'73552','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(604840,190260,'73552','origin','clear','none',0,''),(604841,190261,'73553','origin','text-align','right',0,''),(604842,190261,'73553','origin','margin-bottom','20',0,''),(604843,190261,'73553','origin','margin-top','20',0,''),(604844,190262,'73554','origin','block_type','2',0,''),(604845,190262,'73554','origin','margin-bottom','20',0,''),(604846,190262,'73554','origin','schema','2-2',0,'8349'),(604847,190263,'73555','origin','block_type','1',0,''),(604848,190263,'73555','origin','padding-right','20',0,''),(604849,190263,'73555','origin','padding-right','0',0,'8349'),(604850,190265,'73557','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(604851,190265,'73557','origin','clear','none',0,''),(604852,190266,'73558','origin','block_type','1',0,''),(604853,190266,'73558','origin','padding-left','20',0,''),(604854,190266,'73558','origin','padding-left','0',0,'8349'),(604855,190267,'73559','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(604856,190267,'73559','origin','clear','none',0,''),(604857,190269,'73561','origin','margin-bottom','20',0,''),(604858,190269,'73561','origin','text-align','right',0,''),(604859,190271,'73576','origin','block_type','1',0,''),(604860,190272,'73577','origin','text-align','right',0,''),(604861,190272,'73577','origin','margin-bottom','20',0,''),(604862,190273,'73578','origin','block_type','2',0,''),(604863,190273,'73578','origin','margin-bottom','20',0,''),(604864,190273,'73578','origin','schema','2-2',0,'8349'),(604865,190274,'73579','origin','block_type','1',0,''),(604866,190274,'73579','origin','padding-right','20',0,''),(604867,190274,'73579','origin','padding-right','0',0,'8349'),(604868,190275,'73580','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(604869,190275,'73580','origin','clear','none',0,''),(604870,190277,'73582','origin','block_type','1',0,''),(604871,190277,'73582','origin','padding-left','20',0,''),(604872,190277,'73582','origin','padding-left','0',0,'8349'),(604873,190278,'73583','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(604874,190278,'73583','origin','clear','none',0,''),(604875,190280,'73585','origin','margin-bottom','20',0,''),(604876,190280,'73585','origin','text-align','right',0,''),(604877,190283,'73588','origin','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(604878,190284,'73563','origin','block_type','1',0,''),(604879,190285,'73564','origin','margin-bottom','20',0,''),(604880,190286,'73565','origin','margin-bottom','20',0,''),(604881,190286,'73565','origin','text-align','right',0,''),(604882,190287,'73566','origin','text-align','right',0,''),(604883,190287,'73566','origin','margin-bottom','20',0,''),(604884,190288,'73567','origin','block_type','2',0,''),(604885,190288,'73567','origin','margin-bottom','20',0,''),(604886,190288,'73567','origin','schema','2-2',0,'8349'),(604887,190289,'73568','origin','block_type','1',0,''),(604888,190289,'73568','origin','padding-right','20',0,''),(604889,190289,'73568','origin','padding-right','0',0,'8349'),(604890,190291,'73570','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(604891,190291,'73570','origin','clear','none',0,''),(604892,190292,'73571','origin','block_type','1',0,''),(604893,190292,'73571','origin','padding-left','20',0,''),(604894,190292,'73571','origin','padding-left','0',0,'8349'),(604895,190294,'73573','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(604896,190294,'73573','origin','clear','none',0,''),(604897,190295,'73574','origin','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(604898,190296,'73575','origin','margin-bottom','20',0,''),(604899,190297,'73589','origin','block_type','1',0,''),(604900,190298,'73590','origin','block_type','2',0,''),(604901,190298,'73590','origin','margin-bottom','20',0,''),(604902,190298,'73590','origin','schema','2-2',0,'8349'),(604903,190299,'73591','origin','block_type','1',0,''),(604904,190299,'73591','origin','padding-right','20',0,''),(604905,190299,'73591','origin','padding-right','0',0,'8349'),(604906,190301,'73593','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(604907,190301,'73593','origin','clear','none',0,''),(604908,190302,'73594','origin','block_type','1',0,''),(604909,190302,'73594','origin','padding-left','20',0,''),(604910,190302,'73594','origin','padding-left','0',0,'8349'),(604911,190304,'73596','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(604912,190304,'73596','origin','clear','none',0,''),(604913,190305,'73597','origin','margin-bottom','20',0,''),(604914,190306,'73598','origin','margin-bottom','20',0,''),(604915,190307,'73599','origin','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(604916,190308,'73600','origin','link','products',0,''),(604917,190308,'73600','origin','margin-top','-33',0,''),(604918,190308,'73600','origin','float','right',0,''),(604919,190309,'73601','origin','text-align','right',0,''),(604920,190309,'73601','origin','margin-bottom','20',0,''),(604921,190310,'73602','origin','margin-bottom','20',0,''),(604922,190310,'73602','origin','text-align','right',0,''),(604923,190311,'73603','origin','block_type','2',0,''),(604924,190311,'73603','origin','margin-bottom','20',0,''),(604925,190311,'73603','origin','schema','2-2',0,'8349'),(604926,190312,'73604','origin','block_type','1',0,''),(604927,190312,'73604','origin','padding-right','20',0,''),(604928,190312,'73604','origin','padding-right','0',0,'8349'),(604929,190313,'73605','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(604930,190313,'73605','origin','clear','none',0,''),(604931,190315,'73607','origin','padding-left','20',0,''),(604932,190315,'73607','origin','block_type','1',0,''),(604933,190315,'73607','origin','padding-left','0',0,'8349'),(604934,190316,'73608','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(604935,190316,'73608','origin','clear','none',0,''),(604936,190318,'73610','origin','text','##TEXT_CONFIRMATION##',0,''),(604937,190319,'73611','origin','text','##TEXT_CONFIRMATION##',0,''),(604938,190320,'73613','origin','text','##TEXT_CONFIRMATION##',0,''),(604939,190321,'73612','origin','text','##TEXT_CONFIRMATION##',0,''),(604940,190322,'73614','origin','text','##TEXT_CONFIRMATION##',0,''),(604941,190323,'73615','origin','text','##TEXT_CONFIRMATION##',0,''),(604942,190324,'73616','origin','block_type','2',0,''),(604943,190325,'73617','origin','block_type','1',0,''),(604944,190325,'73617','origin','padding-right','20',0,''),(604945,190326,'73618','origin','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(604946,190328,'73620','origin','block_type','1',0,''),(604947,190328,'73620','origin','padding-left','20',0,''),(604948,190328,'73620','origin','padding-left','0',0,'8356'),(604949,190329,'73621','origin','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(604950,190331,'73623','origin','block_type','4',0,''),(604951,190331,'73623','origin','schema','4-2',0,'8377'),(604952,190331,'73623','origin','padding-top','20',0,''),(604953,190332,'73624','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(604954,190332,'73624','origin','text-align','right',0,''),(604955,190332,'73624','origin','padding-top','10',0,''),(604956,190332,'73624','origin','font_size_measure','em',0,''),(604957,190332,'73624','origin','font-size','1.2',0,''),(604958,190333,'73625','origin','text-align','right',0,''),(604959,190334,'73626','origin','block_type','2',0,''),(604960,190335,'73627','origin','block_type','1',0,''),(604961,190335,'73627','origin','padding-right','20',0,''),(604962,190335,'73627','origin','padding-right','0',0,'8356'),(604963,190336,'73628','origin','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(604964,190338,'73630','origin','block_type','1',0,''),(604965,190338,'73630','origin','padding-right','0',0,'8356'),(604966,190338,'73630','origin','padding-left','20',0,''),(604967,190341,'73633','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(604968,190343,'73635','origin','block_type','2',0,''),(604969,190344,'73636','origin','block_type','1',0,''),(604970,190344,'73636','origin','padding-right','20',0,''),(604971,190346,'73638','origin','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(604972,190347,'73639','origin','block_type','1',0,''),(604973,190347,'73639','origin','padding-left','20',0,''),(604974,190347,'73639','origin','padding-left','0',0,'8356'),(604975,190348,'73640','origin','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(604976,190350,'73642','origin','block_type','4',0,''),(604977,190350,'73642','origin','schema','4-2',0,'8377'),(604978,190351,'73643','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(604979,190351,'73643','origin','text-align','right',0,''),(604980,190351,'73643','origin','padding-top','10',0,''),(604981,190351,'73643','origin','font_size_measure','em',0,''),(604982,190351,'73643','origin','font-size','1.2',0,''),(604983,190352,'73644','origin','text-align','right',0,''),(604984,190353,'73645','origin','block_type','2',0,''),(604985,190354,'73646','origin','block_type','1',0,''),(604986,190354,'73646','origin','padding-right','20',0,''),(604987,190354,'73646','origin','padding-right','0',0,'8356'),(604988,190356,'73648','origin','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(604989,190357,'73649','origin','block_type','1',0,''),(604990,190357,'73649','origin','padding-right','0',0,'8356'),(604991,190357,'73649','origin','padding-left','20',0,''),(604992,190359,'73651','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(604993,190362,'73654','origin','block_type','4',0,''),(604994,190362,'73654','origin','schema','4-2',0,'8377'),(604995,190363,'73655','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(604996,190363,'73655','origin','text-align','right',0,''),(604997,190363,'73655','origin','padding-top','10',0,''),(604998,190363,'73655','origin','font_size_measure','em',0,''),(604999,190363,'73655','origin','font-size','1.2',0,''),(605000,190364,'73656','origin','text-align','right',0,''),(605001,190365,'73657','origin','block_type','2',0,''),(605002,190366,'73658','origin','block_type','1',0,''),(605003,190366,'73658','origin','padding-right','20',0,''),(605004,190368,'73660','origin','block_type','1',0,''),(605005,190368,'73660','origin','padding-left','20',0,''),(605006,190368,'73660','origin','padding-left','0',0,'8356'),(605007,190369,'73661','origin','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605008,190371,'73663','origin','block_type','4',0,''),(605009,190371,'73663','origin','schema','4-2',0,'8377'),(605010,190372,'73664','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(605011,190372,'73664','origin','text-align','right',0,''),(605012,190372,'73664','origin','padding-top','10',0,''),(605013,190372,'73664','origin','font_size_measure','em',0,''),(605014,190372,'73664','origin','font-size','1.2',0,''),(605015,190373,'73665','origin','text-align','right',0,''),(605016,190374,'73666','origin','block_type','2',0,''),(605017,190375,'73667','origin','block_type','1',0,''),(605018,190375,'73667','origin','padding-right','20',0,''),(605019,190377,'73669','origin','block_type','1',0,''),(605020,190377,'73669','origin','padding-left','20',0,''),(605021,190377,'73669','origin','padding-left','0',0,'8356'),(605022,190379,'73671','origin','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605023,190380,'73672','origin','text','##DELIVERY_DETAILS##',0,''),(605024,190381,'73673','origin','text','##DELIVERY_DETAILS##',0,''),(605025,190382,'73675','origin','text','##CONTACT_INFORMATION##',0,''),(605026,190383,'73674','origin','text','##CONTACT_INFORMATION##',0,''),(605027,190384,'73676','origin','text','##DELIVERY_DETAILS##',0,''),(605028,190385,'73677','origin','text','##DELIVERY_DETAILS##',0,''),(605029,190386,'73678','origin','block_type','1',0,''),(605030,190386,'73678','origin','background-color','$content-bg-2',0,''),(605031,190386,'73678','origin','padding-top','30',0,''),(605032,190386,'73678','origin','padding-bottom','30',0,''),(605033,190387,'73679','origin','block_type','4',0,''),(605034,190387,'73679','origin','schema','4-2',0,'8356'),(605035,190388,'73680','origin','block_type','1',0,''),(605036,190388,'73680','origin','padding-right','40',0,''),(605037,190388,'73680','origin','padding-right','0',0,'8356'),(605038,190389,'73682','origin','block_type','1',0,''),(605039,190389,'73682','origin','background-color','$content-bg-1',0,''),(605040,190389,'73682','origin','padding-top','30',0,''),(605041,190389,'73682','origin','padding-left','30',0,''),(605042,190389,'73682','origin','padding-right','30',0,''),(605043,190389,'73682','origin','padding-bottom','30',0,''),(605044,190389,'73682','origin','margin-bottom','20',0,''),(605045,190389,'73682','origin','style_class','hiding-box',0,''),(605046,190390,'73683','origin','margin-bottom','20',0,''),(605047,190391,'73684','origin','padding-top','10',0,''),(605048,190391,'73684','origin','padding-left','20',0,''),(605049,190391,'73684','origin','padding-right','20',0,''),(605050,190391,'73684','origin','margin-top','20',0,''),(605051,190391,'73684','origin','background-color','$content-bg-2',0,''),(605052,190391,'73684','origin','padding-bottom','8',0,''),(605053,190392,'73685','origin','block_type','1',0,''),(605054,190392,'73685','origin','background-color','$content-bg-1',0,''),(605055,190392,'73685','origin','padding-top','30',0,''),(605056,190392,'73685','origin','padding-left','30',0,''),(605057,190392,'73685','origin','padding-right','30',0,''),(605058,190392,'73685','origin','padding-bottom','14',0,''),(605059,190392,'73685','origin','margin-bottom','20',0,''),(605060,190392,'73685','origin','style_class','hiding-box closeable-box',0,''),(605061,190393,'73686','origin','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(605062,190393,'73686','origin','style_class','closeable-heading closeable-event closed',0,''),(605063,190394,'73687','origin','style_class','closeable-content',0,''),(605064,190394,'73687','origin','padding-bottom','20',0,''),(605065,190395,'73688','origin','background-color','$content-bg-1',0,''),(605066,190395,'73688','origin','block_type','1',0,''),(605067,190395,'73688','origin','padding-top','30',0,''),(605068,190395,'73688','origin','padding-left','30',0,''),(605069,190395,'73688','origin','padding-right','30',0,''),(605070,190395,'73688','origin','padding-bottom','30',0,''),(605071,190395,'73688','origin','margin-bottom','20',0,''),(605072,190395,'73688','origin','style_class','hiding-box',0,''),(605073,190396,'73689','origin','block_type','1',0,''),(605074,190396,'73689','origin','content','\\_',0,'3'),(605075,190396,'73689','origin','border-top-width','1',0,'3'),(605076,190396,'73689','origin','border-top-color','$content-border-1',0,'3'),(605077,190396,'73689','origin','display','block',0,'3'),(605078,190396,'73689','origin','position','absolute',0,'3'),(605079,190396,'73689','origin','top','19',0,'3'),(605080,190396,'73689','origin','left','0',0,'3'),(605081,190396,'73689','origin','right','0',0,'3'),(605082,190396,'73689','origin','margin-top','-2',0,'3'),(605083,190396,'73689','origin','position','relative',0,''),(605084,190397,'73690','origin','box_align','2',0,''),(605085,190397,'73690','origin','margin-bottom','10',0,''),(605086,190397,'73690','origin','background-color','$content-bg-1',0,''),(605087,190397,'73690','origin','position','relative',0,''),(605088,190398,'73691','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(605089,190399,'73692','origin','block_type','2',0,''),(605090,190399,'73692','origin','schema','2-2',0,'8356'),(605091,190400,'73693','origin','block_type','1',0,''),(605092,190400,'73693','origin','padding-right','20',0,''),(605093,190400,'73693','origin','padding-left','0',0,'8356'),(605094,190400,'73693','origin','margin-bottom','20',0,'8356'),(605095,190403,'73696','origin','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(605096,190404,'73697','origin','block_type','1',0,''),(605097,190404,'73697','origin','padding-left','20',0,''),(605098,190404,'73697','origin','padding-left','0',0,'8356'),(605099,190405,'73698','origin','border-top-width','1',0,''),(605100,190405,'73698','origin','border-top-color','$content-border-1',0,''),(605101,190405,'73698','origin','padding-top','13',0,''),(605102,190405,'73698','origin','padding-bottom','10',0,''),(605103,190406,'73699','origin','background-color','$content-bg-2',0,''),(605104,190406,'73699','origin','padding-top','10',0,''),(605105,190406,'73699','origin','padding-left','10',0,''),(605106,190406,'73699','origin','padding-right','10',0,''),(605107,190406,'73699','origin','padding-bottom','10',0,''),(605108,190406,'73699','origin','margin-top','10',0,''),(605109,190407,'73700','origin','block_type','1',0,''),(605110,190407,'73700','origin','padding-top','20',0,''),(605111,190407,'73700','origin','padding-left','20',0,''),(605112,190407,'73700','origin','padding-right','20',0,''),(605113,190407,'73700','origin','padding-bottom','20',0,''),(605114,190407,'73700','origin','background-color','$content-bg-1',0,''),(605115,190407,'73700','origin','style_class','order-summary',0,''),(605116,190408,'73701','origin','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(605117,190408,'73701','origin','text-align','center',0,''),(605118,190408,'73701','origin','font-size','14',0,''),(605119,190408,'73701','origin','color','$fade-color-1',0,''),(605120,190408,'73701','origin','padding-top','10',0,''),(605121,190410,'115999','origin','hide_continue_button','1',0,''),(605122,190411,'73703','origin','block_type','1',0,''),(605123,190411,'73703','origin','background-color','$content-bg-2',0,''),(605124,190411,'73703','origin','padding-top','30',0,''),(605125,190411,'73703','origin','padding-bottom','30',0,''),(605126,190411,'73703','origin','color','$content-color-2',0,''),(605127,190412,'73704','origin','block_type','4',0,''),(605128,190413,'73705','origin','block_type','1',0,''),(605129,190413,'73705','origin','padding-right','40',0,''),(605130,190414,'73706','origin','block_type','1',0,''),(605131,190414,'73706','origin','background-color','$content-bg-1',0,''),(605132,190414,'73706','origin','padding-top','30',0,''),(605133,190414,'73706','origin','padding-left','30',0,''),(605134,190414,'73706','origin','padding-right','30',0,''),(605135,190414,'73706','origin','padding-bottom','30',0,''),(605136,190414,'73706','origin','margin-bottom','20',0,''),(605137,190414,'73706','origin','style_class','hiding-box',0,''),(605138,190414,'73706','origin','color','$content-color-1',0,''),(605139,190415,'73707','origin','padding-top','10',0,''),(605140,190415,'73707','origin','padding-left','20',0,''),(605141,190415,'73707','origin','padding-right','20',0,''),(605142,190415,'73707','origin','margin-top','20',0,''),(605143,190415,'73707','origin','background-color','$content-bg-2',0,''),(605144,190415,'73707','origin','padding-bottom','8',0,''),(605145,190415,'73707','origin','color','$content-color-2',0,''),(605146,190416,'73708','origin','margin-bottom','20',0,''),(605147,190417,'73709','origin','block_type','1',0,''),(605148,190417,'73709','origin','padding-top','30',0,''),(605149,190417,'73709','origin','padding-left','30',0,''),(605150,190417,'73709','origin','padding-right','30',0,''),(605151,190417,'73709','origin','padding-bottom','23',0,''),(605152,190417,'73709','origin','margin-bottom','20',0,''),(605153,190417,'73709','origin','background-color','$content-bg-1',0,''),(605154,190417,'73709','origin','style_class','hiding-box',0,''),(605155,190417,'73709','origin','color','$content-color-1',0,''),(605156,190418,'73710','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(605157,190419,'73711','origin','block_type','2',0,''),(605158,190420,'73712','origin','padding-right','20',0,''),(605159,190421,'73713','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605160,190422,'73714','origin','block_type','1',0,''),(605161,190422,'73714','origin','padding-left','20',0,''),(605162,190423,'73715','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605163,190425,'73717','origin','block_type','1',0,''),(605164,190425,'73717','origin','padding-top','30',0,''),(605165,190425,'73717','origin','padding-left','30',0,''),(605166,190425,'73717','origin','padding-right','30',0,''),(605167,190425,'73717','origin','padding-bottom','14',0,''),(605168,190425,'73717','origin','margin-bottom','20',0,''),(605169,190425,'73717','origin','background-color','$content-bg-1',0,''),(605170,190425,'73717','origin','style_class','hiding-box closeable-box',0,''),(605171,190425,'73717','origin','color','$content-color-1',0,''),(605172,190426,'73718','origin','block_type','2',0,''),(605173,190426,'73718','origin','style_class','closeable-content',0,''),(605174,190427,'73719','origin','padding-right','20',0,''),(605175,190427,'73719','origin','padding-bottom','20',0,''),(605176,190428,'73720','origin','padding-left','20',0,''),(605177,190428,'73720','origin','padding-bottom','20',0,''),(605178,190429,'73721','origin','padding-left','20',0,''),(605179,190429,'73721','origin','padding-bottom','20',0,''),(605180,190430,'73722','origin','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(605181,190430,'73722','origin','style_class','closeable-heading closeable-event closed',0,''),(605182,190431,'73723','origin','block_type','1',0,''),(605183,190431,'73723','origin','background-color','$content-bg-1',0,''),(605184,190431,'73723','origin','padding-top','30',0,''),(605185,190431,'73723','origin','padding-left','30',0,''),(605186,190431,'73723','origin','padding-right','30',0,''),(605187,190431,'73723','origin','padding-bottom','14',0,''),(605188,190431,'73723','origin','margin-bottom','20',0,''),(605189,190431,'73723','origin','style_class','hiding-box closeable-box',0,''),(605190,190431,'73723','origin','color','$content-color-1',0,''),(605191,190432,'73724','origin','style_class','closeable-content',0,''),(605192,190432,'73724','origin','padding-bottom','20',0,''),(605193,190433,'73725','origin','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(605194,190433,'73725','origin','style_class','closeable-heading closeable-event closed',0,''),(605195,190434,'73726','origin','block_type','1',0,''),(605196,190434,'73726','origin','padding-top','20',0,''),(605197,190434,'73726','origin','padding-left','20',0,''),(605198,190434,'73726','origin','padding-right','20',0,''),(605199,190434,'73726','origin','padding-bottom','20',0,''),(605200,190434,'73726','origin','background-color','$content-bg-1',0,''),(605201,190434,'73726','origin','style_class','order-summary hiding-box',0,''),(605202,190434,'73726','origin','color','$content-color-1',0,''),(605203,190435,'73727','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(605204,190436,'73728','origin','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(605205,190436,'73728','origin','text-align','center',0,''),(605206,190436,'73728','origin','font-size','14',0,''),(605207,190436,'73728','origin','color','$fade-color-1',0,''),(605208,190436,'73728','origin','padding-top','10',0,''),(605209,190437,'73729','origin','margin-bottom','10',0,''),(605210,190439,'73731','origin','hide_page','1',0,''),(605211,190439,'73731','origin','hide_continue_button','1',0,''),(605212,190440,'73732','origin','block_type','1',0,''),(605213,190442,'73734','origin','block_type','4',0,''),(605214,190442,'73734','origin','schema','4-2',0,'8377'),(605215,190443,'73735','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(605216,190443,'73735','origin','text-align','right',0,''),(605217,190443,'73735','origin','padding-top','10',0,''),(605218,190443,'73735','origin','font_size_measure','em',0,''),(605219,190443,'73735','origin','font-size','1.2',0,''),(605220,190444,'73736','origin','text-align','right',0,''),(605221,190445,'73737','origin','block_type','2',0,''),(605222,190445,'73737','origin','schema','2-2',0,'8356'),(605223,190446,'73738','origin','block_type','1',0,''),(605224,190446,'73738','origin','padding-right','20',0,''),(605225,190446,'73738','origin','padding-right','0',0,'8356'),(605226,190448,'73740','origin','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(605227,190449,'73741','origin','block_type','1',0,''),(605228,190449,'73741','origin','padding-left','20',0,''),(605229,190449,'73741','origin','padding-left','0',0,'8356'),(605230,190451,'73743','origin','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605231,190452,'73744','origin','block_type','2',0,''),(605232,190452,'73744','origin','schema','2-2',0,'8356'),(605233,190453,'73745','origin','block_type','1',0,''),(605234,190453,'73745','origin','padding-right','20',0,''),(605235,190453,'73745','origin','padding-right','0',0,'8356'),(605236,190454,'73746','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605237,190456,'73748','origin','block_type','1',0,''),(605238,190456,'73748','origin','padding-left','20',0,''),(605239,190456,'73748','origin','padding-left','0',0,'8356'),(605240,190461,'73753','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605241,190462,'73754','origin','margin-bottom','20',0,''),(605242,190463,'73755','origin','block_type','1',0,''),(605243,190463,'73755','origin','background-color','$content-bg-2',0,''),(605244,190463,'73755','origin','padding-top','30',0,''),(605245,190463,'73755','origin','padding-bottom','30',0,''),(605246,190464,'73756','origin','block_type','4',0,''),(605247,190464,'73756','origin','schema','4-2',0,'8356'),(605248,190465,'73757','origin','block_type','1',0,''),(605249,190465,'73757','origin','padding-right','40',0,''),(605250,190465,'73757','origin','padding-right','0',0,'8356'),(605251,190466,'73758','origin','background-color','$content-bg-1',0,''),(605252,190466,'73758','origin','padding-top','30',0,''),(605253,190466,'73758','origin','padding-left','30',0,''),(605254,190466,'73758','origin','padding-right','30',0,''),(605255,190466,'73758','origin','padding-bottom','30',0,''),(605256,190466,'73758','origin','margin-bottom','20',0,''),(605257,190467,'73759','origin','block_type','1',0,''),(605258,190467,'73759','origin','background-color','$content-bg-1',0,''),(605259,190467,'73759','origin','padding-top','30',0,''),(605260,190467,'73759','origin','padding-left','30',0,''),(605261,190467,'73759','origin','padding-right','30',0,''),(605262,190467,'73759','origin','padding-bottom','14',0,''),(605263,190467,'73759','origin','margin-bottom','20',0,''),(605264,190467,'73759','origin','style_class','hiding-box closeable-box',0,''),(605265,190468,'73760','origin','style_class','closeable-content',0,''),(605266,190468,'73760','origin','padding-bottom','20',0,''),(605267,190469,'73761','origin','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(605268,190469,'73761','origin','style_class','closeable-heading closeable-event closed',0,''),(605269,190470,'73762','origin','block_type','1',0,''),(605270,190470,'73762','origin','background-color','$content-bg-1',0,''),(605271,190470,'73762','origin','padding-top','30',0,''),(605272,190470,'73762','origin','padding-left','30',0,''),(605273,190470,'73762','origin','padding-right','30',0,''),(605274,190470,'73762','origin','padding-bottom','30',0,''),(605275,190470,'73762','origin','margin-bottom','20',0,''),(605276,190470,'73762','origin','style_class','hiding-box',0,''),(605277,190471,'73763','origin','padding-top','10',0,''),(605278,190471,'73763','origin','padding-left','20',0,''),(605279,190471,'73763','origin','padding-right','20',0,''),(605280,190471,'73763','origin','margin-top','20',0,''),(605281,190471,'73763','origin','background-color','$content-bg-2',0,''),(605282,190471,'73763','origin','padding-bottom','8',0,''),(605283,190472,'73764','origin','margin-bottom','20',0,''),(605284,190473,'73765','origin','block_type','1',0,''),(605285,190473,'73765','origin','padding-top','30',0,''),(605286,190473,'73765','origin','padding-left','30',0,''),(605287,190473,'73765','origin','padding-right','30',0,''),(605288,190473,'73765','origin','padding-bottom','23',0,''),(605289,190473,'73765','origin','margin-bottom','20',0,''),(605290,190473,'73765','origin','background-color','$content-bg-1',0,''),(605291,190473,'73765','origin','style_class','hiding-box',0,''),(605292,190474,'73766','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(605293,190475,'73767','origin','block_type','2',0,''),(605294,190475,'73767','origin','schema','2-2',0,'8356'),(605295,190476,'73768','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605296,190477,'73769','origin','padding-right','20',0,''),(605297,190477,'73769','origin','padding-right','0',0,'8356'),(605298,190477,'73769','origin','padding-bottom','20',0,'8356'),(605299,190478,'73770','origin','block_type','1',0,''),(605300,190478,'73770','origin','padding-left','20',0,''),(605301,190478,'73770','origin','padding-left','0',0,'8356'),(605302,190480,'73772','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605303,190481,'73773','origin','block_type','1',0,''),(605304,190481,'73773','origin','padding-top','20',0,''),(605305,190481,'73773','origin','padding-left','20',0,''),(605306,190481,'73773','origin','padding-right','20',0,''),(605307,190481,'73773','origin','padding-bottom','20',0,''),(605308,190481,'73773','origin','background-color','$content-bg-1',0,''),(605309,190481,'73773','origin','style_class','order-summary',0,''),(605310,190483,'73775','origin','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(605311,190483,'73775','origin','text-align','center',0,''),(605312,190483,'73775','origin','font-size','14',0,''),(605313,190483,'73775','origin','color','$fade-color-1',0,''),(605314,190483,'73775','origin','padding-top','10',0,''),(605315,190484,'73776','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(605316,190485,'73777','origin','margin-bottom','10',0,''),(605317,190486,'73778','origin','block_type','2',0,''),(605318,190487,'73779','origin','block_type','1',0,''),(605319,190487,'73779','origin','padding-left','0',0,'8356'),(605320,190487,'73779','origin','padding-right','20',0,''),(605321,190489,'73781','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605322,190490,'73782','origin','block_type','1',0,''),(605323,190490,'73782','origin','padding-left','20',0,''),(605324,190490,'73782','origin','padding-left','0',0,'8356'),(605325,190495,'73787','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605326,190496,'73788','origin','block_type','4',0,''),(605327,190496,'73788','origin','schema','4-2',0,'8377'),(605328,190496,'73788','origin','padding-top','20',0,''),(605329,190497,'73789','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(605330,190497,'73789','origin','text-align','right',0,''),(605331,190497,'73789','origin','padding-top','10',0,''),(605332,190497,'73789','origin','font_size_measure','em',0,''),(605333,190497,'73789','origin','font-size','1.2',0,''),(605334,190498,'73790','origin','text-align','right',0,''),(605335,190499,'73791','origin','block_type','2',0,''),(605336,190500,'73792','origin','block_type','1',0,''),(605337,190500,'73792','origin','padding-left','0',0,'8356'),(605338,190500,'73792','origin','padding-right','20',0,''),(605339,190502,'73794','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605340,190503,'73795','origin','block_type','1',0,''),(605341,190503,'73795','origin','padding-left','20',0,''),(605342,190503,'73795','origin','padding-left','0',0,'8356'),(605343,190505,'73797','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605344,190509,'73801','origin','block_type','4',0,''),(605345,190509,'73801','origin','schema','4-2',0,'8377'),(605346,190510,'73802','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(605347,190510,'73802','origin','text-align','right',0,''),(605348,190510,'73802','origin','padding-top','10',0,''),(605349,190510,'73802','origin','font_size_measure','em',0,''),(605350,190510,'73802','origin','font-size','1.2',0,''),(605351,190511,'73803','origin','text-align','right',0,''),(605352,190512,'73804','origin','block_type','4',0,''),(605353,190512,'73804','origin','schema','4-2',0,'8377'),(605354,190513,'73805','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(605355,190513,'73805','origin','text-align','right',0,''),(605356,190513,'73805','origin','padding-top','10',0,''),(605357,190513,'73805','origin','font_size_measure','em',0,''),(605358,190513,'73805','origin','font-size','1.2',0,''),(605359,190514,'73806','origin','text-align','right',0,''),(605360,190515,'73807','origin','block_type','2',0,''),(605361,190516,'73808','origin','block_type','1',0,''),(605362,190516,'73808','origin','padding-left','0',0,'8356'),(605363,190516,'73808','origin','padding-right','20',0,''),(605364,190517,'73809','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605365,190519,'73811','origin','block_type','1',0,''),(605366,190519,'73811','origin','padding-left','20',0,''),(605367,190519,'73811','origin','padding-left','0',0,'8356'),(605368,190524,'73816','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605369,190525,'73817','origin','block_type','4',0,''),(605370,190525,'73817','origin','schema','4-2',0,'8377'),(605371,190526,'73818','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(605372,190526,'73818','origin','text-align','right',0,''),(605373,190526,'73818','origin','padding-top','10',0,''),(605374,190526,'73818','origin','font_size_measure','em',0,''),(605375,190526,'73818','origin','font-size','1.2',0,''),(605376,190527,'73819','origin','text-align','right',0,''),(605377,190528,'73820','origin','block_type','2',0,''),(605378,190529,'73821','origin','block_type','1',0,''),(605379,190529,'73821','origin','padding-left','0',0,'8356'),(605380,190529,'73821','origin','padding-right','20',0,''),(605381,190531,'73823','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605382,190532,'73824','origin','block_type','1',0,''),(605383,190532,'73824','origin','padding-left','20',0,''),(605384,190532,'73824','origin','padding-left','0',0,'8356'),(605385,190536,'73828','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605386,190538,'73830','origin','text','##PAYMENT_DETAILS##',0,''),(605387,190539,'73831','origin','text','##PAYMENT_DETAILS##',0,''),(605388,190540,'73832','origin','text','##PAYMENT_DETAILS##',0,''),(605389,190541,'73833','origin','text','##PAYMENT_DETAILS##',0,''),(605390,190542,'73834','origin','text','##PAYMENT_DETAILS##',0,''),(605391,190543,'73835','origin','text','##PAYMENT_DETAILS##',0,''),(605392,190544,'73836','origin','block_type','1',0,''),(605393,190544,'73836','origin','background-color','$content-bg-2',0,''),(605394,190544,'73836','origin','padding-top','30',0,''),(605395,190544,'73836','origin','padding-bottom','30',0,''),(605396,190545,'73837','origin','block_type','4',0,''),(605397,190545,'73837','origin','schema','4-2',0,'8356'),(605398,190546,'73838','origin','block_type','1',0,''),(605399,190546,'73838','origin','padding-right','40',0,''),(605400,190546,'73838','origin','padding-right','0',0,'8356'),(605401,190547,'73839','origin','block_type','1',0,''),(605402,190547,'73839','origin','background-color','$content-bg-1',0,''),(605403,190547,'73839','origin','padding-top','30',0,''),(605404,190547,'73839','origin','padding-left','30',0,''),(605405,190547,'73839','origin','padding-right','30',0,''),(605406,190547,'73839','origin','padding-bottom','30',0,''),(605407,190547,'73839','origin','margin-bottom','20',0,''),(605408,190547,'73839','origin','style_class','hiding-box',0,''),(605409,190548,'73840','origin','padding-top','10',0,''),(605410,190548,'73840','origin','padding-left','20',0,''),(605411,190548,'73840','origin','padding-right','20',0,''),(605412,190548,'73840','origin','margin-top','20',0,''),(605413,190548,'73840','origin','background-color','$content-bg-2',0,''),(605414,190548,'73840','origin','padding-bottom','8',0,''),(605415,190549,'73841','origin','margin-bottom','20',0,''),(605416,190550,'73842','origin','background-color','$content-bg-1',0,''),(605417,190550,'73842','origin','block_type','1',0,''),(605418,190550,'73842','origin','padding-top','30',0,''),(605419,190550,'73842','origin','padding-left','30',0,''),(605420,190550,'73842','origin','padding-right','30',0,''),(605421,190550,'73842','origin','padding-bottom','30',0,''),(605422,190550,'73842','origin','margin-bottom','20',0,''),(605423,190550,'73842','origin','style_class','hiding-box',0,''),(605424,190551,'73843','origin','block_type','1',0,''),(605425,190551,'73843','origin','content','\\_',0,'3'),(605426,190551,'73843','origin','border-top-width','1',0,'3'),(605427,190551,'73843','origin','border-top-color','$content-border-1',0,'3'),(605428,190551,'73843','origin','display','block',0,'3'),(605429,190551,'73843','origin','position','absolute',0,'3'),(605430,190551,'73843','origin','top','19',0,'3'),(605431,190551,'73843','origin','left','0',0,'3'),(605432,190551,'73843','origin','right','0',0,'3'),(605433,190551,'73843','origin','margin-top','-2',0,'3'),(605434,190551,'73843','origin','position','relative',0,''),(605435,190552,'73844','origin','box_align','2',0,''),(605436,190552,'73844','origin','margin-bottom','10',0,''),(605437,190552,'73844','origin','background-color','$content-bg-1',0,''),(605438,190552,'73844','origin','position','relative',0,''),(605439,190553,'73845','origin','background-color','$content-bg-2',0,''),(605440,190553,'73845','origin','padding-top','10',0,''),(605441,190553,'73845','origin','padding-left','10',0,''),(605442,190553,'73845','origin','padding-right','10',0,''),(605443,190553,'73845','origin','padding-bottom','10',0,''),(605444,190553,'73845','origin','margin-top','10',0,''),(605445,190554,'73846','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(605446,190555,'73847','origin','block_type','2',0,''),(605447,190555,'73847','origin','schema','2-2',0,'8356'),(605448,190556,'73848','origin','block_type','1',0,''),(605449,190556,'73848','origin','padding-right','20',0,''),(605450,190556,'73848','origin','padding-left','0',0,'8356'),(605451,190556,'73848','origin','margin-bottom','20',0,'8356'),(605452,190559,'73851','origin','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(605453,190560,'73852','origin','block_type','1',0,''),(605454,190560,'73852','origin','padding-left','20',0,''),(605455,190560,'73852','origin','padding-left','0',0,'8356'),(605456,190562,'73854','origin','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(605457,190563,'73855','origin','border-top-width','1',0,''),(605458,190563,'73855','origin','border-top-color','$content-border-1',0,''),(605459,190563,'73855','origin','padding-top','13',0,''),(605460,190563,'73855','origin','padding-bottom','10',0,''),(605461,190564,'73856','origin','block_type','1',0,''),(605462,190564,'73856','origin','background-color','$content-bg-1',0,''),(605463,190564,'73856','origin','padding-top','30',0,''),(605464,190564,'73856','origin','padding-left','30',0,''),(605465,190564,'73856','origin','padding-right','30',0,''),(605466,190564,'73856','origin','padding-bottom','14',0,''),(605467,190564,'73856','origin','margin-bottom','20',0,''),(605468,190564,'73856','origin','style_class','hiding-box closeable-box',0,''),(605469,190565,'73857','origin','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(605470,190565,'73857','origin','style_class','closeable-heading closeable-event closed',0,''),(605471,190566,'73858','origin','style_class','closeable-content',0,''),(605472,190566,'73858','origin','padding-bottom','20',0,''),(605473,190567,'73860','origin','block_type','1',0,''),(605474,190567,'73860','origin','padding-top','30',0,''),(605475,190567,'73860','origin','padding-left','30',0,''),(605476,190567,'73860','origin','padding-right','30',0,''),(605477,190567,'73860','origin','padding-bottom','23',0,''),(605478,190567,'73860','origin','margin-bottom','20',0,''),(605479,190567,'73860','origin','background-color','$content-bg-1',0,''),(605480,190567,'73860','origin','style_class','hiding-box',0,''),(605481,190568,'73861','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(605482,190569,'73862','origin','block_type','2',0,''),(605483,190569,'73862','origin','schema','2-2',0,'8356'),(605484,190570,'73863','origin','padding-right','20',0,''),(605485,190570,'73863','origin','padding-right','0',0,'8356'),(605486,190570,'73863','origin','padding-bottom','20',0,'8356'),(605487,190571,'73864','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605488,190572,'73865','origin','block_type','1',0,''),(605489,190572,'73865','origin','padding-left','20',0,''),(605490,190572,'73865','origin','padding-left','0',0,'8356'),(605491,190574,'73867','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605492,190575,'73868','origin','block_type','1',0,''),(605493,190575,'73868','origin','padding-top','20',0,''),(605494,190575,'73868','origin','padding-left','20',0,''),(605495,190575,'73868','origin','padding-right','20',0,''),(605496,190575,'73868','origin','padding-bottom','20',0,''),(605497,190575,'73868','origin','background-color','$content-bg-1',0,''),(605498,190575,'73868','origin','style_class','order-summary',0,''),(605499,190576,'73869','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(605500,190577,'73870','origin','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(605501,190577,'73870','origin','text-align','center',0,''),(605502,190577,'73870','origin','font-size','14',0,''),(605503,190577,'73870','origin','color','$fade-color-1',0,''),(605504,190577,'73870','origin','padding-top','10',0,''),(605505,190578,'73871','origin','margin-bottom','10',0,''),(605506,190580,'115996','origin','hide_continue_button','1',0,''),(605507,190581,'73873','origin','block_type','1',0,''),(605508,190581,'73873','origin','background-color','$content-bg-2',0,''),(605509,190581,'73873','origin','padding-top','30',0,''),(605510,190581,'73873','origin','padding-bottom','30',0,''),(605511,190582,'73874','origin','block_type','4',0,''),(605512,190582,'73874','origin','schema','4-2',0,'8356'),(605513,190583,'73875','origin','block_type','1',0,''),(605514,190583,'73875','origin','padding-right','40',0,''),(605515,190583,'73875','origin','padding-right','0',0,'8356'),(605516,190584,'73876','origin','background-color','$content-bg-1',0,''),(605517,190584,'73876','origin','padding-top','30',0,''),(605518,190584,'73876','origin','padding-left','30',0,''),(605519,190584,'73876','origin','padding-right','30',0,''),(605520,190584,'73876','origin','padding-bottom','30',0,''),(605521,190584,'73876','origin','margin-bottom','20',0,''),(605522,190585,'73877','origin','block_type','1',0,''),(605523,190585,'73877','origin','background-color','$content-bg-1',0,''),(605524,190585,'73877','origin','padding-top','30',0,''),(605525,190585,'73877','origin','padding-left','30',0,''),(605526,190585,'73877','origin','padding-right','30',0,''),(605527,190585,'73877','origin','padding-bottom','30',0,''),(605528,190585,'73877','origin','margin-bottom','20',0,''),(605529,190585,'73877','origin','style_class','hiding-box',0,''),(605530,190586,'73878','origin','margin-bottom','20',0,''),(605531,190587,'73879','origin','padding-top','10',0,''),(605532,190587,'73879','origin','padding-left','20',0,''),(605533,190587,'73879','origin','padding-right','20',0,''),(605534,190587,'73879','origin','margin-top','20',0,''),(605535,190587,'73879','origin','background-color','$content-bg-2',0,''),(605536,190587,'73879','origin','padding-bottom','8',0,''),(605537,190588,'73880','origin','background-color','$content-bg-1',0,''),(605538,190588,'73880','origin','block_type','1',0,''),(605539,190588,'73880','origin','padding-top','30',0,''),(605540,190588,'73880','origin','padding-left','30',0,''),(605541,190588,'73880','origin','padding-right','30',0,''),(605542,190588,'73880','origin','padding-bottom','30',0,''),(605543,190588,'73880','origin','margin-bottom','20',0,''),(605544,190588,'73880','origin','style_class','hiding-box',0,''),(605545,190589,'73881','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(605546,190590,'73882','origin','background-color','$content-bg-2',0,''),(605547,190590,'73882','origin','padding-top','10',0,''),(605548,190590,'73882','origin','padding-left','10',0,''),(605549,190590,'73882','origin','padding-right','10',0,''),(605550,190590,'73882','origin','padding-bottom','10',0,''),(605551,190590,'73882','origin','margin-top','10',0,''),(605552,190591,'73883','origin','block_type','1',0,''),(605553,190591,'73883','origin','content','\\_',0,'3'),(605554,190591,'73883','origin','border-top-width','1',0,'3'),(605555,190591,'73883','origin','border-top-color','$content-border-1',0,'3'),(605556,190591,'73883','origin','display','block',0,'3'),(605557,190591,'73883','origin','position','absolute',0,'3'),(605558,190591,'73883','origin','top','19',0,'3'),(605559,190591,'73883','origin','left','0',0,'3'),(605560,190591,'73883','origin','right','0',0,'3'),(605561,190591,'73883','origin','margin-top','-2',0,'3'),(605562,190591,'73883','origin','position','relative',0,''),(605563,190592,'73884','origin','box_align','2',0,''),(605564,190592,'73884','origin','margin-bottom','10',0,''),(605565,190592,'73884','origin','background-color','$content-bg-1',0,''),(605566,190592,'73884','origin','position','relative',0,''),(605567,190593,'73885','origin','block_type','2',0,''),(605568,190593,'73885','origin','schema','2-2',0,'8356'),(605569,190594,'73886','origin','block_type','1',0,''),(605570,190594,'73886','origin','padding-right','20',0,''),(605571,190594,'73886','origin','padding-left','0',0,'8356'),(605572,190594,'73886','origin','margin-bottom','20',0,'8356'),(605573,190597,'73889','origin','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(605574,190598,'73890','origin','block_type','1',0,''),(605575,190598,'73890','origin','padding-left','20',0,''),(605576,190598,'73890','origin','padding-left','0',0,'8356'),(605577,190600,'73892','origin','border-top-width','1',0,''),(605578,190600,'73892','origin','border-top-color','$content-border-1',0,''),(605579,190600,'73892','origin','padding-top','13',0,''),(605580,190600,'73892','origin','padding-bottom','10',0,''),(605581,190601,'73893','origin','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(605582,190602,'73894','origin','block_type','1',0,''),(605583,190602,'73894','origin','padding-top','30',0,''),(605584,190602,'73894','origin','padding-left','30',0,''),(605585,190602,'73894','origin','padding-right','30',0,''),(605586,190602,'73894','origin','padding-bottom','23',0,''),(605587,190602,'73894','origin','margin-bottom','20',0,''),(605588,190602,'73894','origin','background-color','$content-bg-1',0,''),(605589,190602,'73894','origin','style_class','hiding-box',0,''),(605590,190603,'73895','origin','block_type','2',0,''),(605591,190603,'73895','origin','schema','2-2',0,'8356'),(605592,190604,'73896','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605593,190605,'73897','origin','padding-right','20',0,''),(605594,190605,'73897','origin','padding-right','0',0,'8356'),(605595,190605,'73897','origin','padding-bottom','20',0,'8356'),(605596,190606,'73898','origin','block_type','1',0,''),(605597,190606,'73898','origin','padding-left','20',0,''),(605598,190606,'73898','origin','padding-left','0',0,'8356'),(605599,190607,'73899','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605600,190609,'73901','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(605601,190610,'73902','origin','block_type','1',0,''),(605602,190610,'73902','origin','background-color','$content-bg-1',0,''),(605603,190610,'73902','origin','padding-top','30',0,''),(605604,190610,'73902','origin','padding-left','30',0,''),(605605,190610,'73902','origin','padding-right','30',0,''),(605606,190610,'73902','origin','padding-bottom','14',0,''),(605607,190610,'73902','origin','margin-bottom','20',0,''),(605608,190610,'73902','origin','style_class','hiding-box closeable-box',0,''),(605609,190611,'73903','origin','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(605610,190611,'73903','origin','style_class','closeable-heading closeable-event closed',0,''),(605611,190612,'73904','origin','style_class','closeable-content',0,''),(605612,190612,'73904','origin','padding-bottom','20',0,''),(605613,190613,'73905','origin','block_type','1',0,''),(605614,190613,'73905','origin','padding-top','30',0,''),(605615,190613,'73905','origin','padding-left','30',0,''),(605616,190613,'73905','origin','padding-right','30',0,''),(605617,190613,'73905','origin','padding-bottom','14',0,''),(605618,190613,'73905','origin','margin-bottom','20',0,''),(605619,190613,'73905','origin','background-color','$content-bg-1',0,''),(605620,190613,'73905','origin','style_class','hiding-box closeable-box',0,''),(605621,190614,'73906','origin','block_type','2',0,''),(605622,190614,'73906','origin','style_class','closeable-content',0,''),(605623,190614,'73906','origin','schema','2-2',0,'8356'),(605624,190615,'73907','origin','padding-right','20',0,''),(605625,190615,'73907','origin','padding-bottom','20',0,''),(605626,190615,'73907','origin','padding-right','0',0,'8356'),(605627,190616,'73908','origin','padding-left','20',0,''),(605628,190616,'73908','origin','padding-bottom','20',0,''),(605629,190616,'73908','origin','padding-left','0',0,'8356'),(605630,190617,'73909','origin','padding-left','20',0,''),(605631,190617,'73909','origin','padding-bottom','20',0,''),(605632,190617,'73909','origin','padding-left','0',0,'8356'),(605633,190618,'73910','origin','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(605634,190618,'73910','origin','style_class','closeable-heading closeable-event closed',0,''),(605635,190619,'73911','origin','block_type','1',0,''),(605636,190619,'73911','origin','padding-top','20',0,''),(605637,190619,'73911','origin','padding-left','20',0,''),(605638,190619,'73911','origin','padding-right','20',0,''),(605639,190619,'73911','origin','padding-bottom','20',0,''),(605640,190619,'73911','origin','background-color','$content-bg-1',0,''),(605641,190619,'73911','origin','style_class','order-summary',0,''),(605642,190620,'73912','origin','margin-bottom','10',0,''),(605643,190621,'73913','origin','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(605644,190621,'73913','origin','text-align','center',0,''),(605645,190621,'73913','origin','font-size','14',0,''),(605646,190621,'73913','origin','color','$fade-color-1',0,''),(605647,190621,'73913','origin','padding-top','10',0,''),(605648,190622,'73914','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(605649,190624,'115998','origin','hide_continue_button','1',0,''),(605650,190625,'73916','origin','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(605651,190630,'73921','origin','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(605652,190631,'73923','origin','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(605653,190632,'73924','origin','style_class','order-summary',0,''),(605654,190632,'73924','origin','box_align','3',0,''),(605655,190632,'73924','origin','width','400',0,''),(605656,190634,'73922','origin','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(605657,190637,'73928','origin','block_type','1',0,''),(605658,190638,'73929','origin','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(605659,190639,'73930','origin','float','right',0,''),(605660,190639,'73930','origin','position','relative',0,''),(605661,190639,'73930','origin','z-index','1',0,''),(605662,190639,'73930','origin','top','30',0,''),(605663,190639,'73930','origin','margin-bottom','-20',0,''),(605664,190640,'73931','origin','margin-bottom','30',0,''),(605665,190641,'94704','origin','block_type','1',0,''),(605666,190642,'94705','origin','listing_type','Compare Products',0,''),(605667,190643,'94706','origin','block_type','1',0,''),(605668,190643,'94706','origin','style_class','item-holder',0,''),(605669,190643,'94706','origin','padding-top','10',0,''),(605670,190643,'94706','origin','padding-left','20',0,''),(605671,190643,'94706','origin','padding-right','20',0,''),(605672,190643,'94706','origin','padding-bottom','10',0,''),(605673,190643,'94706','origin','text-align','left',0,''),(605674,190646,'94709','origin','margin-bottom','10',0,''),(605675,190647,'94710','origin','block_type','5',0,''),(605676,190649,'94712','origin','clear','both',0,''),(605677,190650,'94713','origin','block_type','2',0,''),(605678,190651,'94714','origin','margin-bottom','7',0,''),(605679,190652,'94715','origin','text-align','right',0,''),(605680,190652,'94715','origin','margin-bottom','10',0,''),(605681,190652,'94715','origin','float','right',0,''),(605682,190653,'73932','origin','block_type','1',0,''),(605683,190653,'73932','origin','background-color','$content-bg-2',0,''),(605684,190653,'73932','origin','padding-bottom','30',0,''),(605685,190653,'73932','origin','color','$content-color-2',0,''),(605686,190654,'73933','origin','block_type','4',0,''),(605687,190654,'73933','origin','schema','4-2',0,'8356'),(605688,190655,'73934','origin','block_type','1',0,''),(605689,190655,'73934','origin','padding-right','40',0,''),(605690,190655,'73934','origin','padding-right','0',0,'8356'),(605691,190656,'73935','origin','block_type','1',0,''),(605692,190656,'73935','origin','padding-right','30',0,''),(605693,190656,'73935','origin','background-color','$content-bg-1',0,''),(605694,190656,'73935','origin','padding-top','20',0,''),(605695,190656,'73935','origin','padding-left','30',0,''),(605696,190656,'73935','origin','padding-bottom','20',0,''),(605697,190656,'73935','origin','padding-left','20',0,'8356'),(605698,190656,'73935','origin','padding-right','20',0,'8356'),(605699,190656,'73935','origin','color','$content-color-1',0,''),(605700,190657,'73936','origin','link','products',0,''),(605701,190657,'73936','origin','float','right',0,''),(605702,190657,'73936','origin','margin-top','-37',0,''),(605703,190659,'73938','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(605704,190660,'73939','origin','block_type','1',0,''),(605705,190660,'73939','origin','background-color','$content-bg-1',0,''),(605706,190660,'73939','origin','padding-top','20',0,''),(605707,190660,'73939','origin','padding-bottom','20',0,''),(605708,190660,'73939','origin','padding-left','30',0,''),(605709,190660,'73939','origin','padding-right','30',0,''),(605710,190660,'73939','origin','margin-bottom','20',0,''),(605711,190660,'73939','origin','color','$content-color-1',0,''),(605712,190661,'73940','origin','float','right',0,''),(605713,190661,'73940','origin','margin-top','-37',0,''),(605714,190661,'73940','origin','link','comments',0,''),(605715,190662,'73941','origin','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605716,190663,'73942','origin','hide_parents','2',0,''),(605717,190664,'73943','origin','block_type','2',0,''),(605718,190664,'73943','origin','margin-bottom','20',0,''),(605719,190664,'73943','origin','schema','2-2',0,'8349'),(605720,190664,'73943','origin','background-color','$content-bg-1',0,''),(605721,190664,'73943','origin','color','$content-color-1',0,''),(605722,190665,'73944','origin','block_type','1',0,''),(605723,190665,'73944','origin','border-right-width','20',0,''),(605724,190665,'73944','origin','border-right-color','$content-bg-2',0,''),(605725,190665,'73944','origin','margin-right','-10',0,''),(605726,190665,'73944','origin','padding-right','30',0,''),(605727,190665,'73944','origin','padding-top','20',0,''),(605728,190665,'73944','origin','padding-left','30',0,''),(605729,190665,'73944','origin','padding-bottom','20',0,''),(605730,190665,'73944','origin','border-right-width','0',0,'8356'),(605731,190665,'73944','origin','margin-right','0',0,'8356'),(605732,190665,'73944','origin','margin-bottom','20',0,'8356'),(605733,190665,'73944','origin','padding-left','20',0,'8356'),(605734,190665,'73944','origin','padding-right','20',0,'8356'),(605735,190666,'73945','origin','link','shipping_method',0,''),(605736,190666,'73945','origin','float','right',0,''),(605737,190666,'73945','origin','margin-top','-31',0,''),(605738,190668,'73947','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(605739,190668,'73947','origin','padding-top','20',0,''),(605740,190669,'73948','origin','link','contact_information',0,''),(605741,190669,'73948','origin','margin-top','-31',0,''),(605742,190669,'73948','origin','float','right',0,''),(605743,190670,'73949','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(605744,190670,'73949','origin','clear','none',0,''),(605745,190672,'73951','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(605746,190673,'73952','origin','link','shipping_address',0,''),(605747,190673,'73952','origin','float','right',0,''),(605748,190673,'73952','origin','margin-top','-31',0,''),(605749,190675,'73954','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(605750,190675,'73954','origin','clear','none',0,''),(605751,190676,'73955','origin','margin-bottom','20',0,''),(605752,190677,'73956','origin','block_type','1',0,''),(605753,190677,'73956','origin','padding-left','30',0,''),(605754,190677,'73956','origin','border-left-width','20',0,''),(605755,190677,'73956','origin','border-left-color','$content-bg-2',0,''),(605756,190677,'73956','origin','margin-left','-10',0,''),(605757,190677,'73956','origin','padding-right','30',0,''),(605758,190677,'73956','origin','padding-top','20',0,''),(605759,190677,'73956','origin','padding-bottom','20',0,''),(605760,190677,'73956','origin','border-left-width','0',0,'8356'),(605761,190678,'73957','origin','link','payment_method',0,''),(605762,190678,'73957','origin','float','right',0,''),(605763,190678,'73957','origin','margin-top','-31',0,''),(605764,190679,'73958','origin','link','billing_address',0,''),(605765,190679,'73958','origin','float','right',0,''),(605766,190679,'73958','origin','margin-top','-31',0,''),(605767,190681,'73960','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605768,190681,'73960','origin','clear','none',0,''),(605769,190682,'73961','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(605770,190683,'73962','origin','margin-bottom','20',0,''),(605771,190684,'73963','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605772,190684,'73963','origin','clear','none',0,''),(605773,190686,'73965','origin','block_type','1',0,''),(605774,190686,'73965','origin','padding-top','20',0,''),(605775,190686,'73965','origin','padding-left','20',0,''),(605776,190686,'73965','origin','padding-right','20',0,''),(605777,190686,'73965','origin','padding-bottom','20',0,''),(605778,190686,'73965','origin','background-color','$content-bg-1',0,''),(605779,190686,'73965','origin','style_class','order-summary2 hiding-box',0,''),(605780,190686,'73965','origin','color','$content-color-1',0,''),(605781,190687,'73966','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(605782,190688,'73967','origin','margin-bottom','20',0,''),(605783,190688,'73967','origin','text-align','right',0,''),(605784,190690,'73969','origin','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(605785,190691,'73970','origin','block_type','1',0,''),(605786,190691,'73970','origin','background-color','$content-bg-2',0,''),(605787,190691,'73970','origin','padding-bottom','30',0,''),(605788,190692,'73971','origin','block_type','4',0,''),(605789,190692,'73971','origin','schema','4-2',0,'8356'),(605790,190693,'73972','origin','block_type','1',0,''),(605791,190693,'73972','origin','padding-right','40',0,''),(605792,190693,'73972','origin','padding-right','0',0,'8356'),(605793,190694,'73973','origin','block_type','1',0,''),(605794,190694,'73973','origin','background-color','$content-bg-1',0,''),(605795,190694,'73973','origin','padding-top','20',0,''),(605796,190694,'73973','origin','padding-bottom','20',0,''),(605797,190694,'73973','origin','padding-left','30',0,''),(605798,190694,'73973','origin','padding-right','30',0,''),(605799,190694,'73973','origin','margin-bottom','20',0,''),(605800,190695,'73974','origin','hide_parents','2',0,''),(605801,190696,'73975','origin','float','right',0,''),(605802,190696,'73975','origin','margin-top','-37',0,''),(605803,190696,'73975','origin','link','comments',0,''),(605804,190697,'73976','origin','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605805,190698,'73977','origin','block_type','1',0,''),(605806,190698,'73977','origin','padding-right','30',0,''),(605807,190698,'73977','origin','background-color','$content-bg-1',0,''),(605808,190698,'73977','origin','padding-top','20',0,''),(605809,190698,'73977','origin','padding-left','30',0,''),(605810,190698,'73977','origin','padding-bottom','20',0,''),(605811,190698,'73977','origin','padding-left','20',0,'8356'),(605812,190698,'73977','origin','padding-right','20',0,'8356'),(605813,190699,'73978','origin','link','products',0,''),(605814,190699,'73978','origin','float','right',0,''),(605815,190699,'73978','origin','margin-top','-37',0,''),(605816,190700,'73979','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(605817,190702,'73981','origin','block_type','2',0,''),(605818,190702,'73981','origin','margin-bottom','20',0,''),(605819,190702,'73981','origin','schema','2-2',0,'8349'),(605820,190702,'73981','origin','background-color','$content-bg-1',0,''),(605821,190703,'73982','origin','block_type','1',0,''),(605822,190703,'73982','origin','border-right-width','20',0,''),(605823,190703,'73982','origin','border-right-color','$content-border-1',0,''),(605824,190703,'73982','origin','margin-right','-10',0,''),(605825,190703,'73982','origin','padding-right','30',0,''),(605826,190703,'73982','origin','padding-top','20',0,''),(605827,190703,'73982','origin','padding-left','30',0,''),(605828,190703,'73982','origin','padding-bottom','20',0,''),(605829,190703,'73982','origin','border-right-width','0',0,'8356'),(605830,190703,'73982','origin','margin-right','0',0,'8356'),(605831,190703,'73982','origin','margin-bottom','20',0,'8356'),(605832,190703,'73982','origin','padding-left','20',0,'8356'),(605833,190703,'73982','origin','padding-right','20',0,'8356'),(605834,190704,'73983','origin','link','shipping_address',0,''),(605835,190704,'73983','origin','float','right',0,''),(605836,190704,'73983','origin','margin-top','-31',0,''),(605837,190706,'73985','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(605838,190706,'73985','origin','clear','none',0,''),(605839,190707,'73986','origin','link','shipping_method',0,''),(605840,190707,'73986','origin','float','right',0,''),(605841,190707,'73986','origin','margin-top','-31',0,''),(605842,190708,'73987','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(605843,190708,'73987','origin','clear','none',0,''),(605844,190709,'73988','origin','margin-bottom','20',0,''),(605845,190710,'73989','origin','block_type','1',0,''),(605846,190710,'73989','origin','padding-left','30',0,''),(605847,190710,'73989','origin','border-left-width','20',0,''),(605848,190710,'73989','origin','border-left-color','$content-border-1',0,''),(605849,190710,'73989','origin','margin-left','-10',0,''),(605850,190710,'73989','origin','padding-right','30',0,''),(605851,190710,'73989','origin','padding-top','20',0,''),(605852,190710,'73989','origin','padding-bottom','20',0,''),(605853,190710,'73989','origin','border-left-width','0',0,'8356'),(605854,190713,'73992','origin','link','contact_information',0,''),(605855,190713,'73992','origin','margin-top','-31',0,''),(605856,190713,'73992','origin','float','right',0,''),(605857,190714,'73993','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(605858,190715,'73994','origin','block_type','1',0,''),(605859,190715,'73994','origin','padding-top','20',0,''),(605860,190715,'73994','origin','padding-left','20',0,''),(605861,190715,'73994','origin','padding-right','20',0,''),(605862,190715,'73994','origin','padding-bottom','20',0,''),(605863,190715,'73994','origin','background-color','$content-bg-1',0,''),(605864,190715,'73994','origin','style_class','order-summary',0,''),(605865,190716,'73995','origin','margin-bottom','20',0,''),(605866,190716,'73995','origin','text-align','right',0,''),(605867,190717,'73996','origin','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(605868,190718,'73997','origin','block_type','1',0,''),(605869,190718,'73997','origin','background-color','$content-bg-2',0,''),(605870,190718,'73997','origin','padding-bottom','30',0,''),(605871,190718,'73997','origin','color','$content-color-2',0,''),(605872,190719,'73998','origin','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(605873,190720,'73999','origin','block_type','4',0,''),(605874,190721,'74000','origin','block_type','1',0,''),(605875,190721,'74000','origin','padding-right','40',0,''),(605876,190722,'74001','origin','block_type','2',0,''),(605877,190722,'74001','origin','margin-bottom','20',0,''),(605878,190722,'74001','origin','schema','2-2',0,'8349'),(605879,190722,'74001','origin','background-color','$content-bg-1',0,''),(605880,190722,'74001','origin','color','$content-color-1',0,''),(605881,190723,'74002','origin','block_type','1',0,''),(605882,190723,'74002','origin','padding-right','0',0,'8349'),(605883,190723,'74002','origin','border-right-width','20',0,''),(605884,190723,'74002','origin','border-right-color','$content-bg-2',0,''),(605885,190723,'74002','origin','margin-right','-10',0,''),(605886,190723,'74002','origin','padding-right','30',0,''),(605887,190723,'74002','origin','padding-top','20',0,''),(605888,190723,'74002','origin','padding-left','30',0,''),(605889,190723,'74002','origin','padding-bottom','20',0,''),(605890,190724,'74003','origin','link','contact_information',0,''),(605891,190724,'74003','origin','margin-top','-37',0,''),(605892,190724,'74003','origin','float','right',0,''),(605893,190725,'74004','origin','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(605894,190725,'74004','origin','padding-top','20',0,''),(605895,190727,'74006','origin','block_type','1',0,''),(605896,190727,'74006','origin','padding-left','30',0,''),(605897,190727,'74006','origin','padding-left','0',0,'8349'),(605898,190727,'74006','origin','border-left-width','20',0,''),(605899,190727,'74006','origin','border-left-color','$content-bg-2',0,''),(605900,190727,'74006','origin','margin-left','-10',0,''),(605901,190727,'74006','origin','padding-right','30',0,''),(605902,190727,'74006','origin','padding-top','20',0,''),(605903,190727,'74006','origin','padding-bottom','20',0,''),(605904,190729,'74008','origin','link','payment_method',0,''),(605905,190729,'74008','origin','float','right',0,''),(605906,190729,'74008','origin','margin-top','-31',0,''),(605907,190730,'74009','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605908,190730,'74009','origin','clear','none',0,''),(605909,190731,'74010','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(605910,190732,'74011','origin','link','billing_address',0,''),(605911,190732,'74011','origin','float','right',0,''),(605912,190732,'74011','origin','margin-top','-31',0,''),(605913,190733,'74012','origin','margin-bottom','20',0,''),(605914,190734,'74013','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605915,190734,'74013','origin','clear','none',0,''),(605916,190735,'74014','origin','block_type','1',0,''),(605917,190735,'74014','origin','background-color','$content-bg-1',0,''),(605918,190735,'74014','origin','padding-top','20',0,''),(605919,190735,'74014','origin','padding-bottom','20',0,''),(605920,190735,'74014','origin','padding-left','30',0,''),(605921,190735,'74014','origin','padding-right','30',0,''),(605922,190735,'74014','origin','margin-bottom','20',0,''),(605923,190735,'74014','origin','color','$content-color-1',0,''),(605924,190736,'74015','origin','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605925,190737,'74016','origin','hide_parents','2',0,''),(605926,190738,'74017','origin','float','right',0,''),(605927,190738,'74017','origin','margin-top','-37',0,''),(605928,190738,'74017','origin','link','comments',0,''),(605929,190739,'74018','origin','block_type','1',0,''),(605930,190739,'74018','origin','padding-right','30',0,''),(605931,190739,'74018','origin','padding-right','0',0,'8349'),(605932,190739,'74018','origin','background-color','$content-bg-1',0,''),(605933,190739,'74018','origin','padding-top','20',0,''),(605934,190739,'74018','origin','padding-left','30',0,''),(605935,190739,'74018','origin','padding-bottom','20',0,''),(605936,190739,'74018','origin','color','$content-color-1',0,''),(605937,190740,'74019','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(605938,190741,'74020','origin','link','products',0,''),(605939,190741,'74020','origin','float','right',0,''),(605940,190741,'74020','origin','margin-top','-37',0,''),(605941,190743,'74022','origin','block_type','1',0,''),(605942,190743,'74022','origin','padding-top','20',0,''),(605943,190743,'74022','origin','padding-left','20',0,''),(605944,190743,'74022','origin','padding-right','20',0,''),(605945,190743,'74022','origin','padding-bottom','20',0,''),(605946,190743,'74022','origin','background-color','$content-bg-1',0,''),(605947,190743,'74022','origin','style_class','order-summary2 hiding-box',0,''),(605948,190743,'74022','origin','color','$content-color-1',0,''),(605949,190744,'74023','origin','margin-bottom','20',0,''),(605950,190744,'74023','origin','text-align','right',0,''),(605951,190745,'74024','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(605952,190747,'74026','origin','block_type','1',0,''),(605953,190747,'74026','origin','background-color','$content-bg-2',0,''),(605954,190747,'74026','origin','padding-bottom','30',0,''),(605955,190748,'74027','origin','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(605956,190749,'74028','origin','block_type','4',0,''),(605957,190749,'74028','origin','schema','4-2',0,'8356'),(605958,190750,'74029','origin','block_type','1',0,''),(605959,190750,'74029','origin','padding-right','40',0,''),(605960,190750,'74029','origin','padding-right','0',0,'8356'),(605961,190751,'74030','origin','block_type','1',0,''),(605962,190751,'74030','origin','background-color','$content-bg-1',0,''),(605963,190751,'74030','origin','padding-top','20',0,''),(605964,190751,'74030','origin','padding-bottom','20',0,''),(605965,190751,'74030','origin','padding-left','30',0,''),(605966,190751,'74030','origin','padding-right','30',0,''),(605967,190751,'74030','origin','margin-bottom','20',0,''),(605968,190752,'74031','origin','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605969,190753,'74032','origin','hide_parents','2',0,''),(605970,190754,'74033','origin','float','right',0,''),(605971,190754,'74033','origin','margin-top','-37',0,''),(605972,190754,'74033','origin','link','comments',0,''),(605973,190755,'74034','origin','block_type','2',0,''),(605974,190755,'74034','origin','margin-bottom','20',0,''),(605975,190755,'74034','origin','schema','2-2',0,'8349'),(605976,190755,'74034','origin','background-color','$content-bg-1',0,''),(605977,190756,'74035','origin','block_type','1',0,''),(605978,190756,'74035','origin','border-right-width','20',0,''),(605979,190756,'74035','origin','border-right-color','$content-border-1',0,''),(605980,190756,'74035','origin','margin-right','-10',0,''),(605981,190756,'74035','origin','padding-right','30',0,''),(605982,190756,'74035','origin','padding-top','20',0,''),(605983,190756,'74035','origin','padding-left','30',0,''),(605984,190756,'74035','origin','padding-bottom','20',0,''),(605985,190756,'74035','origin','border-right-width','0',0,'8356'),(605986,190756,'74035','origin','margin-right','0',0,'8356'),(605987,190756,'74035','origin','margin-bottom','20',0,'8356'),(605988,190756,'74035','origin','padding-left','20',0,'8356'),(605989,190756,'74035','origin','padding-right','20',0,'8356'),(605990,190757,'74036','origin','link','contact_information',0,''),(605991,190757,'74036','origin','margin-top','-31',0,''),(605992,190757,'74036','origin','float','right',0,''),(605993,190760,'74039','origin','link','payment_method',0,''),(605994,190760,'74039','origin','float','right',0,''),(605995,190760,'74039','origin','margin-top','-31',0,''),(605996,190761,'74040','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(605997,190761,'74040','origin','padding-top','20',0,''),(605998,190762,'74041','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605999,190762,'74041','origin','clear','none',0,''),(606000,190763,'74042','origin','block_type','1',0,''),(606001,190763,'74042','origin','padding-left','30',0,''),(606002,190763,'74042','origin','border-left-width','20',0,''),(606003,190763,'74042','origin','border-left-color','$content-border-1',0,''),(606004,190763,'74042','origin','margin-left','-10',0,''),(606005,190763,'74042','origin','padding-right','30',0,''),(606006,190763,'74042','origin','padding-top','20',0,''),(606007,190763,'74042','origin','padding-bottom','20',0,''),(606008,190763,'74042','origin','border-left-width','0',0,'8356'),(606009,190764,'74043','origin','margin-bottom','20',0,''),(606010,190765,'74044','origin','link','billing_address',0,''),(606011,190765,'74044','origin','float','right',0,''),(606012,190765,'74044','origin','margin-top','-31',0,''),(606013,190766,'74045','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(606014,190766,'74045','origin','clear','none',0,''),(606015,190767,'74046','origin','block_type','1',0,''),(606016,190767,'74046','origin','padding-right','30',0,''),(606017,190767,'74046','origin','background-color','$content-bg-1',0,''),(606018,190767,'74046','origin','padding-top','20',0,''),(606019,190767,'74046','origin','padding-left','30',0,''),(606020,190767,'74046','origin','padding-bottom','20',0,''),(606021,190767,'74046','origin','padding-left','20',0,'8356'),(606022,190767,'74046','origin','padding-right','20',0,'8356'),(606023,190768,'74047','origin','link','products',0,''),(606024,190768,'74047','origin','float','right',0,''),(606025,190768,'74047','origin','margin-top','-37',0,''),(606026,190769,'74048','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(606027,190770,'74049','origin','margin-bottom','20',0,''),(606028,190771,'74050','origin','block_type','1',0,''),(606029,190771,'74050','origin','padding-top','20',0,''),(606030,190771,'74050','origin','padding-left','20',0,''),(606031,190771,'74050','origin','padding-right','20',0,''),(606032,190771,'74050','origin','padding-bottom','20',0,''),(606033,190771,'74050','origin','background-color','$content-bg-1',0,''),(606034,190771,'74050','origin','style_class','order-summary',0,''),(606035,190772,'74051','origin','margin-bottom','20',0,''),(606036,190772,'74051','origin','text-align','right',0,''),(606037,190774,'74053','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(606038,190775,'74054','origin','block_type','1',0,''),(606039,190775,'74054','origin','background-color','$content-bg-2',0,''),(606040,190775,'74054','origin','padding-bottom','30',0,''),(606041,190776,'74055','origin','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(606042,190777,'74056','origin','block_type','4',0,''),(606043,190777,'74056','origin','schema','4-2',0,'8356'),(606044,190778,'74057','origin','block_type','1',0,''),(606045,190778,'74057','origin','padding-right','40',0,''),(606046,190778,'74057','origin','padding-right','0',0,'8356'),(606047,190779,'74058','origin','block_type','1',0,''),(606048,190779,'74058','origin','padding-right','30',0,''),(606049,190779,'74058','origin','background-color','$content-bg-1',0,''),(606050,190779,'74058','origin','padding-top','20',0,''),(606051,190779,'74058','origin','padding-left','30',0,''),(606052,190779,'74058','origin','padding-bottom','20',0,''),(606053,190779,'74058','origin','padding-left','20',0,'8356'),(606054,190779,'74058','origin','padding-right','20',0,'8356'),(606055,190781,'74060','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(606056,190782,'74061','origin','link','products',0,''),(606057,190782,'74061','origin','float','right',0,''),(606058,190782,'74061','origin','margin-top','-37',0,''),(606059,190783,'74062','origin','block_type','2',0,''),(606060,190783,'74062','origin','margin-bottom','20',0,''),(606061,190783,'74062','origin','schema','2-2',0,'8349'),(606062,190783,'74062','origin','background-color','$content-bg-1',0,''),(606063,190784,'74063','origin','block_type','1',0,''),(606064,190784,'74063','origin','border-right-width','20',0,''),(606065,190784,'74063','origin','border-right-color','$content-border-1',0,''),(606066,190784,'74063','origin','margin-right','-10',0,''),(606067,190784,'74063','origin','padding-right','30',0,''),(606068,190784,'74063','origin','padding-top','20',0,''),(606069,190784,'74063','origin','padding-left','30',0,''),(606070,190784,'74063','origin','padding-bottom','20',0,''),(606071,190784,'74063','origin','border-right-width','0',0,'8356'),(606072,190784,'74063','origin','margin-right','0',0,'8356'),(606073,190784,'74063','origin','margin-bottom','20',0,'8356'),(606074,190784,'74063','origin','padding-left','20',0,'8356'),(606075,190784,'74063','origin','padding-right','20',0,'8356'),(606076,190785,'74064','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(606077,190786,'74065','origin','link','contact_information',0,''),(606078,190786,'74065','origin','margin-top','-31',0,''),(606079,190786,'74065','origin','float','right',0,''),(606080,190787,'74066','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(606081,190787,'74066','origin','clear','none',0,''),(606082,190789,'74068','origin','margin-bottom','20',0,''),(606083,190791,'74070','origin','link','shipping_address',0,''),(606084,190791,'74070','origin','float','right',0,''),(606085,190791,'74070','origin','margin-top','-31',0,''),(606086,190793,'74072','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(606087,190793,'74072','origin','padding-top','20',0,''),(606088,190794,'74073','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(606089,190794,'74073','origin','clear','none',0,''),(606090,190795,'74074','origin','link','shipping_method',0,''),(606091,190795,'74074','origin','float','right',0,''),(606092,190795,'74074','origin','margin-top','-31',0,''),(606093,190796,'74075','origin','block_type','1',0,''),(606094,190796,'74075','origin','padding-left','30',0,''),(606095,190796,'74075','origin','border-left-width','20',0,''),(606096,190796,'74075','origin','border-left-color','$content-border-1',0,''),(606097,190796,'74075','origin','margin-left','-10',0,''),(606098,190796,'74075','origin','padding-right','30',0,''),(606099,190796,'74075','origin','padding-top','20',0,''),(606100,190796,'74075','origin','padding-bottom','20',0,''),(606101,190796,'74075','origin','border-left-width','0',0,'8356'),(606102,190797,'74076','origin','link','billing_address',0,''),(606103,190797,'74076','origin','float','right',0,''),(606104,190797,'74076','origin','margin-top','-31',0,''),(606105,190798,'74077','origin','margin-bottom','20',0,''),(606106,190800,'74079','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(606107,190801,'74080','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(606108,190801,'74080','origin','clear','none',0,''),(606109,190802,'74081','origin','link','payment_method',0,''),(606110,190802,'74081','origin','float','right',0,''),(606111,190802,'74081','origin','margin-top','-31',0,''),(606112,190803,'74082','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(606113,190803,'74082','origin','clear','none',0,''),(606114,190804,'74083','origin','block_type','1',0,''),(606115,190804,'74083','origin','background-color','$content-bg-1',0,''),(606116,190804,'74083','origin','padding-top','20',0,''),(606117,190804,'74083','origin','padding-bottom','20',0,''),(606118,190804,'74083','origin','padding-left','30',0,''),(606119,190804,'74083','origin','padding-right','30',0,''),(606120,190804,'74083','origin','margin-bottom','20',0,''),(606121,190805,'74084','origin','hide_parents','2',0,''),(606122,190806,'74085','origin','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(606123,190807,'74086','origin','float','right',0,''),(606124,190807,'74086','origin','margin-top','-37',0,''),(606125,190807,'74086','origin','link','comments',0,''),(606126,190808,'74087','origin','block_type','1',0,''),(606127,190808,'74087','origin','padding-top','20',0,''),(606128,190808,'74087','origin','padding-left','20',0,''),(606129,190808,'74087','origin','padding-right','20',0,''),(606130,190808,'74087','origin','padding-bottom','20',0,''),(606131,190808,'74087','origin','background-color','$content-bg-1',0,''),(606132,190808,'74087','origin','style_class','order-summary',0,''),(606133,190809,'74088','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(606134,190811,'74090','origin','margin-bottom','20',0,''),(606135,190811,'74090','origin','text-align','right',0,''),(606136,190812,'74091','origin','block_type','1',0,''),(606137,190812,'74091','origin','background-color','$content-bg-2',0,''),(606138,190812,'74091','origin','padding-bottom','30',0,''),(606139,190813,'74092','origin','block_type','4',0,''),(606140,190813,'74092','origin','schema','4-2',0,'8356'),(606141,190814,'74093','origin','block_type','1',0,''),(606142,190814,'74093','origin','padding-right','40',0,''),(606143,190814,'74093','origin','padding-right','0',0,'8356'),(606144,190815,'74094','origin','block_type','2',0,''),(606145,190815,'74094','origin','margin-bottom','20',0,''),(606146,190815,'74094','origin','schema','2-2',0,'8349'),(606147,190815,'74094','origin','background-color','$content-bg-1',0,''),(606148,190816,'74095','origin','block_type','1',0,''),(606149,190816,'74095','origin','border-right-width','20',0,''),(606150,190816,'74095','origin','border-right-color','$content-border-1',0,''),(606151,190816,'74095','origin','margin-right','-10',0,''),(606152,190816,'74095','origin','padding-right','30',0,''),(606153,190816,'74095','origin','padding-top','20',0,''),(606154,190816,'74095','origin','padding-left','30',0,''),(606155,190816,'74095','origin','padding-bottom','20',0,''),(606156,190816,'74095','origin','border-right-width','0',0,'8356'),(606157,190816,'74095','origin','margin-right','0',0,'8356'),(606158,190816,'74095','origin','margin-bottom','20',0,'8356'),(606159,190816,'74095','origin','padding-left','20',0,'8356'),(606160,190816,'74095','origin','padding-right','20',0,'8356'),(606161,190817,'74096','origin','margin-bottom','20',0,''),(606162,190818,'74097','origin','link','shipping_address',0,''),(606163,190818,'74097','origin','float','right',0,''),(606164,190818,'74097','origin','margin-top','-31',0,''),(606165,190819,'74098','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(606166,190819,'74098','origin','clear','none',0,''),(606167,190822,'74101','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(606168,190823,'74102','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(606169,190823,'74102','origin','clear','none',0,''),(606170,190824,'74103','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(606171,190824,'74103','origin','padding-top','20',0,''),(606172,190826,'74105','origin','link','shipping_method',0,''),(606173,190826,'74105','origin','float','right',0,''),(606174,190826,'74105','origin','margin-top','-31',0,''),(606175,190827,'74106','origin','link','contact_information',0,''),(606176,190827,'74106','origin','margin-top','-31',0,''),(606177,190827,'74106','origin','float','right',0,''),(606178,190828,'74107','origin','block_type','1',0,''),(606179,190828,'74107','origin','padding-left','30',0,''),(606180,190828,'74107','origin','border-left-width','20',0,''),(606181,190828,'74107','origin','border-left-color','$content-border-1',0,''),(606182,190828,'74107','origin','margin-left','-10',0,''),(606183,190828,'74107','origin','padding-right','30',0,''),(606184,190828,'74107','origin','padding-top','20',0,''),(606185,190828,'74107','origin','padding-bottom','20',0,''),(606186,190828,'74107','origin','border-left-width','0',0,'8356'),(606187,190829,'74108','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(606188,190829,'74108','origin','clear','none',0,''),(606189,190830,'74109','origin','margin-bottom','20',0,''),(606190,190831,'74110','origin','link','billing_address',0,''),(606191,190831,'74110','origin','float','right',0,''),(606192,190831,'74110','origin','margin-top','-31',0,''),(606193,190833,'74112','origin','link','payment_method',0,''),(606194,190833,'74112','origin','float','right',0,''),(606195,190833,'74112','origin','margin-top','-31',0,''),(606196,190834,'74113','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(606197,190835,'74114','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(606198,190835,'74114','origin','clear','none',0,''),(606199,190836,'74115','origin','block_type','1',0,''),(606200,190836,'74115','origin','padding-right','30',0,''),(606201,190836,'74115','origin','background-color','$content-bg-1',0,''),(606202,190836,'74115','origin','padding-top','20',0,''),(606203,190836,'74115','origin','padding-left','30',0,''),(606204,190836,'74115','origin','padding-bottom','20',0,''),(606205,190836,'74115','origin','padding-left','20',0,'8356'),(606206,190836,'74115','origin','padding-right','20',0,'8356'),(606207,190837,'74116','origin','link','products',0,''),(606208,190837,'74116','origin','float','right',0,''),(606209,190837,'74116','origin','margin-top','-37',0,''),(606210,190838,'74117','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(606211,190840,'74119','origin','block_type','1',0,''),(606212,190840,'74119','origin','background-color','$content-bg-1',0,''),(606213,190840,'74119','origin','padding-top','20',0,''),(606214,190840,'74119','origin','padding-bottom','20',0,''),(606215,190840,'74119','origin','padding-left','30',0,''),(606216,190840,'74119','origin','padding-right','30',0,''),(606217,190840,'74119','origin','margin-bottom','20',0,''),(606218,190841,'74120','origin','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(606219,190842,'74121','origin','float','right',0,''),(606220,190842,'74121','origin','margin-top','-37',0,''),(606221,190842,'74121','origin','link','comments',0,''),(606222,190843,'74122','origin','hide_parents','2',0,''),(606223,190844,'74123','origin','block_type','1',0,''),(606224,190844,'74123','origin','padding-top','20',0,''),(606225,190844,'74123','origin','padding-left','20',0,''),(606226,190844,'74123','origin','padding-right','20',0,''),(606227,190844,'74123','origin','padding-bottom','20',0,''),(606228,190844,'74123','origin','background-color','$content-bg-1',0,''),(606229,190844,'74123','origin','style_class','order-summary',0,''),(606230,190846,'74125','origin','margin-bottom','20',0,''),(606231,190846,'74125','origin','text-align','right',0,''),(606232,190847,'74126','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(606233,190848,'74127','origin','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(606234,190849,'74128','origin','block_type','1',0,''),(606235,190851,'74133','origin','block_type','2',0,''),(606236,190851,'74133','origin','font-weight','400',0,''),(606237,190851,'74133','origin','padding-bottom','20',0,''),(606238,190851,'74133','origin','schema','2-2',0,'8356'),(606239,190852,'74134','origin','show_captcha','on',0,''),(606240,190853,'74135','origin','font-weight','400',0,''),(606241,190853,'74135','origin','padding-left','40',0,''),(606242,190853,'74135','origin','time_format','24',0,''),(606243,190853,'74135','origin','show_icons','on',0,''),(606244,190853,'74135','origin','padding-left','0',0,'8356'),(606245,190854,'74136','origin','block_type','1',0,''),(606246,190855,'74137','origin','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(606247,190856,'74138','origin','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(606248,190856,'74138','origin','margin-bottom','40',0,''),(606249,190857,'74139','origin','width','680',0,''),(606250,190857,'74139','origin','font-weight','normal',0,''),(606251,190857,'74139','origin','font-size','12',0,''),(606252,190857,'74139','origin','padding-top','20',0,''),(606253,190857,'74139','origin','padding-bottom','20',0,''),(606254,190857,'74139','origin','color','$content-color-1',0,''),(606255,190858,'74140','origin','block_type','3',0,''),(606256,190858,'74140','origin','font-weight','normal',0,''),(606257,190858,'74140','origin','padding-top','20',0,''),(606258,190859,'74141','origin','font-size','12',0,''),(606259,190860,'74142','origin','text','<p>If undelivered please return to:</p>',1,''),(606260,190860,'74142','origin','font-size','12',0,''),(606261,190860,'74142','origin','font-weight','bold',0,''),(606262,190860,'74142','origin','text','<p>If undelivered please return to:</p>',0,''),(606263,190861,'74143','origin','text','<p>Thank you for your order</p>',1,''),(606264,190861,'74143','origin','color','$color-8',0,''),(606265,190861,'74143','origin','font-size','13',0,''),(606266,190861,'74143','origin','font-weight','bold',0,''),(606267,190861,'74143','origin','padding-top','5',0,''),(606268,190861,'74143','origin','text-align','center',0,''),(606269,190861,'74143','origin','text','<p>Thank you for your order</p>',0,''),(606270,190862,'74144','origin','font-weight','400',0,''),(606271,190862,'74144','origin','text-align','center',0,''),(606272,190862,'74144','origin','padding-top','0',0,''),(606273,190862,'74144','origin','padding-left','20',0,''),(606274,190862,'74144','origin','padding-right','20',0,''),(606275,190863,'74145','origin','text','<p>If something has gone wrong please contact us at:</p>',1,''),(606276,190863,'74145','origin','font-size','12',0,''),(606277,190863,'74145','origin','font-weight','bold',0,''),(606278,190863,'74145','origin','text-align','right',0,''),(606279,190863,'74145','origin','text','<p>If something has gone wrong please contact us at:</p>',0,''),(606280,190864,'74146','origin','block_type','6',0,''),(606281,190864,'74146','origin','font-weight','normal',0,''),(606282,190864,'74146','origin','font-size','16',0,''),(606283,190865,'74147','origin','text','<p>Email:</p>',1,''),(606284,190865,'74147','origin','font-weight','normal',0,''),(606285,190865,'74147','origin','text-align','right',0,''),(606286,190865,'74147','origin','font-size','12',0,''),(606287,190865,'74147','origin','text','<p>Email:</p>',0,''),(606288,190866,'74148','origin','font-weight','normal',0,''),(606289,190866,'74148','origin','text-align','right',0,''),(606290,190866,'74148','origin','font-size','12',0,''),(606291,190867,'74149','origin','block_type','6',0,''),(606292,190867,'74149','origin','font-weight','normal',0,''),(606293,190867,'74149','origin','font-size','16',0,''),(606294,190868,'74150','origin','text','<p>Phone:</p>',1,''),(606295,190868,'74150','origin','font-weight','normal',0,''),(606296,190868,'74150','origin','text-align','right',0,''),(606297,190868,'74150','origin','font-size','12',0,''),(606298,190868,'74150','origin','text','<p>Phone:</p>',0,''),(606299,190869,'74151','origin','font-weight','normal',0,''),(606300,190869,'74151','origin','text-align','right',0,''),(606301,190869,'74151','origin','font-size','12',0,''),(606302,190870,'74152','origin','font-weight','400',0,''),(606303,190870,'74152','origin','padding-top','20',0,''),(606304,190870,'74152','origin','padding-bottom','0',0,''),(606305,190870,'74152','origin','font-size','12',0,''),(606306,190871,'74153','origin','block_type','2',0,''),(606307,190871,'74153','origin','font-weight','normal',0,''),(606308,190871,'74153','origin','padding-bottom','20',0,''),(606309,190872,'74154','origin','font-weight','400',0,''),(606310,190872,'74154','origin','padding-top','20',0,''),(606311,190873,'74155','origin','block_type','11',0,''),(606312,190873,'74155','origin','font-weight','normal',0,''),(606313,190874,'74156','origin','text','<p>Web:</p>',1,''),(606314,190874,'74156','origin','font-weight','normal',0,''),(606315,190874,'74156','origin','text-align','right',0,''),(606316,190874,'74156','origin','text','<p>Web:</p>',0,''),(606317,190875,'74157','origin','font-weight','normal',0,''),(606318,190875,'74157','origin','text-align','right',0,''),(606319,190876,'74158','origin','block_type','11',0,''),(606320,190876,'74158','origin','font-weight','normal',0,''),(606321,190877,'74159','origin','text','<p>Phone:</p>',1,''),(606322,190877,'74159','origin','font-weight','normal',0,''),(606323,190877,'74159','origin','text-align','right',0,''),(606324,190877,'74159','origin','text','<p>Phone:</p>',0,''),(606325,190878,'74160','origin','font-weight','normal',0,''),(606326,190878,'74160','origin','text-align','right',0,''),(606327,190879,'74161','origin','block_type','11',0,''),(606328,190879,'74161','origin','font-weight','normal',0,''),(606329,190880,'74162','origin','text','<p>Email:</p>',1,''),(606330,190880,'74162','origin','font-weight','normal',0,''),(606331,190880,'74162','origin','text-align','right',0,''),(606332,190880,'74162','origin','text','<p>Email:</p>',0,''),(606333,190881,'74163','origin','font-weight','normal',0,''),(606334,190881,'74163','origin','text-align','right',0,''),(606335,190882,'74164','origin','block_type','1',0,''),(606336,190883,'74165','origin','font-weight','normal',0,''),(606337,190883,'74165','origin','text-align','right',0,''),(606338,190883,'74165','origin','padding-bottom','10',0,''),(606339,190883,'74165','origin','address_spacer',',',0,''),(606340,190883,'74165','origin','font-size','12',0,''),(606341,190884,'74166','origin','block_type','5',0,''),(606342,190884,'74166','origin','font-weight','normal',0,''),(606343,190884,'74166','origin','border-bottom-width','1',0,''),(606344,190884,'74166','origin','border-bottom-color','$content-border-1',0,''),(606345,190884,'74166','origin','border-top-width','1',0,''),(606346,190884,'74166','origin','border-top-color','$content-border-1',0,''),(606347,190884,'74166','origin','border-left-color','$content-border-1',0,''),(606348,190884,'74166','origin','border-left-width','1',0,''),(606349,190885,'74167','origin','block_type','1',0,''),(606350,190885,'74167','origin','font-weight','normal',0,''),(606351,190885,'74167','origin','padding-top','10',0,''),(606352,190885,'74167','origin','padding-left','10',0,''),(606353,190885,'74167','origin','padding-right','10',0,''),(606354,190886,'74168','origin','font-weight','400',0,''),(606355,190886,'74168','origin','line-height','120',0,''),(606356,190886,'74168','origin','line_height_measure','%',0,''),(606357,190886,'74168','origin','font-size','12',0,''),(606358,190887,'74169','origin','text','<p>SHIPPING ADDRESS:</p>',1,''),(606359,190887,'74169','origin','font-size','14',0,''),(606360,190887,'74169','origin','font-weight','bold',0,''),(606361,190887,'74169','origin','padding-bottom','10',0,''),(606362,190887,'74169','origin','text','<p>SHIPPING ADDRESS:</p>',0,''),(606363,190888,'74170','origin','block_type','1',0,''),(606364,190888,'74170','origin','background-color','$content-bg-2',0,''),(606365,190888,'74170','origin','padding-top','20',0,''),(606366,190888,'74170','origin','padding-left','10',0,''),(606367,190888,'74170','origin','padding-right','10',0,''),(606368,190888,'74170','origin','padding-bottom','20',0,''),(606369,190888,'74170','origin','font-size','14',0,''),(606370,190889,'74171','origin','block_type','4',0,''),(606371,190889,'74171','origin','font-weight','normal',0,''),(606372,190889,'74171','origin','border-top-width','1',0,''),(606373,190889,'74171','origin','border-top-color','$content-border-1',0,''),(606374,190889,'74171','origin','border-left-width','1',0,''),(606375,190889,'74171','origin','border-left-color','$content-border-1',0,''),(606376,190889,'74171','origin','border-right-width','1',0,''),(606377,190889,'74171','origin','border-right-color','$content-border-1',0,''),(606378,190889,'74171','origin','border-bottom-width','1',0,''),(606379,190889,'74171','origin','border-bottom-color','$content-border-1',0,''),(606380,190890,'74172','origin','block_type','2',0,''),(606381,190890,'74172','origin','font-weight','normal',0,''),(606382,190890,'74172','origin','border-right-width','1',0,''),(606383,190890,'74172','origin','border-right-color','$content-border-1',0,''),(606384,190891,'74173','origin','block_type','1',0,''),(606385,190891,'74173','origin','font-weight','400',0,''),(606386,190891,'74173','origin','background-color','$content-bg-2',0,''),(606387,190891,'74173','origin','padding-top','10',0,''),(606388,190891,'74173','origin','padding-left','10',0,''),(606389,190891,'74173','origin','padding-right','10',0,''),(606390,190891,'74173','origin','padding-bottom','30',0,''),(606391,190892,'74174','origin','text','<p>INVOICE ADDRESS:</p>',1,''),(606392,190892,'74174','origin','font-size','14',0,''),(606393,190892,'74174','origin','font-weight','bold',0,''),(606394,190892,'74174','origin','text','<p>INVOICE ADDRESS:</p>',0,''),(606395,190893,'74175','origin','font-size','12',0,''),(606396,190894,'74176','origin','block_type','1',0,''),(606397,190894,'74176','origin','font-weight','normal',0,''),(606398,190894,'74176','origin','padding-top','10',0,''),(606399,190894,'74176','origin','padding-left','10',0,''),(606400,190894,'74176','origin','padding-right','10',0,''),(606401,190894,'74176','origin','padding-bottom','10',0,''),(606402,190895,'74177','origin','font-weight','normal',0,''),(606403,190896,'74178','origin','text','<p>CUSTOMER:</p>',1,''),(606404,190896,'74178','origin','font-size','13',0,''),(606405,190896,'74178','origin','font-weight','bold',0,''),(606406,190896,'74178','origin','text','<p>CUSTOMER:</p>',0,''),(606407,190897,'74179','origin','text','<p>PHONE NUMBER:</p>',1,''),(606408,190897,'74179','origin','font-size','14',0,''),(606409,190897,'74179','origin','font-weight','bold',0,''),(606410,190897,'74179','origin','padding-top','10',0,''),(606411,190897,'74179','origin','text','<p>PHONE NUMBER:</p>',0,''),(606412,190898,'74180','origin','font-weight','normal',0,''),(606413,190900,'74182','origin','text','<p>E-MAIL ADDRESS:</p>',1,''),(606414,190900,'74182','origin','font-weight','bold',0,''),(606415,190900,'74182','origin','font-size','14',0,''),(606416,190900,'74182','origin','padding-top','10',0,''),(606417,190900,'74182','origin','text','<p>E-MAIL ADDRESS:</p>',0,''),(606418,190901,'74183','origin','block_type','2',0,''),(606419,190901,'74183','origin','font-weight','normal',0,''),(606420,190901,'74183','origin','border-top-width','1',0,''),(606421,190901,'74183','origin','border-top-color','$content-border-1',0,''),(606422,190901,'74183','origin','border-right-width','1',0,''),(606423,190901,'74183','origin','border-right-color','$content-border-1',0,''),(606424,190902,'74184','origin','block_type','1',0,''),(606425,190902,'74184','origin','font-weight','normal',0,''),(606426,190902,'74184','origin','padding-top','10',0,''),(606427,190902,'74184','origin','padding-left','10',0,''),(606428,190902,'74184','origin','padding-right','10',0,''),(606429,190902,'74184','origin','padding-bottom','10',0,''),(606430,190902,'74184','origin','border-right-width','1',0,''),(606431,190902,'74184','origin','border-right-color','$content-border-1',0,''),(606432,190904,'74186','origin','text','<p>Shipping via</p>',1,''),(606433,190904,'74186','origin','font-weight','bold',0,''),(606434,190904,'74186','origin','font-size','14',0,''),(606435,190904,'74186','origin','text','<p>Shipping via</p>',0,''),(606436,190905,'74187','origin','block_type','1',0,''),(606437,190905,'74187','origin','font-weight','normal',0,''),(606438,190905,'74187','origin','padding-top','10',0,''),(606439,190905,'74187','origin','padding-left','10',0,''),(606440,190905,'74187','origin','padding-right','10',0,''),(606441,190905,'74187','origin','padding-bottom','10',0,''),(606442,190906,'74188','origin','text','<p>Shipping service</p>',1,''),(606443,190906,'74188','origin','font-weight','bold',0,''),(606444,190906,'74188','origin','font-size','14',0,''),(606445,190906,'74188','origin','text','<p>Shipping service</p>',0,''),(606446,190908,'74190','origin','font-size','14',0,''),(606447,190908,'74190','origin','font-weight','bold',0,''),(606448,190908,'74190','origin','text-align','center',0,''),(606449,190908,'74190','origin','padding-bottom','10',0,''),(606450,190908,'74190','origin','padding-top','10',0,''),(606451,190909,'74191','origin','text','<p>Payment date:</p>',1,''),(606452,190909,'74191','origin','font-weight','bold',0,''),(606453,190909,'74191','origin','text-align','center',0,''),(606454,190909,'74191','origin','font-size','12',0,''),(606455,190909,'74191','origin','text','<p>Payment date:</p>',0,''),(606456,190910,'74192','origin','font-weight','normal',0,''),(606457,190910,'74192','origin','text-align','center',0,''),(606458,190910,'74192','origin','padding-bottom','10',0,''),(606459,190917,'74199','origin','text-align','center',0,''),(606460,190917,'74199','origin','padding-top','10',0,''),(606461,190919,'74201','origin','heading_type','h1',0,''),(606462,190922,'94718','origin','text-align','center',0,''),(606463,190922,'94718','origin','padding-top','10',0,''),(606464,190927,'74202','origin','block_type','1',0,''),(606465,190928,'74203','origin','block_type','1',0,''),(606466,190928,'74203','origin','max-width','800',0,''),(606467,190928,'74203','origin','margin','0 auto',0,''),(606468,190928,'74203','origin','background-color','$content-bg-1',0,''),(606469,190929,'74204','origin','color','$content-color-1',0,''),(606470,190929,'74204','origin','font-size','12',0,''),(606471,190929,'74204','origin','padding-top','20',0,''),(606472,190929,'74204','origin','padding-bottom','20',0,''),(606473,190929,'74204','origin','border-top-width','1',0,''),(606474,190929,'74204','origin','border-top-color','$content-border-1',0,''),(606475,190930,'74205','origin','font-weight','normal',0,''),(606476,190930,'74205','origin','padding-top','20',0,''),(606477,190930,'74205','origin','padding-left','10',0,''),(606478,190930,'74205','origin','padding-right','10',0,''),(606479,190930,'74205','origin','padding-bottom','20',0,''),(606480,190930,'74205','origin','color','$content-color-1',0,''),(606481,190930,'74205','origin','font-size','14',0,''),(606482,190931,'74206','origin','block_type','7',0,''),(606483,190931,'74206','origin','font-weight','normal',0,''),(606484,190931,'74206','origin','background-color','$highlight-box-bg-1',0,''),(606485,190931,'74206','origin','padding-top','5',0,''),(606486,190931,'74206','origin','padding-left','10',0,''),(606487,190931,'74206','origin','padding-right','10',0,''),(606488,190931,'74206','origin','padding-bottom','5',0,''),(606489,190932,'74207','origin','color','$highlight-box-color-1',0,''),(606490,190932,'74207','origin','font-size','14',0,''),(606491,190932,'74207','origin','font-weight','normal',0,''),(606492,190933,'74208','origin','font-weight','normal',0,''),(606493,190933,'74208','origin','text-align','right',0,''),(606494,190933,'74208','origin','color','$highlight-box-color-1',0,''),(606495,190933,'74208','origin','font-size','12',0,''),(606496,190934,'74209','origin','font-weight','normal',0,''),(606497,190934,'74209','origin','padding-bottom','10',0,''),(606498,190934,'74209','origin','padding-top','10',0,''),(606499,190934,'74209','origin','logo_from','theme',0,''),(606500,190935,'74210','origin','block_type','1',0,''),(606501,190936,'74211','origin','block_type','1',0,''),(606502,190936,'74211','origin','max-width','800',0,''),(606503,190936,'74211','origin','margin','0 auto',0,''),(606504,190936,'74211','origin','background-color','$content-bg-1',0,''),(606505,190937,'74212','origin','color','$content-color-1',0,''),(606506,190937,'74212','origin','font-size','12',0,''),(606507,190937,'74212','origin','padding-top','20',0,''),(606508,190937,'74212','origin','padding-bottom','20',0,''),(606509,190937,'74212','origin','border-top-width','1',0,''),(606510,190937,'74212','origin','border-top-color','$content-border-1',0,''),(606511,190938,'74213','origin','font-weight','normal',0,''),(606512,190938,'74213','origin','padding-bottom','10',0,''),(606513,190938,'74213','origin','background-color','$highlight-box-bg-1',0,''),(606514,190938,'74213','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',1,''),(606515,190938,'74213','origin','padding-left','20',0,''),(606516,190938,'74213','origin','padding-top','10',0,''),(606517,190938,'74213','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',0,''),(606518,190939,'74214','origin','font-weight','normal',0,''),(606519,190939,'74214','origin','padding-top','20',0,''),(606520,190939,'74214','origin','padding-left','10',0,''),(606521,190939,'74214','origin','padding-right','10',0,''),(606522,190939,'74214','origin','padding-bottom','20',0,''),(606523,190939,'74214','origin','color','$content-color-1',0,''),(606524,190939,'74214','origin','font-size','14',0,''),(606525,190940,'74215','origin','block_type','7',0,''),(606526,190940,'74215','origin','font-weight','normal',0,''),(606527,190940,'74215','origin','background-color','$highlight-box-bg-1',0,''),(606528,190940,'74215','origin','padding-top','5',0,''),(606529,190940,'74215','origin','padding-left','10',0,''),(606530,190940,'74215','origin','padding-right','10',0,''),(606531,190940,'74215','origin','padding-bottom','5',0,''),(606532,190941,'74216','origin','color','$highlight-box-color-1',0,''),(606533,190941,'74216','origin','font-size','15',0,''),(606534,190941,'74216','origin','font-weight','700',0,''),(606535,190942,'74217','origin','font-weight','normal',0,''),(606536,190942,'74217','origin','text-align','right',0,''),(606537,190942,'74217','origin','color','$highlight-box-color-1',0,''),(606538,190942,'74217','origin','font-size','12',0,''),(606539,190943,'74218','origin','block_type','1',0,''),(606540,190943,'74218','origin','background-color','$content-bg-2',0,''),(606541,190944,'74219','origin','block_type','1',0,''),(606542,190944,'74219','origin','max-width','800',0,''),(606543,190944,'74219','origin','margin','0 auto',0,''),(606544,190945,'74220','origin','block_type','1',0,''),(606545,190945,'74220','origin','background-color','$content-bg-1',0,''),(606546,190945,'74220','origin','padding-top','20',0,''),(606547,190945,'74220','origin','padding-left','20',0,''),(606548,190945,'74220','origin','padding-right','20',0,''),(606549,190945,'74220','origin','padding-bottom','20',0,''),(606550,190946,'74221','origin','font-weight','normal',0,''),(606551,190946,'74221','origin','padding-top','20',0,''),(606552,190946,'74221','origin','padding-bottom','20',0,''),(606553,190946,'74221','origin','color','$content-color-1',0,''),(606554,190946,'74221','origin','font-size','14',0,''),(606555,190947,'74222','origin','block_type','7',0,''),(606556,190947,'74222','origin','font-weight','normal',0,''),(606557,190947,'74222','origin','padding-left','10',0,''),(606558,190947,'74222','origin','padding-right','10',0,''),(606559,190947,'74222','origin','padding-bottom','15',0,''),(606560,190947,'74222','origin','border-bottom-width','1',0,''),(606561,190947,'74222','origin','border-bottom-color','$content-border-1',0,''),(606562,190948,'74223','origin','color','$content-color-1',0,''),(606563,190948,'74223','origin','font-size','14',0,''),(606564,190948,'74223','origin','font-weight','700',0,''),(606565,190949,'74224','origin','font-weight','normal',0,''),(606566,190949,'74224','origin','text-align','right',0,''),(606567,190949,'74224','origin','color','$fade-color-1',0,''),(606568,190949,'74224','origin','font-size','11',0,''),(606569,190949,'74224','origin','text-transform','uppercase',0,''),(606570,190950,'74225','origin','color','$fade-color-1',0,''),(606571,190950,'74225','origin','font-size','12',0,''),(606572,190950,'74225','origin','padding-top','20',0,''),(606573,190950,'74225','origin','padding-bottom','20',0,''),(606574,190950,'74225','origin','text-align','center',0,''),(606575,190951,'74226','origin','font-weight','normal',0,''),(606576,190951,'74226','origin','padding-bottom','10',0,''),(606577,190951,'74226','origin','padding-top','10',0,''),(606578,190951,'74226','origin','text-align','center',0,''),(606579,190951,'74226','origin','logo_from','theme',0,''),(606580,190952,'74227','origin','block_type','1',0,''),(606581,190952,'74227','origin','background-color','$content-bg-2',0,''),(606582,190952,'74227','origin','padding-top','20',0,''),(606583,190952,'74227','origin','padding-bottom','20',0,''),(606584,190953,'74228','origin','block_type','1',0,''),(606585,190953,'74228','origin','max-width','800',0,''),(606586,190953,'74228','origin','margin','0 auto',0,''),(606587,190954,'74229','origin','color','$fade-color-1',0,''),(606588,190954,'74229','origin','font-size','12',0,''),(606589,190954,'74229','origin','padding-top','20',0,''),(606590,190954,'74229','origin','padding-bottom','20',0,''),(606591,190954,'74229','origin','text-align','left',0,''),(606592,190955,'74230','origin','block_type','1',0,''),(606593,190955,'74230','origin','background-color','$content-bg-1',0,''),(606594,190955,'74230','origin','padding-top','20',0,''),(606595,190955,'74230','origin','padding-left','20',0,''),(606596,190955,'74230','origin','padding-right','20',0,''),(606597,190955,'74230','origin','padding-bottom','20',0,''),(606598,190955,'74230','origin','border-top-width','1',0,''),(606599,190955,'74230','origin','border-left-width','1',0,''),(606600,190955,'74230','origin','border-right-width','1',0,''),(606601,190955,'74230','origin','border-bottom-width','1',0,''),(606602,190955,'74230','origin','border-top-color','$content-border-1',0,''),(606603,190955,'74230','origin','border-left-color','$content-border-1',0,''),(606604,190955,'74230','origin','border-bottom-color','$content-border-1',0,''),(606605,190955,'74230','origin','border-right-color','$content-border-1',0,''),(606606,190956,'74231','origin','block_type','2',0,''),(606607,190957,'74232','origin','font-weight','normal',0,''),(606608,190957,'74232','origin','padding-bottom','10',0,''),(606609,190957,'74232','origin','padding-top','10',0,''),(606610,190957,'74232','origin','logo_from','theme',0,''),(606611,190958,'74233','origin','font-weight','normal',0,''),(606612,190958,'74233','origin','text-align','right',0,''),(606613,190958,'74233','origin','color','$fade-color-1',0,''),(606614,190958,'74233','origin','font-size','11',0,''),(606615,190958,'74233','origin','text-transform','uppercase',0,''),(606616,190959,'74234','origin','color','$content-color-1',0,''),(606617,190959,'74234','origin','font-size','14',0,''),(606618,190959,'74234','origin','font-weight','700',0,''),(606619,190959,'74234','origin','text-align','right',0,''),(606620,190960,'74235','origin','font-weight','normal',0,''),(606621,190960,'74235','origin','padding-top','20',0,''),(606622,190960,'74235','origin','padding-bottom','20',0,''),(606623,190960,'74235','origin','color','$content-color-1',0,''),(606624,190960,'74235','origin','font-size','14',0,''),(606625,190961,'74236','origin','block_type','1',0,''),(606626,190961,'74236','origin','font-weight','normal',0,''),(606627,190961,'74236','origin','padding-top','20',0,''),(606628,190961,'74236','origin','background-color','$footer-bg-1',0,''),(606629,190961,'74236','origin','color','$footer-color-1',0,''),(606630,190962,'74237','origin','block_type','14',0,''),(606631,190962,'74237','origin','margin-bottom','15',0,''),(606632,190962,'74237','origin','schema','14-2',0,'8356'),(606633,190962,'74237','origin','schema','14-3',0,'8349'),(606634,190962,'74237','origin','style_class','preFooter',0,''),(606635,190962,'74237','origin','visibility_checkout','1',0,''),(606636,190963,'74238','origin','block_type','1',0,''),(606637,190964,'74239','origin','class','menu-style-2',0,''),(606638,190965,'1695906739.5696','origin','text','##NAVBAR_TITLE_ACCOUNT##',0,''),(606639,190965,'1695906739.5696','origin','style_class','footerTitle',0,''),(606640,190965,'1695906739.5696','origin','font-family','$font-1',0,''),(606641,190965,'1695906739.5696','origin','font-size','20',0,''),(606642,190965,'1695906739.5696','origin','text-transform','uppercase',0,''),(606643,190966,'74241','origin','block_type','1',0,''),(606644,190967,'74243','origin','class','menu-style-2',0,''),(606645,190968,'1695906751.0591','origin','text','##TEXT_PRODUCTS##',0,''),(606646,190968,'1695906751.0591','origin','font-family','$font-1',0,''),(606647,190968,'1695906751.0591','origin','font-size','20',0,''),(606648,190968,'1695906751.0591','origin','text-transform','uppercase',0,''),(606649,190968,'1695906751.0591','origin','style_class','footerTitle',0,''),(606650,190969,'74244','origin','block_type','1',0,''),(606651,190970,'74246','origin','class','menu-style-2',0,''),(606652,190971,'1695906756.0887','origin','text','##TEXT_SHOP##',0,''),(606653,190971,'1695906756.0887','origin','style_class','footerTitle',0,''),(606654,190971,'1695906756.0887','origin','font-family','$font-1',0,''),(606655,190971,'1695906756.0887','origin','font-size','20',0,''),(606656,190971,'1695906756.0887','origin','text-transform','uppercase',0,''),(606657,190972,'74247','origin','block_type','1',0,''),(606658,190973,'74248','origin','view_item','phone_number',0,''),(606659,190974,'74249','origin','view_item','address',0,''),(606660,190974,'74249','origin','address_spacer',',<span> </span>',0,''),(606661,190975,'1695906761.6568','origin','text','##TEXT_CONTACT##',0,''),(606662,190975,'1695906761.6568','origin','font-family','$font-1',0,''),(606663,190975,'1695906761.6568','origin','font-size','20',0,''),(606664,190975,'1695906761.6568','origin','text-transform','uppercase',0,''),(606665,190975,'1695906761.6568','origin','style_class','footerTitle',0,''),(606666,190976,'74256','origin','block_type','2',0,''),(606667,190976,'74256','origin','font-weight','400',0,''),(606668,190976,'74256','origin','padding-top','20',0,''),(606669,190976,'74256','origin','padding-bottom','20',0,''),(606670,190976,'74256','origin','schema','2-2',0,''),(606671,190976,'74256','origin','schema','2-3',0,'8356'),(606672,190978,'74258','origin','address_spacer',', ',0,''),(606673,190978,'74258','origin','font-weight','400',0,''),(606674,190978,'74258','origin','padding-bottom','10',0,'8356'),(606675,190978,'74258','origin','margin-bottom','10',0,'8356'),(606676,190978,'74258','origin','border-bottom-width','1',0,'8356'),(606677,190978,'74258','origin','border-bottom-color','$content-border-1',0,'8356'),(606678,190979,'94723','origin','block_type','5',0,''),(606679,190980,'94724','origin','text','##TEXT_LANGUAGE##',0,''),(606680,190982,'94726','origin','block_type','5',0,''),(606681,190983,'94727','origin','text','##TEXT_CURRENCY##',0,''),(606682,190985,'74263','origin','block_type','1',0,''),(606683,190985,'74263','origin','font-weight','normal',0,''),(606684,190986,'74264','origin','block_type','2',0,''),(606685,190986,'74264','origin','font-weight','normal',0,''),(606686,190986,'74264','origin','padding-bottom','20',0,''),(606687,190987,'74265','origin','block_type','1',0,''),(606688,190987,'74265','origin','margin-right','20',0,''),(606689,190990,'74268','origin','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(606690,190990,'74268','origin','font-weight','normal',0,''),(606691,190990,'74268','origin','padding-bottom','20',0,''),(606692,190990,'74268','origin','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',0,''),(606693,190992,'74270','origin','block_type','1',0,''),(606694,190992,'74270','origin','font-weight','normal',0,''),(606695,190992,'74270','origin','style_class','gift-card-view',0,''),(606696,190992,'74270','origin','text-align','center',0,''),(606697,190992,'74270','origin','padding-bottom','20',0,''),(606698,190992,'74270','origin','background-color','$highlight-box-bg-1',0,''),(606699,190992,'74270','origin','padding-left','20',0,''),(606700,190992,'74270','origin','padding-right','20',0,''),(606701,190992,'74270','origin','color','$highlight-box-color-1',0,''),(606702,190993,'74271','origin','block_type','1',0,''),(606703,190993,'74271','origin','font-weight','normal',0,''),(606704,190993,'74271','origin','padding-top','10',0,''),(606705,190994,'74272','origin','font-size','12',0,''),(606706,190994,'74272','origin','font-weight','bold',0,''),(606707,190994,'74272','origin','text-align','center',0,''),(606708,190994,'74272','origin','style_class','email',0,''),(606709,190995,'74273','origin','text','<p>If you require further assistance please contact us</p>',1,''),(606710,190995,'74273','origin','font-weight','normal',0,''),(606711,190995,'74273','origin','text-align','center',0,''),(606712,190995,'74273','origin','font-size','12',0,''),(606713,190995,'74273','origin','padding-top','10',0,''),(606714,190995,'74273','origin','padding-bottom','5',0,''),(606715,190995,'74273','origin','border-top-width','1',0,''),(606716,190995,'74273','origin','border-top-color','$content-border-3',0,''),(606717,190995,'74273','origin','text','<p>If you require further assistance please contact us</p>',0,''),(606718,190996,'74274','origin','font-size','12',0,''),(606719,190996,'74274','origin','font-weight','bold',0,''),(606720,190996,'74274','origin','text-align','center',0,''),(606721,190996,'74274','origin','style_class','phone',0,''),(606722,190996,'74274','origin','padding-bottom','5',0,''),(606723,190997,'74275','origin','text','<p>WHAT TO DO NEXT:</p>',1,''),(606724,190997,'74275','origin','font-weight','normal',0,''),(606725,190997,'74275','origin','text-align','center',0,''),(606726,190997,'74275','origin','padding-top','20',0,''),(606727,190997,'74275','origin','padding-bottom','10',0,''),(606728,190997,'74275','origin','style_class','question-ico',0,''),(606729,190997,'74275','origin','border-top-width','1',0,''),(606730,190997,'74275','origin','border-top-color','$content-border-3',0,''),(606731,190997,'74275','origin','font-size','18',0,''),(606732,190997,'74275','origin','text','<p>WHAT TO DO NEXT:</p>',0,''),(606733,190998,'74276','origin','text','<p>osCommerce</p>\n',1,''),(606734,190998,'74276','origin','font-family','$font-1',0,''),(606735,190998,'74276','origin','font-size','24',0,''),(606736,190998,'74276','origin','font-weight','normal',0,''),(606737,190998,'74276','origin','text-align','center',0,''),(606738,190998,'74276','origin','padding-top','10',0,''),(606739,190998,'74276','origin','padding-bottom','20',0,''),(606740,190998,'74276','origin','text','<p>osCommerce</p>\n',0,''),(606741,190999,'74277','origin','block_type','4',0,''),(606742,190999,'74277','origin','color','$highlight-box-color-2',0,''),(606743,190999,'74277','origin','font-size','30',0,''),(606744,190999,'74277','origin','font-weight','normal',0,''),(606745,190999,'74277','origin','background-color','$highlight-box-bg-2',0,''),(606746,190999,'74277','origin','padding-top','5',0,''),(606747,190999,'74277','origin','padding-left','10',0,''),(606748,190999,'74277','origin','padding-right','10',0,''),(606749,190999,'74277','origin','padding-bottom','5',0,''),(606750,191000,'74278','origin','text','<p>Your code is:</p>',1,''),(606751,191000,'74278','origin','font-weight','normal',0,''),(606752,191000,'74278','origin','text','<p>Your code is:</p>',0,''),(606753,191002,'74280','origin','font-weight','normal',0,''),(606754,191002,'74280','origin','text-align','center',0,''),(606755,191002,'74280','origin','padding-bottom','20',0,''),(606756,191003,'74281','origin','font-size','60',0,''),(606757,191003,'74281','origin','font-weight','bold',0,''),(606758,191003,'74281','origin','text-align','center',0,''),(606759,191003,'74281','origin','line-height','100',0,''),(606760,191003,'74281','origin','padding-bottom','20',0,''),(606761,191003,'74281','origin','line_height_measure','px',0,''),(606762,191004,'74282','origin','text','<p>PERSONAL MESSAGE</p>',1,''),(606763,191004,'74282','origin','font-size','18',0,''),(606764,191004,'74282','origin','font-weight','normal',0,''),(606765,191004,'74282','origin','text-align','center',0,''),(606766,191004,'74282','origin','padding-top','20',0,''),(606767,191004,'74282','origin','padding-bottom','10',0,''),(606768,191004,'74282','origin','border-top-width','1',0,''),(606769,191004,'74282','origin','border-top-color','$content-border-3',0,''),(606770,191004,'74282','origin','text','<p>PERSONAL MESSAGE</p>',0,''),(606771,191005,'74284','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',1,''),(606772,191005,'74284','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',0,''),(606773,191005,'74284','origin','text-align','center',0,''),(606774,191005,'74284','origin','padding-top','20',0,''),(606775,191005,'74284','origin','logo_from','theme',0,''),(606776,191006,'74285','origin','text','<p>GIFT CARD</p>',1,''),(606777,191006,'74285','origin','font-size','30',0,''),(606778,191006,'74285','origin','font-weight','normal',0,''),(606779,191006,'74285','origin','border-top-width','1',0,''),(606780,191006,'74285','origin','border-top-color','$content-border-3',0,''),(606781,191006,'74285','origin','style_class','gift-ico',0,''),(606782,191006,'74285','origin','text-align','center',0,''),(606783,191006,'74285','origin','padding-top','15',0,''),(606784,191006,'74285','origin','text','<p>GIFT CARD</p>',0,''),(606785,191007,'74286','origin','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(606786,191007,'74286','origin','font-weight','normal',0,''),(606787,191007,'74286','origin','text-align','center',0,''),(606788,191007,'74286','origin','padding-bottom','10',0,''),(606789,191007,'74286','origin','font-size','14',0,''),(606790,191007,'74286','origin','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',0,''),(606791,191008,'74287','origin','block_type','1',0,''),(606792,191008,'74287','origin','font-weight','normal',0,''),(606793,191008,'74287','origin','style_class','gift-card-view',0,''),(606794,191008,'74287','origin','text-align','center',0,''),(606795,191008,'74287','origin','padding-bottom','20',0,''),(606796,191008,'74287','origin','background-color','$content-bg-2',0,''),(606797,191008,'74287','origin','padding-left','20',0,''),(606798,191008,'74287','origin','padding-right','20',0,''),(606799,191008,'74287','origin','color','$fade-color-2',0,''),(606800,191009,'74288','origin','font-size','60',0,''),(606801,191009,'74288','origin','font-weight','bold',0,''),(606802,191009,'74288','origin','text-align','center',0,''),(606803,191009,'74288','origin','line-height','100',0,''),(606804,191009,'74288','origin','padding-bottom','20',0,''),(606805,191009,'74288','origin','line_height_measure','px',0,''),(606806,191010,'74289','origin','block_type','4',0,''),(606807,191010,'74289','origin','color','$highlight-box-color-2',0,''),(606808,191010,'74289','origin','font-size','30',0,''),(606809,191010,'74289','origin','font-weight','normal',0,''),(606810,191010,'74289','origin','background-color','$highlight-box-bg-2',0,''),(606811,191010,'74289','origin','padding-top','5',0,''),(606812,191010,'74289','origin','padding-left','10',0,''),(606813,191010,'74289','origin','padding-right','10',0,''),(606814,191010,'74289','origin','padding-bottom','5',0,''),(606815,191011,'74290','origin','text','<p>Your code is:</p>',1,''),(606816,191011,'74290','origin','font-weight','normal',0,''),(606817,191011,'74290','origin','text','<p>Your code is:</p>',0,''),(606818,191013,'74292','origin','block_type','1',0,''),(606819,191013,'74292','origin','font-weight','normal',0,''),(606820,191013,'74292','origin','padding-top','10',0,''),(606821,191014,'74293','origin','font-size','12',0,''),(606822,191014,'74293','origin','font-weight','bold',0,''),(606823,191014,'74293','origin','text-align','center',0,''),(606824,191014,'74293','origin','style_class','email',0,''),(606825,191015,'74294','origin','text','<p>If you require further assistance please contact us</p>',1,''),(606826,191015,'74294','origin','font-weight','normal',0,''),(606827,191015,'74294','origin','text-align','center',0,''),(606828,191015,'74294','origin','font-size','12',0,''),(606829,191015,'74294','origin','padding-top','10',0,''),(606830,191015,'74294','origin','padding-bottom','5',0,''),(606831,191015,'74294','origin','border-top-width','1',0,''),(606832,191015,'74294','origin','border-top-color','$content-border-3',0,''),(606833,191015,'74294','origin','text','<p>If you require further assistance please contact us</p>',0,''),(606834,191016,'74295','origin','font-size','12',0,''),(606835,191016,'74295','origin','font-weight','bold',0,''),(606836,191016,'74295','origin','text-align','center',0,''),(606837,191016,'74295','origin','style_class','phone',0,''),(606838,191016,'74295','origin','padding-bottom','5',0,''),(606839,191017,'74296','origin','font-weight','normal',0,''),(606840,191017,'74296','origin','text-align','center',0,''),(606841,191017,'74296','origin','padding-bottom','20',0,''),(606842,191018,'74297','origin','text','<p>PERSONAL MESSAGE</p>',1,''),(606843,191018,'74297','origin','font-size','18',0,''),(606844,191018,'74297','origin','font-weight','normal',0,''),(606845,191018,'74297','origin','text-align','center',0,''),(606846,191018,'74297','origin','padding-top','20',0,''),(606847,191018,'74297','origin','padding-bottom','10',0,''),(606848,191018,'74297','origin','border-top-width','1',0,''),(606849,191018,'74297','origin','border-top-color','$content-border-3',0,''),(606850,191018,'74297','origin','text','<p>PERSONAL MESSAGE</p>',0,''),(606851,191019,'74298','origin','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(606852,191019,'74298','origin','font-weight','normal',0,''),(606853,191019,'74298','origin','text-align','center',0,''),(606854,191019,'74298','origin','padding-bottom','10',0,''),(606855,191019,'74298','origin','font-size','14',0,''),(606856,191019,'74298','origin','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',0,''),(606857,191020,'74299','origin','text','<p>GIFT CARD</p>',1,''),(606858,191020,'74299','origin','font-size','30',0,''),(606859,191020,'74299','origin','font-weight','normal',0,''),(606860,191020,'74299','origin','border-top-width','1',0,''),(606861,191020,'74299','origin','border-top-color','$content-border-3',0,''),(606862,191020,'74299','origin','style_class','gift-ico',0,''),(606863,191020,'74299','origin','text-align','center',0,''),(606864,191020,'74299','origin','padding-top','15',0,''),(606865,191020,'74299','origin','text','<p>GIFT CARD</p>',0,''),(606866,191021,'74300','origin','text','<p>WHAT TO DO NEXT:</p>',1,''),(606867,191021,'74300','origin','font-weight','normal',0,''),(606868,191021,'74300','origin','text-align','center',0,''),(606869,191021,'74300','origin','padding-top','20',0,''),(606870,191021,'74300','origin','padding-bottom','10',0,''),(606871,191021,'74300','origin','style_class','question-ico',0,''),(606872,191021,'74300','origin','border-top-width','1',0,''),(606873,191021,'74300','origin','border-top-color','$content-border-3',0,''),(606874,191021,'74300','origin','font-size','18',0,''),(606875,191021,'74300','origin','text','<p>WHAT TO DO NEXT:</p>',0,''),(606876,191022,'74301','origin','text','<p>HOLBI</p>',1,''),(606877,191022,'74301','origin','font-family','$font-1',0,''),(606878,191022,'74301','origin','font-size','24',0,''),(606879,191022,'74301','origin','font-weight','normal',0,''),(606880,191022,'74301','origin','text-align','center',0,''),(606881,191022,'74301','origin','padding-top','10',0,''),(606882,191022,'74301','origin','padding-bottom','20',0,''),(606883,191022,'74301','origin','text','<p>HOLBI</p>',0,''),(606884,191023,'94729','origin','block_type','1',0,''),(606885,191023,'94729','origin','font-weight','normal',0,''),(606886,191023,'94729','origin','style_class','gift-card-view',0,''),(606887,191023,'94729','origin','text-align','center',0,''),(606888,191023,'94729','origin','padding-bottom','20',0,''),(606889,191023,'94729','origin','background-color','$content-bg-2',0,''),(606890,191023,'94729','origin','padding-left','20',0,''),(606891,191023,'94729','origin','padding-right','20',0,''),(606892,191024,'94730','origin','block_type','1',0,''),(606893,191024,'94730','origin','font-weight','normal',0,''),(606894,191024,'94730','origin','padding-top','10',0,''),(606895,191025,'94731','origin','font-size','12',0,''),(606896,191025,'94731','origin','font-weight','bold',0,''),(606897,191025,'94731','origin','text-align','center',0,''),(606898,191025,'94731','origin','style_class','email',0,''),(606899,191026,'94732','origin','font-size','12',0,''),(606900,191026,'94732','origin','font-weight','bold',0,''),(606901,191026,'94732','origin','text-align','center',0,''),(606902,191026,'94732','origin','style_class','phone',0,''),(606903,191026,'94732','origin','padding-bottom','5',0,''),(606904,191027,'94733','origin','text','If you require further assistance please contact us',0,''),(606905,191027,'94733','origin','font-size','12',0,''),(606906,191027,'94733','origin','text-align','center',0,''),(606907,191027,'94733','origin','padding-top','10',0,''),(606908,191028,'94734','origin','block_type','4',0,''),(606909,191028,'94734','origin','color','$highlight-box-color-2',0,''),(606910,191028,'94734','origin','font-size','30',0,''),(606911,191028,'94734','origin','font-weight','normal',0,''),(606912,191028,'94734','origin','background-color','$highlight-box-bg-2',0,''),(606913,191028,'94734','origin','padding-top','5',0,''),(606914,191028,'94734','origin','padding-left','10',0,''),(606915,191028,'94734','origin','padding-right','10',0,''),(606916,191028,'94734','origin','padding-bottom','5',0,''),(606917,191029,'94735','origin','text','Your code is:',0,''),(606918,191029,'94735','origin','font-size','30',0,''),(606919,191029,'94735','origin','color','$highlight-box-color-2',0,''),(606920,191030,'94736','origin','color','$highlight-box-color-2',0,''),(606921,191030,'94736','origin','font-size','30',0,''),(606922,191031,'94737','origin','block_type','1',0,''),(606923,191032,'94738','origin','text','<p>PERSONAL MESSAGE</p>',1,''),(606924,191032,'94738','origin','font-size','18',0,''),(606925,191032,'94738','origin','font-weight','normal',0,''),(606926,191032,'94738','origin','text-align','center',0,''),(606927,191032,'94738','origin','padding-top','20',0,''),(606928,191032,'94738','origin','padding-bottom','10',0,''),(606929,191032,'94738','origin','border-top-width','1',0,''),(606930,191032,'94738','origin','border-top-color','$content-border-3',0,''),(606931,191032,'94738','origin','text','<p>PERSONAL MESSAGE</p>',0,''),(606932,191033,'94739','origin','text','HOLBI',0,''),(606933,191033,'94739','origin','font-size','24',0,''),(606934,191033,'94739','origin','padding-top','20',0,''),(606935,191033,'94739','origin','text-align','center',0,''),(606936,191033,'94739','origin','padding-bottom','20',0,''),(606937,191034,'94740','origin','border-top-color','$content-border-3',0,''),(606938,191034,'94740','origin','border-top-width','1',0,''),(606939,191034,'94740','origin','padding-top','20',0,''),(606940,191034,'94740','origin','font-size','30',0,''),(606941,191034,'94740','origin','text-align','center',0,''),(606942,191034,'94740','origin','text','GIFT CARD',0,''),(606943,191035,'94741','origin','text-align','center',0,''),(606944,191035,'94741','origin','font-weight','bold',0,''),(606945,191035,'94741','origin','font-size','60',0,''),(606946,191036,'94742','origin','font-size','20',0,''),(606947,191036,'94742','origin','text-align','center',0,''),(606948,191036,'94742','origin','padding-top','20',0,''),(606949,191036,'94742','origin','padding-bottom','20',0,''),(606950,191037,'94743','origin','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(606951,191037,'94743','origin','text-align','center',0,''),(606952,191037,'94743','origin','font-size','14',0,''),(606953,191037,'94743','origin','padding-bottom','20',0,''),(606954,191038,'94744','origin','text','WHAT TO DO NEXT:',0,''),(606955,191038,'94744','origin','font-size','18',0,''),(606956,191038,'94744','origin','text-align','center',0,''),(606957,191038,'94744','origin','padding-top','20',0,''),(606958,191038,'94744','origin','padding-bottom','10',0,''),(606959,191038,'94744','origin','border-top-width','1',0,''),(606960,191038,'94744','origin','border-top-color','$content-border-3',0,''),(606961,191039,'94746','origin','block_type','1',0,''),(606962,191039,'94746','origin','font-weight','normal',0,''),(606963,191039,'94746','origin','style_class','gift-card-view',0,''),(606964,191039,'94746','origin','text-align','center',0,''),(606965,191039,'94746','origin','padding-bottom','20',0,''),(606966,191039,'94746','origin','background-color','$highlight-box-bg-1',0,''),(606967,191039,'94746','origin','padding-left','20',0,''),(606968,191039,'94746','origin','padding-right','20',0,''),(606969,191039,'94746','origin','color','$highlight-box-color-1',0,''),(606970,191040,'94747','origin','block_type','1',0,''),(606971,191040,'94747','origin','font-weight','normal',0,''),(606972,191040,'94747','origin','padding-top','10',0,''),(606973,191041,'94748','origin','font-size','12',0,''),(606974,191041,'94748','origin','font-weight','bold',0,''),(606975,191041,'94748','origin','text-align','center',0,''),(606976,191041,'94748','origin','style_class','email',0,''),(606977,191041,'94748','origin','color','$highlight-box-color-1',0,''),(606978,191042,'94749','origin','font-size','12',0,''),(606979,191042,'94749','origin','font-weight','bold',0,''),(606980,191042,'94749','origin','text-align','center',0,''),(606981,191042,'94749','origin','style_class','phone',0,''),(606982,191042,'94749','origin','padding-bottom','5',0,''),(606983,191042,'94749','origin','color','$highlight-box-color-1',0,''),(606984,191043,'94750','origin','text','If you require further assistance please contact us',0,''),(606985,191043,'94750','origin','font-size','12',0,''),(606986,191043,'94750','origin','color','$highlight-box-color-1',0,''),(606987,191043,'94750','origin','text-align','center',0,''),(606988,191043,'94750','origin','padding-top','10',0,''),(606989,191044,'94751','origin','block_type','4',0,''),(606990,191044,'94751','origin','color','$highlight-box-color-2',0,''),(606991,191044,'94751','origin','font-size','30',0,''),(606992,191044,'94751','origin','font-weight','normal',0,''),(606993,191044,'94751','origin','background-color','$highlight-box-bg-2',0,''),(606994,191044,'94751','origin','padding-top','5',0,''),(606995,191044,'94751','origin','padding-left','10',0,''),(606996,191044,'94751','origin','padding-right','10',0,''),(606997,191044,'94751','origin','padding-bottom','5',0,''),(606998,191045,'94752','origin','text','Your code is:',0,''),(606999,191045,'94752','origin','font-size','30',0,''),(607000,191045,'94752','origin','color','$highlight-box-color-2',0,''),(607001,191046,'94753','origin','color','$highlight-box-color-2',0,''),(607002,191046,'94753','origin','font-size','30',0,''),(607003,191047,'94754','origin','block_type','1',0,''),(607004,191048,'94755','origin','text','<p>PERSONAL MESSAGE</p>',1,''),(607005,191048,'94755','origin','font-size','18',0,''),(607006,191048,'94755','origin','font-weight','normal',0,''),(607007,191048,'94755','origin','text-align','center',0,''),(607008,191048,'94755','origin','padding-top','20',0,''),(607009,191048,'94755','origin','padding-bottom','10',0,''),(607010,191048,'94755','origin','border-top-width','1',0,''),(607011,191048,'94755','origin','border-top-color','$content-border-3',0,''),(607012,191048,'94755','origin','text','<p>PERSONAL MESSAGE</p>',0,''),(607013,191049,'94757','origin','border-top-color','$content-border-3',0,''),(607014,191049,'94757','origin','border-top-width','1',0,''),(607015,191049,'94757','origin','padding-top','20',0,''),(607016,191049,'94757','origin','font-size','30',0,''),(607017,191049,'94757','origin','text-align','center',0,''),(607018,191049,'94757','origin','color','$highlight-box-color-1',0,''),(607019,191049,'94757','origin','text','GIFT CARD',0,''),(607020,191050,'94758','origin','text-align','center',0,''),(607021,191050,'94758','origin','font-weight','bold',0,''),(607022,191050,'94758','origin','font-size','60',0,''),(607023,191050,'94758','origin','color','$highlight-box-color-1',0,''),(607024,191051,'94759','origin','font-size','20',0,''),(607025,191051,'94759','origin','text-align','center',0,''),(607026,191051,'94759','origin','color','$highlight-box-color-1',0,''),(607027,191051,'94759','origin','padding-top','20',0,''),(607028,191051,'94759','origin','padding-bottom','20',0,''),(607029,191052,'94760','origin','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(607030,191052,'94760','origin','text-align','center',0,''),(607031,191052,'94760','origin','color','$highlight-box-color-1',0,''),(607032,191052,'94760','origin','font-size','14',0,''),(607033,191052,'94760','origin','padding-bottom','20',0,''),(607034,191053,'94761','origin','text','WHAT TO DO NEXT:',0,''),(607035,191053,'94761','origin','font-size','18',0,''),(607036,191053,'94761','origin','text-align','center',0,''),(607037,191053,'94761','origin','padding-top','20',0,''),(607038,191053,'94761','origin','padding-bottom','10',0,''),(607039,191053,'94761','origin','border-top-width','1',0,''),(607040,191053,'94761','origin','border-top-color','$content-border-3',0,''),(607041,191054,'1707902674.2595','origin','logo_from','theme',0,''),(607042,191054,'1707902674.2595','origin','text-align','center',0,''),(607043,191054,'1707902674.2595','origin','padding-top','20',0,''),(607044,191056,'74302','origin','block_type','1',0,''),(607045,191058,'74304','origin','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(607046,191058,'74304','origin','text-align','center',0,''),(607047,191059,'74305','origin','block_type','1',0,''),(607048,191059,'74305','origin','font-weight','normal',0,''),(607049,191059,'74305','origin','style_class','gift-card-view',0,''),(607050,191059,'74305','origin','text-align','center',0,''),(607051,191059,'74305','origin','padding-bottom','20',0,''),(607052,191059,'74305','origin','background-color','$highlight-box-bg-3',0,''),(607053,191059,'74305','origin','padding-left','20',0,''),(607054,191059,'74305','origin','padding-right','20',0,''),(607055,191059,'74305','origin','color','$highlight-box-color-3',0,''),(607056,191060,'74306','origin','block_type','4',0,''),(607057,191060,'74306','origin','color','$highlight-box-color-2',0,''),(607058,191060,'74306','origin','font-size','30',0,''),(607059,191060,'74306','origin','font-weight','normal',0,''),(607060,191060,'74306','origin','background-color','$highlight-box-bg-2',0,''),(607061,191060,'74306','origin','padding-top','5',0,''),(607062,191060,'74306','origin','padding-left','10',0,''),(607063,191060,'74306','origin','padding-right','10',0,''),(607064,191060,'74306','origin','padding-bottom','5',0,''),(607065,191061,'74307','origin','text','<p>Your code is:</p>',1,''),(607066,191061,'74307','origin','font-weight','normal',0,''),(607067,191061,'74307','origin','text','<p>Your code is:</p>',0,''),(607068,191063,'74309','origin','text','<p>WHAT TO DO NEXT:</p>',1,''),(607069,191063,'74309','origin','font-weight','normal',0,''),(607070,191063,'74309','origin','text-align','center',0,''),(607071,191063,'74309','origin','padding-top','20',0,''),(607072,191063,'74309','origin','padding-bottom','10',0,''),(607073,191063,'74309','origin','style_class','question-ico',0,''),(607074,191063,'74309','origin','border-top-width','1',0,''),(607075,191063,'74309','origin','border-top-color','$content-border-3',0,''),(607076,191063,'74309','origin','font-size','18',0,''),(607077,191063,'74309','origin','text','<p>WHAT TO DO NEXT:</p>',0,''),(607078,191064,'74310','origin','text','<p>osCommerce</p>\n',1,''),(607079,191064,'74310','origin','font-family','$font-1',0,''),(607080,191064,'74310','origin','font-size','24',0,''),(607081,191064,'74310','origin','font-weight','normal',0,''),(607082,191064,'74310','origin','text-align','center',0,''),(607083,191064,'74310','origin','padding-top','10',0,''),(607084,191064,'74310','origin','padding-bottom','20',0,''),(607085,191064,'74310','origin','text','<p>osCommerce</p>\n',0,''),(607086,191065,'74311','origin','block_type','1',0,''),(607087,191065,'74311','origin','font-weight','normal',0,''),(607088,191065,'74311','origin','padding-top','10',0,''),(607089,191066,'74312','origin','text','<p>If you require further assistance please contact us</p>',1,''),(607090,191066,'74312','origin','font-weight','normal',0,''),(607091,191066,'74312','origin','text-align','center',0,''),(607092,191066,'74312','origin','font-size','12',0,''),(607093,191066,'74312','origin','padding-top','10',0,''),(607094,191066,'74312','origin','padding-bottom','5',0,''),(607095,191066,'74312','origin','border-top-width','1',0,''),(607096,191066,'74312','origin','border-top-color','$content-border-3',0,''),(607097,191066,'74312','origin','text','<p>If you require further assistance please contact us</p>',0,''),(607098,191067,'74313','origin','font-size','12',0,''),(607099,191067,'74313','origin','font-weight','bold',0,''),(607100,191067,'74313','origin','text-align','center',0,''),(607101,191067,'74313','origin','style_class','email',0,''),(607102,191068,'74314','origin','font-size','12',0,''),(607103,191068,'74314','origin','font-weight','bold',0,''),(607104,191068,'74314','origin','text-align','center',0,''),(607105,191068,'74314','origin','style_class','phone',0,''),(607106,191068,'74314','origin','padding-bottom','5',0,''),(607107,191069,'74315','origin','font-weight','normal',0,''),(607108,191069,'74315','origin','text-align','center',0,''),(607109,191069,'74315','origin','padding-bottom','20',0,''),(607110,191070,'74316','origin','text','<p>GIFT CARD</p>',1,''),(607111,191070,'74316','origin','font-size','30',0,''),(607112,191070,'74316','origin','font-weight','normal',0,''),(607113,191070,'74316','origin','border-top-width','1',0,''),(607114,191070,'74316','origin','border-top-color','$content-border-3',0,''),(607115,191070,'74316','origin','style_class','gift-ico',0,''),(607116,191070,'74316','origin','text-align','center',0,''),(607117,191070,'74316','origin','padding-top','15',0,''),(607118,191070,'74316','origin','text','<p>GIFT CARD</p>',0,''),(607119,191071,'74317','origin','text','<p>PERSONAL MESSAGE</p>',1,''),(607120,191071,'74317','origin','font-size','18',0,''),(607121,191071,'74317','origin','font-weight','normal',0,''),(607122,191071,'74317','origin','text-align','center',0,''),(607123,191071,'74317','origin','padding-top','20',0,''),(607124,191071,'74317','origin','padding-bottom','10',0,''),(607125,191071,'74317','origin','border-top-width','1',0,''),(607126,191071,'74317','origin','border-top-color','$content-border-3',0,''),(607127,191071,'74317','origin','text','<p>PERSONAL MESSAGE</p>',0,''),(607128,191072,'74318','origin','font-size','60',0,''),(607129,191072,'74318','origin','font-weight','bold',0,''),(607130,191072,'74318','origin','text-align','center',0,''),(607131,191072,'74318','origin','line-height','100',0,''),(607132,191072,'74318','origin','padding-bottom','20',0,''),(607133,191072,'74318','origin','line_height_measure','px',0,''),(607134,191073,'74319','origin','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(607135,191073,'74319','origin','font-weight','normal',0,''),(607136,191073,'74319','origin','text-align','center',0,''),(607137,191073,'74319','origin','padding-bottom','10',0,''),(607138,191073,'74319','origin','font-size','14',0,''),(607139,191073,'74319','origin','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',0,''),(607140,191074,'94763','origin','block_type','1',0,''),(607141,191074,'94763','origin','font-weight','normal',0,''),(607142,191074,'94763','origin','style_class','gift-card-view',0,''),(607143,191074,'94763','origin','text-align','center',0,''),(607144,191074,'94763','origin','padding-bottom','20',0,''),(607145,191074,'94763','origin','background-color','$highlight-box-bg-3',0,''),(607146,191074,'94763','origin','padding-left','20',0,''),(607147,191074,'94763','origin','padding-right','20',0,''),(607148,191074,'94763','origin','color','$highlight-box-color-3',0,''),(607149,191075,'94764','origin','block_type','1',0,''),(607150,191075,'94764','origin','font-weight','normal',0,''),(607151,191075,'94764','origin','padding-top','10',0,''),(607152,191076,'94765','origin','font-size','12',0,''),(607153,191076,'94765','origin','font-weight','bold',0,''),(607154,191076,'94765','origin','text-align','center',0,''),(607155,191076,'94765','origin','style_class','email',0,''),(607156,191077,'94766','origin','font-size','12',0,''),(607157,191077,'94766','origin','font-weight','bold',0,''),(607158,191077,'94766','origin','text-align','center',0,''),(607159,191077,'94766','origin','style_class','phone',0,''),(607160,191077,'94766','origin','padding-bottom','5',0,''),(607161,191078,'94767','origin','text','If you require further assistance please contact us',0,''),(607162,191078,'94767','origin','font-size','12',0,''),(607163,191078,'94767','origin','text-align','center',0,''),(607164,191078,'94767','origin','padding-top','10',0,''),(607165,191079,'94768','origin','block_type','4',0,''),(607166,191079,'94768','origin','color','$highlight-box-color-2',0,''),(607167,191079,'94768','origin','font-size','30',0,''),(607168,191079,'94768','origin','font-weight','normal',0,''),(607169,191079,'94768','origin','background-color','$highlight-box-bg-2',0,''),(607170,191079,'94768','origin','padding-top','5',0,''),(607171,191079,'94768','origin','padding-left','10',0,''),(607172,191079,'94768','origin','padding-right','10',0,''),(607173,191079,'94768','origin','padding-bottom','5',0,''),(607174,191080,'94769','origin','text','Your code is:',0,''),(607175,191080,'94769','origin','font-size','30',0,''),(607176,191080,'94769','origin','color','$highlight-box-color-2',0,''),(607177,191081,'94770','origin','color','$highlight-box-color-2',0,''),(607178,191081,'94770','origin','font-size','30',0,''),(607179,191082,'94771','origin','block_type','1',0,''),(607180,191083,'94772','origin','text','<p>PERSONAL MESSAGE</p>',1,''),(607181,191083,'94772','origin','font-size','18',0,''),(607182,191083,'94772','origin','font-weight','normal',0,''),(607183,191083,'94772','origin','text-align','center',0,''),(607184,191083,'94772','origin','padding-top','20',0,''),(607185,191083,'94772','origin','padding-bottom','10',0,''),(607186,191083,'94772','origin','border-top-width','1',0,''),(607187,191083,'94772','origin','border-top-color','$content-border-3',0,''),(607188,191083,'94772','origin','text','<p>PERSONAL MESSAGE</p>',0,''),(607189,191084,'94773','origin','text','HOLBI',0,''),(607190,191084,'94773','origin','color','$highlight-box-color-3',0,''),(607191,191084,'94773','origin','font-size','24',0,''),(607192,191084,'94773','origin','padding-top','20',0,''),(607193,191084,'94773','origin','text-align','center',0,''),(607194,191084,'94773','origin','padding-bottom','20',0,''),(607195,191085,'94774','origin','border-top-color','$content-border-3',0,''),(607196,191085,'94774','origin','border-top-width','1',0,''),(607197,191085,'94774','origin','padding-top','20',0,''),(607198,191085,'94774','origin','font-size','30',0,''),(607199,191085,'94774','origin','text-align','center',0,''),(607200,191085,'94774','origin','color','$highlight-box-color-3',0,''),(607201,191085,'94774','origin','text','GIFT CARD',0,''),(607202,191086,'94775','origin','text-align','center',0,''),(607203,191086,'94775','origin','font-weight','bold',0,''),(607204,191086,'94775','origin','font-size','60',0,''),(607205,191086,'94775','origin','color','$highlight-box-color-3',0,''),(607206,191087,'94776','origin','font-size','20',0,''),(607207,191087,'94776','origin','text-align','center',0,''),(607208,191087,'94776','origin','padding-top','20',0,''),(607209,191087,'94776','origin','padding-bottom','20',0,''),(607210,191088,'94777','origin','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(607211,191088,'94777','origin','text-align','center',0,''),(607212,191088,'94777','origin','font-size','14',0,''),(607213,191088,'94777','origin','padding-bottom','20',0,''),(607214,191089,'94778','origin','text','WHAT TO DO NEXT:',0,''),(607215,191089,'94778','origin','font-size','18',0,''),(607216,191089,'94778','origin','text-align','center',0,''),(607217,191089,'94778','origin','padding-top','20',0,''),(607218,191089,'94778','origin','padding-bottom','10',0,''),(607219,191089,'94778','origin','border-top-width','1',0,''),(607220,191089,'94778','origin','border-top-color','$content-border-3',0,''),(607221,191090,'1713770938.449798','origin','from_file','header_1.zip',0,''),(607222,191091,'1713770938.464587','origin','block_type','1',0,''),(607223,191091,'1713770938.464587','origin','border-bottom-width','1',0,''),(607224,191091,'1713770938.464587','origin','border-bottom-color','$header-border-1',0,''),(607225,191091,'1713770938.464587','origin','font-weight','normal',0,''),(607226,191091,'1713770938.464587','origin','visibility_checkout','1',0,''),(607227,191091,'1713770938.464587','origin','background-color','$header-bg-1',0,''),(607228,191091,'1713770938.464587','origin','color','$header-color-1',0,''),(607229,191091,'1713770938.464587','origin','from_file','header_1.zip',0,''),(607230,191092,'1713770938.467593','origin','block_type','5',0,''),(607231,191092,'1713770938.467593','origin','font-weight','400',0,''),(607232,191092,'1713770938.467593','origin','schema','2-2',0,''),(607233,191092,'1713770938.467593','origin','schema','5-2',0,'8356'),(607234,191092,'1713770938.467593','origin','schema','5-1',0,'8377'),(607235,191093,'1713770938.470248','origin','class','menu-horizontal',0,''),(607236,191093,'1713770938.470248','origin','box_align','1',0,''),(607237,191093,'1713770938.470248','origin','font-weight','400',0,''),(607238,191093,'1713770938.470248','origin','border-top-width','1',0,'8356'),(607239,191093,'1713770938.470248','origin','border-top-color','$content-border-1',0,'8356'),(607240,191093,'1713770938.470248','origin','display','none',0,'8356'),(607241,191094,'1713770938.51635','origin','block_type','1',0,''),(607242,191095,'1713770938.51828','origin','font-weight','400',0,''),(607243,191095,'1713770938.51828','origin','box_align','3',0,''),(607244,191095,'1713770938.51828','origin','show_products','dropdown',0,''),(607245,191095,'1713770938.51828','origin','only_icon','on',0,''),(607246,191096,'1713770938.573998','origin','font-weight','normal',0,''),(607247,191096,'1713770938.573998','origin','box_align','3',0,''),(607248,191096,'1713770938.573998','origin','border-left-width','1',0,''),(607249,191096,'1713770938.573998','origin','border-left-color','$header-border-1',0,''),(607250,191096,'1713770938.573998','origin','only_icon','on',0,''),(607251,191097,'1713770938.61982','origin','box_align','3',0,''),(607252,191097,'1713770938.61982','origin','font-weight','normal',0,''),(607253,191097,'1713770938.61982','origin','padding-top','0',0,'8356'),(607254,191097,'1713770938.61982','origin','padding-right','0',0,'8356'),(607255,191097,'1713770938.61982','origin','padding-bottom','0',0,'8356'),(607256,191097,'1713770938.61982','origin','padding-left','0',0,'8356'),(607257,191097,'1713770938.61982','origin','show_symbol_left','1',0,''),(607258,191097,'1713770938.61982','origin','show_symbol_right','1',0,''),(607259,191098,'1713770938.663457','origin','box_align','3',0,''),(607260,191098,'1713770938.663457','origin','font-weight','normal',0,''),(607261,191098,'1713770938.663457','origin','border-left-width','1',0,''),(607262,191098,'1713770938.663457','origin','border-left-color','$header-border-1',0,''),(607263,191098,'1713770938.663457','origin','padding-top','0',0,'8356'),(607264,191098,'1713770938.663457','origin','padding-right','0',0,'8356'),(607265,191098,'1713770938.663457','origin','padding-bottom','0',0,'8356'),(607266,191098,'1713770938.663457','origin','padding-left','0',0,'8356'),(607267,191098,'1713770938.663457','origin','show_title','1',0,''),(607268,191099,'1713770938.697915','origin','block_type','1',0,''),(607269,191099,'1713770938.697915','origin','padding-top','20',0,''),(607270,191099,'1713770938.697915','origin','padding-bottom','20',0,''),(607271,191099,'1713770938.697915','origin','style_class','header-content',0,''),(607272,191099,'1713770938.697915','origin','color','$header-color-1',0,''),(607273,191099,'1713770938.697915','origin','background-color','$header-bg-1',0,''),(607274,191099,'1713770938.697915','origin','from_file','header_1.zip',0,''),(607275,191099,'1713770938.697915','origin','padding-top','12',0,'8349'),(607276,191099,'1713770938.697915','origin','padding-bottom','12',0,'8349'),(607277,191100,'1713770938.706821','origin','font-weight','400',0,''),(607278,191100,'1713770938.706821','origin','box_align','1',0,''),(607279,191100,'1713770938.706821','origin','text-align','center',0,'8377'),(607280,191100,'1713770938.706821','origin','width','100',0,'8377'),(607281,191100,'1713770938.706821','origin','width_measure','%',0,'8377'),(607282,191100,'1713770938.706821','origin','logo_from','theme',0,''),(607283,191100,'1713770938.706821','origin','padding-right','20',0,''),(607284,191101,'1713770938.709156','origin','visibility_checkout','1',0,''),(607285,191101,'1713770938.709156','origin','search_history','1',0,''),(607286,191101,'1713770938.709156','origin','history_items','5',0,''),(607287,191101,'1713770938.709156','origin','margin-left','20',0,''),(607288,191102,'1713770938.773998','origin','text','<p class=\"customer-service\">Customer service <b>08000112569</b></p>',1,''),(607289,191102,'1713770938.773998','origin','float','right',0,''),(607290,191102,'1713770938.773998','origin','display_none','1',0,'8377'),(607291,191102,'1713770938.773998','origin','text','<p class=\"customer-service\">Customer service <b>08000112569</b></p>',0,''),(607292,191102,'1713770938.773998','origin','display','none',0,'8356'),(607293,191102,'1713770938.773998','origin','margin-left','20',0,''),(607294,191103,'1713770938.811953','origin','block_type','1',0,''),(607295,191103,'1713770938.811953','origin','font-weight','400',0,''),(607296,191103,'1713770938.811953','origin','background-color','$header-menu-bg-1',0,''),(607297,191103,'1713770938.811953','origin','visibility_checkout','1',0,''),(607298,191103,'1713770938.811953','origin','color','$header-menu-color-1',0,''),(607299,191103,'1713770938.811953','origin','from_file','header_1.zip',0,''),(607300,191103,'1713770938.811953','origin','style_class','header-menu-holder',0,''),(607301,191104,'1713770938.81834','origin','class','menu-style-1',0,''),(607302,191104,'1713770938.81834','origin','box_align','4',0,''),(607303,191104,'1713770938.81834','origin','font-weight','400',0,''),(607304,191104,'1713770938.81834','origin','hide_menu','on',0,''),(607305,191104,'1713770938.81834','origin','color','$header-menu-color-1',0,''),(607306,191104,'1713770938.81834','origin','hide_menu','1',0,'8356'),(607307,191104,'1713770938.81834','origin','show_new','1',0,''),(607308,191104,'1713770938.81834','origin','style_class','header-menu',0,''),(607309,191104,'1713770938.81834','origin','type','builder',0,''),(607310,191104,'1713770938.81834','origin','position','horizontal_center',0,'8422'),(607311,191104,'1713770938.81834','origin','style','1',0,'8422'),(607312,191104,'1713770938.81834','origin','lev2_vis','over',0,'8422'),(607313,191104,'1713770938.81834','origin','lev2_display','down',0,'8422'),(607314,191104,'1713770938.81834','origin','lev3_vis','over',0,'8422'),(607315,191104,'1713770938.81834','origin','lev4_vis','over',0,'8422'),(607316,191104,'1713770938.81834','origin','lev5_vis','over',0,'8422'),(607317,191104,'1713770938.81834','origin','lev6_vis','over',0,'8422'),(607318,191104,'1713770938.81834','origin','lev3_display','lra',0,'8422'),(607319,191104,'1713770938.81834','origin','lev4_display','lra',0,'8422'),(607320,191104,'1713770938.81834','origin','lev5_display','lra',0,'8422'),(607321,191104,'1713770938.81834','origin','lev6_display','lra',0,'8422'),(607322,191104,'1713770938.81834','origin','style','2',0,'8356'),(607323,191104,'1713770938.81834','origin','burger_icon','1',0,'8356'),(607324,191104,'1713770938.81834','origin','open_from','top',0,'8356'),(607325,191104,'1713770938.81834','origin','lev2_vis','click',0,'8356'),(607326,191104,'1713770938.81834','origin','lev3_vis','click',0,'8356'),(607327,191104,'1713770938.81834','origin','lev4_vis','click',0,'8356'),(607328,191104,'1713770938.81834','origin','lev5_vis','click',0,'8356'),(607329,191104,'1713770938.81834','origin','lev6_vis','click',0,'8356'),(607330,191104,'1713770938.81834','origin','from_file','menu_1.zip',0,''),(607331,191105,'74346','origin','block_type','1',0,''),(607332,191110,'74351','origin','width','680',0,''),(607333,191110,'74351','origin','font-weight','normal',0,''),(607334,191110,'74351','origin','font-size','12',0,''),(607335,191110,'74351','origin','padding-top','20',0,''),(607336,191110,'74351','origin','padding-bottom','20',0,''),(607337,191110,'74351','origin','color','$content-color-1',0,''),(607338,191111,'74352','origin','block_type','4',0,''),(607339,191111,'74352','origin','font-weight','normal',0,''),(607340,191111,'74352','origin','border-top-width','1',0,''),(607341,191111,'74352','origin','border-top-color','$content-border-1',0,''),(607342,191111,'74352','origin','border-left-width','1',0,''),(607343,191111,'74352','origin','border-left-color','$content-border-1',0,''),(607344,191111,'74352','origin','border-right-width','1',0,''),(607345,191111,'74352','origin','border-right-color','$content-border-1',0,''),(607346,191111,'74352','origin','border-bottom-width','1',0,''),(607347,191111,'74352','origin','border-bottom-color','$content-border-1',0,''),(607348,191112,'74353','origin','block_type','2',0,''),(607349,191112,'74353','origin','font-weight','normal',0,''),(607350,191112,'74353','origin','border-top-width','1',0,''),(607351,191112,'74353','origin','border-top-color','$content-border-1',0,''),(607352,191112,'74353','origin','border-right-width','1',0,''),(607353,191112,'74353','origin','border-right-color','$content-border-1',0,''),(607354,191113,'74354','origin','block_type','1',0,''),(607355,191113,'74354','origin','font-weight','normal',0,''),(607356,191113,'74354','origin','padding-top','10',0,''),(607357,191113,'74354','origin','padding-left','10',0,''),(607358,191113,'74354','origin','padding-right','10',0,''),(607359,191113,'74354','origin','padding-bottom','10',0,''),(607360,191113,'74354','origin','border-right-width','1',0,''),(607361,191113,'74354','origin','border-right-color','$content-border-1',0,''),(607362,191115,'74356','origin','text','<p>Shipping via</p>',1,''),(607363,191115,'74356','origin','font-weight','bold',0,''),(607364,191115,'74356','origin','font-size','14',0,''),(607365,191115,'74356','origin','text','<p>Shipping via</p>',0,''),(607366,191116,'74357','origin','block_type','1',0,''),(607367,191116,'74357','origin','font-weight','normal',0,''),(607368,191116,'74357','origin','padding-top','10',0,''),(607369,191116,'74357','origin','padding-left','10',0,''),(607370,191116,'74357','origin','padding-right','10',0,''),(607371,191116,'74357','origin','padding-bottom','10',0,''),(607372,191117,'74358','origin','text','<p>Shipping service</p>',1,''),(607373,191117,'74358','origin','font-weight','bold',0,''),(607374,191117,'74358','origin','font-size','14',0,''),(607375,191117,'74358','origin','text','<p>Shipping service</p>',0,''),(607376,191119,'74360','origin','block_type','2',0,''),(607377,191119,'74360','origin','font-weight','normal',0,''),(607378,191119,'74360','origin','border-right-width','1',0,''),(607379,191119,'74360','origin','border-right-color','$content-border-1',0,''),(607380,191120,'74361','origin','block_type','1',0,''),(607381,191120,'74361','origin','font-weight','400',0,''),(607382,191120,'74361','origin','background-color','$content-bg-2',0,''),(607383,191120,'74361','origin','padding-top','10',0,''),(607384,191120,'74361','origin','padding-left','10',0,''),(607385,191120,'74361','origin','padding-right','10',0,''),(607386,191120,'74361','origin','padding-bottom','30',0,''),(607387,191121,'74362','origin','text','<p>INVOICE ADDRESS:</p>',1,''),(607388,191121,'74362','origin','font-size','14',0,''),(607389,191121,'74362','origin','font-weight','bold',0,''),(607390,191121,'74362','origin','text','<p>INVOICE ADDRESS:</p>',0,''),(607391,191122,'74363','origin','font-size','12',0,''),(607392,191123,'74364','origin','block_type','1',0,''),(607393,191123,'74364','origin','font-weight','normal',0,''),(607394,191123,'74364','origin','padding-top','10',0,''),(607395,191123,'74364','origin','padding-left','10',0,''),(607396,191123,'74364','origin','padding-right','10',0,''),(607397,191123,'74364','origin','padding-bottom','10',0,''),(607398,191124,'74365','origin','text','<p>E-MAIL ADDRESS:</p>',1,''),(607399,191124,'74365','origin','font-weight','bold',0,''),(607400,191124,'74365','origin','font-size','14',0,''),(607401,191124,'74365','origin','padding-top','10',0,''),(607402,191124,'74365','origin','text','<p>E-MAIL ADDRESS:</p>',0,''),(607403,191125,'74366','origin','font-weight','normal',0,''),(607404,191126,'74367','origin','font-weight','normal',0,''),(607405,191127,'74368','origin','text','<p>CUSTOMER:</p>',1,''),(607406,191127,'74368','origin','font-size','13',0,''),(607407,191127,'74368','origin','font-weight','bold',0,''),(607408,191127,'74368','origin','text','<p>CUSTOMER:</p>',0,''),(607409,191128,'74369','origin','text','<p>PHONE NUMBER:</p>',1,''),(607410,191128,'74369','origin','font-size','14',0,''),(607411,191128,'74369','origin','font-weight','bold',0,''),(607412,191128,'74369','origin','padding-top','10',0,''),(607413,191128,'74369','origin','text','<p>PHONE NUMBER:</p>',0,''),(607414,191130,'74371','origin','font-weight','normal',0,''),(607415,191130,'74371','origin','text-align','center',0,''),(607416,191130,'74371','origin','padding-bottom','20',0,''),(607417,191131,'74372','origin','text','<p>Payment Method:</p>',1,''),(607418,191131,'74372','origin','font-weight','bold',0,''),(607419,191131,'74372','origin','text-align','center',0,''),(607420,191131,'74372','origin','text','<p>Payment Method:</p>',0,''),(607421,191132,'74373','origin','text','<p>Payment date:</p>',1,''),(607422,191132,'74373','origin','font-weight','bold',0,''),(607423,191132,'74373','origin','text-align','center',0,''),(607424,191132,'74373','origin','font-size','12',0,''),(607425,191132,'74373','origin','text','<p>Payment date:</p>',0,''),(607426,191133,'74374','origin','font-size','14',0,''),(607427,191133,'74374','origin','font-weight','bold',0,''),(607428,191133,'74374','origin','text-align','center',0,''),(607429,191133,'74374','origin','padding-bottom','10',0,''),(607430,191133,'74374','origin','padding-top','10',0,''),(607431,191134,'74375','origin','font-weight','normal',0,''),(607432,191134,'74375','origin','text-align','center',0,''),(607433,191134,'74375','origin','padding-bottom','10',0,''),(607434,191135,'74376','origin','font-weight','normal',0,''),(607435,191135,'74376','origin','text-align','center',0,''),(607436,191136,'74377','origin','block_type','3',0,''),(607437,191136,'74377','origin','font-weight','normal',0,''),(607438,191136,'74377','origin','padding-top','20',0,''),(607439,191137,'74378','origin','font-size','12',0,''),(607440,191138,'74379','origin','text','<p>If undelivered please return to:</p>',1,''),(607441,191138,'74379','origin','font-size','12',0,''),(607442,191138,'74379','origin','font-weight','bold',0,''),(607443,191138,'74379','origin','text','<p>If undelivered please return to:</p>',0,''),(607444,191139,'74380','origin','text','<p>Thank you for your order</p>',1,''),(607445,191139,'74380','origin','color','$color-8',0,''),(607446,191139,'74380','origin','font-size','13',0,''),(607447,191139,'74380','origin','font-weight','bold',0,''),(607448,191139,'74380','origin','padding-top','5',0,''),(607449,191139,'74380','origin','text-align','center',0,''),(607450,191139,'74380','origin','text','<p>Thank you for your order</p>',0,''),(607451,191140,'74381','origin','font-weight','400',0,''),(607452,191140,'74381','origin','text-align','center',0,''),(607453,191140,'74381','origin','padding-top','0',0,''),(607454,191140,'74381','origin','padding-left','20',0,''),(607455,191140,'74381','origin','padding-right','20',0,''),(607456,191140,'74381','origin','logo_from','theme',0,''),(607457,191141,'74382','origin','block_type','6',0,''),(607458,191141,'74382','origin','font-weight','normal',0,''),(607459,191141,'74382','origin','font-size','16',0,''),(607460,191142,'74383','origin','text','<p>Email:</p>',1,''),(607461,191142,'74383','origin','font-weight','normal',0,''),(607462,191142,'74383','origin','text-align','right',0,''),(607463,191142,'74383','origin','font-size','12',0,''),(607464,191142,'74383','origin','text','<p>Email:</p>',0,''),(607465,191143,'74384','origin','font-weight','normal',0,''),(607466,191143,'74384','origin','text-align','right',0,''),(607467,191143,'74384','origin','font-size','12',0,''),(607468,191144,'74385','origin','block_type','6',0,''),(607469,191144,'74385','origin','font-weight','normal',0,''),(607470,191144,'74385','origin','font-size','16',0,''),(607471,191145,'74386','origin','text','<p>Phone:</p>',1,''),(607472,191145,'74386','origin','font-weight','normal',0,''),(607473,191145,'74386','origin','text-align','right',0,''),(607474,191145,'74386','origin','font-size','12',0,''),(607475,191145,'74386','origin','text','<p>Phone:</p>',0,''),(607476,191146,'74387','origin','font-weight','normal',0,''),(607477,191146,'74387','origin','text-align','right',0,''),(607478,191146,'74387','origin','font-size','12',0,''),(607479,191147,'74388','origin','text','<p>If something has gone wrong please contact us at:</p>',1,''),(607480,191147,'74388','origin','font-size','12',0,''),(607481,191147,'74388','origin','font-weight','bold',0,''),(607482,191147,'74388','origin','text-align','right',0,''),(607483,191147,'74388','origin','text','<p>If something has gone wrong please contact us at:</p>',0,''),(607484,191148,'74389','origin','font-weight','400',0,''),(607485,191148,'74389','origin','padding-top','20',0,''),(607486,191148,'74389','origin','padding-bottom','0',0,''),(607487,191148,'74389','origin','font-size','12',0,''),(607488,191149,'74390','origin','block_type','5',0,''),(607489,191149,'74390','origin','font-weight','normal',0,''),(607490,191149,'74390','origin','border-bottom-width','1',0,''),(607491,191149,'74390','origin','border-bottom-color','$content-border-1',0,''),(607492,191149,'74390','origin','border-top-width','1',0,''),(607493,191149,'74390','origin','border-top-color','$content-border-1',0,''),(607494,191149,'74390','origin','border-left-color','$content-border-1',0,''),(607495,191149,'74390','origin','border-left-width','1',0,''),(607496,191150,'74391','origin','block_type','1',0,''),(607497,191150,'74391','origin','font-weight','normal',0,''),(607498,191150,'74391','origin','padding-top','10',0,''),(607499,191150,'74391','origin','padding-left','10',0,''),(607500,191150,'74391','origin','padding-right','10',0,''),(607501,191151,'74392','origin','font-weight','400',0,''),(607502,191151,'74392','origin','line-height','120',0,''),(607503,191151,'74392','origin','line_height_measure','%',0,''),(607504,191151,'74392','origin','font-size','12',0,''),(607505,191152,'74393','origin','text','<p>SHIPPING ADDRESS:</p>',1,''),(607506,191152,'74393','origin','font-size','14',0,''),(607507,191152,'74393','origin','font-weight','bold',0,''),(607508,191152,'74393','origin','padding-bottom','10',0,''),(607509,191152,'74393','origin','text','<p>SHIPPING ADDRESS:</p>',0,''),(607510,191153,'74394','origin','block_type','1',0,''),(607511,191153,'74394','origin','background-color','$content-bg-2',0,''),(607512,191153,'74394','origin','padding-top','20',0,''),(607513,191153,'74394','origin','padding-left','10',0,''),(607514,191153,'74394','origin','padding-right','10',0,''),(607515,191153,'74394','origin','padding-bottom','20',0,''),(607516,191153,'74394','origin','font-size','14',0,''),(607517,191154,'74395','origin','font-weight','normal',0,''),(607518,191154,'74395','origin','text-align','right',0,''),(607519,191154,'74395','origin','font-size','14',0,''),(607520,191154,'74395','origin','box_align','3',0,''),(607521,191155,'74396','origin','block_type','2',0,''),(607522,191155,'74396','origin','font-weight','normal',0,''),(607523,191155,'74396','origin','padding-bottom','20',0,''),(607524,191156,'74397','origin','font-weight','400',0,''),(607525,191156,'74397','origin','padding-top','20',0,''),(607526,191156,'74397','origin','logo_from','theme',0,''),(607527,191157,'74398','origin','block_type','11',0,''),(607528,191157,'74398','origin','font-weight','normal',0,''),(607529,191158,'74399','origin','text','<p>Web:</p>',1,''),(607530,191158,'74399','origin','font-weight','normal',0,''),(607531,191158,'74399','origin','text-align','right',0,''),(607532,191158,'74399','origin','text','<p>Web:</p>',0,''),(607533,191159,'74400','origin','font-weight','normal',0,''),(607534,191159,'74400','origin','text-align','right',0,''),(607535,191160,'74401','origin','block_type','11',0,''),(607536,191160,'74401','origin','font-weight','normal',0,''),(607537,191161,'74402','origin','text','<p>Email:</p>',1,''),(607538,191161,'74402','origin','font-weight','normal',0,''),(607539,191161,'74402','origin','text-align','right',0,''),(607540,191161,'74402','origin','text','<p>Email:</p>',0,''),(607541,191162,'74403','origin','font-weight','normal',0,''),(607542,191162,'74403','origin','text-align','right',0,''),(607543,191163,'74404','origin','block_type','1',0,''),(607544,191164,'74405','origin','font-weight','normal',0,''),(607545,191164,'74405','origin','text-align','right',0,''),(607546,191164,'74405','origin','padding-bottom','10',0,''),(607547,191164,'74405','origin','address_spacer',',',0,''),(607548,191164,'74405','origin','font-size','12',0,''),(607549,191165,'74406','origin','block_type','11',0,''),(607550,191165,'74406','origin','font-weight','normal',0,''),(607551,191166,'74407','origin','text','<p>Phone:</p>',1,''),(607552,191166,'74407','origin','font-weight','normal',0,''),(607553,191166,'74407','origin','text-align','right',0,''),(607554,191166,'74407','origin','text','<p>Phone:</p>',0,''),(607555,191167,'74408','origin','font-weight','normal',0,''),(607556,191167,'74408','origin','text-align','right',0,''),(607557,191168,'74409','origin','block_type','1',0,''),(607558,191168,'74409','origin','padding-top','20',0,''),(607559,191169,'74410','origin','tab_1','RETURNING CUSTOMER',1,''),(607560,191169,'74410','origin','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(607561,191169,'74410','origin','tab_1','RETURNING CUSTOMER',0,''),(607562,191169,'74410','origin','tab_2','REGISTER TO SAVE YOUR DETAILS',0,''),(607563,191171,'74412','origin','block_type','8',0,''),(607564,191172,'74413','origin','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(607565,191173,'74414','origin','block_type','1',0,''),(607566,191173,'74414','origin','padding-left','20',0,''),(607567,191173,'74414','origin','padding-right','20',0,''),(607568,191174,'74415','origin','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(607569,191176,'74417','origin','block_type','1',0,''),(607570,191177,'74418','origin','text','##TEXT_OR##',0,''),(607571,191177,'74418','origin','font-size','18',0,''),(607572,191177,'74418','origin','font-weight','700',0,''),(607573,191177,'74418','origin','padding-top','15',0,''),(607574,191177,'74418','origin','text-align','center',0,''),(607575,191177,'74418','origin','content','\\_',0,'3'),(607576,191177,'74418','origin','height','5',0,'3'),(607577,191177,'74418','origin','width','70',0,'3'),(607578,191177,'74418','origin','display','inline-block',0,'3'),(607579,191177,'74418','origin','border-top-width','1',0,'3'),(607580,191177,'74418','origin','border-top-color','$content-border-1',0,'3'),(607581,191177,'74418','origin','margin-left','10',0,'3'),(607582,191177,'74418','origin','margin-right','10',0,'3'),(607583,191177,'74418','origin','content','\\_',0,'4'),(607584,191177,'74418','origin','display','inline-block',0,'4'),(607585,191177,'74418','origin','width','70',0,'4'),(607586,191177,'74418','origin','height','5',0,'4'),(607587,191177,'74418','origin','border-top-width','1',0,'4'),(607588,191177,'74418','origin','border-top-color','$content-border-1',0,'4'),(607589,191177,'74418','origin','margin-left','10',0,'4'),(607590,191177,'74418','origin','margin-right','10',0,'4'),(607591,191177,'74418','origin','position','relative',0,''),(607592,191177,'74418','origin','top','-10',0,''),(607593,191178,'74419','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607594,191178,'74419','origin','font-size','26',0,''),(607595,191178,'74419','origin','font-family','$font-1',0,''),(607596,191178,'74419','origin','padding-top','15',0,''),(607597,191178,'74419','origin','padding-bottom','15',0,''),(607598,191178,'74419','origin','text-align','center',0,''),(607599,191179,'74420','origin','text-align','center',0,''),(607600,191179,'74420','origin','hide_parents','2',0,''),(607601,191180,'74421','origin','block_type','1',0,''),(607602,191180,'74421','origin','padding-top','40',0,''),(607603,191180,'74421','origin','background-color','$content-bg-2',0,''),(607604,191180,'74421','origin','padding-bottom','40',0,''),(607605,191180,'74421','origin','style_class','checkout-login-wrap',0,''),(607606,191180,'74421','origin','color','$content-color-2',0,''),(607607,191181,'74422','origin','block_type','2',0,''),(607608,191181,'74422','origin','background-color','$content-bg-1',0,''),(607609,191181,'74422','origin','max-width','830',0,''),(607610,191181,'74422','origin','margin_left_measure','auto',0,''),(607611,191181,'74422','origin','margin_right_measure','auto',0,''),(607612,191181,'74422','origin','padding-top','40',0,''),(607613,191181,'74422','origin','padding-bottom','40',0,''),(607614,191181,'74422','origin','schema','2-3',0,'8356'),(607615,191181,'74422','origin','color','$content-color-1',0,''),(607616,191182,'74423','origin','text-align','center',0,''),(607617,191182,'74423','origin','margin-bottom','40',0,''),(607618,191183,'74424','origin','text-align','center',0,''),(607619,191184,'74425','origin','text','##TEXT_OR##',0,''),(607620,191184,'74425','origin','font-size','18',0,''),(607621,191184,'74425','origin','font-weight','700',0,''),(607622,191184,'74425','origin','text-align','center',0,''),(607623,191184,'74425','origin','content','\\_',0,'3'),(607624,191184,'74425','origin','height','5',0,'3'),(607625,191184,'74425','origin','width','70',0,'3'),(607626,191184,'74425','origin','display','inline-block',0,'3'),(607627,191184,'74425','origin','border-top-width','1',0,'3'),(607628,191184,'74425','origin','border-top-color','$content-border-1',0,'3'),(607629,191184,'74425','origin','margin-left','10',0,'3'),(607630,191184,'74425','origin','margin-right','10',0,'3'),(607631,191184,'74425','origin','content','\\_',0,'4'),(607632,191184,'74425','origin','display','inline-block',0,'4'),(607633,191184,'74425','origin','width','70',0,'4'),(607634,191184,'74425','origin','height','5',0,'4'),(607635,191184,'74425','origin','border-top-width','1',0,'4'),(607636,191184,'74425','origin','border-top-color','$content-border-1',0,'4'),(607637,191184,'74425','origin','margin-left','10',0,'4'),(607638,191184,'74425','origin','margin-right','10',0,'4'),(607639,191184,'74425','origin','position','relative',0,''),(607640,191184,'74425','origin','padding-top','10',0,''),(607641,191184,'74425','origin','padding-bottom','10',0,''),(607642,191185,'74426','origin','block_type','1',0,''),(607643,191186,'74427','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607644,191186,'74427','origin','font-size','18',0,''),(607645,191186,'74427','origin','font-family','$font-1',0,''),(607646,191186,'74427','origin','padding-top','15',0,''),(607647,191186,'74427','origin','padding-bottom','15',0,''),(607648,191186,'74427','origin','text-align','center',0,''),(607649,191186,'74427','origin','text-transform','uppercase',0,''),(607650,191187,'74428','origin','text-align','center',0,''),(607651,191187,'74428','origin','hide_parents','2',0,''),(607652,191188,'74429','origin','text','##NEW_CUSTOMER##',0,''),(607653,191188,'74429','origin','font-size','18',0,''),(607654,191188,'74429','origin','font-family','$font-1',0,''),(607655,191188,'74429','origin','text-align','center',0,''),(607656,191188,'74429','origin','text-transform','uppercase',0,''),(607657,191188,'74429','origin','margin-bottom','10',0,''),(607658,191189,'74430','origin','max-width','230',0,''),(607659,191189,'74430','origin','margin_left_measure','auto',0,''),(607660,191189,'74430','origin','margin_right_measure','auto',0,''),(607661,191190,'74431','origin','text','##RETURNING_CUSTOMER##',0,''),(607662,191190,'74431','origin','font-size','18',0,''),(607663,191190,'74431','origin','font-family','$font-1',0,''),(607664,191190,'74431','origin','text-transform','uppercase',0,''),(607665,191190,'74431','origin','text-align','center',0,''),(607666,191191,'74432','origin','block_type','1',0,''),(607667,191191,'74432','origin','padding-top','20',0,''),(607668,191192,'74433','origin','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(607669,191192,'74433','origin','tab_2','RETURNING CUSTOMER',1,''),(607670,191192,'74433','origin','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(607671,191192,'74433','origin','tab_1','GUEST – SINGLE USE ACCOUNT',0,''),(607672,191192,'74433','origin','tab_2','RETURNING CUSTOMER',0,''),(607673,191192,'74433','origin','tab_3','REGISTER TO SAVE YOUR DETAILS',0,''),(607674,191193,'74434','origin','block_type','8',0,''),(607675,191194,'74435','origin','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(607676,191195,'74436','origin','block_type','1',0,''),(607677,191195,'74436','origin','padding-left','20',0,''),(607678,191195,'74436','origin','padding-right','20',0,''),(607679,191197,'74438','origin','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(607680,191197,'74438','origin','border-top-width','1',0,''),(607681,191197,'74438','origin','border-top-color','$content-border-1',0,'');
INSERT INTO `design_boxes_settings` VALUES (607682,191199,'74440','origin','block_type','8',0,''),(607683,191200,'74441','origin','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(607684,191201,'74442','origin','block_type','1',0,''),(607685,191201,'74442','origin','padding-left','20',0,''),(607686,191201,'74442','origin','padding-right','20',0,''),(607687,191202,'74443','origin','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(607688,191204,'74445','origin','text-align','center',0,''),(607689,191205,'74446','origin','text','##TEXT_OR##',0,''),(607690,191205,'74446','origin','font-size','18',0,''),(607691,191205,'74446','origin','font-weight','700',0,''),(607692,191205,'74446','origin','padding-top','15',0,''),(607693,191205,'74446','origin','text-align','center',0,''),(607694,191205,'74446','origin','content','\\_',0,'3'),(607695,191205,'74446','origin','height','5',0,'3'),(607696,191205,'74446','origin','width','70',0,'3'),(607697,191205,'74446','origin','display','inline-block',0,'3'),(607698,191205,'74446','origin','border-top-width','1',0,'3'),(607699,191205,'74446','origin','border-top-color','$content-border-1',0,'3'),(607700,191205,'74446','origin','margin-left','10',0,'3'),(607701,191205,'74446','origin','margin-right','10',0,'3'),(607702,191205,'74446','origin','content','\\_',0,'4'),(607703,191205,'74446','origin','display','inline-block',0,'4'),(607704,191205,'74446','origin','width','70',0,'4'),(607705,191205,'74446','origin','height','5',0,'4'),(607706,191205,'74446','origin','border-top-width','1',0,'4'),(607707,191205,'74446','origin','border-top-color','$content-border-1',0,'4'),(607708,191205,'74446','origin','margin-left','10',0,'4'),(607709,191205,'74446','origin','margin-right','10',0,'4'),(607710,191205,'74446','origin','position','relative',0,''),(607711,191205,'74446','origin','top','-10',0,''),(607712,191206,'74447','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607713,191206,'74447','origin','font-size','26',0,''),(607714,191206,'74447','origin','font-family','$font-1',0,''),(607715,191206,'74447','origin','padding-top','15',0,''),(607716,191206,'74447','origin','padding-bottom','15',0,''),(607717,191206,'74447','origin','text-align','center',0,''),(607718,191207,'74448','origin','block_type','1',0,''),(607719,191207,'74448','origin','padding-top','20',0,''),(607720,191208,'74449','origin','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(607721,191208,'74449','origin','tab_2','RETURNING CUSTOMER',1,''),(607722,191208,'74449','origin','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(607723,191208,'74449','origin','tab_1','GUEST – SINGLE USE ACCOUNT',0,''),(607724,191208,'74449','origin','tab_2','RETURNING CUSTOMER',0,''),(607725,191208,'74449','origin','tab_3','REGISTER TO SAVE YOUR DETAILS',0,''),(607726,191209,'74450','origin','block_type','8',0,''),(607727,191210,'74451','origin','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(607728,191213,'74454','origin','block_type','8',0,''),(607729,191214,'74455','origin','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(607730,191216,'74457','origin','block_type','1',0,''),(607731,191216,'74457','origin','padding-left','20',0,''),(607732,191216,'74457','origin','padding-right','20',0,''),(607733,191218,'74459','origin','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(607734,191219,'74460','origin','text','##TEXT_OR##',0,''),(607735,191219,'74460','origin','font-size','18',0,''),(607736,191219,'74460','origin','font-weight','700',0,''),(607737,191219,'74460','origin','padding-top','15',0,''),(607738,191219,'74460','origin','text-align','center',0,''),(607739,191219,'74460','origin','content','\\_',0,'3'),(607740,191219,'74460','origin','height','5',0,'3'),(607741,191219,'74460','origin','width','70',0,'3'),(607742,191219,'74460','origin','display','inline-block',0,'3'),(607743,191219,'74460','origin','border-top-width','1',0,'3'),(607744,191219,'74460','origin','border-top-color','$content-border-1',0,'3'),(607745,191219,'74460','origin','margin-left','10',0,'3'),(607746,191219,'74460','origin','margin-right','10',0,'3'),(607747,191219,'74460','origin','content','\\_',0,'4'),(607748,191219,'74460','origin','display','inline-block',0,'4'),(607749,191219,'74460','origin','width','70',0,'4'),(607750,191219,'74460','origin','height','5',0,'4'),(607751,191219,'74460','origin','border-top-width','1',0,'4'),(607752,191219,'74460','origin','border-top-color','$content-border-1',0,'4'),(607753,191219,'74460','origin','margin-left','10',0,'4'),(607754,191219,'74460','origin','margin-right','10',0,'4'),(607755,191219,'74460','origin','position','relative',0,''),(607756,191219,'74460','origin','top','-10',0,''),(607757,191220,'74461','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607758,191220,'74461','origin','font-size','26',0,''),(607759,191220,'74461','origin','font-family','$font-1',0,''),(607760,191220,'74461','origin','padding-top','15',0,''),(607761,191220,'74461','origin','padding-bottom','15',0,''),(607762,191220,'74461','origin','text-align','center',0,''),(607763,191221,'74462','origin','text-align','center',0,''),(607764,191222,'74463','origin','block_type','1',0,''),(607765,191222,'74463','origin','padding-top','20',0,''),(607766,191223,'74464','origin','text-align','center',0,''),(607767,191224,'74465','origin','text','##TEXT_OR##',0,''),(607768,191224,'74465','origin','font-size','18',0,''),(607769,191224,'74465','origin','font-weight','700',0,''),(607770,191224,'74465','origin','padding-top','15',0,''),(607771,191224,'74465','origin','text-align','center',0,''),(607772,191224,'74465','origin','content','\\_',0,'3'),(607773,191224,'74465','origin','height','5',0,'3'),(607774,191224,'74465','origin','width','70',0,'3'),(607775,191224,'74465','origin','display','inline-block',0,'3'),(607776,191224,'74465','origin','border-top-width','1',0,'3'),(607777,191224,'74465','origin','border-top-color','$content-border-1',0,'3'),(607778,191224,'74465','origin','margin-left','10',0,'3'),(607779,191224,'74465','origin','margin-right','10',0,'3'),(607780,191224,'74465','origin','content','\\_',0,'4'),(607781,191224,'74465','origin','display','inline-block',0,'4'),(607782,191224,'74465','origin','width','70',0,'4'),(607783,191224,'74465','origin','height','5',0,'4'),(607784,191224,'74465','origin','border-top-width','1',0,'4'),(607785,191224,'74465','origin','border-top-color','$content-border-1',0,'4'),(607786,191224,'74465','origin','margin-left','10',0,'4'),(607787,191224,'74465','origin','margin-right','10',0,'4'),(607788,191224,'74465','origin','position','relative',0,''),(607789,191224,'74465','origin','top','-10',0,''),(607790,191225,'74466','origin','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(607791,191225,'74466','origin','tab_2','RETURNING CUSTOMER',1,''),(607792,191225,'74466','origin','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(607793,191225,'74466','origin','tab_1','GUEST – SINGLE USE ACCOUNT',0,''),(607794,191225,'74466','origin','tab_2','RETURNING CUSTOMER',0,''),(607795,191225,'74466','origin','tab_3','REGISTER TO SAVE YOUR DETAILS',0,''),(607796,191226,'74467','origin','block_type','8',0,''),(607797,191227,'74468','origin','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(607798,191230,'74471','origin','block_type','8',0,''),(607799,191231,'74472','origin','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(607800,191232,'74473','origin','block_type','1',0,''),(607801,191232,'74473','origin','padding-left','20',0,''),(607802,191232,'74473','origin','padding-right','20',0,''),(607803,191234,'74475','origin','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(607804,191235,'74476','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607805,191235,'74476','origin','font-size','26',0,''),(607806,191235,'74476','origin','font-family','$font-1',0,''),(607807,191235,'74476','origin','padding-top','15',0,''),(607808,191235,'74476','origin','padding-bottom','15',0,''),(607809,191235,'74476','origin','text-align','center',0,''),(607810,191236,'74477','origin','block_type','1',0,''),(607811,191236,'74477','origin','padding-top','40',0,''),(607812,191236,'74477','origin','background-color','$content-bg-2',0,''),(607813,191236,'74477','origin','padding-bottom','40',0,''),(607814,191237,'74478','origin','block_type','2',0,''),(607815,191237,'74478','origin','background-color','$content-bg-1',0,''),(607816,191237,'74478','origin','max-width','830',0,''),(607817,191237,'74478','origin','margin_left_measure','auto',0,''),(607818,191237,'74478','origin','margin_right_measure','auto',0,''),(607819,191237,'74478','origin','padding-top','40',0,''),(607820,191237,'74478','origin','padding-bottom','40',0,''),(607821,191238,'74479','origin','block_type','1',0,''),(607822,191239,'74480','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607823,191239,'74480','origin','font-size','18',0,''),(607824,191239,'74480','origin','font-family','$font-1',0,''),(607825,191239,'74480','origin','padding-top','15',0,''),(607826,191239,'74480','origin','padding-bottom','15',0,''),(607827,191239,'74480','origin','text-align','center',0,''),(607828,191239,'74480','origin','text-transform','uppercase',0,''),(607829,191240,'74481','origin','text-align','center',0,''),(607830,191240,'74481','origin','hide_parents','2',0,''),(607831,191241,'74482','origin','text-align','center',0,''),(607832,191242,'74483','origin','text-align','center',0,''),(607833,191242,'74483','origin','margin-bottom','40',0,''),(607834,191243,'74484','origin','text','##TEXT_OR##',0,''),(607835,191243,'74484','origin','font-size','18',0,''),(607836,191243,'74484','origin','font-weight','700',0,''),(607837,191243,'74484','origin','text-align','center',0,''),(607838,191243,'74484','origin','content','\\_',0,'3'),(607839,191243,'74484','origin','height','5',0,'3'),(607840,191243,'74484','origin','width','70',0,'3'),(607841,191243,'74484','origin','display','inline-block',0,'3'),(607842,191243,'74484','origin','border-top-width','1',0,'3'),(607843,191243,'74484','origin','border-top-color','$content-border-1',0,'3'),(607844,191243,'74484','origin','margin-left','10',0,'3'),(607845,191243,'74484','origin','margin-right','10',0,'3'),(607846,191243,'74484','origin','content','\\_',0,'4'),(607847,191243,'74484','origin','display','inline-block',0,'4'),(607848,191243,'74484','origin','width','70',0,'4'),(607849,191243,'74484','origin','height','5',0,'4'),(607850,191243,'74484','origin','border-top-width','1',0,'4'),(607851,191243,'74484','origin','border-top-color','$content-border-1',0,'4'),(607852,191243,'74484','origin','margin-left','10',0,'4'),(607853,191243,'74484','origin','margin-right','10',0,'4'),(607854,191243,'74484','origin','position','relative',0,''),(607855,191243,'74484','origin','padding-top','10',0,''),(607856,191243,'74484','origin','padding-bottom','10',0,''),(607857,191244,'74485','origin','text','##NEW_CUSTOMER##',0,''),(607858,191244,'74485','origin','font-size','18',0,''),(607859,191244,'74485','origin','font-family','$font-1',0,''),(607860,191244,'74485','origin','text-align','center',0,''),(607861,191244,'74485','origin','text-transform','uppercase',0,''),(607862,191244,'74485','origin','margin-bottom','10',0,''),(607863,191245,'74486','origin','text','##RETURNING_CUSTOMER##',0,''),(607864,191245,'74486','origin','font-size','18',0,''),(607865,191245,'74486','origin','font-family','$font-1',0,''),(607866,191245,'74486','origin','text-transform','uppercase',0,''),(607867,191245,'74486','origin','text-align','center',0,''),(607868,191246,'74487','origin','max-width','230',0,''),(607869,191246,'74487','origin','margin_left_measure','auto',0,''),(607870,191246,'74487','origin','margin_right_measure','auto',0,''),(607871,191247,'74488','origin','block_type','1',0,''),(607872,191247,'74488','origin','padding-top','40',0,''),(607873,191247,'74488','origin','background-color','$content-bg-2',0,''),(607874,191247,'74488','origin','padding-bottom','40',0,''),(607875,191248,'74489','origin','block_type','2',0,''),(607876,191248,'74489','origin','background-color','$content-bg-1',0,''),(607877,191248,'74489','origin','max-width','830',0,''),(607878,191248,'74489','origin','margin_left_measure','auto',0,''),(607879,191248,'74489','origin','margin_right_measure','auto',0,''),(607880,191248,'74489','origin','padding-top','40',0,''),(607881,191248,'74489','origin','padding-bottom','40',0,''),(607882,191249,'74490','origin','text','##NEW_CUSTOMER##',0,''),(607883,191249,'74490','origin','font-size','18',0,''),(607884,191249,'74490','origin','font-family','$font-1',0,''),(607885,191249,'74490','origin','text-align','center',0,''),(607886,191249,'74490','origin','text-transform','uppercase',0,''),(607887,191249,'74490','origin','margin-bottom','10',0,''),(607888,191250,'74491','origin','text-align','center',0,''),(607889,191251,'74492','origin','text-align','center',0,''),(607890,191251,'74492','origin','margin-bottom','40',0,''),(607891,191252,'74493','origin','text','##TEXT_OR##',0,''),(607892,191252,'74493','origin','font-size','18',0,''),(607893,191252,'74493','origin','font-weight','700',0,''),(607894,191252,'74493','origin','text-align','center',0,''),(607895,191252,'74493','origin','content','\\_',0,'3'),(607896,191252,'74493','origin','height','5',0,'3'),(607897,191252,'74493','origin','width','70',0,'3'),(607898,191252,'74493','origin','display','inline-block',0,'3'),(607899,191252,'74493','origin','border-top-width','1',0,'3'),(607900,191252,'74493','origin','border-top-color','$content-border-1',0,'3'),(607901,191252,'74493','origin','margin-left','10',0,'3'),(607902,191252,'74493','origin','margin-right','10',0,'3'),(607903,191252,'74493','origin','content','\\_',0,'4'),(607904,191252,'74493','origin','display','inline-block',0,'4'),(607905,191252,'74493','origin','width','70',0,'4'),(607906,191252,'74493','origin','height','5',0,'4'),(607907,191252,'74493','origin','border-top-width','1',0,'4'),(607908,191252,'74493','origin','border-top-color','$content-border-1',0,'4'),(607909,191252,'74493','origin','margin-left','10',0,'4'),(607910,191252,'74493','origin','margin-right','10',0,'4'),(607911,191252,'74493','origin','position','relative',0,''),(607912,191252,'74493','origin','padding-top','10',0,''),(607913,191252,'74493','origin','padding-bottom','10',0,''),(607914,191253,'74494','origin','block_type','1',0,''),(607915,191254,'74495','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607916,191254,'74495','origin','font-size','18',0,''),(607917,191254,'74495','origin','font-family','$font-1',0,''),(607918,191254,'74495','origin','padding-top','15',0,''),(607919,191254,'74495','origin','padding-bottom','15',0,''),(607920,191254,'74495','origin','text-align','center',0,''),(607921,191254,'74495','origin','text-transform','uppercase',0,''),(607922,191255,'74496','origin','text-align','center',0,''),(607923,191255,'74496','origin','hide_parents','2',0,''),(607924,191256,'74497','origin','text','##RETURNING_CUSTOMER##',0,''),(607925,191256,'74497','origin','font-size','18',0,''),(607926,191256,'74497','origin','font-family','$font-1',0,''),(607927,191256,'74497','origin','text-transform','uppercase',0,''),(607928,191256,'74497','origin','text-align','center',0,''),(607929,191257,'74498','origin','max-width','230',0,''),(607930,191257,'74498','origin','margin_left_measure','auto',0,''),(607931,191257,'74498','origin','margin_right_measure','auto',0,''),(607932,191258,'74499','origin','block_type','1',0,''),(607933,191259,'74500','origin','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(607934,191259,'74500','origin','margin-bottom','30',0,''),(607935,191260,'74501','origin','block_type','1',0,''),(607936,191261,'74502','origin','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(607937,191261,'74502','origin','margin-bottom','30',0,''),(607938,191262,'74503','origin','block_type','1',0,''),(607939,191262,'74503','origin','background-color','$best-sellers-bg-1',0,''),(607940,191262,'74503','origin','padding-top','20',0,''),(607941,191262,'74503','origin','padding-bottom','20',0,''),(607942,191262,'74503','origin','font-weight','400',0,''),(607943,191262,'74503','origin','visibility_product','1',0,''),(607944,191262,'74503','origin','visibility_catalog','1',0,''),(607945,191262,'74503','origin','visibility_info','1',0,''),(607946,191262,'74503','origin','visibility_cart','1',0,''),(607947,191262,'74503','origin','visibility_checkout','1',0,''),(607948,191262,'74503','origin','visibility_success','1',0,''),(607949,191262,'74503','origin','visibility_account','1',0,''),(607950,191262,'74503','origin','visibility_login','1',0,''),(607951,191262,'74503','origin','visibility_other','1',0,''),(607952,191262,'74503','origin','margin-bottom','20',0,''),(607953,191262,'74503','origin','display_none','on',0,'8356'),(607954,191263,'74504','origin','block_type','2',0,''),(607955,191263,'74504','origin','font-weight','normal',0,''),(607956,191264,'74505','origin','font-weight','400',0,''),(607957,191264,'74505','origin','visibility_product','1',0,''),(607958,191264,'74505','origin','show_name','0',0,''),(607959,191264,'74505','origin','show_stock','1',0,''),(607960,191264,'74505','origin','show_description','1',0,''),(607961,191264,'74505','origin','show_model','1',0,''),(607962,191264,'74505','origin','show_rating','1',0,''),(607963,191264,'74505','origin','show_rating_counts','1',0,''),(607964,191264,'74505','origin','show_qty_input','1',0,''),(607965,191264,'74505','origin','show_view_button','1',0,''),(607966,191264,'74505','origin','show_wishlist_button','1',0,''),(607967,191264,'74505','origin','show_compare','1',0,''),(607968,191264,'74505','origin','listing_type','productListing',0,''),(607969,191264,'74505','origin','show_properties','1',0,''),(607970,191264,'74505','origin','col_in_row','2',0,''),(607971,191264,'74505','origin','show_bonus_points','1',0,''),(607972,191264,'74505','origin','show_buy_button','1',0,''),(607973,191264,'74505','origin','show_attributes','1',0,''),(607974,191265,'74506','origin','font-weight','normal',0,''),(607975,191265,'74506','origin','visibility_product','1',0,''),(607976,191266,'74507','origin','font-weight','400',0,''),(607977,191266,'74507','origin','visibility_product','1',0,''),(607978,191266,'74507','origin','visibility_catalog','1',0,''),(607979,191266,'74507','origin','visibility_info','1',0,''),(607980,191266,'74507','origin','visibility_cart','1',0,''),(607981,191266,'74507','origin','visibility_checkout','1',0,''),(607982,191266,'74507','origin','visibility_success','1',0,''),(607983,191266,'74507','origin','visibility_account','1',0,''),(607984,191266,'74507','origin','visibility_login','1',0,''),(607985,191266,'74507','origin','visibility_other','1',0,''),(607986,191266,'74507','origin','banners_group','home',0,''),(607987,191266,'74507','origin','banners_type','single',0,''),(607988,191266,'74507','origin','lazy_load','1',0,''),(607989,191266,'74507','origin','template','1',0,''),(607990,191266,'74507','origin','ban_id','41',0,''),(607991,191267,'74508','origin','block_type','1',0,''),(607992,191267,'74508','origin','font-weight','normal',0,''),(607993,191268,'74510','origin','tab_1','##NEW_PRODUCTS##',0,''),(607994,191268,'74510','origin','tab_2','##SPECIALS_PRODUCTS##',0,''),(607995,191268,'74510','origin','tab_3','##FEATURED_PRODUCTS##',0,''),(607996,191269,'74511','origin','col_in_row','4',0,''),(607997,191269,'74511','origin','view_as','carousel',0,''),(607998,191269,'74511','origin','show_attributes','1',0,''),(607999,191269,'74511','origin','col_in_row','3',0,'8356'),(608000,191269,'74511','origin','col_in_row','2',0,'8349'),(608001,191269,'74511','origin','col_in_row','1',0,'8377'),(608002,191269,'74511','origin','listing_type','productListing',0,''),(608003,191269,'74511','origin','show_qty_input','1',0,''),(608004,191269,'74511','origin','show_compare','1',0,''),(608005,191269,'74511','origin','lazy_load','1',0,''),(608006,191270,'74512','origin','font-weight','400',0,''),(608007,191270,'74512','origin','show_compare','1',0,''),(608008,191270,'74512','origin','listing_type','productListing',0,''),(608009,191270,'74512','origin','show_model','1',0,''),(608010,191270,'74512','origin','show_properties','1',0,''),(608011,191270,'74512','origin','col_in_row','4',0,''),(608012,191270,'74512','origin','show_name','0',0,''),(608013,191270,'74512','origin','show_image','0',0,''),(608014,191270,'74512','origin','show_stock','0',0,''),(608015,191270,'74512','origin','show_description','0',0,''),(608016,191270,'74512','origin','show_rating','0',0,''),(608017,191270,'74512','origin','show_rating_counts','0',0,''),(608018,191270,'74512','origin','show_price','0',0,''),(608019,191270,'74512','origin','show_buy_button','0',0,''),(608020,191270,'74512','origin','show_qty_input','0',0,''),(608021,191270,'74512','origin','show_view_button','0',0,''),(608022,191270,'74512','origin','show_wishlist_button','0',0,''),(608023,191270,'74512','origin','col_in_row','2',0,'8356'),(608024,191270,'74512','origin','col_in_row','1',0,'8377'),(608025,191270,'74512','origin','view_as','carousel',0,''),(608026,191270,'74512','origin','product_names_teg','h2',0,''),(608027,191270,'74512','origin','show_attributes','1',0,''),(608028,191271,'74513','origin','font-weight','400',0,''),(608029,191271,'74513','origin','listing_type','productListing',0,''),(608030,191271,'74513','origin','col_in_row','4',0,''),(608031,191271,'74513','origin','show_image','0',0,''),(608032,191271,'74513','origin','show_stock','0',0,''),(608033,191271,'74513','origin','show_description','0',0,''),(608034,191271,'74513','origin','show_rating','0',0,''),(608035,191271,'74513','origin','show_rating_counts','0',0,''),(608036,191271,'74513','origin','show_price','0',0,''),(608037,191271,'74513','origin','show_buy_button','0',0,''),(608038,191271,'74513','origin','show_qty_input','0',0,''),(608039,191271,'74513','origin','show_view_button','0',0,''),(608040,191271,'74513','origin','show_wishlist_button','0',0,''),(608041,191271,'74513','origin','col_in_row','2',0,'8356'),(608042,191271,'74513','origin','col_in_row','1',0,'8377'),(608043,191271,'74513','origin','view_as','carousel',0,''),(608044,191271,'74513','origin','col_in_row','2',0,'8349'),(608045,191271,'74513','origin','featured_type_id','0',0,''),(608046,191273,'74515','origin','heading_type','h1',0,''),(608047,191275,'74516','origin','block_type','1',0,''),(608048,191276,'74517','origin','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(608049,191278,'74519','origin','block_type','1',0,''),(608050,191278,'74519','origin','padding-top','40',0,''),(608051,191278,'74519','origin','padding-bottom','80',0,''),(608052,191279,'74520','origin','block_type','6',0,''),(608053,191280,'74521','origin','block_type','1',0,''),(608054,191280,'74521','origin','padding-top','20',0,''),(608055,191280,'74521','origin','padding-left','20',0,''),(608056,191280,'74521','origin','padding-right','20',0,''),(608057,191280,'74521','origin','padding-bottom','20',0,''),(608058,191280,'74521','origin','border-top-width','1',0,''),(608059,191280,'74521','origin','border-left-width','1',0,''),(608060,191280,'74521','origin','border-right-width','1',0,''),(608061,191280,'74521','origin','border-bottom-width','1',0,''),(608062,191280,'74521','origin','border-top-color','$content-border-1',0,''),(608063,191280,'74521','origin','border-left-color','$content-border-1',0,''),(608064,191280,'74521','origin','border-right-color','$content-border-1',0,''),(608065,191280,'74521','origin','border-bottom-color','$content-border-1',0,''),(608066,191280,'74521','origin','margin-right','20',0,''),(608067,191283,'74524','origin','block_type','1',0,''),(608068,191283,'74524','origin','padding-top','20',0,''),(608069,191284,'74525','origin','block_type','6',0,''),(608070,191285,'74526','origin','padding-right','20',0,''),(608071,191287,'74528','origin','block_type','1',0,''),(608072,191287,'74528','origin','padding-top','20',0,''),(608073,191288,'74529','origin','block_type','6',0,''),(608074,191289,'74530','origin','padding-right','20',0,''),(608075,191291,'74532','origin','block_type','1',0,''),(608076,191291,'74532','origin','style_class','account-password-wrap',0,''),(608077,191292,'74533','origin','block_type','6',0,''),(608078,191292,'74533','origin','schema','6-3',0,'8356'),(608079,191293,'74534','origin','aria_name','account-menu',0,''),(608080,191294,'73374','origin','block_type','1',0,''),(608081,191294,'73374','origin','padding-top','70',0,''),(608082,191294,'73374','origin','padding-right','30',0,''),(608083,191294,'73374','origin','padding-bottom','30',0,''),(608084,191294,'73374','origin','padding-top','0',0,'8356'),(608085,191294,'73374','origin','padding-left','0',0,'8356'),(608086,191294,'73374','origin','padding-right','0',0,'8356'),(608087,191294,'73374','origin','padding-bottom','0',0,'8356'),(608130,191314,'74536','origin','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(608131,191315,'74537','origin','block_type','1',0,''),(608132,191315,'74537','origin','padding-top','20',0,''),(608133,191316,'74538','origin','tab_1','RETURNING CUSTOMER',1,''),(608134,191316,'74538','origin','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(608135,191316,'74538','origin','tab_1','RETURNING CUSTOMER',0,''),(608136,191316,'74538','origin','tab_2','REGISTER TO SAVE YOUR DETAILS',0,''),(608137,191318,'74540','origin','block_type','8',0,''),(608138,191319,'74541','origin','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(608139,191320,'74542','origin','block_type','1',0,''),(608140,191320,'74542','origin','padding-left','20',0,''),(608141,191320,'74542','origin','padding-right','20',0,''),(608142,191322,'74544','origin','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(608143,191323,'74545','origin','block_type','1',0,''),(608144,191324,'74546','origin','block_type','1',0,''),(608145,191325,'74547','origin','margin_left_measure','auto',0,''),(608146,191325,'74547','origin','margin_right_measure','auto',0,''),(608147,191325,'74547','origin','max-width','560',0,''),(608148,191326,'74548','origin','margin-bottom','30',0,''),(608149,191327,'74549','origin','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(608150,191328,'94779','origin','block_type','1',0,''),(608151,191330,'94781','origin','block_type','6',0,''),(608152,191330,'94781','origin','font-weight','400',0,''),(608153,191330,'94781','origin','schema','6-2',0,'8377'),(608154,191330,'94781','origin','schema','6-2',0,'8356'),(608155,191331,'94782','origin','font-weight','400',0,''),(608156,191331,'94782','origin','padding-right','40',0,''),(608157,191331,'94782','origin','padding-right','0',0,'8377'),(608158,191331,'94782','origin','padding-right','0',0,'8356'),(608159,191332,'94783','origin','col_in_row','3',0,''),(608160,191332,'94783','origin','products_align','left',0,''),(608161,191332,'94783','origin','font-weight','400',0,''),(608162,191332,'94783','origin','show_qty_input','0',0,''),(608163,191332,'94783','origin','listing_type','productListing',0,''),(608164,191332,'94783','origin','listing_type_rows','no',0,''),(608165,191332,'94783','origin','show_buy_button_b2b','on',0,''),(608166,191332,'94783','origin','show_wishlist_button_b2b','1',0,''),(608167,191332,'94783','origin','show_compare_b2b','1',0,''),(608168,191332,'94783','origin','show_stock','0',0,''),(608169,191332,'94783','origin','show_description','0',0,''),(608170,191332,'94783','origin','show_model','0',0,''),(608171,191332,'94783','origin','show_properties','0',0,''),(608172,191332,'94783','origin','show_rating','0',0,''),(608173,191332,'94783','origin','show_rating_counts','0',0,''),(608174,191332,'94783','origin','show_price','0',0,''),(608175,191332,'94783','origin','show_buy_button','0',0,''),(608176,191332,'94783','origin','show_view_button','0',0,''),(608177,191332,'94783','origin','show_wishlist_button','0',0,''),(608178,191332,'94783','origin','show_compare','0',0,''),(608179,191332,'94783','origin','show_name_rows','0',0,''),(608180,191332,'94783','origin','show_image_rows','0',0,''),(608181,191332,'94783','origin','show_stock_rows','0',0,''),(608182,191332,'94783','origin','show_description_rows','0',0,''),(608183,191332,'94783','origin','show_model_rows','0',0,''),(608184,191332,'94783','origin','show_properties_rows','0',0,''),(608185,191332,'94783','origin','show_rating_rows','0',0,''),(608186,191332,'94783','origin','show_rating_counts_rows','0',0,''),(608187,191332,'94783','origin','show_price_rows','0',0,''),(608188,191332,'94783','origin','show_buy_button_rows','0',0,''),(608189,191332,'94783','origin','show_qty_input_rows','0',0,''),(608190,191332,'94783','origin','show_view_button_rows','0',0,''),(608191,191332,'94783','origin','show_wishlist_button_rows','0',0,''),(608192,191332,'94783','origin','show_compare_rows','0',0,''),(608193,191332,'94783','origin','show_name_b2b','0',0,''),(608194,191332,'94783','origin','show_image_b2b','0',0,''),(608195,191332,'94783','origin','show_stock_b2b','0',0,''),(608196,191332,'94783','origin','show_description_b2b','0',0,''),(608197,191332,'94783','origin','show_model_b2b','0',0,''),(608198,191332,'94783','origin','show_properties_b2b','0',0,''),(608199,191332,'94783','origin','show_rating_b2b','0',0,''),(608200,191332,'94783','origin','show_rating_counts_b2b','0',0,''),(608201,191332,'94783','origin','show_price_b2b','0',0,''),(608202,191332,'94783','origin','show_qty_input_b2b','0',0,''),(608203,191332,'94783','origin','show_view_button_b2b','0',0,''),(608204,191332,'94783','origin','show_attributes_b2b','0',0,''),(608205,191332,'94783','origin','items_on_page','9',0,''),(608206,191332,'94783','origin','col_in_row','2',0,'8356'),(608207,191332,'94783','origin','col_in_row','1',0,'8377'),(608208,191332,'94783','origin','product_names_teg','h2',0,''),(608209,191334,'94785','origin','block_type','5',0,''),(608210,191334,'94785','origin','padding-top','10',0,''),(608211,191334,'94785','origin','padding-bottom','10',0,''),(608212,191334,'94785','origin','schema','5-2',0,'8377'),(608213,191334,'94785','origin','border-top-color','$content-border-1',0,''),(608214,191334,'94785','origin','border-top-width','1',0,''),(608215,191336,'94787','origin','float','right',0,''),(608216,191337,'94788','origin','listing_type','productListing',0,''),(608217,191339,'94790','origin','block_type','1',0,''),(608218,191339,'94790','origin','padding-top','10',0,''),(608219,191339,'94790','origin','padding-bottom','10',0,''),(608220,191339,'94790','origin','border-bottom-width','1',0,''),(608221,191339,'94790','origin','border-bottom-color','$content-border-1',0,''),(608222,191339,'94790','origin','margin-left','0',0,''),(608223,191339,'94790','origin','margin-right','0',0,''),(608224,191340,'94791','origin','float','right',0,''),(608225,191340,'94791','origin','display','none',0,'8377'),(608226,191341,'94792','origin','float','left',0,''),(608227,191341,'94792','origin','clear','none',0,''),(608228,191341,'94792','origin','margin-left','20',0,''),(608229,191341,'94792','origin','display','none',0,'8377'),(608230,191342,'94793','origin','margin-right','20',0,''),(608231,191342,'94793','origin','float','right',0,''),(608232,191342,'94793','origin','clear','none',0,''),(608233,191342,'94793','origin','display','none',0,'8356'),(608234,191343,'94794','origin','float','left',0,''),(608235,191343,'94794','origin','clear','none',0,''),(608236,191343,'94794','origin','sort_pos_3','1',0,''),(608237,191343,'94794','origin','sort_pos_4','2',0,''),(608238,191343,'94794','origin','sort_pos_10','3',0,''),(608239,191343,'94794','origin','sort_pos_9','4',0,''),(608240,191343,'94794','origin','sort_pos_11','5',0,''),(608241,191343,'94794','origin','sort_pos_12','6',0,''),(608242,191343,'94794','origin','sort_pos_14','7',0,''),(608243,191343,'94794','origin','sort_pos_13','8',0,''),(608244,191343,'94794','origin','sort_pos_8','9',0,''),(608245,191343,'94794','origin','sort_pos_7','10',0,''),(608246,191343,'94794','origin','sort_pos_2','11',0,''),(608247,191343,'94794','origin','sort_pos_1','12',0,''),(608248,191343,'94794','origin','sort_pos_6','13',0,''),(608249,191343,'94794','origin','sort_pos_5','14',0,''),(608250,191343,'94794','origin','sort_pos_0','15',0,''),(608251,191343,'94794','origin','sort_hide_10','1',0,''),(608252,191343,'94794','origin','sort_hide_9','1',0,''),(608253,191343,'94794','origin','hide_icons','1',0,''),(608254,191343,'94794','origin','sort_hide_16','1',0,''),(608255,191343,'94794','origin','sort_hide_15','1',0,''),(608256,191343,'94794','origin','sort_hide_3','0',0,''),(608257,191343,'94794','origin','sort_hide_4','0',0,''),(608258,191343,'94794','origin','sort_hide_11','1',0,''),(608259,191343,'94794','origin','sort_hide_12','1',0,''),(608260,191343,'94794','origin','sort_hide_14','1',0,''),(608261,191343,'94794','origin','sort_hide_13','1',0,''),(608262,191343,'94794','origin','sort_hide_8','0',0,''),(608263,191343,'94794','origin','sort_hide_7','0',0,''),(608264,191343,'94794','origin','sort_hide_2','1',0,''),(608265,191343,'94794','origin','sort_hide_1','1',0,''),(608266,191343,'94794','origin','sort_hide_6','1',0,''),(608267,191343,'94794','origin','sort_hide_5','1',0,''),(608268,191343,'94794','origin','sort_hide_0','1',0,''),(608269,191344,'74550','origin','block_type','1',0,''),(608270,191345,'74551','origin','margin-bottom','30',0,''),(608271,191346,'74552','origin','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(608272,191347,'74553','origin','block_type','1',0,''),(608273,191348,'74554','origin','block_type','5',0,''),(608274,191348,'74554','origin','padding-top','10',0,''),(608275,191348,'74554','origin','padding-bottom','10',0,''),(608276,191348,'74554','origin','schema','5-2',0,'8377'),(608277,191348,'74554','origin','border-top-color','$content-border-1',0,''),(608278,191348,'74554','origin','border-top-width','1',0,''),(608279,191349,'74555','origin','padding-top','3',0,''),(608280,191350,'74556','origin','float','right',0,''),(608281,191350,'74556','origin','height','31',0,''),(608282,191351,'74557','origin','col_in_row','4',0,''),(608283,191351,'74557','origin','products_align','left',0,''),(608284,191351,'74557','origin','font-weight','400',0,''),(608285,191351,'74557','origin','listing_type','productListing',0,''),(608286,191351,'74557','origin','listing_type_rows','Rows',0,''),(608287,191351,'74557','origin','show_buy_button_b2b','on',0,''),(608288,191351,'74557','origin','show_wishlist_button_b2b','1',0,''),(608289,191351,'74557','origin','show_compare_b2b','1',0,''),(608290,191351,'74557','origin','show_image','0',0,''),(608291,191351,'74557','origin','show_stock','0',0,''),(608292,191351,'74557','origin','show_description','0',0,''),(608293,191351,'74557','origin','show_model','0',0,''),(608294,191351,'74557','origin','show_properties','0',0,''),(608295,191351,'74557','origin','show_rating','0',0,''),(608296,191351,'74557','origin','show_rating_counts','0',0,''),(608297,191351,'74557','origin','show_price','0',0,''),(608298,191351,'74557','origin','show_buy_button','0',0,''),(608299,191351,'74557','origin','show_view_button','0',0,''),(608300,191351,'74557','origin','show_wishlist_button','0',0,''),(608301,191351,'74557','origin','show_compare','0',0,''),(608302,191351,'74557','origin','show_name_rows','0',0,''),(608303,191351,'74557','origin','show_image_rows','0',0,''),(608304,191351,'74557','origin','show_stock_rows','0',0,''),(608305,191351,'74557','origin','show_description_rows','0',0,''),(608306,191351,'74557','origin','show_model_rows','0',0,''),(608307,191351,'74557','origin','show_properties_rows','0',0,''),(608308,191351,'74557','origin','show_rating_rows','0',0,''),(608309,191351,'74557','origin','show_rating_counts_rows','0',0,''),(608310,191351,'74557','origin','show_price_rows','0',0,''),(608311,191351,'74557','origin','show_buy_button_rows','0',0,''),(608312,191351,'74557','origin','show_qty_input_rows','0',0,''),(608313,191351,'74557','origin','show_view_button_rows','0',0,''),(608314,191351,'74557','origin','show_wishlist_button_rows','0',0,''),(608315,191351,'74557','origin','show_compare_rows','0',0,''),(608316,191351,'74557','origin','show_name_b2b','0',0,''),(608317,191351,'74557','origin','show_image_b2b','0',0,''),(608318,191351,'74557','origin','show_stock_b2b','0',0,''),(608319,191351,'74557','origin','show_description_b2b','0',0,''),(608320,191351,'74557','origin','show_model_b2b','0',0,''),(608321,191351,'74557','origin','show_properties_b2b','0',0,''),(608322,191351,'74557','origin','show_rating_b2b','0',0,''),(608323,191351,'74557','origin','show_rating_counts_b2b','0',0,''),(608324,191351,'74557','origin','show_price_b2b','0',0,''),(608325,191351,'74557','origin','show_qty_input_b2b','0',0,''),(608326,191351,'74557','origin','show_view_button_b2b','0',0,''),(608327,191351,'74557','origin','show_attributes_b2b','0',0,''),(608328,191351,'74557','origin','items_on_page','12',0,''),(608329,191351,'74557','origin','col_in_row','2',0,'8356'),(608330,191351,'74557','origin','col_in_row','1',0,'8377'),(608331,191351,'74557','origin','product_names_teg','h2',0,''),(608332,191354,'74560','origin','block_type','1',0,''),(608333,191355,'74561','origin','block_type','1',0,''),(608334,191355,'74561','origin','padding-top','10',0,''),(608335,191355,'74561','origin','padding-bottom','10',0,''),(608336,191355,'74561','origin','border-bottom-width','1',0,''),(608337,191355,'74561','origin','border-bottom-color','$content-border-1',0,''),(608338,191355,'74561','origin','margin-left','0',0,''),(608339,191355,'74561','origin','margin-right','0',0,''),(608340,191356,'74562','origin','clear','none',0,''),(608341,191356,'74562','origin','float','left',0,''),(608342,191356,'74562','origin','padding-top','3',0,''),(608343,191356,'74562','origin','margin-left','20',0,''),(608344,191357,'74563','origin','float','right',0,''),(608345,191357,'74563','origin','display','none',0,'8377'),(608346,191358,'74564','origin','margin-right','20',0,''),(608347,191358,'74564','origin','float','right',0,''),(608348,191358,'74564','origin','clear','none',0,''),(608349,191358,'74564','origin','display','none',0,'8356'),(608350,191359,'74565','origin','float','left',0,''),(608351,191359,'74565','origin','clear','none',0,''),(608352,191359,'74565','origin','margin-left','20',0,''),(608353,191359,'74565','origin','display','none',0,'8377'),(608354,191360,'74566','origin','float','left',0,''),(608355,191360,'74566','origin','clear','none',0,''),(608356,191360,'74566','origin','sort_pos_3','2',0,''),(608357,191360,'74566','origin','sort_pos_4','3',0,''),(608358,191360,'74566','origin','sort_pos_10','11',0,''),(608359,191360,'74566','origin','sort_pos_9','10',0,''),(608360,191360,'74566','origin','sort_pos_11','12',0,''),(608361,191360,'74566','origin','sort_pos_12','13',0,''),(608362,191360,'74566','origin','sort_pos_14','15',0,''),(608363,191360,'74566','origin','sort_pos_13','14',0,''),(608364,191360,'74566','origin','sort_pos_8','4',0,''),(608365,191360,'74566','origin','sort_pos_7','5',0,''),(608366,191360,'74566','origin','sort_pos_2','7',0,''),(608367,191360,'74566','origin','sort_pos_1','6',0,''),(608368,191360,'74566','origin','sort_pos_6','9',0,''),(608369,191360,'74566','origin','sort_pos_5','8',0,''),(608370,191360,'74566','origin','sort_pos_0','1',0,''),(608371,191360,'74566','origin','sort_hide_10','1',0,''),(608372,191360,'74566','origin','sort_hide_9','1',0,''),(608373,191360,'74566','origin','sort_pos_15','16',0,''),(608374,191360,'74566','origin','sort_pos_16','17',0,''),(608375,191360,'74566','origin','sort_hide_4','0',0,''),(608376,191360,'74566','origin','sort_hide_3','0',0,''),(608377,191360,'74566','origin','sort_hide_16','1',0,''),(608378,191360,'74566','origin','sort_hide_15','1',0,''),(608379,191360,'74566','origin','sort_hide_11','1',0,''),(608380,191360,'74566','origin','sort_hide_12','1',0,''),(608381,191360,'74566','origin','sort_hide_14','1',0,''),(608382,191360,'74566','origin','sort_hide_13','1',0,''),(608383,191360,'74566','origin','sort_hide_8','0',0,''),(608384,191360,'74566','origin','sort_hide_7','0',0,''),(608385,191360,'74566','origin','sort_hide_2','1',0,''),(608386,191360,'74566','origin','sort_hide_1','1',0,''),(608387,191360,'74566','origin','sort_hide_6','1',0,''),(608388,191360,'74566','origin','sort_hide_5','1',0,''),(608389,191360,'74566','origin','sort_hide_0','0',0,''),(608390,191360,'74566','origin','hide_icons','1',0,''),(608391,191361,'74567','origin','margin-bottom','20',0,''),(608392,191362,'74568','origin','block_type','1',0,''),(608393,191362,'74568','origin','style_class','account-order-history',0,''),(608394,191363,'74569','origin','block_type','6',0,''),(608395,191363,'74569','origin','schema','6-3',0,'8356'),(608396,191364,'74570','origin','aria_name','account-menu',0,''),(608397,191365,'73374','origin','block_type','1',0,''),(608398,191365,'73374','origin','padding-top','70',0,''),(608399,191365,'73374','origin','padding-right','30',0,''),(608400,191365,'73374','origin','padding-bottom','30',0,''),(608401,191365,'73374','origin','padding-top','0',0,'8356'),(608402,191365,'73374','origin','padding-left','0',0,'8356'),(608403,191365,'73374','origin','padding-right','0',0,'8356'),(608404,191365,'73374','origin','padding-bottom','0',0,'8356'),(608447,191384,'74571','origin','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(608448,191385,'74572','origin','link','Order History Info',0,''),(608449,191385,'74572','origin','text','TEXT_VIEW',0,''),(608450,191385,'74572','origin','show_pagenation','1',0,''),(608451,191385,'74572','origin','link_pay','Order pay',0,''),(608452,191385,'74572','origin','margin-bottom','20',0,''),(608453,191386,'74573','origin','block_type','1',0,''),(608454,191386,'74573','origin','style_class','account-order-history-info',0,''),(608455,191387,'74574','origin','block_type','6',0,''),(608456,191387,'74574','origin','schema','6-3',0,'8356'),(608457,191388,'74575','origin','aria_name','account-menu',0,''),(608458,191389,'73374','origin','block_type','1',0,''),(608459,191389,'73374','origin','padding-top','70',0,''),(608460,191389,'73374','origin','padding-right','30',0,''),(608461,191389,'73374','origin','padding-bottom','30',0,''),(608462,191389,'73374','origin','padding-top','0',0,'8356'),(608463,191389,'73374','origin','padding-left','0',0,'8356'),(608464,191389,'73374','origin','padding-right','0',0,'8356'),(608465,191389,'73374','origin','padding-bottom','0',0,'8356'),(608508,191408,'74576','origin','float','right',0,''),(608509,191408,'74576','origin','clear','none',0,''),(608510,191408,'74576','origin','margin-left','20',0,''),(608511,191410,'74578','origin','float','right',0,''),(608512,191410,'74578','origin','clear','none',0,''),(608513,191410,'74578','origin','like_button','2',0,''),(608514,191410,'74578','origin','link','Order pay',0,''),(608515,191411,'74579','origin','block_type','2',0,''),(608516,191411,'74579','origin','padding-top','20',0,''),(608517,191411,'74579','origin','margin-bottom','20',0,''),(608518,191412,'74580','origin','like_button','1',0,''),(608519,191412,'74580','origin','text','IMAGE_BUTTON_BACK',0,''),(608520,191412,'74580','origin','link','Order History',0,''),(608521,191413,'74581','origin','text-align','right',0,''),(608522,191414,'74582','origin','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(608523,191416,'74584','origin','float','right',0,''),(608524,191416,'74584','origin','clear','none',0,''),(608525,191416,'74584','origin','margin-left','20',0,''),(608526,191418,'74586','origin','float','right',0,''),(608527,191419,'74587','origin','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(608528,191421,'74589','origin','float','left',0,''),(608529,191422,'74590','origin','block_type','3',0,''),(608530,191422,'74590','origin','clear','both',0,''),(608531,191422,'74590','origin','padding-top','20',0,''),(608532,191422,'74590','origin','schema','3-4',0,'8349'),(608533,191423,'74591','origin','block_type','1',0,''),(608534,191423,'74591','origin','margin-bottom','20',0,''),(608535,191423,'74591','origin','padding-right','0',0,'8349'),(608536,191423,'74591','origin','padding-right','20',0,''),(608537,191424,'74592','origin','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(608538,191425,'74593','origin','padding-left','30',0,''),(608539,191425,'74593','origin','orders_data','telephone',0,''),(608540,191425,'74593','origin','hide_parents','2',0,''),(608541,191426,'74594','origin','block_type','1',0,''),(608542,191426,'74594','origin','padding-right','20',0,''),(608543,191426,'74594','origin','padding-bottom','20',0,''),(608544,191426,'74594','origin','padding-right','0',0,'8349'),(608545,191427,'74595','origin','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(608546,191428,'74596','origin','orders_data','name',0,''),(608547,191428,'74596','origin','padding-left','30',0,''),(608548,191429,'74597','origin','block_type','1',0,''),(608549,191429,'74597','origin','padding-right','20',0,''),(608550,191429,'74597','origin','margin-bottom','20',0,''),(608551,191429,'74597','origin','padding-right','0',0,'8349'),(608552,191430,'74598','origin','short_view','1',0,''),(608553,191430,'74598','origin','hide_parents','2',0,''),(608554,191431,'74599','origin','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(608555,191432,'74600','origin','link','Tracking numbers',0,''),(608556,191432,'74600','origin','text','MORE_TRACKING_NUMBER',0,''),(608557,191432,'74600','origin','popup','1',0,''),(608558,191432,'74600','origin','order_id','1',0,''),(608559,191432,'74600','origin','popup_class','tracking-numbers-popup',0,''),(608560,191432,'74600','origin','font-weight','700',0,''),(608561,191432,'74600','origin','font-size','18',0,''),(608562,191433,'74601','origin','block_type','1',0,''),(608563,191433,'74601','origin','padding-right','20',0,''),(608564,191433,'74601','origin','padding-right','0',0,'8349'),(608565,191434,'74602','origin','orders_data','shipping_method',0,''),(608566,191434,'74602','origin','padding-left','30',0,''),(608567,191435,'74603','origin','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(608568,191436,'74604','origin','block_type','1',0,''),(608569,191436,'74604','origin','padding-right','20',0,''),(608570,191436,'74604','origin','padding-bottom','20',0,''),(608571,191436,'74604','origin','padding-right','0',0,'8349'),(608572,191437,'74605','origin','orders_data','delivery_address',0,''),(608573,191437,'74605','origin','padding-left','30',0,''),(608574,191438,'74606','origin','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(608575,191439,'74607','origin','block_type','1',0,''),(608576,191440,'74608','origin','orders_data','payment_method',0,''),(608577,191440,'74608','origin','padding-left','30',0,''),(608578,191441,'74609','origin','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(608579,191442,'74610','origin','block_type','1',0,''),(608580,191442,'74610','origin','padding-bottom','20',0,''),(608581,191443,'74611','origin','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(608582,191444,'74612','origin','orders_data','billing_address',0,''),(608583,191444,'74612','origin','padding-left','30',0,''),(608584,191445,'74613','origin','block_type','1',0,''),(608585,191445,'74613','origin','style_class','account-order-pay',0,''),(608586,191446,'74614','origin','block_type','6',0,''),(608587,191446,'74614','origin','schema','6-3',0,'8356'),(608588,191447,'74615','origin','aria_name','account-menu',0,''),(608589,191448,'73374','origin','block_type','1',0,''),(608590,191448,'73374','origin','padding-top','70',0,''),(608591,191448,'73374','origin','padding-right','30',0,''),(608592,191448,'73374','origin','padding-bottom','30',0,''),(608593,191448,'73374','origin','padding-top','0',0,'8356'),(608594,191448,'73374','origin','padding-left','0',0,'8356'),(608595,191448,'73374','origin','padding-right','0',0,'8356'),(608596,191448,'73374','origin','padding-bottom','0',0,'8356'),(608639,191468,'74617','origin','block_type','3',0,''),(608640,191469,'74618','origin','block_type','1',0,''),(608641,191469,'74618','origin','padding-right','20',0,''),(608642,191469,'74618','origin','padding-bottom','20',0,''),(608643,191470,'74619','origin','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(608644,191471,'74620','origin','orders_data','name',0,''),(608645,191471,'74620','origin','padding-left','30',0,''),(608646,191472,'74621','origin','block_type','1',0,''),(608647,191473,'74622','origin','padding-left','30',0,''),(608648,191474,'74623','origin','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(608649,191475,'74624','origin','block_type','1',0,''),(608650,191475,'74624','origin','padding-right','20',0,''),(608651,191475,'74624','origin','padding-bottom','20',0,''),(608652,191476,'74625','origin','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(608653,191477,'74626','origin','orders_data','delivery_address',0,''),(608654,191477,'74626','origin','padding-left','30',0,''),(608655,191478,'74627','origin','block_type','1',0,''),(608656,191478,'74627','origin','padding-right','20',0,''),(608657,191479,'74628','origin','orders_data','shipping_method',0,''),(608658,191479,'74628','origin','padding-left','30',0,''),(608659,191480,'74629','origin','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(608660,191481,'74630','origin','block_type','1',0,''),(608661,191482,'74631','origin','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(608662,191483,'74632','origin','orders_data','payment_method',0,''),(608663,191483,'74632','origin','padding-left','30',0,''),(608664,191484,'74633','origin','block_type','1',0,''),(608665,191484,'74633','origin','padding-bottom','20',0,''),(608666,191485,'74634','origin','orders_data','billing_address',0,''),(608667,191485,'74634','origin','padding-left','30',0,''),(608668,191486,'74635','origin','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(608669,191487,'74636','origin','margin-bottom','20',0,''),(608670,191488,'74637','origin','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(608671,191491,'74640','origin','width','680',0,''),(608672,191491,'74640','origin','font-weight','400',0,''),(608673,191491,'74640','origin','font-size','12',0,''),(608674,191491,'74640','origin','padding-top','20',0,''),(608675,191491,'74640','origin','padding-bottom','20',0,''),(608676,191492,'74641','origin','block_type','2',0,''),(608677,191492,'74641','origin','font-weight','normal',0,''),(608678,191492,'74641','origin','padding-bottom','20',0,''),(608679,191493,'74642','origin','font-weight','400',0,''),(608680,191493,'74642','origin','text-align','center',0,''),(608681,191493,'74642','origin','padding-top','10',0,''),(608682,191493,'74642','origin','logo_from','theme',0,''),(608683,191494,'74643','origin','block_type','11',0,''),(608684,191494,'74643','origin','font-weight','normal',0,''),(608685,191495,'74644','origin','text','<p>Email:</p>',1,''),(608686,191495,'74644','origin','font-weight','normal',0,''),(608687,191495,'74644','origin','text-align','right',0,''),(608688,191495,'74644','origin','text','<p>Email:</p>',0,''),(608689,191496,'74645','origin','font-weight','normal',0,''),(608690,191496,'74645','origin','text-align','right',0,''),(608691,191497,'74646','origin','block_type','11',0,''),(608692,191497,'74646','origin','font-weight','normal',0,''),(608693,191498,'74647','origin','text','<p>Phone:</p>',1,''),(608694,191498,'74647','origin','font-weight','normal',0,''),(608695,191498,'74647','origin','text-align','right',0,''),(608696,191498,'74647','origin','text','<p>Phone:</p>',0,''),(608697,191499,'74648','origin','font-weight','normal',0,''),(608698,191499,'74648','origin','text-align','right',0,''),(608699,191500,'74649','origin','block_type','1',0,''),(608700,191501,'74650','origin','font-weight','400',0,''),(608701,191501,'74650','origin','text-align','right',0,''),(608702,191501,'74650','origin','padding-bottom','10',0,''),(608703,191501,'74650','origin','address_spacer',',',0,''),(608704,191501,'74650','origin','font-size','12',0,''),(608705,191502,'74651','origin','block_type','11',0,''),(608706,191502,'74651','origin','font-weight','400',0,''),(608707,191503,'74652','origin','text','<p>Web:</p>',1,''),(608708,191503,'74652','origin','font-weight','400',0,''),(608709,191503,'74652','origin','text-align','right',0,''),(608710,191503,'74652','origin','text','<p>Web:</p>',0,''),(608711,191504,'74653','origin','font-weight','normal',0,''),(608712,191504,'74653','origin','text-align','right',0,''),(608713,191505,'74654','origin','font-weight','normal',0,''),(608714,191505,'74654','origin','padding-top','20',0,''),(608715,191505,'74654','origin','font-size','12',0,''),(608716,191506,'74655','origin','block_type','1',0,''),(608717,191506,'74655','origin','font-weight','normal',0,''),(608718,191506,'74655','origin','padding-top','10',0,''),(608719,191506,'74655','origin','padding-bottom','10',0,''),(608720,191508,'74657','origin','text','<p>If undelivered please return to:</p>',1,''),(608721,191508,'74657','origin','font-weight','bold',0,''),(608722,191508,'74657','origin','text','<p>If undelivered please return to:</p>',0,''),(608723,191509,'74658','origin','block_type','4',0,''),(608724,191509,'74658','origin','font-weight','400',0,''),(608725,191509,'74658','origin','border-top-width','1',0,''),(608726,191509,'74658','origin','border-top-color','$content-border-1',0,''),(608727,191509,'74658','origin','border-left-width','1',0,''),(608728,191509,'74658','origin','border-left-color','$content-border-1',0,''),(608729,191509,'74658','origin','border-right-width','1',0,''),(608730,191509,'74658','origin','border-right-color','$content-border-1',0,''),(608731,191509,'74658','origin','border-bottom-width','1',0,''),(608732,191509,'74658','origin','border-bottom-color','$content-border-1',0,''),(608733,191510,'74659','origin','block_type','2',0,''),(608734,191510,'74659','origin','font-weight','normal',0,''),(608735,191510,'74659','origin','border-right-width','1',0,''),(608736,191510,'74659','origin','border-right-color','$content-border-1',0,''),(608737,191511,'74660','origin','block_type','1',0,''),(608738,191511,'74660','origin','font-weight','normal',0,''),(608739,191511,'74660','origin','border-right-width','1',0,''),(608740,191511,'74660','origin','border-right-color','$content-border-1',0,''),(608741,191511,'74660','origin','background-color','$content-bg-2',0,''),(608742,191511,'74660','origin','padding-top','10',0,''),(608743,191511,'74660','origin','padding-left','10',0,''),(608744,191511,'74660','origin','padding-right','10',0,''),(608745,191511,'74660','origin','padding-bottom','10',0,''),(608746,191512,'74661','origin','font-size','12',0,''),(608747,191512,'74661','origin','font-weight','normal',0,''),(608748,191513,'74662','origin','text','<p>SHIPPING ADDRESS:</p>',1,''),(608749,191513,'74662','origin','font-size','13',0,''),(608750,191513,'74662','origin','font-weight','bold',0,''),(608751,191513,'74662','origin','padding-bottom','10',0,''),(608752,191513,'74662','origin','text','<p>SHIPPING ADDRESS:</p>',0,''),(608753,191514,'74663','origin','block_type','1',0,''),(608754,191514,'74663','origin','font-weight','normal',0,''),(608755,191514,'74663','origin','padding-top','10',0,''),(608756,191514,'74663','origin','padding-left','10',0,''),(608757,191514,'74663','origin','padding-right','10',0,''),(608758,191514,'74663','origin','padding-bottom','10',0,''),(608759,191515,'74664','origin','text','<p>CUSTOMER:</p>',1,''),(608760,191515,'74664','origin','font-size','13',0,''),(608761,191515,'74664','origin','font-weight','bold',0,''),(608762,191515,'74664','origin','text','<p>CUSTOMER:</p>',0,''),(608763,191516,'74665','origin','font-size','12',0,''),(608764,191518,'74667','origin','text','<p>PHONE NUMBER:</p>',1,''),(608765,191518,'74667','origin','font-size','13',0,''),(608766,191518,'74667','origin','font-weight','bold',0,''),(608767,191518,'74667','origin','padding-top','10',0,''),(608768,191518,'74667','origin','text','<p>PHONE NUMBER:</p>',0,''),(608769,191519,'74668','origin','font-size','12',0,''),(608770,191520,'74669','origin','text','<p>E-MAIL ADDRESS:</p>',1,''),(608771,191520,'74669','origin','font-size','13',0,''),(608772,191520,'74669','origin','font-weight','bold',0,''),(608773,191520,'74669','origin','padding-top','10',0,''),(608774,191520,'74669','origin','text','<p>E-MAIL ADDRESS:</p>',0,''),(608775,191521,'74670','origin','block_type','2',0,''),(608776,191521,'74670','origin','font-weight','normal',0,''),(608777,191521,'74670','origin','border-right-width','1',0,''),(608778,191521,'74670','origin','border-right-color','$content-border-1',0,''),(608779,191521,'74670','origin','border-top-width','1',0,''),(608780,191521,'74670','origin','border-top-color','$content-border-1',0,''),(608781,191522,'74671','origin','block_type','1',0,''),(608782,191522,'74671','origin','font-weight','normal',0,''),(608783,191522,'74671','origin','padding-top','10',0,''),(608784,191522,'74671','origin','padding-left','10',0,''),(608785,191522,'74671','origin','padding-right','10',0,''),(608786,191522,'74671','origin','padding-bottom','10',0,''),(608787,191522,'74671','origin','border-right-width','1',0,''),(608788,191522,'74671','origin','border-right-color','$content-border-1',0,''),(608789,191524,'74673','origin','text','<p>Shipping via</p>',1,''),(608790,191524,'74673','origin','font-weight','bold',0,''),(608791,191524,'74673','origin','text','<p>Shipping via</p>',0,''),(608792,191525,'74674','origin','block_type','1',0,''),(608793,191525,'74674','origin','font-weight','normal',0,''),(608794,191525,'74674','origin','padding-top','10',0,''),(608795,191525,'74674','origin','padding-left','10',0,''),(608796,191525,'74674','origin','padding-right','10',0,''),(608797,191525,'74674','origin','padding-bottom','10',0,''),(608798,191527,'74676','origin','text','<p>Shipping service</p>',1,''),(608799,191527,'74676','origin','font-weight','bold',0,''),(608800,191527,'74676','origin','text','<p>Shipping service</p>',0,''),(608801,191528,'74677','origin','font-weight','normal',0,''),(608802,191528,'74677','origin','text-align','center',0,''),(608803,191528,'74677','origin','padding-top','40',0,''),(608804,191529,'74678','origin','block_type','1',0,''),(608805,191530,'74679','origin','block_type','8',0,''),(608806,191531,'74680','origin','text','##TEXT_MAIN##',0,''),(608807,191531,'74680','origin','margin-bottom','20',0,''),(608808,191531,'74680','origin','text-align','center',0,''),(608809,191532,'74681','origin','margin-bottom','20',0,''),(608810,191533,'74682','origin','text','<h1>##HEADING_TITLE##</h1>',0,''),(608811,191535,'74684','origin','block_type','2',0,''),(608812,191536,'74685','origin','block_type','1',0,''),(608813,191536,'74685','origin','style_class','product',0,''),(608814,191536,'74685','origin','padding-right','10',0,''),(608815,191536,'74685','origin','padding-bottom','20',0,''),(608816,191537,'74686','origin','block_type','1',0,''),(608817,191538,'74687','origin','product_element','products_name',0,''),(608818,191538,'74687','origin','font-family','$font-1',0,''),(608819,191538,'74687','origin','padding-bottom','10',0,''),(608820,191538,'74687','origin','font-size','16',0,''),(608821,191539,'74688','origin','block_type','2',0,''),(608822,191540,'74689','origin','product_element','image',0,''),(608823,191540,'74689','origin','padding-right','10',0,''),(608824,191541,'74690','origin','product_element','products_price_old',0,''),(608825,191541,'74690','origin','font-family','$font-1',0,''),(608826,191541,'74690','origin','font-size','14',0,''),(608827,191541,'74690','origin','text-decoration','line-through',0,''),(608828,191542,'74691','origin','product_element','products_price',0,''),(608829,191542,'74691','origin','font-family','$font-1',0,''),(608830,191542,'74691','origin','font-size','20',0,''),(608831,191542,'74691','origin','padding-top','20',0,''),(608832,191543,'74692','origin','block_type','1',0,''),(608833,191543,'74692','origin','style_class','product',0,''),(608834,191543,'74692','origin','padding-left','10',0,''),(608835,191543,'74692','origin','padding-bottom','20',0,''),(608836,191544,'74693','origin','block_type','2',0,''),(608837,191545,'74694','origin','product_element','image',0,''),(608838,191545,'74694','origin','padding-right','10',0,''),(608839,191546,'74695','origin','font-size','14',0,''),(608840,191546,'74695','origin','font-family','$font-1',0,''),(608841,191546,'74695','origin','text-decoration','line-through',0,''),(608842,191546,'74695','origin','product_element','products_price_old',0,''),(608843,191547,'74696','origin','product_element','products_price',0,''),(608844,191547,'74696','origin','font-family','$font-1',0,''),(608845,191547,'74696','origin','font-size','20',0,''),(608846,191547,'74696','origin','padding-top','20',0,''),(608847,191548,'74697','origin','block_type','1',0,''),(608848,191549,'74698','origin','product_element','products_name',0,''),(608849,191549,'74698','origin','font-family','$font-1',0,''),(608850,191549,'74698','origin','font-size','16',0,''),(608851,191549,'74698','origin','padding-bottom','10',0,''),(608852,191550,'74699','origin','font-size','30',0,''),(608853,191550,'74699','origin','font-family','$font-1',0,''),(608854,191550,'74699','origin','text-align','center',0,''),(608855,191550,'74699','origin','padding-bottom','50',0,''),(608856,191551,'74700','origin','padding-bottom','20',0,''),(608857,191551,'74700','origin','text-align','center',0,''),(608858,191552,'74701','origin','width','680',0,''),(608859,191553,'74702','origin','padding-top','200',0,''),(608860,191553,'74702','origin','padding-left','200',0,''),(608861,191553,'74702','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',1,''),(608862,191553,'74702','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',0,''),(608863,191554,'74703','origin','text','osCommerce 4',1,''),(608864,191554,'74703','origin','font-family','$font-1',0,''),(608865,191554,'74703','origin','font-size','40',0,''),(608866,191554,'74703','origin','padding-top','50',0,''),(608867,191554,'74703','origin','text-align','center',0,''),(608868,191554,'74703','origin','text','osCommerce 4',0,''),(608869,191555,'74704','origin','block_type','2',0,''),(608870,191555,'74704','origin','border-top-width','1',0,''),(608871,191555,'74704','origin','border-top-color','$content-border-1',0,''),(608872,191556,'74705','origin','text-align','right',0,''),(608873,191556,'74705','origin','padding-top','15',0,''),(608874,191556,'74705','origin','padding-bottom','15',0,''),(608875,191556,'74705','origin','font-size','14',0,''),(608876,191557,'74706','origin','font-family','$font-1',0,''),(608877,191557,'74706','origin','text-align','center',0,''),(608878,191557,'74706','origin','font-size','20',0,''),(608879,191557,'74706','origin','color','$highlight-color-1',0,''),(608880,191557,'74706','origin','border-bottom-width','1',0,''),(608881,191557,'74706','origin','border-bottom-color','$content-border-1',0,''),(608882,191557,'74706','origin','padding-top','10',0,''),(608883,191557,'74706','origin','padding-bottom','10',0,''),(608884,191558,'74707','origin','block_type','1',0,''),(608885,191559,'74708','origin','block_type','6',0,''),(608886,191559,'74708','origin','schema','6-3',0,'8356'),(608887,191560,'74709','origin','aria_name','account-menu',0,''),(608888,191561,'73374','origin','block_type','1',0,''),(608889,191561,'73374','origin','padding-top','70',0,''),(608890,191561,'73374','origin','padding-right','30',0,''),(608891,191561,'73374','origin','padding-bottom','30',0,''),(608892,191561,'73374','origin','padding-top','0',0,'8356'),(608893,191561,'73374','origin','padding-left','0',0,'8356'),(608894,191561,'73374','origin','padding-right','0',0,'8356'),(608895,191561,'73374','origin','padding-bottom','0',0,'8356'),(608938,191580,'74710','origin','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(608939,191581,'74711','origin','like_button','1',0,''),(608940,191581,'74711','origin','link','personal_catalog',0,''),(608941,191581,'74711','origin','text','BOX_INFORMATION_ALLPRODS',0,''),(608942,191581,'74711','origin','text-align','center',0,''),(608943,191581,'74711','origin','padding-top','20',0,''),(608944,191581,'74711','origin','padding-bottom','20',0,''),(608945,191582,'74712','origin','max_items','10',0,''),(608946,191583,'74713','origin','block_type','1',0,''),(608947,191583,'74713','origin','padding-top','20',0,''),(608948,191583,'74713','origin','padding-left','20',0,''),(608949,191583,'74713','origin','padding-right','20',0,''),(608950,191583,'74713','origin','padding-bottom','20',0,''),(608951,191584,'74714','origin','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(608952,191586,'74716','origin','block_type','1',0,''),(608953,191587,'74717','origin','margin_left_measure','auto',0,''),(608954,191587,'74717','origin','margin_right_measure','auto',0,''),(608955,191587,'74717','origin','max-width','560',0,''),(608956,191588,'74718','origin','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(608957,191589,'74719','origin','margin-bottom','30',0,''),(608958,191590,'74720','origin','block_type','1',0,''),(608959,191590,'74720','origin','style_class','catalog-product-wrap',0,''),(608960,191592,'74722','origin','block_type','2',0,''),(608961,191592,'74722','origin','font-weight','400',0,''),(608962,191592,'74722','origin','padding-bottom','20',0,''),(608963,191592,'74722','origin','schema','2-2',0,'8377'),(608964,191593,'74724','origin','font-weight','400',0,''),(608965,191593,'74724','origin','padding-top','20',0,''),(608966,191593,'74724','origin','padding-right','20',0,''),(608967,191593,'74724','origin','box_align','4',0,''),(608968,191593,'74724','origin','margin-bottom','50',0,''),(608969,191593,'74724','origin','align_position','horizontal',0,''),(608970,191596,'74727','origin','block_type','12',0,''),(608971,191596,'74727','origin','padding-top','15',0,''),(608972,191596,'74727','origin','padding-bottom','5',0,''),(608973,191596,'74727','origin','border-top-width','1',0,''),(608974,191596,'74727','origin','border-top-color','$content-border-1',0,''),(608975,191596,'74727','origin','schema','2-2',0,'8349'),(608976,191596,'74727','origin','margin-bottom','15',0,''),(608977,191596,'74727','origin','border-bottom-width','1',0,''),(608978,191596,'74727','origin','border-bottom-color','$content-border-1',0,''),(608979,191596,'74727','origin','schema','12-2',0,'8356'),(608980,191597,'74728','origin','padding-top','10',0,''),(608981,191597,'74728','origin','padding-bottom','10',0,''),(608982,191598,'74729','origin','block_type','2',0,''),(608983,191598,'74729','origin','schema','2-1',0,'8356'),(608984,191599,'74730','origin','font-size','30',0,''),(608985,191599,'74730','origin','font-weight','400',0,''),(608986,191599,'74730','origin','line-height','35',0,''),(608987,191599,'74730','origin','font-family','$font-1',0,''),(608988,191599,'74730','origin','line_height_measure','px',0,''),(608989,191599,'74730','origin','padding-top','5',0,''),(608990,191600,'74731','origin','box_align','4',0,''),(608991,191600,'74731','origin','margin-bottom','15',0,'8356'),(608992,191600,'74731','origin','text-align','right',0,'8356'),(608993,191600,'74731','origin','padding-top','5',0,''),(608994,191600,'74731','origin','text-align','left',0,''),(608995,191601,'74732','origin','margin-bottom','15',0,''),(608996,191601,'74732','origin','padding-top','15',0,''),(608997,191602,'1694165842.4776','origin','padding-top','10',0,''),(608998,191603,'74733','origin','text-align','right',0,''),(608999,191603,'74733','origin','width','100',0,'8349'),(609000,191603,'74733','origin','width_measure','%',0,'8349'),(609001,191603,'74733','origin','float','none',0,'8349'),(609002,191603,'74733','origin','hide_additional_buttons','1',0,''),(609003,191604,'74734','origin','text-align','right',0,''),(609004,191605,'74735','origin','cat_description','on',0,''),(609005,191605,'74735','origin','length_description','250',0,''),(609006,191605,'74735','origin','padding-bottom','20',0,''),(609007,191606,'74737','origin','document_types_id','4',0,''),(609008,191607,'74738','origin','show_address','1',0,''),(609009,191607,'74738','origin','show_time','1',0,''),(609010,191607,'74738','origin','show_qty','1',0,''),(609011,191607,'74738','origin','show_qty_level1','500',0,''),(609012,191607,'74738','origin','show_qty_level2','2000',0,''),(609013,191607,'74738','origin','text-align','right',0,''),(609014,191607,'74738','origin','margin-bottom','10',0,''),(609015,191608,'74739','origin','block_type','2',0,''),(609016,191612,'74745','origin','font-weight','400',0,''),(609017,191616,'74750','origin','font-weight','normal',0,''),(609018,191616,'74750','origin','padding-top','10',0,''),(609019,191616,'74750','origin','padding-bottom','10',0,''),(609020,191616,'74750','origin','box_align','4',0,''),(609021,191617,'74752','origin','tab_1','Description',1,''),(609022,191617,'74752','origin','tab_2','Reviews',1,''),(609023,191617,'74752','origin','font-weight','400',0,''),(609024,191617,'74752','origin','tab_1','Description',0,''),(609025,191617,'74752','origin','tab_2','Reviews',0,''),(609026,191618,'74753','origin','hTagsInline','block',0,''),(609027,191619,'74754','origin','margin-bottom','20',0,''),(609028,191619,'74754','origin','max-width','500',0,''),(609029,191620,'74755','origin','padding-bottom','10',0,''),(609030,191620,'74755','origin','padding-top','5',0,''),(609031,191621,'74757','origin','font-weight','normal',0,''),(609032,191621,'74757','origin','padding-bottom','20',0,''),(609033,191622,'74758','origin','font-weight','normal',0,''),(609034,191622,'74758','origin','padding-bottom','20',0,''),(609035,191623,'1694166186.2638','origin','block_type','1',0,''),(609036,191624,'74751','origin','font-weight','400',0,''),(609037,191624,'74751','origin','padding-bottom','20',0,''),(609038,191624,'74751','origin','show_qty_input','1',0,''),(609039,191624,'74751','origin','show_compare','1',0,''),(609040,191624,'74751','origin','listing_type','productListing',0,''),(609041,191624,'74751','origin','view_as','carousel',0,''),(609042,191624,'74751','origin','show_name','0',0,''),(609043,191624,'74751','origin','show_image','0',0,''),(609044,191624,'74751','origin','show_stock','0',0,''),(609045,191624,'74751','origin','show_description','0',0,''),(609046,191624,'74751','origin','show_model','0',0,''),(609047,191624,'74751','origin','show_properties','0',0,''),(609048,191624,'74751','origin','show_rating','0',0,''),(609049,191624,'74751','origin','show_rating_counts','0',0,''),(609050,191624,'74751','origin','show_price','0',0,''),(609051,191624,'74751','origin','show_buy_button','0',0,''),(609052,191624,'74751','origin','show_view_button','0',0,''),(609053,191624,'74751','origin','show_wishlist_button','0',0,''),(609054,191624,'74751','origin','display','none',0,'8356'),(609055,191624,'74751','origin','product_names_teg','h2',0,''),(609056,191624,'74751','origin','show_attributes','1',0,''),(609057,191624,'74751','origin','col_in_row','4',0,''),(609058,191624,'74751','origin','hide_parents','2',0,''),(609059,191625,'1694166209.3278','origin','text','<div class=\"heading-3\">##PRODUCT_ALSO_PURCHASED##</div>',0,''),(609060,191626,'1694166191.5684','origin','block_type','1',0,''),(609061,191627,'74747','origin','font-weight','400',0,''),(609062,191627,'74747','origin','padding-bottom','20',0,''),(609063,191627,'74747','origin','show_compare','1',0,''),(609064,191627,'74747','origin','show_name','0',0,''),(609065,191627,'74747','origin','show_image','0',0,''),(609066,191627,'74747','origin','show_stock','0',0,''),(609067,191627,'74747','origin','show_description','0',0,''),(609068,191627,'74747','origin','show_model','0',0,''),(609069,191627,'74747','origin','show_properties','0',0,''),(609070,191627,'74747','origin','show_rating','0',0,''),(609071,191627,'74747','origin','show_rating_counts','0',0,''),(609072,191627,'74747','origin','show_price','0',0,''),(609073,191627,'74747','origin','show_buy_button','0',0,''),(609074,191627,'74747','origin','show_view_button','0',0,''),(609075,191627,'74747','origin','show_wishlist_button','0',0,''),(609076,191627,'74747','origin','listing_type','productListing',0,''),(609077,191627,'74747','origin','col_in_row','2',0,'8356'),(609078,191627,'74747','origin','col_in_row','1',0,'8377'),(609079,191627,'74747','origin','col_in_row','4',0,''),(609080,191627,'74747','origin','hide_parents','2',0,''),(609081,191628,'1694166222.3382','origin','text','<div class=\"heading-3\">##VIEWED_PRODUCTS##</div>',0,''),(609082,191639,'74771','origin','block_type','1',0,''),(609083,191639,'74771','origin','style_class','item-holder',0,''),(609084,191639,'74771','origin','padding-top','25',0,''),(609085,191639,'74771','origin','padding-left','25',0,''),(609086,191639,'74771','origin','padding-right','25',0,''),(609087,191639,'74771','origin','padding-bottom','25',0,''),(609088,191639,'74771','origin','text-align','left',0,''),(609089,191642,'74775','origin','description_characters','90',0,''),(609090,191643,'74776','origin','text-align','right',0,''),(609091,191643,'74776','origin','margin-bottom','10',0,''),(609092,191644,'74777','origin','text-align','right',0,''),(609093,191644,'74777','origin','clear','none',0,''),(609094,191644,'74777','origin','float','left',0,''),(609095,191646,'74779','origin','block_type','2',0,''),(609096,191647,'74780','origin','margin-bottom','7',0,''),(609097,191648,'74781','origin','margin-bottom','10',0,''),(609098,191648,'74781','origin','text-align','right',0,''),(609099,191648,'74781','origin','float','right',0,''),(609100,191649,'74782','origin','clear','both',0,''),(609101,191650,'74783','origin','float','left',0,''),(609102,191650,'74783','origin','margin-right','20',0,''),(609103,191650,'74783','origin','margin-bottom','5',0,''),(609104,191652,'74785','origin','block_type','1',0,''),(609105,191653,'74786','origin','block_type','6',0,''),(609106,191653,'74786','origin','font-weight','400',0,''),(609107,191653,'74786','origin','schema','6-2',0,'8377'),(609108,191653,'74786','origin','schema','6-2',0,'8356'),(609109,191654,'74787','origin','font-weight','400',0,''),(609110,191654,'74787','origin','padding-right','40',0,''),(609111,191654,'74787','origin','padding-right','0',0,'8377'),(609112,191654,'74787','origin','padding-right','0',0,'8356'),(609113,191654,'74787','origin','margin-bottom','20',0,''),(609114,191655,'74788','origin','margin-bottom','20',0,''),(609115,191657,'74790','origin','block_type','1',0,''),(609116,191657,'74790','origin','padding-top','10',0,''),(609117,191657,'74790','origin','padding-bottom','10',0,''),(609118,191657,'74790','origin','border-bottom-width','1',0,''),(609119,191657,'74790','origin','border-bottom-color','$content-border-1',0,''),(609120,191657,'74790','origin','margin-left','0',0,''),(609121,191657,'74790','origin','margin-right','0',0,''),(609122,191658,'74791','origin','float','left',0,''),(609123,191658,'74791','origin','clear','none',0,''),(609124,191658,'74791','origin','sort_pos_3','2',0,''),(609125,191658,'74791','origin','sort_pos_4','3',0,''),(609126,191658,'74791','origin','sort_pos_10','11',0,''),(609127,191658,'74791','origin','sort_pos_9','10',0,''),(609128,191658,'74791','origin','sort_pos_11','12',0,''),(609129,191658,'74791','origin','sort_pos_12','13',0,''),(609130,191658,'74791','origin','sort_pos_14','15',0,''),(609131,191658,'74791','origin','sort_pos_13','14',0,''),(609132,191658,'74791','origin','sort_pos_8','4',0,''),(609133,191658,'74791','origin','sort_pos_7','5',0,''),(609134,191658,'74791','origin','sort_pos_2','7',0,''),(609135,191658,'74791','origin','sort_pos_1','6',0,''),(609136,191658,'74791','origin','sort_pos_6','9',0,''),(609137,191658,'74791','origin','sort_pos_5','8',0,''),(609138,191658,'74791','origin','sort_pos_0','1',0,''),(609139,191658,'74791','origin','sort_hide_10','1',0,''),(609140,191658,'74791','origin','sort_hide_9','1',0,''),(609141,191658,'74791','origin','sort_pos_15','16',0,''),(609142,191658,'74791','origin','sort_pos_16','17',0,''),(609143,191658,'74791','origin','sort_hide_4','0',0,''),(609144,191658,'74791','origin','sort_hide_3','0',0,''),(609145,191658,'74791','origin','sort_hide_16','1',0,''),(609146,191658,'74791','origin','sort_hide_15','1',0,''),(609147,191658,'74791','origin','sort_hide_11','1',0,''),(609148,191658,'74791','origin','sort_hide_12','1',0,''),(609149,191658,'74791','origin','sort_hide_14','1',0,''),(609150,191658,'74791','origin','sort_hide_13','1',0,''),(609151,191658,'74791','origin','sort_hide_8','0',0,''),(609152,191658,'74791','origin','sort_hide_7','0',0,''),(609153,191658,'74791','origin','sort_hide_2','1',0,''),(609154,191658,'74791','origin','sort_hide_1','1',0,''),(609155,191658,'74791','origin','sort_hide_6','1',0,''),(609156,191658,'74791','origin','sort_hide_5','1',0,''),(609157,191658,'74791','origin','sort_hide_0','0',0,''),(609158,191658,'74791','origin','hide_icons','1',0,''),(609159,191659,'74792','origin','float','right',0,''),(609160,191659,'74792','origin','display','none',0,'8377'),(609161,191660,'74793','origin','float','left',0,''),(609162,191660,'74793','origin','clear','none',0,''),(609163,191660,'74793','origin','margin-left','20',0,''),(609164,191660,'74793','origin','display','none',0,'8377'),(609165,191661,'74794','origin','margin-right','20',0,''),(609166,191661,'74794','origin','float','right',0,''),(609167,191661,'74794','origin','clear','none',0,''),(609168,191661,'74794','origin','display','none',0,'8356'),(609169,191662,'74795','origin','block_type','5',0,''),(609170,191662,'74795','origin','padding-top','10',0,''),(609171,191662,'74795','origin','padding-bottom','10',0,''),(609172,191662,'74795','origin','schema','5-2',0,'8377'),(609173,191662,'74795','origin','border-top-color','$content-border-1',0,''),(609174,191662,'74795','origin','border-top-width','1',0,''),(609175,191663,'74796','origin','padding-top','3',0,''),(609176,191664,'74797','origin','float','right',0,''),(609177,191664,'74797','origin','height','31',0,''),(609178,191665,'74798','origin','col_in_row','3',0,''),(609179,191665,'74798','origin','products_align','left',0,''),(609180,191665,'74798','origin','font-weight','400',0,''),(609181,191665,'74798','origin','listing_type','productListing',0,''),(609182,191665,'74798','origin','listing_type_rows','Rows',0,''),(609183,191665,'74798','origin','show_buy_button_b2b','on',0,''),(609184,191665,'74798','origin','show_wishlist_button_b2b','1',0,''),(609185,191665,'74798','origin','show_compare_b2b','1',0,''),(609186,191665,'74798','origin','show_image','0',0,''),(609187,191665,'74798','origin','show_stock','0',0,''),(609188,191665,'74798','origin','show_description','0',0,''),(609189,191665,'74798','origin','show_model','0',0,''),(609190,191665,'74798','origin','show_properties','0',0,''),(609191,191665,'74798','origin','show_rating','0',0,''),(609192,191665,'74798','origin','show_rating_counts','0',0,''),(609193,191665,'74798','origin','show_price','0',0,''),(609194,191665,'74798','origin','show_buy_button','0',0,''),(609195,191665,'74798','origin','show_view_button','0',0,''),(609196,191665,'74798','origin','show_wishlist_button','0',0,''),(609197,191665,'74798','origin','show_compare','0',0,''),(609198,191665,'74798','origin','show_name_rows','0',0,''),(609199,191665,'74798','origin','show_image_rows','0',0,''),(609200,191665,'74798','origin','show_stock_rows','0',0,''),(609201,191665,'74798','origin','show_description_rows','0',0,''),(609202,191665,'74798','origin','show_model_rows','0',0,''),(609203,191665,'74798','origin','show_properties_rows','0',0,''),(609204,191665,'74798','origin','show_rating_rows','0',0,''),(609205,191665,'74798','origin','show_rating_counts_rows','0',0,''),(609206,191665,'74798','origin','show_price_rows','0',0,''),(609207,191665,'74798','origin','show_buy_button_rows','0',0,''),(609208,191665,'74798','origin','show_qty_input_rows','0',0,''),(609209,191665,'74798','origin','show_view_button_rows','0',0,''),(609210,191665,'74798','origin','show_wishlist_button_rows','0',0,''),(609211,191665,'74798','origin','show_compare_rows','0',0,''),(609212,191665,'74798','origin','show_name_b2b','0',0,''),(609213,191665,'74798','origin','show_image_b2b','0',0,''),(609214,191665,'74798','origin','show_stock_b2b','0',0,''),(609215,191665,'74798','origin','show_description_b2b','0',0,''),(609216,191665,'74798','origin','show_model_b2b','0',0,''),(609217,191665,'74798','origin','show_properties_b2b','0',0,''),(609218,191665,'74798','origin','show_rating_b2b','0',0,''),(609219,191665,'74798','origin','show_rating_counts_b2b','0',0,''),(609220,191665,'74798','origin','show_price_b2b','0',0,''),(609221,191665,'74798','origin','show_qty_input_b2b','0',0,''),(609222,191665,'74798','origin','show_view_button_b2b','0',0,''),(609223,191665,'74798','origin','show_attributes_b2b','0',0,''),(609224,191665,'74798','origin','items_on_page','9',0,''),(609225,191665,'74798','origin','col_in_row','2',0,'8356'),(609226,191665,'74798','origin','col_in_row','1',0,'8377'),(609227,191665,'74798','origin','product_names_teg','h2',0,''),(609228,191667,'74800','origin','block_type','1',0,''),(609229,191668,'74801','origin','margin-bottom','20',0,''),(609230,191670,'74802','origin','block_type','1',0,''),(609231,191672,'74804','origin','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(609232,191673,'74805','origin','width','680',0,''),(609233,191673,'74805','origin','font-weight','normal',0,''),(609234,191673,'74805','origin','font-size','12',0,''),(609235,191673,'74805','origin','padding-top','20',0,''),(609236,191673,'74805','origin','padding-bottom','20',0,''),(609237,191673,'74805','origin','color','$content-color-1',0,''),(609238,191674,'74806','origin','font-weight','400',0,''),(609239,191674,'74806','origin','padding-top','20',0,''),(609240,191674,'74806','origin','padding-bottom','0',0,''),(609241,191674,'74806','origin','font-size','12',0,''),(609242,191675,'74807','origin','block_type','3',0,''),(609243,191675,'74807','origin','font-weight','normal',0,''),(609244,191675,'74807','origin','padding-top','20',0,''),(609245,191676,'74808','origin','text','<p>If undelivered please return to:</p>',1,''),(609246,191676,'74808','origin','font-size','12',0,''),(609247,191676,'74808','origin','font-weight','bold',0,''),(609248,191676,'74808','origin','text','<p>If undelivered please return to:</p>',0,''),(609249,191677,'74809','origin','font-size','12',0,''),(609250,191678,'74810','origin','text','<p>Thank you for your order</p>',1,''),(609251,191678,'74810','origin','color','$color-8',0,''),(609252,191678,'74810','origin','font-size','13',0,''),(609253,191678,'74810','origin','font-weight','bold',0,''),(609254,191678,'74810','origin','padding-top','5',0,''),(609255,191678,'74810','origin','text-align','center',0,''),(609256,191678,'74810','origin','text','<p>Thank you for your order</p>',0,''),(609257,191679,'74811','origin','font-weight','400',0,''),(609258,191679,'74811','origin','text-align','center',0,''),(609259,191679,'74811','origin','padding-top','0',0,''),(609260,191679,'74811','origin','padding-left','20',0,''),(609261,191679,'74811','origin','padding-right','20',0,''),(609262,191680,'74812','origin','block_type','6',0,''),(609263,191680,'74812','origin','font-weight','normal',0,''),(609264,191680,'74812','origin','font-size','16',0,''),(609265,191681,'74813','origin','text','<p>Email:</p>',1,''),(609266,191681,'74813','origin','font-weight','normal',0,''),(609267,191681,'74813','origin','text-align','right',0,''),(609268,191681,'74813','origin','font-size','12',0,''),(609269,191681,'74813','origin','text','<p>Email:</p>',0,''),(609270,191682,'74814','origin','font-weight','normal',0,''),(609271,191682,'74814','origin','text-align','right',0,''),(609272,191682,'74814','origin','font-size','12',0,''),(609273,191683,'74815','origin','text','<p>If something has gone wrong please contact us at:</p>',1,''),(609274,191683,'74815','origin','font-size','12',0,''),(609275,191683,'74815','origin','font-weight','bold',0,''),(609276,191683,'74815','origin','text-align','right',0,''),(609277,191683,'74815','origin','text','<p>If something has gone wrong please contact us at:</p>',0,''),(609278,191684,'74816','origin','block_type','6',0,''),(609279,191684,'74816','origin','font-weight','normal',0,''),(609280,191684,'74816','origin','font-size','16',0,''),(609281,191685,'74817','origin','text','<p>Phone:</p>',1,''),(609282,191685,'74817','origin','font-weight','normal',0,''),(609283,191685,'74817','origin','text-align','right',0,''),(609284,191685,'74817','origin','font-size','12',0,''),(609285,191685,'74817','origin','text','<p>Phone:</p>',0,''),(609286,191686,'74818','origin','font-weight','normal',0,''),(609287,191686,'74818','origin','text-align','right',0,''),(609288,191686,'74818','origin','font-size','12',0,''),(609289,191687,'74819','origin','block_type','2',0,''),(609290,191687,'74819','origin','font-weight','normal',0,''),(609291,191687,'74819','origin','padding-bottom','20',0,''),(609292,191688,'74820','origin','font-weight','400',0,''),(609293,191688,'74820','origin','padding-top','20',0,''),(609294,191689,'74821','origin','block_type','11',0,''),(609295,191689,'74821','origin','font-weight','normal',0,''),(609296,191690,'74822','origin','text','<p>Phone:</p>',1,''),(609297,191690,'74822','origin','font-weight','normal',0,''),(609298,191690,'74822','origin','text-align','right',0,''),(609299,191690,'74822','origin','text','<p>Phone:</p>',0,''),(609300,191691,'74823','origin','font-weight','normal',0,''),(609301,191691,'74823','origin','text-align','right',0,''),(609302,191692,'74824','origin','block_type','11',0,''),(609303,191692,'74824','origin','font-weight','normal',0,''),(609304,191693,'74825','origin','text','<p>Web:</p>',1,''),(609305,191693,'74825','origin','font-weight','normal',0,''),(609306,191693,'74825','origin','text-align','right',0,''),(609307,191693,'74825','origin','text','<p>Web:</p>',0,''),(609308,191694,'74826','origin','font-weight','normal',0,''),(609309,191694,'74826','origin','text-align','right',0,''),(609310,191695,'74827','origin','block_type','1',0,''),(609311,191696,'74828','origin','font-weight','normal',0,''),(609312,191696,'74828','origin','text-align','right',0,''),(609313,191696,'74828','origin','padding-bottom','10',0,''),(609314,191696,'74828','origin','address_spacer',',',0,''),(609315,191696,'74828','origin','font-size','12',0,''),(609316,191697,'74829','origin','block_type','11',0,''),(609317,191697,'74829','origin','font-weight','normal',0,''),(609318,191698,'74830','origin','text','<p>Email:</p>',1,''),(609319,191698,'74830','origin','font-weight','normal',0,''),(609320,191698,'74830','origin','text-align','right',0,''),(609321,191698,'74830','origin','text','<p>Email:</p>',0,''),(609322,191699,'74831','origin','font-weight','normal',0,''),(609323,191699,'74831','origin','text-align','right',0,''),(609324,191700,'74832','origin','block_type','4',0,''),(609325,191700,'74832','origin','font-weight','normal',0,''),(609326,191700,'74832','origin','border-top-width','1',0,''),(609327,191700,'74832','origin','border-top-color','$content-border-1',0,''),(609328,191700,'74832','origin','border-left-width','1',0,''),(609329,191700,'74832','origin','border-left-color','$content-border-1',0,''),(609330,191700,'74832','origin','border-right-width','1',0,''),(609331,191700,'74832','origin','border-right-color','$content-border-1',0,''),(609332,191700,'74832','origin','border-bottom-width','1',0,''),(609333,191700,'74832','origin','border-bottom-color','$content-border-1',0,''),(609334,191701,'74833','origin','block_type','2',0,''),(609335,191701,'74833','origin','font-weight','normal',0,''),(609336,191701,'74833','origin','border-right-width','1',0,''),(609337,191701,'74833','origin','border-right-color','$content-border-1',0,''),(609338,191702,'74834','origin','block_type','1',0,''),(609339,191702,'74834','origin','font-weight','400',0,''),(609340,191702,'74834','origin','background-color','$content-bg-2',0,''),(609341,191702,'74834','origin','padding-top','10',0,''),(609342,191702,'74834','origin','padding-left','10',0,''),(609343,191702,'74834','origin','padding-right','10',0,''),(609344,191702,'74834','origin','padding-bottom','30',0,''),(609345,191703,'74835','origin','font-size','12',0,''),(609346,191704,'74836','origin','text','<p>ADDRESS:</p>\n',1,''),(609347,191704,'74836','origin','font-size','14',0,''),(609348,191704,'74836','origin','font-weight','bold',0,''),(609349,191704,'74836','origin','text','<p>ADDRESS:</p>\n',0,''),(609350,191705,'74837','origin','block_type','1',0,''),(609351,191705,'74837','origin','font-weight','normal',0,''),(609352,191705,'74837','origin','padding-top','10',0,''),(609353,191705,'74837','origin','padding-left','10',0,''),(609354,191705,'74837','origin','padding-right','10',0,''),(609355,191705,'74837','origin','padding-bottom','10',0,''),(609356,191707,'74839','origin','text','<p>E-MAIL ADDRESS:</p>',1,''),(609357,191707,'74839','origin','font-weight','bold',0,''),(609358,191707,'74839','origin','font-size','14',0,''),(609359,191707,'74839','origin','padding-top','10',0,''),(609360,191707,'74839','origin','text','<p>E-MAIL ADDRESS:</p>',0,''),(609361,191708,'74840','origin','font-weight','normal',0,''),(609362,191709,'74841','origin','font-weight','normal',0,''),(609363,191710,'74842','origin','text','<p>PHONE NUMBER:</p>',1,''),(609364,191710,'74842','origin','font-size','14',0,''),(609365,191710,'74842','origin','font-weight','bold',0,''),(609366,191710,'74842','origin','padding-top','10',0,''),(609367,191710,'74842','origin','text','<p>PHONE NUMBER:</p>',0,''),(609368,191711,'74843','origin','text','<p>CUSTOMER:</p>',1,''),(609369,191711,'74843','origin','font-size','13',0,''),(609370,191711,'74843','origin','font-weight','bold',0,''),(609371,191711,'74843','origin','text','<p>CUSTOMER:</p>',0,''),(609372,191712,'74844','origin','font-size','14',0,''),(609373,191712,'74844','origin','font-weight','bold',0,''),(609374,191712,'74844','origin','text-align','center',0,''),(609375,191712,'74844','origin','padding-bottom','10',0,''),(609376,191712,'74844','origin','padding-top','10',0,''),(609377,191713,'74845','origin','text','<p>Order date:</p>\n',1,''),(609378,191713,'74845','origin','font-weight','bold',0,''),(609379,191713,'74845','origin','text-align','center',0,''),(609380,191713,'74845','origin','font-size','12',0,''),(609381,191713,'74845','origin','text','<p>Order date:</p>\n',0,''),(609382,191714,'74846','origin','font-weight','normal',0,''),(609383,191714,'74846','origin','text-align','center',0,''),(609384,191714,'74846','origin','padding-bottom','10',0,''),(609385,191715,'74847','origin','block_type','5',0,''),(609386,191715,'74847','origin','font-weight','normal',0,''),(609387,191715,'74847','origin','border-bottom-width','1',0,''),(609388,191715,'74847','origin','border-bottom-color','$content-border-1',0,''),(609389,191715,'74847','origin','border-top-width','1',0,''),(609390,191715,'74847','origin','border-top-color','$content-border-1',0,''),(609391,191715,'74847','origin','border-left-color','$content-border-1',0,''),(609392,191715,'74847','origin','border-left-width','1',0,''),(609393,191716,'74848','origin','block_type','1',0,''),(609394,191716,'74848','origin','font-weight','normal',0,''),(609395,191716,'74848','origin','padding-top','10',0,''),(609396,191716,'74848','origin','padding-left','10',0,''),(609397,191716,'74848','origin','padding-right','10',0,''),(609398,191717,'74849','origin','font-weight','400',0,''),(609399,191717,'74849','origin','line-height','120',0,''),(609400,191717,'74849','origin','line_height_measure','%',0,''),(609401,191717,'74849','origin','font-size','12',0,''),(609402,191718,'74850','origin','text','<p>SHIPPING ADDRESS:</p>',1,''),(609403,191718,'74850','origin','font-size','14',0,''),(609404,191718,'74850','origin','font-weight','bold',0,''),(609405,191718,'74850','origin','padding-bottom','10',0,''),(609406,191718,'74850','origin','text','<p>SHIPPING ADDRESS:</p>',0,''),(609407,191719,'74851','origin','block_type','1',0,''),(609408,191720,'74852','origin','block_type','6',0,''),(609409,191721,'74853','origin','aria_name','account-menu',0,''),(609410,191722,'73374','origin','block_type','1',0,''),(609411,191722,'73374','origin','padding-top','70',0,''),(609412,191722,'73374','origin','padding-right','30',0,''),(609413,191722,'73374','origin','padding-bottom','30',0,''),(609414,191722,'73374','origin','padding-top','0',0,'8356'),(609415,191722,'73374','origin','padding-left','0',0,'8356'),(609416,191722,'73374','origin','padding-right','0',0,'8356'),(609417,191722,'73374','origin','padding-bottom','0',0,'8356'),(609460,191741,'74854','origin','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(609461,191742,'74855','origin','link','Quotation Info',0,''),(609462,191742,'74855','origin','margin-bottom','20',0,''),(609463,191743,'74856','origin','block_type','1',0,''),(609464,191744,'74857','origin','block_type','6',0,''),(609465,191744,'74857','origin','schema','6-3',0,'8356'),(609466,191745,'74858','origin','aria_name','account-menu',0,''),(609467,191746,'73374','origin','block_type','1',0,''),(609468,191746,'73374','origin','padding-top','70',0,''),(609469,191746,'73374','origin','padding-right','30',0,''),(609470,191746,'73374','origin','padding-bottom','30',0,''),(609471,191746,'73374','origin','padding-top','0',0,'8356'),(609472,191746,'73374','origin','padding-left','0',0,'8356'),(609473,191746,'73374','origin','padding-right','0',0,'8356'),(609474,191746,'73374','origin','padding-bottom','0',0,'8356'),(609517,191765,'74859','origin','block_type','3',0,''),(609518,191766,'74860','origin','block_type','1',0,''),(609519,191766,'74860','origin','padding-right','20',0,''),(609520,191766,'74860','origin','padding-bottom','20',0,''),(609521,191767,'74861','origin','orders_data','name',0,''),(609522,191768,'74862','origin','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(609523,191769,'74863','origin','block_type','1',0,''),(609524,191769,'74863','origin','padding-right','20',0,''),(609525,191769,'74863','origin','padding-bottom','20',0,''),(609526,191770,'74864','origin','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(609527,191771,'74865','origin','orders_data','telephone',0,''),(609528,191772,'74866','origin','block_type','1',0,''),(609529,191772,'74866','origin','padding-right','20',0,''),(609530,191773,'74867','origin','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(609531,191774,'74868','origin','orders_data','shipping_method',0,''),(609532,191775,'74869','origin','block_type','1',0,''),(609533,191775,'74869','origin','padding-right','20',0,''),(609534,191775,'74869','origin','padding-bottom','20',0,''),(609535,191776,'74870','origin','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(609536,191777,'74871','origin','orders_data','delivery_address',0,''),(609537,191778,'74872','origin','block_type','1',0,''),(609538,191778,'74872','origin','padding-bottom','20',0,''),(609539,191779,'74873','origin','orders_data','billing_address',0,''),(609540,191780,'74874','origin','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(609541,191781,'74875','origin','block_type','1',0,''),(609542,191782,'74876','origin','orders_data','payment_method',0,''),(609543,191783,'74877','origin','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(609544,191784,'74878','origin','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(609545,191786,'74880','origin','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(609546,191789,'74883','origin','block_type','2',0,''),(609547,191789,'74883','origin','padding-top','20',0,''),(609548,191789,'74883','origin','margin-bottom','20',0,''),(609549,191790,'74884','origin','like_button','1',0,''),(609550,191790,'74884','origin','text','IMAGE_BUTTON_BACK',0,''),(609551,191790,'74884','origin','link','Quotations',0,''),(609552,191791,'74885','origin','text','<h1>##HEADING_TITLE##</h1>',0,''),(609553,191792,'74886','origin','padding-top','20',0,''),(609554,191792,'74886','origin','padding-bottom','20',0,''),(609555,191792,'74886','origin','block_type','1',0,''),(609556,191792,'74886','origin','background-color','$content-bg-2',0,''),(609557,191794,'74888','origin','block_type','4',0,''),(609558,191795,'74889','origin','background-color','$content-bg-1',0,''),(609559,191796,'74890','origin','block_type','1',0,''),(609560,191796,'74890','origin','style_class','order-summary',0,''),(609561,191796,'74890','origin','margin-left','30',0,''),(609562,191797,'74891','origin','block_type','1',0,''),(609563,191797,'74891','origin','padding-left','20',0,''),(609564,191797,'74891','origin','padding-right','20',0,''),(609565,191797,'74891','origin','padding-bottom','30',0,''),(609566,191800,'74894','origin','block_type','1',0,''),(609567,191801,'74895','origin','block_type','6',0,''),(609568,191801,'74895','origin','schema','6-3',0,'8356'),(609569,191802,'74896','origin','aria_name','account-menu',0,''),(609570,191803,'73374','origin','block_type','1',0,''),(609571,191803,'73374','origin','padding-top','70',0,''),(609572,191803,'73374','origin','padding-right','30',0,''),(609573,191803,'73374','origin','padding-bottom','30',0,''),(609574,191803,'73374','origin','padding-top','0',0,'8356'),(609575,191803,'73374','origin','padding-left','0',0,'8356'),(609576,191803,'73374','origin','padding-right','0',0,'8356'),(609577,191803,'73374','origin','padding-bottom','0',0,'8356'),(609620,191822,'74897','origin','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(609621,191823,'74898','origin','margin-bottom','20',0,''),(609622,191824,'74899','origin','block_type','1',0,''),(609623,191826,'74901','origin','pagination','bottom',0,''),(609624,191827,'74902','origin','width','800',0,''),(609625,191828,'74903','origin','block_type','11',0,''),(609626,191828,'74903','origin','border-top-width','1',0,''),(609627,191828,'74903','origin','border-left-width','1',0,''),(609628,191828,'74903','origin','border-right-width','1',0,''),(609629,191828,'74903','origin','border-bottom-width','1',0,''),(609630,191828,'74903','origin','border-top-color','$content-border-1',0,''),(609631,191828,'74903','origin','border-left-color','$content-border-1',0,''),(609632,191828,'74903','origin','border-right-color','$content-border-1',0,''),(609633,191828,'74903','origin','border-bottom-color','$content-border-1',0,''),(609634,191829,'74904','origin','block_type','1',0,''),(609635,191829,'74904','origin','border-right-width','1',0,''),(609636,191829,'74904','origin','border-right-color','$content-border-1',0,''),(609637,191829,'74904','origin','padding-top','10',0,''),(609638,191829,'74904','origin','padding-right','10',0,''),(609639,191829,'74904','origin','padding-bottom','10',0,''),(609640,191830,'74905','origin','block_type','9',0,''),(609641,191831,'74906','origin','text','1.',0,''),(609642,191831,'74906','origin','font-size','12',0,''),(609643,191831,'74906','origin','text-align','right',0,''),(609644,191831,'74906','origin','padding-right','5',0,''),(609645,191832,'74907','origin','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(609646,191832,'74907','origin','font-size','12',0,''),(609647,191832,'74907','origin','padding-bottom','5',0,''),(609648,191833,'74908','origin','block_type','9',0,''),(609649,191834,'74909','origin','text','4.',0,''),(609650,191834,'74909','origin','font-size','12',0,''),(609651,191834,'74909','origin','text-align','right',0,''),(609652,191834,'74909','origin','margin-right','5',0,''),(609653,191835,'74910','origin','text','Our Replacement Department will process your request.',0,''),(609654,191835,'74910','origin','font-size','12',0,''),(609655,191835,'74910','origin','padding-bottom','5',0,''),(609656,191836,'74911','origin','block_type','9',0,''),(609657,191837,'74912','origin','text','3.',0,''),(609658,191837,'74912','origin','font-size','12',0,''),(609659,191837,'74912','origin','text-align','right',0,''),(609660,191837,'74912','origin','margin-right','5',0,''),(609661,191838,'74913','origin','text','Return the authorized item(s) per shipping instructions.',0,''),(609662,191838,'74913','origin','font-size','12',0,''),(609663,191838,'74913','origin','padding-bottom','5',0,''),(609664,191839,'74914','origin','block_type','9',0,''),(609665,191840,'74915','origin','text','2.',0,''),(609666,191840,'74915','origin','font-size','12',0,''),(609667,191840,'74915','origin','text-align','right',0,''),(609668,191840,'74915','origin','margin-right','5',0,''),(609669,191841,'74916','origin','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(609670,191841,'74916','origin','font-size','12',0,''),(609671,191841,'74916','origin','padding-bottom','5',0,''),(609672,191842,'74917','origin','block_type','1',0,''),(609673,191842,'74917','origin','padding-left','15',0,''),(609674,191843,'74918','origin','text','Replacement Policy:',0,''),(609675,191843,'74918','origin','font-size','14',0,''),(609676,191843,'74918','origin','padding-bottom','5',0,''),(609677,191843,'74918','origin','font-weight','bold',0,''),(609678,191844,'74919','origin','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(609679,191844,'74919','origin','font-size','11',0,''),(609680,191844,'74919','origin','font-style','italic',0,''),(609681,191844,'74919','origin','padding-bottom','5',0,''),(609682,191845,'74920','origin','block_type','1',0,''),(609683,191845,'74920','origin','border-bottom-width','1',0,''),(609684,191845,'74920','origin','border-bottom-color','$content-border-1',0,''),(609685,191846,'74921','origin','text','Return Material Authorization (RMA) Form',0,''),(609686,191846,'74921','origin','text-align','center',0,''),(609687,191846,'74921','origin','font-size','16',0,''),(609688,191846,'74921','origin','font-weight','bold',0,''),(609689,191847,'74922','origin','text-align','center',0,''),(609690,191847,'74922','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',1,''),(609691,191847,'74922','origin','padding-top','10',0,''),(609692,191847,'74922','origin','padding-bottom','10',0,''),(609693,191847,'74922','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',0,''),(609694,191848,'74923','origin','block_type','1',0,''),(609695,191848,'74923','origin','padding-top','10',0,''),(609696,191848,'74923','origin','padding-left','10',0,''),(609697,191848,'74923','origin','padding-right','10',0,''),(609698,191848,'74923','origin','padding-bottom','20',0,''),(609699,191849,'74924','origin','block_type','2',0,''),(609700,191849,'74924','origin','padding-top','5',0,''),(609701,191850,'74925','origin','block_type','11',0,''),(609702,191851,'74926','origin','text','Email:',0,''),(609703,191851,'74926','origin','font-size','12',0,''),(609704,191852,'74927','origin','data','rrDelivery_email_address',0,''),(609705,191852,'74927','origin','font-size','12',0,''),(609706,191853,'74928','origin','block_type','11',0,''),(609707,191854,'74929','origin','text','Phone:',0,''),(609708,191854,'74929','origin','font-size','12',0,''),(609709,191855,'74930','origin','data','rrDelivery_telephone',0,''),(609710,191855,'74930','origin','font-size','12',0,''),(609711,191856,'74931','origin','block_type','2',0,''),(609712,191856,'74931','origin','padding-top','5',0,''),(609713,191857,'74932','origin','block_type','11',0,''),(609714,191858,'74933','origin','text','Country:',0,''),(609715,191858,'74933','origin','font-size','12',0,''),(609716,191859,'74934','origin','data','rrDelivery_country',0,''),(609717,191859,'74934','origin','font-size','12',0,''),(609718,191860,'74935','origin','block_type','11',0,''),(609719,191861,'74936','origin','text','Postcode:',0,''),(609720,191861,'74936','origin','font-size','12',0,''),(609721,191862,'74937','origin','data','rrDelivery_postcode',0,''),(609722,191862,'74937','origin','font-size','12',0,''),(609723,191863,'74938','origin','block_type','2',0,''),(609724,191863,'74938','origin','padding-top','5',0,''),(609725,191864,'74939','origin','block_type','11',0,''),(609726,191865,'74940','origin','text','City:',0,''),(609727,191865,'74940','origin','font-size','12',0,''),(609728,191866,'74941','origin','data','rrDelivery_city',0,''),(609729,191866,'74941','origin','font-size','12',0,''),(609730,191867,'74942','origin','block_type','11',0,''),(609731,191868,'74943','origin','text','State:',0,''),(609732,191868,'74943','origin','font-size','12',0,''),(609733,191869,'74944','origin','data','rrDelivery_state',0,''),(609734,191869,'74944','origin','font-size','12',0,''),(609735,191870,'74945','origin','block_type','9',0,''),(609736,191870,'74945','origin','padding-top','5',0,''),(609737,191871,'74946','origin','text','Address:',0,''),(609738,191871,'74946','origin','font-size','12',0,''),(609739,191872,'74947','origin','data','rrDelivery_street_address',0,''),(609740,191872,'74947','origin','font-size','12',0,''),(609741,191873,'74948','origin','block_type','2',0,''),(609742,191874,'74949','origin','block_type','11',0,''),(609743,191875,'74950','origin','text','Company:',0,''),(609744,191875,'74950','origin','font-size','12',0,''),(609745,191876,'74951','origin','data','rrDelivery_company',0,''),(609746,191876,'74951','origin','font-size','12',0,''),(609747,191877,'74952','origin','block_type','2',0,''),(609748,191878,'74953','origin','text','Contact Name:',0,''),(609749,191878,'74953','origin','font-size','12',0,''),(609750,191879,'74954','origin','data','rrDelivery_name',0,''),(609751,191879,'74954','origin','font-size','12',0,''),(609752,191880,'74955','origin','block_type','2',0,''),(609753,191880,'74955','origin','padding-left','10',0,''),(609754,191880,'74955','origin','padding-top','20',0,''),(609755,191880,'74955','origin','padding-right','10',0,''),(609756,191881,'74956','origin','block_type','5',0,''),(609757,191882,'74957','origin','text','RMA No:',0,''),(609758,191882,'74957','origin','font-size','12',0,''),(609759,191882,'74957','origin','font-weight','bold',0,''),(609760,191883,'74958','origin','data','rrNumber',0,''),(609761,191883,'74958','origin','font-size','12',0,''),(609762,191883,'74958','origin','font-weight','bold',0,''),(609763,191884,'74959','origin','block_type','2',0,''),(609764,191885,'74960','origin','text','Date Issued:',0,''),(609765,191885,'74960','origin','font-size','12',0,''),(609766,191885,'74960','origin','font-weight','bold',0,''),(609767,191886,'74961','origin','data','rrDateCreate',0,''),(609768,191886,'74961','origin','font-size','12',0,''),(609769,191886,'74961','origin','font-weight','bold',0,''),(609770,191887,'74962','origin','block_type','1',0,''),(609771,191888,'74963','origin','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(609772,191888,'74963','origin','font-size','12',0,''),(609773,191888,'74963','origin','font-style','italic',0,''),(609774,191888,'74963','origin','padding-bottom','20',0,''),(609775,191890,'74965','origin','block_type','1',0,''),(609776,191890,'74965','origin','border-top-width','1',0,''),(609777,191890,'74965','origin','border-left-width','1',0,''),(609778,191890,'74965','origin','border-right-width','1',0,''),(609779,191890,'74965','origin','border-bottom-width','1',0,''),(609780,191890,'74965','origin','border-top-color','$content-border-1',0,''),(609781,191890,'74965','origin','border-left-color','$content-border-1',0,''),(609782,191890,'74965','origin','border-right-color','$content-border-1',0,''),(609783,191890,'74965','origin','border-bottom-color','$content-border-1',0,''),(609784,191891,'74966','origin','block_type','11',0,''),(609785,191892,'74967','origin','block_type','1',0,''),(609786,191892,'74967','origin','padding-top','10',0,''),(609787,191892,'74967','origin','padding-right','10',0,''),(609788,191892,'74967','origin','padding-bottom','10',0,''),(609789,191892,'74967','origin','border-right-width','1',0,''),(609790,191892,'74967','origin','border-right-color','$content-border-1',0,''),(609791,191893,'74968','origin','block_type','9',0,''),(609792,191894,'74969','origin','text','4.',0,''),(609793,191894,'74969','origin','font-size','12',0,''),(609794,191894,'74969','origin','text-align','right',0,''),(609795,191894,'74969','origin','padding-right','5',0,''),(609796,191895,'74970','origin','font-size','11',0,''),(609797,191895,'74970','origin','font-style','italic',0,''),(609798,191895,'74970','origin','padding-bottom','5',0,''),(609799,191896,'74971','origin','text','Ship returned items to:',0,''),(609800,191896,'74971','origin','font-size','12',0,''),(609801,191896,'74971','origin','padding-bottom','5',0,''),(609802,191897,'74972','origin','block_type','9',0,''),(609803,191898,'74973','origin','text','3.',0,''),(609804,191898,'74973','origin','font-size','12',0,''),(609805,191898,'74973','origin','text-align','right',0,''),(609806,191898,'74973','origin','padding-right','5',0,''),(609807,191899,'74974','origin','text','Ship only the items that are authorized.',0,''),(609808,191899,'74974','origin','font-size','12',0,''),(609809,191899,'74974','origin','padding-bottom','10',0,''),(609810,191900,'74975','origin','block_type','9',0,''),(609811,191901,'74976','origin','text','1.',0,''),(609812,191901,'74976','origin','font-size','12',0,''),(609813,191901,'74976','origin','text-align','right',0,''),(609814,191901,'74976','origin','padding-right','5',0,''),(609815,191902,'74977','origin','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(609816,191902,'74977','origin','font-size','12',0,''),(609817,191902,'74977','origin','padding-bottom','10',0,''),(609818,191903,'74978','origin','block_type','1',0,''),(609819,191904,'74979','origin','text','Shipping Instructions:',0,''),(609820,191904,'74979','origin','font-weight','bold',0,''),(609821,191904,'74979','origin','font-size','14',0,''),(609822,191904,'74979','origin','padding-bottom','5',0,''),(609823,191904,'74979','origin','padding-left','10',0,''),(609824,191905,'74980','origin','block_type','9',0,''),(609825,191906,'74981','origin','text','2.',0,''),(609826,191906,'74981','origin','font-size','12',0,''),(609827,191906,'74981','origin','text-align','right',0,''),(609828,191906,'74981','origin','padding-right','5',0,''),(609829,191907,'74982','origin','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(609830,191907,'74982','origin','font-size','12',0,''),(609831,191907,'74982','origin','padding-bottom','10',0,''),(609832,191908,'74983','origin','block_type','1',0,''),(609833,191908,'74983','origin','padding-left','10',0,''),(609834,191908,'74983','origin','padding-right','10',0,''),(609835,191908,'74983','origin','padding-bottom','10',0,''),(609836,191909,'74984','origin','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(609837,191909,'74984','origin','font-size','11',0,''),(609838,191909,'74984','origin','font-style','italic',0,''),(609839,191910,'74985','origin','block_type','1',0,''),(609840,191910,'74985','origin','padding-top','10',0,''),(609841,191910,'74985','origin','padding-left','40',0,''),(609842,191910,'74985','origin','padding-right','40',0,''),(609843,191910,'74985','origin','padding-bottom','10',0,''),(609844,191911,'74986','origin','block_type','1',0,''),(609845,191911,'74986','origin','padding-top','10',0,''),(609846,191911,'74986','origin','padding-left','10',0,''),(609847,191911,'74986','origin','padding-right','10',0,''),(609848,191911,'74986','origin','padding-bottom','10',0,''),(609849,191911,'74986','origin','border-top-width','1',0,''),(609850,191911,'74986','origin','border-left-width','1',0,''),(609851,191911,'74986','origin','border-right-width','1',0,''),(609852,191911,'74986','origin','border-bottom-width','1',0,''),(609853,191911,'74986','origin','border-top-color','$content-border-1',0,''),(609854,191911,'74986','origin','border-left-color','$content-border-1',0,''),(609855,191911,'74986','origin','border-right-color','$content-border-1',0,''),(609856,191911,'74986','origin','border-bottom-color','$content-border-1',0,''),(609857,191912,'74987','origin','block_type','3',0,''),(609858,191913,'74988','origin','data','rrDelivery_name',0,''),(609859,191913,'74988','origin','font-size','9',0,''),(609860,191914,'74989','origin','block_type','2',0,''),(609861,191915,'74990','origin','text','RMA#:',0,''),(609862,191915,'74990','origin','font-size','10',0,''),(609863,191916,'74991','origin','data','rrNumber',0,''),(609864,191916,'74991','origin','font-size','9',0,''),(609865,191917,'74992','origin','block_type','5',0,''),(609866,191918,'74993','origin','font-size','9',0,''),(609867,191919,'74994','origin','block_type','1',0,''),(609868,191919,'74994','origin','padding-left','10',0,''),(609869,191919,'74994','origin','padding-right','10',0,''),(609870,191919,'74994','origin','padding-bottom','10',0,''),(609871,191920,'74995','origin','text','Use this space for additional Comments:',0,''),(609872,191920,'74995','origin','font-size','11',0,''),(609873,191920,'74995','origin','font-style','italic',0,''),(609874,191921,'74996','origin','text','&nbsp;',0,''),(609875,191921,'74996','origin','border-bottom-width','1',0,''),(609876,191921,'74996','origin','border-bottom-color','$content-border-1',0,''),(609877,191922,'74997','origin','text','&nbsp;',0,''),(609878,191922,'74997','origin','border-bottom-width','1',0,''),(609879,191922,'74997','origin','border-bottom-color','$content-border-1',0,''),(609880,191922,'74997','origin','padding-top','5',0,''),(609881,191923,'74998','origin','text','&nbsp;',0,''),(609882,191923,'74998','origin','border-bottom-width','1',0,''),(609883,191923,'74998','origin','border-bottom-color','$content-border-1',0,''),(609884,191923,'74998','origin','padding-top','5',0,''),(609885,191924,'74999','origin','text','&nbsp;',0,''),(609886,191924,'74999','origin','border-bottom-width','1',0,''),(609887,191924,'74999','origin','border-bottom-color','$content-border-1',0,''),(609888,191924,'74999','origin','padding-top','5',0,''),(609889,191925,'75000','origin','block_type','3',0,''),(609890,191925,'75000','origin','padding-top','10',0,''),(609891,191925,'75000','origin','padding-bottom','10',0,''),(609892,191925,'75000','origin','padding-right','10',0,''),(609893,191926,'75001','origin','font-size','11',0,''),(609894,191926,'75001','origin','font-weight','bold',0,''),(609895,191926,'75001','origin','text','Return Approval:',0,''),(609896,191926,'75001','origin','padding-top','5',0,''),(609897,191926,'75001','origin','padding-left','10',0,''),(609898,191927,'75002','origin','border-bottom-width','1',0,''),(609899,191927,'75002','origin','border-bottom-color','$content-border-1',0,''),(609900,191927,'75002','origin','text','&nbsp;',0,''),(609901,191928,'75003','origin','block_type','5',0,''),(609902,191929,'75004','origin','text','Date:',0,''),(609903,191929,'75004','origin','padding-top','5',0,''),(609904,191929,'75004','origin','font-size','11',0,''),(609905,191929,'75004','origin','font-weight','bold',0,''),(609906,191929,'75004','origin','padding-left','5',0,''),(609907,191930,'75005','origin','text','&nbsp;',0,''),(609908,191930,'75005','origin','border-bottom-width','1',0,''),(609909,191930,'75005','origin','border-bottom-color','$content-border-1',0,''),(609910,191931,'75006','origin','block_type','3',0,''),(609911,191931,'75006','origin','padding-right','10',0,''),(609912,191932,'75007','origin','text','Customer Signature:',0,''),(609913,191932,'75007','origin','font-weight','bold',0,''),(609914,191932,'75007','origin','font-size','11',0,''),(609915,191932,'75007','origin','padding-top','5',0,''),(609916,191932,'75007','origin','padding-left','10',0,''),(609917,191933,'75008','origin','text','&nbsp;',0,''),(609918,191933,'75008','origin','border-bottom-width','1',0,''),(609919,191933,'75008','origin','border-bottom-color','$content-border-1',0,''),(609920,191934,'75009','origin','block_type','5',0,''),(609921,191935,'75010','origin','text','Date:',0,''),(609922,191935,'75010','origin','padding-top','5',0,''),(609923,191935,'75010','origin','font-size','11',0,''),(609924,191935,'75010','origin','font-weight','bold',0,''),(609925,191935,'75010','origin','padding-left','5',0,''),(609926,191936,'75011','origin','text','&nbsp;',0,''),(609927,191936,'75011','origin','border-bottom-width','1',0,''),(609928,191936,'75011','origin','border-bottom-color','$content-border-1',0,''),(609929,191937,'75012','origin','block_type','1',0,''),(609930,191937,'75012','origin','style_class','item-holder',0,''),(609931,191937,'75012','origin','padding-top','25',0,''),(609932,191937,'75012','origin','padding-bottom','25',0,''),(609933,191937,'75012','origin','text-align','left',0,''),(609934,191937,'75012','origin','border-top-width','1',0,''),(609935,191937,'75012','origin','border-top-color','$content-border-1',0,''),(609936,191938,'75013','origin','block_type','7',0,''),(609937,191938,'75013','origin','schema','7-2',0,'8356'),(609938,191939,'75014','origin','block_type','5',0,''),(609939,191939,'75014','origin','schema','5-2',0,'8356'),(609940,191940,'75015','origin','clear','none',0,''),(609941,191940,'75015','origin','padding-right','20',0,''),(609942,191941,'75016','origin','padding-right','20',0,''),(609943,191941,'75016','origin','max-width','300',0,'8356'),(609944,191941,'75016','origin','margin_left_measure','auto',0,'8356'),(609945,191941,'75016','origin','margin_right_measure','auto',0,'8356'),(609946,191942,'75017','origin','block_type','1',0,''),(609947,191943,'75018','origin','text-align','right',0,''),(609948,191943,'75018','origin','margin-top','4',0,''),(609949,191943,'75018','origin','margin-bottom','7',0,''),(609950,191943,'75018','origin','float','left',0,''),(609951,191944,'75019','origin','padding-top','6',0,''),(609952,191944,'75019','origin','padding-left','5',0,''),(609953,191944,'75019','origin','float','left',0,''),(609954,191944,'75019','origin','clear','none',0,''),(609955,191945,'75020','origin','padding-right','20',0,''),(609956,191946,'75021','origin','description_characters','200',0,''),(609957,191946,'75021','origin','clear','none',0,''),(609958,191946,'75021','origin','padding-right','20',0,''),(609959,191947,'75022','origin','clear','none',0,''),(609960,191948,'75023','origin','margin-bottom','20',0,''),(609961,191949,'75024','origin','block_type','1',0,''),(609962,191949,'75024','origin','padding-left','40',0,''),(609963,191949,'75024','origin','style_class','right-aria',0,''),(609964,191949,'75024','origin','padding-left','0',0,'8356'),(609965,191950,'75025','origin','margin-bottom','15',0,''),(609966,191950,'75025','origin','text-align','right',0,''),(609967,191951,'75026','origin','margin-bottom','10',0,''),(609968,191951,'75026','origin','text-align','right',0,''),(609969,191952,'75027','origin','margin-bottom','10',0,''),(609970,191953,'75028','origin','text-align','right',0,''),(609971,191953,'75028','origin','margin-bottom','15',0,''),(609972,191954,'75030','origin','text-align','right',0,''),(609973,191954,'75030','origin','margin-bottom','10',0,''),(609974,191955,'75031','origin','block_type','1',0,''),(609975,191955,'75031','origin','padding-top','20',0,''),(609976,191955,'75031','origin','padding-bottom','20',0,''),(609977,191955,'75031','origin','background-color','$content-bg-2',0,''),(609978,191957,'75033','origin','block_type','4',0,''),(609979,191958,'75034','origin','padding-bottom','20',0,''),(609980,191958,'75034','origin','background-color','$content-bg-1',0,''),(609981,191959,'75035','origin','style_class','order-summary',0,''),(609982,191959,'75035','origin','padding-left','30',0,''),(609983,191959,'75035','origin','block_type','1',0,''),(609984,191960,'75036','origin','block_type','1',0,''),(609985,191960,'75036','origin','padding-left','20',0,''),(609986,191960,'75036','origin','padding-right','20',0,''),(609987,191960,'75036','origin','padding-bottom','20',0,''),(609988,191960,'75036','origin','padding-top','20',0,''),(609989,191961,'75037','origin','margin-bottom','40',0,''),(609990,191962,'75038','origin','block_type','1',0,''),(609991,191962,'75038','origin','style_class','account-samples',0,''),(609992,191963,'75039','origin','block_type','6',0,''),(609993,191963,'75039','origin','schema','6-3',0,'8356'),(609994,191964,'75040','origin','aria_name','account-menu',0,''),(609995,191965,'73374','origin','block_type','1',0,''),(609996,191965,'73374','origin','padding-top','70',0,''),(609997,191965,'73374','origin','padding-right','30',0,''),(609998,191965,'73374','origin','padding-bottom','30',0,''),(609999,191965,'73374','origin','padding-top','0',0,'8356'),(610000,191965,'73374','origin','padding-left','0',0,'8356'),(610001,191965,'73374','origin','padding-right','0',0,'8356'),(610002,191965,'73374','origin','padding-bottom','0',0,'8356'),(610045,191984,'75041','origin','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(610046,191985,'75042','origin','show_pagenation','1',0,''),(610047,191985,'75042','origin','link','Sample Info',0,''),(610048,191985,'75042','origin','margin-bottom','20',0,''),(610049,191986,'75043','origin','block_type','1',0,''),(610050,191986,'75043','origin','style_class','account-sample-info',0,''),(610051,191987,'75044','origin','block_type','6',0,''),(610052,191988,'75045','origin','aria_name','account-menu',0,''),(610053,191989,'73374','origin','block_type','1',0,''),(610054,191989,'73374','origin','padding-top','70',0,''),(610055,191989,'73374','origin','padding-right','30',0,''),(610056,191989,'73374','origin','padding-bottom','30',0,''),(610057,191989,'73374','origin','padding-top','0',0,'8356'),(610058,191989,'73374','origin','padding-left','0',0,'8356'),(610059,191989,'73374','origin','padding-right','0',0,'8356'),(610060,191989,'73374','origin','padding-bottom','0',0,'8356'),(610103,192008,'75046','origin','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(610104,192009,'75047','origin','block_type','2',0,''),(610105,192009,'75047','origin','padding-top','20',0,''),(610106,192009,'75047','origin','margin-bottom','20',0,''),(610107,192010,'75048','origin','like_button','1',0,''),(610108,192010,'75048','origin','text','IMAGE_BUTTON_BACK',0,''),(610109,192010,'75048','origin','link','Samples',0,''),(610110,192012,'75050','origin','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(610111,192015,'75053','origin','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(610112,192016,'75054','origin','block_type','3',0,''),(610113,192017,'75055','origin','block_type','1',0,''),(610114,192017,'75055','origin','padding-right','20',0,''),(610115,192017,'75055','origin','padding-bottom','20',0,''),(610116,192018,'75056','origin','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(610117,192019,'75057','origin','orders_data','telephone',0,''),(610118,192020,'75058','origin','block_type','1',0,''),(610119,192020,'75058','origin','padding-right','20',0,''),(610120,192020,'75058','origin','padding-bottom','20',0,''),(610121,192021,'75059','origin','orders_data','name',0,''),(610122,192022,'75060','origin','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(610123,192023,'75061','origin','block_type','1',0,''),(610124,192023,'75061','origin','padding-right','20',0,''),(610125,192024,'75062','origin','orders_data','shipping_method',0,''),(610126,192025,'75063','origin','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(610127,192026,'75064','origin','block_type','1',0,''),(610128,192026,'75064','origin','padding-right','20',0,''),(610129,192026,'75064','origin','padding-bottom','20',0,''),(610130,192027,'75065','origin','orders_data','delivery_address',0,''),(610131,192028,'75066','origin','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(610132,192029,'75067','origin','block_type','1',0,''),(610133,192030,'75068','origin','orders_data','payment_method',0,''),(610134,192031,'75069','origin','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(610135,192032,'75070','origin','block_type','1',0,''),(610136,192032,'75070','origin','padding-bottom','20',0,''),(610137,192033,'75071','origin','orders_data','billing_address',0,''),(610138,192034,'75072','origin','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(610139,192035,'75073','origin','block_type','1',0,''),(610140,192036,'75074','origin','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(610141,192037,'75075','origin','block_type','6',0,''),(610142,192038,'75076','origin','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(610143,192039,'75077','origin','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(610144,192040,'75078','origin','text','<div class=\"heading-4\">Categories</div>',0,''),(610145,192043,'75081','origin','class','menu-simple',0,''),(610146,192045,'75083','origin','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(610147,192046,'75084','origin','block_type','1',0,''),(610148,192047,'75085','origin','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(610149,192047,'75085','origin','style_class','middle-form',0,''),(610150,192048,'75086','origin','style_class','middle-form',0,''),(610151,192049,'75087','origin','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(610152,192050,'75088','origin','style_class','middle-form',0,''),(610153,192050,'75088','origin','margin-bottom','30',0,''),(610154,192051,'75089','origin','block_type','1',0,''),(610155,192052,'75090','origin','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(610156,192052,'75090','origin','padding-top','100',0,''),(610157,192052,'75090','origin','margin-bottom','100',0,''),(610158,192052,'75090','origin','text-align','center',0,''),(610159,192052,'75090','origin','font-size','20',0,''),(610160,192053,'94795','origin','block_type','1',0,''),(610161,192054,'94796','origin','block_type','6',0,''),(610162,192054,'94796','origin','schema','6-3',0,'8356'),(610163,192055,'94797','origin','aria_name','account-menu',0,''),(610164,192056,'73374','origin','block_type','1',0,''),(610165,192056,'73374','origin','padding-top','70',0,''),(610166,192056,'73374','origin','padding-right','30',0,''),(610167,192056,'73374','origin','padding-bottom','30',0,''),(610168,192056,'73374','origin','padding-top','0',0,'8356'),(610169,192056,'73374','origin','padding-left','0',0,'8356'),(610170,192056,'73374','origin','padding-right','0',0,'8356'),(610171,192056,'73374','origin','padding-bottom','0',0,'8356'),(610214,192075,'94798','origin','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(610215,192076,'94799','origin','text','##SUBSCRIPTION_TEXT##',0,''),(610216,192078,'1694099590.22143','origin','block_type','1',0,''),(610217,192078,'1694099590.22143','origin','background-color','$content-bg-2',0,''),(610218,192078,'1694099590.22143','origin','padding-bottom','30',0,''),(610219,192078,'1694099590.22143','origin','style_class','success-page',0,''),(610220,192078,'1694099590.22143','origin','color','$content-color-2',0,''),(610221,192079,'1694099590.340695','origin','block_type','12',0,''),(610222,192079,'1694099590.340695','origin','schema','4-2',0,'8356'),(610223,192080,'1694099590.343733','origin','block_type','1',0,''),(610224,192080,'1694099590.343733','origin','padding-right','40',0,''),(610225,192080,'1694099590.343733','origin','padding-right','0',0,'8356'),(610226,192081,'1694099590.345212','origin','block_type','2',0,''),(610227,192081,'1694099590.345212','origin','margin-bottom','20',0,''),(610228,192081,'1694099590.345212','origin','schema','2-2',0,'8349'),(610229,192081,'1694099590.345212','origin','background-color','$content-bg-1',0,''),(610230,192081,'1694099590.345212','origin','color','$content-color-1',0,''),(610231,192082,'1694099590.34749','origin','block_type','1',0,''),(610232,192082,'1694099590.34749','origin','border-right-width','20',0,''),(610233,192082,'1694099590.34749','origin','border-right-color','$content-bg-2',0,''),(610234,192082,'1694099590.34749','origin','margin-right','-10',0,''),(610235,192082,'1694099590.34749','origin','padding-right','30',0,''),(610236,192082,'1694099590.34749','origin','padding-top','20',0,''),(610237,192082,'1694099590.34749','origin','padding-left','30',0,''),(610238,192082,'1694099590.34749','origin','padding-bottom','20',0,''),(610239,192082,'1694099590.34749','origin','border-right-width','0',0,'8356'),(610240,192082,'1694099590.34749','origin','margin-right','0',0,'8356'),(610241,192082,'1694099590.34749','origin','margin-bottom','20',0,'8356'),(610242,192082,'1694099590.34749','origin','padding-left','20',0,'8356'),(610243,192082,'1694099590.34749','origin','padding-right','20',0,'8356'),(610244,192084,'1694099590.351567','origin','margin-bottom','20',0,''),(610245,192085,'1694099590.35337','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(610246,192085,'1694099590.35337','origin','padding-top','20',0,''),(610247,192086,'1694099590.360420','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(610248,192086,'1694099590.360420','origin','clear','none',0,''),(610249,192087,'1694099590.362714','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(610250,192089,'1694099590.365625','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(610251,192089,'1694099590.365625','origin','clear','none',0,''),(610252,192090,'1694099590.367789','origin','block_type','1',0,''),(610253,192090,'1694099590.367789','origin','padding-left','30',0,''),(610254,192090,'1694099590.367789','origin','border-left-width','20',0,''),(610255,192090,'1694099590.367789','origin','border-left-color','$content-bg-2',0,''),(610256,192090,'1694099590.367789','origin','margin-left','-10',0,''),(610257,192090,'1694099590.367789','origin','padding-right','30',0,''),(610258,192090,'1694099590.367789','origin','padding-top','20',0,''),(610259,192090,'1694099590.367789','origin','padding-bottom','20',0,''),(610260,192090,'1694099590.367789','origin','border-left-width','0',0,'8356'),(610261,192092,'1694099590.370690','origin','margin-bottom','20',0,''),(610262,192093,'1694099590.371953','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(610263,192093,'1694099590.371953','origin','clear','none',0,''),(610264,192094,'1694099590.373633','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(610265,192095,'1694099590.37590','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(610266,192095,'1694099590.37590','origin','clear','none',0,''),(610267,192096,'1694099590.376747','origin','text','<div class=\"page-success\">\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>',0,''),(610268,192096,'1694099590.376747','origin','background-color','$content-bg-1',0,''),(610269,192096,'1694099590.376747','origin','margin-bottom','30',0,''),(610270,192096,'1694099590.376747','origin','padding-top','30',0,''),(610271,192096,'1694099590.376747','origin','padding-bottom','30',0,''),(610272,192096,'1694099590.376747','origin','padding-left','30',0,''),(610273,192096,'1694099590.376747','origin','padding-right','30',0,''),(610274,192096,'1694099590.376747','origin','color','$content-color-1',0,''),(610275,192097,'1694099590.38020','origin','block_type','1',0,''),(610276,192097,'1694099590.38020','origin','style_class','order-summary2 hiding-box',0,''),(610277,192098,'1694099590.381373','origin','text-align','center',0,''),(610278,192098,'1694099590.381373','origin','margin-bottom','20',0,''),(610279,192099,'1694099590.382864','origin','text-align','center',0,''),(610280,192102,'1694099590.386683','origin','block_type','12',0,''),(610281,192103,'1694099590.387673','origin','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n</div>\n',0,''),(610282,192103,'1694099590.387673','origin','margin-bottom','20',0,''),(610283,192104,'1694099590.389337','origin','text-align','center',0,''),(610284,192104,'1694099590.389337','origin','padding-top','40',0,''),(610285,192105,'75097','origin','block_type','1',0,''),(610286,192106,'75098','origin','block_type','1',0,''),(610287,192106,'75098','origin','font-weight','normal',0,''),(610288,192107,'75099','origin','block_type','1',0,''),(610289,192107,'75099','origin','text-align','center',0,''),(610290,192107,'75099','origin','padding-top','30',0,''),(610291,192107,'75099','origin','margin-bottom','200',0,''),(610292,192108,'75100','origin','display','inline-block',0,''),(610293,192108,'75100','origin','clear','none',0,''),(610294,192108,'75100','origin','margin-left','20',0,''),(610295,192109,'75101','origin','display','inline-block',0,''),(610296,192110,'75102','origin','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(610297,192111,'75107','origin','width','680',0,''),(610298,192111,'75107','origin','font-weight','normal',0,''),(610299,192111,'75107','origin','font-size','12',0,''),(610300,192111,'75107','origin','padding-top','20',0,''),(610301,192111,'75107','origin','padding-bottom','20',0,''),(610302,192111,'75107','origin','color','$content-color-1',0,''),(610303,192112,'75108','origin','block_type','5',0,''),(610304,192112,'75108','origin','font-weight','normal',0,''),(610305,192112,'75108','origin','border-bottom-width','1',0,''),(610306,192112,'75108','origin','border-bottom-color','$content-border-1',0,''),(610307,192112,'75108','origin','border-top-width','1',0,''),(610308,192112,'75108','origin','border-top-color','$content-border-1',0,''),(610309,192112,'75108','origin','border-left-color','$content-border-1',0,''),(610310,192112,'75108','origin','border-left-width','1',0,''),(610311,192113,'75109','origin','block_type','1',0,''),(610312,192113,'75109','origin','font-weight','normal',0,''),(610313,192113,'75109','origin','padding-top','10',0,''),(610314,192113,'75109','origin','padding-left','10',0,''),(610315,192113,'75109','origin','padding-right','10',0,''),(610316,192114,'75110','origin','font-weight','400',0,''),(610317,192114,'75110','origin','line-height','120',0,''),(610318,192114,'75110','origin','line_height_measure','%',0,''),(610319,192114,'75110','origin','font-size','12',0,''),(610320,192115,'75111','origin','text','<p>SHIPPING ADDRESS:</p>',1,''),(610321,192115,'75111','origin','font-size','14',0,''),(610322,192115,'75111','origin','font-weight','bold',0,''),(610323,192115,'75111','origin','padding-bottom','10',0,''),(610324,192115,'75111','origin','text','<p>SHIPPING ADDRESS:</p>',0,''),(610325,192116,'75112','origin','block_type','1',0,''),(610326,192116,'75112','origin','background-color','$content-bg-2',0,''),(610327,192116,'75112','origin','padding-top','20',0,''),(610328,192116,'75112','origin','padding-left','10',0,''),(610329,192116,'75112','origin','padding-right','10',0,''),(610330,192116,'75112','origin','padding-bottom','20',0,''),(610331,192116,'75112','origin','font-size','14',0,''),(610332,192117,'75113','origin','font-weight','normal',0,''),(610333,192117,'75113','origin','text-align','right',0,''),(610334,192117,'75113','origin','font-size','14',0,''),(610335,192117,'75113','origin','box_align','3',0,''),(610336,192118,'75114','origin','block_type','3',0,''),(610337,192118,'75114','origin','font-weight','normal',0,''),(610338,192118,'75114','origin','padding-top','20',0,''),(610339,192119,'75115','origin','text','<p>If undelivered please return to:</p>',1,''),(610340,192119,'75115','origin','font-size','12',0,''),(610341,192119,'75115','origin','font-weight','bold',0,''),(610342,192119,'75115','origin','text','<p>If undelivered please return to:</p>',0,''),(610343,192120,'75116','origin','font-size','12',0,''),(610344,192121,'75117','origin','font-weight','400',0,''),(610345,192121,'75117','origin','text-align','center',0,''),(610346,192121,'75117','origin','padding-top','0',0,''),(610347,192121,'75117','origin','padding-left','20',0,''),(610348,192121,'75117','origin','padding-right','20',0,''),(610349,192122,'75118','origin','text','<p>Thank you for your order</p>',1,''),(610350,192122,'75118','origin','color','$color-8',0,''),(610351,192122,'75118','origin','font-size','13',0,''),(610352,192122,'75118','origin','font-weight','bold',0,''),(610353,192122,'75118','origin','padding-top','5',0,''),(610354,192122,'75118','origin','text-align','center',0,''),(610355,192122,'75118','origin','text','<p>Thank you for your order</p>',0,''),(610356,192123,'75119','origin','text','<p>If something has gone wrong please contact us at:</p>',1,''),(610357,192123,'75119','origin','font-size','12',0,''),(610358,192123,'75119','origin','font-weight','bold',0,''),(610359,192123,'75119','origin','text-align','right',0,''),(610360,192123,'75119','origin','text','<p>If something has gone wrong please contact us at:</p>',0,''),(610361,192124,'75120','origin','block_type','6',0,''),(610362,192124,'75120','origin','font-weight','normal',0,''),(610363,192124,'75120','origin','font-size','16',0,''),(610364,192125,'75121','origin','text','<p>Email:</p>',1,''),(610365,192125,'75121','origin','font-weight','normal',0,''),(610366,192125,'75121','origin','text-align','right',0,''),(610367,192125,'75121','origin','font-size','12',0,''),(610368,192125,'75121','origin','text','<p>Email:</p>',0,''),(610369,192126,'75122','origin','font-weight','normal',0,''),(610370,192126,'75122','origin','text-align','right',0,''),(610371,192126,'75122','origin','font-size','12',0,''),(610372,192127,'75123','origin','block_type','6',0,''),(610373,192127,'75123','origin','font-weight','normal',0,''),(610374,192127,'75123','origin','font-size','16',0,''),(610375,192128,'75124','origin','text','<p>Phone:</p>',1,''),(610376,192128,'75124','origin','font-weight','normal',0,''),(610377,192128,'75124','origin','text-align','right',0,''),(610378,192128,'75124','origin','font-size','12',0,''),(610379,192128,'75124','origin','text','<p>Phone:</p>',0,''),(610380,192129,'75125','origin','font-weight','normal',0,''),(610381,192129,'75125','origin','text-align','right',0,''),(610382,192129,'75125','origin','font-size','12',0,''),(610383,192130,'75126','origin','font-weight','400',0,''),(610384,192130,'75126','origin','padding-top','20',0,''),(610385,192130,'75126','origin','padding-bottom','0',0,''),(610386,192130,'75126','origin','font-size','12',0,''),(610387,192131,'75127','origin','block_type','2',0,''),(610388,192131,'75127','origin','font-weight','normal',0,''),(610389,192131,'75127','origin','padding-bottom','20',0,''),(610390,192132,'75128','origin','block_type','11',0,''),(610391,192132,'75128','origin','font-weight','normal',0,''),(610392,192133,'75129','origin','text','<p>Email:</p>',1,''),(610393,192133,'75129','origin','font-weight','normal',0,''),(610394,192133,'75129','origin','text-align','right',0,''),(610395,192133,'75129','origin','text','<p>Email:</p>',0,''),(610396,192134,'75130','origin','font-weight','normal',0,''),(610397,192134,'75130','origin','text-align','right',0,''),(610398,192135,'75131','origin','block_type','11',0,''),(610399,192135,'75131','origin','font-weight','normal',0,''),(610400,192136,'75132','origin','text','<p>Web:</p>',1,''),(610401,192136,'75132','origin','font-weight','normal',0,''),(610402,192136,'75132','origin','text-align','right',0,''),(610403,192136,'75132','origin','text','<p>Web:</p>',0,''),(610404,192137,'75133','origin','font-weight','normal',0,''),(610405,192137,'75133','origin','text-align','right',0,''),(610406,192138,'75134','origin','block_type','1',0,''),(610407,192139,'75135','origin','font-weight','normal',0,''),(610408,192139,'75135','origin','text-align','right',0,''),(610409,192139,'75135','origin','padding-bottom','10',0,''),(610410,192139,'75135','origin','address_spacer',',',0,''),(610411,192139,'75135','origin','font-size','12',0,''),(610412,192140,'75136','origin','block_type','11',0,''),(610413,192140,'75136','origin','font-weight','normal',0,''),(610414,192141,'75137','origin','text','<p>Phone:</p>',1,''),(610415,192141,'75137','origin','font-weight','normal',0,''),(610416,192141,'75137','origin','text-align','right',0,''),(610417,192141,'75137','origin','text','<p>Phone:</p>',0,''),(610418,192142,'75138','origin','font-weight','normal',0,''),(610419,192142,'75138','origin','text-align','right',0,''),(610420,192143,'75139','origin','block_type','4',0,''),(610421,192143,'75139','origin','font-weight','normal',0,''),(610422,192143,'75139','origin','border-top-width','1',0,''),(610423,192143,'75139','origin','border-top-color','$content-border-1',0,''),(610424,192143,'75139','origin','border-left-width','1',0,''),(610425,192143,'75139','origin','border-left-color','$content-border-1',0,''),(610426,192143,'75139','origin','border-right-width','1',0,''),(610427,192143,'75139','origin','border-right-color','$content-border-1',0,''),(610428,192143,'75139','origin','border-bottom-width','1',0,''),(610429,192143,'75139','origin','border-bottom-color','$content-border-1',0,''),(610430,192144,'75140','origin','block_type','2',0,''),(610431,192144,'75140','origin','font-weight','normal',0,''),(610432,192144,'75140','origin','border-top-width','1',0,''),(610433,192144,'75140','origin','border-top-color','$content-border-1',0,''),(610434,192144,'75140','origin','border-right-width','1',0,''),(610435,192144,'75140','origin','border-right-color','$content-border-1',0,''),(610436,192145,'75141','origin','block_type','1',0,''),(610437,192145,'75141','origin','font-weight','normal',0,''),(610438,192145,'75141','origin','padding-top','10',0,''),(610439,192145,'75141','origin','padding-left','10',0,''),(610440,192145,'75141','origin','padding-right','10',0,''),(610441,192145,'75141','origin','padding-bottom','10',0,''),(610442,192145,'75141','origin','border-right-width','1',0,''),(610443,192145,'75141','origin','border-right-color','$content-border-1',0,''),(610444,192146,'75142','origin','text','<p>Shipping via</p>',1,''),(610445,192146,'75142','origin','font-weight','bold',0,''),(610446,192146,'75142','origin','font-size','14',0,''),(610447,192146,'75142','origin','text','<p>Shipping via</p>',0,''),(610448,192148,'75144','origin','block_type','1',0,''),(610449,192148,'75144','origin','font-weight','normal',0,''),(610450,192148,'75144','origin','padding-top','10',0,''),(610451,192148,'75144','origin','padding-left','10',0,''),(610452,192148,'75144','origin','padding-right','10',0,''),(610453,192148,'75144','origin','padding-bottom','10',0,''),(610454,192149,'75145','origin','text','<p>Shipping service</p>',1,''),(610455,192149,'75145','origin','font-weight','bold',0,''),(610456,192149,'75145','origin','font-size','14',0,''),(610457,192149,'75145','origin','text','<p>Shipping service</p>',0,''),(610458,192151,'75147','origin','block_type','2',0,''),(610459,192151,'75147','origin','font-weight','normal',0,''),(610460,192151,'75147','origin','border-right-width','1',0,''),(610461,192151,'75147','origin','border-right-color','$content-border-1',0,''),(610462,192152,'75148','origin','block_type','1',0,''),(610463,192152,'75148','origin','font-weight','400',0,''),(610464,192152,'75148','origin','background-color','$content-bg-2',0,''),(610465,192152,'75148','origin','padding-top','10',0,''),(610466,192152,'75148','origin','padding-left','10',0,''),(610467,192152,'75148','origin','padding-right','10',0,''),(610468,192152,'75148','origin','padding-bottom','30',0,''),(610469,192153,'75149','origin','font-size','12',0,''),(610470,192154,'75150','origin','text','<p>INVOICE ADDRESS:</p>',1,''),(610471,192154,'75150','origin','font-size','14',0,''),(610472,192154,'75150','origin','font-weight','bold',0,''),(610473,192154,'75150','origin','text','<p>INVOICE ADDRESS:</p>',0,''),(610474,192155,'75151','origin','block_type','1',0,''),(610475,192155,'75151','origin','font-weight','normal',0,''),(610476,192155,'75151','origin','padding-top','10',0,''),(610477,192155,'75151','origin','padding-left','10',0,''),(610478,192155,'75151','origin','padding-right','10',0,''),(610479,192155,'75151','origin','padding-bottom','10',0,''),(610480,192156,'75152','origin','font-weight','normal',0,''),(610481,192157,'75153','origin','text','<p>PHONE NUMBER:</p>',1,''),(610482,192157,'75153','origin','font-size','14',0,''),(610483,192157,'75153','origin','font-weight','bold',0,''),(610484,192157,'75153','origin','padding-top','10',0,''),(610485,192157,'75153','origin','text','<p>PHONE NUMBER:</p>',0,''),(610486,192159,'75155','origin','font-weight','normal',0,''),(610487,192160,'75156','origin','text','<p>E-MAIL ADDRESS:</p>',1,''),(610488,192160,'75156','origin','font-weight','bold',0,''),(610489,192160,'75156','origin','font-size','14',0,''),(610490,192160,'75156','origin','padding-top','10',0,''),(610491,192160,'75156','origin','text','<p>E-MAIL ADDRESS:</p>',0,''),(610492,192161,'75157','origin','text','<p>CUSTOMER:</p>',1,''),(610493,192161,'75157','origin','font-size','13',0,''),(610494,192161,'75157','origin','font-weight','bold',0,''),(610495,192161,'75157','origin','text','<p>CUSTOMER:</p>',0,''),(610496,192162,'75158','origin','font-weight','normal',0,''),(610497,192162,'75158','origin','text-align','center',0,''),(610498,192162,'75158','origin','padding-bottom','10',0,''),(610499,192163,'75159','origin','text','<p>Payment date:</p>',1,''),(610500,192163,'75159','origin','font-weight','bold',0,''),(610501,192163,'75159','origin','text-align','center',0,''),(610502,192163,'75159','origin','font-size','12',0,''),(610503,192163,'75159','origin','text','<p>Payment date:</p>',0,''),(610504,192164,'75160','origin','text','<p>Payment Method:</p>',1,''),(610505,192164,'75160','origin','font-weight','bold',0,''),(610506,192164,'75160','origin','text-align','center',0,''),(610507,192164,'75160','origin','text','<p>Payment Method:</p>',0,''),(610508,192165,'75161','origin','font-size','14',0,''),(610509,192165,'75161','origin','font-weight','bold',0,''),(610510,192165,'75161','origin','text-align','center',0,''),(610511,192165,'75161','origin','padding-bottom','10',0,''),(610512,192165,'75161','origin','padding-top','10',0,''),(610513,192166,'75162','origin','font-weight','normal',0,''),(610514,192166,'75162','origin','text-align','center',0,''),(610515,192166,'75162','origin','padding-bottom','20',0,''),(610516,192167,'75163','origin','font-weight','normal',0,''),(610517,192167,'75163','origin','text-align','center',0,''),(610518,192168,'75194','origin','block_type','1',0,''),(610519,192169,'75195','origin','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(610520,192171,'75418','origin','block_type','1',0,''),(610521,192172,'75419','origin','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(610522,192172,'75419','origin','padding-top','100',0,''),(610523,192172,'75419','origin','margin-bottom','100',0,''),(610524,192172,'75419','origin','text-align','center',0,''),(610525,192172,'75419','origin','font-size','20',0,''),(610526,192173,'75420','origin','block_type','1',0,''),(610527,192173,'75420','origin','background-color','$content-bg-2',0,''),(610528,192173,'75420','origin','padding-bottom','30',0,''),(610529,192174,'75421','origin','block_type','4',0,''),(610530,192174,'75421','origin','schema','4-2',0,'8356'),(610531,192175,'75422','origin','block_type','1',0,''),(610532,192175,'75422','origin','padding-right','40',0,''),(610533,192175,'75422','origin','padding-right','0',0,'8356'),(610534,192176,'75423','origin','block_type','2',0,''),(610535,192176,'75423','origin','margin-bottom','20',0,''),(610536,192176,'75423','origin','schema','2-2',0,'8349'),(610537,192176,'75423','origin','background-color','$content-bg-1',0,''),(610538,192177,'75424','origin','block_type','1',0,''),(610539,192177,'75424','origin','border-right-width','20',0,''),(610540,192177,'75424','origin','border-right-color','$content-border-1',0,''),(610541,192177,'75424','origin','margin-right','-10',0,''),(610542,192177,'75424','origin','padding-right','30',0,''),(610543,192177,'75424','origin','padding-top','20',0,''),(610544,192177,'75424','origin','padding-left','30',0,''),(610545,192177,'75424','origin','padding-bottom','20',0,''),(610546,192177,'75424','origin','border-right-width','0',0,'8356'),(610547,192177,'75424','origin','margin-right','0',0,'8356'),(610548,192177,'75424','origin','margin-bottom','20',0,'8356'),(610549,192177,'75424','origin','padding-left','20',0,'8356'),(610550,192177,'75424','origin','padding-right','20',0,'8356'),(610551,192179,'75426','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(610552,192179,'75426','origin','clear','none',0,''),(610553,192180,'75427','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(610554,192180,'75427','origin','clear','none',0,''),(610555,192181,'75428','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(610556,192183,'75430','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(610557,192183,'75430','origin','padding-top','20',0,''),(610558,192186,'75433','origin','margin-bottom','20',0,''),(610559,192187,'75434','origin','block_type','1',0,''),(610560,192187,'75434','origin','padding-left','30',0,''),(610561,192187,'75434','origin','border-left-width','20',0,''),(610562,192187,'75434','origin','border-left-color','$content-border-1',0,''),(610563,192187,'75434','origin','margin-left','-10',0,''),(610564,192187,'75434','origin','padding-right','30',0,''),(610565,192187,'75434','origin','padding-top','20',0,''),(610566,192187,'75434','origin','padding-bottom','20',0,''),(610567,192187,'75434','origin','border-left-width','0',0,'8356'),(610568,192188,'75435','origin','margin-bottom','20',0,''),(610569,192190,'75437','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(610570,192191,'75438','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(610571,192191,'75438','origin','clear','none',0,''),(610572,192192,'75439','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(610573,192192,'75439','origin','clear','none',0,''),(610574,192193,'75440','origin','block_type','1',0,''),(610575,192193,'75440','origin','padding-right','30',0,''),(610576,192193,'75440','origin','background-color','$content-bg-1',0,''),(610577,192193,'75440','origin','padding-top','20',0,''),(610578,192193,'75440','origin','padding-left','30',0,''),(610579,192193,'75440','origin','padding-bottom','20',0,''),(610580,192193,'75440','origin','padding-left','20',0,'8356'),(610581,192193,'75440','origin','padding-right','20',0,'8356'),(610582,192195,'75442','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(610583,192196,'75443','origin','block_type','1',0,''),(610584,192196,'75443','origin','padding-top','20',0,''),(610585,192196,'75443','origin','padding-left','20',0,''),(610586,192196,'75443','origin','padding-right','20',0,''),(610587,192196,'75443','origin','padding-bottom','20',0,''),(610588,192196,'75443','origin','background-color','$content-bg-1',0,''),(610589,192196,'75443','origin','style_class','order-summary',0,''),(610590,192197,'75444','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(610591,192201,'75448','origin','block_type','1',0,''),(610592,192201,'75448','origin','background-color','$content-bg-2',0,''),(610593,192201,'75448','origin','padding-bottom','30',0,''),(610594,192202,'75449','origin','block_type','4',0,''),(610595,192202,'75449','origin','schema','4-2',0,'8356'),(610596,192203,'75450','origin','block_type','1',0,''),(610597,192203,'75450','origin','padding-right','40',0,''),(610598,192203,'75450','origin','padding-right','0',0,'8356'),(610599,192204,'75451','origin','block_type','2',0,''),(610600,192204,'75451','origin','margin-bottom','20',0,''),(610601,192204,'75451','origin','schema','2-2',0,'8349'),(610602,192204,'75451','origin','background-color','$content-bg-1',0,''),(610603,192205,'75452','origin','block_type','1',0,''),(610604,192205,'75452','origin','border-right-width','20',0,''),(610605,192205,'75452','origin','border-right-color','$content-border-1',0,''),(610606,192205,'75452','origin','margin-right','-10',0,''),(610607,192205,'75452','origin','padding-right','30',0,''),(610608,192205,'75452','origin','padding-top','20',0,''),(610609,192205,'75452','origin','padding-left','30',0,''),(610610,192205,'75452','origin','padding-bottom','20',0,''),(610611,192205,'75452','origin','border-right-width','0',0,'8356'),(610612,192205,'75452','origin','margin-right','0',0,'8356'),(610613,192205,'75452','origin','margin-bottom','20',0,'8356'),(610614,192205,'75452','origin','padding-left','20',0,'8356'),(610615,192205,'75452','origin','padding-right','20',0,'8356'),(610616,192206,'75453','origin','margin-bottom','20',0,''),(610617,192209,'75456','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(610618,192209,'75456','origin','padding-top','20',0,''),(610619,192211,'75458','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(610620,192211,'75458','origin','clear','none',0,''),(610621,192213,'75460','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(610622,192214,'75461','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(610623,192214,'75461','origin','clear','none',0,''),(610624,192215,'75462','origin','block_type','1',0,''),(610625,192215,'75462','origin','padding-left','30',0,''),(610626,192215,'75462','origin','border-left-width','20',0,''),(610627,192215,'75462','origin','border-left-color','$content-border-1',0,''),(610628,192215,'75462','origin','margin-left','-10',0,''),(610629,192215,'75462','origin','padding-right','30',0,''),(610630,192215,'75462','origin','padding-top','20',0,''),(610631,192215,'75462','origin','padding-bottom','20',0,''),(610632,192215,'75462','origin','border-left-width','0',0,'8356'),(610633,192216,'75463','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(610634,192217,'75464','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(610635,192217,'75464','origin','clear','none',0,''),(610636,192218,'75465','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(610637,192218,'75465','origin','clear','none',0,''),(610638,192219,'75466','origin','margin-bottom','20',0,''),(610639,192221,'75468','origin','block_type','1',0,''),(610640,192221,'75468','origin','padding-right','30',0,''),(610641,192221,'75468','origin','background-color','$content-bg-1',0,''),(610642,192221,'75468','origin','padding-top','20',0,''),(610643,192221,'75468','origin','padding-left','30',0,''),(610644,192221,'75468','origin','padding-bottom','20',0,''),(610645,192221,'75468','origin','padding-left','20',0,'8356'),(610646,192221,'75468','origin','padding-right','20',0,'8356'),(610647,192222,'75469','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(610648,192224,'75471','origin','block_type','1',0,''),(610649,192224,'75471','origin','padding-top','20',0,''),(610650,192224,'75471','origin','padding-left','20',0,''),(610651,192224,'75471','origin','padding-right','20',0,''),(610652,192224,'75471','origin','padding-bottom','20',0,''),(610653,192224,'75471','origin','background-color','$content-bg-1',0,''),(610654,192224,'75471','origin','style_class','order-summary',0,''),(610655,192227,'75474','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(610656,192229,'75540','origin','block_type','1',0,''),(610657,192230,'75541','origin','block_type','6',0,''),(610658,192230,'75541','origin','schema','6-3',0,'8356'),(610659,192231,'75542','origin','aria_name','account-menu',0,''),(610660,192232,'73374','origin','block_type','1',0,''),(610661,192232,'73374','origin','padding-top','70',0,''),(610662,192232,'73374','origin','padding-right','30',0,''),(610663,192232,'73374','origin','padding-bottom','30',0,''),(610664,192232,'73374','origin','padding-top','0',0,'8356'),(610665,192232,'73374','origin','padding-left','0',0,'8356'),(610666,192232,'73374','origin','padding-right','0',0,'8356'),(610667,192232,'73374','origin','padding-bottom','0',0,'8356'),(610668,192233,'73375','origin','block_type','1',0,''),(610669,192233,'73375','origin','style_class','account-menu',0,''),(610670,192234,'73376','origin','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(610671,192234,'73376','origin','style_class','heading-settings',0,''),(610672,192235,'73377','origin','link','logoff',0,''),(610673,192236,'73378','origin','link','delete',0,''),(610674,192236,'73378','origin','text','DELETE_ACCOUNT',0,''),(610675,192237,'73379','origin','text','TEXT_DASHBOARD',0,''),(610676,192237,'73379','origin','font-family','$font-1',0,''),(610677,192237,'73379','origin','font-size','18',0,''),(610678,192237,'73379','origin','text-transform','uppercase',0,''),(610679,192238,'73380','origin','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(610680,192238,'73380','origin','style_class','heading-saved-lists',0,''),(610681,192239,'73381','origin','link','Personal Catalog',0,''),(610682,192239,'73381','origin','text','TEXT_PERSONAL_CATALOG',0,''),(610683,192239,'73381','origin','hide_link','personal_catalog',0,''),(610684,192240,'73382','origin','link','Order History',0,''),(610685,192240,'73382','origin','text','HEADING_ORDER_HISTORY',0,''),(610686,192240,'73382','origin','active_link','Order History Info,Order pay',0,''),(610687,192241,'73383','origin','link','Address Book',0,''),(610688,192241,'73383','origin','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(610689,192242,'73384','origin','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(610690,192242,'73384','origin','style_class','heading-ordered-items',0,''),(610691,192243,'73385','origin','link','Wishlist',0,''),(610692,192243,'73385','origin','hide_link','wishlist',0,''),(610693,192243,'73385','origin','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(610694,192244,'73386','origin','link','My password',0,''),(610695,192244,'73386','origin','text','TEXT_MY_PASSWORD',0,''),(610696,192245,'73387','origin','link','Samples',0,''),(610697,192245,'73387','origin','text','TEXT_HEADING_SAMPLE_CART',0,''),(610698,192245,'73387','origin','hide_link','samples',0,''),(610699,192246,'73388','origin','link','Review',0,''),(610700,192246,'73388','origin','text','REVIEWS',0,''),(610701,192247,'73389','origin','link','Quotations',0,''),(610702,192247,'73389','origin','hide_link','quotations',0,''),(610703,192247,'73389','origin','text','TEXT_HEADING_QUOTE_CART',0,''),(610704,192248,'73390','origin','link','Account edit',0,''),(610705,192248,'73390','origin','text','ACCOUNT_EDIT',0,''),(610706,192249,'73391','origin','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(610707,192249,'73391','origin','style_class','heading-settings',0,''),(610708,192250,'73392','origin','link','trade_form',0,''),(610709,192250,'73392','origin','text','TRADE_FORM',0,''),(610710,192251,'75543','origin','margin-bottom','20',0,''),(610711,192252,'75544','origin','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(610712,192253,'75545','origin','block_type','1',0,''),(610713,192253,'75545','origin','padding-top','20',0,''),(610714,192253,'75545','origin','padding-bottom','20',0,''),(610715,192255,'75547','origin','padding-top','20',0,''),(610716,192255,'75547','origin','padding-bottom','20',0,''),(610717,192256,'73349','new_theme','text','##TEXT_PAGE_NOT_FOUND##',0,''),(610718,192256,'73349','new_theme','text-align','center',0,''),(610719,192256,'73349','new_theme','padding-top','100',0,''),(610720,192256,'73349','new_theme','padding-bottom','100',0,''),(610721,192257,'73350','new_theme','block_type','1',0,''),(610722,192257,'73350','new_theme','style_class','account-index',0,''),(610723,192258,'73351','new_theme','block_type','6',0,''),(610724,192258,'73351','new_theme','schema','6-3',0,'8451'),(610725,192259,'73352','new_theme','aria_name','account-menu',0,''),(610726,192260,'73374','new_theme','block_type','1',0,''),(610727,192260,'73374','new_theme','padding-top','70',0,''),(610728,192260,'73374','new_theme','padding-right','30',0,''),(610729,192260,'73374','new_theme','padding-bottom','30',0,''),(610730,192260,'73374','new_theme','padding-top','0',0,'8451'),(610731,192260,'73374','new_theme','padding-left','0',0,'8451'),(610732,192260,'73374','new_theme','padding-right','0',0,'8451'),(610733,192260,'73374','new_theme','padding-bottom','0',0,'8451'),(610776,192279,'1704978704.8413','new_theme','block_type','1',0,''),(610777,192280,'73353','new_theme','link','Order History Info',0,''),(610778,192280,'73353','new_theme','text','TEXT_VIEW',0,''),(610779,192280,'73353','new_theme','max_orders','3',0,''),(610780,192280,'73353','new_theme','link_pay','Order pay',0,''),(610781,192280,'73353','new_theme','margin-bottom','30',0,''),(610782,192280,'73353','new_theme','text_pay','ORDER_PAY',0,''),(610783,192281,'73354','new_theme','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(610784,192282,'73357','new_theme','text','<h1>##HEADING_TITLE##</h1>',0,''),(610785,192283,'1705060269.3517','new_theme','block_type','1',0,''),(610786,192283,'1705060269.3517','new_theme','padding-top','20',0,''),(610787,192283,'1705060269.3517','new_theme','padding-left','20',0,''),(610788,192283,'1705060269.3517','new_theme','padding-right','20',0,''),(610789,192283,'1705060269.3517','new_theme','padding-bottom','20',0,''),(610790,192283,'1705060269.3517','new_theme','margin-bottom','30',0,''),(610791,192283,'1705060269.3517','new_theme','border-top-width','1',0,''),(610792,192283,'1705060269.3517','new_theme','border-left-width','1',0,''),(610793,192283,'1705060269.3517','new_theme','border-right-width','1',0,''),(610794,192283,'1705060269.3517','new_theme','border-bottom-width','1',0,''),(610795,192283,'1705060269.3517','new_theme','border-top-color','$content-border-1',0,''),(610796,192283,'1705060269.3517','new_theme','border-left-color','$content-border-1',0,''),(610797,192283,'1705060269.3517','new_theme','border-right-color','$content-border-1',0,''),(610798,192283,'1705060269.3517','new_theme','border-bottom-color','$content-border-1',0,''),(610799,192283,'1705060269.3517','new_theme','style_class','account-content-top',0,''),(610800,192284,'1705060551.6998','new_theme','block_type','1',0,''),(610801,192285,'73361','new_theme','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(610802,192285,'73361','new_theme','font-family','trueloaded',0,'3'),(610803,192285,'73361','new_theme','content','\\e920',0,'3'),(610804,192285,'73361','new_theme','color','$highlight-color-3',0,'3'),(610805,192285,'73361','new_theme','font-size','30',0,'3'),(610806,192285,'73361','new_theme','text-align','center',0,'3'),(610807,192285,'73361','new_theme','margin-bottom','10',0,'3'),(610808,192285,'73361','new_theme','text-align','center',0,''),(610809,192285,'73361','new_theme','font-size','16',0,''),(610810,192285,'73361','new_theme','text-transform','uppercase',0,''),(610811,192285,'73361','new_theme','line-height','1',0,'3'),(610812,192285,'73361','new_theme','font-size','14',0,'8444'),(610813,192286,'73362','new_theme','font-family','$font-1',0,''),(610814,192286,'73362','new_theme','color','$highlight-color-3',0,''),(610815,192286,'73362','new_theme','font-size','14',0,''),(610816,192286,'73362','new_theme','text-align','center',0,''),(610817,192287,'1705060566.121','new_theme','block_type','1',0,''),(610818,192288,'73363','new_theme','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(610819,192288,'73363','new_theme','font-family','trueloaded',0,'3'),(610820,192288,'73363','new_theme','content','\\e928',0,'3'),(610821,192288,'73363','new_theme','color','$highlight-color-3',0,'3'),(610822,192288,'73363','new_theme','font-size','30',0,'3'),(610823,192288,'73363','new_theme','text-align','center',0,'3'),(610824,192288,'73363','new_theme','text-align','center',0,''),(610825,192288,'73363','new_theme','font-size','16',0,''),(610826,192288,'73363','new_theme','text-transform','uppercase',0,''),(610827,192288,'73363','new_theme','line-height','1',0,'3'),(610828,192288,'73363','new_theme','font-size','14',0,'8444'),(610829,192289,'73364','new_theme','font-family','$font-1',0,''),(610830,192289,'73364','new_theme','color','$highlight-color-3',0,''),(610831,192289,'73364','new_theme','font-size','14',0,''),(610832,192289,'73364','new_theme','text-align','center',0,''),(610833,192290,'73365','new_theme','link','download_orders',0,''),(610834,192290,'73365','new_theme','text','TEXT_DOWNLOAD_ORDERS',0,''),(610835,192290,'73365','new_theme','hide_link','orders',0,''),(610836,192290,'73365','new_theme','text-align','center',0,''),(610837,192290,'73365','new_theme','popup','2',0,''),(610838,192290,'73365','new_theme','font-size','14',0,''),(610839,192291,'1705060582.9285','new_theme','block_type','1',0,''),(610840,192292,'73366','new_theme','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(610841,192292,'73366','new_theme','font-family','trueloaded',0,'3'),(610842,192292,'73366','new_theme','content','\\e922',0,'3'),(610843,192292,'73366','new_theme','color','$highlight-color-3',0,'3'),(610844,192292,'73366','new_theme','font-size','30',0,'3'),(610845,192292,'73366','new_theme','line-height','1',0,'3'),(610846,192292,'73366','new_theme','font-size','16',0,''),(610847,192292,'73366','new_theme','text-align','center',0,''),(610848,192292,'73366','new_theme','text-transform','uppercase',0,''),(610849,192292,'73366','new_theme','font-size','14',0,'8444'),(610850,192293,'73367','new_theme','font-family','$font-1',0,''),(610851,192293,'73367','new_theme','color','$highlight-color-3',0,''),(610852,192293,'73367','new_theme','line-height','1',0,''),(610853,192293,'73367','new_theme','text-align','center',0,''),(610854,192293,'73367','new_theme','font-size','14',0,''),(610855,192294,'1705060591.4402','new_theme','block_type','1',0,''),(610856,192295,'73368','new_theme','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(610857,192295,'73368','new_theme','content','\\e994',0,'3'),(610858,192295,'73368','new_theme','font-family','trueloaded',0,'3'),(610859,192295,'73368','new_theme','color','$highlight-color-3',0,'3'),(610860,192295,'73368','new_theme','font-size','30',0,'3'),(610861,192295,'73368','new_theme','line-height','1',0,'3'),(610862,192295,'73368','new_theme','font-size','16',0,''),(610863,192295,'73368','new_theme','text-align','center',0,''),(610864,192295,'73368','new_theme','text-transform','uppercase',0,''),(610865,192295,'73368','new_theme','font-size','14',0,'8444'),(610866,192296,'73369','new_theme','font-family','$font-1',0,''),(610867,192296,'73369','new_theme','color','$highlight-color-3',0,''),(610868,192296,'73369','new_theme','font-size','14',0,''),(610869,192296,'73369','new_theme','text-align','center',0,''),(610870,192297,'73370','new_theme','link','Gift Certificate',0,''),(610871,192297,'73370','new_theme','text','GIFT_CERTIFICATE',0,''),(610872,192297,'73370','new_theme','popup','1',0,''),(610873,192297,'73370','new_theme','text-align','center',0,''),(610874,192297,'73370','new_theme','font-size','14',0,''),(610875,192298,'1705060602.1936','new_theme','block_type','1',0,''),(610876,192299,'73371','new_theme','text','TEXT_VIEW_HISTORY',0,''),(610877,192299,'73371','new_theme','popup','1',0,''),(610878,192299,'73371','new_theme','text-align','center',0,''),(610879,192299,'73371','new_theme','link','Points Earnt History',0,''),(610880,192299,'73371','new_theme','font-size','14',0,''),(610881,192300,'73372','new_theme','font-family','$font-1',0,''),(610882,192300,'73372','new_theme','color','$highlight-color-3',0,''),(610883,192300,'73372','new_theme','font-size','14',0,''),(610884,192300,'73372','new_theme','text-align','center',0,''),(610885,192301,'73373','new_theme','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(610886,192301,'73373','new_theme','content','\\e990',0,'3'),(610887,192301,'73373','new_theme','font-family','trueloaded',0,'3'),(610888,192301,'73373','new_theme','font-size','30',0,'3'),(610889,192301,'73373','new_theme','text-align','center',0,'3'),(610890,192301,'73373','new_theme','line-height','1',0,'3'),(610891,192301,'73373','new_theme','color','$highlight-color-3',0,'3'),(610892,192301,'73373','new_theme','font-size','16',0,''),(610893,192301,'73373','new_theme','text-align','center',0,''),(610894,192301,'73373','new_theme','text-transform','uppercase',0,''),(610895,192301,'73373','new_theme','font-size','14',0,'8444'),(610896,192302,'73374','new_theme','block_type','1',0,''),(610897,192302,'73374','new_theme','padding-top','70',0,''),(610898,192302,'73374','new_theme','padding-right','30',0,''),(610899,192302,'73374','new_theme','padding-bottom','30',0,''),(610900,192302,'73374','new_theme','padding-top','0',0,'8451'),(610901,192302,'73374','new_theme','padding-left','0',0,'8451'),(610902,192302,'73374','new_theme','padding-right','0',0,'8451'),(610903,192302,'73374','new_theme','padding-bottom','0',0,'8451'),(610946,192321,'73393','new_theme','block_type','1',0,''),(610947,192321,'73393','new_theme','style_class','account-edit-wrap',0,''),(610948,192322,'73394','new_theme','block_type','6',0,''),(610949,192322,'73394','new_theme','schema','6-3',0,'8451'),(610950,192323,'73395','new_theme','aria_name','account-menu',0,''),(610951,192324,'73374','new_theme','block_type','1',0,''),(610952,192324,'73374','new_theme','padding-top','70',0,''),(610953,192324,'73374','new_theme','padding-right','30',0,''),(610954,192324,'73374','new_theme','padding-bottom','30',0,''),(610955,192324,'73374','new_theme','padding-top','0',0,'8451'),(610956,192324,'73374','new_theme','padding-left','0',0,'8451'),(610957,192324,'73374','new_theme','padding-right','0',0,'8451'),(610958,192324,'73374','new_theme','padding-bottom','0',0,'8451'),(611001,192344,'73397','new_theme','text','<h1>##HEADING_TITLE##</h1>',0,''),(611002,192345,'73398','new_theme','block_type','1',0,''),(611003,192345,'73398','new_theme','style_class','account-address-book',0,''),(611004,192346,'73399','new_theme','block_type','6',0,''),(611005,192346,'73399','new_theme','schema','6-3',0,'8451'),(611006,192347,'73400','new_theme','aria_name','account-menu',0,''),(611007,192348,'73374','new_theme','block_type','1',0,''),(611008,192348,'73374','new_theme','padding-top','70',0,''),(611009,192348,'73374','new_theme','padding-right','30',0,''),(611010,192348,'73374','new_theme','padding-bottom','30',0,''),(611011,192348,'73374','new_theme','padding-top','0',0,'8451'),(611012,192348,'73374','new_theme','padding-left','0',0,'8451'),(611013,192348,'73374','new_theme','padding-right','0',0,'8451'),(611014,192348,'73374','new_theme','padding-bottom','0',0,'8451'),(611057,192367,'73401','new_theme','padding-top','15',0,''),(611058,192367,'73401','new_theme','padding-bottom','15',0,''),(611059,192367,'73401','new_theme','link','Address Book Process',0,''),(611060,192367,'73401','new_theme','text','EDIT',0,''),(611061,192367,'73401','new_theme','link_add','Address Book Process',0,''),(611062,192367,'73401','new_theme','like_button_add','2',0,''),(611063,192367,'73401','new_theme','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(611064,192368,'73402','new_theme','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(611065,192369,'73403','new_theme','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(611066,192370,'73404','new_theme','block_type','1',0,''),(611067,192370,'73404','new_theme','style_class','account-address-book-process',0,''),(611068,192371,'73405','new_theme','block_type','6',0,''),(611069,192371,'73405','new_theme','schema','6-3',0,'8451'),(611070,192372,'73406','new_theme','aria_name','account-menu',0,''),(611071,192373,'73374','new_theme','block_type','1',0,''),(611072,192373,'73374','new_theme','padding-top','70',0,''),(611073,192373,'73374','new_theme','padding-right','30',0,''),(611074,192373,'73374','new_theme','padding-bottom','30',0,''),(611075,192373,'73374','new_theme','padding-top','0',0,'8451'),(611076,192373,'73374','new_theme','padding-left','0',0,'8451'),(611077,192373,'73374','new_theme','padding-right','0',0,'8451'),(611078,192373,'73374','new_theme','padding-bottom','0',0,'8451'),(611121,192392,'73407','new_theme','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(611122,192394,'73409','new_theme','block_type','1',0,''),(611123,192394,'73409','new_theme','style_class','item-holder',0,''),(611124,192394,'73409','new_theme','padding-top','25',0,''),(611125,192394,'73409','new_theme','padding-bottom','25',0,''),(611126,192394,'73409','new_theme','text-align','left',0,''),(611127,192394,'73409','new_theme','border-top-color','$content-border-1',0,''),(611128,192394,'73409','new_theme','border-top-width','1',0,''),(611129,192395,'73410','new_theme','block_type','6',0,''),(611130,192396,'73411','new_theme','padding-right','20',0,''),(611131,192397,'73412','new_theme','description_characters','200',0,''),(611132,192397,'73412','new_theme','clear','none',0,''),(611133,192397,'73412','new_theme','padding-right','20',0,''),(611134,192398,'73413','new_theme','clear','none',0,''),(611135,192400,'73415','new_theme','block_type','4',0,''),(611136,192401,'73416','new_theme','block_type','2',0,''),(611137,192402,'73417','new_theme','margin-bottom','7',0,''),(611138,192403,'73418','new_theme','clear','none',0,''),(611139,192404,'73419','new_theme','margin-bottom','20',0,''),(611140,192404,'73419','new_theme','text-align','right',0,''),(611141,192405,'73420','new_theme','padding-right','20',0,''),(611142,192406,'73421','new_theme','block_type','2',0,''),(611143,192407,'73422','new_theme','clear','none',0,''),(611144,192409,'76000','new_theme','block_type','1',0,''),(611145,192409,'76000','new_theme','style_class','item-holder',0,''),(611146,192409,'76000','new_theme','padding-top','25',0,''),(611147,192409,'76000','new_theme','padding-left','25',0,''),(611148,192409,'76000','new_theme','padding-right','25',0,''),(611149,192409,'76000','new_theme','padding-bottom','25',0,''),(611150,192409,'76000','new_theme','text-align','left',0,''),(611151,192411,'76002','new_theme','margin-bottom','7',0,''),(611152,192412,'76003','new_theme','clear','both',0,''),(611153,192415,'76006','new_theme','block_type','1',0,''),(611154,192415,'76006','new_theme','style_class','item-holder',0,''),(611155,192415,'76006','new_theme','padding-top','25',0,''),(611156,192415,'76006','new_theme','padding-left','25',0,''),(611157,192415,'76006','new_theme','padding-right','25',0,''),(611158,192415,'76006','new_theme','padding-bottom','25',0,''),(611159,192415,'76006','new_theme','text-align','left',0,''),(611160,192416,'76007','new_theme','block_type','5',0,''),(611161,192419,'76010','new_theme','margin-bottom','7',0,''),(611162,192420,'76011','new_theme','clear','both',0,''),(611163,192421,'76012','new_theme','block_type','1',0,''),(611164,192422,'76013','new_theme','block_type','6',0,''),(611165,192422,'76013','new_theme','font-weight','400',0,''),(611166,192422,'76013','new_theme','schema','6-2',0,'8472'),(611167,192422,'76013','new_theme','schema','6-2',0,'8451'),(611168,192423,'76014','new_theme','font-weight','400',0,''),(611169,192423,'76014','new_theme','padding-right','40',0,''),(611170,192423,'76014','new_theme','padding-right','0',0,'8472'),(611171,192423,'76014','new_theme','padding-right','0',0,'8451'),(611172,192424,'76015','new_theme','block_type','5',0,''),(611173,192424,'76015','new_theme','padding-top','10',0,''),(611174,192424,'76015','new_theme','padding-bottom','10',0,''),(611175,192424,'76015','new_theme','schema','5-2',0,'8472'),(611176,192424,'76015','new_theme','border-top-color','$content-border-1',0,''),(611177,192424,'76015','new_theme','border-top-width','1',0,''),(611178,192426,'76017','new_theme','float','right',0,''),(611179,192428,'76019','new_theme','col_in_row','3',0,''),(611180,192428,'76019','new_theme','products_align','left',0,''),(611181,192428,'76019','new_theme','font-weight','400',0,''),(611182,192428,'76019','new_theme','show_qty_input','0',0,''),(611183,192428,'76019','new_theme','listing_type','productListing',0,''),(611184,192428,'76019','new_theme','listing_type_rows','no',0,''),(611185,192428,'76019','new_theme','show_buy_button_b2b','on',0,''),(611186,192428,'76019','new_theme','show_wishlist_button_b2b','1',0,''),(611187,192428,'76019','new_theme','show_compare_b2b','1',0,''),(611188,192428,'76019','new_theme','show_stock','0',0,''),(611189,192428,'76019','new_theme','show_description','0',0,''),(611190,192428,'76019','new_theme','show_model','0',0,''),(611191,192428,'76019','new_theme','show_properties','0',0,''),(611192,192428,'76019','new_theme','show_rating','0',0,''),(611193,192428,'76019','new_theme','show_rating_counts','0',0,''),(611194,192428,'76019','new_theme','show_price','0',0,''),(611195,192428,'76019','new_theme','show_buy_button','0',0,''),(611196,192428,'76019','new_theme','show_view_button','0',0,''),(611197,192428,'76019','new_theme','show_wishlist_button','0',0,''),(611198,192428,'76019','new_theme','show_compare','0',0,''),(611199,192428,'76019','new_theme','show_name_rows','0',0,''),(611200,192428,'76019','new_theme','show_image_rows','0',0,''),(611201,192428,'76019','new_theme','show_stock_rows','0',0,''),(611202,192428,'76019','new_theme','show_description_rows','0',0,''),(611203,192428,'76019','new_theme','show_model_rows','0',0,''),(611204,192428,'76019','new_theme','show_properties_rows','0',0,''),(611205,192428,'76019','new_theme','show_rating_rows','0',0,''),(611206,192428,'76019','new_theme','show_rating_counts_rows','0',0,''),(611207,192428,'76019','new_theme','show_price_rows','0',0,''),(611208,192428,'76019','new_theme','show_buy_button_rows','0',0,''),(611209,192428,'76019','new_theme','show_qty_input_rows','0',0,''),(611210,192428,'76019','new_theme','show_view_button_rows','0',0,''),(611211,192428,'76019','new_theme','show_wishlist_button_rows','0',0,''),(611212,192428,'76019','new_theme','show_compare_rows','0',0,''),(611213,192428,'76019','new_theme','show_name_b2b','0',0,''),(611214,192428,'76019','new_theme','show_image_b2b','0',0,''),(611215,192428,'76019','new_theme','show_stock_b2b','0',0,''),(611216,192428,'76019','new_theme','show_description_b2b','0',0,''),(611217,192428,'76019','new_theme','show_model_b2b','0',0,''),(611218,192428,'76019','new_theme','show_properties_b2b','0',0,''),(611219,192428,'76019','new_theme','show_rating_b2b','0',0,''),(611220,192428,'76019','new_theme','show_rating_counts_b2b','0',0,''),(611221,192428,'76019','new_theme','show_price_b2b','0',0,''),(611222,192428,'76019','new_theme','show_qty_input_b2b','0',0,''),(611223,192428,'76019','new_theme','show_view_button_b2b','0',0,''),(611224,192428,'76019','new_theme','show_attributes_b2b','0',0,''),(611225,192428,'76019','new_theme','items_on_page','9',0,''),(611226,192428,'76019','new_theme','col_in_row','2',0,'8451'),(611227,192428,'76019','new_theme','col_in_row','1',0,'8472'),(611228,192428,'76019','new_theme','product_names_teg','h2',0,''),(611229,192429,'76020','new_theme','listing_type','productListing',0,''),(611230,192430,'76021','new_theme','block_type','1',0,''),(611231,192430,'76021','new_theme','padding-top','10',0,''),(611232,192430,'76021','new_theme','padding-bottom','10',0,''),(611233,192430,'76021','new_theme','border-bottom-width','1',0,''),(611234,192430,'76021','new_theme','border-bottom-color','$content-border-1',0,''),(611235,192430,'76021','new_theme','margin-left','0',0,''),(611236,192430,'76021','new_theme','margin-right','0',0,''),(611237,192431,'76022','new_theme','float','right',0,''),(611238,192431,'76022','new_theme','display','none',0,'8472'),(611239,192432,'76023','new_theme','margin-right','20',0,''),(611240,192432,'76023','new_theme','float','right',0,''),(611241,192432,'76023','new_theme','clear','none',0,''),(611242,192432,'76023','new_theme','display','none',0,'8451'),(611243,192433,'76024','new_theme','float','left',0,''),(611244,192433,'76024','new_theme','clear','none',0,''),(611245,192433,'76024','new_theme','margin-left','20',0,''),(611246,192433,'76024','new_theme','display','none',0,'8472'),(611247,192434,'76025','new_theme','float','left',0,''),(611248,192434,'76025','new_theme','clear','none',0,''),(611249,192434,'76025','new_theme','sort_pos_3','1',0,''),(611250,192434,'76025','new_theme','sort_pos_4','2',0,''),(611251,192434,'76025','new_theme','sort_pos_10','3',0,''),(611252,192434,'76025','new_theme','sort_pos_9','4',0,''),(611253,192434,'76025','new_theme','sort_pos_11','5',0,''),(611254,192434,'76025','new_theme','sort_pos_12','6',0,''),(611255,192434,'76025','new_theme','sort_pos_14','7',0,''),(611256,192434,'76025','new_theme','sort_pos_13','8',0,''),(611257,192434,'76025','new_theme','sort_pos_8','9',0,''),(611258,192434,'76025','new_theme','sort_pos_7','10',0,''),(611259,192434,'76025','new_theme','sort_pos_2','11',0,''),(611260,192434,'76025','new_theme','sort_pos_1','12',0,''),(611261,192434,'76025','new_theme','sort_pos_6','13',0,''),(611262,192434,'76025','new_theme','sort_pos_5','14',0,''),(611263,192434,'76025','new_theme','sort_pos_0','15',0,''),(611264,192434,'76025','new_theme','sort_hide_10','1',0,''),(611265,192434,'76025','new_theme','sort_hide_9','1',0,''),(611266,192434,'76025','new_theme','hide_icons','1',0,''),(611267,192434,'76025','new_theme','sort_hide_16','1',0,''),(611268,192434,'76025','new_theme','sort_hide_15','1',0,''),(611269,192434,'76025','new_theme','sort_hide_3','0',0,''),(611270,192434,'76025','new_theme','sort_hide_4','0',0,''),(611271,192434,'76025','new_theme','sort_hide_11','1',0,''),(611272,192434,'76025','new_theme','sort_hide_12','1',0,''),(611273,192434,'76025','new_theme','sort_hide_14','1',0,''),(611274,192434,'76025','new_theme','sort_hide_13','1',0,''),(611275,192434,'76025','new_theme','sort_hide_8','0',0,''),(611276,192434,'76025','new_theme','sort_hide_7','0',0,''),(611277,192434,'76025','new_theme','sort_hide_2','1',0,''),(611278,192434,'76025','new_theme','sort_hide_1','1',0,''),(611279,192434,'76025','new_theme','sort_hide_6','1',0,''),(611280,192434,'76025','new_theme','sort_hide_5','1',0,''),(611281,192434,'76025','new_theme','sort_hide_0','1',0,''),(611282,192437,'1683124632.767746','new_theme','block_type','1',0,''),(611283,192437,'1683124632.767746','new_theme','font-weight','normal',0,''),(611284,192437,'1683124632.767746','new_theme','padding-top','20',0,''),(611285,192437,'1683124632.767746','new_theme','background-color','$content-bg-2',0,''),(611286,192437,'1683124632.767746','new_theme','style_class','shopping-cart-index',0,''),(611287,192437,'1683124632.767746','new_theme','color','$content-color-2',0,''),(611288,192438,'1683124632.80670','new_theme','block_type','4',0,''),(611289,192438,'1683124632.80670','new_theme','schema','4-1',0,'8456'),(611290,192438,'1683124632.80670','new_theme','schema','4-2',0,'8451'),(611291,192439,'1683124632.809680','new_theme','block_type','1',0,''),(611292,192439,'1683124632.809680','new_theme','background-color','$content-bg-1',0,''),(611293,192439,'1683124632.809680','new_theme','padding-top','20',0,''),(611294,192439,'1683124632.809680','new_theme','padding-bottom','20',0,''),(611295,192439,'1683124632.809680','new_theme','padding-left','25',0,''),(611296,192439,'1683124632.809680','new_theme','padding-right','25',0,''),(611297,192439,'1683124632.809680','new_theme','margin-bottom','30',0,''),(611298,192439,'1683124632.809680','new_theme','color','$content-color-1',0,''),(611299,192440,'1683124632.816335','new_theme','block_type','1',0,''),(611300,192440,'1683124632.816335','new_theme','background-color','$content-bg-1',0,''),(611301,192440,'1683124632.816335','new_theme','margin-bottom','30',0,''),(611302,192440,'1683124632.816335','new_theme','color','$content-color-1',0,''),(611303,192441,'1683124632.817623','new_theme','padding-top','20',0,''),(611304,192441,'1683124632.817623','new_theme','padding-left','25',0,''),(611305,192441,'1683124632.817623','new_theme','padding-right','25',0,''),(611306,192441,'1683124632.817623','new_theme','padding-bottom','20',0,''),(611307,192442,'1683124632.818551','new_theme','block_type','2',0,''),(611308,192442,'1683124632.818551','new_theme','padding-bottom','20',0,''),(611309,192442,'1683124632.818551','new_theme','padding-top','20',0,''),(611310,192442,'1683124632.818551','new_theme','padding-left','25',0,''),(611311,192442,'1683124632.818551','new_theme','padding-right','25',0,''),(611312,192442,'1683124632.818551','new_theme','border-bottom-color','#e0e0e0',0,''),(611313,192442,'1683124632.818551','new_theme','border-bottom-width','1',0,''),(611314,192442,'1683124632.818551','new_theme','schema','2-2',0,'8451'),(611315,192443,'1683124632.820317','new_theme','float','left',0,''),(611316,192444,'1683124632.820914','new_theme','text-align','right',0,''),(611317,192444,'1683124632.820914','new_theme','clear','none',0,''),(611318,192444,'1683124632.820914','new_theme','float','right',0,''),(611319,192444,'1683124632.820914','new_theme','padding-top','22',0,''),(611320,192445,'1683124632.822588','new_theme','float','right',0,''),(611321,192445,'1683124632.822588','new_theme','padding-top','26',0,''),(611322,192446,'1683124632.823175','new_theme','block_type','3',0,''),(611323,192446,'1683124632.823175','new_theme','font-weight','400',0,''),(611324,192446,'1683124632.823175','new_theme','schema','2-2',0,'8444'),(611325,192446,'1683124632.823175','new_theme','style_class','closeable-content',0,''),(611326,192446,'1683124632.823175','new_theme','padding-top','10',0,''),(611327,192446,'1683124632.823175','new_theme','padding-left','25',0,''),(611328,192446,'1683124632.823175','new_theme','padding-right','25',0,''),(611329,192446,'1683124632.823175','new_theme','padding-bottom','20',0,''),(611330,192449,'1683124632.82683','new_theme','block_type','1',0,''),(611331,192449,'1683124632.82683','new_theme','padding-top','20',0,''),(611332,192449,'1683124632.82683','new_theme','padding-bottom','20',0,''),(611333,192449,'1683124632.82683','new_theme','padding-left','25',0,''),(611334,192449,'1683124632.82683','new_theme','padding-right','25',0,''),(611335,192449,'1683124632.82683','new_theme','background-color','$content-bg-1',0,''),(611336,192449,'1683124632.82683','new_theme','margin-bottom','30',0,''),(611337,192449,'1683124632.82683','new_theme','color','$content-color-1',0,''),(611338,192450,'1683124632.827413','new_theme','hide_parents','2',0,''),(611339,192451,'1683124632.828374','new_theme','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(611340,192452,'1683124632.829840','new_theme','block_type','1',0,''),(611341,192452,'1683124632.829840','new_theme','background-color','$content-bg-1',0,''),(611342,192452,'1683124632.829840','new_theme','padding-top','20',0,''),(611343,192452,'1683124632.829840','new_theme','padding-left','25',0,''),(611344,192452,'1683124632.829840','new_theme','padding-right','25',0,''),(611345,192452,'1683124632.829840','new_theme','padding-bottom','20',0,''),(611346,192452,'1683124632.829840','new_theme','margin-bottom','30',0,''),(611347,192452,'1683124632.829840','new_theme','style_class','closeable-box',0,''),(611348,192452,'1683124632.829840','new_theme','display','none',0,'8451'),(611349,192453,'1683124632.831459','new_theme','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(611350,192453,'1683124632.831459','new_theme','style_class','shipping-ico closeable-heading closeable-event',0,''),(611351,192454,'1683124632.832592','new_theme','font-weight','normal',0,''),(611352,192454,'1683124632.832592','new_theme','style_class','closeable-content',0,''),(611353,192454,'1683124632.832592','new_theme','padding-top','10',0,''),(611354,192454,'1683124632.832592','new_theme','hide_parents','2',0,''),(611355,192455,'1683124632.833353','new_theme','style_class','order-summary',0,''),(611356,192455,'1683124632.833353','new_theme','block_type','1',0,''),(611357,192455,'1683124632.833353','new_theme','margin-left','30',0,''),(611358,192455,'1683124632.833353','new_theme','margin-left','0',0,'8451'),(611359,192455,'1683124632.833353','new_theme','margin-bottom','30',0,'8451'),(611360,192456,'1683124632.834715','new_theme','block_type','1',0,''),(611361,192456,'1683124632.834715','new_theme','padding-left','20',0,''),(611362,192456,'1683124632.834715','new_theme','padding-right','20',0,''),(611363,192456,'1683124632.834715','new_theme','padding-bottom','20',0,''),(611364,192457,'1683124632.835884','new_theme','font-weight','400',0,''),(611365,192457,'1683124632.835884','new_theme','padding-top','12',0,'8444'),(611366,192457,'1683124632.835884','new_theme','padding-left','0',0,'8444'),(611367,192458,'1683124632.836532','new_theme','font-weight','400',0,''),(611368,192458,'1683124632.836532','new_theme','logo','themes/new_theme/img/themes/basic/img/payment.png',1,''),(611369,192458,'1683124632.836532','new_theme','padding-top','20',0,''),(611370,192458,'1683124632.836532','new_theme','padding-bottom','10',0,''),(611371,192458,'1683124632.836532','new_theme','logo','themes/new_theme/img/themes/basic/img/payment.png',0,''),(611372,192459,'1683124632.844829','new_theme','font-weight','400',0,''),(611373,192459,'1683124632.844829','new_theme','box_align','4',0,''),(611374,192459,'1683124632.844829','new_theme','text-align','center',0,'8444'),(611375,192459,'1683124632.844829','new_theme','float','none',0,'8444'),(611376,192459,'1683124632.844829','new_theme','width','100',0,'8444'),(611377,192459,'1683124632.844829','new_theme','width_measure','%',0,'8444'),(611378,192460,'1683124632.84681','new_theme','style_class','bottom-totals',0,''),(611379,192461,'1683124632.846538','new_theme','style_class','top-totals',0,''),(611380,192462,'1683124632.84726','new_theme','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(611381,192463,'94658','new_theme','block_type','1',0,''),(611382,192463,'94658','new_theme','font-weight','normal',0,''),(611383,192463,'94658','new_theme','padding-top','20',0,''),(611384,192463,'94658','new_theme','background-color','$content-bg-2',0,''),(611385,192465,'94660','new_theme','block_type','4',0,''),(611386,192465,'94660','new_theme','schema','4-1',0,'8456'),(611387,192465,'94660','new_theme','schema','4-2',0,'8451'),(611388,192466,'94661','new_theme','block_type','1',0,''),(611389,192466,'94661','new_theme','background-color','$content-bg-1',0,''),(611390,192466,'94661','new_theme','padding-top','20',0,''),(611391,192466,'94661','new_theme','padding-bottom','20',0,''),(611392,192466,'94661','new_theme','padding-left','25',0,''),(611393,192466,'94661','new_theme','padding-right','25',0,''),(611394,192466,'94661','new_theme','margin-bottom','30',0,''),(611395,192467,'94662','new_theme','col_in_row','3',0,''),(611396,192467,'94662','new_theme','show_description','1',0,''),(611397,192467,'94662','new_theme','show_model','1',0,''),(611398,192467,'94662','new_theme','show_properties','1',0,''),(611399,192467,'94662','new_theme','show_rating','1',0,''),(611400,192467,'94662','new_theme','show_rating_counts','1',0,''),(611401,192467,'94662','new_theme','show_qty_input','1',0,''),(611402,192467,'94662','new_theme','show_view_button','1',0,''),(611403,192467,'94662','new_theme','show_wishlist_button','1',0,''),(611404,192467,'94662','new_theme','show_compare','1',0,''),(611405,192467,'94662','new_theme','view_as','carousel',0,''),(611406,192467,'94662','new_theme','hide_parents','2',0,''),(611407,192468,'94663','new_theme','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(611408,192468,'94663','new_theme','style_class','bell-ico',0,''),(611409,192469,'94664','new_theme','block_type','1',0,''),(611410,192469,'94664','new_theme','background-color','$content-bg-1',0,''),(611411,192469,'94664','new_theme','margin-bottom','30',0,''),(611412,192470,'94665','new_theme','padding-top','20',0,''),(611413,192470,'94665','new_theme','padding-left','25',0,''),(611414,192470,'94665','new_theme','padding-right','25',0,''),(611415,192470,'94665','new_theme','padding-bottom','20',0,''),(611416,192471,'94666','new_theme','block_type','2',0,''),(611417,192471,'94666','new_theme','padding-bottom','20',0,''),(611418,192471,'94666','new_theme','padding-top','20',0,''),(611419,192471,'94666','new_theme','padding-left','25',0,''),(611420,192471,'94666','new_theme','padding-right','25',0,''),(611421,192471,'94666','new_theme','border-bottom-color','$content-border-1',0,''),(611422,192471,'94666','new_theme','border-bottom-width','1',0,''),(611423,192471,'94666','new_theme','schema','2-2',0,'8451'),(611424,192472,'94667','new_theme','float','left',0,''),(611425,192473,'94668','new_theme','text-align','right',0,''),(611426,192473,'94668','new_theme','clear','none',0,''),(611427,192473,'94668','new_theme','float','right',0,''),(611428,192473,'94668','new_theme','padding-top','22',0,''),(611429,192474,'94669','new_theme','float','right',0,''),(611430,192474,'94669','new_theme','padding-top','26',0,''),(611431,192475,'94670','new_theme','block_type','1',0,''),(611432,192475,'94670','new_theme','padding-top','20',0,''),(611433,192475,'94670','new_theme','padding-bottom','20',0,''),(611434,192475,'94670','new_theme','padding-left','25',0,''),(611435,192475,'94670','new_theme','padding-right','25',0,''),(611436,192475,'94670','new_theme','background-color','$content-bg-1',0,''),(611437,192475,'94670','new_theme','margin-bottom','30',0,''),(611438,192476,'94671','new_theme','hide_parents','2',0,''),(611439,192477,'94672','new_theme','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(611440,192478,'94673','new_theme','block_type','1',0,''),(611441,192478,'94673','new_theme','background-color','$content-bg-1',0,''),(611442,192478,'94673','new_theme','padding-top','20',0,''),(611443,192478,'94673','new_theme','padding-bottom','20',0,''),(611444,192478,'94673','new_theme','padding-left','25',0,''),(611445,192478,'94673','new_theme','padding-right','25',0,''),(611446,192478,'94673','new_theme','margin-bottom','30',0,''),(611447,192478,'94673','new_theme','style_class','closeable-box',0,''),(611448,192479,'94674','new_theme','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(611449,192479,'94674','new_theme','style_class','savings-ico closeable-heading closeable-event',0,''),(611450,192480,'94675','new_theme','block_type','3',0,''),(611451,192480,'94675','new_theme','font-weight','400',0,''),(611452,192480,'94675','new_theme','schema','2-2',0,'8444'),(611453,192480,'94675','new_theme','style_class','closeable-content',0,''),(611454,192480,'94675','new_theme','padding-top','10',0,''),(611455,192481,'94676','new_theme','font-weight','400',0,''),(611456,192481,'94676','new_theme','padding-top','12',0,'8444'),(611457,192481,'94676','new_theme','padding-left','0',0,'8444'),(611458,192484,'94679','new_theme','block_type','1',0,''),(611459,192484,'94679','new_theme','background-color','$content-bg-1',0,''),(611460,192484,'94679','new_theme','padding-top','20',0,''),(611461,192484,'94679','new_theme','padding-left','25',0,''),(611462,192484,'94679','new_theme','padding-right','25',0,''),(611463,192484,'94679','new_theme','padding-bottom','20',0,''),(611464,192484,'94679','new_theme','margin-bottom','30',0,''),(611465,192484,'94679','new_theme','style_class','closeable-box',0,''),(611466,192484,'94679','new_theme','display','none',0,'8451'),(611467,192485,'94680','new_theme','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(611468,192485,'94680','new_theme','style_class','shipping-ico closeable-heading closeable-event',0,''),(611469,192486,'94681','new_theme','font-weight','normal',0,''),(611470,192486,'94681','new_theme','style_class','closeable-content',0,''),(611471,192486,'94681','new_theme','padding-top','10',0,''),(611472,192486,'94681','new_theme','hide_parents','2',0,''),(611473,192487,'94682','new_theme','style_class','order-summary',0,''),(611474,192487,'94682','new_theme','block_type','1',0,''),(611475,192487,'94682','new_theme','margin-left','30',0,''),(611476,192487,'94682','new_theme','margin-left','0',0,'8451'),(611477,192487,'94682','new_theme','margin-bottom','30',0,'8451'),(611478,192488,'94683','new_theme','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(611479,192489,'94684','new_theme','block_type','1',0,''),(611480,192489,'94684','new_theme','padding-left','20',0,''),(611481,192489,'94684','new_theme','padding-right','20',0,''),(611482,192489,'94684','new_theme','padding-bottom','20',0,''),(611483,192490,'94685','new_theme','font-weight','400',0,''),(611484,192490,'94685','new_theme','logo','themes/new_theme/img/themes/basic/img/payment.png',1,''),(611485,192490,'94685','new_theme','padding-top','20',0,''),(611486,192490,'94685','new_theme','padding-bottom','10',0,''),(611487,192490,'94685','new_theme','logo','themes/new_theme/img/themes/basic/img/payment.png',0,''),(611488,192491,'94686','new_theme','font-weight','400',0,''),(611489,192491,'94686','new_theme','box_align','4',0,''),(611490,192491,'94686','new_theme','text-align','center',0,'8444'),(611491,192491,'94686','new_theme','float','none',0,'8444'),(611492,192491,'94686','new_theme','width','100',0,'8444'),(611493,192491,'94686','new_theme','width_measure','%',0,'8444'),(611494,192493,'73462','new_theme','block_type','1',0,''),(611495,192494,'73463','new_theme','block_type','6',0,''),(611496,192494,'73463','new_theme','font-weight','400',0,''),(611497,192494,'73463','new_theme','schema','6-2',0,'8472'),(611498,192494,'73463','new_theme','schema','6-2',0,'8451'),(611499,192495,'73464','new_theme','font-weight','400',0,''),(611500,192495,'73464','new_theme','padding-right','40',0,''),(611501,192495,'73464','new_theme','padding-right','0',0,'8472'),(611502,192495,'73464','new_theme','padding-right','0',0,'8451'),(611503,192496,'73465','new_theme','col_in_row','3',0,''),(611504,192496,'73465','new_theme','products_align','left',0,''),(611505,192496,'73465','new_theme','font-weight','400',0,''),(611506,192496,'73465','new_theme','show_qty_input','0',0,''),(611507,192496,'73465','new_theme','listing_type','productListing',0,''),(611508,192496,'73465','new_theme','listing_type_rows','Rows',0,''),(611509,192496,'73465','new_theme','show_buy_button_b2b','on',0,''),(611510,192496,'73465','new_theme','show_wishlist_button_b2b','1',0,''),(611511,192496,'73465','new_theme','show_compare_b2b','1',0,''),(611512,192496,'73465','new_theme','show_stock','0',0,''),(611513,192496,'73465','new_theme','show_description','0',0,''),(611514,192496,'73465','new_theme','show_model','0',0,''),(611515,192496,'73465','new_theme','show_properties','0',0,''),(611516,192496,'73465','new_theme','show_rating','0',0,''),(611517,192496,'73465','new_theme','show_rating_counts','0',0,''),(611518,192496,'73465','new_theme','show_price','0',0,''),(611519,192496,'73465','new_theme','show_buy_button','0',0,''),(611520,192496,'73465','new_theme','show_view_button','0',0,''),(611521,192496,'73465','new_theme','show_wishlist_button','0',0,''),(611522,192496,'73465','new_theme','show_compare','0',0,''),(611523,192496,'73465','new_theme','show_name_rows','0',0,''),(611524,192496,'73465','new_theme','show_image_rows','0',0,''),(611525,192496,'73465','new_theme','show_stock_rows','0',0,''),(611526,192496,'73465','new_theme','show_description_rows','0',0,''),(611527,192496,'73465','new_theme','show_model_rows','0',0,''),(611528,192496,'73465','new_theme','show_properties_rows','0',0,''),(611529,192496,'73465','new_theme','show_rating_rows','0',0,''),(611530,192496,'73465','new_theme','show_rating_counts_rows','0',0,''),(611531,192496,'73465','new_theme','show_price_rows','0',0,''),(611532,192496,'73465','new_theme','show_buy_button_rows','0',0,''),(611533,192496,'73465','new_theme','show_qty_input_rows','0',0,''),(611534,192496,'73465','new_theme','show_view_button_rows','0',0,''),(611535,192496,'73465','new_theme','show_wishlist_button_rows','0',0,''),(611536,192496,'73465','new_theme','show_compare_rows','0',0,''),(611537,192496,'73465','new_theme','show_name_b2b','0',0,''),(611538,192496,'73465','new_theme','show_image_b2b','0',0,''),(611539,192496,'73465','new_theme','show_stock_b2b','0',0,''),(611540,192496,'73465','new_theme','show_description_b2b','0',0,''),(611541,192496,'73465','new_theme','show_model_b2b','0',0,''),(611542,192496,'73465','new_theme','show_properties_b2b','0',0,''),(611543,192496,'73465','new_theme','show_rating_b2b','0',0,''),(611544,192496,'73465','new_theme','show_rating_counts_b2b','0',0,''),(611545,192496,'73465','new_theme','show_price_b2b','0',0,''),(611546,192496,'73465','new_theme','show_qty_input_b2b','0',0,''),(611547,192496,'73465','new_theme','show_view_button_b2b','0',0,''),(611548,192496,'73465','new_theme','show_attributes_b2b','0',0,''),(611549,192496,'73465','new_theme','items_on_page','9',0,''),(611550,192496,'73465','new_theme','col_in_row','2',0,'8451'),(611551,192496,'73465','new_theme','col_in_row','1',0,'8472'),(611552,192496,'73465','new_theme','product_names_teg','h2',0,''),(611553,192498,'73467','new_theme','block_type','5',0,''),(611554,192498,'73467','new_theme','padding-top','10',0,''),(611555,192498,'73467','new_theme','padding-bottom','10',0,''),(611556,192498,'73467','new_theme','schema','5-2',0,'8472'),(611557,192498,'73467','new_theme','border-top-color','$content-border-1',0,''),(611558,192498,'73467','new_theme','border-top-width','1',0,''),(611559,192500,'73469','new_theme','float','right',0,''),(611560,192501,'73470','new_theme','listing_type','productListing',0,''),(611561,192503,'73472','new_theme','block_type','1',0,''),(611562,192503,'73472','new_theme','padding-top','10',0,''),(611563,192503,'73472','new_theme','padding-bottom','10',0,''),(611564,192503,'73472','new_theme','border-bottom-width','1',0,''),(611565,192503,'73472','new_theme','border-bottom-color','$content-border-1',0,''),(611566,192503,'73472','new_theme','margin-left','0',0,''),(611567,192503,'73472','new_theme','margin-right','0',0,''),(611568,192504,'73473','new_theme','float','right',0,''),(611569,192504,'73473','new_theme','display','none',0,'8472'),(611570,192505,'73474','new_theme','margin-right','20',0,''),(611571,192505,'73474','new_theme','float','right',0,''),(611572,192505,'73474','new_theme','clear','none',0,''),(611573,192505,'73474','new_theme','display','none',0,'8451'),(611574,192506,'73475','new_theme','float','left',0,''),(611575,192506,'73475','new_theme','clear','none',0,''),(611576,192506,'73475','new_theme','margin-left','20',0,''),(611577,192506,'73475','new_theme','display','none',0,'8472'),(611578,192507,'73476','new_theme','float','left',0,''),(611579,192507,'73476','new_theme','clear','none',0,''),(611580,192507,'73476','new_theme','sort_pos_3','2',0,''),(611581,192507,'73476','new_theme','sort_pos_4','3',0,''),(611582,192507,'73476','new_theme','sort_pos_10','11',0,''),(611583,192507,'73476','new_theme','sort_pos_9','10',0,''),(611584,192507,'73476','new_theme','sort_pos_11','12',0,''),(611585,192507,'73476','new_theme','sort_pos_12','13',0,''),(611586,192507,'73476','new_theme','sort_pos_14','15',0,''),(611587,192507,'73476','new_theme','sort_pos_13','14',0,''),(611588,192507,'73476','new_theme','sort_pos_8','4',0,''),(611589,192507,'73476','new_theme','sort_pos_7','5',0,''),(611590,192507,'73476','new_theme','sort_pos_2','7',0,''),(611591,192507,'73476','new_theme','sort_pos_1','6',0,''),(611592,192507,'73476','new_theme','sort_pos_6','9',0,''),(611593,192507,'73476','new_theme','sort_pos_5','8',0,''),(611594,192507,'73476','new_theme','sort_pos_0','1',0,''),(611595,192507,'73476','new_theme','sort_hide_10','1',0,''),(611596,192507,'73476','new_theme','sort_hide_9','1',0,''),(611597,192507,'73476','new_theme','hide_icons','1',0,''),(611598,192507,'73476','new_theme','sort_hide_16','1',0,''),(611599,192507,'73476','new_theme','sort_hide_15','1',0,''),(611600,192507,'73476','new_theme','sort_hide_3','0',0,''),(611601,192507,'73476','new_theme','sort_hide_4','0',0,''),(611602,192507,'73476','new_theme','sort_hide_11','1',0,''),(611603,192507,'73476','new_theme','sort_hide_12','1',0,''),(611604,192507,'73476','new_theme','sort_hide_14','1',0,''),(611605,192507,'73476','new_theme','sort_hide_13','1',0,''),(611606,192507,'73476','new_theme','sort_hide_8','0',0,''),(611607,192507,'73476','new_theme','sort_hide_7','0',0,''),(611608,192507,'73476','new_theme','sort_hide_2','1',0,''),(611609,192507,'73476','new_theme','sort_hide_1','1',0,''),(611610,192507,'73476','new_theme','sort_hide_6','1',0,''),(611611,192507,'73476','new_theme','sort_hide_5','1',0,''),(611612,192507,'73476','new_theme','sort_hide_0','0',0,''),(611613,192507,'73476','new_theme','sort_pos_15','16',0,''),(611614,192507,'73476','new_theme','sort_pos_16','17',0,''),(611615,192514,'94688','new_theme','block_type','1',0,''),(611616,192516,'94690','new_theme','block_type','6',0,''),(611617,192516,'94690','new_theme','font-weight','400',0,''),(611618,192516,'94690','new_theme','schema','6-2',0,'8472'),(611619,192516,'94690','new_theme','schema','6-2',0,'8451'),(611620,192517,'94691','new_theme','font-weight','400',0,''),(611621,192517,'94691','new_theme','padding-right','40',0,''),(611622,192517,'94691','new_theme','padding-right','0',0,'8472'),(611623,192517,'94691','new_theme','padding-right','0',0,'8451'),(611624,192519,'94693','new_theme','col_in_row','3',0,''),(611625,192519,'94693','new_theme','products_align','left',0,''),(611626,192519,'94693','new_theme','font-weight','400',0,''),(611627,192519,'94693','new_theme','show_qty_input','0',0,''),(611628,192519,'94693','new_theme','listing_type','productListing',0,''),(611629,192519,'94693','new_theme','listing_type_rows','no',0,''),(611630,192519,'94693','new_theme','show_buy_button_b2b','on',0,''),(611631,192519,'94693','new_theme','show_wishlist_button_b2b','1',0,''),(611632,192519,'94693','new_theme','show_compare_b2b','1',0,''),(611633,192519,'94693','new_theme','show_stock','0',0,''),(611634,192519,'94693','new_theme','show_description','0',0,''),(611635,192519,'94693','new_theme','show_model','0',0,''),(611636,192519,'94693','new_theme','show_properties','0',0,''),(611637,192519,'94693','new_theme','show_rating','0',0,''),(611638,192519,'94693','new_theme','show_rating_counts','0',0,''),(611639,192519,'94693','new_theme','show_price','0',0,''),(611640,192519,'94693','new_theme','show_buy_button','0',0,''),(611641,192519,'94693','new_theme','show_view_button','0',0,''),(611642,192519,'94693','new_theme','show_wishlist_button','0',0,''),(611643,192519,'94693','new_theme','show_compare','0',0,''),(611644,192519,'94693','new_theme','show_name_rows','0',0,''),(611645,192519,'94693','new_theme','show_image_rows','0',0,''),(611646,192519,'94693','new_theme','show_stock_rows','0',0,''),(611647,192519,'94693','new_theme','show_description_rows','0',0,''),(611648,192519,'94693','new_theme','show_model_rows','0',0,''),(611649,192519,'94693','new_theme','show_properties_rows','0',0,''),(611650,192519,'94693','new_theme','show_rating_rows','0',0,''),(611651,192519,'94693','new_theme','show_rating_counts_rows','0',0,''),(611652,192519,'94693','new_theme','show_price_rows','0',0,''),(611653,192519,'94693','new_theme','show_buy_button_rows','0',0,''),(611654,192519,'94693','new_theme','show_qty_input_rows','0',0,''),(611655,192519,'94693','new_theme','show_view_button_rows','0',0,''),(611656,192519,'94693','new_theme','show_wishlist_button_rows','0',0,''),(611657,192519,'94693','new_theme','show_compare_rows','0',0,''),(611658,192519,'94693','new_theme','show_name_b2b','0',0,''),(611659,192519,'94693','new_theme','show_image_b2b','0',0,''),(611660,192519,'94693','new_theme','show_stock_b2b','0',0,''),(611661,192519,'94693','new_theme','show_description_b2b','0',0,''),(611662,192519,'94693','new_theme','show_model_b2b','0',0,''),(611663,192519,'94693','new_theme','show_properties_b2b','0',0,''),(611664,192519,'94693','new_theme','show_rating_b2b','0',0,''),(611665,192519,'94693','new_theme','show_rating_counts_b2b','0',0,''),(611666,192519,'94693','new_theme','show_price_b2b','0',0,''),(611667,192519,'94693','new_theme','show_qty_input_b2b','0',0,''),(611668,192519,'94693','new_theme','show_view_button_b2b','0',0,''),(611669,192519,'94693','new_theme','show_attributes_b2b','0',0,''),(611670,192519,'94693','new_theme','items_on_page','9',0,''),(611671,192519,'94693','new_theme','col_in_row','2',0,'8451'),(611672,192519,'94693','new_theme','col_in_row','1',0,'8472'),(611673,192519,'94693','new_theme','product_names_teg','h2',0,''),(611674,192520,'94694','new_theme','block_type','1',0,''),(611675,192520,'94694','new_theme','padding-top','10',0,''),(611676,192520,'94694','new_theme','padding-bottom','10',0,''),(611677,192520,'94694','new_theme','border-bottom-width','1',0,''),(611678,192520,'94694','new_theme','border-bottom-color','$content-border-1',0,''),(611679,192520,'94694','new_theme','margin-left','0',0,''),(611680,192520,'94694','new_theme','margin-right','0',0,''),(611681,192521,'94695','new_theme','float','left',0,''),(611682,192521,'94695','new_theme','clear','none',0,''),(611683,192521,'94695','new_theme','sort_pos_3','1',0,''),(611684,192521,'94695','new_theme','sort_pos_4','2',0,''),(611685,192521,'94695','new_theme','sort_pos_10','3',0,''),(611686,192521,'94695','new_theme','sort_pos_9','4',0,''),(611687,192521,'94695','new_theme','sort_pos_11','5',0,''),(611688,192521,'94695','new_theme','sort_pos_12','6',0,''),(611689,192521,'94695','new_theme','sort_pos_14','7',0,''),(611690,192521,'94695','new_theme','sort_pos_13','8',0,''),(611691,192521,'94695','new_theme','sort_pos_8','9',0,''),(611692,192521,'94695','new_theme','sort_pos_7','10',0,''),(611693,192521,'94695','new_theme','sort_pos_2','11',0,''),(611694,192521,'94695','new_theme','sort_pos_1','12',0,''),(611695,192521,'94695','new_theme','sort_pos_6','13',0,''),(611696,192521,'94695','new_theme','sort_pos_5','14',0,''),(611697,192521,'94695','new_theme','sort_pos_0','15',0,''),(611698,192521,'94695','new_theme','sort_hide_10','1',0,''),(611699,192521,'94695','new_theme','sort_hide_9','1',0,''),(611700,192521,'94695','new_theme','hide_icons','1',0,''),(611701,192521,'94695','new_theme','sort_hide_16','1',0,''),(611702,192521,'94695','new_theme','sort_hide_15','1',0,''),(611703,192521,'94695','new_theme','sort_hide_3','0',0,''),(611704,192521,'94695','new_theme','sort_hide_4','0',0,''),(611705,192521,'94695','new_theme','sort_hide_11','1',0,''),(611706,192521,'94695','new_theme','sort_hide_12','1',0,''),(611707,192521,'94695','new_theme','sort_hide_14','1',0,''),(611708,192521,'94695','new_theme','sort_hide_13','1',0,''),(611709,192521,'94695','new_theme','sort_hide_8','0',0,''),(611710,192521,'94695','new_theme','sort_hide_7','0',0,''),(611711,192521,'94695','new_theme','sort_hide_2','1',0,''),(611712,192521,'94695','new_theme','sort_hide_1','1',0,''),(611713,192521,'94695','new_theme','sort_hide_6','1',0,''),(611714,192521,'94695','new_theme','sort_hide_5','1',0,''),(611715,192521,'94695','new_theme','sort_hide_0','1',0,''),(611716,192522,'94696','new_theme','float','left',0,''),(611717,192522,'94696','new_theme','clear','none',0,''),(611718,192522,'94696','new_theme','margin-left','20',0,''),(611719,192522,'94696','new_theme','display','none',0,'8472'),(611720,192523,'94697','new_theme','margin-right','20',0,''),(611721,192523,'94697','new_theme','float','right',0,''),(611722,192523,'94697','new_theme','clear','none',0,''),(611723,192523,'94697','new_theme','display','none',0,'8451'),(611724,192524,'94698','new_theme','float','right',0,''),(611725,192524,'94698','new_theme','display','none',0,'8472'),(611726,192525,'94699','new_theme','listing_type','productListing',0,''),(611727,192527,'94701','new_theme','block_type','5',0,''),(611728,192527,'94701','new_theme','padding-top','10',0,''),(611729,192527,'94701','new_theme','padding-bottom','10',0,''),(611730,192527,'94701','new_theme','schema','5-2',0,'8472'),(611731,192527,'94701','new_theme','border-top-color','$content-border-1',0,''),(611732,192527,'94701','new_theme','border-top-width','1',0,''),(611733,192529,'94703','new_theme','float','right',0,''),(611734,192530,'73483','new_theme','block_type','1',0,''),(611735,192533,'73486','new_theme','block_type','1',0,''),(611736,192533,'73486','new_theme','padding-top','10',0,''),(611737,192533,'73486','new_theme','padding-bottom','10',0,''),(611738,192533,'73486','new_theme','border-bottom-width','1',0,''),(611739,192533,'73486','new_theme','border-bottom-color','$content-border-1',0,''),(611740,192533,'73486','new_theme','margin-left','0',0,''),(611741,192533,'73486','new_theme','margin-right','0',0,''),(611742,192534,'73487','new_theme','float','left',0,''),(611743,192534,'73487','new_theme','clear','none',0,''),(611744,192534,'73487','new_theme','margin-left','20',0,''),(611745,192534,'73487','new_theme','display','none',0,'8472'),(611746,192535,'73488','new_theme','float','left',0,''),(611747,192535,'73488','new_theme','clear','none',0,''),(611748,192535,'73488','new_theme','sort_pos_3','2',0,''),(611749,192535,'73488','new_theme','sort_pos_4','3',0,''),(611750,192535,'73488','new_theme','sort_pos_10','11',0,''),(611751,192535,'73488','new_theme','sort_pos_9','10',0,''),(611752,192535,'73488','new_theme','sort_pos_11','12',0,''),(611753,192535,'73488','new_theme','sort_pos_12','13',0,''),(611754,192535,'73488','new_theme','sort_pos_14','15',0,''),(611755,192535,'73488','new_theme','sort_pos_13','14',0,''),(611756,192535,'73488','new_theme','sort_pos_8','4',0,''),(611757,192535,'73488','new_theme','sort_pos_7','5',0,''),(611758,192535,'73488','new_theme','sort_pos_2','7',0,''),(611759,192535,'73488','new_theme','sort_pos_1','6',0,''),(611760,192535,'73488','new_theme','sort_pos_6','9',0,''),(611761,192535,'73488','new_theme','sort_pos_5','8',0,''),(611762,192535,'73488','new_theme','sort_pos_0','1',0,''),(611763,192535,'73488','new_theme','sort_hide_10','1',0,''),(611764,192535,'73488','new_theme','sort_hide_9','1',0,''),(611765,192535,'73488','new_theme','hide_icons','1',0,''),(611766,192535,'73488','new_theme','sort_hide_16','1',0,''),(611767,192535,'73488','new_theme','sort_hide_15','1',0,''),(611768,192535,'73488','new_theme','sort_hide_3','0',0,''),(611769,192535,'73488','new_theme','sort_hide_4','0',0,''),(611770,192535,'73488','new_theme','sort_hide_11','1',0,''),(611771,192535,'73488','new_theme','sort_hide_12','1',0,''),(611772,192535,'73488','new_theme','sort_hide_14','1',0,''),(611773,192535,'73488','new_theme','sort_hide_13','1',0,''),(611774,192535,'73488','new_theme','sort_hide_8','0',0,''),(611775,192535,'73488','new_theme','sort_hide_7','0',0,''),(611776,192535,'73488','new_theme','sort_hide_2','1',0,''),(611777,192535,'73488','new_theme','sort_hide_1','1',0,''),(611778,192535,'73488','new_theme','sort_hide_6','1',0,''),(611779,192535,'73488','new_theme','sort_hide_5','1',0,''),(611780,192535,'73488','new_theme','sort_hide_0','0',0,''),(611781,192535,'73488','new_theme','sort_pos_15','16',0,''),(611782,192535,'73488','new_theme','sort_pos_16','17',0,''),(611783,192536,'73489','new_theme','margin-right','20',0,''),(611784,192536,'73489','new_theme','float','right',0,''),(611785,192536,'73489','new_theme','clear','none',0,''),(611786,192536,'73489','new_theme','display','none',0,'8451'),(611787,192537,'73490','new_theme','float','right',0,''),(611788,192537,'73490','new_theme','display','none',0,'8472'),(611789,192538,'73491','new_theme','clear','none',0,''),(611790,192538,'73491','new_theme','float','left',0,''),(611791,192538,'73491','new_theme','padding-top','3',0,''),(611792,192538,'73491','new_theme','padding-left','20',0,''),(611793,192539,'73492','new_theme','block_type','5',0,''),(611794,192539,'73492','new_theme','padding-top','10',0,''),(611795,192539,'73492','new_theme','padding-bottom','10',0,''),(611796,192539,'73492','new_theme','schema','5-2',0,'8472'),(611797,192539,'73492','new_theme','border-top-color','$content-border-1',0,''),(611798,192539,'73492','new_theme','border-top-width','1',0,''),(611799,192541,'73494','new_theme','float','right',0,''),(611800,192542,'73495','new_theme','col_in_row','4',0,''),(611801,192542,'73495','new_theme','products_align','left',0,''),(611802,192542,'73495','new_theme','font-weight','400',0,''),(611803,192542,'73495','new_theme','show_qty_input','0',0,''),(611804,192542,'73495','new_theme','listing_type','productListing',0,''),(611805,192542,'73495','new_theme','listing_type_rows','Rows',0,''),(611806,192542,'73495','new_theme','show_buy_button_b2b','on',0,''),(611807,192542,'73495','new_theme','show_wishlist_button_b2b','1',0,''),(611808,192542,'73495','new_theme','show_compare_b2b','1',0,''),(611809,192542,'73495','new_theme','show_image','0',0,''),(611810,192542,'73495','new_theme','show_stock','0',0,''),(611811,192542,'73495','new_theme','show_description','0',0,''),(611812,192542,'73495','new_theme','show_model','0',0,''),(611813,192542,'73495','new_theme','show_properties','0',0,''),(611814,192542,'73495','new_theme','show_rating','0',0,''),(611815,192542,'73495','new_theme','show_rating_counts','0',0,''),(611816,192542,'73495','new_theme','show_price','0',0,''),(611817,192542,'73495','new_theme','show_buy_button','0',0,''),(611818,192542,'73495','new_theme','show_view_button','0',0,''),(611819,192542,'73495','new_theme','show_wishlist_button','0',0,''),(611820,192542,'73495','new_theme','show_compare','0',0,''),(611821,192542,'73495','new_theme','show_name_rows','0',0,''),(611822,192542,'73495','new_theme','show_image_rows','0',0,''),(611823,192542,'73495','new_theme','show_stock_rows','0',0,''),(611824,192542,'73495','new_theme','show_description_rows','0',0,''),(611825,192542,'73495','new_theme','show_model_rows','0',0,''),(611826,192542,'73495','new_theme','show_properties_rows','0',0,''),(611827,192542,'73495','new_theme','show_rating_rows','0',0,''),(611828,192542,'73495','new_theme','show_rating_counts_rows','0',0,''),(611829,192542,'73495','new_theme','show_price_rows','0',0,''),(611830,192542,'73495','new_theme','show_buy_button_rows','0',0,''),(611831,192542,'73495','new_theme','show_qty_input_rows','0',0,''),(611832,192542,'73495','new_theme','show_view_button_rows','0',0,''),(611833,192542,'73495','new_theme','show_wishlist_button_rows','0',0,''),(611834,192542,'73495','new_theme','show_compare_rows','0',0,''),(611835,192542,'73495','new_theme','show_name_b2b','0',0,''),(611836,192542,'73495','new_theme','show_image_b2b','0',0,''),(611837,192542,'73495','new_theme','show_stock_b2b','0',0,''),(611838,192542,'73495','new_theme','show_description_b2b','0',0,''),(611839,192542,'73495','new_theme','show_model_b2b','0',0,''),(611840,192542,'73495','new_theme','show_properties_b2b','0',0,''),(611841,192542,'73495','new_theme','show_rating_b2b','0',0,''),(611842,192542,'73495','new_theme','show_rating_counts_b2b','0',0,''),(611843,192542,'73495','new_theme','show_price_b2b','0',0,''),(611844,192542,'73495','new_theme','show_qty_input_b2b','0',0,''),(611845,192542,'73495','new_theme','show_view_button_b2b','0',0,''),(611846,192542,'73495','new_theme','show_attributes_b2b','0',0,''),(611847,192542,'73495','new_theme','items_on_page','12',0,''),(611848,192542,'73495','new_theme','col_in_row','2',0,'8451'),(611849,192542,'73495','new_theme','col_in_row','1',0,'8472'),(611850,192542,'73495','new_theme','product_names_teg','h2',0,''),(611851,192545,'1683125852.345798','new_theme','block_type','1',0,''),(611852,192545,'1683125852.345798','new_theme','background-color','$content-bg-2',0,''),(611853,192545,'1683125852.345798','new_theme','padding-top','30',0,''),(611854,192545,'1683125852.345798','new_theme','padding-bottom','30',0,''),(611855,192545,'1683125852.345798','new_theme','style_class','checkout-index-wrap',0,''),(611856,192545,'1683125852.345798','new_theme','color','$content-color-2',0,''),(611857,192546,'1683125852.356555','new_theme','block_type','4',0,''),(611858,192546,'1683125852.356555','new_theme','schema','4-2',0,'8451'),(611859,192546,'1683125852.356555','new_theme','style_class','checkoutDoubleBox',0,''),(611860,192547,'1683125852.358412','new_theme','block_type','1',0,''),(611861,192547,'1683125852.358412','new_theme','padding-right','40',0,''),(611862,192547,'1683125852.358412','new_theme','padding-right','0',0,'8451'),(611863,192548,'1683125852.35982','new_theme','block_type','1',0,''),(611864,192548,'1683125852.35982','new_theme','background-color','$content-bg-1',0,''),(611865,192548,'1683125852.35982','new_theme','padding-top','30',0,''),(611866,192548,'1683125852.35982','new_theme','padding-left','30',0,''),(611867,192548,'1683125852.35982','new_theme','padding-right','30',0,''),(611868,192548,'1683125852.35982','new_theme','padding-bottom','30',0,''),(611869,192548,'1683125852.35982','new_theme','margin-bottom','20',0,''),(611870,192548,'1683125852.35982','new_theme','style_class','hiding-box closeable-box',0,''),(611871,192548,'1683125852.35982','new_theme','color','$content-color-1',0,''),(611872,192549,'1683125852.361569','new_theme','style_class','closeable-content',0,''),(611873,192549,'1683125852.361569','new_theme','padding-bottom','20',0,''),(611874,192550,'1683125852.362847','new_theme','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(611875,192550,'1683125852.362847','new_theme','style_class','closeable-heading closeable-event closed',0,''),(611876,192551,'1683125852.36485','new_theme','block_type','1',0,''),(611877,192551,'1683125852.36485','new_theme','padding-top','30',0,''),(611878,192551,'1683125852.36485','new_theme','padding-left','30',0,''),(611879,192551,'1683125852.36485','new_theme','padding-right','30',0,''),(611880,192551,'1683125852.36485','new_theme','padding-bottom','30',0,''),(611881,192551,'1683125852.36485','new_theme','margin-bottom','20',0,''),(611882,192551,'1683125852.36485','new_theme','background-color','$content-bg-1',0,''),(611883,192551,'1683125852.36485','new_theme','style_class','hiding-box closeable-box',0,''),(611884,192551,'1683125852.36485','new_theme','color','$content-color-1',0,''),(611885,192552,'1683125852.366422','new_theme','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(611886,192552,'1683125852.366422','new_theme','style_class','closeable-heading closeable-event closed',0,''),(611887,192553,'1683125852.367732','new_theme','block_type','2',0,''),(611888,192553,'1683125852.367732','new_theme','style_class','closeable-content',0,''),(611889,192553,'1683125852.367732','new_theme','schema','2-2',0,'8451'),(611890,192554,'1683125852.36968','new_theme','padding-right','20',0,''),(611891,192554,'1683125852.36968','new_theme','padding-bottom','20',0,''),(611892,192554,'1683125852.36968','new_theme','padding-right','0',0,'8451'),(611893,192555,'1683125852.369745','new_theme','padding-left','20',0,''),(611894,192555,'1683125852.369745','new_theme','padding-bottom','20',0,''),(611895,192555,'1683125852.369745','new_theme','padding-left','0',0,'8451'),(611896,192556,'1683125852.37045','new_theme','padding-left','20',0,''),(611897,192556,'1683125852.37045','new_theme','padding-bottom','20',0,''),(611898,192556,'1683125852.37045','new_theme','padding-left','0',0,'8451'),(611899,192557,'1683125852.371233','new_theme','background-color','$content-bg-1',0,''),(611900,192557,'1683125852.371233','new_theme','block_type','1',0,''),(611901,192557,'1683125852.371233','new_theme','padding-top','30',0,''),(611902,192557,'1683125852.371233','new_theme','padding-left','30',0,''),(611903,192557,'1683125852.371233','new_theme','padding-right','30',0,''),(611904,192557,'1683125852.371233','new_theme','padding-bottom','30',0,''),(611905,192557,'1683125852.371233','new_theme','margin-bottom','20',0,''),(611906,192557,'1683125852.371233','new_theme','style_class','hiding-box',0,''),(611907,192557,'1683125852.371233','new_theme','color','$content-color-1',0,''),(611908,192558,'1683125852.37350','new_theme','block_type','1',0,''),(611909,192558,'1683125852.37350','new_theme','content','\\_',0,'3'),(611910,192558,'1683125852.37350','new_theme','border-top-width','1',0,'3'),(611911,192558,'1683125852.37350','new_theme','border-top-color','#e0e0e0',0,'3'),(611912,192558,'1683125852.37350','new_theme','display','block',0,'3'),(611913,192558,'1683125852.37350','new_theme','position','absolute',0,'3'),(611914,192558,'1683125852.37350','new_theme','top','19',0,'3'),(611915,192558,'1683125852.37350','new_theme','left','0',0,'3'),(611916,192558,'1683125852.37350','new_theme','right','0',0,'3'),(611917,192558,'1683125852.37350','new_theme','margin-top','-2',0,'3'),(611918,192558,'1683125852.37350','new_theme','position','relative',0,''),(611919,192559,'1683125852.374899','new_theme','box_align','2',0,''),(611920,192559,'1683125852.374899','new_theme','margin-bottom','10',0,''),(611921,192559,'1683125852.374899','new_theme','background-color','$content-bg-1',0,''),(611922,192559,'1683125852.374899','new_theme','position','relative',0,''),(611923,192560,'1683125852.375685','new_theme','background-color','$content-bg-2',0,''),(611924,192560,'1683125852.375685','new_theme','padding-top','10',0,''),(611925,192560,'1683125852.375685','new_theme','padding-left','10',0,''),(611926,192560,'1683125852.375685','new_theme','padding-right','10',0,''),(611927,192560,'1683125852.375685','new_theme','padding-bottom','10',0,''),(611928,192560,'1683125852.375685','new_theme','margin-top','10',0,''),(611929,192561,'1683125852.376557','new_theme','block_type','2',0,''),(611930,192561,'1683125852.376557','new_theme','schema','2-2',0,'8451'),(611931,192562,'1683125852.377637','new_theme','block_type','1',0,''),(611932,192562,'1683125852.377637','new_theme','padding-right','20',0,''),(611933,192562,'1683125852.377637','new_theme','padding-left','0',0,'8451'),(611934,192562,'1683125852.377637','new_theme','margin-bottom','20',0,'8451'),(611935,192562,'1683125852.377637','new_theme','padding-right','0',0,'8451'),(611936,192563,'1683125852.378829','new_theme','address_in','popup',0,''),(611937,192564,'1683125852.379375','new_theme','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(611938,192567,'1683125852.381183','new_theme','block_type','1',0,''),(611939,192567,'1683125852.381183','new_theme','padding-left','20',0,''),(611940,192567,'1683125852.381183','new_theme','padding-left','0',0,'8451'),(611941,192569,'1683125852.382635','new_theme','border-top-width','1',0,''),(611942,192569,'1683125852.382635','new_theme','border-top-color','#e0e0e0',0,''),(611943,192569,'1683125852.382635','new_theme','padding-top','13',0,''),(611944,192569,'1683125852.382635','new_theme','padding-bottom','10',0,''),(611945,192570,'1683125852.383516','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(611946,192571,'1683125852.385278','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(611947,192572,'1683125852.386397','new_theme','margin-bottom','20',0,''),(611948,192572,'1683125852.386397','new_theme','style_class','hiding-box',0,''),(611949,192573,'1683125852.386970','new_theme','padding-top','30',0,''),(611950,192573,'1683125852.386970','new_theme','padding-left','30',0,''),(611951,192573,'1683125852.386970','new_theme','padding-right','30',0,''),(611952,192573,'1683125852.386970','new_theme','margin-top','20',0,''),(611953,192573,'1683125852.386970','new_theme','background-color','$content-bg-1',0,''),(611954,192573,'1683125852.386970','new_theme','padding-bottom','30',0,''),(611955,192573,'1683125852.386970','new_theme','margin-bottom','20',0,''),(611956,192573,'1683125852.386970','new_theme','color','$content-color-1',0,''),(611957,192574,'1683125852.38820','new_theme','block_type','1',0,''),(611958,192574,'1683125852.38820','new_theme','padding-top','30',0,''),(611959,192574,'1683125852.38820','new_theme','padding-left','30',0,''),(611960,192574,'1683125852.38820','new_theme','padding-right','30',0,''),(611961,192574,'1683125852.38820','new_theme','padding-bottom','23',0,''),(611962,192574,'1683125852.38820','new_theme','margin-bottom','20',0,''),(611963,192574,'1683125852.38820','new_theme','background-color','$content-bg-1',0,''),(611964,192574,'1683125852.38820','new_theme','style_class','hiding-box',0,''),(611965,192574,'1683125852.38820','new_theme','color','$content-color-1',0,''),(611966,192575,'1683125852.390244','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(611967,192576,'1683125852.391810','new_theme','block_type','2',0,''),(611968,192576,'1683125852.391810','new_theme','schema','2-2',0,'8451'),(611969,192577,'1683125852.393320','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(611970,192578,'1683125852.394747','new_theme','padding-right','20',0,''),(611971,192578,'1683125852.394747','new_theme','padding-right','0',0,'8451'),(611972,192578,'1683125852.394747','new_theme','padding-bottom','20',0,'8451'),(611973,192578,'1683125852.394747','new_theme','address_in','popup',0,''),(611974,192579,'1683125852.395767','new_theme','block_type','1',0,''),(611975,192579,'1683125852.395767','new_theme','padding-left','20',0,''),(611976,192579,'1683125852.395767','new_theme','padding-left','0',0,'8451'),(611977,192581,'1683125852.398588','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(611978,192582,'1683125852.400291','new_theme','block_type','1',0,''),(611979,192582,'1683125852.400291','new_theme','padding-top','30',0,''),(611980,192582,'1683125852.400291','new_theme','padding-left','30',0,''),(611981,192582,'1683125852.400291','new_theme','padding-right','30',0,''),(611982,192582,'1683125852.400291','new_theme','padding-bottom','30',0,''),(611983,192582,'1683125852.400291','new_theme','margin-bottom','20',0,''),(611984,192582,'1683125852.400291','new_theme','background-color','$content-bg-1',0,''),(611985,192582,'1683125852.400291','new_theme','color','$content-color-1',0,''),(611986,192585,'1683125852.403563','new_theme','block_type','1',0,''),(611987,192585,'1683125852.403563','new_theme','padding-top','20',0,''),(611988,192585,'1683125852.403563','new_theme','padding-left','20',0,''),(611989,192585,'1683125852.403563','new_theme','padding-right','20',0,''),(611990,192585,'1683125852.403563','new_theme','padding-bottom','20',0,''),(611991,192585,'1683125852.403563','new_theme','background-color','$content-bg-1',0,''),(611992,192585,'1683125852.403563','new_theme','style_class','order-summary',0,''),(611993,192585,'1683125852.403563','new_theme','color','$content-color-1',0,''),(611994,192586,'1683125852.405625','new_theme','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(611995,192586,'1683125852.405625','new_theme','text-align','center',0,''),(611996,192586,'1683125852.405625','new_theme','font-size','14',0,''),(611997,192586,'1683125852.405625','new_theme','color','$fade-color-1',0,''),(611998,192586,'1683125852.405625','new_theme','padding-top','10',0,''),(611999,192587,'1683125852.407666','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(612000,192588,'1683125852.40885','new_theme','hide_page','1',0,''),(612001,192588,'1683125852.40885','new_theme','hide_continue_button','1',0,''),(612002,192589,'1683125852.409688','new_theme','margin-bottom','10',0,''),(612003,192592,'73542','new_theme','block_type','1',0,''),(612004,192593,'73543','new_theme','margin-top','20',0,''),(612005,192594,'73544','new_theme','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(612006,192595,'73545','new_theme','link','products',0,''),(612007,192595,'73545','new_theme','margin-top','-33',0,''),(612008,192595,'73545','new_theme','float','right',0,''),(612009,192596,'73546','new_theme','block_type','2',0,''),(612010,192596,'73546','new_theme','margin-bottom','20',0,''),(612011,192596,'73546','new_theme','schema','2-2',0,'8444'),(612012,192597,'73547','new_theme','block_type','1',0,''),(612013,192597,'73547','new_theme','padding-right','20',0,''),(612014,192597,'73547','new_theme','padding-right','0',0,'8444'),(612015,192598,'73548','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612016,192598,'73548','new_theme','clear','none',0,''),(612017,192600,'73550','new_theme','padding-left','20',0,''),(612018,192600,'73550','new_theme','block_type','1',0,''),(612019,192600,'73550','new_theme','padding-left','0',0,'8444'),(612020,192602,'73552','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612021,192602,'73552','new_theme','clear','none',0,''),(612022,192603,'73553','new_theme','text-align','right',0,''),(612023,192603,'73553','new_theme','margin-bottom','20',0,''),(612024,192603,'73553','new_theme','margin-top','20',0,''),(612025,192604,'73554','new_theme','block_type','2',0,''),(612026,192604,'73554','new_theme','margin-bottom','20',0,''),(612027,192604,'73554','new_theme','schema','2-2',0,'8444'),(612028,192605,'73555','new_theme','block_type','1',0,''),(612029,192605,'73555','new_theme','padding-right','20',0,''),(612030,192605,'73555','new_theme','padding-right','0',0,'8444'),(612031,192607,'73557','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(612032,192607,'73557','new_theme','clear','none',0,''),(612033,192608,'73558','new_theme','block_type','1',0,''),(612034,192608,'73558','new_theme','padding-left','20',0,''),(612035,192608,'73558','new_theme','padding-left','0',0,'8444'),(612036,192609,'73559','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612037,192609,'73559','new_theme','clear','none',0,''),(612038,192611,'73561','new_theme','margin-bottom','20',0,''),(612039,192611,'73561','new_theme','text-align','right',0,''),(612040,192613,'73576','new_theme','block_type','1',0,''),(612041,192614,'73577','new_theme','text-align','right',0,''),(612042,192614,'73577','new_theme','margin-bottom','20',0,''),(612043,192615,'73578','new_theme','block_type','2',0,''),(612044,192615,'73578','new_theme','margin-bottom','20',0,''),(612045,192615,'73578','new_theme','schema','2-2',0,'8444'),(612046,192616,'73579','new_theme','block_type','1',0,''),(612047,192616,'73579','new_theme','padding-right','20',0,''),(612048,192616,'73579','new_theme','padding-right','0',0,'8444'),(612049,192617,'73580','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612050,192617,'73580','new_theme','clear','none',0,''),(612051,192619,'73582','new_theme','block_type','1',0,''),(612052,192619,'73582','new_theme','padding-left','20',0,''),(612053,192619,'73582','new_theme','padding-left','0',0,'8444'),(612054,192620,'73583','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612055,192620,'73583','new_theme','clear','none',0,''),(612056,192622,'73585','new_theme','margin-bottom','20',0,''),(612057,192622,'73585','new_theme','text-align','right',0,''),(612058,192625,'73588','new_theme','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(612059,192626,'73563','new_theme','block_type','1',0,''),(612060,192627,'73564','new_theme','margin-bottom','20',0,''),(612061,192628,'73565','new_theme','margin-bottom','20',0,''),(612062,192628,'73565','new_theme','text-align','right',0,''),(612063,192629,'73566','new_theme','text-align','right',0,''),(612064,192629,'73566','new_theme','margin-bottom','20',0,''),(612065,192630,'73567','new_theme','block_type','2',0,''),(612066,192630,'73567','new_theme','margin-bottom','20',0,''),(612067,192630,'73567','new_theme','schema','2-2',0,'8444'),(612068,192631,'73568','new_theme','block_type','1',0,''),(612069,192631,'73568','new_theme','padding-right','20',0,''),(612070,192631,'73568','new_theme','padding-right','0',0,'8444'),(612071,192633,'73570','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612072,192633,'73570','new_theme','clear','none',0,''),(612073,192634,'73571','new_theme','block_type','1',0,''),(612074,192634,'73571','new_theme','padding-left','20',0,''),(612075,192634,'73571','new_theme','padding-left','0',0,'8444'),(612076,192636,'73573','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612077,192636,'73573','new_theme','clear','none',0,''),(612078,192637,'73574','new_theme','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(612079,192638,'73575','new_theme','margin-bottom','20',0,''),(612080,192639,'73589','new_theme','block_type','1',0,''),(612081,192640,'73590','new_theme','block_type','2',0,''),(612082,192640,'73590','new_theme','margin-bottom','20',0,''),(612083,192640,'73590','new_theme','schema','2-2',0,'8444'),(612084,192641,'73591','new_theme','block_type','1',0,''),(612085,192641,'73591','new_theme','padding-right','20',0,''),(612086,192641,'73591','new_theme','padding-right','0',0,'8444'),(612087,192643,'73593','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(612088,192643,'73593','new_theme','clear','none',0,''),(612089,192644,'73594','new_theme','block_type','1',0,''),(612090,192644,'73594','new_theme','padding-left','20',0,''),(612091,192644,'73594','new_theme','padding-left','0',0,'8444'),(612092,192646,'73596','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612093,192646,'73596','new_theme','clear','none',0,''),(612094,192647,'73597','new_theme','margin-bottom','20',0,''),(612095,192648,'73598','new_theme','margin-bottom','20',0,''),(612096,192649,'73599','new_theme','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(612097,192650,'73600','new_theme','link','products',0,''),(612098,192650,'73600','new_theme','margin-top','-33',0,''),(612099,192650,'73600','new_theme','float','right',0,''),(612100,192651,'73601','new_theme','text-align','right',0,''),(612101,192651,'73601','new_theme','margin-bottom','20',0,''),(612102,192652,'73602','new_theme','margin-bottom','20',0,''),(612103,192652,'73602','new_theme','text-align','right',0,''),(612104,192653,'73603','new_theme','block_type','2',0,''),(612105,192653,'73603','new_theme','margin-bottom','20',0,''),(612106,192653,'73603','new_theme','schema','2-2',0,'8444'),(612107,192654,'73604','new_theme','block_type','1',0,''),(612108,192654,'73604','new_theme','padding-right','20',0,''),(612109,192654,'73604','new_theme','padding-right','0',0,'8444'),(612110,192655,'73605','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612111,192655,'73605','new_theme','clear','none',0,''),(612112,192657,'73607','new_theme','padding-left','20',0,''),(612113,192657,'73607','new_theme','block_type','1',0,''),(612114,192657,'73607','new_theme','padding-left','0',0,'8444'),(612115,192658,'73608','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612116,192658,'73608','new_theme','clear','none',0,''),(612117,192660,'73610','new_theme','text','##TEXT_CONFIRMATION##',0,''),(612118,192661,'73611','new_theme','text','##TEXT_CONFIRMATION##',0,''),(612119,192662,'73613','new_theme','text','##TEXT_CONFIRMATION##',0,''),(612120,192663,'73612','new_theme','text','##TEXT_CONFIRMATION##',0,''),(612121,192664,'73614','new_theme','text','##TEXT_CONFIRMATION##',0,''),(612122,192665,'73615','new_theme','text','##TEXT_CONFIRMATION##',0,''),(612123,192666,'73616','new_theme','block_type','2',0,''),(612124,192667,'73617','new_theme','block_type','1',0,''),(612125,192667,'73617','new_theme','padding-right','20',0,''),(612126,192668,'73618','new_theme','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(612127,192670,'73620','new_theme','block_type','1',0,''),(612128,192670,'73620','new_theme','padding-left','20',0,''),(612129,192670,'73620','new_theme','padding-left','0',0,'8451'),(612130,192671,'73621','new_theme','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612131,192673,'73623','new_theme','block_type','4',0,''),(612132,192673,'73623','new_theme','schema','4-2',0,'8472'),(612133,192673,'73623','new_theme','padding-top','20',0,''),(612134,192674,'73624','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612135,192674,'73624','new_theme','text-align','right',0,''),(612136,192674,'73624','new_theme','padding-top','10',0,''),(612137,192674,'73624','new_theme','font_size_measure','em',0,''),(612138,192674,'73624','new_theme','font-size','1.2',0,''),(612139,192675,'73625','new_theme','text-align','right',0,''),(612140,192676,'73626','new_theme','block_type','2',0,''),(612141,192677,'73627','new_theme','block_type','1',0,''),(612142,192677,'73627','new_theme','padding-right','20',0,''),(612143,192677,'73627','new_theme','padding-right','0',0,'8451'),(612144,192678,'73628','new_theme','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(612145,192680,'73630','new_theme','block_type','1',0,''),(612146,192680,'73630','new_theme','padding-right','0',0,'8451'),(612147,192680,'73630','new_theme','padding-left','20',0,''),(612148,192683,'73633','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612149,192685,'73635','new_theme','block_type','2',0,''),(612150,192686,'73636','new_theme','block_type','1',0,''),(612151,192686,'73636','new_theme','padding-right','20',0,''),(612152,192688,'73638','new_theme','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(612153,192689,'73639','new_theme','block_type','1',0,''),(612154,192689,'73639','new_theme','padding-left','20',0,''),(612155,192689,'73639','new_theme','padding-left','0',0,'8451'),(612156,192690,'73640','new_theme','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612157,192692,'73642','new_theme','block_type','4',0,''),(612158,192692,'73642','new_theme','schema','4-2',0,'8472'),(612159,192693,'73643','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612160,192693,'73643','new_theme','text-align','right',0,''),(612161,192693,'73643','new_theme','padding-top','10',0,''),(612162,192693,'73643','new_theme','font_size_measure','em',0,''),(612163,192693,'73643','new_theme','font-size','1.2',0,''),(612164,192694,'73644','new_theme','text-align','right',0,''),(612165,192695,'73645','new_theme','block_type','2',0,''),(612166,192696,'73646','new_theme','block_type','1',0,''),(612167,192696,'73646','new_theme','padding-right','20',0,''),(612168,192696,'73646','new_theme','padding-right','0',0,'8451'),(612169,192698,'73648','new_theme','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(612170,192699,'73649','new_theme','block_type','1',0,''),(612171,192699,'73649','new_theme','padding-right','0',0,'8451'),(612172,192699,'73649','new_theme','padding-left','20',0,''),(612173,192701,'73651','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612174,192704,'73654','new_theme','block_type','4',0,''),(612175,192704,'73654','new_theme','schema','4-2',0,'8472'),(612176,192705,'73655','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612177,192705,'73655','new_theme','text-align','right',0,''),(612178,192705,'73655','new_theme','padding-top','10',0,''),(612179,192705,'73655','new_theme','font_size_measure','em',0,''),(612180,192705,'73655','new_theme','font-size','1.2',0,''),(612181,192706,'73656','new_theme','text-align','right',0,''),(612182,192707,'73657','new_theme','block_type','2',0,''),(612183,192708,'73658','new_theme','block_type','1',0,''),(612184,192708,'73658','new_theme','padding-right','20',0,''),(612185,192710,'73660','new_theme','block_type','1',0,''),(612186,192710,'73660','new_theme','padding-left','20',0,''),(612187,192710,'73660','new_theme','padding-left','0',0,'8451'),(612188,192711,'73661','new_theme','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612189,192713,'73663','new_theme','block_type','4',0,''),(612190,192713,'73663','new_theme','schema','4-2',0,'8472'),(612191,192714,'73664','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612192,192714,'73664','new_theme','text-align','right',0,''),(612193,192714,'73664','new_theme','padding-top','10',0,''),(612194,192714,'73664','new_theme','font_size_measure','em',0,''),(612195,192714,'73664','new_theme','font-size','1.2',0,''),(612196,192715,'73665','new_theme','text-align','right',0,''),(612197,192716,'73666','new_theme','block_type','2',0,''),(612198,192717,'73667','new_theme','block_type','1',0,''),(612199,192717,'73667','new_theme','padding-right','20',0,''),(612200,192719,'73669','new_theme','block_type','1',0,''),(612201,192719,'73669','new_theme','padding-left','20',0,''),(612202,192719,'73669','new_theme','padding-left','0',0,'8451'),(612203,192721,'73671','new_theme','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612204,192722,'73672','new_theme','text','##DELIVERY_DETAILS##',0,''),(612205,192723,'73673','new_theme','text','##DELIVERY_DETAILS##',0,''),(612206,192724,'73675','new_theme','text','##CONTACT_INFORMATION##',0,''),(612207,192725,'73674','new_theme','text','##CONTACT_INFORMATION##',0,''),(612208,192726,'73676','new_theme','text','##DELIVERY_DETAILS##',0,''),(612209,192727,'73677','new_theme','text','##DELIVERY_DETAILS##',0,''),(612210,192728,'73678','new_theme','block_type','1',0,''),(612211,192728,'73678','new_theme','background-color','$content-bg-2',0,''),(612212,192728,'73678','new_theme','padding-top','30',0,''),(612213,192728,'73678','new_theme','padding-bottom','30',0,''),(612214,192729,'73679','new_theme','block_type','4',0,''),(612215,192729,'73679','new_theme','schema','4-2',0,'8451'),(612216,192730,'73680','new_theme','block_type','1',0,''),(612217,192730,'73680','new_theme','padding-right','40',0,''),(612218,192730,'73680','new_theme','padding-right','0',0,'8451'),(612219,192731,'73682','new_theme','block_type','1',0,''),(612220,192731,'73682','new_theme','background-color','$content-bg-1',0,''),(612221,192731,'73682','new_theme','padding-top','30',0,''),(612222,192731,'73682','new_theme','padding-left','30',0,''),(612223,192731,'73682','new_theme','padding-right','30',0,''),(612224,192731,'73682','new_theme','padding-bottom','30',0,''),(612225,192731,'73682','new_theme','margin-bottom','20',0,''),(612226,192731,'73682','new_theme','style_class','hiding-box',0,''),(612227,192732,'73683','new_theme','margin-bottom','20',0,''),(612228,192733,'73684','new_theme','padding-top','10',0,''),(612229,192733,'73684','new_theme','padding-left','20',0,''),(612230,192733,'73684','new_theme','padding-right','20',0,''),(612231,192733,'73684','new_theme','margin-top','20',0,''),(612232,192733,'73684','new_theme','background-color','$content-bg-2',0,''),(612233,192733,'73684','new_theme','padding-bottom','8',0,''),(612234,192734,'73685','new_theme','block_type','1',0,''),(612235,192734,'73685','new_theme','background-color','$content-bg-1',0,''),(612236,192734,'73685','new_theme','padding-top','30',0,''),(612237,192734,'73685','new_theme','padding-left','30',0,''),(612238,192734,'73685','new_theme','padding-right','30',0,''),(612239,192734,'73685','new_theme','padding-bottom','14',0,''),(612240,192734,'73685','new_theme','margin-bottom','20',0,''),(612241,192734,'73685','new_theme','style_class','hiding-box closeable-box',0,''),(612242,192735,'73686','new_theme','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(612243,192735,'73686','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612244,192736,'73687','new_theme','style_class','closeable-content',0,''),(612245,192736,'73687','new_theme','padding-bottom','20',0,''),(612246,192737,'73688','new_theme','background-color','$content-bg-1',0,''),(612247,192737,'73688','new_theme','block_type','1',0,''),(612248,192737,'73688','new_theme','padding-top','30',0,''),(612249,192737,'73688','new_theme','padding-left','30',0,''),(612250,192737,'73688','new_theme','padding-right','30',0,''),(612251,192737,'73688','new_theme','padding-bottom','30',0,''),(612252,192737,'73688','new_theme','margin-bottom','20',0,''),(612253,192737,'73688','new_theme','style_class','hiding-box',0,''),(612254,192738,'73689','new_theme','block_type','1',0,''),(612255,192738,'73689','new_theme','content','\\_',0,'3'),(612256,192738,'73689','new_theme','border-top-width','1',0,'3'),(612257,192738,'73689','new_theme','border-top-color','$content-border-1',0,'3'),(612258,192738,'73689','new_theme','display','block',0,'3'),(612259,192738,'73689','new_theme','position','absolute',0,'3'),(612260,192738,'73689','new_theme','top','19',0,'3'),(612261,192738,'73689','new_theme','left','0',0,'3'),(612262,192738,'73689','new_theme','right','0',0,'3'),(612263,192738,'73689','new_theme','margin-top','-2',0,'3'),(612264,192738,'73689','new_theme','position','relative',0,''),(612265,192739,'73690','new_theme','box_align','2',0,''),(612266,192739,'73690','new_theme','margin-bottom','10',0,''),(612267,192739,'73690','new_theme','background-color','$content-bg-1',0,''),(612268,192739,'73690','new_theme','position','relative',0,''),(612269,192740,'73691','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(612270,192741,'73692','new_theme','block_type','2',0,''),(612271,192741,'73692','new_theme','schema','2-2',0,'8451'),(612272,192742,'73693','new_theme','block_type','1',0,''),(612273,192742,'73693','new_theme','padding-right','20',0,''),(612274,192742,'73693','new_theme','padding-left','0',0,'8451'),(612275,192742,'73693','new_theme','margin-bottom','20',0,'8451'),(612276,192745,'73696','new_theme','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(612277,192746,'73697','new_theme','block_type','1',0,''),(612278,192746,'73697','new_theme','padding-left','20',0,''),(612279,192746,'73697','new_theme','padding-left','0',0,'8451'),(612280,192747,'73698','new_theme','border-top-width','1',0,''),(612281,192747,'73698','new_theme','border-top-color','$content-border-1',0,''),(612282,192747,'73698','new_theme','padding-top','13',0,''),(612283,192747,'73698','new_theme','padding-bottom','10',0,''),(612284,192748,'73699','new_theme','background-color','$content-bg-2',0,''),(612285,192748,'73699','new_theme','padding-top','10',0,''),(612286,192748,'73699','new_theme','padding-left','10',0,''),(612287,192748,'73699','new_theme','padding-right','10',0,''),(612288,192748,'73699','new_theme','padding-bottom','10',0,''),(612289,192748,'73699','new_theme','margin-top','10',0,''),(612290,192749,'73700','new_theme','block_type','1',0,''),(612291,192749,'73700','new_theme','padding-top','20',0,''),(612292,192749,'73700','new_theme','padding-left','20',0,''),(612293,192749,'73700','new_theme','padding-right','20',0,''),(612294,192749,'73700','new_theme','padding-bottom','20',0,''),(612295,192749,'73700','new_theme','background-color','$content-bg-1',0,''),(612296,192749,'73700','new_theme','style_class','order-summary',0,''),(612297,192750,'73701','new_theme','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(612298,192750,'73701','new_theme','text-align','center',0,''),(612299,192750,'73701','new_theme','font-size','14',0,''),(612300,192750,'73701','new_theme','color','$fade-color-1',0,''),(612301,192750,'73701','new_theme','padding-top','10',0,''),(612302,192752,'115999','new_theme','hide_continue_button','1',0,''),(612303,192753,'73703','new_theme','block_type','1',0,''),(612304,192753,'73703','new_theme','background-color','$content-bg-2',0,''),(612305,192753,'73703','new_theme','padding-top','30',0,''),(612306,192753,'73703','new_theme','padding-bottom','30',0,''),(612307,192753,'73703','new_theme','color','$content-color-2',0,''),(612308,192754,'73704','new_theme','block_type','4',0,''),(612309,192755,'73705','new_theme','block_type','1',0,''),(612310,192755,'73705','new_theme','padding-right','40',0,''),(612311,192756,'73706','new_theme','block_type','1',0,''),(612312,192756,'73706','new_theme','background-color','$content-bg-1',0,''),(612313,192756,'73706','new_theme','padding-top','30',0,''),(612314,192756,'73706','new_theme','padding-left','30',0,''),(612315,192756,'73706','new_theme','padding-right','30',0,''),(612316,192756,'73706','new_theme','padding-bottom','30',0,''),(612317,192756,'73706','new_theme','margin-bottom','20',0,''),(612318,192756,'73706','new_theme','style_class','hiding-box',0,''),(612319,192756,'73706','new_theme','color','$content-color-1',0,''),(612320,192757,'73707','new_theme','padding-top','10',0,''),(612321,192757,'73707','new_theme','padding-left','20',0,''),(612322,192757,'73707','new_theme','padding-right','20',0,''),(612323,192757,'73707','new_theme','margin-top','20',0,''),(612324,192757,'73707','new_theme','background-color','$content-bg-2',0,''),(612325,192757,'73707','new_theme','padding-bottom','8',0,''),(612326,192757,'73707','new_theme','color','$content-color-2',0,''),(612327,192758,'73708','new_theme','margin-bottom','20',0,''),(612328,192759,'73709','new_theme','block_type','1',0,''),(612329,192759,'73709','new_theme','padding-top','30',0,''),(612330,192759,'73709','new_theme','padding-left','30',0,''),(612331,192759,'73709','new_theme','padding-right','30',0,''),(612332,192759,'73709','new_theme','padding-bottom','23',0,''),(612333,192759,'73709','new_theme','margin-bottom','20',0,''),(612334,192759,'73709','new_theme','background-color','$content-bg-1',0,''),(612335,192759,'73709','new_theme','style_class','hiding-box',0,''),(612336,192759,'73709','new_theme','color','$content-color-1',0,''),(612337,192760,'73710','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(612338,192761,'73711','new_theme','block_type','2',0,''),(612339,192762,'73712','new_theme','padding-right','20',0,''),(612340,192763,'73713','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612341,192764,'73714','new_theme','block_type','1',0,''),(612342,192764,'73714','new_theme','padding-left','20',0,''),(612343,192765,'73715','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612344,192767,'73717','new_theme','block_type','1',0,''),(612345,192767,'73717','new_theme','padding-top','30',0,''),(612346,192767,'73717','new_theme','padding-left','30',0,''),(612347,192767,'73717','new_theme','padding-right','30',0,''),(612348,192767,'73717','new_theme','padding-bottom','14',0,''),(612349,192767,'73717','new_theme','margin-bottom','20',0,''),(612350,192767,'73717','new_theme','background-color','$content-bg-1',0,''),(612351,192767,'73717','new_theme','style_class','hiding-box closeable-box',0,''),(612352,192767,'73717','new_theme','color','$content-color-1',0,''),(612353,192768,'73718','new_theme','block_type','2',0,''),(612354,192768,'73718','new_theme','style_class','closeable-content',0,''),(612355,192769,'73719','new_theme','padding-right','20',0,''),(612356,192769,'73719','new_theme','padding-bottom','20',0,''),(612357,192770,'73720','new_theme','padding-left','20',0,''),(612358,192770,'73720','new_theme','padding-bottom','20',0,''),(612359,192771,'73721','new_theme','padding-left','20',0,''),(612360,192771,'73721','new_theme','padding-bottom','20',0,''),(612361,192772,'73722','new_theme','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(612362,192772,'73722','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612363,192773,'73723','new_theme','block_type','1',0,''),(612364,192773,'73723','new_theme','background-color','$content-bg-1',0,''),(612365,192773,'73723','new_theme','padding-top','30',0,''),(612366,192773,'73723','new_theme','padding-left','30',0,''),(612367,192773,'73723','new_theme','padding-right','30',0,''),(612368,192773,'73723','new_theme','padding-bottom','14',0,''),(612369,192773,'73723','new_theme','margin-bottom','20',0,''),(612370,192773,'73723','new_theme','style_class','hiding-box closeable-box',0,''),(612371,192773,'73723','new_theme','color','$content-color-1',0,''),(612372,192774,'73724','new_theme','style_class','closeable-content',0,''),(612373,192774,'73724','new_theme','padding-bottom','20',0,''),(612374,192775,'73725','new_theme','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(612375,192775,'73725','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612376,192776,'73726','new_theme','block_type','1',0,''),(612377,192776,'73726','new_theme','padding-top','20',0,''),(612378,192776,'73726','new_theme','padding-left','20',0,''),(612379,192776,'73726','new_theme','padding-right','20',0,''),(612380,192776,'73726','new_theme','padding-bottom','20',0,''),(612381,192776,'73726','new_theme','background-color','$content-bg-1',0,''),(612382,192776,'73726','new_theme','style_class','order-summary hiding-box',0,''),(612383,192776,'73726','new_theme','color','$content-color-1',0,''),(612384,192777,'73727','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(612385,192778,'73728','new_theme','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(612386,192778,'73728','new_theme','text-align','center',0,''),(612387,192778,'73728','new_theme','font-size','14',0,''),(612388,192778,'73728','new_theme','color','$fade-color-1',0,''),(612389,192778,'73728','new_theme','padding-top','10',0,''),(612390,192779,'73729','new_theme','margin-bottom','10',0,''),(612391,192781,'73731','new_theme','hide_page','1',0,''),(612392,192781,'73731','new_theme','hide_continue_button','1',0,''),(612393,192782,'73732','new_theme','block_type','1',0,''),(612394,192784,'73734','new_theme','block_type','4',0,''),(612395,192784,'73734','new_theme','schema','4-2',0,'8472'),(612396,192785,'73735','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612397,192785,'73735','new_theme','text-align','right',0,''),(612398,192785,'73735','new_theme','padding-top','10',0,''),(612399,192785,'73735','new_theme','font_size_measure','em',0,''),(612400,192785,'73735','new_theme','font-size','1.2',0,''),(612401,192786,'73736','new_theme','text-align','right',0,''),(612402,192787,'73737','new_theme','block_type','2',0,''),(612403,192787,'73737','new_theme','schema','2-2',0,'8451'),(612404,192788,'73738','new_theme','block_type','1',0,''),(612405,192788,'73738','new_theme','padding-right','20',0,''),(612406,192788,'73738','new_theme','padding-right','0',0,'8451'),(612407,192790,'73740','new_theme','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(612408,192791,'73741','new_theme','block_type','1',0,''),(612409,192791,'73741','new_theme','padding-left','20',0,''),(612410,192791,'73741','new_theme','padding-left','0',0,'8451'),(612411,192793,'73743','new_theme','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612412,192794,'73744','new_theme','block_type','2',0,''),(612413,192794,'73744','new_theme','schema','2-2',0,'8451'),(612414,192795,'73745','new_theme','block_type','1',0,''),(612415,192795,'73745','new_theme','padding-right','20',0,''),(612416,192795,'73745','new_theme','padding-right','0',0,'8451'),(612417,192796,'73746','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612418,192798,'73748','new_theme','block_type','1',0,''),(612419,192798,'73748','new_theme','padding-left','20',0,''),(612420,192798,'73748','new_theme','padding-left','0',0,'8451'),(612421,192803,'73753','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612422,192804,'73754','new_theme','margin-bottom','20',0,''),(612423,192805,'73755','new_theme','block_type','1',0,''),(612424,192805,'73755','new_theme','background-color','$content-bg-2',0,''),(612425,192805,'73755','new_theme','padding-top','30',0,''),(612426,192805,'73755','new_theme','padding-bottom','30',0,''),(612427,192806,'73756','new_theme','block_type','4',0,''),(612428,192806,'73756','new_theme','schema','4-2',0,'8451'),(612429,192807,'73757','new_theme','block_type','1',0,''),(612430,192807,'73757','new_theme','padding-right','40',0,''),(612431,192807,'73757','new_theme','padding-right','0',0,'8451'),(612432,192808,'73758','new_theme','background-color','$content-bg-1',0,''),(612433,192808,'73758','new_theme','padding-top','30',0,''),(612434,192808,'73758','new_theme','padding-left','30',0,''),(612435,192808,'73758','new_theme','padding-right','30',0,''),(612436,192808,'73758','new_theme','padding-bottom','30',0,''),(612437,192808,'73758','new_theme','margin-bottom','20',0,''),(612438,192809,'73759','new_theme','block_type','1',0,''),(612439,192809,'73759','new_theme','background-color','$content-bg-1',0,''),(612440,192809,'73759','new_theme','padding-top','30',0,''),(612441,192809,'73759','new_theme','padding-left','30',0,''),(612442,192809,'73759','new_theme','padding-right','30',0,''),(612443,192809,'73759','new_theme','padding-bottom','14',0,''),(612444,192809,'73759','new_theme','margin-bottom','20',0,''),(612445,192809,'73759','new_theme','style_class','hiding-box closeable-box',0,''),(612446,192810,'73760','new_theme','style_class','closeable-content',0,''),(612447,192810,'73760','new_theme','padding-bottom','20',0,''),(612448,192811,'73761','new_theme','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(612449,192811,'73761','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612450,192812,'73762','new_theme','block_type','1',0,''),(612451,192812,'73762','new_theme','background-color','$content-bg-1',0,''),(612452,192812,'73762','new_theme','padding-top','30',0,''),(612453,192812,'73762','new_theme','padding-left','30',0,''),(612454,192812,'73762','new_theme','padding-right','30',0,''),(612455,192812,'73762','new_theme','padding-bottom','30',0,''),(612456,192812,'73762','new_theme','margin-bottom','20',0,''),(612457,192812,'73762','new_theme','style_class','hiding-box',0,''),(612458,192813,'73763','new_theme','padding-top','10',0,''),(612459,192813,'73763','new_theme','padding-left','20',0,''),(612460,192813,'73763','new_theme','padding-right','20',0,''),(612461,192813,'73763','new_theme','margin-top','20',0,''),(612462,192813,'73763','new_theme','background-color','$content-bg-2',0,''),(612463,192813,'73763','new_theme','padding-bottom','8',0,''),(612464,192814,'73764','new_theme','margin-bottom','20',0,''),(612465,192815,'73765','new_theme','block_type','1',0,''),(612466,192815,'73765','new_theme','padding-top','30',0,''),(612467,192815,'73765','new_theme','padding-left','30',0,''),(612468,192815,'73765','new_theme','padding-right','30',0,''),(612469,192815,'73765','new_theme','padding-bottom','23',0,''),(612470,192815,'73765','new_theme','margin-bottom','20',0,''),(612471,192815,'73765','new_theme','background-color','$content-bg-1',0,''),(612472,192815,'73765','new_theme','style_class','hiding-box',0,''),(612473,192816,'73766','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(612474,192817,'73767','new_theme','block_type','2',0,''),(612475,192817,'73767','new_theme','schema','2-2',0,'8451'),(612476,192818,'73768','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612477,192819,'73769','new_theme','padding-right','20',0,''),(612478,192819,'73769','new_theme','padding-right','0',0,'8451'),(612479,192819,'73769','new_theme','padding-bottom','20',0,'8451'),(612480,192820,'73770','new_theme','block_type','1',0,''),(612481,192820,'73770','new_theme','padding-left','20',0,''),(612482,192820,'73770','new_theme','padding-left','0',0,'8451'),(612483,192822,'73772','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612484,192823,'73773','new_theme','block_type','1',0,''),(612485,192823,'73773','new_theme','padding-top','20',0,''),(612486,192823,'73773','new_theme','padding-left','20',0,''),(612487,192823,'73773','new_theme','padding-right','20',0,''),(612488,192823,'73773','new_theme','padding-bottom','20',0,''),(612489,192823,'73773','new_theme','background-color','$content-bg-1',0,''),(612490,192823,'73773','new_theme','style_class','order-summary',0,''),(612491,192825,'73775','new_theme','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(612492,192825,'73775','new_theme','text-align','center',0,''),(612493,192825,'73775','new_theme','font-size','14',0,''),(612494,192825,'73775','new_theme','color','$fade-color-1',0,''),(612495,192825,'73775','new_theme','padding-top','10',0,''),(612496,192826,'73776','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(612497,192827,'73777','new_theme','margin-bottom','10',0,''),(612498,192828,'73778','new_theme','block_type','2',0,''),(612499,192829,'73779','new_theme','block_type','1',0,''),(612500,192829,'73779','new_theme','padding-left','0',0,'8451'),(612501,192829,'73779','new_theme','padding-right','20',0,''),(612502,192831,'73781','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612503,192832,'73782','new_theme','block_type','1',0,''),(612504,192832,'73782','new_theme','padding-left','20',0,''),(612505,192832,'73782','new_theme','padding-left','0',0,'8451'),(612506,192837,'73787','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612507,192838,'73788','new_theme','block_type','4',0,''),(612508,192838,'73788','new_theme','schema','4-2',0,'8472'),(612509,192838,'73788','new_theme','padding-top','20',0,''),(612510,192839,'73789','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612511,192839,'73789','new_theme','text-align','right',0,''),(612512,192839,'73789','new_theme','padding-top','10',0,''),(612513,192839,'73789','new_theme','font_size_measure','em',0,''),(612514,192839,'73789','new_theme','font-size','1.2',0,''),(612515,192840,'73790','new_theme','text-align','right',0,''),(612516,192841,'73791','new_theme','block_type','2',0,''),(612517,192842,'73792','new_theme','block_type','1',0,''),(612518,192842,'73792','new_theme','padding-left','0',0,'8451'),(612519,192842,'73792','new_theme','padding-right','20',0,''),(612520,192844,'73794','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612521,192845,'73795','new_theme','block_type','1',0,''),(612522,192845,'73795','new_theme','padding-left','20',0,''),(612523,192845,'73795','new_theme','padding-left','0',0,'8451'),(612524,192847,'73797','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612525,192851,'73801','new_theme','block_type','4',0,''),(612526,192851,'73801','new_theme','schema','4-2',0,'8472'),(612527,192852,'73802','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612528,192852,'73802','new_theme','text-align','right',0,''),(612529,192852,'73802','new_theme','padding-top','10',0,''),(612530,192852,'73802','new_theme','font_size_measure','em',0,''),(612531,192852,'73802','new_theme','font-size','1.2',0,''),(612532,192853,'73803','new_theme','text-align','right',0,''),(612533,192854,'73804','new_theme','block_type','4',0,''),(612534,192854,'73804','new_theme','schema','4-2',0,'8472'),(612535,192855,'73805','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612536,192855,'73805','new_theme','text-align','right',0,''),(612537,192855,'73805','new_theme','padding-top','10',0,''),(612538,192855,'73805','new_theme','font_size_measure','em',0,''),(612539,192855,'73805','new_theme','font-size','1.2',0,''),(612540,192856,'73806','new_theme','text-align','right',0,''),(612541,192857,'73807','new_theme','block_type','2',0,''),(612542,192858,'73808','new_theme','block_type','1',0,''),(612543,192858,'73808','new_theme','padding-left','0',0,'8451'),(612544,192858,'73808','new_theme','padding-right','20',0,''),(612545,192859,'73809','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612546,192861,'73811','new_theme','block_type','1',0,''),(612547,192861,'73811','new_theme','padding-left','20',0,''),(612548,192861,'73811','new_theme','padding-left','0',0,'8451'),(612549,192866,'73816','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612550,192867,'73817','new_theme','block_type','4',0,''),(612551,192867,'73817','new_theme','schema','4-2',0,'8472'),(612552,192868,'73818','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612553,192868,'73818','new_theme','text-align','right',0,''),(612554,192868,'73818','new_theme','padding-top','10',0,''),(612555,192868,'73818','new_theme','font_size_measure','em',0,''),(612556,192868,'73818','new_theme','font-size','1.2',0,''),(612557,192869,'73819','new_theme','text-align','right',0,''),(612558,192870,'73820','new_theme','block_type','2',0,''),(612559,192871,'73821','new_theme','block_type','1',0,''),(612560,192871,'73821','new_theme','padding-left','0',0,'8451'),(612561,192871,'73821','new_theme','padding-right','20',0,''),(612562,192873,'73823','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612563,192874,'73824','new_theme','block_type','1',0,''),(612564,192874,'73824','new_theme','padding-left','20',0,''),(612565,192874,'73824','new_theme','padding-left','0',0,'8451'),(612566,192878,'73828','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612567,192880,'73830','new_theme','text','##PAYMENT_DETAILS##',0,''),(612568,192881,'73831','new_theme','text','##PAYMENT_DETAILS##',0,''),(612569,192882,'73832','new_theme','text','##PAYMENT_DETAILS##',0,''),(612570,192883,'73833','new_theme','text','##PAYMENT_DETAILS##',0,''),(612571,192884,'73834','new_theme','text','##PAYMENT_DETAILS##',0,''),(612572,192885,'73835','new_theme','text','##PAYMENT_DETAILS##',0,''),(612573,192886,'73836','new_theme','block_type','1',0,''),(612574,192886,'73836','new_theme','background-color','$content-bg-2',0,''),(612575,192886,'73836','new_theme','padding-top','30',0,''),(612576,192886,'73836','new_theme','padding-bottom','30',0,''),(612577,192887,'73837','new_theme','block_type','4',0,''),(612578,192887,'73837','new_theme','schema','4-2',0,'8451'),(612579,192888,'73838','new_theme','block_type','1',0,''),(612580,192888,'73838','new_theme','padding-right','40',0,''),(612581,192888,'73838','new_theme','padding-right','0',0,'8451'),(612582,192889,'73839','new_theme','block_type','1',0,''),(612583,192889,'73839','new_theme','background-color','$content-bg-1',0,''),(612584,192889,'73839','new_theme','padding-top','30',0,''),(612585,192889,'73839','new_theme','padding-left','30',0,''),(612586,192889,'73839','new_theme','padding-right','30',0,''),(612587,192889,'73839','new_theme','padding-bottom','30',0,''),(612588,192889,'73839','new_theme','margin-bottom','20',0,''),(612589,192889,'73839','new_theme','style_class','hiding-box',0,''),(612590,192890,'73840','new_theme','padding-top','10',0,''),(612591,192890,'73840','new_theme','padding-left','20',0,''),(612592,192890,'73840','new_theme','padding-right','20',0,''),(612593,192890,'73840','new_theme','margin-top','20',0,''),(612594,192890,'73840','new_theme','background-color','$content-bg-2',0,''),(612595,192890,'73840','new_theme','padding-bottom','8',0,''),(612596,192891,'73841','new_theme','margin-bottom','20',0,''),(612597,192892,'73842','new_theme','background-color','$content-bg-1',0,''),(612598,192892,'73842','new_theme','block_type','1',0,''),(612599,192892,'73842','new_theme','padding-top','30',0,''),(612600,192892,'73842','new_theme','padding-left','30',0,''),(612601,192892,'73842','new_theme','padding-right','30',0,''),(612602,192892,'73842','new_theme','padding-bottom','30',0,''),(612603,192892,'73842','new_theme','margin-bottom','20',0,''),(612604,192892,'73842','new_theme','style_class','hiding-box',0,''),(612605,192893,'73843','new_theme','block_type','1',0,''),(612606,192893,'73843','new_theme','content','\\_',0,'3'),(612607,192893,'73843','new_theme','border-top-width','1',0,'3'),(612608,192893,'73843','new_theme','border-top-color','$content-border-1',0,'3'),(612609,192893,'73843','new_theme','display','block',0,'3'),(612610,192893,'73843','new_theme','position','absolute',0,'3'),(612611,192893,'73843','new_theme','top','19',0,'3'),(612612,192893,'73843','new_theme','left','0',0,'3'),(612613,192893,'73843','new_theme','right','0',0,'3'),(612614,192893,'73843','new_theme','margin-top','-2',0,'3'),(612615,192893,'73843','new_theme','position','relative',0,''),(612616,192894,'73844','new_theme','box_align','2',0,''),(612617,192894,'73844','new_theme','margin-bottom','10',0,''),(612618,192894,'73844','new_theme','background-color','$content-bg-1',0,''),(612619,192894,'73844','new_theme','position','relative',0,''),(612620,192895,'73845','new_theme','background-color','$content-bg-2',0,''),(612621,192895,'73845','new_theme','padding-top','10',0,''),(612622,192895,'73845','new_theme','padding-left','10',0,''),(612623,192895,'73845','new_theme','padding-right','10',0,''),(612624,192895,'73845','new_theme','padding-bottom','10',0,''),(612625,192895,'73845','new_theme','margin-top','10',0,''),(612626,192896,'73846','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(612627,192897,'73847','new_theme','block_type','2',0,''),(612628,192897,'73847','new_theme','schema','2-2',0,'8451'),(612629,192898,'73848','new_theme','block_type','1',0,''),(612630,192898,'73848','new_theme','padding-right','20',0,''),(612631,192898,'73848','new_theme','padding-left','0',0,'8451'),(612632,192898,'73848','new_theme','margin-bottom','20',0,'8451'),(612633,192901,'73851','new_theme','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(612634,192902,'73852','new_theme','block_type','1',0,''),(612635,192902,'73852','new_theme','padding-left','20',0,''),(612636,192902,'73852','new_theme','padding-left','0',0,'8451'),(612637,192904,'73854','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612638,192905,'73855','new_theme','border-top-width','1',0,''),(612639,192905,'73855','new_theme','border-top-color','$content-border-1',0,''),(612640,192905,'73855','new_theme','padding-top','13',0,''),(612641,192905,'73855','new_theme','padding-bottom','10',0,''),(612642,192906,'73856','new_theme','block_type','1',0,''),(612643,192906,'73856','new_theme','background-color','$content-bg-1',0,''),(612644,192906,'73856','new_theme','padding-top','30',0,''),(612645,192906,'73856','new_theme','padding-left','30',0,''),(612646,192906,'73856','new_theme','padding-right','30',0,''),(612647,192906,'73856','new_theme','padding-bottom','14',0,''),(612648,192906,'73856','new_theme','margin-bottom','20',0,''),(612649,192906,'73856','new_theme','style_class','hiding-box closeable-box',0,''),(612650,192907,'73857','new_theme','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(612651,192907,'73857','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612652,192908,'73858','new_theme','style_class','closeable-content',0,''),(612653,192908,'73858','new_theme','padding-bottom','20',0,''),(612654,192909,'73860','new_theme','block_type','1',0,''),(612655,192909,'73860','new_theme','padding-top','30',0,''),(612656,192909,'73860','new_theme','padding-left','30',0,''),(612657,192909,'73860','new_theme','padding-right','30',0,''),(612658,192909,'73860','new_theme','padding-bottom','23',0,''),(612659,192909,'73860','new_theme','margin-bottom','20',0,''),(612660,192909,'73860','new_theme','background-color','$content-bg-1',0,''),(612661,192909,'73860','new_theme','style_class','hiding-box',0,''),(612662,192910,'73861','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(612663,192911,'73862','new_theme','block_type','2',0,''),(612664,192911,'73862','new_theme','schema','2-2',0,'8451'),(612665,192912,'73863','new_theme','padding-right','20',0,''),(612666,192912,'73863','new_theme','padding-right','0',0,'8451'),(612667,192912,'73863','new_theme','padding-bottom','20',0,'8451'),(612668,192913,'73864','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612669,192914,'73865','new_theme','block_type','1',0,''),(612670,192914,'73865','new_theme','padding-left','20',0,''),(612671,192914,'73865','new_theme','padding-left','0',0,'8451'),(612672,192916,'73867','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612673,192917,'73868','new_theme','block_type','1',0,''),(612674,192917,'73868','new_theme','padding-top','20',0,''),(612675,192917,'73868','new_theme','padding-left','20',0,''),(612676,192917,'73868','new_theme','padding-right','20',0,''),(612677,192917,'73868','new_theme','padding-bottom','20',0,''),(612678,192917,'73868','new_theme','background-color','$content-bg-1',0,''),(612679,192917,'73868','new_theme','style_class','order-summary',0,''),(612680,192918,'73869','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(612681,192919,'73870','new_theme','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(612682,192919,'73870','new_theme','text-align','center',0,''),(612683,192919,'73870','new_theme','font-size','14',0,''),(612684,192919,'73870','new_theme','color','$fade-color-1',0,''),(612685,192919,'73870','new_theme','padding-top','10',0,''),(612686,192920,'73871','new_theme','margin-bottom','10',0,''),(612687,192922,'115996','new_theme','hide_continue_button','1',0,''),(612688,192923,'73873','new_theme','block_type','1',0,''),(612689,192923,'73873','new_theme','background-color','$content-bg-2',0,''),(612690,192923,'73873','new_theme','padding-top','30',0,''),(612691,192923,'73873','new_theme','padding-bottom','30',0,''),(612692,192924,'73874','new_theme','block_type','4',0,''),(612693,192924,'73874','new_theme','schema','4-2',0,'8451'),(612694,192925,'73875','new_theme','block_type','1',0,''),(612695,192925,'73875','new_theme','padding-right','40',0,''),(612696,192925,'73875','new_theme','padding-right','0',0,'8451'),(612697,192926,'73876','new_theme','background-color','$content-bg-1',0,''),(612698,192926,'73876','new_theme','padding-top','30',0,''),(612699,192926,'73876','new_theme','padding-left','30',0,''),(612700,192926,'73876','new_theme','padding-right','30',0,''),(612701,192926,'73876','new_theme','padding-bottom','30',0,''),(612702,192926,'73876','new_theme','margin-bottom','20',0,''),(612703,192927,'73877','new_theme','block_type','1',0,''),(612704,192927,'73877','new_theme','background-color','$content-bg-1',0,''),(612705,192927,'73877','new_theme','padding-top','30',0,''),(612706,192927,'73877','new_theme','padding-left','30',0,''),(612707,192927,'73877','new_theme','padding-right','30',0,''),(612708,192927,'73877','new_theme','padding-bottom','30',0,''),(612709,192927,'73877','new_theme','margin-bottom','20',0,''),(612710,192927,'73877','new_theme','style_class','hiding-box',0,''),(612711,192928,'73878','new_theme','margin-bottom','20',0,''),(612712,192929,'73879','new_theme','padding-top','10',0,''),(612713,192929,'73879','new_theme','padding-left','20',0,''),(612714,192929,'73879','new_theme','padding-right','20',0,''),(612715,192929,'73879','new_theme','margin-top','20',0,''),(612716,192929,'73879','new_theme','background-color','$content-bg-2',0,''),(612717,192929,'73879','new_theme','padding-bottom','8',0,''),(612718,192930,'73880','new_theme','background-color','$content-bg-1',0,''),(612719,192930,'73880','new_theme','block_type','1',0,''),(612720,192930,'73880','new_theme','padding-top','30',0,''),(612721,192930,'73880','new_theme','padding-left','30',0,''),(612722,192930,'73880','new_theme','padding-right','30',0,''),(612723,192930,'73880','new_theme','padding-bottom','30',0,''),(612724,192930,'73880','new_theme','margin-bottom','20',0,''),(612725,192930,'73880','new_theme','style_class','hiding-box',0,''),(612726,192931,'73881','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(612727,192932,'73882','new_theme','background-color','$content-bg-2',0,''),(612728,192932,'73882','new_theme','padding-top','10',0,''),(612729,192932,'73882','new_theme','padding-left','10',0,''),(612730,192932,'73882','new_theme','padding-right','10',0,''),(612731,192932,'73882','new_theme','padding-bottom','10',0,''),(612732,192932,'73882','new_theme','margin-top','10',0,''),(612733,192933,'73883','new_theme','block_type','1',0,''),(612734,192933,'73883','new_theme','content','\\_',0,'3'),(612735,192933,'73883','new_theme','border-top-width','1',0,'3'),(612736,192933,'73883','new_theme','border-top-color','$content-border-1',0,'3'),(612737,192933,'73883','new_theme','display','block',0,'3'),(612738,192933,'73883','new_theme','position','absolute',0,'3'),(612739,192933,'73883','new_theme','top','19',0,'3'),(612740,192933,'73883','new_theme','left','0',0,'3'),(612741,192933,'73883','new_theme','right','0',0,'3'),(612742,192933,'73883','new_theme','margin-top','-2',0,'3'),(612743,192933,'73883','new_theme','position','relative',0,''),(612744,192934,'73884','new_theme','box_align','2',0,''),(612745,192934,'73884','new_theme','margin-bottom','10',0,''),(612746,192934,'73884','new_theme','background-color','$content-bg-1',0,''),(612747,192934,'73884','new_theme','position','relative',0,''),(612748,192935,'73885','new_theme','block_type','2',0,''),(612749,192935,'73885','new_theme','schema','2-2',0,'8451'),(612750,192936,'73886','new_theme','block_type','1',0,''),(612751,192936,'73886','new_theme','padding-right','20',0,''),(612752,192936,'73886','new_theme','padding-left','0',0,'8451'),(612753,192936,'73886','new_theme','margin-bottom','20',0,'8451'),(612754,192939,'73889','new_theme','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(612755,192940,'73890','new_theme','block_type','1',0,''),(612756,192940,'73890','new_theme','padding-left','20',0,''),(612757,192940,'73890','new_theme','padding-left','0',0,'8451'),(612758,192942,'73892','new_theme','border-top-width','1',0,''),(612759,192942,'73892','new_theme','border-top-color','$content-border-1',0,''),(612760,192942,'73892','new_theme','padding-top','13',0,''),(612761,192942,'73892','new_theme','padding-bottom','10',0,''),(612762,192943,'73893','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612763,192944,'73894','new_theme','block_type','1',0,''),(612764,192944,'73894','new_theme','padding-top','30',0,''),(612765,192944,'73894','new_theme','padding-left','30',0,''),(612766,192944,'73894','new_theme','padding-right','30',0,''),(612767,192944,'73894','new_theme','padding-bottom','23',0,''),(612768,192944,'73894','new_theme','margin-bottom','20',0,''),(612769,192944,'73894','new_theme','background-color','$content-bg-1',0,''),(612770,192944,'73894','new_theme','style_class','hiding-box',0,''),(612771,192945,'73895','new_theme','block_type','2',0,''),(612772,192945,'73895','new_theme','schema','2-2',0,'8451'),(612773,192946,'73896','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612774,192947,'73897','new_theme','padding-right','20',0,''),(612775,192947,'73897','new_theme','padding-right','0',0,'8451'),(612776,192947,'73897','new_theme','padding-bottom','20',0,'8451'),(612777,192948,'73898','new_theme','block_type','1',0,''),(612778,192948,'73898','new_theme','padding-left','20',0,''),(612779,192948,'73898','new_theme','padding-left','0',0,'8451'),(612780,192949,'73899','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612781,192951,'73901','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(612782,192952,'73902','new_theme','block_type','1',0,''),(612783,192952,'73902','new_theme','background-color','$content-bg-1',0,''),(612784,192952,'73902','new_theme','padding-top','30',0,''),(612785,192952,'73902','new_theme','padding-left','30',0,''),(612786,192952,'73902','new_theme','padding-right','30',0,''),(612787,192952,'73902','new_theme','padding-bottom','14',0,''),(612788,192952,'73902','new_theme','margin-bottom','20',0,''),(612789,192952,'73902','new_theme','style_class','hiding-box closeable-box',0,''),(612790,192953,'73903','new_theme','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(612791,192953,'73903','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612792,192954,'73904','new_theme','style_class','closeable-content',0,''),(612793,192954,'73904','new_theme','padding-bottom','20',0,''),(612794,192955,'73905','new_theme','block_type','1',0,''),(612795,192955,'73905','new_theme','padding-top','30',0,''),(612796,192955,'73905','new_theme','padding-left','30',0,''),(612797,192955,'73905','new_theme','padding-right','30',0,''),(612798,192955,'73905','new_theme','padding-bottom','14',0,''),(612799,192955,'73905','new_theme','margin-bottom','20',0,''),(612800,192955,'73905','new_theme','background-color','$content-bg-1',0,''),(612801,192955,'73905','new_theme','style_class','hiding-box closeable-box',0,''),(612802,192956,'73906','new_theme','block_type','2',0,''),(612803,192956,'73906','new_theme','style_class','closeable-content',0,''),(612804,192956,'73906','new_theme','schema','2-2',0,'8451'),(612805,192957,'73907','new_theme','padding-right','20',0,''),(612806,192957,'73907','new_theme','padding-bottom','20',0,''),(612807,192957,'73907','new_theme','padding-right','0',0,'8451'),(612808,192958,'73908','new_theme','padding-left','20',0,''),(612809,192958,'73908','new_theme','padding-bottom','20',0,''),(612810,192958,'73908','new_theme','padding-left','0',0,'8451'),(612811,192959,'73909','new_theme','padding-left','20',0,''),(612812,192959,'73909','new_theme','padding-bottom','20',0,''),(612813,192959,'73909','new_theme','padding-left','0',0,'8451'),(612814,192960,'73910','new_theme','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(612815,192960,'73910','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612816,192961,'73911','new_theme','block_type','1',0,''),(612817,192961,'73911','new_theme','padding-top','20',0,''),(612818,192961,'73911','new_theme','padding-left','20',0,''),(612819,192961,'73911','new_theme','padding-right','20',0,''),(612820,192961,'73911','new_theme','padding-bottom','20',0,''),(612821,192961,'73911','new_theme','background-color','$content-bg-1',0,''),(612822,192961,'73911','new_theme','style_class','order-summary',0,''),(612823,192962,'73912','new_theme','margin-bottom','10',0,''),(612824,192963,'73913','new_theme','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(612825,192963,'73913','new_theme','text-align','center',0,''),(612826,192963,'73913','new_theme','font-size','14',0,''),(612827,192963,'73913','new_theme','color','$fade-color-1',0,''),(612828,192963,'73913','new_theme','padding-top','10',0,''),(612829,192964,'73914','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(612830,192966,'115998','new_theme','hide_continue_button','1',0,''),(612831,192967,'73916','new_theme','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(612832,192972,'73921','new_theme','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(612833,192973,'73923','new_theme','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(612834,192974,'73924','new_theme','style_class','order-summary',0,''),(612835,192974,'73924','new_theme','box_align','3',0,''),(612836,192974,'73924','new_theme','width','400',0,''),(612837,192976,'73922','new_theme','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(612838,192979,'73928','new_theme','block_type','1',0,''),(612839,192980,'73929','new_theme','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(612840,192981,'73930','new_theme','float','right',0,''),(612841,192981,'73930','new_theme','position','relative',0,''),(612842,192981,'73930','new_theme','z-index','1',0,''),(612843,192981,'73930','new_theme','top','30',0,''),(612844,192981,'73930','new_theme','margin-bottom','-20',0,''),(612845,192982,'73931','new_theme','margin-bottom','30',0,''),(612846,192983,'94704','new_theme','block_type','1',0,''),(612847,192984,'94705','new_theme','listing_type','Compare Products',0,''),(612848,192985,'94706','new_theme','block_type','1',0,''),(612849,192985,'94706','new_theme','style_class','item-holder',0,''),(612850,192985,'94706','new_theme','padding-top','10',0,''),(612851,192985,'94706','new_theme','padding-left','20',0,''),(612852,192985,'94706','new_theme','padding-right','20',0,''),(612853,192985,'94706','new_theme','padding-bottom','10',0,''),(612854,192985,'94706','new_theme','text-align','left',0,''),(612855,192988,'94709','new_theme','margin-bottom','10',0,''),(612856,192989,'94710','new_theme','block_type','5',0,''),(612857,192991,'94712','new_theme','clear','both',0,''),(612858,192992,'94713','new_theme','block_type','2',0,''),(612859,192993,'94714','new_theme','margin-bottom','7',0,''),(612860,192994,'94715','new_theme','text-align','right',0,''),(612861,192994,'94715','new_theme','margin-bottom','10',0,''),(612862,192994,'94715','new_theme','float','right',0,''),(612863,192995,'73932','new_theme','block_type','1',0,''),(612864,192995,'73932','new_theme','background-color','$content-bg-2',0,''),(612865,192995,'73932','new_theme','padding-bottom','30',0,''),(612866,192995,'73932','new_theme','color','$content-color-2',0,''),(612867,192996,'73933','new_theme','block_type','4',0,''),(612868,192996,'73933','new_theme','schema','4-2',0,'8451'),(612869,192997,'73934','new_theme','block_type','1',0,''),(612870,192997,'73934','new_theme','padding-right','40',0,''),(612871,192997,'73934','new_theme','padding-right','0',0,'8451'),(612872,192998,'73935','new_theme','block_type','1',0,''),(612873,192998,'73935','new_theme','padding-right','30',0,''),(612874,192998,'73935','new_theme','background-color','$content-bg-1',0,''),(612875,192998,'73935','new_theme','padding-top','20',0,''),(612876,192998,'73935','new_theme','padding-left','30',0,''),(612877,192998,'73935','new_theme','padding-bottom','20',0,''),(612878,192998,'73935','new_theme','padding-left','20',0,'8451'),(612879,192998,'73935','new_theme','padding-right','20',0,'8451'),(612880,192998,'73935','new_theme','color','$content-color-1',0,''),(612881,192999,'73936','new_theme','link','products',0,''),(612882,192999,'73936','new_theme','float','right',0,''),(612883,192999,'73936','new_theme','margin-top','-37',0,''),(612884,193001,'73938','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(612885,193002,'73939','new_theme','block_type','1',0,''),(612886,193002,'73939','new_theme','background-color','$content-bg-1',0,''),(612887,193002,'73939','new_theme','padding-top','20',0,''),(612888,193002,'73939','new_theme','padding-bottom','20',0,''),(612889,193002,'73939','new_theme','padding-left','30',0,''),(612890,193002,'73939','new_theme','padding-right','30',0,''),(612891,193002,'73939','new_theme','margin-bottom','20',0,''),(612892,193002,'73939','new_theme','color','$content-color-1',0,''),(612893,193003,'73940','new_theme','float','right',0,''),(612894,193003,'73940','new_theme','margin-top','-37',0,''),(612895,193003,'73940','new_theme','link','comments',0,''),(612896,193004,'73941','new_theme','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612897,193005,'73942','new_theme','hide_parents','2',0,''),(612898,193006,'73943','new_theme','block_type','2',0,''),(612899,193006,'73943','new_theme','margin-bottom','20',0,''),(612900,193006,'73943','new_theme','schema','2-2',0,'8444'),(612901,193006,'73943','new_theme','background-color','$content-bg-1',0,''),(612902,193006,'73943','new_theme','color','$content-color-1',0,''),(612903,193007,'73944','new_theme','block_type','1',0,''),(612904,193007,'73944','new_theme','border-right-width','20',0,''),(612905,193007,'73944','new_theme','border-right-color','$content-bg-2',0,''),(612906,193007,'73944','new_theme','margin-right','-10',0,''),(612907,193007,'73944','new_theme','padding-right','30',0,''),(612908,193007,'73944','new_theme','padding-top','20',0,''),(612909,193007,'73944','new_theme','padding-left','30',0,''),(612910,193007,'73944','new_theme','padding-bottom','20',0,''),(612911,193007,'73944','new_theme','border-right-width','0',0,'8451'),(612912,193007,'73944','new_theme','margin-right','0',0,'8451'),(612913,193007,'73944','new_theme','margin-bottom','20',0,'8451'),(612914,193007,'73944','new_theme','padding-left','20',0,'8451'),(612915,193007,'73944','new_theme','padding-right','20',0,'8451'),(612916,193008,'73945','new_theme','link','shipping_method',0,''),(612917,193008,'73945','new_theme','float','right',0,''),(612918,193008,'73945','new_theme','margin-top','-31',0,''),(612919,193010,'73947','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(612920,193010,'73947','new_theme','padding-top','20',0,''),(612921,193011,'73948','new_theme','link','contact_information',0,''),(612922,193011,'73948','new_theme','margin-top','-31',0,''),(612923,193011,'73948','new_theme','float','right',0,''),(612924,193012,'73949','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612925,193012,'73949','new_theme','clear','none',0,''),(612926,193014,'73951','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(612927,193015,'73952','new_theme','link','shipping_address',0,''),(612928,193015,'73952','new_theme','float','right',0,''),(612929,193015,'73952','new_theme','margin-top','-31',0,''),(612930,193017,'73954','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(612931,193017,'73954','new_theme','clear','none',0,''),(612932,193018,'73955','new_theme','margin-bottom','20',0,''),(612933,193019,'73956','new_theme','block_type','1',0,''),(612934,193019,'73956','new_theme','padding-left','30',0,''),(612935,193019,'73956','new_theme','border-left-width','20',0,''),(612936,193019,'73956','new_theme','border-left-color','$content-bg-2',0,''),(612937,193019,'73956','new_theme','margin-left','-10',0,''),(612938,193019,'73956','new_theme','padding-right','30',0,''),(612939,193019,'73956','new_theme','padding-top','20',0,''),(612940,193019,'73956','new_theme','padding-bottom','20',0,''),(612941,193019,'73956','new_theme','border-left-width','0',0,'8451'),(612942,193020,'73957','new_theme','link','payment_method',0,''),(612943,193020,'73957','new_theme','float','right',0,''),(612944,193020,'73957','new_theme','margin-top','-31',0,''),(612945,193021,'73958','new_theme','link','billing_address',0,''),(612946,193021,'73958','new_theme','float','right',0,''),(612947,193021,'73958','new_theme','margin-top','-31',0,''),(612948,193023,'73960','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612949,193023,'73960','new_theme','clear','none',0,''),(612950,193024,'73961','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(612951,193025,'73962','new_theme','margin-bottom','20',0,''),(612952,193026,'73963','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612953,193026,'73963','new_theme','clear','none',0,''),(612954,193028,'73965','new_theme','block_type','1',0,''),(612955,193028,'73965','new_theme','padding-top','20',0,''),(612956,193028,'73965','new_theme','padding-left','20',0,''),(612957,193028,'73965','new_theme','padding-right','20',0,''),(612958,193028,'73965','new_theme','padding-bottom','20',0,''),(612959,193028,'73965','new_theme','background-color','$content-bg-1',0,''),(612960,193028,'73965','new_theme','style_class','order-summary2 hiding-box',0,''),(612961,193028,'73965','new_theme','color','$content-color-1',0,''),(612962,193029,'73966','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(612963,193030,'73967','new_theme','margin-bottom','20',0,''),(612964,193030,'73967','new_theme','text-align','right',0,''),(612965,193032,'73969','new_theme','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(612966,193033,'73970','new_theme','block_type','1',0,''),(612967,193033,'73970','new_theme','background-color','$content-bg-2',0,''),(612968,193033,'73970','new_theme','padding-bottom','30',0,''),(612969,193034,'73971','new_theme','block_type','4',0,''),(612970,193034,'73971','new_theme','schema','4-2',0,'8451'),(612971,193035,'73972','new_theme','block_type','1',0,''),(612972,193035,'73972','new_theme','padding-right','40',0,''),(612973,193035,'73972','new_theme','padding-right','0',0,'8451'),(612974,193036,'73973','new_theme','block_type','1',0,''),(612975,193036,'73973','new_theme','background-color','$content-bg-1',0,''),(612976,193036,'73973','new_theme','padding-top','20',0,''),(612977,193036,'73973','new_theme','padding-bottom','20',0,''),(612978,193036,'73973','new_theme','padding-left','30',0,''),(612979,193036,'73973','new_theme','padding-right','30',0,''),(612980,193036,'73973','new_theme','margin-bottom','20',0,''),(612981,193037,'73974','new_theme','hide_parents','2',0,''),(612982,193038,'73975','new_theme','float','right',0,''),(612983,193038,'73975','new_theme','margin-top','-37',0,''),(612984,193038,'73975','new_theme','link','comments',0,''),(612985,193039,'73976','new_theme','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612986,193040,'73977','new_theme','block_type','1',0,''),(612987,193040,'73977','new_theme','padding-right','30',0,''),(612988,193040,'73977','new_theme','background-color','$content-bg-1',0,''),(612989,193040,'73977','new_theme','padding-top','20',0,''),(612990,193040,'73977','new_theme','padding-left','30',0,''),(612991,193040,'73977','new_theme','padding-bottom','20',0,''),(612992,193040,'73977','new_theme','padding-left','20',0,'8451'),(612993,193040,'73977','new_theme','padding-right','20',0,'8451'),(612994,193041,'73978','new_theme','link','products',0,''),(612995,193041,'73978','new_theme','float','right',0,''),(612996,193041,'73978','new_theme','margin-top','-37',0,''),(612997,193042,'73979','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(612998,193044,'73981','new_theme','block_type','2',0,''),(612999,193044,'73981','new_theme','margin-bottom','20',0,''),(613000,193044,'73981','new_theme','schema','2-2',0,'8444'),(613001,193044,'73981','new_theme','background-color','$content-bg-1',0,''),(613002,193045,'73982','new_theme','block_type','1',0,''),(613003,193045,'73982','new_theme','border-right-width','20',0,''),(613004,193045,'73982','new_theme','border-right-color','$content-border-1',0,''),(613005,193045,'73982','new_theme','margin-right','-10',0,''),(613006,193045,'73982','new_theme','padding-right','30',0,''),(613007,193045,'73982','new_theme','padding-top','20',0,''),(613008,193045,'73982','new_theme','padding-left','30',0,''),(613009,193045,'73982','new_theme','padding-bottom','20',0,''),(613010,193045,'73982','new_theme','border-right-width','0',0,'8451'),(613011,193045,'73982','new_theme','margin-right','0',0,'8451'),(613012,193045,'73982','new_theme','margin-bottom','20',0,'8451'),(613013,193045,'73982','new_theme','padding-left','20',0,'8451'),(613014,193045,'73982','new_theme','padding-right','20',0,'8451'),(613015,193046,'73983','new_theme','link','shipping_address',0,''),(613016,193046,'73983','new_theme','float','right',0,''),(613017,193046,'73983','new_theme','margin-top','-31',0,''),(613018,193048,'73985','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(613019,193048,'73985','new_theme','clear','none',0,''),(613020,193049,'73986','new_theme','link','shipping_method',0,''),(613021,193049,'73986','new_theme','float','right',0,''),(613022,193049,'73986','new_theme','margin-top','-31',0,''),(613023,193050,'73987','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(613024,193050,'73987','new_theme','clear','none',0,''),(613025,193051,'73988','new_theme','margin-bottom','20',0,''),(613026,193052,'73989','new_theme','block_type','1',0,''),(613027,193052,'73989','new_theme','padding-left','30',0,''),(613028,193052,'73989','new_theme','border-left-width','20',0,''),(613029,193052,'73989','new_theme','border-left-color','$content-border-1',0,''),(613030,193052,'73989','new_theme','margin-left','-10',0,''),(613031,193052,'73989','new_theme','padding-right','30',0,''),(613032,193052,'73989','new_theme','padding-top','20',0,''),(613033,193052,'73989','new_theme','padding-bottom','20',0,''),(613034,193052,'73989','new_theme','border-left-width','0',0,'8451'),(613035,193055,'73992','new_theme','link','contact_information',0,''),(613036,193055,'73992','new_theme','margin-top','-31',0,''),(613037,193055,'73992','new_theme','float','right',0,''),(613038,193056,'73993','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(613039,193057,'73994','new_theme','block_type','1',0,''),(613040,193057,'73994','new_theme','padding-top','20',0,''),(613041,193057,'73994','new_theme','padding-left','20',0,''),(613042,193057,'73994','new_theme','padding-right','20',0,''),(613043,193057,'73994','new_theme','padding-bottom','20',0,''),(613044,193057,'73994','new_theme','background-color','$content-bg-1',0,''),(613045,193057,'73994','new_theme','style_class','order-summary',0,''),(613046,193058,'73995','new_theme','margin-bottom','20',0,''),(613047,193058,'73995','new_theme','text-align','right',0,''),(613048,193059,'73996','new_theme','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(613049,193060,'73997','new_theme','block_type','1',0,''),(613050,193060,'73997','new_theme','background-color','$content-bg-2',0,''),(613051,193060,'73997','new_theme','padding-bottom','30',0,''),(613052,193060,'73997','new_theme','color','$content-color-2',0,''),(613053,193061,'73998','new_theme','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(613054,193062,'73999','new_theme','block_type','4',0,''),(613055,193063,'74000','new_theme','block_type','1',0,''),(613056,193063,'74000','new_theme','padding-right','40',0,''),(613057,193064,'74001','new_theme','block_type','2',0,''),(613058,193064,'74001','new_theme','margin-bottom','20',0,''),(613059,193064,'74001','new_theme','schema','2-2',0,'8444'),(613060,193064,'74001','new_theme','background-color','$content-bg-1',0,''),(613061,193064,'74001','new_theme','color','$content-color-1',0,''),(613062,193065,'74002','new_theme','block_type','1',0,''),(613063,193065,'74002','new_theme','padding-right','0',0,'8444'),(613064,193065,'74002','new_theme','border-right-width','20',0,''),(613065,193065,'74002','new_theme','border-right-color','$content-bg-2',0,''),(613066,193065,'74002','new_theme','margin-right','-10',0,''),(613067,193065,'74002','new_theme','padding-right','30',0,''),(613068,193065,'74002','new_theme','padding-top','20',0,''),(613069,193065,'74002','new_theme','padding-left','30',0,''),(613070,193065,'74002','new_theme','padding-bottom','20',0,''),(613071,193066,'74003','new_theme','link','contact_information',0,''),(613072,193066,'74003','new_theme','margin-top','-37',0,''),(613073,193066,'74003','new_theme','float','right',0,''),(613074,193067,'74004','new_theme','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(613075,193067,'74004','new_theme','padding-top','20',0,''),(613076,193069,'74006','new_theme','block_type','1',0,''),(613077,193069,'74006','new_theme','padding-left','30',0,''),(613078,193069,'74006','new_theme','padding-left','0',0,'8444'),(613079,193069,'74006','new_theme','border-left-width','20',0,''),(613080,193069,'74006','new_theme','border-left-color','$content-bg-2',0,''),(613081,193069,'74006','new_theme','margin-left','-10',0,''),(613082,193069,'74006','new_theme','padding-right','30',0,''),(613083,193069,'74006','new_theme','padding-top','20',0,''),(613084,193069,'74006','new_theme','padding-bottom','20',0,''),(613085,193071,'74008','new_theme','link','payment_method',0,''),(613086,193071,'74008','new_theme','float','right',0,''),(613087,193071,'74008','new_theme','margin-top','-31',0,''),(613088,193072,'74009','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(613089,193072,'74009','new_theme','clear','none',0,''),(613090,193073,'74010','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(613091,193074,'74011','new_theme','link','billing_address',0,''),(613092,193074,'74011','new_theme','float','right',0,''),(613093,193074,'74011','new_theme','margin-top','-31',0,''),(613094,193075,'74012','new_theme','margin-bottom','20',0,''),(613095,193076,'74013','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(613096,193076,'74013','new_theme','clear','none',0,''),(613097,193077,'74014','new_theme','block_type','1',0,''),(613098,193077,'74014','new_theme','background-color','$content-bg-1',0,''),(613099,193077,'74014','new_theme','padding-top','20',0,''),(613100,193077,'74014','new_theme','padding-bottom','20',0,''),(613101,193077,'74014','new_theme','padding-left','30',0,''),(613102,193077,'74014','new_theme','padding-right','30',0,''),(613103,193077,'74014','new_theme','margin-bottom','20',0,''),(613104,193077,'74014','new_theme','color','$content-color-1',0,''),(613105,193078,'74015','new_theme','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(613106,193079,'74016','new_theme','hide_parents','2',0,''),(613107,193080,'74017','new_theme','float','right',0,''),(613108,193080,'74017','new_theme','margin-top','-37',0,''),(613109,193080,'74017','new_theme','link','comments',0,''),(613110,193081,'74018','new_theme','block_type','1',0,''),(613111,193081,'74018','new_theme','padding-right','30',0,''),(613112,193081,'74018','new_theme','padding-right','0',0,'8444'),(613113,193081,'74018','new_theme','background-color','$content-bg-1',0,''),(613114,193081,'74018','new_theme','padding-top','20',0,''),(613115,193081,'74018','new_theme','padding-left','30',0,''),(613116,193081,'74018','new_theme','padding-bottom','20',0,''),(613117,193081,'74018','new_theme','color','$content-color-1',0,''),(613118,193082,'74019','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(613119,193083,'74020','new_theme','link','products',0,''),(613120,193083,'74020','new_theme','float','right',0,''),(613121,193083,'74020','new_theme','margin-top','-37',0,''),(613122,193085,'74022','new_theme','block_type','1',0,''),(613123,193085,'74022','new_theme','padding-top','20',0,''),(613124,193085,'74022','new_theme','padding-left','20',0,''),(613125,193085,'74022','new_theme','padding-right','20',0,''),(613126,193085,'74022','new_theme','padding-bottom','20',0,''),(613127,193085,'74022','new_theme','background-color','$content-bg-1',0,''),(613128,193085,'74022','new_theme','style_class','order-summary2 hiding-box',0,''),(613129,193085,'74022','new_theme','color','$content-color-1',0,''),(613130,193086,'74023','new_theme','margin-bottom','20',0,''),(613131,193086,'74023','new_theme','text-align','right',0,''),(613132,193087,'74024','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(613133,193089,'74026','new_theme','block_type','1',0,''),(613134,193089,'74026','new_theme','background-color','$content-bg-2',0,''),(613135,193089,'74026','new_theme','padding-bottom','30',0,''),(613136,193090,'74027','new_theme','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(613137,193091,'74028','new_theme','block_type','4',0,''),(613138,193091,'74028','new_theme','schema','4-2',0,'8451'),(613139,193092,'74029','new_theme','block_type','1',0,''),(613140,193092,'74029','new_theme','padding-right','40',0,''),(613141,193092,'74029','new_theme','padding-right','0',0,'8451'),(613142,193093,'74030','new_theme','block_type','1',0,''),(613143,193093,'74030','new_theme','background-color','$content-bg-1',0,''),(613144,193093,'74030','new_theme','padding-top','20',0,''),(613145,193093,'74030','new_theme','padding-bottom','20',0,''),(613146,193093,'74030','new_theme','padding-left','30',0,''),(613147,193093,'74030','new_theme','padding-right','30',0,''),(613148,193093,'74030','new_theme','margin-bottom','20',0,''),(613149,193094,'74031','new_theme','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(613150,193095,'74032','new_theme','hide_parents','2',0,''),(613151,193096,'74033','new_theme','float','right',0,''),(613152,193096,'74033','new_theme','margin-top','-37',0,''),(613153,193096,'74033','new_theme','link','comments',0,''),(613154,193097,'74034','new_theme','block_type','2',0,''),(613155,193097,'74034','new_theme','margin-bottom','20',0,''),(613156,193097,'74034','new_theme','schema','2-2',0,'8444'),(613157,193097,'74034','new_theme','background-color','$content-bg-1',0,''),(613158,193098,'74035','new_theme','block_type','1',0,''),(613159,193098,'74035','new_theme','border-right-width','20',0,''),(613160,193098,'74035','new_theme','border-right-color','$content-border-1',0,''),(613161,193098,'74035','new_theme','margin-right','-10',0,''),(613162,193098,'74035','new_theme','padding-right','30',0,''),(613163,193098,'74035','new_theme','padding-top','20',0,''),(613164,193098,'74035','new_theme','padding-left','30',0,''),(613165,193098,'74035','new_theme','padding-bottom','20',0,''),(613166,193098,'74035','new_theme','border-right-width','0',0,'8451'),(613167,193098,'74035','new_theme','margin-right','0',0,'8451'),(613168,193098,'74035','new_theme','margin-bottom','20',0,'8451'),(613169,193098,'74035','new_theme','padding-left','20',0,'8451'),(613170,193098,'74035','new_theme','padding-right','20',0,'8451'),(613171,193099,'74036','new_theme','link','contact_information',0,''),(613172,193099,'74036','new_theme','margin-top','-31',0,''),(613173,193099,'74036','new_theme','float','right',0,''),(613174,193102,'74039','new_theme','link','payment_method',0,''),(613175,193102,'74039','new_theme','float','right',0,''),(613176,193102,'74039','new_theme','margin-top','-31',0,''),(613177,193103,'74040','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(613178,193103,'74040','new_theme','padding-top','20',0,''),(613179,193104,'74041','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(613180,193104,'74041','new_theme','clear','none',0,''),(613181,193105,'74042','new_theme','block_type','1',0,''),(613182,193105,'74042','new_theme','padding-left','30',0,''),(613183,193105,'74042','new_theme','border-left-width','20',0,''),(613184,193105,'74042','new_theme','border-left-color','$content-border-1',0,''),(613185,193105,'74042','new_theme','margin-left','-10',0,''),(613186,193105,'74042','new_theme','padding-right','30',0,''),(613187,193105,'74042','new_theme','padding-top','20',0,''),(613188,193105,'74042','new_theme','padding-bottom','20',0,''),(613189,193105,'74042','new_theme','border-left-width','0',0,'8451'),(613190,193106,'74043','new_theme','margin-bottom','20',0,''),(613191,193107,'74044','new_theme','link','billing_address',0,''),(613192,193107,'74044','new_theme','float','right',0,''),(613193,193107,'74044','new_theme','margin-top','-31',0,''),(613194,193108,'74045','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(613195,193108,'74045','new_theme','clear','none',0,''),(613196,193109,'74046','new_theme','block_type','1',0,''),(613197,193109,'74046','new_theme','padding-right','30',0,''),(613198,193109,'74046','new_theme','background-color','$content-bg-1',0,''),(613199,193109,'74046','new_theme','padding-top','20',0,''),(613200,193109,'74046','new_theme','padding-left','30',0,''),(613201,193109,'74046','new_theme','padding-bottom','20',0,''),(613202,193109,'74046','new_theme','padding-left','20',0,'8451'),(613203,193109,'74046','new_theme','padding-right','20',0,'8451'),(613204,193110,'74047','new_theme','link','products',0,''),(613205,193110,'74047','new_theme','float','right',0,''),(613206,193110,'74047','new_theme','margin-top','-37',0,''),(613207,193111,'74048','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(613208,193112,'74049','new_theme','margin-bottom','20',0,''),(613209,193113,'74050','new_theme','block_type','1',0,''),(613210,193113,'74050','new_theme','padding-top','20',0,''),(613211,193113,'74050','new_theme','padding-left','20',0,''),(613212,193113,'74050','new_theme','padding-right','20',0,''),(613213,193113,'74050','new_theme','padding-bottom','20',0,''),(613214,193113,'74050','new_theme','background-color','$content-bg-1',0,''),(613215,193113,'74050','new_theme','style_class','order-summary',0,''),(613216,193114,'74051','new_theme','margin-bottom','20',0,''),(613217,193114,'74051','new_theme','text-align','right',0,''),(613218,193116,'74053','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(613219,193117,'74054','new_theme','block_type','1',0,''),(613220,193117,'74054','new_theme','background-color','$content-bg-2',0,''),(613221,193117,'74054','new_theme','padding-bottom','30',0,''),(613222,193118,'74055','new_theme','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(613223,193119,'74056','new_theme','block_type','4',0,''),(613224,193119,'74056','new_theme','schema','4-2',0,'8451'),(613225,193120,'74057','new_theme','block_type','1',0,''),(613226,193120,'74057','new_theme','padding-right','40',0,''),(613227,193120,'74057','new_theme','padding-right','0',0,'8451'),(613228,193121,'74058','new_theme','block_type','1',0,''),(613229,193121,'74058','new_theme','padding-right','30',0,''),(613230,193121,'74058','new_theme','background-color','$content-bg-1',0,''),(613231,193121,'74058','new_theme','padding-top','20',0,''),(613232,193121,'74058','new_theme','padding-left','30',0,''),(613233,193121,'74058','new_theme','padding-bottom','20',0,''),(613234,193121,'74058','new_theme','padding-left','20',0,'8451'),(613235,193121,'74058','new_theme','padding-right','20',0,'8451'),(613236,193123,'74060','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(613237,193124,'74061','new_theme','link','products',0,''),(613238,193124,'74061','new_theme','float','right',0,''),(613239,193124,'74061','new_theme','margin-top','-37',0,''),(613240,193125,'74062','new_theme','block_type','2',0,''),(613241,193125,'74062','new_theme','margin-bottom','20',0,''),(613242,193125,'74062','new_theme','schema','2-2',0,'8444'),(613243,193125,'74062','new_theme','background-color','$content-bg-1',0,''),(613244,193126,'74063','new_theme','block_type','1',0,''),(613245,193126,'74063','new_theme','border-right-width','20',0,''),(613246,193126,'74063','new_theme','border-right-color','$content-border-1',0,''),(613247,193126,'74063','new_theme','margin-right','-10',0,''),(613248,193126,'74063','new_theme','padding-right','30',0,''),(613249,193126,'74063','new_theme','padding-top','20',0,''),(613250,193126,'74063','new_theme','padding-left','30',0,''),(613251,193126,'74063','new_theme','padding-bottom','20',0,''),(613252,193126,'74063','new_theme','border-right-width','0',0,'8451'),(613253,193126,'74063','new_theme','margin-right','0',0,'8451'),(613254,193126,'74063','new_theme','margin-bottom','20',0,'8451'),(613255,193126,'74063','new_theme','padding-left','20',0,'8451'),(613256,193126,'74063','new_theme','padding-right','20',0,'8451'),(613257,193127,'74064','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(613258,193128,'74065','new_theme','link','contact_information',0,''),(613259,193128,'74065','new_theme','margin-top','-31',0,''),(613260,193128,'74065','new_theme','float','right',0,''),(613261,193129,'74066','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(613262,193129,'74066','new_theme','clear','none',0,''),(613263,193131,'74068','new_theme','margin-bottom','20',0,''),(613264,193133,'74070','new_theme','link','shipping_address',0,''),(613265,193133,'74070','new_theme','float','right',0,''),(613266,193133,'74070','new_theme','margin-top','-31',0,''),(613267,193135,'74072','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(613268,193135,'74072','new_theme','padding-top','20',0,''),(613269,193136,'74073','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(613270,193136,'74073','new_theme','clear','none',0,''),(613271,193137,'74074','new_theme','link','shipping_method',0,''),(613272,193137,'74074','new_theme','float','right',0,''),(613273,193137,'74074','new_theme','margin-top','-31',0,''),(613274,193138,'74075','new_theme','block_type','1',0,''),(613275,193138,'74075','new_theme','padding-left','30',0,''),(613276,193138,'74075','new_theme','border-left-width','20',0,''),(613277,193138,'74075','new_theme','border-left-color','$content-border-1',0,''),(613278,193138,'74075','new_theme','margin-left','-10',0,''),(613279,193138,'74075','new_theme','padding-right','30',0,''),(613280,193138,'74075','new_theme','padding-top','20',0,''),(613281,193138,'74075','new_theme','padding-bottom','20',0,''),(613282,193138,'74075','new_theme','border-left-width','0',0,'8451'),(613283,193139,'74076','new_theme','link','billing_address',0,''),(613284,193139,'74076','new_theme','float','right',0,''),(613285,193139,'74076','new_theme','margin-top','-31',0,''),(613286,193140,'74077','new_theme','margin-bottom','20',0,''),(613287,193142,'74079','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(613288,193143,'74080','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(613289,193143,'74080','new_theme','clear','none',0,''),(613290,193144,'74081','new_theme','link','payment_method',0,''),(613291,193144,'74081','new_theme','float','right',0,''),(613292,193144,'74081','new_theme','margin-top','-31',0,''),(613293,193145,'74082','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(613294,193145,'74082','new_theme','clear','none',0,''),(613295,193146,'74083','new_theme','block_type','1',0,''),(613296,193146,'74083','new_theme','background-color','$content-bg-1',0,''),(613297,193146,'74083','new_theme','padding-top','20',0,''),(613298,193146,'74083','new_theme','padding-bottom','20',0,''),(613299,193146,'74083','new_theme','padding-left','30',0,''),(613300,193146,'74083','new_theme','padding-right','30',0,''),(613301,193146,'74083','new_theme','margin-bottom','20',0,''),(613302,193147,'74084','new_theme','hide_parents','2',0,''),(613303,193148,'74085','new_theme','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(613304,193149,'74086','new_theme','float','right',0,''),(613305,193149,'74086','new_theme','margin-top','-37',0,''),(613306,193149,'74086','new_theme','link','comments',0,''),(613307,193150,'74087','new_theme','block_type','1',0,''),(613308,193150,'74087','new_theme','padding-top','20',0,''),(613309,193150,'74087','new_theme','padding-left','20',0,''),(613310,193150,'74087','new_theme','padding-right','20',0,''),(613311,193150,'74087','new_theme','padding-bottom','20',0,''),(613312,193150,'74087','new_theme','background-color','$content-bg-1',0,''),(613313,193150,'74087','new_theme','style_class','order-summary',0,''),(613314,193151,'74088','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(613315,193153,'74090','new_theme','margin-bottom','20',0,''),(613316,193153,'74090','new_theme','text-align','right',0,''),(613317,193154,'74091','new_theme','block_type','1',0,''),(613318,193154,'74091','new_theme','background-color','$content-bg-2',0,''),(613319,193154,'74091','new_theme','padding-bottom','30',0,''),(613320,193155,'74092','new_theme','block_type','4',0,''),(613321,193155,'74092','new_theme','schema','4-2',0,'8451'),(613322,193156,'74093','new_theme','block_type','1',0,''),(613323,193156,'74093','new_theme','padding-right','40',0,''),(613324,193156,'74093','new_theme','padding-right','0',0,'8451'),(613325,193157,'74094','new_theme','block_type','2',0,''),(613326,193157,'74094','new_theme','margin-bottom','20',0,''),(613327,193157,'74094','new_theme','schema','2-2',0,'8444'),(613328,193157,'74094','new_theme','background-color','$content-bg-1',0,''),(613329,193158,'74095','new_theme','block_type','1',0,''),(613330,193158,'74095','new_theme','border-right-width','20',0,''),(613331,193158,'74095','new_theme','border-right-color','$content-border-1',0,''),(613332,193158,'74095','new_theme','margin-right','-10',0,''),(613333,193158,'74095','new_theme','padding-right','30',0,''),(613334,193158,'74095','new_theme','padding-top','20',0,''),(613335,193158,'74095','new_theme','padding-left','30',0,''),(613336,193158,'74095','new_theme','padding-bottom','20',0,''),(613337,193158,'74095','new_theme','border-right-width','0',0,'8451'),(613338,193158,'74095','new_theme','margin-right','0',0,'8451'),(613339,193158,'74095','new_theme','margin-bottom','20',0,'8451'),(613340,193158,'74095','new_theme','padding-left','20',0,'8451'),(613341,193158,'74095','new_theme','padding-right','20',0,'8451'),(613342,193159,'74096','new_theme','margin-bottom','20',0,''),(613343,193160,'74097','new_theme','link','shipping_address',0,''),(613344,193160,'74097','new_theme','float','right',0,''),(613345,193160,'74097','new_theme','margin-top','-31',0,''),(613346,193161,'74098','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(613347,193161,'74098','new_theme','clear','none',0,''),(613348,193164,'74101','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(613349,193165,'74102','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(613350,193165,'74102','new_theme','clear','none',0,''),(613351,193166,'74103','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(613352,193166,'74103','new_theme','padding-top','20',0,''),(613353,193168,'74105','new_theme','link','shipping_method',0,''),(613354,193168,'74105','new_theme','float','right',0,''),(613355,193168,'74105','new_theme','margin-top','-31',0,''),(613356,193169,'74106','new_theme','link','contact_information',0,''),(613357,193169,'74106','new_theme','margin-top','-31',0,''),(613358,193169,'74106','new_theme','float','right',0,''),(613359,193170,'74107','new_theme','block_type','1',0,''),(613360,193170,'74107','new_theme','padding-left','30',0,''),(613361,193170,'74107','new_theme','border-left-width','20',0,''),(613362,193170,'74107','new_theme','border-left-color','$content-border-1',0,''),(613363,193170,'74107','new_theme','margin-left','-10',0,''),(613364,193170,'74107','new_theme','padding-right','30',0,''),(613365,193170,'74107','new_theme','padding-top','20',0,''),(613366,193170,'74107','new_theme','padding-bottom','20',0,''),(613367,193170,'74107','new_theme','border-left-width','0',0,'8451'),(613368,193171,'74108','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(613369,193171,'74108','new_theme','clear','none',0,''),(613370,193172,'74109','new_theme','margin-bottom','20',0,''),(613371,193173,'74110','new_theme','link','billing_address',0,''),(613372,193173,'74110','new_theme','float','right',0,''),(613373,193173,'74110','new_theme','margin-top','-31',0,''),(613374,193175,'74112','new_theme','link','payment_method',0,''),(613375,193175,'74112','new_theme','float','right',0,''),(613376,193175,'74112','new_theme','margin-top','-31',0,''),(613377,193176,'74113','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(613378,193177,'74114','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(613379,193177,'74114','new_theme','clear','none',0,''),(613380,193178,'74115','new_theme','block_type','1',0,''),(613381,193178,'74115','new_theme','padding-right','30',0,''),(613382,193178,'74115','new_theme','background-color','$content-bg-1',0,''),(613383,193178,'74115','new_theme','padding-top','20',0,''),(613384,193178,'74115','new_theme','padding-left','30',0,''),(613385,193178,'74115','new_theme','padding-bottom','20',0,''),(613386,193178,'74115','new_theme','padding-left','20',0,'8451'),(613387,193178,'74115','new_theme','padding-right','20',0,'8451'),(613388,193179,'74116','new_theme','link','products',0,''),(613389,193179,'74116','new_theme','float','right',0,''),(613390,193179,'74116','new_theme','margin-top','-37',0,''),(613391,193180,'74117','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(613392,193182,'74119','new_theme','block_type','1',0,''),(613393,193182,'74119','new_theme','background-color','$content-bg-1',0,''),(613394,193182,'74119','new_theme','padding-top','20',0,''),(613395,193182,'74119','new_theme','padding-bottom','20',0,''),(613396,193182,'74119','new_theme','padding-left','30',0,''),(613397,193182,'74119','new_theme','padding-right','30',0,''),(613398,193182,'74119','new_theme','margin-bottom','20',0,''),(613399,193183,'74120','new_theme','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(613400,193184,'74121','new_theme','float','right',0,''),(613401,193184,'74121','new_theme','margin-top','-37',0,''),(613402,193184,'74121','new_theme','link','comments',0,''),(613403,193185,'74122','new_theme','hide_parents','2',0,''),(613404,193186,'74123','new_theme','block_type','1',0,''),(613405,193186,'74123','new_theme','padding-top','20',0,''),(613406,193186,'74123','new_theme','padding-left','20',0,''),(613407,193186,'74123','new_theme','padding-right','20',0,''),(613408,193186,'74123','new_theme','padding-bottom','20',0,''),(613409,193186,'74123','new_theme','background-color','$content-bg-1',0,''),(613410,193186,'74123','new_theme','style_class','order-summary',0,''),(613411,193188,'74125','new_theme','margin-bottom','20',0,''),(613412,193188,'74125','new_theme','text-align','right',0,''),(613413,193189,'74126','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(613414,193190,'74127','new_theme','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(613415,193191,'74128','new_theme','block_type','1',0,''),(613416,193193,'74133','new_theme','block_type','2',0,''),(613417,193193,'74133','new_theme','font-weight','400',0,''),(613418,193193,'74133','new_theme','padding-bottom','20',0,''),(613419,193193,'74133','new_theme','schema','2-2',0,'8451'),(613420,193194,'74134','new_theme','show_captcha','on',0,''),(613421,193195,'74135','new_theme','font-weight','400',0,''),(613422,193195,'74135','new_theme','padding-left','40',0,''),(613423,193195,'74135','new_theme','time_format','24',0,''),(613424,193195,'74135','new_theme','show_icons','on',0,''),(613425,193195,'74135','new_theme','padding-left','0',0,'8451'),(613426,193196,'74136','new_theme','block_type','1',0,''),(613427,193197,'74137','new_theme','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(613428,193198,'74138','new_theme','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(613429,193198,'74138','new_theme','margin-bottom','40',0,''),(613430,193199,'74139','new_theme','width','680',0,''),(613431,193199,'74139','new_theme','font-weight','normal',0,''),(613432,193199,'74139','new_theme','font-size','12',0,''),(613433,193199,'74139','new_theme','padding-top','20',0,''),(613434,193199,'74139','new_theme','padding-bottom','20',0,''),(613435,193199,'74139','new_theme','color','$content-color-1',0,''),(613436,193200,'74140','new_theme','block_type','3',0,''),(613437,193200,'74140','new_theme','font-weight','normal',0,''),(613438,193200,'74140','new_theme','padding-top','20',0,''),(613439,193201,'74141','new_theme','font-size','12',0,''),(613440,193202,'74142','new_theme','text','<p>If undelivered please return to:</p>',1,''),(613441,193202,'74142','new_theme','font-size','12',0,''),(613442,193202,'74142','new_theme','font-weight','bold',0,''),(613443,193202,'74142','new_theme','text','<p>If undelivered please return to:</p>',0,''),(613444,193203,'74143','new_theme','text','<p>Thank you for your order</p>',1,''),(613445,193203,'74143','new_theme','color','$color-8',0,''),(613446,193203,'74143','new_theme','font-size','13',0,''),(613447,193203,'74143','new_theme','font-weight','bold',0,''),(613448,193203,'74143','new_theme','padding-top','5',0,''),(613449,193203,'74143','new_theme','text-align','center',0,''),(613450,193203,'74143','new_theme','text','<p>Thank you for your order</p>',0,''),(613451,193204,'74144','new_theme','font-weight','400',0,''),(613452,193204,'74144','new_theme','text-align','center',0,''),(613453,193204,'74144','new_theme','padding-top','0',0,''),(613454,193204,'74144','new_theme','padding-left','20',0,''),(613455,193204,'74144','new_theme','padding-right','20',0,''),(613456,193205,'74145','new_theme','text','<p>If something has gone wrong please contact us at:</p>',1,''),(613457,193205,'74145','new_theme','font-size','12',0,''),(613458,193205,'74145','new_theme','font-weight','bold',0,''),(613459,193205,'74145','new_theme','text-align','right',0,''),(613460,193205,'74145','new_theme','text','<p>If something has gone wrong please contact us at:</p>',0,''),(613461,193206,'74146','new_theme','block_type','6',0,''),(613462,193206,'74146','new_theme','font-weight','normal',0,''),(613463,193206,'74146','new_theme','font-size','16',0,''),(613464,193207,'74147','new_theme','text','<p>Email:</p>',1,''),(613465,193207,'74147','new_theme','font-weight','normal',0,''),(613466,193207,'74147','new_theme','text-align','right',0,''),(613467,193207,'74147','new_theme','font-size','12',0,''),(613468,193207,'74147','new_theme','text','<p>Email:</p>',0,''),(613469,193208,'74148','new_theme','font-weight','normal',0,''),(613470,193208,'74148','new_theme','text-align','right',0,''),(613471,193208,'74148','new_theme','font-size','12',0,''),(613472,193209,'74149','new_theme','block_type','6',0,''),(613473,193209,'74149','new_theme','font-weight','normal',0,''),(613474,193209,'74149','new_theme','font-size','16',0,''),(613475,193210,'74150','new_theme','text','<p>Phone:</p>',1,''),(613476,193210,'74150','new_theme','font-weight','normal',0,''),(613477,193210,'74150','new_theme','text-align','right',0,''),(613478,193210,'74150','new_theme','font-size','12',0,''),(613479,193210,'74150','new_theme','text','<p>Phone:</p>',0,''),(613480,193211,'74151','new_theme','font-weight','normal',0,''),(613481,193211,'74151','new_theme','text-align','right',0,''),(613482,193211,'74151','new_theme','font-size','12',0,''),(613483,193212,'74152','new_theme','font-weight','400',0,''),(613484,193212,'74152','new_theme','padding-top','20',0,''),(613485,193212,'74152','new_theme','padding-bottom','0',0,''),(613486,193212,'74152','new_theme','font-size','12',0,''),(613487,193213,'74153','new_theme','block_type','2',0,''),(613488,193213,'74153','new_theme','font-weight','normal',0,''),(613489,193213,'74153','new_theme','padding-bottom','20',0,''),(613490,193214,'74154','new_theme','font-weight','400',0,''),(613491,193214,'74154','new_theme','padding-top','20',0,''),(613492,193215,'74155','new_theme','block_type','11',0,''),(613493,193215,'74155','new_theme','font-weight','normal',0,''),(613494,193216,'74156','new_theme','text','<p>Web:</p>',1,''),(613495,193216,'74156','new_theme','font-weight','normal',0,''),(613496,193216,'74156','new_theme','text-align','right',0,''),(613497,193216,'74156','new_theme','text','<p>Web:</p>',0,''),(613498,193217,'74157','new_theme','font-weight','normal',0,''),(613499,193217,'74157','new_theme','text-align','right',0,''),(613500,193218,'74158','new_theme','block_type','11',0,''),(613501,193218,'74158','new_theme','font-weight','normal',0,''),(613502,193219,'74159','new_theme','text','<p>Phone:</p>',1,''),(613503,193219,'74159','new_theme','font-weight','normal',0,''),(613504,193219,'74159','new_theme','text-align','right',0,''),(613505,193219,'74159','new_theme','text','<p>Phone:</p>',0,''),(613506,193220,'74160','new_theme','font-weight','normal',0,''),(613507,193220,'74160','new_theme','text-align','right',0,''),(613508,193221,'74161','new_theme','block_type','11',0,''),(613509,193221,'74161','new_theme','font-weight','normal',0,''),(613510,193222,'74162','new_theme','text','<p>Email:</p>',1,''),(613511,193222,'74162','new_theme','font-weight','normal',0,''),(613512,193222,'74162','new_theme','text-align','right',0,''),(613513,193222,'74162','new_theme','text','<p>Email:</p>',0,''),(613514,193223,'74163','new_theme','font-weight','normal',0,''),(613515,193223,'74163','new_theme','text-align','right',0,''),(613516,193224,'74164','new_theme','block_type','1',0,''),(613517,193225,'74165','new_theme','font-weight','normal',0,''),(613518,193225,'74165','new_theme','text-align','right',0,''),(613519,193225,'74165','new_theme','padding-bottom','10',0,''),(613520,193225,'74165','new_theme','address_spacer',',',0,''),(613521,193225,'74165','new_theme','font-size','12',0,''),(613522,193226,'74166','new_theme','block_type','5',0,''),(613523,193226,'74166','new_theme','font-weight','normal',0,''),(613524,193226,'74166','new_theme','border-bottom-width','1',0,''),(613525,193226,'74166','new_theme','border-bottom-color','$content-border-1',0,''),(613526,193226,'74166','new_theme','border-top-width','1',0,''),(613527,193226,'74166','new_theme','border-top-color','$content-border-1',0,''),(613528,193226,'74166','new_theme','border-left-color','$content-border-1',0,''),(613529,193226,'74166','new_theme','border-left-width','1',0,''),(613530,193227,'74167','new_theme','block_type','1',0,''),(613531,193227,'74167','new_theme','font-weight','normal',0,''),(613532,193227,'74167','new_theme','padding-top','10',0,''),(613533,193227,'74167','new_theme','padding-left','10',0,''),(613534,193227,'74167','new_theme','padding-right','10',0,''),(613535,193228,'74168','new_theme','font-weight','400',0,''),(613536,193228,'74168','new_theme','line-height','120',0,''),(613537,193228,'74168','new_theme','line_height_measure','%',0,''),(613538,193228,'74168','new_theme','font-size','12',0,''),(613539,193229,'74169','new_theme','text','<p>SHIPPING ADDRESS:</p>',1,''),(613540,193229,'74169','new_theme','font-size','14',0,''),(613541,193229,'74169','new_theme','font-weight','bold',0,''),(613542,193229,'74169','new_theme','padding-bottom','10',0,''),(613543,193229,'74169','new_theme','text','<p>SHIPPING ADDRESS:</p>',0,''),(613544,193230,'74170','new_theme','block_type','1',0,''),(613545,193230,'74170','new_theme','background-color','$content-bg-2',0,''),(613546,193230,'74170','new_theme','padding-top','20',0,''),(613547,193230,'74170','new_theme','padding-left','10',0,''),(613548,193230,'74170','new_theme','padding-right','10',0,''),(613549,193230,'74170','new_theme','padding-bottom','20',0,''),(613550,193230,'74170','new_theme','font-size','14',0,''),(613551,193231,'74171','new_theme','block_type','4',0,''),(613552,193231,'74171','new_theme','font-weight','normal',0,''),(613553,193231,'74171','new_theme','border-top-width','1',0,''),(613554,193231,'74171','new_theme','border-top-color','$content-border-1',0,''),(613555,193231,'74171','new_theme','border-left-width','1',0,''),(613556,193231,'74171','new_theme','border-left-color','$content-border-1',0,''),(613557,193231,'74171','new_theme','border-right-width','1',0,''),(613558,193231,'74171','new_theme','border-right-color','$content-border-1',0,''),(613559,193231,'74171','new_theme','border-bottom-width','1',0,''),(613560,193231,'74171','new_theme','border-bottom-color','$content-border-1',0,''),(613561,193232,'74172','new_theme','block_type','2',0,''),(613562,193232,'74172','new_theme','font-weight','normal',0,''),(613563,193232,'74172','new_theme','border-right-width','1',0,''),(613564,193232,'74172','new_theme','border-right-color','$content-border-1',0,''),(613565,193233,'74173','new_theme','block_type','1',0,''),(613566,193233,'74173','new_theme','font-weight','400',0,''),(613567,193233,'74173','new_theme','background-color','$content-bg-2',0,''),(613568,193233,'74173','new_theme','padding-top','10',0,''),(613569,193233,'74173','new_theme','padding-left','10',0,''),(613570,193233,'74173','new_theme','padding-right','10',0,''),(613571,193233,'74173','new_theme','padding-bottom','30',0,''),(613572,193234,'74174','new_theme','text','<p>INVOICE ADDRESS:</p>',1,''),(613573,193234,'74174','new_theme','font-size','14',0,''),(613574,193234,'74174','new_theme','font-weight','bold',0,''),(613575,193234,'74174','new_theme','text','<p>INVOICE ADDRESS:</p>',0,''),(613576,193235,'74175','new_theme','font-size','12',0,''),(613577,193236,'74176','new_theme','block_type','1',0,''),(613578,193236,'74176','new_theme','font-weight','normal',0,''),(613579,193236,'74176','new_theme','padding-top','10',0,''),(613580,193236,'74176','new_theme','padding-left','10',0,''),(613581,193236,'74176','new_theme','padding-right','10',0,''),(613582,193236,'74176','new_theme','padding-bottom','10',0,''),(613583,193237,'74177','new_theme','font-weight','normal',0,''),(613584,193238,'74178','new_theme','text','<p>CUSTOMER:</p>',1,''),(613585,193238,'74178','new_theme','font-size','13',0,''),(613586,193238,'74178','new_theme','font-weight','bold',0,''),(613587,193238,'74178','new_theme','text','<p>CUSTOMER:</p>',0,''),(613588,193239,'74179','new_theme','text','<p>PHONE NUMBER:</p>',1,''),(613589,193239,'74179','new_theme','font-size','14',0,''),(613590,193239,'74179','new_theme','font-weight','bold',0,''),(613591,193239,'74179','new_theme','padding-top','10',0,''),(613592,193239,'74179','new_theme','text','<p>PHONE NUMBER:</p>',0,''),(613593,193240,'74180','new_theme','font-weight','normal',0,''),(613594,193242,'74182','new_theme','text','<p>E-MAIL ADDRESS:</p>',1,''),(613595,193242,'74182','new_theme','font-weight','bold',0,''),(613596,193242,'74182','new_theme','font-size','14',0,''),(613597,193242,'74182','new_theme','padding-top','10',0,''),(613598,193242,'74182','new_theme','text','<p>E-MAIL ADDRESS:</p>',0,''),(613599,193243,'74183','new_theme','block_type','2',0,''),(613600,193243,'74183','new_theme','font-weight','normal',0,''),(613601,193243,'74183','new_theme','border-top-width','1',0,''),(613602,193243,'74183','new_theme','border-top-color','$content-border-1',0,''),(613603,193243,'74183','new_theme','border-right-width','1',0,''),(613604,193243,'74183','new_theme','border-right-color','$content-border-1',0,''),(613605,193244,'74184','new_theme','block_type','1',0,''),(613606,193244,'74184','new_theme','font-weight','normal',0,''),(613607,193244,'74184','new_theme','padding-top','10',0,''),(613608,193244,'74184','new_theme','padding-left','10',0,''),(613609,193244,'74184','new_theme','padding-right','10',0,''),(613610,193244,'74184','new_theme','padding-bottom','10',0,''),(613611,193244,'74184','new_theme','border-right-width','1',0,''),(613612,193244,'74184','new_theme','border-right-color','$content-border-1',0,''),(613613,193246,'74186','new_theme','text','<p>Shipping via</p>',1,''),(613614,193246,'74186','new_theme','font-weight','bold',0,''),(613615,193246,'74186','new_theme','font-size','14',0,''),(613616,193246,'74186','new_theme','text','<p>Shipping via</p>',0,''),(613617,193247,'74187','new_theme','block_type','1',0,''),(613618,193247,'74187','new_theme','font-weight','normal',0,''),(613619,193247,'74187','new_theme','padding-top','10',0,''),(613620,193247,'74187','new_theme','padding-left','10',0,''),(613621,193247,'74187','new_theme','padding-right','10',0,''),(613622,193247,'74187','new_theme','padding-bottom','10',0,''),(613623,193248,'74188','new_theme','text','<p>Shipping service</p>',1,''),(613624,193248,'74188','new_theme','font-weight','bold',0,''),(613625,193248,'74188','new_theme','font-size','14',0,''),(613626,193248,'74188','new_theme','text','<p>Shipping service</p>',0,''),(613627,193250,'74190','new_theme','font-size','14',0,''),(613628,193250,'74190','new_theme','font-weight','bold',0,''),(613629,193250,'74190','new_theme','text-align','center',0,''),(613630,193250,'74190','new_theme','padding-bottom','10',0,''),(613631,193250,'74190','new_theme','padding-top','10',0,''),(613632,193251,'74191','new_theme','text','<p>Payment date:</p>',1,''),(613633,193251,'74191','new_theme','font-weight','bold',0,''),(613634,193251,'74191','new_theme','text-align','center',0,''),(613635,193251,'74191','new_theme','font-size','12',0,''),(613636,193251,'74191','new_theme','text','<p>Payment date:</p>',0,''),(613637,193252,'74192','new_theme','font-weight','normal',0,''),(613638,193252,'74192','new_theme','text-align','center',0,''),(613639,193252,'74192','new_theme','padding-bottom','10',0,''),(613640,193259,'74199','new_theme','text-align','center',0,''),(613641,193259,'74199','new_theme','padding-top','10',0,''),(613642,193261,'74201','new_theme','heading_type','h1',0,''),(613643,193264,'94718','new_theme','text-align','center',0,''),(613644,193264,'94718','new_theme','padding-top','10',0,''),(613645,193269,'74202','new_theme','block_type','1',0,''),(613646,193270,'74203','new_theme','block_type','1',0,''),(613647,193270,'74203','new_theme','max-width','800',0,''),(613648,193270,'74203','new_theme','margin','0 auto',0,''),(613649,193270,'74203','new_theme','background-color','$content-bg-1',0,''),(613650,193271,'74204','new_theme','color','$content-color-1',0,''),(613651,193271,'74204','new_theme','font-size','12',0,''),(613652,193271,'74204','new_theme','padding-top','20',0,''),(613653,193271,'74204','new_theme','padding-bottom','20',0,''),(613654,193271,'74204','new_theme','border-top-width','1',0,''),(613655,193271,'74204','new_theme','border-top-color','$content-border-1',0,''),(613656,193272,'74205','new_theme','font-weight','normal',0,''),(613657,193272,'74205','new_theme','padding-top','20',0,''),(613658,193272,'74205','new_theme','padding-left','10',0,''),(613659,193272,'74205','new_theme','padding-right','10',0,''),(613660,193272,'74205','new_theme','padding-bottom','20',0,''),(613661,193272,'74205','new_theme','color','$content-color-1',0,''),(613662,193272,'74205','new_theme','font-size','14',0,''),(613663,193273,'74206','new_theme','block_type','7',0,''),(613664,193273,'74206','new_theme','font-weight','normal',0,''),(613665,193273,'74206','new_theme','background-color','$highlight-box-bg-1',0,''),(613666,193273,'74206','new_theme','padding-top','5',0,''),(613667,193273,'74206','new_theme','padding-left','10',0,''),(613668,193273,'74206','new_theme','padding-right','10',0,''),(613669,193273,'74206','new_theme','padding-bottom','5',0,''),(613670,193274,'74207','new_theme','color','$highlight-box-color-1',0,''),(613671,193274,'74207','new_theme','font-size','14',0,''),(613672,193274,'74207','new_theme','font-weight','normal',0,''),(613673,193275,'74208','new_theme','font-weight','normal',0,''),(613674,193275,'74208','new_theme','text-align','right',0,''),(613675,193275,'74208','new_theme','color','$highlight-box-color-1',0,''),(613676,193275,'74208','new_theme','font-size','12',0,''),(613677,193276,'74209','new_theme','font-weight','normal',0,''),(613678,193276,'74209','new_theme','padding-bottom','10',0,''),(613679,193276,'74209','new_theme','padding-top','10',0,''),(613680,193276,'74209','new_theme','logo_from','theme',0,''),(613681,193277,'74210','new_theme','block_type','1',0,''),(613682,193278,'74211','new_theme','block_type','1',0,''),(613683,193278,'74211','new_theme','max-width','800',0,''),(613684,193278,'74211','new_theme','margin','0 auto',0,''),(613685,193278,'74211','new_theme','background-color','$content-bg-1',0,''),(613686,193279,'74212','new_theme','color','$content-color-1',0,''),(613687,193279,'74212','new_theme','font-size','12',0,''),(613688,193279,'74212','new_theme','padding-top','20',0,''),(613689,193279,'74212','new_theme','padding-bottom','20',0,''),(613690,193279,'74212','new_theme','border-top-width','1',0,''),(613691,193279,'74212','new_theme','border-top-color','$content-border-1',0,''),(613692,193280,'74213','new_theme','font-weight','normal',0,''),(613693,193280,'74213','new_theme','padding-bottom','10',0,''),(613694,193280,'74213','new_theme','background-color','$highlight-box-bg-1',0,''),(613695,193280,'74213','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',1,''),(613696,193280,'74213','new_theme','padding-left','20',0,''),(613697,193280,'74213','new_theme','padding-top','10',0,''),(613698,193280,'74213','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',0,''),(613699,193281,'74214','new_theme','font-weight','normal',0,''),(613700,193281,'74214','new_theme','padding-top','20',0,''),(613701,193281,'74214','new_theme','padding-left','10',0,''),(613702,193281,'74214','new_theme','padding-right','10',0,''),(613703,193281,'74214','new_theme','padding-bottom','20',0,''),(613704,193281,'74214','new_theme','color','$content-color-1',0,''),(613705,193281,'74214','new_theme','font-size','14',0,''),(613706,193282,'74215','new_theme','block_type','7',0,''),(613707,193282,'74215','new_theme','font-weight','normal',0,''),(613708,193282,'74215','new_theme','background-color','$highlight-box-bg-1',0,''),(613709,193282,'74215','new_theme','padding-top','5',0,''),(613710,193282,'74215','new_theme','padding-left','10',0,''),(613711,193282,'74215','new_theme','padding-right','10',0,''),(613712,193282,'74215','new_theme','padding-bottom','5',0,''),(613713,193283,'74216','new_theme','color','$highlight-box-color-1',0,''),(613714,193283,'74216','new_theme','font-size','15',0,''),(613715,193283,'74216','new_theme','font-weight','700',0,''),(613716,193284,'74217','new_theme','font-weight','normal',0,''),(613717,193284,'74217','new_theme','text-align','right',0,''),(613718,193284,'74217','new_theme','color','$highlight-box-color-1',0,''),(613719,193284,'74217','new_theme','font-size','12',0,''),(613720,193285,'74218','new_theme','block_type','1',0,''),(613721,193285,'74218','new_theme','background-color','$content-bg-2',0,''),(613722,193286,'74219','new_theme','block_type','1',0,''),(613723,193286,'74219','new_theme','max-width','800',0,''),(613724,193286,'74219','new_theme','margin','0 auto',0,''),(613725,193287,'74220','new_theme','block_type','1',0,''),(613726,193287,'74220','new_theme','background-color','$content-bg-1',0,''),(613727,193287,'74220','new_theme','padding-top','20',0,''),(613728,193287,'74220','new_theme','padding-left','20',0,''),(613729,193287,'74220','new_theme','padding-right','20',0,''),(613730,193287,'74220','new_theme','padding-bottom','20',0,''),(613731,193288,'74221','new_theme','font-weight','normal',0,''),(613732,193288,'74221','new_theme','padding-top','20',0,''),(613733,193288,'74221','new_theme','padding-bottom','20',0,''),(613734,193288,'74221','new_theme','color','$content-color-1',0,''),(613735,193288,'74221','new_theme','font-size','14',0,''),(613736,193289,'74222','new_theme','block_type','7',0,''),(613737,193289,'74222','new_theme','font-weight','normal',0,''),(613738,193289,'74222','new_theme','padding-left','10',0,''),(613739,193289,'74222','new_theme','padding-right','10',0,''),(613740,193289,'74222','new_theme','padding-bottom','15',0,''),(613741,193289,'74222','new_theme','border-bottom-width','1',0,''),(613742,193289,'74222','new_theme','border-bottom-color','$content-border-1',0,''),(613743,193290,'74223','new_theme','color','$content-color-1',0,''),(613744,193290,'74223','new_theme','font-size','14',0,''),(613745,193290,'74223','new_theme','font-weight','700',0,''),(613746,193291,'74224','new_theme','font-weight','normal',0,''),(613747,193291,'74224','new_theme','text-align','right',0,''),(613748,193291,'74224','new_theme','color','$fade-color-1',0,''),(613749,193291,'74224','new_theme','font-size','11',0,''),(613750,193291,'74224','new_theme','text-transform','uppercase',0,''),(613751,193292,'74225','new_theme','color','$fade-color-1',0,''),(613752,193292,'74225','new_theme','font-size','12',0,''),(613753,193292,'74225','new_theme','padding-top','20',0,''),(613754,193292,'74225','new_theme','padding-bottom','20',0,''),(613755,193292,'74225','new_theme','text-align','center',0,''),(613756,193293,'74226','new_theme','font-weight','normal',0,''),(613757,193293,'74226','new_theme','padding-bottom','10',0,''),(613758,193293,'74226','new_theme','padding-top','10',0,''),(613759,193293,'74226','new_theme','text-align','center',0,''),(613760,193293,'74226','new_theme','logo_from','theme',0,''),(613761,193294,'74227','new_theme','block_type','1',0,''),(613762,193294,'74227','new_theme','background-color','$content-bg-2',0,''),(613763,193294,'74227','new_theme','padding-top','20',0,''),(613764,193294,'74227','new_theme','padding-bottom','20',0,''),(613765,193295,'74228','new_theme','block_type','1',0,''),(613766,193295,'74228','new_theme','max-width','800',0,''),(613767,193295,'74228','new_theme','margin','0 auto',0,''),(613768,193296,'74229','new_theme','color','$fade-color-1',0,''),(613769,193296,'74229','new_theme','font-size','12',0,''),(613770,193296,'74229','new_theme','padding-top','20',0,''),(613771,193296,'74229','new_theme','padding-bottom','20',0,''),(613772,193296,'74229','new_theme','text-align','left',0,''),(613773,193297,'74230','new_theme','block_type','1',0,''),(613774,193297,'74230','new_theme','background-color','$content-bg-1',0,''),(613775,193297,'74230','new_theme','padding-top','20',0,''),(613776,193297,'74230','new_theme','padding-left','20',0,''),(613777,193297,'74230','new_theme','padding-right','20',0,''),(613778,193297,'74230','new_theme','padding-bottom','20',0,''),(613779,193297,'74230','new_theme','border-top-width','1',0,''),(613780,193297,'74230','new_theme','border-left-width','1',0,''),(613781,193297,'74230','new_theme','border-right-width','1',0,''),(613782,193297,'74230','new_theme','border-bottom-width','1',0,''),(613783,193297,'74230','new_theme','border-top-color','$content-border-1',0,''),(613784,193297,'74230','new_theme','border-left-color','$content-border-1',0,''),(613785,193297,'74230','new_theme','border-bottom-color','$content-border-1',0,''),(613786,193297,'74230','new_theme','border-right-color','$content-border-1',0,''),(613787,193298,'74231','new_theme','block_type','2',0,''),(613788,193299,'74232','new_theme','font-weight','normal',0,''),(613789,193299,'74232','new_theme','padding-bottom','10',0,''),(613790,193299,'74232','new_theme','padding-top','10',0,''),(613791,193299,'74232','new_theme','logo_from','theme',0,''),(613792,193300,'74233','new_theme','font-weight','normal',0,''),(613793,193300,'74233','new_theme','text-align','right',0,''),(613794,193300,'74233','new_theme','color','$fade-color-1',0,''),(613795,193300,'74233','new_theme','font-size','11',0,''),(613796,193300,'74233','new_theme','text-transform','uppercase',0,''),(613797,193301,'74234','new_theme','color','$content-color-1',0,''),(613798,193301,'74234','new_theme','font-size','14',0,''),(613799,193301,'74234','new_theme','font-weight','700',0,''),(613800,193301,'74234','new_theme','text-align','right',0,''),(613801,193302,'74235','new_theme','font-weight','normal',0,''),(613802,193302,'74235','new_theme','padding-top','20',0,''),(613803,193302,'74235','new_theme','padding-bottom','20',0,''),(613804,193302,'74235','new_theme','color','$content-color-1',0,''),(613805,193302,'74235','new_theme','font-size','14',0,''),(613806,193303,'74236','new_theme','block_type','1',0,''),(613807,193303,'74236','new_theme','font-weight','normal',0,''),(613808,193303,'74236','new_theme','padding-top','20',0,''),(613809,193303,'74236','new_theme','background-color','$footer-bg-1',0,''),(613810,193303,'74236','new_theme','color','$footer-color-1',0,''),(613811,193304,'74237','new_theme','block_type','14',0,''),(613812,193304,'74237','new_theme','margin-bottom','15',0,''),(613813,193304,'74237','new_theme','schema','14-2',0,'8451'),(613814,193304,'74237','new_theme','schema','14-3',0,'8444'),(613815,193304,'74237','new_theme','style_class','preFooter',0,''),(613816,193304,'74237','new_theme','visibility_checkout','1',0,''),(613817,193305,'74238','new_theme','block_type','1',0,''),(613818,193306,'74239','new_theme','class','menu-style-2',0,''),(613819,193307,'1695906739.5696','new_theme','text','##NAVBAR_TITLE_ACCOUNT##',0,''),(613820,193307,'1695906739.5696','new_theme','style_class','footerTitle',0,''),(613821,193307,'1695906739.5696','new_theme','font-family','$font-1',0,''),(613822,193307,'1695906739.5696','new_theme','font-size','20',0,''),(613823,193307,'1695906739.5696','new_theme','text-transform','uppercase',0,''),(613824,193308,'74241','new_theme','block_type','1',0,''),(613825,193309,'74243','new_theme','class','menu-style-2',0,''),(613826,193310,'1695906751.0591','new_theme','text','##TEXT_PRODUCTS##',0,''),(613827,193310,'1695906751.0591','new_theme','font-family','$font-1',0,''),(613828,193310,'1695906751.0591','new_theme','font-size','20',0,''),(613829,193310,'1695906751.0591','new_theme','text-transform','uppercase',0,''),(613830,193310,'1695906751.0591','new_theme','style_class','footerTitle',0,''),(613831,193311,'74244','new_theme','block_type','1',0,''),(613832,193312,'74246','new_theme','class','menu-style-2',0,''),(613833,193313,'1695906756.0887','new_theme','text','##TEXT_SHOP##',0,''),(613834,193313,'1695906756.0887','new_theme','style_class','footerTitle',0,''),(613835,193313,'1695906756.0887','new_theme','font-family','$font-1',0,''),(613836,193313,'1695906756.0887','new_theme','font-size','20',0,''),(613837,193313,'1695906756.0887','new_theme','text-transform','uppercase',0,''),(613838,193314,'74247','new_theme','block_type','1',0,''),(613839,193315,'74248','new_theme','view_item','phone_number',0,''),(613840,193316,'74249','new_theme','view_item','address',0,''),(613841,193316,'74249','new_theme','address_spacer',',<span> </span>',0,''),(613842,193317,'1695906761.6568','new_theme','text','##TEXT_CONTACT##',0,''),(613843,193317,'1695906761.6568','new_theme','font-family','$font-1',0,''),(613844,193317,'1695906761.6568','new_theme','font-size','20',0,''),(613845,193317,'1695906761.6568','new_theme','text-transform','uppercase',0,''),(613846,193317,'1695906761.6568','new_theme','style_class','footerTitle',0,''),(613847,193318,'74256','new_theme','block_type','2',0,''),(613848,193318,'74256','new_theme','font-weight','400',0,''),(613849,193318,'74256','new_theme','padding-top','20',0,''),(613850,193318,'74256','new_theme','padding-bottom','20',0,''),(613851,193318,'74256','new_theme','schema','2-2',0,''),(613852,193318,'74256','new_theme','schema','2-3',0,'8451'),(613853,193320,'74258','new_theme','address_spacer',', ',0,''),(613854,193320,'74258','new_theme','font-weight','400',0,''),(613855,193320,'74258','new_theme','padding-bottom','10',0,'8451'),(613856,193320,'74258','new_theme','margin-bottom','10',0,'8451'),(613857,193320,'74258','new_theme','border-bottom-width','1',0,'8451'),(613858,193320,'74258','new_theme','border-bottom-color','$content-border-1',0,'8451'),(613859,193321,'94723','new_theme','block_type','5',0,''),(613860,193322,'94724','new_theme','text','##TEXT_LANGUAGE##',0,''),(613861,193324,'94726','new_theme','block_type','5',0,''),(613862,193325,'94727','new_theme','text','##TEXT_CURRENCY##',0,''),(613863,193327,'74263','new_theme','block_type','1',0,''),(613864,193327,'74263','new_theme','font-weight','normal',0,''),(613865,193328,'74264','new_theme','block_type','2',0,''),(613866,193328,'74264','new_theme','font-weight','normal',0,''),(613867,193328,'74264','new_theme','padding-bottom','20',0,''),(613868,193329,'74265','new_theme','block_type','1',0,''),(613869,193329,'74265','new_theme','margin-right','20',0,''),(613870,193332,'74268','new_theme','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(613871,193332,'74268','new_theme','font-weight','normal',0,''),(613872,193332,'74268','new_theme','padding-bottom','20',0,''),(613873,193332,'74268','new_theme','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',0,''),(613874,193334,'74270','new_theme','block_type','1',0,''),(613875,193334,'74270','new_theme','font-weight','normal',0,''),(613876,193334,'74270','new_theme','style_class','gift-card-view',0,''),(613877,193334,'74270','new_theme','text-align','center',0,''),(613878,193334,'74270','new_theme','padding-bottom','20',0,''),(613879,193334,'74270','new_theme','background-color','$highlight-box-bg-1',0,''),(613880,193334,'74270','new_theme','padding-left','20',0,''),(613881,193334,'74270','new_theme','padding-right','20',0,''),(613882,193334,'74270','new_theme','color','$highlight-box-color-1',0,''),(613883,193335,'74271','new_theme','block_type','1',0,''),(613884,193335,'74271','new_theme','font-weight','normal',0,''),(613885,193335,'74271','new_theme','padding-top','10',0,''),(613886,193336,'74272','new_theme','font-size','12',0,''),(613887,193336,'74272','new_theme','font-weight','bold',0,''),(613888,193336,'74272','new_theme','text-align','center',0,''),(613889,193336,'74272','new_theme','style_class','email',0,''),(613890,193337,'74273','new_theme','text','<p>If you require further assistance please contact us</p>',1,''),(613891,193337,'74273','new_theme','font-weight','normal',0,''),(613892,193337,'74273','new_theme','text-align','center',0,''),(613893,193337,'74273','new_theme','font-size','12',0,''),(613894,193337,'74273','new_theme','padding-top','10',0,''),(613895,193337,'74273','new_theme','padding-bottom','5',0,''),(613896,193337,'74273','new_theme','border-top-width','1',0,''),(613897,193337,'74273','new_theme','border-top-color','$content-border-3',0,''),(613898,193337,'74273','new_theme','text','<p>If you require further assistance please contact us</p>',0,''),(613899,193338,'74274','new_theme','font-size','12',0,''),(613900,193338,'74274','new_theme','font-weight','bold',0,''),(613901,193338,'74274','new_theme','text-align','center',0,''),(613902,193338,'74274','new_theme','style_class','phone',0,''),(613903,193338,'74274','new_theme','padding-bottom','5',0,''),(613904,193339,'74275','new_theme','text','<p>WHAT TO DO NEXT:</p>',1,''),(613905,193339,'74275','new_theme','font-weight','normal',0,''),(613906,193339,'74275','new_theme','text-align','center',0,''),(613907,193339,'74275','new_theme','padding-top','20',0,''),(613908,193339,'74275','new_theme','padding-bottom','10',0,''),(613909,193339,'74275','new_theme','style_class','question-ico',0,''),(613910,193339,'74275','new_theme','border-top-width','1',0,''),(613911,193339,'74275','new_theme','border-top-color','$content-border-3',0,''),(613912,193339,'74275','new_theme','font-size','18',0,''),(613913,193339,'74275','new_theme','text','<p>WHAT TO DO NEXT:</p>',0,''),(613914,193340,'74276','new_theme','text','<p>osCommerce</p>\n',1,''),(613915,193340,'74276','new_theme','font-family','$font-1',0,''),(613916,193340,'74276','new_theme','font-size','24',0,''),(613917,193340,'74276','new_theme','font-weight','normal',0,''),(613918,193340,'74276','new_theme','text-align','center',0,''),(613919,193340,'74276','new_theme','padding-top','10',0,''),(613920,193340,'74276','new_theme','padding-bottom','20',0,''),(613921,193340,'74276','new_theme','text','<p>osCommerce</p>\n',0,''),(613922,193341,'74277','new_theme','block_type','4',0,''),(613923,193341,'74277','new_theme','color','$highlight-box-color-2',0,''),(613924,193341,'74277','new_theme','font-size','30',0,''),(613925,193341,'74277','new_theme','font-weight','normal',0,''),(613926,193341,'74277','new_theme','background-color','$highlight-box-bg-2',0,''),(613927,193341,'74277','new_theme','padding-top','5',0,''),(613928,193341,'74277','new_theme','padding-left','10',0,''),(613929,193341,'74277','new_theme','padding-right','10',0,''),(613930,193341,'74277','new_theme','padding-bottom','5',0,''),(613931,193342,'74278','new_theme','text','<p>Your code is:</p>',1,''),(613932,193342,'74278','new_theme','font-weight','normal',0,''),(613933,193342,'74278','new_theme','text','<p>Your code is:</p>',0,''),(613934,193344,'74280','new_theme','font-weight','normal',0,''),(613935,193344,'74280','new_theme','text-align','center',0,''),(613936,193344,'74280','new_theme','padding-bottom','20',0,''),(613937,193345,'74281','new_theme','font-size','60',0,''),(613938,193345,'74281','new_theme','font-weight','bold',0,''),(613939,193345,'74281','new_theme','text-align','center',0,''),(613940,193345,'74281','new_theme','line-height','100',0,''),(613941,193345,'74281','new_theme','padding-bottom','20',0,''),(613942,193345,'74281','new_theme','line_height_measure','px',0,''),(613943,193346,'74282','new_theme','text','<p>PERSONAL MESSAGE</p>',1,''),(613944,193346,'74282','new_theme','font-size','18',0,''),(613945,193346,'74282','new_theme','font-weight','normal',0,''),(613946,193346,'74282','new_theme','text-align','center',0,''),(613947,193346,'74282','new_theme','padding-top','20',0,''),(613948,193346,'74282','new_theme','padding-bottom','10',0,''),(613949,193346,'74282','new_theme','border-top-width','1',0,''),(613950,193346,'74282','new_theme','border-top-color','$content-border-3',0,''),(613951,193346,'74282','new_theme','text','<p>PERSONAL MESSAGE</p>',0,''),(613952,193347,'74284','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',1,''),(613953,193347,'74284','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',0,''),(613954,193347,'74284','new_theme','text-align','center',0,''),(613955,193347,'74284','new_theme','padding-top','20',0,''),(613956,193347,'74284','new_theme','logo_from','theme',0,''),(613957,193348,'74285','new_theme','text','<p>GIFT CARD</p>',1,''),(613958,193348,'74285','new_theme','font-size','30',0,''),(613959,193348,'74285','new_theme','font-weight','normal',0,''),(613960,193348,'74285','new_theme','border-top-width','1',0,''),(613961,193348,'74285','new_theme','border-top-color','$content-border-3',0,''),(613962,193348,'74285','new_theme','style_class','gift-ico',0,''),(613963,193348,'74285','new_theme','text-align','center',0,''),(613964,193348,'74285','new_theme','padding-top','15',0,''),(613965,193348,'74285','new_theme','text','<p>GIFT CARD</p>',0,''),(613966,193349,'74286','new_theme','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(613967,193349,'74286','new_theme','font-weight','normal',0,''),(613968,193349,'74286','new_theme','text-align','center',0,''),(613969,193349,'74286','new_theme','padding-bottom','10',0,''),(613970,193349,'74286','new_theme','font-size','14',0,''),(613971,193349,'74286','new_theme','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',0,''),(613972,193350,'74287','new_theme','block_type','1',0,''),(613973,193350,'74287','new_theme','font-weight','normal',0,''),(613974,193350,'74287','new_theme','style_class','gift-card-view',0,''),(613975,193350,'74287','new_theme','text-align','center',0,''),(613976,193350,'74287','new_theme','padding-bottom','20',0,''),(613977,193350,'74287','new_theme','background-color','$content-bg-2',0,''),(613978,193350,'74287','new_theme','padding-left','20',0,''),(613979,193350,'74287','new_theme','padding-right','20',0,''),(613980,193350,'74287','new_theme','color','$fade-color-2',0,''),(613981,193351,'74288','new_theme','font-size','60',0,''),(613982,193351,'74288','new_theme','font-weight','bold',0,''),(613983,193351,'74288','new_theme','text-align','center',0,''),(613984,193351,'74288','new_theme','line-height','100',0,''),(613985,193351,'74288','new_theme','padding-bottom','20',0,''),(613986,193351,'74288','new_theme','line_height_measure','px',0,''),(613987,193352,'74289','new_theme','block_type','4',0,''),(613988,193352,'74289','new_theme','color','$highlight-box-color-2',0,''),(613989,193352,'74289','new_theme','font-size','30',0,''),(613990,193352,'74289','new_theme','font-weight','normal',0,''),(613991,193352,'74289','new_theme','background-color','$highlight-box-bg-2',0,''),(613992,193352,'74289','new_theme','padding-top','5',0,''),(613993,193352,'74289','new_theme','padding-left','10',0,''),(613994,193352,'74289','new_theme','padding-right','10',0,''),(613995,193352,'74289','new_theme','padding-bottom','5',0,''),(613996,193353,'74290','new_theme','text','<p>Your code is:</p>',1,''),(613997,193353,'74290','new_theme','font-weight','normal',0,''),(613998,193353,'74290','new_theme','text','<p>Your code is:</p>',0,''),(613999,193355,'74292','new_theme','block_type','1',0,''),(614000,193355,'74292','new_theme','font-weight','normal',0,''),(614001,193355,'74292','new_theme','padding-top','10',0,''),(614002,193356,'74293','new_theme','font-size','12',0,''),(614003,193356,'74293','new_theme','font-weight','bold',0,''),(614004,193356,'74293','new_theme','text-align','center',0,''),(614005,193356,'74293','new_theme','style_class','email',0,''),(614006,193357,'74294','new_theme','text','<p>If you require further assistance please contact us</p>',1,''),(614007,193357,'74294','new_theme','font-weight','normal',0,''),(614008,193357,'74294','new_theme','text-align','center',0,''),(614009,193357,'74294','new_theme','font-size','12',0,''),(614010,193357,'74294','new_theme','padding-top','10',0,''),(614011,193357,'74294','new_theme','padding-bottom','5',0,''),(614012,193357,'74294','new_theme','border-top-width','1',0,''),(614013,193357,'74294','new_theme','border-top-color','$content-border-3',0,''),(614014,193357,'74294','new_theme','text','<p>If you require further assistance please contact us</p>',0,''),(614015,193358,'74295','new_theme','font-size','12',0,''),(614016,193358,'74295','new_theme','font-weight','bold',0,''),(614017,193358,'74295','new_theme','text-align','center',0,''),(614018,193358,'74295','new_theme','style_class','phone',0,''),(614019,193358,'74295','new_theme','padding-bottom','5',0,''),(614020,193359,'74296','new_theme','font-weight','normal',0,''),(614021,193359,'74296','new_theme','text-align','center',0,''),(614022,193359,'74296','new_theme','padding-bottom','20',0,''),(614023,193360,'74297','new_theme','text','<p>PERSONAL MESSAGE</p>',1,''),(614024,193360,'74297','new_theme','font-size','18',0,''),(614025,193360,'74297','new_theme','font-weight','normal',0,''),(614026,193360,'74297','new_theme','text-align','center',0,''),(614027,193360,'74297','new_theme','padding-top','20',0,''),(614028,193360,'74297','new_theme','padding-bottom','10',0,''),(614029,193360,'74297','new_theme','border-top-width','1',0,''),(614030,193360,'74297','new_theme','border-top-color','$content-border-3',0,''),(614031,193360,'74297','new_theme','text','<p>PERSONAL MESSAGE</p>',0,''),(614032,193361,'74298','new_theme','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(614033,193361,'74298','new_theme','font-weight','normal',0,''),(614034,193361,'74298','new_theme','text-align','center',0,''),(614035,193361,'74298','new_theme','padding-bottom','10',0,''),(614036,193361,'74298','new_theme','font-size','14',0,''),(614037,193361,'74298','new_theme','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',0,''),(614038,193362,'74299','new_theme','text','<p>GIFT CARD</p>',1,''),(614039,193362,'74299','new_theme','font-size','30',0,''),(614040,193362,'74299','new_theme','font-weight','normal',0,''),(614041,193362,'74299','new_theme','border-top-width','1',0,''),(614042,193362,'74299','new_theme','border-top-color','$content-border-3',0,''),(614043,193362,'74299','new_theme','style_class','gift-ico',0,''),(614044,193362,'74299','new_theme','text-align','center',0,''),(614045,193362,'74299','new_theme','padding-top','15',0,''),(614046,193362,'74299','new_theme','text','<p>GIFT CARD</p>',0,''),(614047,193363,'74300','new_theme','text','<p>WHAT TO DO NEXT:</p>',1,''),(614048,193363,'74300','new_theme','font-weight','normal',0,''),(614049,193363,'74300','new_theme','text-align','center',0,''),(614050,193363,'74300','new_theme','padding-top','20',0,''),(614051,193363,'74300','new_theme','padding-bottom','10',0,''),(614052,193363,'74300','new_theme','style_class','question-ico',0,''),(614053,193363,'74300','new_theme','border-top-width','1',0,''),(614054,193363,'74300','new_theme','border-top-color','$content-border-3',0,''),(614055,193363,'74300','new_theme','font-size','18',0,''),(614056,193363,'74300','new_theme','text','<p>WHAT TO DO NEXT:</p>',0,''),(614057,193364,'74301','new_theme','text','<p>HOLBI</p>',1,''),(614058,193364,'74301','new_theme','font-family','$font-1',0,''),(614059,193364,'74301','new_theme','font-size','24',0,''),(614060,193364,'74301','new_theme','font-weight','normal',0,''),(614061,193364,'74301','new_theme','text-align','center',0,''),(614062,193364,'74301','new_theme','padding-top','10',0,''),(614063,193364,'74301','new_theme','padding-bottom','20',0,''),(614064,193364,'74301','new_theme','text','<p>HOLBI</p>',0,''),(614065,193365,'94729','new_theme','block_type','1',0,''),(614066,193365,'94729','new_theme','font-weight','normal',0,''),(614067,193365,'94729','new_theme','style_class','gift-card-view',0,''),(614068,193365,'94729','new_theme','text-align','center',0,''),(614069,193365,'94729','new_theme','padding-bottom','20',0,''),(614070,193365,'94729','new_theme','background-color','$content-bg-2',0,''),(614071,193365,'94729','new_theme','padding-left','20',0,''),(614072,193365,'94729','new_theme','padding-right','20',0,''),(614073,193366,'94730','new_theme','block_type','1',0,''),(614074,193366,'94730','new_theme','font-weight','normal',0,''),(614075,193366,'94730','new_theme','padding-top','10',0,''),(614076,193367,'94731','new_theme','font-size','12',0,''),(614077,193367,'94731','new_theme','font-weight','bold',0,''),(614078,193367,'94731','new_theme','text-align','center',0,''),(614079,193367,'94731','new_theme','style_class','email',0,''),(614080,193368,'94732','new_theme','font-size','12',0,''),(614081,193368,'94732','new_theme','font-weight','bold',0,''),(614082,193368,'94732','new_theme','text-align','center',0,''),(614083,193368,'94732','new_theme','style_class','phone',0,''),(614084,193368,'94732','new_theme','padding-bottom','5',0,''),(614085,193369,'94733','new_theme','text','If you require further assistance please contact us',0,''),(614086,193369,'94733','new_theme','font-size','12',0,''),(614087,193369,'94733','new_theme','text-align','center',0,''),(614088,193369,'94733','new_theme','padding-top','10',0,''),(614089,193370,'94734','new_theme','block_type','4',0,''),(614090,193370,'94734','new_theme','color','$highlight-box-color-2',0,''),(614091,193370,'94734','new_theme','font-size','30',0,''),(614092,193370,'94734','new_theme','font-weight','normal',0,''),(614093,193370,'94734','new_theme','background-color','$highlight-box-bg-2',0,''),(614094,193370,'94734','new_theme','padding-top','5',0,''),(614095,193370,'94734','new_theme','padding-left','10',0,''),(614096,193370,'94734','new_theme','padding-right','10',0,''),(614097,193370,'94734','new_theme','padding-bottom','5',0,''),(614098,193371,'94735','new_theme','text','Your code is:',0,''),(614099,193371,'94735','new_theme','font-size','30',0,''),(614100,193371,'94735','new_theme','color','$highlight-box-color-2',0,''),(614101,193372,'94736','new_theme','color','$highlight-box-color-2',0,''),(614102,193372,'94736','new_theme','font-size','30',0,''),(614103,193373,'94737','new_theme','block_type','1',0,''),(614104,193374,'94738','new_theme','text','<p>PERSONAL MESSAGE</p>',1,''),(614105,193374,'94738','new_theme','font-size','18',0,''),(614106,193374,'94738','new_theme','font-weight','normal',0,''),(614107,193374,'94738','new_theme','text-align','center',0,''),(614108,193374,'94738','new_theme','padding-top','20',0,''),(614109,193374,'94738','new_theme','padding-bottom','10',0,''),(614110,193374,'94738','new_theme','border-top-width','1',0,''),(614111,193374,'94738','new_theme','border-top-color','$content-border-3',0,''),(614112,193374,'94738','new_theme','text','<p>PERSONAL MESSAGE</p>',0,''),(614113,193375,'94739','new_theme','text','HOLBI',0,''),(614114,193375,'94739','new_theme','font-size','24',0,''),(614115,193375,'94739','new_theme','padding-top','20',0,''),(614116,193375,'94739','new_theme','text-align','center',0,''),(614117,193375,'94739','new_theme','padding-bottom','20',0,''),(614118,193376,'94740','new_theme','border-top-color','$content-border-3',0,''),(614119,193376,'94740','new_theme','border-top-width','1',0,''),(614120,193376,'94740','new_theme','padding-top','20',0,''),(614121,193376,'94740','new_theme','font-size','30',0,''),(614122,193376,'94740','new_theme','text-align','center',0,''),(614123,193376,'94740','new_theme','text','GIFT CARD',0,''),(614124,193377,'94741','new_theme','text-align','center',0,''),(614125,193377,'94741','new_theme','font-weight','bold',0,''),(614126,193377,'94741','new_theme','font-size','60',0,''),(614127,193378,'94742','new_theme','font-size','20',0,''),(614128,193378,'94742','new_theme','text-align','center',0,''),(614129,193378,'94742','new_theme','padding-top','20',0,''),(614130,193378,'94742','new_theme','padding-bottom','20',0,''),(614131,193379,'94743','new_theme','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(614132,193379,'94743','new_theme','text-align','center',0,''),(614133,193379,'94743','new_theme','font-size','14',0,''),(614134,193379,'94743','new_theme','padding-bottom','20',0,''),(614135,193380,'94744','new_theme','text','WHAT TO DO NEXT:',0,''),(614136,193380,'94744','new_theme','font-size','18',0,''),(614137,193380,'94744','new_theme','text-align','center',0,''),(614138,193380,'94744','new_theme','padding-top','20',0,''),(614139,193380,'94744','new_theme','padding-bottom','10',0,''),(614140,193380,'94744','new_theme','border-top-width','1',0,''),(614141,193380,'94744','new_theme','border-top-color','$content-border-3',0,''),(614142,193381,'94746','new_theme','block_type','1',0,''),(614143,193381,'94746','new_theme','font-weight','normal',0,''),(614144,193381,'94746','new_theme','style_class','gift-card-view',0,''),(614145,193381,'94746','new_theme','text-align','center',0,''),(614146,193381,'94746','new_theme','padding-bottom','20',0,''),(614147,193381,'94746','new_theme','background-color','$highlight-box-bg-1',0,''),(614148,193381,'94746','new_theme','padding-left','20',0,''),(614149,193381,'94746','new_theme','padding-right','20',0,''),(614150,193381,'94746','new_theme','color','$highlight-box-color-1',0,''),(614151,193382,'94747','new_theme','block_type','1',0,''),(614152,193382,'94747','new_theme','font-weight','normal',0,''),(614153,193382,'94747','new_theme','padding-top','10',0,''),(614154,193383,'94748','new_theme','font-size','12',0,''),(614155,193383,'94748','new_theme','font-weight','bold',0,''),(614156,193383,'94748','new_theme','text-align','center',0,''),(614157,193383,'94748','new_theme','style_class','email',0,''),(614158,193383,'94748','new_theme','color','$highlight-box-color-1',0,''),(614159,193384,'94749','new_theme','font-size','12',0,''),(614160,193384,'94749','new_theme','font-weight','bold',0,''),(614161,193384,'94749','new_theme','text-align','center',0,''),(614162,193384,'94749','new_theme','style_class','phone',0,''),(614163,193384,'94749','new_theme','padding-bottom','5',0,''),(614164,193384,'94749','new_theme','color','$highlight-box-color-1',0,''),(614165,193385,'94750','new_theme','text','If you require further assistance please contact us',0,''),(614166,193385,'94750','new_theme','font-size','12',0,''),(614167,193385,'94750','new_theme','color','$highlight-box-color-1',0,''),(614168,193385,'94750','new_theme','text-align','center',0,''),(614169,193385,'94750','new_theme','padding-top','10',0,''),(614170,193386,'94751','new_theme','block_type','4',0,''),(614171,193386,'94751','new_theme','color','$highlight-box-color-2',0,''),(614172,193386,'94751','new_theme','font-size','30',0,''),(614173,193386,'94751','new_theme','font-weight','normal',0,''),(614174,193386,'94751','new_theme','background-color','$highlight-box-bg-2',0,''),(614175,193386,'94751','new_theme','padding-top','5',0,''),(614176,193386,'94751','new_theme','padding-left','10',0,''),(614177,193386,'94751','new_theme','padding-right','10',0,''),(614178,193386,'94751','new_theme','padding-bottom','5',0,''),(614179,193387,'94752','new_theme','text','Your code is:',0,''),(614180,193387,'94752','new_theme','font-size','30',0,''),(614181,193387,'94752','new_theme','color','$highlight-box-color-2',0,''),(614182,193388,'94753','new_theme','color','$highlight-box-color-2',0,''),(614183,193388,'94753','new_theme','font-size','30',0,''),(614184,193389,'94754','new_theme','block_type','1',0,''),(614185,193390,'94755','new_theme','text','<p>PERSONAL MESSAGE</p>',1,''),(614186,193390,'94755','new_theme','font-size','18',0,''),(614187,193390,'94755','new_theme','font-weight','normal',0,''),(614188,193390,'94755','new_theme','text-align','center',0,''),(614189,193390,'94755','new_theme','padding-top','20',0,''),(614190,193390,'94755','new_theme','padding-bottom','10',0,''),(614191,193390,'94755','new_theme','border-top-width','1',0,''),(614192,193390,'94755','new_theme','border-top-color','$content-border-3',0,''),(614193,193390,'94755','new_theme','text','<p>PERSONAL MESSAGE</p>',0,''),(614194,193391,'94757','new_theme','border-top-color','$content-border-3',0,''),(614195,193391,'94757','new_theme','border-top-width','1',0,''),(614196,193391,'94757','new_theme','padding-top','20',0,''),(614197,193391,'94757','new_theme','font-size','30',0,''),(614198,193391,'94757','new_theme','text-align','center',0,''),(614199,193391,'94757','new_theme','color','$highlight-box-color-1',0,''),(614200,193391,'94757','new_theme','text','GIFT CARD',0,''),(614201,193392,'94758','new_theme','text-align','center',0,''),(614202,193392,'94758','new_theme','font-weight','bold',0,''),(614203,193392,'94758','new_theme','font-size','60',0,''),(614204,193392,'94758','new_theme','color','$highlight-box-color-1',0,''),(614205,193393,'94759','new_theme','font-size','20',0,''),(614206,193393,'94759','new_theme','text-align','center',0,''),(614207,193393,'94759','new_theme','color','$highlight-box-color-1',0,''),(614208,193393,'94759','new_theme','padding-top','20',0,''),(614209,193393,'94759','new_theme','padding-bottom','20',0,''),(614210,193394,'94760','new_theme','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(614211,193394,'94760','new_theme','text-align','center',0,''),(614212,193394,'94760','new_theme','color','$highlight-box-color-1',0,''),(614213,193394,'94760','new_theme','font-size','14',0,''),(614214,193394,'94760','new_theme','padding-bottom','20',0,''),(614215,193395,'94761','new_theme','text','WHAT TO DO NEXT:',0,''),(614216,193395,'94761','new_theme','font-size','18',0,''),(614217,193395,'94761','new_theme','text-align','center',0,''),(614218,193395,'94761','new_theme','padding-top','20',0,''),(614219,193395,'94761','new_theme','padding-bottom','10',0,''),(614220,193395,'94761','new_theme','border-top-width','1',0,''),(614221,193395,'94761','new_theme','border-top-color','$content-border-3',0,''),(614222,193396,'1707902674.2595','new_theme','logo_from','theme',0,''),(614223,193396,'1707902674.2595','new_theme','text-align','center',0,''),(614224,193396,'1707902674.2595','new_theme','padding-top','20',0,''),(614225,193398,'74302','new_theme','block_type','1',0,''),(614226,193400,'74304','new_theme','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(614227,193400,'74304','new_theme','text-align','center',0,''),(614228,193401,'74305','new_theme','block_type','1',0,''),(614229,193401,'74305','new_theme','font-weight','normal',0,''),(614230,193401,'74305','new_theme','style_class','gift-card-view',0,''),(614231,193401,'74305','new_theme','text-align','center',0,''),(614232,193401,'74305','new_theme','padding-bottom','20',0,''),(614233,193401,'74305','new_theme','background-color','$highlight-box-bg-3',0,''),(614234,193401,'74305','new_theme','padding-left','20',0,''),(614235,193401,'74305','new_theme','padding-right','20',0,''),(614236,193401,'74305','new_theme','color','$highlight-box-color-3',0,''),(614237,193402,'74306','new_theme','block_type','4',0,''),(614238,193402,'74306','new_theme','color','$highlight-box-color-2',0,''),(614239,193402,'74306','new_theme','font-size','30',0,''),(614240,193402,'74306','new_theme','font-weight','normal',0,''),(614241,193402,'74306','new_theme','background-color','$highlight-box-bg-2',0,''),(614242,193402,'74306','new_theme','padding-top','5',0,''),(614243,193402,'74306','new_theme','padding-left','10',0,''),(614244,193402,'74306','new_theme','padding-right','10',0,''),(614245,193402,'74306','new_theme','padding-bottom','5',0,''),(614246,193403,'74307','new_theme','text','<p>Your code is:</p>',1,''),(614247,193403,'74307','new_theme','font-weight','normal',0,''),(614248,193403,'74307','new_theme','text','<p>Your code is:</p>',0,''),(614249,193405,'74309','new_theme','text','<p>WHAT TO DO NEXT:</p>',1,''),(614250,193405,'74309','new_theme','font-weight','normal',0,''),(614251,193405,'74309','new_theme','text-align','center',0,''),(614252,193405,'74309','new_theme','padding-top','20',0,''),(614253,193405,'74309','new_theme','padding-bottom','10',0,''),(614254,193405,'74309','new_theme','style_class','question-ico',0,''),(614255,193405,'74309','new_theme','border-top-width','1',0,''),(614256,193405,'74309','new_theme','border-top-color','$content-border-3',0,''),(614257,193405,'74309','new_theme','font-size','18',0,''),(614258,193405,'74309','new_theme','text','<p>WHAT TO DO NEXT:</p>',0,''),(614259,193406,'74310','new_theme','text','<p>osCommerce</p>\n',1,''),(614260,193406,'74310','new_theme','font-family','$font-1',0,''),(614261,193406,'74310','new_theme','font-size','24',0,''),(614262,193406,'74310','new_theme','font-weight','normal',0,''),(614263,193406,'74310','new_theme','text-align','center',0,''),(614264,193406,'74310','new_theme','padding-top','10',0,''),(614265,193406,'74310','new_theme','padding-bottom','20',0,''),(614266,193406,'74310','new_theme','text','<p>osCommerce</p>\n',0,''),(614267,193407,'74311','new_theme','block_type','1',0,''),(614268,193407,'74311','new_theme','font-weight','normal',0,''),(614269,193407,'74311','new_theme','padding-top','10',0,''),(614270,193408,'74312','new_theme','text','<p>If you require further assistance please contact us</p>',1,''),(614271,193408,'74312','new_theme','font-weight','normal',0,''),(614272,193408,'74312','new_theme','text-align','center',0,''),(614273,193408,'74312','new_theme','font-size','12',0,''),(614274,193408,'74312','new_theme','padding-top','10',0,''),(614275,193408,'74312','new_theme','padding-bottom','5',0,''),(614276,193408,'74312','new_theme','border-top-width','1',0,''),(614277,193408,'74312','new_theme','border-top-color','$content-border-3',0,''),(614278,193408,'74312','new_theme','text','<p>If you require further assistance please contact us</p>',0,''),(614279,193409,'74313','new_theme','font-size','12',0,''),(614280,193409,'74313','new_theme','font-weight','bold',0,''),(614281,193409,'74313','new_theme','text-align','center',0,''),(614282,193409,'74313','new_theme','style_class','email',0,''),(614283,193410,'74314','new_theme','font-size','12',0,''),(614284,193410,'74314','new_theme','font-weight','bold',0,''),(614285,193410,'74314','new_theme','text-align','center',0,''),(614286,193410,'74314','new_theme','style_class','phone',0,''),(614287,193410,'74314','new_theme','padding-bottom','5',0,''),(614288,193411,'74315','new_theme','font-weight','normal',0,''),(614289,193411,'74315','new_theme','text-align','center',0,''),(614290,193411,'74315','new_theme','padding-bottom','20',0,''),(614291,193412,'74316','new_theme','text','<p>GIFT CARD</p>',1,''),(614292,193412,'74316','new_theme','font-size','30',0,''),(614293,193412,'74316','new_theme','font-weight','normal',0,''),(614294,193412,'74316','new_theme','border-top-width','1',0,''),(614295,193412,'74316','new_theme','border-top-color','$content-border-3',0,''),(614296,193412,'74316','new_theme','style_class','gift-ico',0,''),(614297,193412,'74316','new_theme','text-align','center',0,''),(614298,193412,'74316','new_theme','padding-top','15',0,''),(614299,193412,'74316','new_theme','text','<p>GIFT CARD</p>',0,''),(614300,193413,'74317','new_theme','text','<p>PERSONAL MESSAGE</p>',1,''),(614301,193413,'74317','new_theme','font-size','18',0,''),(614302,193413,'74317','new_theme','font-weight','normal',0,''),(614303,193413,'74317','new_theme','text-align','center',0,''),(614304,193413,'74317','new_theme','padding-top','20',0,''),(614305,193413,'74317','new_theme','padding-bottom','10',0,''),(614306,193413,'74317','new_theme','border-top-width','1',0,''),(614307,193413,'74317','new_theme','border-top-color','$content-border-3',0,''),(614308,193413,'74317','new_theme','text','<p>PERSONAL MESSAGE</p>',0,''),(614309,193414,'74318','new_theme','font-size','60',0,''),(614310,193414,'74318','new_theme','font-weight','bold',0,''),(614311,193414,'74318','new_theme','text-align','center',0,''),(614312,193414,'74318','new_theme','line-height','100',0,''),(614313,193414,'74318','new_theme','padding-bottom','20',0,''),(614314,193414,'74318','new_theme','line_height_measure','px',0,''),(614315,193415,'74319','new_theme','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(614316,193415,'74319','new_theme','font-weight','normal',0,''),(614317,193415,'74319','new_theme','text-align','center',0,''),(614318,193415,'74319','new_theme','padding-bottom','10',0,''),(614319,193415,'74319','new_theme','font-size','14',0,''),(614320,193415,'74319','new_theme','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',0,''),(614321,193416,'94763','new_theme','block_type','1',0,''),(614322,193416,'94763','new_theme','font-weight','normal',0,''),(614323,193416,'94763','new_theme','style_class','gift-card-view',0,''),(614324,193416,'94763','new_theme','text-align','center',0,''),(614325,193416,'94763','new_theme','padding-bottom','20',0,''),(614326,193416,'94763','new_theme','background-color','$highlight-box-bg-3',0,''),(614327,193416,'94763','new_theme','padding-left','20',0,''),(614328,193416,'94763','new_theme','padding-right','20',0,''),(614329,193416,'94763','new_theme','color','$highlight-box-color-3',0,''),(614330,193417,'94764','new_theme','block_type','1',0,''),(614331,193417,'94764','new_theme','font-weight','normal',0,''),(614332,193417,'94764','new_theme','padding-top','10',0,''),(614333,193418,'94765','new_theme','font-size','12',0,''),(614334,193418,'94765','new_theme','font-weight','bold',0,''),(614335,193418,'94765','new_theme','text-align','center',0,''),(614336,193418,'94765','new_theme','style_class','email',0,''),(614337,193419,'94766','new_theme','font-size','12',0,''),(614338,193419,'94766','new_theme','font-weight','bold',0,''),(614339,193419,'94766','new_theme','text-align','center',0,''),(614340,193419,'94766','new_theme','style_class','phone',0,''),(614341,193419,'94766','new_theme','padding-bottom','5',0,''),(614342,193420,'94767','new_theme','text','If you require further assistance please contact us',0,''),(614343,193420,'94767','new_theme','font-size','12',0,''),(614344,193420,'94767','new_theme','text-align','center',0,''),(614345,193420,'94767','new_theme','padding-top','10',0,''),(614346,193421,'94768','new_theme','block_type','4',0,''),(614347,193421,'94768','new_theme','color','$highlight-box-color-2',0,''),(614348,193421,'94768','new_theme','font-size','30',0,''),(614349,193421,'94768','new_theme','font-weight','normal',0,''),(614350,193421,'94768','new_theme','background-color','$highlight-box-bg-2',0,''),(614351,193421,'94768','new_theme','padding-top','5',0,''),(614352,193421,'94768','new_theme','padding-left','10',0,''),(614353,193421,'94768','new_theme','padding-right','10',0,''),(614354,193421,'94768','new_theme','padding-bottom','5',0,''),(614355,193422,'94769','new_theme','text','Your code is:',0,''),(614356,193422,'94769','new_theme','font-size','30',0,''),(614357,193422,'94769','new_theme','color','$highlight-box-color-2',0,''),(614358,193423,'94770','new_theme','color','$highlight-box-color-2',0,''),(614359,193423,'94770','new_theme','font-size','30',0,''),(614360,193424,'94771','new_theme','block_type','1',0,''),(614361,193425,'94772','new_theme','text','<p>PERSONAL MESSAGE</p>',1,''),(614362,193425,'94772','new_theme','font-size','18',0,''),(614363,193425,'94772','new_theme','font-weight','normal',0,''),(614364,193425,'94772','new_theme','text-align','center',0,''),(614365,193425,'94772','new_theme','padding-top','20',0,''),(614366,193425,'94772','new_theme','padding-bottom','10',0,''),(614367,193425,'94772','new_theme','border-top-width','1',0,''),(614368,193425,'94772','new_theme','border-top-color','$content-border-3',0,''),(614369,193425,'94772','new_theme','text','<p>PERSONAL MESSAGE</p>',0,''),(614370,193426,'94773','new_theme','text','HOLBI',0,''),(614371,193426,'94773','new_theme','color','$highlight-box-color-3',0,''),(614372,193426,'94773','new_theme','font-size','24',0,''),(614373,193426,'94773','new_theme','padding-top','20',0,''),(614374,193426,'94773','new_theme','text-align','center',0,''),(614375,193426,'94773','new_theme','padding-bottom','20',0,''),(614376,193427,'94774','new_theme','border-top-color','$content-border-3',0,''),(614377,193427,'94774','new_theme','border-top-width','1',0,''),(614378,193427,'94774','new_theme','padding-top','20',0,''),(614379,193427,'94774','new_theme','font-size','30',0,''),(614380,193427,'94774','new_theme','text-align','center',0,''),(614381,193427,'94774','new_theme','color','$highlight-box-color-3',0,''),(614382,193427,'94774','new_theme','text','GIFT CARD',0,''),(614383,193428,'94775','new_theme','text-align','center',0,''),(614384,193428,'94775','new_theme','font-weight','bold',0,''),(614385,193428,'94775','new_theme','font-size','60',0,''),(614386,193428,'94775','new_theme','color','$highlight-box-color-3',0,''),(614387,193429,'94776','new_theme','font-size','20',0,''),(614388,193429,'94776','new_theme','text-align','center',0,''),(614389,193429,'94776','new_theme','padding-top','20',0,''),(614390,193429,'94776','new_theme','padding-bottom','20',0,''),(614391,193430,'94777','new_theme','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(614392,193430,'94777','new_theme','text-align','center',0,''),(614393,193430,'94777','new_theme','font-size','14',0,''),(614394,193430,'94777','new_theme','padding-bottom','20',0,''),(614395,193431,'94778','new_theme','text','WHAT TO DO NEXT:',0,''),(614396,193431,'94778','new_theme','font-size','18',0,''),(614397,193431,'94778','new_theme','text-align','center',0,''),(614398,193431,'94778','new_theme','padding-top','20',0,''),(614399,193431,'94778','new_theme','padding-bottom','10',0,''),(614400,193431,'94778','new_theme','border-top-width','1',0,''),(614401,193431,'94778','new_theme','border-top-color','$content-border-3',0,''),(614402,193432,'1713770938.449798','new_theme','from_file','header_1.zip',0,''),(614403,193433,'1713770938.464587','new_theme','block_type','1',0,''),(614404,193433,'1713770938.464587','new_theme','border-bottom-width','1',0,''),(614405,193433,'1713770938.464587','new_theme','border-bottom-color','$header-border-1',0,''),(614406,193433,'1713770938.464587','new_theme','font-weight','normal',0,''),(614407,193433,'1713770938.464587','new_theme','visibility_checkout','1',0,''),(614408,193433,'1713770938.464587','new_theme','background-color','$header-bg-1',0,''),(614409,193433,'1713770938.464587','new_theme','color','$header-color-1',0,''),(614410,193433,'1713770938.464587','new_theme','from_file','header_1.zip',0,''),(614411,193434,'1713770938.467593','new_theme','block_type','5',0,''),(614412,193434,'1713770938.467593','new_theme','font-weight','400',0,''),(614413,193434,'1713770938.467593','new_theme','schema','2-2',0,''),(614414,193434,'1713770938.467593','new_theme','schema','5-2',0,'8451'),(614415,193434,'1713770938.467593','new_theme','schema','5-1',0,'8472'),(614416,193435,'1713770938.470248','new_theme','class','menu-horizontal',0,''),(614417,193435,'1713770938.470248','new_theme','box_align','1',0,''),(614418,193435,'1713770938.470248','new_theme','font-weight','400',0,''),(614419,193435,'1713770938.470248','new_theme','border-top-width','1',0,'8451'),(614420,193435,'1713770938.470248','new_theme','border-top-color','$content-border-1',0,'8451'),(614421,193435,'1713770938.470248','new_theme','display','none',0,'8451'),(614422,193436,'1713770938.51635','new_theme','block_type','1',0,''),(614423,193437,'1713770938.51828','new_theme','font-weight','400',0,''),(614424,193437,'1713770938.51828','new_theme','box_align','3',0,''),(614425,193437,'1713770938.51828','new_theme','show_products','dropdown',0,''),(614426,193437,'1713770938.51828','new_theme','only_icon','on',0,''),(614427,193438,'1713770938.573998','new_theme','font-weight','normal',0,''),(614428,193438,'1713770938.573998','new_theme','box_align','3',0,''),(614429,193438,'1713770938.573998','new_theme','border-left-width','1',0,''),(614430,193438,'1713770938.573998','new_theme','border-left-color','$header-border-1',0,''),(614431,193438,'1713770938.573998','new_theme','only_icon','on',0,''),(614432,193439,'1713770938.61982','new_theme','box_align','3',0,''),(614433,193439,'1713770938.61982','new_theme','font-weight','normal',0,''),(614434,193439,'1713770938.61982','new_theme','padding-top','0',0,'8451'),(614435,193439,'1713770938.61982','new_theme','padding-right','0',0,'8451'),(614436,193439,'1713770938.61982','new_theme','padding-bottom','0',0,'8451'),(614437,193439,'1713770938.61982','new_theme','padding-left','0',0,'8451'),(614438,193439,'1713770938.61982','new_theme','show_symbol_left','1',0,''),(614439,193439,'1713770938.61982','new_theme','show_symbol_right','1',0,''),(614440,193440,'1713770938.663457','new_theme','box_align','3',0,''),(614441,193440,'1713770938.663457','new_theme','font-weight','normal',0,''),(614442,193440,'1713770938.663457','new_theme','border-left-width','1',0,''),(614443,193440,'1713770938.663457','new_theme','border-left-color','$header-border-1',0,''),(614444,193440,'1713770938.663457','new_theme','padding-top','0',0,'8451'),(614445,193440,'1713770938.663457','new_theme','padding-right','0',0,'8451'),(614446,193440,'1713770938.663457','new_theme','padding-bottom','0',0,'8451'),(614447,193440,'1713770938.663457','new_theme','padding-left','0',0,'8451'),(614448,193440,'1713770938.663457','new_theme','show_title','1',0,''),(614449,193441,'1713770938.697915','new_theme','block_type','1',0,''),(614450,193441,'1713770938.697915','new_theme','padding-top','20',0,''),(614451,193441,'1713770938.697915','new_theme','padding-bottom','20',0,''),(614452,193441,'1713770938.697915','new_theme','style_class','header-content',0,''),(614453,193441,'1713770938.697915','new_theme','color','$header-color-1',0,''),(614454,193441,'1713770938.697915','new_theme','background-color','$header-bg-1',0,''),(614455,193441,'1713770938.697915','new_theme','from_file','header_1.zip',0,''),(614456,193441,'1713770938.697915','new_theme','padding-top','12',0,'8444'),(614457,193441,'1713770938.697915','new_theme','padding-bottom','12',0,'8444'),(614458,193442,'1713770938.706821','new_theme','font-weight','400',0,''),(614459,193442,'1713770938.706821','new_theme','box_align','1',0,''),(614460,193442,'1713770938.706821','new_theme','text-align','center',0,'8472'),(614461,193442,'1713770938.706821','new_theme','width','100',0,'8472'),(614462,193442,'1713770938.706821','new_theme','width_measure','%',0,'8472'),(614463,193442,'1713770938.706821','new_theme','logo_from','theme',0,''),(614464,193442,'1713770938.706821','new_theme','padding-right','20',0,''),(614465,193443,'1713770938.709156','new_theme','visibility_checkout','1',0,''),(614466,193443,'1713770938.709156','new_theme','search_history','1',0,''),(614467,193443,'1713770938.709156','new_theme','history_items','5',0,''),(614468,193443,'1713770938.709156','new_theme','margin-left','20',0,''),(614469,193444,'1713770938.773998','new_theme','text','<p class=\"customer-service\">Customer service <b>08000112569</b></p>',1,''),(614470,193444,'1713770938.773998','new_theme','float','right',0,''),(614471,193444,'1713770938.773998','new_theme','display_none','1',0,'8472'),(614472,193444,'1713770938.773998','new_theme','text','<p class=\"customer-service\">Customer service <b>08000112569</b></p>',0,''),(614473,193444,'1713770938.773998','new_theme','display','none',0,'8451'),(614474,193444,'1713770938.773998','new_theme','margin-left','20',0,''),(614475,193445,'1713770938.811953','new_theme','block_type','1',0,''),(614476,193445,'1713770938.811953','new_theme','font-weight','400',0,''),(614477,193445,'1713770938.811953','new_theme','background-color','$header-menu-bg-1',0,''),(614478,193445,'1713770938.811953','new_theme','visibility_checkout','1',0,''),(614479,193445,'1713770938.811953','new_theme','color','$header-menu-color-1',0,''),(614480,193445,'1713770938.811953','new_theme','from_file','header_1.zip',0,''),(614481,193445,'1713770938.811953','new_theme','style_class','header-menu-holder',0,''),(614482,193446,'1713770938.81834','new_theme','class','menu-style-1',0,''),(614483,193446,'1713770938.81834','new_theme','box_align','4',0,''),(614484,193446,'1713770938.81834','new_theme','font-weight','400',0,''),(614485,193446,'1713770938.81834','new_theme','hide_menu','on',0,''),(614486,193446,'1713770938.81834','new_theme','color','$header-menu-color-1',0,''),(614487,193446,'1713770938.81834','new_theme','hide_menu','1',0,'8451'),(614488,193446,'1713770938.81834','new_theme','show_new','1',0,''),(614489,193446,'1713770938.81834','new_theme','style_class','header-menu',0,''),(614490,193446,'1713770938.81834','new_theme','type','builder',0,''),(614491,193446,'1713770938.81834','new_theme','position','horizontal_center',0,'8517'),(614492,193446,'1713770938.81834','new_theme','style','1',0,'8517'),(614493,193446,'1713770938.81834','new_theme','lev2_vis','over',0,'8517'),(614494,193446,'1713770938.81834','new_theme','lev2_display','down',0,'8517'),(614495,193446,'1713770938.81834','new_theme','lev3_vis','over',0,'8517'),(614496,193446,'1713770938.81834','new_theme','lev4_vis','over',0,'8517'),(614497,193446,'1713770938.81834','new_theme','lev5_vis','over',0,'8517'),(614498,193446,'1713770938.81834','new_theme','lev6_vis','over',0,'8517'),(614499,193446,'1713770938.81834','new_theme','lev3_display','lra',0,'8517'),(614500,193446,'1713770938.81834','new_theme','lev4_display','lra',0,'8517'),(614501,193446,'1713770938.81834','new_theme','lev5_display','lra',0,'8517'),(614502,193446,'1713770938.81834','new_theme','lev6_display','lra',0,'8517'),(614503,193446,'1713770938.81834','new_theme','style','2',0,'8451'),(614504,193446,'1713770938.81834','new_theme','burger_icon','1',0,'8451'),(614505,193446,'1713770938.81834','new_theme','open_from','top',0,'8451'),(614506,193446,'1713770938.81834','new_theme','lev2_vis','click',0,'8451'),(614507,193446,'1713770938.81834','new_theme','lev3_vis','click',0,'8451'),(614508,193446,'1713770938.81834','new_theme','lev4_vis','click',0,'8451'),(614509,193446,'1713770938.81834','new_theme','lev5_vis','click',0,'8451'),(614510,193446,'1713770938.81834','new_theme','lev6_vis','click',0,'8451'),(614511,193446,'1713770938.81834','new_theme','from_file','menu_1.zip',0,''),(614512,193447,'74346','new_theme','block_type','1',0,''),(614513,193452,'74351','new_theme','width','680',0,''),(614514,193452,'74351','new_theme','font-weight','normal',0,''),(614515,193452,'74351','new_theme','font-size','12',0,''),(614516,193452,'74351','new_theme','padding-top','20',0,''),(614517,193452,'74351','new_theme','padding-bottom','20',0,''),(614518,193452,'74351','new_theme','color','$content-color-1',0,''),(614519,193453,'74352','new_theme','block_type','4',0,''),(614520,193453,'74352','new_theme','font-weight','normal',0,''),(614521,193453,'74352','new_theme','border-top-width','1',0,''),(614522,193453,'74352','new_theme','border-top-color','$content-border-1',0,''),(614523,193453,'74352','new_theme','border-left-width','1',0,''),(614524,193453,'74352','new_theme','border-left-color','$content-border-1',0,''),(614525,193453,'74352','new_theme','border-right-width','1',0,''),(614526,193453,'74352','new_theme','border-right-color','$content-border-1',0,''),(614527,193453,'74352','new_theme','border-bottom-width','1',0,''),(614528,193453,'74352','new_theme','border-bottom-color','$content-border-1',0,''),(614529,193454,'74353','new_theme','block_type','2',0,''),(614530,193454,'74353','new_theme','font-weight','normal',0,''),(614531,193454,'74353','new_theme','border-top-width','1',0,''),(614532,193454,'74353','new_theme','border-top-color','$content-border-1',0,''),(614533,193454,'74353','new_theme','border-right-width','1',0,''),(614534,193454,'74353','new_theme','border-right-color','$content-border-1',0,''),(614535,193455,'74354','new_theme','block_type','1',0,''),(614536,193455,'74354','new_theme','font-weight','normal',0,''),(614537,193455,'74354','new_theme','padding-top','10',0,''),(614538,193455,'74354','new_theme','padding-left','10',0,''),(614539,193455,'74354','new_theme','padding-right','10',0,''),(614540,193455,'74354','new_theme','padding-bottom','10',0,''),(614541,193455,'74354','new_theme','border-right-width','1',0,''),(614542,193455,'74354','new_theme','border-right-color','$content-border-1',0,''),(614543,193457,'74356','new_theme','text','<p>Shipping via</p>',1,''),(614544,193457,'74356','new_theme','font-weight','bold',0,''),(614545,193457,'74356','new_theme','font-size','14',0,''),(614546,193457,'74356','new_theme','text','<p>Shipping via</p>',0,''),(614547,193458,'74357','new_theme','block_type','1',0,''),(614548,193458,'74357','new_theme','font-weight','normal',0,''),(614549,193458,'74357','new_theme','padding-top','10',0,''),(614550,193458,'74357','new_theme','padding-left','10',0,''),(614551,193458,'74357','new_theme','padding-right','10',0,''),(614552,193458,'74357','new_theme','padding-bottom','10',0,''),(614553,193459,'74358','new_theme','text','<p>Shipping service</p>',1,''),(614554,193459,'74358','new_theme','font-weight','bold',0,''),(614555,193459,'74358','new_theme','font-size','14',0,''),(614556,193459,'74358','new_theme','text','<p>Shipping service</p>',0,''),(614557,193461,'74360','new_theme','block_type','2',0,''),(614558,193461,'74360','new_theme','font-weight','normal',0,''),(614559,193461,'74360','new_theme','border-right-width','1',0,''),(614560,193461,'74360','new_theme','border-right-color','$content-border-1',0,''),(614561,193462,'74361','new_theme','block_type','1',0,''),(614562,193462,'74361','new_theme','font-weight','400',0,''),(614563,193462,'74361','new_theme','background-color','$content-bg-2',0,''),(614564,193462,'74361','new_theme','padding-top','10',0,''),(614565,193462,'74361','new_theme','padding-left','10',0,''),(614566,193462,'74361','new_theme','padding-right','10',0,''),(614567,193462,'74361','new_theme','padding-bottom','30',0,''),(614568,193463,'74362','new_theme','text','<p>INVOICE ADDRESS:</p>',1,''),(614569,193463,'74362','new_theme','font-size','14',0,''),(614570,193463,'74362','new_theme','font-weight','bold',0,''),(614571,193463,'74362','new_theme','text','<p>INVOICE ADDRESS:</p>',0,''),(614572,193464,'74363','new_theme','font-size','12',0,''),(614573,193465,'74364','new_theme','block_type','1',0,''),(614574,193465,'74364','new_theme','font-weight','normal',0,''),(614575,193465,'74364','new_theme','padding-top','10',0,''),(614576,193465,'74364','new_theme','padding-left','10',0,''),(614577,193465,'74364','new_theme','padding-right','10',0,''),(614578,193465,'74364','new_theme','padding-bottom','10',0,''),(614579,193466,'74365','new_theme','text','<p>E-MAIL ADDRESS:</p>',1,''),(614580,193466,'74365','new_theme','font-weight','bold',0,''),(614581,193466,'74365','new_theme','font-size','14',0,''),(614582,193466,'74365','new_theme','padding-top','10',0,''),(614583,193466,'74365','new_theme','text','<p>E-MAIL ADDRESS:</p>',0,''),(614584,193467,'74366','new_theme','font-weight','normal',0,''),(614585,193468,'74367','new_theme','font-weight','normal',0,''),(614586,193469,'74368','new_theme','text','<p>CUSTOMER:</p>',1,''),(614587,193469,'74368','new_theme','font-size','13',0,''),(614588,193469,'74368','new_theme','font-weight','bold',0,''),(614589,193469,'74368','new_theme','text','<p>CUSTOMER:</p>',0,''),(614590,193470,'74369','new_theme','text','<p>PHONE NUMBER:</p>',1,''),(614591,193470,'74369','new_theme','font-size','14',0,''),(614592,193470,'74369','new_theme','font-weight','bold',0,''),(614593,193470,'74369','new_theme','padding-top','10',0,''),(614594,193470,'74369','new_theme','text','<p>PHONE NUMBER:</p>',0,''),(614595,193472,'74371','new_theme','font-weight','normal',0,''),(614596,193472,'74371','new_theme','text-align','center',0,''),(614597,193472,'74371','new_theme','padding-bottom','20',0,''),(614598,193473,'74372','new_theme','text','<p>Payment Method:</p>',1,''),(614599,193473,'74372','new_theme','font-weight','bold',0,''),(614600,193473,'74372','new_theme','text-align','center',0,''),(614601,193473,'74372','new_theme','text','<p>Payment Method:</p>',0,''),(614602,193474,'74373','new_theme','text','<p>Payment date:</p>',1,''),(614603,193474,'74373','new_theme','font-weight','bold',0,''),(614604,193474,'74373','new_theme','text-align','center',0,''),(614605,193474,'74373','new_theme','font-size','12',0,''),(614606,193474,'74373','new_theme','text','<p>Payment date:</p>',0,''),(614607,193475,'74374','new_theme','font-size','14',0,''),(614608,193475,'74374','new_theme','font-weight','bold',0,''),(614609,193475,'74374','new_theme','text-align','center',0,''),(614610,193475,'74374','new_theme','padding-bottom','10',0,''),(614611,193475,'74374','new_theme','padding-top','10',0,''),(614612,193476,'74375','new_theme','font-weight','normal',0,''),(614613,193476,'74375','new_theme','text-align','center',0,''),(614614,193476,'74375','new_theme','padding-bottom','10',0,''),(614615,193477,'74376','new_theme','font-weight','normal',0,''),(614616,193477,'74376','new_theme','text-align','center',0,''),(614617,193478,'74377','new_theme','block_type','3',0,''),(614618,193478,'74377','new_theme','font-weight','normal',0,''),(614619,193478,'74377','new_theme','padding-top','20',0,''),(614620,193479,'74378','new_theme','font-size','12',0,''),(614621,193480,'74379','new_theme','text','<p>If undelivered please return to:</p>',1,''),(614622,193480,'74379','new_theme','font-size','12',0,''),(614623,193480,'74379','new_theme','font-weight','bold',0,''),(614624,193480,'74379','new_theme','text','<p>If undelivered please return to:</p>',0,''),(614625,193481,'74380','new_theme','text','<p>Thank you for your order</p>',1,''),(614626,193481,'74380','new_theme','color','$color-8',0,''),(614627,193481,'74380','new_theme','font-size','13',0,''),(614628,193481,'74380','new_theme','font-weight','bold',0,''),(614629,193481,'74380','new_theme','padding-top','5',0,''),(614630,193481,'74380','new_theme','text-align','center',0,''),(614631,193481,'74380','new_theme','text','<p>Thank you for your order</p>',0,''),(614632,193482,'74381','new_theme','font-weight','400',0,''),(614633,193482,'74381','new_theme','text-align','center',0,''),(614634,193482,'74381','new_theme','padding-top','0',0,''),(614635,193482,'74381','new_theme','padding-left','20',0,''),(614636,193482,'74381','new_theme','padding-right','20',0,''),(614637,193482,'74381','new_theme','logo_from','theme',0,''),(614638,193483,'74382','new_theme','block_type','6',0,''),(614639,193483,'74382','new_theme','font-weight','normal',0,''),(614640,193483,'74382','new_theme','font-size','16',0,''),(614641,193484,'74383','new_theme','text','<p>Email:</p>',1,''),(614642,193484,'74383','new_theme','font-weight','normal',0,''),(614643,193484,'74383','new_theme','text-align','right',0,''),(614644,193484,'74383','new_theme','font-size','12',0,''),(614645,193484,'74383','new_theme','text','<p>Email:</p>',0,''),(614646,193485,'74384','new_theme','font-weight','normal',0,''),(614647,193485,'74384','new_theme','text-align','right',0,''),(614648,193485,'74384','new_theme','font-size','12',0,''),(614649,193486,'74385','new_theme','block_type','6',0,''),(614650,193486,'74385','new_theme','font-weight','normal',0,''),(614651,193486,'74385','new_theme','font-size','16',0,''),(614652,193487,'74386','new_theme','text','<p>Phone:</p>',1,''),(614653,193487,'74386','new_theme','font-weight','normal',0,''),(614654,193487,'74386','new_theme','text-align','right',0,''),(614655,193487,'74386','new_theme','font-size','12',0,''),(614656,193487,'74386','new_theme','text','<p>Phone:</p>',0,''),(614657,193488,'74387','new_theme','font-weight','normal',0,''),(614658,193488,'74387','new_theme','text-align','right',0,''),(614659,193488,'74387','new_theme','font-size','12',0,''),(614660,193489,'74388','new_theme','text','<p>If something has gone wrong please contact us at:</p>',1,''),(614661,193489,'74388','new_theme','font-size','12',0,''),(614662,193489,'74388','new_theme','font-weight','bold',0,''),(614663,193489,'74388','new_theme','text-align','right',0,''),(614664,193489,'74388','new_theme','text','<p>If something has gone wrong please contact us at:</p>',0,''),(614665,193490,'74389','new_theme','font-weight','400',0,''),(614666,193490,'74389','new_theme','padding-top','20',0,''),(614667,193490,'74389','new_theme','padding-bottom','0',0,''),(614668,193490,'74389','new_theme','font-size','12',0,''),(614669,193491,'74390','new_theme','block_type','5',0,''),(614670,193491,'74390','new_theme','font-weight','normal',0,''),(614671,193491,'74390','new_theme','border-bottom-width','1',0,''),(614672,193491,'74390','new_theme','border-bottom-color','$content-border-1',0,''),(614673,193491,'74390','new_theme','border-top-width','1',0,''),(614674,193491,'74390','new_theme','border-top-color','$content-border-1',0,''),(614675,193491,'74390','new_theme','border-left-color','$content-border-1',0,''),(614676,193491,'74390','new_theme','border-left-width','1',0,''),(614677,193492,'74391','new_theme','block_type','1',0,''),(614678,193492,'74391','new_theme','font-weight','normal',0,''),(614679,193492,'74391','new_theme','padding-top','10',0,''),(614680,193492,'74391','new_theme','padding-left','10',0,''),(614681,193492,'74391','new_theme','padding-right','10',0,''),(614682,193493,'74392','new_theme','font-weight','400',0,''),(614683,193493,'74392','new_theme','line-height','120',0,''),(614684,193493,'74392','new_theme','line_height_measure','%',0,''),(614685,193493,'74392','new_theme','font-size','12',0,''),(614686,193494,'74393','new_theme','text','<p>SHIPPING ADDRESS:</p>',1,''),(614687,193494,'74393','new_theme','font-size','14',0,''),(614688,193494,'74393','new_theme','font-weight','bold',0,''),(614689,193494,'74393','new_theme','padding-bottom','10',0,''),(614690,193494,'74393','new_theme','text','<p>SHIPPING ADDRESS:</p>',0,''),(614691,193495,'74394','new_theme','block_type','1',0,''),(614692,193495,'74394','new_theme','background-color','$content-bg-2',0,''),(614693,193495,'74394','new_theme','padding-top','20',0,''),(614694,193495,'74394','new_theme','padding-left','10',0,''),(614695,193495,'74394','new_theme','padding-right','10',0,''),(614696,193495,'74394','new_theme','padding-bottom','20',0,''),(614697,193495,'74394','new_theme','font-size','14',0,''),(614698,193496,'74395','new_theme','font-weight','normal',0,''),(614699,193496,'74395','new_theme','text-align','right',0,''),(614700,193496,'74395','new_theme','font-size','14',0,''),(614701,193496,'74395','new_theme','box_align','3',0,''),(614702,193497,'74396','new_theme','block_type','2',0,''),(614703,193497,'74396','new_theme','font-weight','normal',0,''),(614704,193497,'74396','new_theme','padding-bottom','20',0,''),(614705,193498,'74397','new_theme','font-weight','400',0,''),(614706,193498,'74397','new_theme','padding-top','20',0,''),(614707,193498,'74397','new_theme','logo_from','theme',0,''),(614708,193499,'74398','new_theme','block_type','11',0,''),(614709,193499,'74398','new_theme','font-weight','normal',0,''),(614710,193500,'74399','new_theme','text','<p>Web:</p>',1,''),(614711,193500,'74399','new_theme','font-weight','normal',0,''),(614712,193500,'74399','new_theme','text-align','right',0,''),(614713,193500,'74399','new_theme','text','<p>Web:</p>',0,''),(614714,193501,'74400','new_theme','font-weight','normal',0,''),(614715,193501,'74400','new_theme','text-align','right',0,''),(614716,193502,'74401','new_theme','block_type','11',0,''),(614717,193502,'74401','new_theme','font-weight','normal',0,''),(614718,193503,'74402','new_theme','text','<p>Email:</p>',1,''),(614719,193503,'74402','new_theme','font-weight','normal',0,''),(614720,193503,'74402','new_theme','text-align','right',0,''),(614721,193503,'74402','new_theme','text','<p>Email:</p>',0,''),(614722,193504,'74403','new_theme','font-weight','normal',0,''),(614723,193504,'74403','new_theme','text-align','right',0,''),(614724,193505,'74404','new_theme','block_type','1',0,''),(614725,193506,'74405','new_theme','font-weight','normal',0,''),(614726,193506,'74405','new_theme','text-align','right',0,''),(614727,193506,'74405','new_theme','padding-bottom','10',0,''),(614728,193506,'74405','new_theme','address_spacer',',',0,''),(614729,193506,'74405','new_theme','font-size','12',0,''),(614730,193507,'74406','new_theme','block_type','11',0,''),(614731,193507,'74406','new_theme','font-weight','normal',0,''),(614732,193508,'74407','new_theme','text','<p>Phone:</p>',1,''),(614733,193508,'74407','new_theme','font-weight','normal',0,''),(614734,193508,'74407','new_theme','text-align','right',0,''),(614735,193508,'74407','new_theme','text','<p>Phone:</p>',0,''),(614736,193509,'74408','new_theme','font-weight','normal',0,''),(614737,193509,'74408','new_theme','text-align','right',0,''),(614738,193510,'74409','new_theme','block_type','1',0,''),(614739,193510,'74409','new_theme','padding-top','20',0,''),(614740,193511,'74410','new_theme','tab_1','RETURNING CUSTOMER',1,''),(614741,193511,'74410','new_theme','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(614742,193511,'74410','new_theme','tab_1','RETURNING CUSTOMER',0,''),(614743,193511,'74410','new_theme','tab_2','REGISTER TO SAVE YOUR DETAILS',0,''),(614744,193513,'74412','new_theme','block_type','8',0,''),(614745,193514,'74413','new_theme','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(614746,193515,'74414','new_theme','block_type','1',0,''),(614747,193515,'74414','new_theme','padding-left','20',0,''),(614748,193515,'74414','new_theme','padding-right','20',0,''),(614749,193516,'74415','new_theme','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(614750,193518,'74417','new_theme','block_type','1',0,''),(614751,193519,'74418','new_theme','text','##TEXT_OR##',0,''),(614752,193519,'74418','new_theme','font-size','18',0,''),(614753,193519,'74418','new_theme','font-weight','700',0,''),(614754,193519,'74418','new_theme','padding-top','15',0,''),(614755,193519,'74418','new_theme','text-align','center',0,''),(614756,193519,'74418','new_theme','content','\\_',0,'3'),(614757,193519,'74418','new_theme','height','5',0,'3'),(614758,193519,'74418','new_theme','width','70',0,'3'),(614759,193519,'74418','new_theme','display','inline-block',0,'3'),(614760,193519,'74418','new_theme','border-top-width','1',0,'3'),(614761,193519,'74418','new_theme','border-top-color','$content-border-1',0,'3'),(614762,193519,'74418','new_theme','margin-left','10',0,'3'),(614763,193519,'74418','new_theme','margin-right','10',0,'3'),(614764,193519,'74418','new_theme','content','\\_',0,'4'),(614765,193519,'74418','new_theme','display','inline-block',0,'4'),(614766,193519,'74418','new_theme','width','70',0,'4'),(614767,193519,'74418','new_theme','height','5',0,'4'),(614768,193519,'74418','new_theme','border-top-width','1',0,'4'),(614769,193519,'74418','new_theme','border-top-color','$content-border-1',0,'4'),(614770,193519,'74418','new_theme','margin-left','10',0,'4'),(614771,193519,'74418','new_theme','margin-right','10',0,'4'),(614772,193519,'74418','new_theme','position','relative',0,''),(614773,193519,'74418','new_theme','top','-10',0,''),(614774,193520,'74419','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(614775,193520,'74419','new_theme','font-size','26',0,''),(614776,193520,'74419','new_theme','font-family','$font-1',0,''),(614777,193520,'74419','new_theme','padding-top','15',0,''),(614778,193520,'74419','new_theme','padding-bottom','15',0,''),(614779,193520,'74419','new_theme','text-align','center',0,''),(614780,193521,'74420','new_theme','text-align','center',0,''),(614781,193521,'74420','new_theme','hide_parents','2',0,''),(614782,193522,'74421','new_theme','block_type','1',0,''),(614783,193522,'74421','new_theme','padding-top','40',0,''),(614784,193522,'74421','new_theme','background-color','$content-bg-2',0,''),(614785,193522,'74421','new_theme','padding-bottom','40',0,''),(614786,193522,'74421','new_theme','style_class','checkout-login-wrap',0,''),(614787,193522,'74421','new_theme','color','$content-color-2',0,''),(614788,193523,'74422','new_theme','block_type','2',0,''),(614789,193523,'74422','new_theme','background-color','$content-bg-1',0,''),(614790,193523,'74422','new_theme','max-width','830',0,''),(614791,193523,'74422','new_theme','margin_left_measure','auto',0,''),(614792,193523,'74422','new_theme','margin_right_measure','auto',0,''),(614793,193523,'74422','new_theme','padding-top','40',0,''),(614794,193523,'74422','new_theme','padding-bottom','40',0,''),(614795,193523,'74422','new_theme','schema','2-3',0,'8451'),(614796,193523,'74422','new_theme','color','$content-color-1',0,''),(614797,193524,'74423','new_theme','text-align','center',0,''),(614798,193524,'74423','new_theme','margin-bottom','40',0,''),(614799,193525,'74424','new_theme','text-align','center',0,''),(614800,193526,'74425','new_theme','text','##TEXT_OR##',0,''),(614801,193526,'74425','new_theme','font-size','18',0,''),(614802,193526,'74425','new_theme','font-weight','700',0,''),(614803,193526,'74425','new_theme','text-align','center',0,''),(614804,193526,'74425','new_theme','content','\\_',0,'3'),(614805,193526,'74425','new_theme','height','5',0,'3'),(614806,193526,'74425','new_theme','width','70',0,'3'),(614807,193526,'74425','new_theme','display','inline-block',0,'3'),(614808,193526,'74425','new_theme','border-top-width','1',0,'3'),(614809,193526,'74425','new_theme','border-top-color','$content-border-1',0,'3'),(614810,193526,'74425','new_theme','margin-left','10',0,'3'),(614811,193526,'74425','new_theme','margin-right','10',0,'3'),(614812,193526,'74425','new_theme','content','\\_',0,'4'),(614813,193526,'74425','new_theme','display','inline-block',0,'4'),(614814,193526,'74425','new_theme','width','70',0,'4'),(614815,193526,'74425','new_theme','height','5',0,'4'),(614816,193526,'74425','new_theme','border-top-width','1',0,'4'),(614817,193526,'74425','new_theme','border-top-color','$content-border-1',0,'4'),(614818,193526,'74425','new_theme','margin-left','10',0,'4'),(614819,193526,'74425','new_theme','margin-right','10',0,'4'),(614820,193526,'74425','new_theme','position','relative',0,''),(614821,193526,'74425','new_theme','padding-top','10',0,''),(614822,193526,'74425','new_theme','padding-bottom','10',0,''),(614823,193527,'74426','new_theme','block_type','1',0,''),(614824,193528,'74427','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(614825,193528,'74427','new_theme','font-size','18',0,''),(614826,193528,'74427','new_theme','font-family','$font-1',0,''),(614827,193528,'74427','new_theme','padding-top','15',0,''),(614828,193528,'74427','new_theme','padding-bottom','15',0,''),(614829,193528,'74427','new_theme','text-align','center',0,''),(614830,193528,'74427','new_theme','text-transform','uppercase',0,''),(614831,193529,'74428','new_theme','text-align','center',0,''),(614832,193529,'74428','new_theme','hide_parents','2',0,''),(614833,193530,'74429','new_theme','text','##NEW_CUSTOMER##',0,''),(614834,193530,'74429','new_theme','font-size','18',0,''),(614835,193530,'74429','new_theme','font-family','$font-1',0,''),(614836,193530,'74429','new_theme','text-align','center',0,''),(614837,193530,'74429','new_theme','text-transform','uppercase',0,''),(614838,193530,'74429','new_theme','margin-bottom','10',0,''),(614839,193531,'74430','new_theme','max-width','230',0,''),(614840,193531,'74430','new_theme','margin_left_measure','auto',0,''),(614841,193531,'74430','new_theme','margin_right_measure','auto',0,''),(614842,193532,'74431','new_theme','text','##RETURNING_CUSTOMER##',0,''),(614843,193532,'74431','new_theme','font-size','18',0,''),(614844,193532,'74431','new_theme','font-family','$font-1',0,''),(614845,193532,'74431','new_theme','text-transform','uppercase',0,''),(614846,193532,'74431','new_theme','text-align','center',0,''),(614847,193533,'74432','new_theme','block_type','1',0,''),(614848,193533,'74432','new_theme','padding-top','20',0,''),(614849,193534,'74433','new_theme','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(614850,193534,'74433','new_theme','tab_2','RETURNING CUSTOMER',1,''),(614851,193534,'74433','new_theme','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(614852,193534,'74433','new_theme','tab_1','GUEST – SINGLE USE ACCOUNT',0,''),(614853,193534,'74433','new_theme','tab_2','RETURNING CUSTOMER',0,''),(614854,193534,'74433','new_theme','tab_3','REGISTER TO SAVE YOUR DETAILS',0,''),(614855,193535,'74434','new_theme','block_type','8',0,''),(614856,193536,'74435','new_theme','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(614857,193537,'74436','new_theme','block_type','1',0,''),(614858,193537,'74436','new_theme','padding-left','20',0,''),(614859,193537,'74436','new_theme','padding-right','20',0,''),(614860,193539,'74438','new_theme','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(614861,193539,'74438','new_theme','border-top-width','1',0,''),(614862,193539,'74438','new_theme','border-top-color','$content-border-1',0,''),(614863,193541,'74440','new_theme','block_type','8',0,''),(614864,193542,'74441','new_theme','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(614865,193543,'74442','new_theme','block_type','1',0,''),(614866,193543,'74442','new_theme','padding-left','20',0,''),(614867,193543,'74442','new_theme','padding-right','20',0,''),(614868,193544,'74443','new_theme','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(614869,193546,'74445','new_theme','text-align','center',0,''),(614870,193547,'74446','new_theme','text','##TEXT_OR##',0,''),(614871,193547,'74446','new_theme','font-size','18',0,''),(614872,193547,'74446','new_theme','font-weight','700',0,''),(614873,193547,'74446','new_theme','padding-top','15',0,''),(614874,193547,'74446','new_theme','text-align','center',0,''),(614875,193547,'74446','new_theme','content','\\_',0,'3'),(614876,193547,'74446','new_theme','height','5',0,'3'),(614877,193547,'74446','new_theme','width','70',0,'3'),(614878,193547,'74446','new_theme','display','inline-block',0,'3'),(614879,193547,'74446','new_theme','border-top-width','1',0,'3'),(614880,193547,'74446','new_theme','border-top-color','$content-border-1',0,'3'),(614881,193547,'74446','new_theme','margin-left','10',0,'3'),(614882,193547,'74446','new_theme','margin-right','10',0,'3'),(614883,193547,'74446','new_theme','content','\\_',0,'4'),(614884,193547,'74446','new_theme','display','inline-block',0,'4'),(614885,193547,'74446','new_theme','width','70',0,'4'),(614886,193547,'74446','new_theme','height','5',0,'4'),(614887,193547,'74446','new_theme','border-top-width','1',0,'4'),(614888,193547,'74446','new_theme','border-top-color','$content-border-1',0,'4'),(614889,193547,'74446','new_theme','margin-left','10',0,'4'),(614890,193547,'74446','new_theme','margin-right','10',0,'4'),(614891,193547,'74446','new_theme','position','relative',0,''),(614892,193547,'74446','new_theme','top','-10',0,''),(614893,193548,'74447','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(614894,193548,'74447','new_theme','font-size','26',0,''),(614895,193548,'74447','new_theme','font-family','$font-1',0,''),(614896,193548,'74447','new_theme','padding-top','15',0,''),(614897,193548,'74447','new_theme','padding-bottom','15',0,''),(614898,193548,'74447','new_theme','text-align','center',0,''),(614899,193549,'74448','new_theme','block_type','1',0,''),(614900,193549,'74448','new_theme','padding-top','20',0,''),(614901,193550,'74449','new_theme','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(614902,193550,'74449','new_theme','tab_2','RETURNING CUSTOMER',1,''),(614903,193550,'74449','new_theme','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(614904,193550,'74449','new_theme','tab_1','GUEST – SINGLE USE ACCOUNT',0,''),(614905,193550,'74449','new_theme','tab_2','RETURNING CUSTOMER',0,''),(614906,193550,'74449','new_theme','tab_3','REGISTER TO SAVE YOUR DETAILS',0,''),(614907,193551,'74450','new_theme','block_type','8',0,''),(614908,193552,'74451','new_theme','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(614909,193555,'74454','new_theme','block_type','8',0,''),(614910,193556,'74455','new_theme','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(614911,193558,'74457','new_theme','block_type','1',0,''),(614912,193558,'74457','new_theme','padding-left','20',0,''),(614913,193558,'74457','new_theme','padding-right','20',0,''),(614914,193560,'74459','new_theme','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(614915,193561,'74460','new_theme','text','##TEXT_OR##',0,''),(614916,193561,'74460','new_theme','font-size','18',0,''),(614917,193561,'74460','new_theme','font-weight','700',0,''),(614918,193561,'74460','new_theme','padding-top','15',0,''),(614919,193561,'74460','new_theme','text-align','center',0,''),(614920,193561,'74460','new_theme','content','\\_',0,'3'),(614921,193561,'74460','new_theme','height','5',0,'3'),(614922,193561,'74460','new_theme','width','70',0,'3'),(614923,193561,'74460','new_theme','display','inline-block',0,'3'),(614924,193561,'74460','new_theme','border-top-width','1',0,'3'),(614925,193561,'74460','new_theme','border-top-color','$content-border-1',0,'3'),(614926,193561,'74460','new_theme','margin-left','10',0,'3'),(614927,193561,'74460','new_theme','margin-right','10',0,'3'),(614928,193561,'74460','new_theme','content','\\_',0,'4'),(614929,193561,'74460','new_theme','display','inline-block',0,'4'),(614930,193561,'74460','new_theme','width','70',0,'4'),(614931,193561,'74460','new_theme','height','5',0,'4'),(614932,193561,'74460','new_theme','border-top-width','1',0,'4'),(614933,193561,'74460','new_theme','border-top-color','$content-border-1',0,'4'),(614934,193561,'74460','new_theme','margin-left','10',0,'4'),(614935,193561,'74460','new_theme','margin-right','10',0,'4'),(614936,193561,'74460','new_theme','position','relative',0,''),(614937,193561,'74460','new_theme','top','-10',0,''),(614938,193562,'74461','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(614939,193562,'74461','new_theme','font-size','26',0,''),(614940,193562,'74461','new_theme','font-family','$font-1',0,''),(614941,193562,'74461','new_theme','padding-top','15',0,''),(614942,193562,'74461','new_theme','padding-bottom','15',0,''),(614943,193562,'74461','new_theme','text-align','center',0,''),(614944,193563,'74462','new_theme','text-align','center',0,''),(614945,193564,'74463','new_theme','block_type','1',0,''),(614946,193564,'74463','new_theme','padding-top','20',0,''),(614947,193565,'74464','new_theme','text-align','center',0,''),(614948,193566,'74465','new_theme','text','##TEXT_OR##',0,''),(614949,193566,'74465','new_theme','font-size','18',0,''),(614950,193566,'74465','new_theme','font-weight','700',0,''),(614951,193566,'74465','new_theme','padding-top','15',0,''),(614952,193566,'74465','new_theme','text-align','center',0,''),(614953,193566,'74465','new_theme','content','\\_',0,'3'),(614954,193566,'74465','new_theme','height','5',0,'3'),(614955,193566,'74465','new_theme','width','70',0,'3'),(614956,193566,'74465','new_theme','display','inline-block',0,'3'),(614957,193566,'74465','new_theme','border-top-width','1',0,'3'),(614958,193566,'74465','new_theme','border-top-color','$content-border-1',0,'3'),(614959,193566,'74465','new_theme','margin-left','10',0,'3'),(614960,193566,'74465','new_theme','margin-right','10',0,'3'),(614961,193566,'74465','new_theme','content','\\_',0,'4'),(614962,193566,'74465','new_theme','display','inline-block',0,'4'),(614963,193566,'74465','new_theme','width','70',0,'4'),(614964,193566,'74465','new_theme','height','5',0,'4'),(614965,193566,'74465','new_theme','border-top-width','1',0,'4'),(614966,193566,'74465','new_theme','border-top-color','$content-border-1',0,'4'),(614967,193566,'74465','new_theme','margin-left','10',0,'4'),(614968,193566,'74465','new_theme','margin-right','10',0,'4'),(614969,193566,'74465','new_theme','position','relative',0,''),(614970,193566,'74465','new_theme','top','-10',0,''),(614971,193567,'74466','new_theme','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(614972,193567,'74466','new_theme','tab_2','RETURNING CUSTOMER',1,''),(614973,193567,'74466','new_theme','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(614974,193567,'74466','new_theme','tab_1','GUEST – SINGLE USE ACCOUNT',0,''),(614975,193567,'74466','new_theme','tab_2','RETURNING CUSTOMER',0,''),(614976,193567,'74466','new_theme','tab_3','REGISTER TO SAVE YOUR DETAILS',0,''),(614977,193568,'74467','new_theme','block_type','8',0,''),(614978,193569,'74468','new_theme','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(614979,193572,'74471','new_theme','block_type','8',0,''),(614980,193573,'74472','new_theme','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(614981,193574,'74473','new_theme','block_type','1',0,''),(614982,193574,'74473','new_theme','padding-left','20',0,''),(614983,193574,'74473','new_theme','padding-right','20',0,''),(614984,193576,'74475','new_theme','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(614985,193577,'74476','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(614986,193577,'74476','new_theme','font-size','26',0,''),(614987,193577,'74476','new_theme','font-family','$font-1',0,''),(614988,193577,'74476','new_theme','padding-top','15',0,''),(614989,193577,'74476','new_theme','padding-bottom','15',0,''),(614990,193577,'74476','new_theme','text-align','center',0,''),(614991,193578,'74477','new_theme','block_type','1',0,''),(614992,193578,'74477','new_theme','padding-top','40',0,''),(614993,193578,'74477','new_theme','background-color','$content-bg-2',0,''),(614994,193578,'74477','new_theme','padding-bottom','40',0,''),(614995,193579,'74478','new_theme','block_type','2',0,''),(614996,193579,'74478','new_theme','background-color','$content-bg-1',0,''),(614997,193579,'74478','new_theme','max-width','830',0,''),(614998,193579,'74478','new_theme','margin_left_measure','auto',0,''),(614999,193579,'74478','new_theme','margin_right_measure','auto',0,''),(615000,193579,'74478','new_theme','padding-top','40',0,''),(615001,193579,'74478','new_theme','padding-bottom','40',0,''),(615002,193580,'74479','new_theme','block_type','1',0,''),(615003,193581,'74480','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(615004,193581,'74480','new_theme','font-size','18',0,''),(615005,193581,'74480','new_theme','font-family','$font-1',0,''),(615006,193581,'74480','new_theme','padding-top','15',0,''),(615007,193581,'74480','new_theme','padding-bottom','15',0,''),(615008,193581,'74480','new_theme','text-align','center',0,''),(615009,193581,'74480','new_theme','text-transform','uppercase',0,''),(615010,193582,'74481','new_theme','text-align','center',0,''),(615011,193582,'74481','new_theme','hide_parents','2',0,''),(615012,193583,'74482','new_theme','text-align','center',0,''),(615013,193584,'74483','new_theme','text-align','center',0,''),(615014,193584,'74483','new_theme','margin-bottom','40',0,''),(615015,193585,'74484','new_theme','text','##TEXT_OR##',0,''),(615016,193585,'74484','new_theme','font-size','18',0,''),(615017,193585,'74484','new_theme','font-weight','700',0,''),(615018,193585,'74484','new_theme','text-align','center',0,''),(615019,193585,'74484','new_theme','content','\\_',0,'3'),(615020,193585,'74484','new_theme','height','5',0,'3'),(615021,193585,'74484','new_theme','width','70',0,'3'),(615022,193585,'74484','new_theme','display','inline-block',0,'3'),(615023,193585,'74484','new_theme','border-top-width','1',0,'3'),(615024,193585,'74484','new_theme','border-top-color','$content-border-1',0,'3'),(615025,193585,'74484','new_theme','margin-left','10',0,'3'),(615026,193585,'74484','new_theme','margin-right','10',0,'3'),(615027,193585,'74484','new_theme','content','\\_',0,'4'),(615028,193585,'74484','new_theme','display','inline-block',0,'4'),(615029,193585,'74484','new_theme','width','70',0,'4'),(615030,193585,'74484','new_theme','height','5',0,'4'),(615031,193585,'74484','new_theme','border-top-width','1',0,'4'),(615032,193585,'74484','new_theme','border-top-color','$content-border-1',0,'4'),(615033,193585,'74484','new_theme','margin-left','10',0,'4'),(615034,193585,'74484','new_theme','margin-right','10',0,'4'),(615035,193585,'74484','new_theme','position','relative',0,''),(615036,193585,'74484','new_theme','padding-top','10',0,''),(615037,193585,'74484','new_theme','padding-bottom','10',0,''),(615038,193586,'74485','new_theme','text','##NEW_CUSTOMER##',0,''),(615039,193586,'74485','new_theme','font-size','18',0,''),(615040,193586,'74485','new_theme','font-family','$font-1',0,''),(615041,193586,'74485','new_theme','text-align','center',0,''),(615042,193586,'74485','new_theme','text-transform','uppercase',0,''),(615043,193586,'74485','new_theme','margin-bottom','10',0,''),(615044,193587,'74486','new_theme','text','##RETURNING_CUSTOMER##',0,''),(615045,193587,'74486','new_theme','font-size','18',0,''),(615046,193587,'74486','new_theme','font-family','$font-1',0,''),(615047,193587,'74486','new_theme','text-transform','uppercase',0,''),(615048,193587,'74486','new_theme','text-align','center',0,''),(615049,193588,'74487','new_theme','max-width','230',0,''),(615050,193588,'74487','new_theme','margin_left_measure','auto',0,''),(615051,193588,'74487','new_theme','margin_right_measure','auto',0,''),(615052,193589,'74488','new_theme','block_type','1',0,''),(615053,193589,'74488','new_theme','padding-top','40',0,''),(615054,193589,'74488','new_theme','background-color','$content-bg-2',0,''),(615055,193589,'74488','new_theme','padding-bottom','40',0,''),(615056,193590,'74489','new_theme','block_type','2',0,''),(615057,193590,'74489','new_theme','background-color','$content-bg-1',0,''),(615058,193590,'74489','new_theme','max-width','830',0,''),(615059,193590,'74489','new_theme','margin_left_measure','auto',0,''),(615060,193590,'74489','new_theme','margin_right_measure','auto',0,''),(615061,193590,'74489','new_theme','padding-top','40',0,''),(615062,193590,'74489','new_theme','padding-bottom','40',0,''),(615063,193591,'74490','new_theme','text','##NEW_CUSTOMER##',0,''),(615064,193591,'74490','new_theme','font-size','18',0,''),(615065,193591,'74490','new_theme','font-family','$font-1',0,''),(615066,193591,'74490','new_theme','text-align','center',0,''),(615067,193591,'74490','new_theme','text-transform','uppercase',0,''),(615068,193591,'74490','new_theme','margin-bottom','10',0,''),(615069,193592,'74491','new_theme','text-align','center',0,''),(615070,193593,'74492','new_theme','text-align','center',0,''),(615071,193593,'74492','new_theme','margin-bottom','40',0,''),(615072,193594,'74493','new_theme','text','##TEXT_OR##',0,''),(615073,193594,'74493','new_theme','font-size','18',0,''),(615074,193594,'74493','new_theme','font-weight','700',0,''),(615075,193594,'74493','new_theme','text-align','center',0,''),(615076,193594,'74493','new_theme','content','\\_',0,'3'),(615077,193594,'74493','new_theme','height','5',0,'3'),(615078,193594,'74493','new_theme','width','70',0,'3'),(615079,193594,'74493','new_theme','display','inline-block',0,'3'),(615080,193594,'74493','new_theme','border-top-width','1',0,'3'),(615081,193594,'74493','new_theme','border-top-color','$content-border-1',0,'3'),(615082,193594,'74493','new_theme','margin-left','10',0,'3'),(615083,193594,'74493','new_theme','margin-right','10',0,'3'),(615084,193594,'74493','new_theme','content','\\_',0,'4'),(615085,193594,'74493','new_theme','display','inline-block',0,'4'),(615086,193594,'74493','new_theme','width','70',0,'4'),(615087,193594,'74493','new_theme','height','5',0,'4'),(615088,193594,'74493','new_theme','border-top-width','1',0,'4'),(615089,193594,'74493','new_theme','border-top-color','$content-border-1',0,'4'),(615090,193594,'74493','new_theme','margin-left','10',0,'4'),(615091,193594,'74493','new_theme','margin-right','10',0,'4'),(615092,193594,'74493','new_theme','position','relative',0,''),(615093,193594,'74493','new_theme','padding-top','10',0,''),(615094,193594,'74493','new_theme','padding-bottom','10',0,''),(615095,193595,'74494','new_theme','block_type','1',0,''),(615096,193596,'74495','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(615097,193596,'74495','new_theme','font-size','18',0,''),(615098,193596,'74495','new_theme','font-family','$font-1',0,''),(615099,193596,'74495','new_theme','padding-top','15',0,''),(615100,193596,'74495','new_theme','padding-bottom','15',0,''),(615101,193596,'74495','new_theme','text-align','center',0,''),(615102,193596,'74495','new_theme','text-transform','uppercase',0,''),(615103,193597,'74496','new_theme','text-align','center',0,''),(615104,193597,'74496','new_theme','hide_parents','2',0,''),(615105,193598,'74497','new_theme','text','##RETURNING_CUSTOMER##',0,''),(615106,193598,'74497','new_theme','font-size','18',0,''),(615107,193598,'74497','new_theme','font-family','$font-1',0,''),(615108,193598,'74497','new_theme','text-transform','uppercase',0,''),(615109,193598,'74497','new_theme','text-align','center',0,''),(615110,193599,'74498','new_theme','max-width','230',0,''),(615111,193599,'74498','new_theme','margin_left_measure','auto',0,''),(615112,193599,'74498','new_theme','margin_right_measure','auto',0,''),(615113,193600,'74499','new_theme','block_type','1',0,''),(615114,193601,'74500','new_theme','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(615115,193601,'74500','new_theme','margin-bottom','30',0,''),(615116,193602,'74501','new_theme','block_type','1',0,''),(615117,193603,'74502','new_theme','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(615118,193603,'74502','new_theme','margin-bottom','30',0,''),(615119,193604,'74503','new_theme','block_type','1',0,''),(615120,193604,'74503','new_theme','background-color','$best-sellers-bg-1',0,''),(615121,193604,'74503','new_theme','padding-top','20',0,''),(615122,193604,'74503','new_theme','padding-bottom','20',0,''),(615123,193604,'74503','new_theme','font-weight','400',0,''),(615124,193604,'74503','new_theme','visibility_product','1',0,''),(615125,193604,'74503','new_theme','visibility_catalog','1',0,''),(615126,193604,'74503','new_theme','visibility_info','1',0,''),(615127,193604,'74503','new_theme','visibility_cart','1',0,''),(615128,193604,'74503','new_theme','visibility_checkout','1',0,''),(615129,193604,'74503','new_theme','visibility_success','1',0,''),(615130,193604,'74503','new_theme','visibility_account','1',0,''),(615131,193604,'74503','new_theme','visibility_login','1',0,''),(615132,193604,'74503','new_theme','visibility_other','1',0,''),(615133,193604,'74503','new_theme','margin-bottom','20',0,''),(615134,193604,'74503','new_theme','display_none','on',0,'8451'),(615135,193605,'74504','new_theme','block_type','2',0,''),(615136,193605,'74504','new_theme','font-weight','normal',0,''),(615137,193606,'74505','new_theme','font-weight','400',0,''),(615138,193606,'74505','new_theme','visibility_product','1',0,''),(615139,193606,'74505','new_theme','show_name','0',0,''),(615140,193606,'74505','new_theme','show_stock','1',0,''),(615141,193606,'74505','new_theme','show_description','1',0,''),(615142,193606,'74505','new_theme','show_model','1',0,''),(615143,193606,'74505','new_theme','show_rating','1',0,''),(615144,193606,'74505','new_theme','show_rating_counts','1',0,''),(615145,193606,'74505','new_theme','show_qty_input','1',0,''),(615146,193606,'74505','new_theme','show_view_button','1',0,''),(615147,193606,'74505','new_theme','show_wishlist_button','1',0,''),(615148,193606,'74505','new_theme','show_compare','1',0,''),(615149,193606,'74505','new_theme','listing_type','productListing',0,''),(615150,193606,'74505','new_theme','show_properties','1',0,''),(615151,193606,'74505','new_theme','col_in_row','2',0,''),(615152,193606,'74505','new_theme','show_bonus_points','1',0,''),(615153,193606,'74505','new_theme','show_buy_button','1',0,''),(615154,193606,'74505','new_theme','show_attributes','1',0,''),(615155,193607,'74506','new_theme','font-weight','normal',0,''),(615156,193607,'74506','new_theme','visibility_product','1',0,''),(615157,193608,'74507','new_theme','font-weight','400',0,''),(615158,193608,'74507','new_theme','visibility_product','1',0,''),(615159,193608,'74507','new_theme','visibility_catalog','1',0,''),(615160,193608,'74507','new_theme','visibility_info','1',0,''),(615161,193608,'74507','new_theme','visibility_cart','1',0,''),(615162,193608,'74507','new_theme','visibility_checkout','1',0,''),(615163,193608,'74507','new_theme','visibility_success','1',0,''),(615164,193608,'74507','new_theme','visibility_account','1',0,''),(615165,193608,'74507','new_theme','visibility_login','1',0,''),(615166,193608,'74507','new_theme','visibility_other','1',0,''),(615167,193608,'74507','new_theme','banners_group','home',0,''),(615168,193608,'74507','new_theme','banners_type','single',0,''),(615169,193608,'74507','new_theme','lazy_load','1',0,''),(615170,193608,'74507','new_theme','template','1',0,''),(615171,193608,'74507','new_theme','ban_id','41',0,''),(615172,193609,'74508','new_theme','block_type','1',0,''),(615173,193609,'74508','new_theme','font-weight','normal',0,''),(615174,193610,'74510','new_theme','tab_1','##NEW_PRODUCTS##',0,''),(615175,193610,'74510','new_theme','tab_2','##SPECIALS_PRODUCTS##',0,''),(615176,193610,'74510','new_theme','tab_3','##FEATURED_PRODUCTS##',0,''),(615177,193611,'74511','new_theme','col_in_row','4',0,''),(615178,193611,'74511','new_theme','view_as','carousel',0,''),(615179,193611,'74511','new_theme','show_attributes','1',0,''),(615180,193611,'74511','new_theme','col_in_row','3',0,'8451'),(615181,193611,'74511','new_theme','col_in_row','2',0,'8444'),(615182,193611,'74511','new_theme','col_in_row','1',0,'8472'),(615183,193611,'74511','new_theme','listing_type','productListing',0,''),(615184,193611,'74511','new_theme','show_qty_input','1',0,''),(615185,193611,'74511','new_theme','show_compare','1',0,''),(615186,193611,'74511','new_theme','lazy_load','1',0,''),(615187,193612,'74512','new_theme','font-weight','400',0,''),(615188,193612,'74512','new_theme','show_compare','1',0,''),(615189,193612,'74512','new_theme','listing_type','productListing',0,''),(615190,193612,'74512','new_theme','show_model','1',0,''),(615191,193612,'74512','new_theme','show_properties','1',0,''),(615192,193612,'74512','new_theme','col_in_row','4',0,''),(615193,193612,'74512','new_theme','show_name','0',0,''),(615194,193612,'74512','new_theme','show_image','0',0,''),(615195,193612,'74512','new_theme','show_stock','0',0,''),(615196,193612,'74512','new_theme','show_description','0',0,''),(615197,193612,'74512','new_theme','show_rating','0',0,''),(615198,193612,'74512','new_theme','show_rating_counts','0',0,''),(615199,193612,'74512','new_theme','show_price','0',0,''),(615200,193612,'74512','new_theme','show_buy_button','0',0,''),(615201,193612,'74512','new_theme','show_qty_input','0',0,''),(615202,193612,'74512','new_theme','show_view_button','0',0,''),(615203,193612,'74512','new_theme','show_wishlist_button','0',0,''),(615204,193612,'74512','new_theme','col_in_row','2',0,'8451'),(615205,193612,'74512','new_theme','col_in_row','1',0,'8472'),(615206,193612,'74512','new_theme','view_as','carousel',0,''),(615207,193612,'74512','new_theme','product_names_teg','h2',0,''),(615208,193612,'74512','new_theme','show_attributes','1',0,''),(615209,193613,'74513','new_theme','font-weight','400',0,''),(615210,193613,'74513','new_theme','listing_type','productListing',0,''),(615211,193613,'74513','new_theme','col_in_row','4',0,''),(615212,193613,'74513','new_theme','show_image','0',0,''),(615213,193613,'74513','new_theme','show_stock','0',0,''),(615214,193613,'74513','new_theme','show_description','0',0,''),(615215,193613,'74513','new_theme','show_rating','0',0,''),(615216,193613,'74513','new_theme','show_rating_counts','0',0,''),(615217,193613,'74513','new_theme','show_price','0',0,''),(615218,193613,'74513','new_theme','show_buy_button','0',0,''),(615219,193613,'74513','new_theme','show_qty_input','0',0,''),(615220,193613,'74513','new_theme','show_view_button','0',0,''),(615221,193613,'74513','new_theme','show_wishlist_button','0',0,''),(615222,193613,'74513','new_theme','col_in_row','2',0,'8451'),(615223,193613,'74513','new_theme','col_in_row','1',0,'8472'),(615224,193613,'74513','new_theme','view_as','carousel',0,''),(615225,193613,'74513','new_theme','col_in_row','2',0,'8444'),(615226,193613,'74513','new_theme','featured_type_id','0',0,''),(615227,193615,'74515','new_theme','heading_type','h1',0,''),(615228,193617,'74516','new_theme','block_type','1',0,''),(615229,193618,'74517','new_theme','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(615230,193620,'74519','new_theme','block_type','1',0,''),(615231,193620,'74519','new_theme','padding-top','40',0,''),(615232,193620,'74519','new_theme','padding-bottom','80',0,''),(615233,193621,'74520','new_theme','block_type','6',0,''),(615234,193622,'74521','new_theme','block_type','1',0,''),(615235,193622,'74521','new_theme','padding-top','20',0,''),(615236,193622,'74521','new_theme','padding-left','20',0,''),(615237,193622,'74521','new_theme','padding-right','20',0,''),(615238,193622,'74521','new_theme','padding-bottom','20',0,''),(615239,193622,'74521','new_theme','border-top-width','1',0,''),(615240,193622,'74521','new_theme','border-left-width','1',0,''),(615241,193622,'74521','new_theme','border-right-width','1',0,''),(615242,193622,'74521','new_theme','border-bottom-width','1',0,''),(615243,193622,'74521','new_theme','border-top-color','$content-border-1',0,''),(615244,193622,'74521','new_theme','border-left-color','$content-border-1',0,''),(615245,193622,'74521','new_theme','border-right-color','$content-border-1',0,''),(615246,193622,'74521','new_theme','border-bottom-color','$content-border-1',0,''),(615247,193622,'74521','new_theme','margin-right','20',0,''),(615248,193625,'74524','new_theme','block_type','1',0,''),(615249,193625,'74524','new_theme','padding-top','20',0,''),(615250,193626,'74525','new_theme','block_type','6',0,''),(615251,193627,'74526','new_theme','padding-right','20',0,''),(615252,193629,'74528','new_theme','block_type','1',0,''),(615253,193629,'74528','new_theme','padding-top','20',0,''),(615254,193630,'74529','new_theme','block_type','6',0,''),(615255,193631,'74530','new_theme','padding-right','20',0,''),(615256,193633,'74532','new_theme','block_type','1',0,''),(615257,193633,'74532','new_theme','style_class','account-password-wrap',0,''),(615258,193634,'74533','new_theme','block_type','6',0,''),(615259,193634,'74533','new_theme','schema','6-3',0,'8451'),(615260,193635,'74534','new_theme','aria_name','account-menu',0,''),(615261,193636,'73374','new_theme','block_type','1',0,''),(615262,193636,'73374','new_theme','padding-top','70',0,''),(615263,193636,'73374','new_theme','padding-right','30',0,''),(615264,193636,'73374','new_theme','padding-bottom','30',0,''),(615265,193636,'73374','new_theme','padding-top','0',0,'8451'),(615266,193636,'73374','new_theme','padding-left','0',0,'8451'),(615267,193636,'73374','new_theme','padding-right','0',0,'8451'),(615268,193636,'73374','new_theme','padding-bottom','0',0,'8451'),(615311,193656,'74536','new_theme','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(615312,193657,'74537','new_theme','block_type','1',0,''),(615313,193657,'74537','new_theme','padding-top','20',0,''),(615314,193658,'74538','new_theme','tab_1','RETURNING CUSTOMER',1,''),(615315,193658,'74538','new_theme','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(615316,193658,'74538','new_theme','tab_1','RETURNING CUSTOMER',0,''),(615317,193658,'74538','new_theme','tab_2','REGISTER TO SAVE YOUR DETAILS',0,''),(615318,193660,'74540','new_theme','block_type','8',0,''),(615319,193661,'74541','new_theme','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(615320,193662,'74542','new_theme','block_type','1',0,''),(615321,193662,'74542','new_theme','padding-left','20',0,''),(615322,193662,'74542','new_theme','padding-right','20',0,''),(615323,193664,'74544','new_theme','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(615324,193665,'74545','new_theme','block_type','1',0,''),(615325,193666,'74546','new_theme','block_type','1',0,''),(615326,193667,'74547','new_theme','margin_left_measure','auto',0,''),(615327,193667,'74547','new_theme','margin_right_measure','auto',0,''),(615328,193667,'74547','new_theme','max-width','560',0,''),(615329,193668,'74548','new_theme','margin-bottom','30',0,''),(615330,193669,'74549','new_theme','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(615331,193670,'94779','new_theme','block_type','1',0,''),(615332,193672,'94781','new_theme','block_type','6',0,''),(615333,193672,'94781','new_theme','font-weight','400',0,''),(615334,193672,'94781','new_theme','schema','6-2',0,'8472'),(615335,193672,'94781','new_theme','schema','6-2',0,'8451'),(615336,193673,'94782','new_theme','font-weight','400',0,''),(615337,193673,'94782','new_theme','padding-right','40',0,''),(615338,193673,'94782','new_theme','padding-right','0',0,'8472'),(615339,193673,'94782','new_theme','padding-right','0',0,'8451'),(615340,193674,'94783','new_theme','col_in_row','3',0,''),(615341,193674,'94783','new_theme','products_align','left',0,''),(615342,193674,'94783','new_theme','font-weight','400',0,''),(615343,193674,'94783','new_theme','show_qty_input','0',0,''),(615344,193674,'94783','new_theme','listing_type','productListing',0,''),(615345,193674,'94783','new_theme','listing_type_rows','no',0,''),(615346,193674,'94783','new_theme','show_buy_button_b2b','on',0,''),(615347,193674,'94783','new_theme','show_wishlist_button_b2b','1',0,''),(615348,193674,'94783','new_theme','show_compare_b2b','1',0,''),(615349,193674,'94783','new_theme','show_stock','0',0,''),(615350,193674,'94783','new_theme','show_description','0',0,''),(615351,193674,'94783','new_theme','show_model','0',0,''),(615352,193674,'94783','new_theme','show_properties','0',0,''),(615353,193674,'94783','new_theme','show_rating','0',0,''),(615354,193674,'94783','new_theme','show_rating_counts','0',0,''),(615355,193674,'94783','new_theme','show_price','0',0,''),(615356,193674,'94783','new_theme','show_buy_button','0',0,''),(615357,193674,'94783','new_theme','show_view_button','0',0,''),(615358,193674,'94783','new_theme','show_wishlist_button','0',0,''),(615359,193674,'94783','new_theme','show_compare','0',0,''),(615360,193674,'94783','new_theme','show_name_rows','0',0,''),(615361,193674,'94783','new_theme','show_image_rows','0',0,''),(615362,193674,'94783','new_theme','show_stock_rows','0',0,''),(615363,193674,'94783','new_theme','show_description_rows','0',0,''),(615364,193674,'94783','new_theme','show_model_rows','0',0,''),(615365,193674,'94783','new_theme','show_properties_rows','0',0,''),(615366,193674,'94783','new_theme','show_rating_rows','0',0,''),(615367,193674,'94783','new_theme','show_rating_counts_rows','0',0,''),(615368,193674,'94783','new_theme','show_price_rows','0',0,''),(615369,193674,'94783','new_theme','show_buy_button_rows','0',0,''),(615370,193674,'94783','new_theme','show_qty_input_rows','0',0,''),(615371,193674,'94783','new_theme','show_view_button_rows','0',0,''),(615372,193674,'94783','new_theme','show_wishlist_button_rows','0',0,''),(615373,193674,'94783','new_theme','show_compare_rows','0',0,''),(615374,193674,'94783','new_theme','show_name_b2b','0',0,''),(615375,193674,'94783','new_theme','show_image_b2b','0',0,''),(615376,193674,'94783','new_theme','show_stock_b2b','0',0,''),(615377,193674,'94783','new_theme','show_description_b2b','0',0,''),(615378,193674,'94783','new_theme','show_model_b2b','0',0,''),(615379,193674,'94783','new_theme','show_properties_b2b','0',0,''),(615380,193674,'94783','new_theme','show_rating_b2b','0',0,''),(615381,193674,'94783','new_theme','show_rating_counts_b2b','0',0,''),(615382,193674,'94783','new_theme','show_price_b2b','0',0,''),(615383,193674,'94783','new_theme','show_qty_input_b2b','0',0,''),(615384,193674,'94783','new_theme','show_view_button_b2b','0',0,''),(615385,193674,'94783','new_theme','show_attributes_b2b','0',0,''),(615386,193674,'94783','new_theme','items_on_page','9',0,''),(615387,193674,'94783','new_theme','col_in_row','2',0,'8451'),(615388,193674,'94783','new_theme','col_in_row','1',0,'8472'),(615389,193674,'94783','new_theme','product_names_teg','h2',0,''),(615390,193676,'94785','new_theme','block_type','5',0,''),(615391,193676,'94785','new_theme','padding-top','10',0,''),(615392,193676,'94785','new_theme','padding-bottom','10',0,''),(615393,193676,'94785','new_theme','schema','5-2',0,'8472'),(615394,193676,'94785','new_theme','border-top-color','$content-border-1',0,''),(615395,193676,'94785','new_theme','border-top-width','1',0,''),(615396,193678,'94787','new_theme','float','right',0,''),(615397,193679,'94788','new_theme','listing_type','productListing',0,''),(615398,193681,'94790','new_theme','block_type','1',0,''),(615399,193681,'94790','new_theme','padding-top','10',0,''),(615400,193681,'94790','new_theme','padding-bottom','10',0,''),(615401,193681,'94790','new_theme','border-bottom-width','1',0,''),(615402,193681,'94790','new_theme','border-bottom-color','$content-border-1',0,''),(615403,193681,'94790','new_theme','margin-left','0',0,''),(615404,193681,'94790','new_theme','margin-right','0',0,''),(615405,193682,'94791','new_theme','float','right',0,''),(615406,193682,'94791','new_theme','display','none',0,'8472'),(615407,193683,'94792','new_theme','float','left',0,''),(615408,193683,'94792','new_theme','clear','none',0,''),(615409,193683,'94792','new_theme','margin-left','20',0,''),(615410,193683,'94792','new_theme','display','none',0,'8472'),(615411,193684,'94793','new_theme','margin-right','20',0,''),(615412,193684,'94793','new_theme','float','right',0,''),(615413,193684,'94793','new_theme','clear','none',0,''),(615414,193684,'94793','new_theme','display','none',0,'8451'),(615415,193685,'94794','new_theme','float','left',0,''),(615416,193685,'94794','new_theme','clear','none',0,''),(615417,193685,'94794','new_theme','sort_pos_3','1',0,''),(615418,193685,'94794','new_theme','sort_pos_4','2',0,''),(615419,193685,'94794','new_theme','sort_pos_10','3',0,''),(615420,193685,'94794','new_theme','sort_pos_9','4',0,''),(615421,193685,'94794','new_theme','sort_pos_11','5',0,''),(615422,193685,'94794','new_theme','sort_pos_12','6',0,''),(615423,193685,'94794','new_theme','sort_pos_14','7',0,''),(615424,193685,'94794','new_theme','sort_pos_13','8',0,''),(615425,193685,'94794','new_theme','sort_pos_8','9',0,''),(615426,193685,'94794','new_theme','sort_pos_7','10',0,''),(615427,193685,'94794','new_theme','sort_pos_2','11',0,''),(615428,193685,'94794','new_theme','sort_pos_1','12',0,''),(615429,193685,'94794','new_theme','sort_pos_6','13',0,''),(615430,193685,'94794','new_theme','sort_pos_5','14',0,''),(615431,193685,'94794','new_theme','sort_pos_0','15',0,''),(615432,193685,'94794','new_theme','sort_hide_10','1',0,''),(615433,193685,'94794','new_theme','sort_hide_9','1',0,''),(615434,193685,'94794','new_theme','hide_icons','1',0,''),(615435,193685,'94794','new_theme','sort_hide_16','1',0,''),(615436,193685,'94794','new_theme','sort_hide_15','1',0,''),(615437,193685,'94794','new_theme','sort_hide_3','0',0,''),(615438,193685,'94794','new_theme','sort_hide_4','0',0,''),(615439,193685,'94794','new_theme','sort_hide_11','1',0,''),(615440,193685,'94794','new_theme','sort_hide_12','1',0,''),(615441,193685,'94794','new_theme','sort_hide_14','1',0,''),(615442,193685,'94794','new_theme','sort_hide_13','1',0,''),(615443,193685,'94794','new_theme','sort_hide_8','0',0,''),(615444,193685,'94794','new_theme','sort_hide_7','0',0,''),(615445,193685,'94794','new_theme','sort_hide_2','1',0,''),(615446,193685,'94794','new_theme','sort_hide_1','1',0,''),(615447,193685,'94794','new_theme','sort_hide_6','1',0,''),(615448,193685,'94794','new_theme','sort_hide_5','1',0,''),(615449,193685,'94794','new_theme','sort_hide_0','1',0,''),(615450,193686,'74550','new_theme','block_type','1',0,''),(615451,193687,'74551','new_theme','margin-bottom','30',0,''),(615452,193688,'74552','new_theme','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(615453,193689,'74553','new_theme','block_type','1',0,''),(615454,193690,'74554','new_theme','block_type','5',0,''),(615455,193690,'74554','new_theme','padding-top','10',0,''),(615456,193690,'74554','new_theme','padding-bottom','10',0,''),(615457,193690,'74554','new_theme','schema','5-2',0,'8472'),(615458,193690,'74554','new_theme','border-top-color','$content-border-1',0,''),(615459,193690,'74554','new_theme','border-top-width','1',0,''),(615460,193691,'74555','new_theme','padding-top','3',0,''),(615461,193692,'74556','new_theme','float','right',0,''),(615462,193692,'74556','new_theme','height','31',0,''),(615463,193693,'74557','new_theme','col_in_row','4',0,''),(615464,193693,'74557','new_theme','products_align','left',0,''),(615465,193693,'74557','new_theme','font-weight','400',0,''),(615466,193693,'74557','new_theme','listing_type','productListing',0,''),(615467,193693,'74557','new_theme','listing_type_rows','Rows',0,''),(615468,193693,'74557','new_theme','show_buy_button_b2b','on',0,''),(615469,193693,'74557','new_theme','show_wishlist_button_b2b','1',0,''),(615470,193693,'74557','new_theme','show_compare_b2b','1',0,''),(615471,193693,'74557','new_theme','show_image','0',0,''),(615472,193693,'74557','new_theme','show_stock','0',0,''),(615473,193693,'74557','new_theme','show_description','0',0,''),(615474,193693,'74557','new_theme','show_model','0',0,''),(615475,193693,'74557','new_theme','show_properties','0',0,''),(615476,193693,'74557','new_theme','show_rating','0',0,''),(615477,193693,'74557','new_theme','show_rating_counts','0',0,''),(615478,193693,'74557','new_theme','show_price','0',0,''),(615479,193693,'74557','new_theme','show_buy_button','0',0,''),(615480,193693,'74557','new_theme','show_view_button','0',0,''),(615481,193693,'74557','new_theme','show_wishlist_button','0',0,''),(615482,193693,'74557','new_theme','show_compare','0',0,''),(615483,193693,'74557','new_theme','show_name_rows','0',0,''),(615484,193693,'74557','new_theme','show_image_rows','0',0,''),(615485,193693,'74557','new_theme','show_stock_rows','0',0,''),(615486,193693,'74557','new_theme','show_description_rows','0',0,''),(615487,193693,'74557','new_theme','show_model_rows','0',0,''),(615488,193693,'74557','new_theme','show_properties_rows','0',0,''),(615489,193693,'74557','new_theme','show_rating_rows','0',0,''),(615490,193693,'74557','new_theme','show_rating_counts_rows','0',0,''),(615491,193693,'74557','new_theme','show_price_rows','0',0,''),(615492,193693,'74557','new_theme','show_buy_button_rows','0',0,''),(615493,193693,'74557','new_theme','show_qty_input_rows','0',0,''),(615494,193693,'74557','new_theme','show_view_button_rows','0',0,''),(615495,193693,'74557','new_theme','show_wishlist_button_rows','0',0,''),(615496,193693,'74557','new_theme','show_compare_rows','0',0,''),(615497,193693,'74557','new_theme','show_name_b2b','0',0,''),(615498,193693,'74557','new_theme','show_image_b2b','0',0,''),(615499,193693,'74557','new_theme','show_stock_b2b','0',0,''),(615500,193693,'74557','new_theme','show_description_b2b','0',0,''),(615501,193693,'74557','new_theme','show_model_b2b','0',0,''),(615502,193693,'74557','new_theme','show_properties_b2b','0',0,''),(615503,193693,'74557','new_theme','show_rating_b2b','0',0,''),(615504,193693,'74557','new_theme','show_rating_counts_b2b','0',0,''),(615505,193693,'74557','new_theme','show_price_b2b','0',0,''),(615506,193693,'74557','new_theme','show_qty_input_b2b','0',0,''),(615507,193693,'74557','new_theme','show_view_button_b2b','0',0,''),(615508,193693,'74557','new_theme','show_attributes_b2b','0',0,''),(615509,193693,'74557','new_theme','items_on_page','12',0,''),(615510,193693,'74557','new_theme','col_in_row','2',0,'8451'),(615511,193693,'74557','new_theme','col_in_row','1',0,'8472'),(615512,193693,'74557','new_theme','product_names_teg','h2',0,''),(615513,193696,'74560','new_theme','block_type','1',0,''),(615514,193697,'74561','new_theme','block_type','1',0,''),(615515,193697,'74561','new_theme','padding-top','10',0,''),(615516,193697,'74561','new_theme','padding-bottom','10',0,''),(615517,193697,'74561','new_theme','border-bottom-width','1',0,''),(615518,193697,'74561','new_theme','border-bottom-color','$content-border-1',0,''),(615519,193697,'74561','new_theme','margin-left','0',0,''),(615520,193697,'74561','new_theme','margin-right','0',0,''),(615521,193698,'74562','new_theme','clear','none',0,''),(615522,193698,'74562','new_theme','float','left',0,''),(615523,193698,'74562','new_theme','padding-top','3',0,''),(615524,193698,'74562','new_theme','margin-left','20',0,''),(615525,193699,'74563','new_theme','float','right',0,''),(615526,193699,'74563','new_theme','display','none',0,'8472'),(615527,193700,'74564','new_theme','margin-right','20',0,''),(615528,193700,'74564','new_theme','float','right',0,''),(615529,193700,'74564','new_theme','clear','none',0,''),(615530,193700,'74564','new_theme','display','none',0,'8451'),(615531,193701,'74565','new_theme','float','left',0,''),(615532,193701,'74565','new_theme','clear','none',0,''),(615533,193701,'74565','new_theme','margin-left','20',0,''),(615534,193701,'74565','new_theme','display','none',0,'8472'),(615535,193702,'74566','new_theme','float','left',0,''),(615536,193702,'74566','new_theme','clear','none',0,''),(615537,193702,'74566','new_theme','sort_pos_3','2',0,''),(615538,193702,'74566','new_theme','sort_pos_4','3',0,''),(615539,193702,'74566','new_theme','sort_pos_10','11',0,''),(615540,193702,'74566','new_theme','sort_pos_9','10',0,''),(615541,193702,'74566','new_theme','sort_pos_11','12',0,''),(615542,193702,'74566','new_theme','sort_pos_12','13',0,''),(615543,193702,'74566','new_theme','sort_pos_14','15',0,''),(615544,193702,'74566','new_theme','sort_pos_13','14',0,''),(615545,193702,'74566','new_theme','sort_pos_8','4',0,''),(615546,193702,'74566','new_theme','sort_pos_7','5',0,''),(615547,193702,'74566','new_theme','sort_pos_2','7',0,''),(615548,193702,'74566','new_theme','sort_pos_1','6',0,''),(615549,193702,'74566','new_theme','sort_pos_6','9',0,''),(615550,193702,'74566','new_theme','sort_pos_5','8',0,''),(615551,193702,'74566','new_theme','sort_pos_0','1',0,''),(615552,193702,'74566','new_theme','sort_hide_10','1',0,''),(615553,193702,'74566','new_theme','sort_hide_9','1',0,''),(615554,193702,'74566','new_theme','sort_pos_15','16',0,''),(615555,193702,'74566','new_theme','sort_pos_16','17',0,''),(615556,193702,'74566','new_theme','sort_hide_4','0',0,''),(615557,193702,'74566','new_theme','sort_hide_3','0',0,''),(615558,193702,'74566','new_theme','sort_hide_16','1',0,''),(615559,193702,'74566','new_theme','sort_hide_15','1',0,''),(615560,193702,'74566','new_theme','sort_hide_11','1',0,''),(615561,193702,'74566','new_theme','sort_hide_12','1',0,''),(615562,193702,'74566','new_theme','sort_hide_14','1',0,''),(615563,193702,'74566','new_theme','sort_hide_13','1',0,''),(615564,193702,'74566','new_theme','sort_hide_8','0',0,''),(615565,193702,'74566','new_theme','sort_hide_7','0',0,''),(615566,193702,'74566','new_theme','sort_hide_2','1',0,''),(615567,193702,'74566','new_theme','sort_hide_1','1',0,''),(615568,193702,'74566','new_theme','sort_hide_6','1',0,''),(615569,193702,'74566','new_theme','sort_hide_5','1',0,''),(615570,193702,'74566','new_theme','sort_hide_0','0',0,''),(615571,193702,'74566','new_theme','hide_icons','1',0,''),(615572,193703,'74567','new_theme','margin-bottom','20',0,''),(615573,193704,'74568','new_theme','block_type','1',0,''),(615574,193704,'74568','new_theme','style_class','account-order-history',0,''),(615575,193705,'74569','new_theme','block_type','6',0,''),(615576,193705,'74569','new_theme','schema','6-3',0,'8451'),(615577,193706,'74570','new_theme','aria_name','account-menu',0,''),(615578,193707,'73374','new_theme','block_type','1',0,''),(615579,193707,'73374','new_theme','padding-top','70',0,''),(615580,193707,'73374','new_theme','padding-right','30',0,''),(615581,193707,'73374','new_theme','padding-bottom','30',0,''),(615582,193707,'73374','new_theme','padding-top','0',0,'8451'),(615583,193707,'73374','new_theme','padding-left','0',0,'8451'),(615584,193707,'73374','new_theme','padding-right','0',0,'8451'),(615585,193707,'73374','new_theme','padding-bottom','0',0,'8451'),(615628,193726,'74571','new_theme','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(615629,193727,'74572','new_theme','link','Order History Info',0,''),(615630,193727,'74572','new_theme','text','TEXT_VIEW',0,''),(615631,193727,'74572','new_theme','show_pagenation','1',0,''),(615632,193727,'74572','new_theme','link_pay','Order pay',0,''),(615633,193727,'74572','new_theme','margin-bottom','20',0,''),(615634,193728,'74573','new_theme','block_type','1',0,''),(615635,193728,'74573','new_theme','style_class','account-order-history-info',0,''),(615636,193729,'74574','new_theme','block_type','6',0,''),(615637,193729,'74574','new_theme','schema','6-3',0,'8451'),(615638,193730,'74575','new_theme','aria_name','account-menu',0,''),(615639,193731,'73374','new_theme','block_type','1',0,''),(615640,193731,'73374','new_theme','padding-top','70',0,''),(615641,193731,'73374','new_theme','padding-right','30',0,''),(615642,193731,'73374','new_theme','padding-bottom','30',0,''),(615643,193731,'73374','new_theme','padding-top','0',0,'8451'),(615644,193731,'73374','new_theme','padding-left','0',0,'8451'),(615645,193731,'73374','new_theme','padding-right','0',0,'8451'),(615646,193731,'73374','new_theme','padding-bottom','0',0,'8451'),(615689,193750,'74576','new_theme','float','right',0,''),(615690,193750,'74576','new_theme','clear','none',0,''),(615691,193750,'74576','new_theme','margin-left','20',0,''),(615692,193752,'74578','new_theme','float','right',0,''),(615693,193752,'74578','new_theme','clear','none',0,''),(615694,193752,'74578','new_theme','like_button','2',0,''),(615695,193752,'74578','new_theme','link','Order pay',0,''),(615696,193753,'74579','new_theme','block_type','2',0,''),(615697,193753,'74579','new_theme','padding-top','20',0,''),(615698,193753,'74579','new_theme','margin-bottom','20',0,''),(615699,193754,'74580','new_theme','like_button','1',0,''),(615700,193754,'74580','new_theme','text','IMAGE_BUTTON_BACK',0,''),(615701,193754,'74580','new_theme','link','Order History',0,''),(615702,193755,'74581','new_theme','text-align','right',0,''),(615703,193756,'74582','new_theme','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(615704,193758,'74584','new_theme','float','right',0,''),(615705,193758,'74584','new_theme','clear','none',0,''),(615706,193758,'74584','new_theme','margin-left','20',0,''),(615707,193760,'74586','new_theme','float','right',0,''),(615708,193761,'74587','new_theme','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(615709,193763,'74589','new_theme','float','left',0,''),(615710,193764,'74590','new_theme','block_type','3',0,''),(615711,193764,'74590','new_theme','clear','both',0,''),(615712,193764,'74590','new_theme','padding-top','20',0,''),(615713,193764,'74590','new_theme','schema','3-4',0,'8444'),(615714,193765,'74591','new_theme','block_type','1',0,''),(615715,193765,'74591','new_theme','margin-bottom','20',0,''),(615716,193765,'74591','new_theme','padding-right','0',0,'8444'),(615717,193765,'74591','new_theme','padding-right','20',0,''),(615718,193766,'74592','new_theme','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(615719,193767,'74593','new_theme','padding-left','30',0,''),(615720,193767,'74593','new_theme','orders_data','telephone',0,''),(615721,193767,'74593','new_theme','hide_parents','2',0,''),(615722,193768,'74594','new_theme','block_type','1',0,''),(615723,193768,'74594','new_theme','padding-right','20',0,''),(615724,193768,'74594','new_theme','padding-bottom','20',0,''),(615725,193768,'74594','new_theme','padding-right','0',0,'8444'),(615726,193769,'74595','new_theme','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(615727,193770,'74596','new_theme','orders_data','name',0,''),(615728,193770,'74596','new_theme','padding-left','30',0,''),(615729,193771,'74597','new_theme','block_type','1',0,''),(615730,193771,'74597','new_theme','padding-right','20',0,''),(615731,193771,'74597','new_theme','margin-bottom','20',0,''),(615732,193771,'74597','new_theme','padding-right','0',0,'8444'),(615733,193772,'74598','new_theme','short_view','1',0,''),(615734,193772,'74598','new_theme','hide_parents','2',0,''),(615735,193773,'74599','new_theme','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(615736,193774,'74600','new_theme','link','Tracking numbers',0,''),(615737,193774,'74600','new_theme','text','MORE_TRACKING_NUMBER',0,''),(615738,193774,'74600','new_theme','popup','1',0,''),(615739,193774,'74600','new_theme','order_id','1',0,''),(615740,193774,'74600','new_theme','popup_class','tracking-numbers-popup',0,''),(615741,193774,'74600','new_theme','font-weight','700',0,''),(615742,193774,'74600','new_theme','font-size','18',0,''),(615743,193775,'74601','new_theme','block_type','1',0,''),(615744,193775,'74601','new_theme','padding-right','20',0,''),(615745,193775,'74601','new_theme','padding-right','0',0,'8444'),(615746,193776,'74602','new_theme','orders_data','shipping_method',0,''),(615747,193776,'74602','new_theme','padding-left','30',0,''),(615748,193777,'74603','new_theme','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(615749,193778,'74604','new_theme','block_type','1',0,''),(615750,193778,'74604','new_theme','padding-right','20',0,''),(615751,193778,'74604','new_theme','padding-bottom','20',0,''),(615752,193778,'74604','new_theme','padding-right','0',0,'8444'),(615753,193779,'74605','new_theme','orders_data','delivery_address',0,''),(615754,193779,'74605','new_theme','padding-left','30',0,''),(615755,193780,'74606','new_theme','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(615756,193781,'74607','new_theme','block_type','1',0,''),(615757,193782,'74608','new_theme','orders_data','payment_method',0,''),(615758,193782,'74608','new_theme','padding-left','30',0,''),(615759,193783,'74609','new_theme','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(615760,193784,'74610','new_theme','block_type','1',0,''),(615761,193784,'74610','new_theme','padding-bottom','20',0,''),(615762,193785,'74611','new_theme','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(615763,193786,'74612','new_theme','orders_data','billing_address',0,''),(615764,193786,'74612','new_theme','padding-left','30',0,''),(615765,193787,'74613','new_theme','block_type','1',0,''),(615766,193787,'74613','new_theme','style_class','account-order-pay',0,''),(615767,193788,'74614','new_theme','block_type','6',0,''),(615768,193788,'74614','new_theme','schema','6-3',0,'8451'),(615769,193789,'74615','new_theme','aria_name','account-menu',0,''),(615770,193790,'73374','new_theme','block_type','1',0,''),(615771,193790,'73374','new_theme','padding-top','70',0,''),(615772,193790,'73374','new_theme','padding-right','30',0,''),(615773,193790,'73374','new_theme','padding-bottom','30',0,''),(615774,193790,'73374','new_theme','padding-top','0',0,'8451'),(615775,193790,'73374','new_theme','padding-left','0',0,'8451'),(615776,193790,'73374','new_theme','padding-right','0',0,'8451'),(615777,193790,'73374','new_theme','padding-bottom','0',0,'8451'),(615820,193810,'74617','new_theme','block_type','3',0,''),(615821,193811,'74618','new_theme','block_type','1',0,''),(615822,193811,'74618','new_theme','padding-right','20',0,''),(615823,193811,'74618','new_theme','padding-bottom','20',0,''),(615824,193812,'74619','new_theme','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(615825,193813,'74620','new_theme','orders_data','name',0,''),(615826,193813,'74620','new_theme','padding-left','30',0,''),(615827,193814,'74621','new_theme','block_type','1',0,''),(615828,193815,'74622','new_theme','padding-left','30',0,''),(615829,193816,'74623','new_theme','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(615830,193817,'74624','new_theme','block_type','1',0,''),(615831,193817,'74624','new_theme','padding-right','20',0,''),(615832,193817,'74624','new_theme','padding-bottom','20',0,''),(615833,193818,'74625','new_theme','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(615834,193819,'74626','new_theme','orders_data','delivery_address',0,''),(615835,193819,'74626','new_theme','padding-left','30',0,''),(615836,193820,'74627','new_theme','block_type','1',0,''),(615837,193820,'74627','new_theme','padding-right','20',0,''),(615838,193821,'74628','new_theme','orders_data','shipping_method',0,''),(615839,193821,'74628','new_theme','padding-left','30',0,''),(615840,193822,'74629','new_theme','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(615841,193823,'74630','new_theme','block_type','1',0,''),(615842,193824,'74631','new_theme','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(615843,193825,'74632','new_theme','orders_data','payment_method',0,''),(615844,193825,'74632','new_theme','padding-left','30',0,''),(615845,193826,'74633','new_theme','block_type','1',0,''),(615846,193826,'74633','new_theme','padding-bottom','20',0,''),(615847,193827,'74634','new_theme','orders_data','billing_address',0,''),(615848,193827,'74634','new_theme','padding-left','30',0,''),(615849,193828,'74635','new_theme','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(615850,193829,'74636','new_theme','margin-bottom','20',0,''),(615851,193830,'74637','new_theme','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(615852,193833,'74640','new_theme','width','680',0,''),(615853,193833,'74640','new_theme','font-weight','400',0,''),(615854,193833,'74640','new_theme','font-size','12',0,''),(615855,193833,'74640','new_theme','padding-top','20',0,''),(615856,193833,'74640','new_theme','padding-bottom','20',0,''),(615857,193834,'74641','new_theme','block_type','2',0,''),(615858,193834,'74641','new_theme','font-weight','normal',0,''),(615859,193834,'74641','new_theme','padding-bottom','20',0,''),(615860,193835,'74642','new_theme','font-weight','400',0,''),(615861,193835,'74642','new_theme','text-align','center',0,''),(615862,193835,'74642','new_theme','padding-top','10',0,''),(615863,193835,'74642','new_theme','logo_from','theme',0,''),(615864,193836,'74643','new_theme','block_type','11',0,''),(615865,193836,'74643','new_theme','font-weight','normal',0,''),(615866,193837,'74644','new_theme','text','<p>Email:</p>',1,''),(615867,193837,'74644','new_theme','font-weight','normal',0,''),(615868,193837,'74644','new_theme','text-align','right',0,''),(615869,193837,'74644','new_theme','text','<p>Email:</p>',0,''),(615870,193838,'74645','new_theme','font-weight','normal',0,''),(615871,193838,'74645','new_theme','text-align','right',0,''),(615872,193839,'74646','new_theme','block_type','11',0,''),(615873,193839,'74646','new_theme','font-weight','normal',0,''),(615874,193840,'74647','new_theme','text','<p>Phone:</p>',1,''),(615875,193840,'74647','new_theme','font-weight','normal',0,''),(615876,193840,'74647','new_theme','text-align','right',0,''),(615877,193840,'74647','new_theme','text','<p>Phone:</p>',0,''),(615878,193841,'74648','new_theme','font-weight','normal',0,''),(615879,193841,'74648','new_theme','text-align','right',0,''),(615880,193842,'74649','new_theme','block_type','1',0,''),(615881,193843,'74650','new_theme','font-weight','400',0,''),(615882,193843,'74650','new_theme','text-align','right',0,''),(615883,193843,'74650','new_theme','padding-bottom','10',0,''),(615884,193843,'74650','new_theme','address_spacer',',',0,''),(615885,193843,'74650','new_theme','font-size','12',0,''),(615886,193844,'74651','new_theme','block_type','11',0,''),(615887,193844,'74651','new_theme','font-weight','400',0,''),(615888,193845,'74652','new_theme','text','<p>Web:</p>',1,''),(615889,193845,'74652','new_theme','font-weight','400',0,''),(615890,193845,'74652','new_theme','text-align','right',0,''),(615891,193845,'74652','new_theme','text','<p>Web:</p>',0,''),(615892,193846,'74653','new_theme','font-weight','normal',0,''),(615893,193846,'74653','new_theme','text-align','right',0,''),(615894,193847,'74654','new_theme','font-weight','normal',0,''),(615895,193847,'74654','new_theme','padding-top','20',0,''),(615896,193847,'74654','new_theme','font-size','12',0,''),(615897,193848,'74655','new_theme','block_type','1',0,''),(615898,193848,'74655','new_theme','font-weight','normal',0,''),(615899,193848,'74655','new_theme','padding-top','10',0,''),(615900,193848,'74655','new_theme','padding-bottom','10',0,''),(615901,193850,'74657','new_theme','text','<p>If undelivered please return to:</p>',1,''),(615902,193850,'74657','new_theme','font-weight','bold',0,''),(615903,193850,'74657','new_theme','text','<p>If undelivered please return to:</p>',0,''),(615904,193851,'74658','new_theme','block_type','4',0,''),(615905,193851,'74658','new_theme','font-weight','400',0,''),(615906,193851,'74658','new_theme','border-top-width','1',0,''),(615907,193851,'74658','new_theme','border-top-color','$content-border-1',0,''),(615908,193851,'74658','new_theme','border-left-width','1',0,''),(615909,193851,'74658','new_theme','border-left-color','$content-border-1',0,''),(615910,193851,'74658','new_theme','border-right-width','1',0,''),(615911,193851,'74658','new_theme','border-right-color','$content-border-1',0,''),(615912,193851,'74658','new_theme','border-bottom-width','1',0,''),(615913,193851,'74658','new_theme','border-bottom-color','$content-border-1',0,''),(615914,193852,'74659','new_theme','block_type','2',0,''),(615915,193852,'74659','new_theme','font-weight','normal',0,''),(615916,193852,'74659','new_theme','border-right-width','1',0,''),(615917,193852,'74659','new_theme','border-right-color','$content-border-1',0,''),(615918,193853,'74660','new_theme','block_type','1',0,''),(615919,193853,'74660','new_theme','font-weight','normal',0,''),(615920,193853,'74660','new_theme','border-right-width','1',0,''),(615921,193853,'74660','new_theme','border-right-color','$content-border-1',0,''),(615922,193853,'74660','new_theme','background-color','$content-bg-2',0,''),(615923,193853,'74660','new_theme','padding-top','10',0,''),(615924,193853,'74660','new_theme','padding-left','10',0,''),(615925,193853,'74660','new_theme','padding-right','10',0,''),(615926,193853,'74660','new_theme','padding-bottom','10',0,''),(615927,193854,'74661','new_theme','font-size','12',0,''),(615928,193854,'74661','new_theme','font-weight','normal',0,''),(615929,193855,'74662','new_theme','text','<p>SHIPPING ADDRESS:</p>',1,''),(615930,193855,'74662','new_theme','font-size','13',0,''),(615931,193855,'74662','new_theme','font-weight','bold',0,''),(615932,193855,'74662','new_theme','padding-bottom','10',0,''),(615933,193855,'74662','new_theme','text','<p>SHIPPING ADDRESS:</p>',0,''),(615934,193856,'74663','new_theme','block_type','1',0,''),(615935,193856,'74663','new_theme','font-weight','normal',0,''),(615936,193856,'74663','new_theme','padding-top','10',0,''),(615937,193856,'74663','new_theme','padding-left','10',0,''),(615938,193856,'74663','new_theme','padding-right','10',0,''),(615939,193856,'74663','new_theme','padding-bottom','10',0,''),(615940,193857,'74664','new_theme','text','<p>CUSTOMER:</p>',1,''),(615941,193857,'74664','new_theme','font-size','13',0,''),(615942,193857,'74664','new_theme','font-weight','bold',0,''),(615943,193857,'74664','new_theme','text','<p>CUSTOMER:</p>',0,''),(615944,193858,'74665','new_theme','font-size','12',0,''),(615945,193860,'74667','new_theme','text','<p>PHONE NUMBER:</p>',1,''),(615946,193860,'74667','new_theme','font-size','13',0,''),(615947,193860,'74667','new_theme','font-weight','bold',0,''),(615948,193860,'74667','new_theme','padding-top','10',0,''),(615949,193860,'74667','new_theme','text','<p>PHONE NUMBER:</p>',0,''),(615950,193861,'74668','new_theme','font-size','12',0,''),(615951,193862,'74669','new_theme','text','<p>E-MAIL ADDRESS:</p>',1,''),(615952,193862,'74669','new_theme','font-size','13',0,''),(615953,193862,'74669','new_theme','font-weight','bold',0,''),(615954,193862,'74669','new_theme','padding-top','10',0,''),(615955,193862,'74669','new_theme','text','<p>E-MAIL ADDRESS:</p>',0,''),(615956,193863,'74670','new_theme','block_type','2',0,''),(615957,193863,'74670','new_theme','font-weight','normal',0,''),(615958,193863,'74670','new_theme','border-right-width','1',0,''),(615959,193863,'74670','new_theme','border-right-color','$content-border-1',0,''),(615960,193863,'74670','new_theme','border-top-width','1',0,''),(615961,193863,'74670','new_theme','border-top-color','$content-border-1',0,''),(615962,193864,'74671','new_theme','block_type','1',0,''),(615963,193864,'74671','new_theme','font-weight','normal',0,''),(615964,193864,'74671','new_theme','padding-top','10',0,''),(615965,193864,'74671','new_theme','padding-left','10',0,''),(615966,193864,'74671','new_theme','padding-right','10',0,''),(615967,193864,'74671','new_theme','padding-bottom','10',0,''),(615968,193864,'74671','new_theme','border-right-width','1',0,''),(615969,193864,'74671','new_theme','border-right-color','$content-border-1',0,''),(615970,193866,'74673','new_theme','text','<p>Shipping via</p>',1,''),(615971,193866,'74673','new_theme','font-weight','bold',0,''),(615972,193866,'74673','new_theme','text','<p>Shipping via</p>',0,''),(615973,193867,'74674','new_theme','block_type','1',0,''),(615974,193867,'74674','new_theme','font-weight','normal',0,''),(615975,193867,'74674','new_theme','padding-top','10',0,''),(615976,193867,'74674','new_theme','padding-left','10',0,''),(615977,193867,'74674','new_theme','padding-right','10',0,''),(615978,193867,'74674','new_theme','padding-bottom','10',0,''),(615979,193869,'74676','new_theme','text','<p>Shipping service</p>',1,''),(615980,193869,'74676','new_theme','font-weight','bold',0,''),(615981,193869,'74676','new_theme','text','<p>Shipping service</p>',0,''),(615982,193870,'74677','new_theme','font-weight','normal',0,''),(615983,193870,'74677','new_theme','text-align','center',0,''),(615984,193870,'74677','new_theme','padding-top','40',0,''),(615985,193871,'74678','new_theme','block_type','1',0,''),(615986,193872,'74679','new_theme','block_type','8',0,''),(615987,193873,'74680','new_theme','text','##TEXT_MAIN##',0,''),(615988,193873,'74680','new_theme','margin-bottom','20',0,''),(615989,193873,'74680','new_theme','text-align','center',0,''),(615990,193874,'74681','new_theme','margin-bottom','20',0,''),(615991,193875,'74682','new_theme','text','<h1>##HEADING_TITLE##</h1>',0,''),(615992,193877,'74684','new_theme','block_type','2',0,''),(615993,193878,'74685','new_theme','block_type','1',0,''),(615994,193878,'74685','new_theme','style_class','product',0,''),(615995,193878,'74685','new_theme','padding-right','10',0,''),(615996,193878,'74685','new_theme','padding-bottom','20',0,''),(615997,193879,'74686','new_theme','block_type','1',0,''),(615998,193880,'74687','new_theme','product_element','products_name',0,''),(615999,193880,'74687','new_theme','font-family','$font-1',0,''),(616000,193880,'74687','new_theme','padding-bottom','10',0,''),(616001,193880,'74687','new_theme','font-size','16',0,''),(616002,193881,'74688','new_theme','block_type','2',0,''),(616003,193882,'74689','new_theme','product_element','image',0,''),(616004,193882,'74689','new_theme','padding-right','10',0,''),(616005,193883,'74690','new_theme','product_element','products_price_old',0,''),(616006,193883,'74690','new_theme','font-family','$font-1',0,''),(616007,193883,'74690','new_theme','font-size','14',0,''),(616008,193883,'74690','new_theme','text-decoration','line-through',0,''),(616009,193884,'74691','new_theme','product_element','products_price',0,''),(616010,193884,'74691','new_theme','font-family','$font-1',0,''),(616011,193884,'74691','new_theme','font-size','20',0,''),(616012,193884,'74691','new_theme','padding-top','20',0,''),(616013,193885,'74692','new_theme','block_type','1',0,''),(616014,193885,'74692','new_theme','style_class','product',0,''),(616015,193885,'74692','new_theme','padding-left','10',0,''),(616016,193885,'74692','new_theme','padding-bottom','20',0,''),(616017,193886,'74693','new_theme','block_type','2',0,''),(616018,193887,'74694','new_theme','product_element','image',0,''),(616019,193887,'74694','new_theme','padding-right','10',0,''),(616020,193888,'74695','new_theme','font-size','14',0,''),(616021,193888,'74695','new_theme','font-family','$font-1',0,''),(616022,193888,'74695','new_theme','text-decoration','line-through',0,''),(616023,193888,'74695','new_theme','product_element','products_price_old',0,''),(616024,193889,'74696','new_theme','product_element','products_price',0,''),(616025,193889,'74696','new_theme','font-family','$font-1',0,''),(616026,193889,'74696','new_theme','font-size','20',0,''),(616027,193889,'74696','new_theme','padding-top','20',0,''),(616028,193890,'74697','new_theme','block_type','1',0,''),(616029,193891,'74698','new_theme','product_element','products_name',0,''),(616030,193891,'74698','new_theme','font-family','$font-1',0,''),(616031,193891,'74698','new_theme','font-size','16',0,''),(616032,193891,'74698','new_theme','padding-bottom','10',0,''),(616033,193892,'74699','new_theme','font-size','30',0,''),(616034,193892,'74699','new_theme','font-family','$font-1',0,''),(616035,193892,'74699','new_theme','text-align','center',0,''),(616036,193892,'74699','new_theme','padding-bottom','50',0,''),(616037,193893,'74700','new_theme','padding-bottom','20',0,''),(616038,193893,'74700','new_theme','text-align','center',0,''),(616039,193894,'74701','new_theme','width','680',0,''),(616040,193895,'74702','new_theme','padding-top','200',0,''),(616041,193895,'74702','new_theme','padding-left','200',0,''),(616042,193895,'74702','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',1,''),(616043,193895,'74702','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',0,''),(616044,193896,'74703','new_theme','text','osCommerce 4',1,''),(616045,193896,'74703','new_theme','font-family','$font-1',0,''),(616046,193896,'74703','new_theme','font-size','40',0,''),(616047,193896,'74703','new_theme','padding-top','50',0,''),(616048,193896,'74703','new_theme','text-align','center',0,''),(616049,193896,'74703','new_theme','text','osCommerce 4',0,''),(616050,193897,'74704','new_theme','block_type','2',0,''),(616051,193897,'74704','new_theme','border-top-width','1',0,''),(616052,193897,'74704','new_theme','border-top-color','$content-border-1',0,''),(616053,193898,'74705','new_theme','text-align','right',0,''),(616054,193898,'74705','new_theme','padding-top','15',0,''),(616055,193898,'74705','new_theme','padding-bottom','15',0,''),(616056,193898,'74705','new_theme','font-size','14',0,''),(616057,193899,'74706','new_theme','font-family','$font-1',0,''),(616058,193899,'74706','new_theme','text-align','center',0,''),(616059,193899,'74706','new_theme','font-size','20',0,''),(616060,193899,'74706','new_theme','color','$highlight-color-1',0,''),(616061,193899,'74706','new_theme','border-bottom-width','1',0,''),(616062,193899,'74706','new_theme','border-bottom-color','$content-border-1',0,''),(616063,193899,'74706','new_theme','padding-top','10',0,''),(616064,193899,'74706','new_theme','padding-bottom','10',0,''),(616065,193900,'74707','new_theme','block_type','1',0,''),(616066,193901,'74708','new_theme','block_type','6',0,''),(616067,193901,'74708','new_theme','schema','6-3',0,'8451'),(616068,193902,'74709','new_theme','aria_name','account-menu',0,''),(616069,193903,'73374','new_theme','block_type','1',0,''),(616070,193903,'73374','new_theme','padding-top','70',0,''),(616071,193903,'73374','new_theme','padding-right','30',0,''),(616072,193903,'73374','new_theme','padding-bottom','30',0,''),(616073,193903,'73374','new_theme','padding-top','0',0,'8451'),(616074,193903,'73374','new_theme','padding-left','0',0,'8451'),(616075,193903,'73374','new_theme','padding-right','0',0,'8451'),(616076,193903,'73374','new_theme','padding-bottom','0',0,'8451'),(616119,193922,'74710','new_theme','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(616120,193923,'74711','new_theme','like_button','1',0,''),(616121,193923,'74711','new_theme','link','personal_catalog',0,''),(616122,193923,'74711','new_theme','text','BOX_INFORMATION_ALLPRODS',0,''),(616123,193923,'74711','new_theme','text-align','center',0,''),(616124,193923,'74711','new_theme','padding-top','20',0,''),(616125,193923,'74711','new_theme','padding-bottom','20',0,''),(616126,193924,'74712','new_theme','max_items','10',0,''),(616127,193925,'74713','new_theme','block_type','1',0,''),(616128,193925,'74713','new_theme','padding-top','20',0,''),(616129,193925,'74713','new_theme','padding-left','20',0,''),(616130,193925,'74713','new_theme','padding-right','20',0,''),(616131,193925,'74713','new_theme','padding-bottom','20',0,''),(616132,193926,'74714','new_theme','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(616133,193928,'74716','new_theme','block_type','1',0,''),(616134,193929,'74717','new_theme','margin_left_measure','auto',0,''),(616135,193929,'74717','new_theme','margin_right_measure','auto',0,''),(616136,193929,'74717','new_theme','max-width','560',0,''),(616137,193930,'74718','new_theme','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(616138,193931,'74719','new_theme','margin-bottom','30',0,''),(616139,193932,'74720','new_theme','block_type','1',0,''),(616140,193932,'74720','new_theme','style_class','catalog-product-wrap',0,''),(616141,193934,'74722','new_theme','block_type','2',0,''),(616142,193934,'74722','new_theme','font-weight','400',0,''),(616143,193934,'74722','new_theme','padding-bottom','20',0,''),(616144,193934,'74722','new_theme','schema','2-2',0,'8472'),(616145,193935,'74724','new_theme','font-weight','400',0,''),(616146,193935,'74724','new_theme','padding-top','20',0,''),(616147,193935,'74724','new_theme','padding-right','20',0,''),(616148,193935,'74724','new_theme','box_align','4',0,''),(616149,193935,'74724','new_theme','margin-bottom','50',0,''),(616150,193935,'74724','new_theme','align_position','horizontal',0,''),(616151,193938,'74727','new_theme','block_type','12',0,''),(616152,193938,'74727','new_theme','padding-top','15',0,''),(616153,193938,'74727','new_theme','padding-bottom','5',0,''),(616154,193938,'74727','new_theme','border-top-width','1',0,''),(616155,193938,'74727','new_theme','border-top-color','$content-border-1',0,''),(616156,193938,'74727','new_theme','schema','2-2',0,'8444'),(616157,193938,'74727','new_theme','margin-bottom','15',0,''),(616158,193938,'74727','new_theme','border-bottom-width','1',0,''),(616159,193938,'74727','new_theme','border-bottom-color','$content-border-1',0,''),(616160,193938,'74727','new_theme','schema','12-2',0,'8451'),(616161,193939,'74728','new_theme','padding-top','10',0,''),(616162,193939,'74728','new_theme','padding-bottom','10',0,''),(616163,193940,'74729','new_theme','block_type','2',0,''),(616164,193940,'74729','new_theme','schema','2-1',0,'8451'),(616165,193941,'74730','new_theme','font-size','30',0,''),(616166,193941,'74730','new_theme','font-weight','400',0,''),(616167,193941,'74730','new_theme','line-height','35',0,''),(616168,193941,'74730','new_theme','font-family','$font-1',0,''),(616169,193941,'74730','new_theme','line_height_measure','px',0,''),(616170,193941,'74730','new_theme','padding-top','5',0,''),(616171,193942,'74731','new_theme','box_align','4',0,''),(616172,193942,'74731','new_theme','margin-bottom','15',0,'8451'),(616173,193942,'74731','new_theme','text-align','right',0,'8451'),(616174,193942,'74731','new_theme','padding-top','5',0,''),(616175,193942,'74731','new_theme','text-align','left',0,''),(616176,193943,'74732','new_theme','margin-bottom','15',0,''),(616177,193943,'74732','new_theme','padding-top','15',0,''),(616178,193944,'1694165842.4776','new_theme','padding-top','10',0,''),(616179,193945,'74733','new_theme','text-align','right',0,''),(616180,193945,'74733','new_theme','width','100',0,'8444'),(616181,193945,'74733','new_theme','width_measure','%',0,'8444'),(616182,193945,'74733','new_theme','float','none',0,'8444'),(616183,193945,'74733','new_theme','hide_additional_buttons','1',0,''),(616184,193946,'74734','new_theme','text-align','right',0,''),(616185,193947,'74735','new_theme','cat_description','on',0,''),(616186,193947,'74735','new_theme','length_description','250',0,''),(616187,193947,'74735','new_theme','padding-bottom','20',0,''),(616188,193948,'74737','new_theme','document_types_id','4',0,''),(616189,193949,'74738','new_theme','show_address','1',0,''),(616190,193949,'74738','new_theme','show_time','1',0,''),(616191,193949,'74738','new_theme','show_qty','1',0,''),(616192,193949,'74738','new_theme','show_qty_level1','500',0,''),(616193,193949,'74738','new_theme','show_qty_level2','2000',0,''),(616194,193949,'74738','new_theme','text-align','right',0,''),(616195,193949,'74738','new_theme','margin-bottom','10',0,''),(616196,193950,'74739','new_theme','block_type','2',0,''),(616197,193954,'74745','new_theme','font-weight','400',0,''),(616198,193958,'74750','new_theme','font-weight','normal',0,''),(616199,193958,'74750','new_theme','padding-top','10',0,''),(616200,193958,'74750','new_theme','padding-bottom','10',0,''),(616201,193958,'74750','new_theme','box_align','4',0,''),(616202,193959,'74752','new_theme','tab_1','Description',1,''),(616203,193959,'74752','new_theme','tab_2','Reviews',1,''),(616204,193959,'74752','new_theme','font-weight','400',0,''),(616205,193959,'74752','new_theme','tab_1','Description',0,''),(616206,193959,'74752','new_theme','tab_2','Reviews',0,''),(616207,193960,'74753','new_theme','hTagsInline','block',0,''),(616208,193961,'74754','new_theme','margin-bottom','20',0,''),(616209,193961,'74754','new_theme','max-width','500',0,''),(616210,193962,'74755','new_theme','padding-bottom','10',0,''),(616211,193962,'74755','new_theme','padding-top','5',0,''),(616212,193963,'74757','new_theme','font-weight','normal',0,''),(616213,193963,'74757','new_theme','padding-bottom','20',0,''),(616214,193964,'74758','new_theme','font-weight','normal',0,''),(616215,193964,'74758','new_theme','padding-bottom','20',0,''),(616216,193965,'1694166186.2638','new_theme','block_type','1',0,''),(616217,193966,'74751','new_theme','font-weight','400',0,''),(616218,193966,'74751','new_theme','padding-bottom','20',0,''),(616219,193966,'74751','new_theme','show_qty_input','1',0,''),(616220,193966,'74751','new_theme','show_compare','1',0,''),(616221,193966,'74751','new_theme','listing_type','productListing',0,''),(616222,193966,'74751','new_theme','view_as','carousel',0,''),(616223,193966,'74751','new_theme','show_name','0',0,''),(616224,193966,'74751','new_theme','show_image','0',0,''),(616225,193966,'74751','new_theme','show_stock','0',0,''),(616226,193966,'74751','new_theme','show_description','0',0,''),(616227,193966,'74751','new_theme','show_model','0',0,''),(616228,193966,'74751','new_theme','show_properties','0',0,''),(616229,193966,'74751','new_theme','show_rating','0',0,''),(616230,193966,'74751','new_theme','show_rating_counts','0',0,''),(616231,193966,'74751','new_theme','show_price','0',0,''),(616232,193966,'74751','new_theme','show_buy_button','0',0,''),(616233,193966,'74751','new_theme','show_view_button','0',0,''),(616234,193966,'74751','new_theme','show_wishlist_button','0',0,''),(616235,193966,'74751','new_theme','display','none',0,'8451'),(616236,193966,'74751','new_theme','product_names_teg','h2',0,''),(616237,193966,'74751','new_theme','show_attributes','1',0,''),(616238,193966,'74751','new_theme','col_in_row','4',0,''),(616239,193966,'74751','new_theme','hide_parents','2',0,''),(616240,193967,'1694166209.3278','new_theme','text','<div class=\"heading-3\">##PRODUCT_ALSO_PURCHASED##</div>',0,''),(616241,193968,'1694166191.5684','new_theme','block_type','1',0,''),(616242,193969,'74747','new_theme','font-weight','400',0,''),(616243,193969,'74747','new_theme','padding-bottom','20',0,''),(616244,193969,'74747','new_theme','show_compare','1',0,''),(616245,193969,'74747','new_theme','show_name','0',0,''),(616246,193969,'74747','new_theme','show_image','0',0,''),(616247,193969,'74747','new_theme','show_stock','0',0,''),(616248,193969,'74747','new_theme','show_description','0',0,''),(616249,193969,'74747','new_theme','show_model','0',0,''),(616250,193969,'74747','new_theme','show_properties','0',0,''),(616251,193969,'74747','new_theme','show_rating','0',0,''),(616252,193969,'74747','new_theme','show_rating_counts','0',0,''),(616253,193969,'74747','new_theme','show_price','0',0,''),(616254,193969,'74747','new_theme','show_buy_button','0',0,''),(616255,193969,'74747','new_theme','show_view_button','0',0,''),(616256,193969,'74747','new_theme','show_wishlist_button','0',0,''),(616257,193969,'74747','new_theme','listing_type','productListing',0,''),(616258,193969,'74747','new_theme','col_in_row','2',0,'8451'),(616259,193969,'74747','new_theme','col_in_row','1',0,'8472'),(616260,193969,'74747','new_theme','col_in_row','4',0,''),(616261,193969,'74747','new_theme','hide_parents','2',0,''),(616262,193970,'1694166222.3382','new_theme','text','<div class=\"heading-3\">##VIEWED_PRODUCTS##</div>',0,''),(616263,193981,'74771','new_theme','block_type','1',0,''),(616264,193981,'74771','new_theme','style_class','item-holder',0,''),(616265,193981,'74771','new_theme','padding-top','25',0,''),(616266,193981,'74771','new_theme','padding-left','25',0,''),(616267,193981,'74771','new_theme','padding-right','25',0,''),(616268,193981,'74771','new_theme','padding-bottom','25',0,''),(616269,193981,'74771','new_theme','text-align','left',0,''),(616270,193984,'74775','new_theme','description_characters','90',0,''),(616271,193985,'74776','new_theme','text-align','right',0,''),(616272,193985,'74776','new_theme','margin-bottom','10',0,''),(616273,193986,'74777','new_theme','text-align','right',0,''),(616274,193986,'74777','new_theme','clear','none',0,''),(616275,193986,'74777','new_theme','float','left',0,''),(616276,193988,'74779','new_theme','block_type','2',0,''),(616277,193989,'74780','new_theme','margin-bottom','7',0,''),(616278,193990,'74781','new_theme','margin-bottom','10',0,''),(616279,193990,'74781','new_theme','text-align','right',0,''),(616280,193990,'74781','new_theme','float','right',0,''),(616281,193991,'74782','new_theme','clear','both',0,''),(616282,193992,'74783','new_theme','float','left',0,''),(616283,193992,'74783','new_theme','margin-right','20',0,''),(616284,193992,'74783','new_theme','margin-bottom','5',0,''),(616285,193994,'74785','new_theme','block_type','1',0,''),(616286,193995,'74786','new_theme','block_type','6',0,''),(616287,193995,'74786','new_theme','font-weight','400',0,''),(616288,193995,'74786','new_theme','schema','6-2',0,'8472'),(616289,193995,'74786','new_theme','schema','6-2',0,'8451'),(616290,193996,'74787','new_theme','font-weight','400',0,''),(616291,193996,'74787','new_theme','padding-right','40',0,''),(616292,193996,'74787','new_theme','padding-right','0',0,'8472'),(616293,193996,'74787','new_theme','padding-right','0',0,'8451'),(616294,193996,'74787','new_theme','margin-bottom','20',0,''),(616295,193997,'74788','new_theme','margin-bottom','20',0,''),(616296,193999,'74790','new_theme','block_type','1',0,''),(616297,193999,'74790','new_theme','padding-top','10',0,''),(616298,193999,'74790','new_theme','padding-bottom','10',0,''),(616299,193999,'74790','new_theme','border-bottom-width','1',0,''),(616300,193999,'74790','new_theme','border-bottom-color','$content-border-1',0,''),(616301,193999,'74790','new_theme','margin-left','0',0,''),(616302,193999,'74790','new_theme','margin-right','0',0,''),(616303,194000,'74791','new_theme','float','left',0,''),(616304,194000,'74791','new_theme','clear','none',0,''),(616305,194000,'74791','new_theme','sort_pos_3','2',0,''),(616306,194000,'74791','new_theme','sort_pos_4','3',0,''),(616307,194000,'74791','new_theme','sort_pos_10','11',0,''),(616308,194000,'74791','new_theme','sort_pos_9','10',0,''),(616309,194000,'74791','new_theme','sort_pos_11','12',0,''),(616310,194000,'74791','new_theme','sort_pos_12','13',0,''),(616311,194000,'74791','new_theme','sort_pos_14','15',0,''),(616312,194000,'74791','new_theme','sort_pos_13','14',0,''),(616313,194000,'74791','new_theme','sort_pos_8','4',0,''),(616314,194000,'74791','new_theme','sort_pos_7','5',0,''),(616315,194000,'74791','new_theme','sort_pos_2','7',0,''),(616316,194000,'74791','new_theme','sort_pos_1','6',0,''),(616317,194000,'74791','new_theme','sort_pos_6','9',0,''),(616318,194000,'74791','new_theme','sort_pos_5','8',0,''),(616319,194000,'74791','new_theme','sort_pos_0','1',0,''),(616320,194000,'74791','new_theme','sort_hide_10','1',0,''),(616321,194000,'74791','new_theme','sort_hide_9','1',0,''),(616322,194000,'74791','new_theme','sort_pos_15','16',0,''),(616323,194000,'74791','new_theme','sort_pos_16','17',0,''),(616324,194000,'74791','new_theme','sort_hide_4','0',0,''),(616325,194000,'74791','new_theme','sort_hide_3','0',0,''),(616326,194000,'74791','new_theme','sort_hide_16','1',0,''),(616327,194000,'74791','new_theme','sort_hide_15','1',0,''),(616328,194000,'74791','new_theme','sort_hide_11','1',0,''),(616329,194000,'74791','new_theme','sort_hide_12','1',0,''),(616330,194000,'74791','new_theme','sort_hide_14','1',0,''),(616331,194000,'74791','new_theme','sort_hide_13','1',0,''),(616332,194000,'74791','new_theme','sort_hide_8','0',0,''),(616333,194000,'74791','new_theme','sort_hide_7','0',0,''),(616334,194000,'74791','new_theme','sort_hide_2','1',0,''),(616335,194000,'74791','new_theme','sort_hide_1','1',0,''),(616336,194000,'74791','new_theme','sort_hide_6','1',0,''),(616337,194000,'74791','new_theme','sort_hide_5','1',0,''),(616338,194000,'74791','new_theme','sort_hide_0','0',0,''),(616339,194000,'74791','new_theme','hide_icons','1',0,''),(616340,194001,'74792','new_theme','float','right',0,''),(616341,194001,'74792','new_theme','display','none',0,'8472'),(616342,194002,'74793','new_theme','float','left',0,''),(616343,194002,'74793','new_theme','clear','none',0,''),(616344,194002,'74793','new_theme','margin-left','20',0,''),(616345,194002,'74793','new_theme','display','none',0,'8472'),(616346,194003,'74794','new_theme','margin-right','20',0,''),(616347,194003,'74794','new_theme','float','right',0,''),(616348,194003,'74794','new_theme','clear','none',0,''),(616349,194003,'74794','new_theme','display','none',0,'8451'),(616350,194004,'74795','new_theme','block_type','5',0,''),(616351,194004,'74795','new_theme','padding-top','10',0,''),(616352,194004,'74795','new_theme','padding-bottom','10',0,''),(616353,194004,'74795','new_theme','schema','5-2',0,'8472'),(616354,194004,'74795','new_theme','border-top-color','$content-border-1',0,''),(616355,194004,'74795','new_theme','border-top-width','1',0,''),(616356,194005,'74796','new_theme','padding-top','3',0,''),(616357,194006,'74797','new_theme','float','right',0,''),(616358,194006,'74797','new_theme','height','31',0,''),(616359,194007,'74798','new_theme','col_in_row','3',0,''),(616360,194007,'74798','new_theme','products_align','left',0,''),(616361,194007,'74798','new_theme','font-weight','400',0,''),(616362,194007,'74798','new_theme','listing_type','productListing',0,''),(616363,194007,'74798','new_theme','listing_type_rows','Rows',0,''),(616364,194007,'74798','new_theme','show_buy_button_b2b','on',0,''),(616365,194007,'74798','new_theme','show_wishlist_button_b2b','1',0,''),(616366,194007,'74798','new_theme','show_compare_b2b','1',0,''),(616367,194007,'74798','new_theme','show_image','0',0,''),(616368,194007,'74798','new_theme','show_stock','0',0,''),(616369,194007,'74798','new_theme','show_description','0',0,''),(616370,194007,'74798','new_theme','show_model','0',0,''),(616371,194007,'74798','new_theme','show_properties','0',0,''),(616372,194007,'74798','new_theme','show_rating','0',0,''),(616373,194007,'74798','new_theme','show_rating_counts','0',0,''),(616374,194007,'74798','new_theme','show_price','0',0,''),(616375,194007,'74798','new_theme','show_buy_button','0',0,''),(616376,194007,'74798','new_theme','show_view_button','0',0,''),(616377,194007,'74798','new_theme','show_wishlist_button','0',0,''),(616378,194007,'74798','new_theme','show_compare','0',0,''),(616379,194007,'74798','new_theme','show_name_rows','0',0,''),(616380,194007,'74798','new_theme','show_image_rows','0',0,''),(616381,194007,'74798','new_theme','show_stock_rows','0',0,''),(616382,194007,'74798','new_theme','show_description_rows','0',0,''),(616383,194007,'74798','new_theme','show_model_rows','0',0,''),(616384,194007,'74798','new_theme','show_properties_rows','0',0,''),(616385,194007,'74798','new_theme','show_rating_rows','0',0,''),(616386,194007,'74798','new_theme','show_rating_counts_rows','0',0,''),(616387,194007,'74798','new_theme','show_price_rows','0',0,''),(616388,194007,'74798','new_theme','show_buy_button_rows','0',0,''),(616389,194007,'74798','new_theme','show_qty_input_rows','0',0,''),(616390,194007,'74798','new_theme','show_view_button_rows','0',0,''),(616391,194007,'74798','new_theme','show_wishlist_button_rows','0',0,''),(616392,194007,'74798','new_theme','show_compare_rows','0',0,''),(616393,194007,'74798','new_theme','show_name_b2b','0',0,''),(616394,194007,'74798','new_theme','show_image_b2b','0',0,''),(616395,194007,'74798','new_theme','show_stock_b2b','0',0,''),(616396,194007,'74798','new_theme','show_description_b2b','0',0,''),(616397,194007,'74798','new_theme','show_model_b2b','0',0,''),(616398,194007,'74798','new_theme','show_properties_b2b','0',0,''),(616399,194007,'74798','new_theme','show_rating_b2b','0',0,''),(616400,194007,'74798','new_theme','show_rating_counts_b2b','0',0,''),(616401,194007,'74798','new_theme','show_price_b2b','0',0,''),(616402,194007,'74798','new_theme','show_qty_input_b2b','0',0,''),(616403,194007,'74798','new_theme','show_view_button_b2b','0',0,''),(616404,194007,'74798','new_theme','show_attributes_b2b','0',0,''),(616405,194007,'74798','new_theme','items_on_page','9',0,''),(616406,194007,'74798','new_theme','col_in_row','2',0,'8451'),(616407,194007,'74798','new_theme','col_in_row','1',0,'8472'),(616408,194007,'74798','new_theme','product_names_teg','h2',0,''),(616409,194009,'74800','new_theme','block_type','1',0,''),(616410,194010,'74801','new_theme','margin-bottom','20',0,''),(616411,194012,'74802','new_theme','block_type','1',0,''),(616412,194014,'74804','new_theme','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(616413,194015,'74805','new_theme','width','680',0,''),(616414,194015,'74805','new_theme','font-weight','normal',0,''),(616415,194015,'74805','new_theme','font-size','12',0,''),(616416,194015,'74805','new_theme','padding-top','20',0,''),(616417,194015,'74805','new_theme','padding-bottom','20',0,''),(616418,194015,'74805','new_theme','color','$content-color-1',0,''),(616419,194016,'74806','new_theme','font-weight','400',0,''),(616420,194016,'74806','new_theme','padding-top','20',0,''),(616421,194016,'74806','new_theme','padding-bottom','0',0,''),(616422,194016,'74806','new_theme','font-size','12',0,''),(616423,194017,'74807','new_theme','block_type','3',0,''),(616424,194017,'74807','new_theme','font-weight','normal',0,''),(616425,194017,'74807','new_theme','padding-top','20',0,''),(616426,194018,'74808','new_theme','text','<p>If undelivered please return to:</p>',1,''),(616427,194018,'74808','new_theme','font-size','12',0,''),(616428,194018,'74808','new_theme','font-weight','bold',0,''),(616429,194018,'74808','new_theme','text','<p>If undelivered please return to:</p>',0,''),(616430,194019,'74809','new_theme','font-size','12',0,''),(616431,194020,'74810','new_theme','text','<p>Thank you for your order</p>',1,''),(616432,194020,'74810','new_theme','color','$color-8',0,''),(616433,194020,'74810','new_theme','font-size','13',0,''),(616434,194020,'74810','new_theme','font-weight','bold',0,''),(616435,194020,'74810','new_theme','padding-top','5',0,''),(616436,194020,'74810','new_theme','text-align','center',0,''),(616437,194020,'74810','new_theme','text','<p>Thank you for your order</p>',0,''),(616438,194021,'74811','new_theme','font-weight','400',0,''),(616439,194021,'74811','new_theme','text-align','center',0,''),(616440,194021,'74811','new_theme','padding-top','0',0,''),(616441,194021,'74811','new_theme','padding-left','20',0,''),(616442,194021,'74811','new_theme','padding-right','20',0,''),(616443,194022,'74812','new_theme','block_type','6',0,''),(616444,194022,'74812','new_theme','font-weight','normal',0,''),(616445,194022,'74812','new_theme','font-size','16',0,''),(616446,194023,'74813','new_theme','text','<p>Email:</p>',1,''),(616447,194023,'74813','new_theme','font-weight','normal',0,''),(616448,194023,'74813','new_theme','text-align','right',0,''),(616449,194023,'74813','new_theme','font-size','12',0,''),(616450,194023,'74813','new_theme','text','<p>Email:</p>',0,''),(616451,194024,'74814','new_theme','font-weight','normal',0,''),(616452,194024,'74814','new_theme','text-align','right',0,''),(616453,194024,'74814','new_theme','font-size','12',0,''),(616454,194025,'74815','new_theme','text','<p>If something has gone wrong please contact us at:</p>',1,''),(616455,194025,'74815','new_theme','font-size','12',0,''),(616456,194025,'74815','new_theme','font-weight','bold',0,''),(616457,194025,'74815','new_theme','text-align','right',0,''),(616458,194025,'74815','new_theme','text','<p>If something has gone wrong please contact us at:</p>',0,''),(616459,194026,'74816','new_theme','block_type','6',0,''),(616460,194026,'74816','new_theme','font-weight','normal',0,''),(616461,194026,'74816','new_theme','font-size','16',0,''),(616462,194027,'74817','new_theme','text','<p>Phone:</p>',1,''),(616463,194027,'74817','new_theme','font-weight','normal',0,''),(616464,194027,'74817','new_theme','text-align','right',0,''),(616465,194027,'74817','new_theme','font-size','12',0,''),(616466,194027,'74817','new_theme','text','<p>Phone:</p>',0,''),(616467,194028,'74818','new_theme','font-weight','normal',0,''),(616468,194028,'74818','new_theme','text-align','right',0,''),(616469,194028,'74818','new_theme','font-size','12',0,''),(616470,194029,'74819','new_theme','block_type','2',0,''),(616471,194029,'74819','new_theme','font-weight','normal',0,''),(616472,194029,'74819','new_theme','padding-bottom','20',0,''),(616473,194030,'74820','new_theme','font-weight','400',0,''),(616474,194030,'74820','new_theme','padding-top','20',0,''),(616475,194031,'74821','new_theme','block_type','11',0,''),(616476,194031,'74821','new_theme','font-weight','normal',0,''),(616477,194032,'74822','new_theme','text','<p>Phone:</p>',1,''),(616478,194032,'74822','new_theme','font-weight','normal',0,''),(616479,194032,'74822','new_theme','text-align','right',0,''),(616480,194032,'74822','new_theme','text','<p>Phone:</p>',0,''),(616481,194033,'74823','new_theme','font-weight','normal',0,''),(616482,194033,'74823','new_theme','text-align','right',0,''),(616483,194034,'74824','new_theme','block_type','11',0,''),(616484,194034,'74824','new_theme','font-weight','normal',0,''),(616485,194035,'74825','new_theme','text','<p>Web:</p>',1,''),(616486,194035,'74825','new_theme','font-weight','normal',0,''),(616487,194035,'74825','new_theme','text-align','right',0,''),(616488,194035,'74825','new_theme','text','<p>Web:</p>',0,''),(616489,194036,'74826','new_theme','font-weight','normal',0,''),(616490,194036,'74826','new_theme','text-align','right',0,''),(616491,194037,'74827','new_theme','block_type','1',0,''),(616492,194038,'74828','new_theme','font-weight','normal',0,''),(616493,194038,'74828','new_theme','text-align','right',0,''),(616494,194038,'74828','new_theme','padding-bottom','10',0,''),(616495,194038,'74828','new_theme','address_spacer',',',0,''),(616496,194038,'74828','new_theme','font-size','12',0,''),(616497,194039,'74829','new_theme','block_type','11',0,''),(616498,194039,'74829','new_theme','font-weight','normal',0,''),(616499,194040,'74830','new_theme','text','<p>Email:</p>',1,''),(616500,194040,'74830','new_theme','font-weight','normal',0,''),(616501,194040,'74830','new_theme','text-align','right',0,''),(616502,194040,'74830','new_theme','text','<p>Email:</p>',0,''),(616503,194041,'74831','new_theme','font-weight','normal',0,''),(616504,194041,'74831','new_theme','text-align','right',0,''),(616505,194042,'74832','new_theme','block_type','4',0,''),(616506,194042,'74832','new_theme','font-weight','normal',0,''),(616507,194042,'74832','new_theme','border-top-width','1',0,''),(616508,194042,'74832','new_theme','border-top-color','$content-border-1',0,''),(616509,194042,'74832','new_theme','border-left-width','1',0,''),(616510,194042,'74832','new_theme','border-left-color','$content-border-1',0,''),(616511,194042,'74832','new_theme','border-right-width','1',0,''),(616512,194042,'74832','new_theme','border-right-color','$content-border-1',0,''),(616513,194042,'74832','new_theme','border-bottom-width','1',0,''),(616514,194042,'74832','new_theme','border-bottom-color','$content-border-1',0,''),(616515,194043,'74833','new_theme','block_type','2',0,''),(616516,194043,'74833','new_theme','font-weight','normal',0,''),(616517,194043,'74833','new_theme','border-right-width','1',0,''),(616518,194043,'74833','new_theme','border-right-color','$content-border-1',0,''),(616519,194044,'74834','new_theme','block_type','1',0,''),(616520,194044,'74834','new_theme','font-weight','400',0,''),(616521,194044,'74834','new_theme','background-color','$content-bg-2',0,''),(616522,194044,'74834','new_theme','padding-top','10',0,''),(616523,194044,'74834','new_theme','padding-left','10',0,''),(616524,194044,'74834','new_theme','padding-right','10',0,''),(616525,194044,'74834','new_theme','padding-bottom','30',0,''),(616526,194045,'74835','new_theme','font-size','12',0,''),(616527,194046,'74836','new_theme','text','<p>ADDRESS:</p>\n',1,''),(616528,194046,'74836','new_theme','font-size','14',0,''),(616529,194046,'74836','new_theme','font-weight','bold',0,''),(616530,194046,'74836','new_theme','text','<p>ADDRESS:</p>\n',0,''),(616531,194047,'74837','new_theme','block_type','1',0,''),(616532,194047,'74837','new_theme','font-weight','normal',0,''),(616533,194047,'74837','new_theme','padding-top','10',0,''),(616534,194047,'74837','new_theme','padding-left','10',0,''),(616535,194047,'74837','new_theme','padding-right','10',0,''),(616536,194047,'74837','new_theme','padding-bottom','10',0,''),(616537,194049,'74839','new_theme','text','<p>E-MAIL ADDRESS:</p>',1,''),(616538,194049,'74839','new_theme','font-weight','bold',0,''),(616539,194049,'74839','new_theme','font-size','14',0,''),(616540,194049,'74839','new_theme','padding-top','10',0,''),(616541,194049,'74839','new_theme','text','<p>E-MAIL ADDRESS:</p>',0,''),(616542,194050,'74840','new_theme','font-weight','normal',0,''),(616543,194051,'74841','new_theme','font-weight','normal',0,''),(616544,194052,'74842','new_theme','text','<p>PHONE NUMBER:</p>',1,''),(616545,194052,'74842','new_theme','font-size','14',0,''),(616546,194052,'74842','new_theme','font-weight','bold',0,''),(616547,194052,'74842','new_theme','padding-top','10',0,''),(616548,194052,'74842','new_theme','text','<p>PHONE NUMBER:</p>',0,''),(616549,194053,'74843','new_theme','text','<p>CUSTOMER:</p>',1,''),(616550,194053,'74843','new_theme','font-size','13',0,''),(616551,194053,'74843','new_theme','font-weight','bold',0,''),(616552,194053,'74843','new_theme','text','<p>CUSTOMER:</p>',0,''),(616553,194054,'74844','new_theme','font-size','14',0,''),(616554,194054,'74844','new_theme','font-weight','bold',0,''),(616555,194054,'74844','new_theme','text-align','center',0,''),(616556,194054,'74844','new_theme','padding-bottom','10',0,''),(616557,194054,'74844','new_theme','padding-top','10',0,''),(616558,194055,'74845','new_theme','text','<p>Order date:</p>\n',1,''),(616559,194055,'74845','new_theme','font-weight','bold',0,''),(616560,194055,'74845','new_theme','text-align','center',0,''),(616561,194055,'74845','new_theme','font-size','12',0,''),(616562,194055,'74845','new_theme','text','<p>Order date:</p>\n',0,''),(616563,194056,'74846','new_theme','font-weight','normal',0,''),(616564,194056,'74846','new_theme','text-align','center',0,''),(616565,194056,'74846','new_theme','padding-bottom','10',0,''),(616566,194057,'74847','new_theme','block_type','5',0,''),(616567,194057,'74847','new_theme','font-weight','normal',0,''),(616568,194057,'74847','new_theme','border-bottom-width','1',0,''),(616569,194057,'74847','new_theme','border-bottom-color','$content-border-1',0,''),(616570,194057,'74847','new_theme','border-top-width','1',0,''),(616571,194057,'74847','new_theme','border-top-color','$content-border-1',0,''),(616572,194057,'74847','new_theme','border-left-color','$content-border-1',0,''),(616573,194057,'74847','new_theme','border-left-width','1',0,''),(616574,194058,'74848','new_theme','block_type','1',0,''),(616575,194058,'74848','new_theme','font-weight','normal',0,''),(616576,194058,'74848','new_theme','padding-top','10',0,''),(616577,194058,'74848','new_theme','padding-left','10',0,''),(616578,194058,'74848','new_theme','padding-right','10',0,''),(616579,194059,'74849','new_theme','font-weight','400',0,''),(616580,194059,'74849','new_theme','line-height','120',0,''),(616581,194059,'74849','new_theme','line_height_measure','%',0,''),(616582,194059,'74849','new_theme','font-size','12',0,''),(616583,194060,'74850','new_theme','text','<p>SHIPPING ADDRESS:</p>',1,''),(616584,194060,'74850','new_theme','font-size','14',0,''),(616585,194060,'74850','new_theme','font-weight','bold',0,''),(616586,194060,'74850','new_theme','padding-bottom','10',0,''),(616587,194060,'74850','new_theme','text','<p>SHIPPING ADDRESS:</p>',0,''),(616588,194061,'74851','new_theme','block_type','1',0,''),(616589,194062,'74852','new_theme','block_type','6',0,''),(616590,194063,'74853','new_theme','aria_name','account-menu',0,''),(616591,194064,'73374','new_theme','block_type','1',0,''),(616592,194064,'73374','new_theme','padding-top','70',0,''),(616593,194064,'73374','new_theme','padding-right','30',0,''),(616594,194064,'73374','new_theme','padding-bottom','30',0,''),(616595,194064,'73374','new_theme','padding-top','0',0,'8451'),(616596,194064,'73374','new_theme','padding-left','0',0,'8451'),(616597,194064,'73374','new_theme','padding-right','0',0,'8451'),(616598,194064,'73374','new_theme','padding-bottom','0',0,'8451'),(616641,194083,'74854','new_theme','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(616642,194084,'74855','new_theme','link','Quotation Info',0,''),(616643,194084,'74855','new_theme','margin-bottom','20',0,''),(616644,194085,'74856','new_theme','block_type','1',0,''),(616645,194086,'74857','new_theme','block_type','6',0,''),(616646,194086,'74857','new_theme','schema','6-3',0,'8451'),(616647,194087,'74858','new_theme','aria_name','account-menu',0,''),(616648,194088,'73374','new_theme','block_type','1',0,''),(616649,194088,'73374','new_theme','padding-top','70',0,''),(616650,194088,'73374','new_theme','padding-right','30',0,''),(616651,194088,'73374','new_theme','padding-bottom','30',0,''),(616652,194088,'73374','new_theme','padding-top','0',0,'8451'),(616653,194088,'73374','new_theme','padding-left','0',0,'8451'),(616654,194088,'73374','new_theme','padding-right','0',0,'8451'),(616655,194088,'73374','new_theme','padding-bottom','0',0,'8451'),(616698,194107,'74859','new_theme','block_type','3',0,''),(616699,194108,'74860','new_theme','block_type','1',0,''),(616700,194108,'74860','new_theme','padding-right','20',0,''),(616701,194108,'74860','new_theme','padding-bottom','20',0,''),(616702,194109,'74861','new_theme','orders_data','name',0,''),(616703,194110,'74862','new_theme','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(616704,194111,'74863','new_theme','block_type','1',0,''),(616705,194111,'74863','new_theme','padding-right','20',0,''),(616706,194111,'74863','new_theme','padding-bottom','20',0,''),(616707,194112,'74864','new_theme','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(616708,194113,'74865','new_theme','orders_data','telephone',0,''),(616709,194114,'74866','new_theme','block_type','1',0,''),(616710,194114,'74866','new_theme','padding-right','20',0,''),(616711,194115,'74867','new_theme','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(616712,194116,'74868','new_theme','orders_data','shipping_method',0,''),(616713,194117,'74869','new_theme','block_type','1',0,''),(616714,194117,'74869','new_theme','padding-right','20',0,''),(616715,194117,'74869','new_theme','padding-bottom','20',0,''),(616716,194118,'74870','new_theme','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(616717,194119,'74871','new_theme','orders_data','delivery_address',0,''),(616718,194120,'74872','new_theme','block_type','1',0,''),(616719,194120,'74872','new_theme','padding-bottom','20',0,''),(616720,194121,'74873','new_theme','orders_data','billing_address',0,''),(616721,194122,'74874','new_theme','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(616722,194123,'74875','new_theme','block_type','1',0,''),(616723,194124,'74876','new_theme','orders_data','payment_method',0,''),(616724,194125,'74877','new_theme','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(616725,194126,'74878','new_theme','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(616726,194128,'74880','new_theme','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(616727,194131,'74883','new_theme','block_type','2',0,''),(616728,194131,'74883','new_theme','padding-top','20',0,''),(616729,194131,'74883','new_theme','margin-bottom','20',0,''),(616730,194132,'74884','new_theme','like_button','1',0,''),(616731,194132,'74884','new_theme','text','IMAGE_BUTTON_BACK',0,''),(616732,194132,'74884','new_theme','link','Quotations',0,''),(616733,194133,'74885','new_theme','text','<h1>##HEADING_TITLE##</h1>',0,''),(616734,194134,'74886','new_theme','padding-top','20',0,''),(616735,194134,'74886','new_theme','padding-bottom','20',0,''),(616736,194134,'74886','new_theme','block_type','1',0,''),(616737,194134,'74886','new_theme','background-color','$content-bg-2',0,''),(616738,194136,'74888','new_theme','block_type','4',0,''),(616739,194137,'74889','new_theme','background-color','$content-bg-1',0,''),(616740,194138,'74890','new_theme','block_type','1',0,''),(616741,194138,'74890','new_theme','style_class','order-summary',0,''),(616742,194138,'74890','new_theme','margin-left','30',0,''),(616743,194139,'74891','new_theme','block_type','1',0,''),(616744,194139,'74891','new_theme','padding-left','20',0,''),(616745,194139,'74891','new_theme','padding-right','20',0,''),(616746,194139,'74891','new_theme','padding-bottom','30',0,''),(616747,194142,'74894','new_theme','block_type','1',0,''),(616748,194143,'74895','new_theme','block_type','6',0,''),(616749,194143,'74895','new_theme','schema','6-3',0,'8451'),(616750,194144,'74896','new_theme','aria_name','account-menu',0,''),(616751,194145,'73374','new_theme','block_type','1',0,''),(616752,194145,'73374','new_theme','padding-top','70',0,''),(616753,194145,'73374','new_theme','padding-right','30',0,''),(616754,194145,'73374','new_theme','padding-bottom','30',0,''),(616755,194145,'73374','new_theme','padding-top','0',0,'8451'),(616756,194145,'73374','new_theme','padding-left','0',0,'8451'),(616757,194145,'73374','new_theme','padding-right','0',0,'8451'),(616758,194145,'73374','new_theme','padding-bottom','0',0,'8451'),(616801,194164,'74897','new_theme','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(616802,194165,'74898','new_theme','margin-bottom','20',0,''),(616803,194166,'74899','new_theme','block_type','1',0,''),(616804,194168,'74901','new_theme','pagination','bottom',0,''),(616805,194169,'74902','new_theme','width','800',0,''),(616806,194170,'74903','new_theme','block_type','11',0,''),(616807,194170,'74903','new_theme','border-top-width','1',0,''),(616808,194170,'74903','new_theme','border-left-width','1',0,''),(616809,194170,'74903','new_theme','border-right-width','1',0,''),(616810,194170,'74903','new_theme','border-bottom-width','1',0,''),(616811,194170,'74903','new_theme','border-top-color','$content-border-1',0,''),(616812,194170,'74903','new_theme','border-left-color','$content-border-1',0,''),(616813,194170,'74903','new_theme','border-right-color','$content-border-1',0,''),(616814,194170,'74903','new_theme','border-bottom-color','$content-border-1',0,''),(616815,194171,'74904','new_theme','block_type','1',0,''),(616816,194171,'74904','new_theme','border-right-width','1',0,''),(616817,194171,'74904','new_theme','border-right-color','$content-border-1',0,''),(616818,194171,'74904','new_theme','padding-top','10',0,''),(616819,194171,'74904','new_theme','padding-right','10',0,''),(616820,194171,'74904','new_theme','padding-bottom','10',0,''),(616821,194172,'74905','new_theme','block_type','9',0,''),(616822,194173,'74906','new_theme','text','1.',0,''),(616823,194173,'74906','new_theme','font-size','12',0,''),(616824,194173,'74906','new_theme','text-align','right',0,''),(616825,194173,'74906','new_theme','padding-right','5',0,''),(616826,194174,'74907','new_theme','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(616827,194174,'74907','new_theme','font-size','12',0,''),(616828,194174,'74907','new_theme','padding-bottom','5',0,''),(616829,194175,'74908','new_theme','block_type','9',0,''),(616830,194176,'74909','new_theme','text','4.',0,''),(616831,194176,'74909','new_theme','font-size','12',0,''),(616832,194176,'74909','new_theme','text-align','right',0,''),(616833,194176,'74909','new_theme','margin-right','5',0,''),(616834,194177,'74910','new_theme','text','Our Replacement Department will process your request.',0,''),(616835,194177,'74910','new_theme','font-size','12',0,''),(616836,194177,'74910','new_theme','padding-bottom','5',0,''),(616837,194178,'74911','new_theme','block_type','9',0,''),(616838,194179,'74912','new_theme','text','3.',0,''),(616839,194179,'74912','new_theme','font-size','12',0,''),(616840,194179,'74912','new_theme','text-align','right',0,''),(616841,194179,'74912','new_theme','margin-right','5',0,''),(616842,194180,'74913','new_theme','text','Return the authorized item(s) per shipping instructions.',0,''),(616843,194180,'74913','new_theme','font-size','12',0,''),(616844,194180,'74913','new_theme','padding-bottom','5',0,''),(616845,194181,'74914','new_theme','block_type','9',0,''),(616846,194182,'74915','new_theme','text','2.',0,''),(616847,194182,'74915','new_theme','font-size','12',0,''),(616848,194182,'74915','new_theme','text-align','right',0,''),(616849,194182,'74915','new_theme','margin-right','5',0,''),(616850,194183,'74916','new_theme','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(616851,194183,'74916','new_theme','font-size','12',0,''),(616852,194183,'74916','new_theme','padding-bottom','5',0,''),(616853,194184,'74917','new_theme','block_type','1',0,''),(616854,194184,'74917','new_theme','padding-left','15',0,''),(616855,194185,'74918','new_theme','text','Replacement Policy:',0,''),(616856,194185,'74918','new_theme','font-size','14',0,''),(616857,194185,'74918','new_theme','padding-bottom','5',0,''),(616858,194185,'74918','new_theme','font-weight','bold',0,''),(616859,194186,'74919','new_theme','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(616860,194186,'74919','new_theme','font-size','11',0,''),(616861,194186,'74919','new_theme','font-style','italic',0,''),(616862,194186,'74919','new_theme','padding-bottom','5',0,''),(616863,194187,'74920','new_theme','block_type','1',0,''),(616864,194187,'74920','new_theme','border-bottom-width','1',0,''),(616865,194187,'74920','new_theme','border-bottom-color','$content-border-1',0,''),(616866,194188,'74921','new_theme','text','Return Material Authorization (RMA) Form',0,''),(616867,194188,'74921','new_theme','text-align','center',0,''),(616868,194188,'74921','new_theme','font-size','16',0,''),(616869,194188,'74921','new_theme','font-weight','bold',0,''),(616870,194189,'74922','new_theme','text-align','center',0,''),(616871,194189,'74922','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',1,''),(616872,194189,'74922','new_theme','padding-top','10',0,''),(616873,194189,'74922','new_theme','padding-bottom','10',0,''),(616874,194189,'74922','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',0,''),(616875,194190,'74923','new_theme','block_type','1',0,''),(616876,194190,'74923','new_theme','padding-top','10',0,''),(616877,194190,'74923','new_theme','padding-left','10',0,''),(616878,194190,'74923','new_theme','padding-right','10',0,''),(616879,194190,'74923','new_theme','padding-bottom','20',0,''),(616880,194191,'74924','new_theme','block_type','2',0,''),(616881,194191,'74924','new_theme','padding-top','5',0,''),(616882,194192,'74925','new_theme','block_type','11',0,''),(616883,194193,'74926','new_theme','text','Email:',0,''),(616884,194193,'74926','new_theme','font-size','12',0,''),(616885,194194,'74927','new_theme','data','rrDelivery_email_address',0,''),(616886,194194,'74927','new_theme','font-size','12',0,''),(616887,194195,'74928','new_theme','block_type','11',0,''),(616888,194196,'74929','new_theme','text','Phone:',0,''),(616889,194196,'74929','new_theme','font-size','12',0,''),(616890,194197,'74930','new_theme','data','rrDelivery_telephone',0,''),(616891,194197,'74930','new_theme','font-size','12',0,''),(616892,194198,'74931','new_theme','block_type','2',0,''),(616893,194198,'74931','new_theme','padding-top','5',0,''),(616894,194199,'74932','new_theme','block_type','11',0,''),(616895,194200,'74933','new_theme','text','Country:',0,''),(616896,194200,'74933','new_theme','font-size','12',0,''),(616897,194201,'74934','new_theme','data','rrDelivery_country',0,''),(616898,194201,'74934','new_theme','font-size','12',0,''),(616899,194202,'74935','new_theme','block_type','11',0,''),(616900,194203,'74936','new_theme','text','Postcode:',0,''),(616901,194203,'74936','new_theme','font-size','12',0,''),(616902,194204,'74937','new_theme','data','rrDelivery_postcode',0,''),(616903,194204,'74937','new_theme','font-size','12',0,''),(616904,194205,'74938','new_theme','block_type','2',0,''),(616905,194205,'74938','new_theme','padding-top','5',0,''),(616906,194206,'74939','new_theme','block_type','11',0,''),(616907,194207,'74940','new_theme','text','City:',0,''),(616908,194207,'74940','new_theme','font-size','12',0,''),(616909,194208,'74941','new_theme','data','rrDelivery_city',0,''),(616910,194208,'74941','new_theme','font-size','12',0,''),(616911,194209,'74942','new_theme','block_type','11',0,''),(616912,194210,'74943','new_theme','text','State:',0,''),(616913,194210,'74943','new_theme','font-size','12',0,''),(616914,194211,'74944','new_theme','data','rrDelivery_state',0,''),(616915,194211,'74944','new_theme','font-size','12',0,''),(616916,194212,'74945','new_theme','block_type','9',0,''),(616917,194212,'74945','new_theme','padding-top','5',0,''),(616918,194213,'74946','new_theme','text','Address:',0,''),(616919,194213,'74946','new_theme','font-size','12',0,''),(616920,194214,'74947','new_theme','data','rrDelivery_street_address',0,''),(616921,194214,'74947','new_theme','font-size','12',0,''),(616922,194215,'74948','new_theme','block_type','2',0,''),(616923,194216,'74949','new_theme','block_type','11',0,''),(616924,194217,'74950','new_theme','text','Company:',0,''),(616925,194217,'74950','new_theme','font-size','12',0,''),(616926,194218,'74951','new_theme','data','rrDelivery_company',0,''),(616927,194218,'74951','new_theme','font-size','12',0,''),(616928,194219,'74952','new_theme','block_type','2',0,''),(616929,194220,'74953','new_theme','text','Contact Name:',0,''),(616930,194220,'74953','new_theme','font-size','12',0,''),(616931,194221,'74954','new_theme','data','rrDelivery_name',0,''),(616932,194221,'74954','new_theme','font-size','12',0,''),(616933,194222,'74955','new_theme','block_type','2',0,''),(616934,194222,'74955','new_theme','padding-left','10',0,''),(616935,194222,'74955','new_theme','padding-top','20',0,''),(616936,194222,'74955','new_theme','padding-right','10',0,''),(616937,194223,'74956','new_theme','block_type','5',0,''),(616938,194224,'74957','new_theme','text','RMA No:',0,''),(616939,194224,'74957','new_theme','font-size','12',0,''),(616940,194224,'74957','new_theme','font-weight','bold',0,''),(616941,194225,'74958','new_theme','data','rrNumber',0,''),(616942,194225,'74958','new_theme','font-size','12',0,''),(616943,194225,'74958','new_theme','font-weight','bold',0,''),(616944,194226,'74959','new_theme','block_type','2',0,''),(616945,194227,'74960','new_theme','text','Date Issued:',0,''),(616946,194227,'74960','new_theme','font-size','12',0,''),(616947,194227,'74960','new_theme','font-weight','bold',0,''),(616948,194228,'74961','new_theme','data','rrDateCreate',0,''),(616949,194228,'74961','new_theme','font-size','12',0,''),(616950,194228,'74961','new_theme','font-weight','bold',0,''),(616951,194229,'74962','new_theme','block_type','1',0,''),(616952,194230,'74963','new_theme','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(616953,194230,'74963','new_theme','font-size','12',0,''),(616954,194230,'74963','new_theme','font-style','italic',0,''),(616955,194230,'74963','new_theme','padding-bottom','20',0,''),(616956,194232,'74965','new_theme','block_type','1',0,''),(616957,194232,'74965','new_theme','border-top-width','1',0,''),(616958,194232,'74965','new_theme','border-left-width','1',0,''),(616959,194232,'74965','new_theme','border-right-width','1',0,''),(616960,194232,'74965','new_theme','border-bottom-width','1',0,''),(616961,194232,'74965','new_theme','border-top-color','$content-border-1',0,''),(616962,194232,'74965','new_theme','border-left-color','$content-border-1',0,''),(616963,194232,'74965','new_theme','border-right-color','$content-border-1',0,''),(616964,194232,'74965','new_theme','border-bottom-color','$content-border-1',0,''),(616965,194233,'74966','new_theme','block_type','11',0,''),(616966,194234,'74967','new_theme','block_type','1',0,''),(616967,194234,'74967','new_theme','padding-top','10',0,''),(616968,194234,'74967','new_theme','padding-right','10',0,''),(616969,194234,'74967','new_theme','padding-bottom','10',0,''),(616970,194234,'74967','new_theme','border-right-width','1',0,''),(616971,194234,'74967','new_theme','border-right-color','$content-border-1',0,''),(616972,194235,'74968','new_theme','block_type','9',0,''),(616973,194236,'74969','new_theme','text','4.',0,''),(616974,194236,'74969','new_theme','font-size','12',0,''),(616975,194236,'74969','new_theme','text-align','right',0,''),(616976,194236,'74969','new_theme','padding-right','5',0,''),(616977,194237,'74970','new_theme','font-size','11',0,''),(616978,194237,'74970','new_theme','font-style','italic',0,''),(616979,194237,'74970','new_theme','padding-bottom','5',0,''),(616980,194238,'74971','new_theme','text','Ship returned items to:',0,''),(616981,194238,'74971','new_theme','font-size','12',0,''),(616982,194238,'74971','new_theme','padding-bottom','5',0,''),(616983,194239,'74972','new_theme','block_type','9',0,''),(616984,194240,'74973','new_theme','text','3.',0,''),(616985,194240,'74973','new_theme','font-size','12',0,''),(616986,194240,'74973','new_theme','text-align','right',0,''),(616987,194240,'74973','new_theme','padding-right','5',0,''),(616988,194241,'74974','new_theme','text','Ship only the items that are authorized.',0,''),(616989,194241,'74974','new_theme','font-size','12',0,''),(616990,194241,'74974','new_theme','padding-bottom','10',0,''),(616991,194242,'74975','new_theme','block_type','9',0,''),(616992,194243,'74976','new_theme','text','1.',0,''),(616993,194243,'74976','new_theme','font-size','12',0,''),(616994,194243,'74976','new_theme','text-align','right',0,''),(616995,194243,'74976','new_theme','padding-right','5',0,''),(616996,194244,'74977','new_theme','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(616997,194244,'74977','new_theme','font-size','12',0,''),(616998,194244,'74977','new_theme','padding-bottom','10',0,''),(616999,194245,'74978','new_theme','block_type','1',0,''),(617000,194246,'74979','new_theme','text','Shipping Instructions:',0,''),(617001,194246,'74979','new_theme','font-weight','bold',0,''),(617002,194246,'74979','new_theme','font-size','14',0,''),(617003,194246,'74979','new_theme','padding-bottom','5',0,''),(617004,194246,'74979','new_theme','padding-left','10',0,''),(617005,194247,'74980','new_theme','block_type','9',0,''),(617006,194248,'74981','new_theme','text','2.',0,''),(617007,194248,'74981','new_theme','font-size','12',0,''),(617008,194248,'74981','new_theme','text-align','right',0,''),(617009,194248,'74981','new_theme','padding-right','5',0,''),(617010,194249,'74982','new_theme','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(617011,194249,'74982','new_theme','font-size','12',0,''),(617012,194249,'74982','new_theme','padding-bottom','10',0,''),(617013,194250,'74983','new_theme','block_type','1',0,''),(617014,194250,'74983','new_theme','padding-left','10',0,''),(617015,194250,'74983','new_theme','padding-right','10',0,''),(617016,194250,'74983','new_theme','padding-bottom','10',0,''),(617017,194251,'74984','new_theme','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(617018,194251,'74984','new_theme','font-size','11',0,''),(617019,194251,'74984','new_theme','font-style','italic',0,''),(617020,194252,'74985','new_theme','block_type','1',0,''),(617021,194252,'74985','new_theme','padding-top','10',0,''),(617022,194252,'74985','new_theme','padding-left','40',0,''),(617023,194252,'74985','new_theme','padding-right','40',0,''),(617024,194252,'74985','new_theme','padding-bottom','10',0,''),(617025,194253,'74986','new_theme','block_type','1',0,''),(617026,194253,'74986','new_theme','padding-top','10',0,''),(617027,194253,'74986','new_theme','padding-left','10',0,''),(617028,194253,'74986','new_theme','padding-right','10',0,''),(617029,194253,'74986','new_theme','padding-bottom','10',0,''),(617030,194253,'74986','new_theme','border-top-width','1',0,''),(617031,194253,'74986','new_theme','border-left-width','1',0,''),(617032,194253,'74986','new_theme','border-right-width','1',0,''),(617033,194253,'74986','new_theme','border-bottom-width','1',0,''),(617034,194253,'74986','new_theme','border-top-color','$content-border-1',0,''),(617035,194253,'74986','new_theme','border-left-color','$content-border-1',0,''),(617036,194253,'74986','new_theme','border-right-color','$content-border-1',0,''),(617037,194253,'74986','new_theme','border-bottom-color','$content-border-1',0,''),(617038,194254,'74987','new_theme','block_type','3',0,''),(617039,194255,'74988','new_theme','data','rrDelivery_name',0,''),(617040,194255,'74988','new_theme','font-size','9',0,''),(617041,194256,'74989','new_theme','block_type','2',0,''),(617042,194257,'74990','new_theme','text','RMA#:',0,''),(617043,194257,'74990','new_theme','font-size','10',0,''),(617044,194258,'74991','new_theme','data','rrNumber',0,''),(617045,194258,'74991','new_theme','font-size','9',0,''),(617046,194259,'74992','new_theme','block_type','5',0,''),(617047,194260,'74993','new_theme','font-size','9',0,''),(617048,194261,'74994','new_theme','block_type','1',0,''),(617049,194261,'74994','new_theme','padding-left','10',0,''),(617050,194261,'74994','new_theme','padding-right','10',0,''),(617051,194261,'74994','new_theme','padding-bottom','10',0,''),(617052,194262,'74995','new_theme','text','Use this space for additional Comments:',0,''),(617053,194262,'74995','new_theme','font-size','11',0,''),(617054,194262,'74995','new_theme','font-style','italic',0,''),(617055,194263,'74996','new_theme','text','&nbsp;',0,''),(617056,194263,'74996','new_theme','border-bottom-width','1',0,''),(617057,194263,'74996','new_theme','border-bottom-color','$content-border-1',0,''),(617058,194264,'74997','new_theme','text','&nbsp;',0,''),(617059,194264,'74997','new_theme','border-bottom-width','1',0,''),(617060,194264,'74997','new_theme','border-bottom-color','$content-border-1',0,''),(617061,194264,'74997','new_theme','padding-top','5',0,''),(617062,194265,'74998','new_theme','text','&nbsp;',0,''),(617063,194265,'74998','new_theme','border-bottom-width','1',0,''),(617064,194265,'74998','new_theme','border-bottom-color','$content-border-1',0,''),(617065,194265,'74998','new_theme','padding-top','5',0,''),(617066,194266,'74999','new_theme','text','&nbsp;',0,''),(617067,194266,'74999','new_theme','border-bottom-width','1',0,''),(617068,194266,'74999','new_theme','border-bottom-color','$content-border-1',0,''),(617069,194266,'74999','new_theme','padding-top','5',0,''),(617070,194267,'75000','new_theme','block_type','3',0,''),(617071,194267,'75000','new_theme','padding-top','10',0,''),(617072,194267,'75000','new_theme','padding-bottom','10',0,''),(617073,194267,'75000','new_theme','padding-right','10',0,''),(617074,194268,'75001','new_theme','font-size','11',0,''),(617075,194268,'75001','new_theme','font-weight','bold',0,''),(617076,194268,'75001','new_theme','text','Return Approval:',0,''),(617077,194268,'75001','new_theme','padding-top','5',0,''),(617078,194268,'75001','new_theme','padding-left','10',0,''),(617079,194269,'75002','new_theme','border-bottom-width','1',0,''),(617080,194269,'75002','new_theme','border-bottom-color','$content-border-1',0,''),(617081,194269,'75002','new_theme','text','&nbsp;',0,''),(617082,194270,'75003','new_theme','block_type','5',0,''),(617083,194271,'75004','new_theme','text','Date:',0,''),(617084,194271,'75004','new_theme','padding-top','5',0,''),(617085,194271,'75004','new_theme','font-size','11',0,''),(617086,194271,'75004','new_theme','font-weight','bold',0,''),(617087,194271,'75004','new_theme','padding-left','5',0,''),(617088,194272,'75005','new_theme','text','&nbsp;',0,''),(617089,194272,'75005','new_theme','border-bottom-width','1',0,''),(617090,194272,'75005','new_theme','border-bottom-color','$content-border-1',0,''),(617091,194273,'75006','new_theme','block_type','3',0,''),(617092,194273,'75006','new_theme','padding-right','10',0,''),(617093,194274,'75007','new_theme','text','Customer Signature:',0,''),(617094,194274,'75007','new_theme','font-weight','bold',0,''),(617095,194274,'75007','new_theme','font-size','11',0,''),(617096,194274,'75007','new_theme','padding-top','5',0,''),(617097,194274,'75007','new_theme','padding-left','10',0,''),(617098,194275,'75008','new_theme','text','&nbsp;',0,''),(617099,194275,'75008','new_theme','border-bottom-width','1',0,''),(617100,194275,'75008','new_theme','border-bottom-color','$content-border-1',0,''),(617101,194276,'75009','new_theme','block_type','5',0,''),(617102,194277,'75010','new_theme','text','Date:',0,''),(617103,194277,'75010','new_theme','padding-top','5',0,''),(617104,194277,'75010','new_theme','font-size','11',0,''),(617105,194277,'75010','new_theme','font-weight','bold',0,''),(617106,194277,'75010','new_theme','padding-left','5',0,''),(617107,194278,'75011','new_theme','text','&nbsp;',0,''),(617108,194278,'75011','new_theme','border-bottom-width','1',0,''),(617109,194278,'75011','new_theme','border-bottom-color','$content-border-1',0,''),(617110,194279,'75012','new_theme','block_type','1',0,''),(617111,194279,'75012','new_theme','style_class','item-holder',0,''),(617112,194279,'75012','new_theme','padding-top','25',0,''),(617113,194279,'75012','new_theme','padding-bottom','25',0,''),(617114,194279,'75012','new_theme','text-align','left',0,''),(617115,194279,'75012','new_theme','border-top-width','1',0,''),(617116,194279,'75012','new_theme','border-top-color','$content-border-1',0,''),(617117,194280,'75013','new_theme','block_type','7',0,''),(617118,194280,'75013','new_theme','schema','7-2',0,'8451'),(617119,194281,'75014','new_theme','block_type','5',0,''),(617120,194281,'75014','new_theme','schema','5-2',0,'8451'),(617121,194282,'75015','new_theme','clear','none',0,''),(617122,194282,'75015','new_theme','padding-right','20',0,''),(617123,194283,'75016','new_theme','padding-right','20',0,''),(617124,194283,'75016','new_theme','max-width','300',0,'8451'),(617125,194283,'75016','new_theme','margin_left_measure','auto',0,'8451'),(617126,194283,'75016','new_theme','margin_right_measure','auto',0,'8451'),(617127,194284,'75017','new_theme','block_type','1',0,''),(617128,194285,'75018','new_theme','text-align','right',0,''),(617129,194285,'75018','new_theme','margin-top','4',0,''),(617130,194285,'75018','new_theme','margin-bottom','7',0,''),(617131,194285,'75018','new_theme','float','left',0,''),(617132,194286,'75019','new_theme','padding-top','6',0,''),(617133,194286,'75019','new_theme','padding-left','5',0,''),(617134,194286,'75019','new_theme','float','left',0,''),(617135,194286,'75019','new_theme','clear','none',0,''),(617136,194287,'75020','new_theme','padding-right','20',0,''),(617137,194288,'75021','new_theme','description_characters','200',0,''),(617138,194288,'75021','new_theme','clear','none',0,''),(617139,194288,'75021','new_theme','padding-right','20',0,''),(617140,194289,'75022','new_theme','clear','none',0,''),(617141,194290,'75023','new_theme','margin-bottom','20',0,''),(617142,194291,'75024','new_theme','block_type','1',0,''),(617143,194291,'75024','new_theme','padding-left','40',0,''),(617144,194291,'75024','new_theme','style_class','right-aria',0,''),(617145,194291,'75024','new_theme','padding-left','0',0,'8451'),(617146,194292,'75025','new_theme','margin-bottom','15',0,''),(617147,194292,'75025','new_theme','text-align','right',0,''),(617148,194293,'75026','new_theme','margin-bottom','10',0,''),(617149,194293,'75026','new_theme','text-align','right',0,''),(617150,194294,'75027','new_theme','margin-bottom','10',0,''),(617151,194295,'75028','new_theme','text-align','right',0,''),(617152,194295,'75028','new_theme','margin-bottom','15',0,''),(617153,194296,'75030','new_theme','text-align','right',0,''),(617154,194296,'75030','new_theme','margin-bottom','10',0,''),(617155,194297,'75031','new_theme','block_type','1',0,''),(617156,194297,'75031','new_theme','padding-top','20',0,''),(617157,194297,'75031','new_theme','padding-bottom','20',0,''),(617158,194297,'75031','new_theme','background-color','$content-bg-2',0,''),(617159,194299,'75033','new_theme','block_type','4',0,''),(617160,194300,'75034','new_theme','padding-bottom','20',0,''),(617161,194300,'75034','new_theme','background-color','$content-bg-1',0,''),(617162,194301,'75035','new_theme','style_class','order-summary',0,''),(617163,194301,'75035','new_theme','padding-left','30',0,''),(617164,194301,'75035','new_theme','block_type','1',0,''),(617165,194302,'75036','new_theme','block_type','1',0,''),(617166,194302,'75036','new_theme','padding-left','20',0,''),(617167,194302,'75036','new_theme','padding-right','20',0,''),(617168,194302,'75036','new_theme','padding-bottom','20',0,''),(617169,194302,'75036','new_theme','padding-top','20',0,''),(617170,194303,'75037','new_theme','margin-bottom','40',0,''),(617171,194304,'75038','new_theme','block_type','1',0,''),(617172,194304,'75038','new_theme','style_class','account-samples',0,''),(617173,194305,'75039','new_theme','block_type','6',0,''),(617174,194305,'75039','new_theme','schema','6-3',0,'8451'),(617175,194306,'75040','new_theme','aria_name','account-menu',0,''),(617176,194307,'73374','new_theme','block_type','1',0,''),(617177,194307,'73374','new_theme','padding-top','70',0,''),(617178,194307,'73374','new_theme','padding-right','30',0,''),(617179,194307,'73374','new_theme','padding-bottom','30',0,''),(617180,194307,'73374','new_theme','padding-top','0',0,'8451'),(617181,194307,'73374','new_theme','padding-left','0',0,'8451'),(617182,194307,'73374','new_theme','padding-right','0',0,'8451'),(617183,194307,'73374','new_theme','padding-bottom','0',0,'8451'),(617226,194326,'75041','new_theme','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(617227,194327,'75042','new_theme','show_pagenation','1',0,''),(617228,194327,'75042','new_theme','link','Sample Info',0,''),(617229,194327,'75042','new_theme','margin-bottom','20',0,''),(617230,194328,'75043','new_theme','block_type','1',0,''),(617231,194328,'75043','new_theme','style_class','account-sample-info',0,''),(617232,194329,'75044','new_theme','block_type','6',0,''),(617233,194330,'75045','new_theme','aria_name','account-menu',0,''),(617234,194331,'73374','new_theme','block_type','1',0,''),(617235,194331,'73374','new_theme','padding-top','70',0,''),(617236,194331,'73374','new_theme','padding-right','30',0,''),(617237,194331,'73374','new_theme','padding-bottom','30',0,''),(617238,194331,'73374','new_theme','padding-top','0',0,'8451'),(617239,194331,'73374','new_theme','padding-left','0',0,'8451'),(617240,194331,'73374','new_theme','padding-right','0',0,'8451'),(617241,194331,'73374','new_theme','padding-bottom','0',0,'8451'),(617284,194350,'75046','new_theme','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(617285,194351,'75047','new_theme','block_type','2',0,''),(617286,194351,'75047','new_theme','padding-top','20',0,''),(617287,194351,'75047','new_theme','margin-bottom','20',0,''),(617288,194352,'75048','new_theme','like_button','1',0,''),(617289,194352,'75048','new_theme','text','IMAGE_BUTTON_BACK',0,''),(617290,194352,'75048','new_theme','link','Samples',0,''),(617291,194354,'75050','new_theme','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(617292,194357,'75053','new_theme','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(617293,194358,'75054','new_theme','block_type','3',0,''),(617294,194359,'75055','new_theme','block_type','1',0,''),(617295,194359,'75055','new_theme','padding-right','20',0,''),(617296,194359,'75055','new_theme','padding-bottom','20',0,''),(617297,194360,'75056','new_theme','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(617298,194361,'75057','new_theme','orders_data','telephone',0,''),(617299,194362,'75058','new_theme','block_type','1',0,''),(617300,194362,'75058','new_theme','padding-right','20',0,''),(617301,194362,'75058','new_theme','padding-bottom','20',0,''),(617302,194363,'75059','new_theme','orders_data','name',0,''),(617303,194364,'75060','new_theme','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(617304,194365,'75061','new_theme','block_type','1',0,''),(617305,194365,'75061','new_theme','padding-right','20',0,''),(617306,194366,'75062','new_theme','orders_data','shipping_method',0,''),(617307,194367,'75063','new_theme','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(617308,194368,'75064','new_theme','block_type','1',0,''),(617309,194368,'75064','new_theme','padding-right','20',0,''),(617310,194368,'75064','new_theme','padding-bottom','20',0,''),(617311,194369,'75065','new_theme','orders_data','delivery_address',0,''),(617312,194370,'75066','new_theme','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(617313,194371,'75067','new_theme','block_type','1',0,''),(617314,194372,'75068','new_theme','orders_data','payment_method',0,''),(617315,194373,'75069','new_theme','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(617316,194374,'75070','new_theme','block_type','1',0,''),(617317,194374,'75070','new_theme','padding-bottom','20',0,''),(617318,194375,'75071','new_theme','orders_data','billing_address',0,''),(617319,194376,'75072','new_theme','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(617320,194377,'75073','new_theme','block_type','1',0,''),(617321,194378,'75074','new_theme','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(617322,194379,'75075','new_theme','block_type','6',0,''),(617323,194380,'75076','new_theme','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(617324,194381,'75077','new_theme','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(617325,194382,'75078','new_theme','text','<div class=\"heading-4\">Categories</div>',0,''),(617326,194385,'75081','new_theme','class','menu-simple',0,''),(617327,194387,'75083','new_theme','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(617328,194388,'75084','new_theme','block_type','1',0,''),(617329,194389,'75085','new_theme','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(617330,194389,'75085','new_theme','style_class','middle-form',0,''),(617331,194390,'75086','new_theme','style_class','middle-form',0,''),(617332,194391,'75087','new_theme','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(617333,194392,'75088','new_theme','style_class','middle-form',0,''),(617334,194392,'75088','new_theme','margin-bottom','30',0,''),(617335,194393,'75089','new_theme','block_type','1',0,''),(617336,194394,'75090','new_theme','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(617337,194394,'75090','new_theme','padding-top','100',0,''),(617338,194394,'75090','new_theme','margin-bottom','100',0,''),(617339,194394,'75090','new_theme','text-align','center',0,''),(617340,194394,'75090','new_theme','font-size','20',0,''),(617341,194395,'94795','new_theme','block_type','1',0,''),(617342,194396,'94796','new_theme','block_type','6',0,''),(617343,194396,'94796','new_theme','schema','6-3',0,'8451'),(617344,194397,'94797','new_theme','aria_name','account-menu',0,''),(617345,194398,'73374','new_theme','block_type','1',0,''),(617346,194398,'73374','new_theme','padding-top','70',0,''),(617347,194398,'73374','new_theme','padding-right','30',0,''),(617348,194398,'73374','new_theme','padding-bottom','30',0,''),(617349,194398,'73374','new_theme','padding-top','0',0,'8451'),(617350,194398,'73374','new_theme','padding-left','0',0,'8451'),(617351,194398,'73374','new_theme','padding-right','0',0,'8451'),(617352,194398,'73374','new_theme','padding-bottom','0',0,'8451'),(617395,194417,'94798','new_theme','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(617396,194418,'94799','new_theme','text','##SUBSCRIPTION_TEXT##',0,''),(617397,194420,'1694099590.22143','new_theme','block_type','1',0,''),(617398,194420,'1694099590.22143','new_theme','background-color','$content-bg-2',0,''),(617399,194420,'1694099590.22143','new_theme','padding-bottom','30',0,''),(617400,194420,'1694099590.22143','new_theme','style_class','success-page',0,''),(617401,194420,'1694099590.22143','new_theme','color','$content-color-2',0,''),(617402,194421,'1694099590.340695','new_theme','block_type','12',0,''),(617403,194421,'1694099590.340695','new_theme','schema','4-2',0,'8451'),(617404,194422,'1694099590.343733','new_theme','block_type','1',0,''),(617405,194422,'1694099590.343733','new_theme','padding-right','40',0,''),(617406,194422,'1694099590.343733','new_theme','padding-right','0',0,'8451'),(617407,194423,'1694099590.345212','new_theme','block_type','2',0,''),(617408,194423,'1694099590.345212','new_theme','margin-bottom','20',0,''),(617409,194423,'1694099590.345212','new_theme','schema','2-2',0,'8444'),(617410,194423,'1694099590.345212','new_theme','background-color','$content-bg-1',0,''),(617411,194423,'1694099590.345212','new_theme','color','$content-color-1',0,''),(617412,194424,'1694099590.34749','new_theme','block_type','1',0,''),(617413,194424,'1694099590.34749','new_theme','border-right-width','20',0,''),(617414,194424,'1694099590.34749','new_theme','border-right-color','$content-bg-2',0,''),(617415,194424,'1694099590.34749','new_theme','margin-right','-10',0,''),(617416,194424,'1694099590.34749','new_theme','padding-right','30',0,''),(617417,194424,'1694099590.34749','new_theme','padding-top','20',0,''),(617418,194424,'1694099590.34749','new_theme','padding-left','30',0,''),(617419,194424,'1694099590.34749','new_theme','padding-bottom','20',0,''),(617420,194424,'1694099590.34749','new_theme','border-right-width','0',0,'8451'),(617421,194424,'1694099590.34749','new_theme','margin-right','0',0,'8451'),(617422,194424,'1694099590.34749','new_theme','margin-bottom','20',0,'8451'),(617423,194424,'1694099590.34749','new_theme','padding-left','20',0,'8451'),(617424,194424,'1694099590.34749','new_theme','padding-right','20',0,'8451'),(617425,194426,'1694099590.351567','new_theme','margin-bottom','20',0,''),(617426,194427,'1694099590.35337','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(617427,194427,'1694099590.35337','new_theme','padding-top','20',0,''),(617428,194428,'1694099590.360420','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(617429,194428,'1694099590.360420','new_theme','clear','none',0,''),(617430,194429,'1694099590.362714','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(617431,194431,'1694099590.365625','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(617432,194431,'1694099590.365625','new_theme','clear','none',0,''),(617433,194432,'1694099590.367789','new_theme','block_type','1',0,''),(617434,194432,'1694099590.367789','new_theme','padding-left','30',0,''),(617435,194432,'1694099590.367789','new_theme','border-left-width','20',0,''),(617436,194432,'1694099590.367789','new_theme','border-left-color','$content-bg-2',0,''),(617437,194432,'1694099590.367789','new_theme','margin-left','-10',0,''),(617438,194432,'1694099590.367789','new_theme','padding-right','30',0,''),(617439,194432,'1694099590.367789','new_theme','padding-top','20',0,''),(617440,194432,'1694099590.367789','new_theme','padding-bottom','20',0,''),(617441,194432,'1694099590.367789','new_theme','border-left-width','0',0,'8451'),(617442,194434,'1694099590.370690','new_theme','margin-bottom','20',0,''),(617443,194435,'1694099590.371953','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(617444,194435,'1694099590.371953','new_theme','clear','none',0,''),(617445,194436,'1694099590.373633','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(617446,194437,'1694099590.37590','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(617447,194437,'1694099590.37590','new_theme','clear','none',0,''),(617448,194438,'1694099590.376747','new_theme','text','<div class=\"page-success\">\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>',0,''),(617449,194438,'1694099590.376747','new_theme','background-color','$content-bg-1',0,''),(617450,194438,'1694099590.376747','new_theme','margin-bottom','30',0,''),(617451,194438,'1694099590.376747','new_theme','padding-top','30',0,''),(617452,194438,'1694099590.376747','new_theme','padding-bottom','30',0,''),(617453,194438,'1694099590.376747','new_theme','padding-left','30',0,''),(617454,194438,'1694099590.376747','new_theme','padding-right','30',0,''),(617455,194438,'1694099590.376747','new_theme','color','$content-color-1',0,''),(617456,194439,'1694099590.38020','new_theme','block_type','1',0,''),(617457,194439,'1694099590.38020','new_theme','style_class','order-summary2 hiding-box',0,''),(617458,194440,'1694099590.381373','new_theme','text-align','center',0,''),(617459,194440,'1694099590.381373','new_theme','margin-bottom','20',0,''),(617460,194441,'1694099590.382864','new_theme','text-align','center',0,''),(617461,194444,'1694099590.386683','new_theme','block_type','12',0,''),(617462,194445,'1694099590.387673','new_theme','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n</div>\n',0,''),(617463,194445,'1694099590.387673','new_theme','margin-bottom','20',0,''),(617464,194446,'1694099590.389337','new_theme','text-align','center',0,''),(617465,194446,'1694099590.389337','new_theme','padding-top','40',0,''),(617466,194447,'75097','new_theme','block_type','1',0,''),(617467,194448,'75098','new_theme','block_type','1',0,''),(617468,194448,'75098','new_theme','font-weight','normal',0,''),(617469,194449,'75099','new_theme','block_type','1',0,''),(617470,194449,'75099','new_theme','text-align','center',0,''),(617471,194449,'75099','new_theme','padding-top','30',0,''),(617472,194449,'75099','new_theme','margin-bottom','200',0,''),(617473,194450,'75100','new_theme','display','inline-block',0,''),(617474,194450,'75100','new_theme','clear','none',0,''),(617475,194450,'75100','new_theme','margin-left','20',0,''),(617476,194451,'75101','new_theme','display','inline-block',0,''),(617477,194452,'75102','new_theme','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(617478,194453,'75107','new_theme','width','680',0,''),(617479,194453,'75107','new_theme','font-weight','normal',0,''),(617480,194453,'75107','new_theme','font-size','12',0,''),(617481,194453,'75107','new_theme','padding-top','20',0,''),(617482,194453,'75107','new_theme','padding-bottom','20',0,''),(617483,194453,'75107','new_theme','color','$content-color-1',0,''),(617484,194454,'75108','new_theme','block_type','5',0,''),(617485,194454,'75108','new_theme','font-weight','normal',0,''),(617486,194454,'75108','new_theme','border-bottom-width','1',0,''),(617487,194454,'75108','new_theme','border-bottom-color','$content-border-1',0,''),(617488,194454,'75108','new_theme','border-top-width','1',0,''),(617489,194454,'75108','new_theme','border-top-color','$content-border-1',0,''),(617490,194454,'75108','new_theme','border-left-color','$content-border-1',0,''),(617491,194454,'75108','new_theme','border-left-width','1',0,''),(617492,194455,'75109','new_theme','block_type','1',0,''),(617493,194455,'75109','new_theme','font-weight','normal',0,''),(617494,194455,'75109','new_theme','padding-top','10',0,''),(617495,194455,'75109','new_theme','padding-left','10',0,''),(617496,194455,'75109','new_theme','padding-right','10',0,''),(617497,194456,'75110','new_theme','font-weight','400',0,''),(617498,194456,'75110','new_theme','line-height','120',0,''),(617499,194456,'75110','new_theme','line_height_measure','%',0,''),(617500,194456,'75110','new_theme','font-size','12',0,''),(617501,194457,'75111','new_theme','text','<p>SHIPPING ADDRESS:</p>',1,''),(617502,194457,'75111','new_theme','font-size','14',0,''),(617503,194457,'75111','new_theme','font-weight','bold',0,''),(617504,194457,'75111','new_theme','padding-bottom','10',0,''),(617505,194457,'75111','new_theme','text','<p>SHIPPING ADDRESS:</p>',0,''),(617506,194458,'75112','new_theme','block_type','1',0,''),(617507,194458,'75112','new_theme','background-color','$content-bg-2',0,''),(617508,194458,'75112','new_theme','padding-top','20',0,''),(617509,194458,'75112','new_theme','padding-left','10',0,''),(617510,194458,'75112','new_theme','padding-right','10',0,''),(617511,194458,'75112','new_theme','padding-bottom','20',0,''),(617512,194458,'75112','new_theme','font-size','14',0,''),(617513,194459,'75113','new_theme','font-weight','normal',0,''),(617514,194459,'75113','new_theme','text-align','right',0,''),(617515,194459,'75113','new_theme','font-size','14',0,''),(617516,194459,'75113','new_theme','box_align','3',0,''),(617517,194460,'75114','new_theme','block_type','3',0,''),(617518,194460,'75114','new_theme','font-weight','normal',0,''),(617519,194460,'75114','new_theme','padding-top','20',0,''),(617520,194461,'75115','new_theme','text','<p>If undelivered please return to:</p>',1,''),(617521,194461,'75115','new_theme','font-size','12',0,''),(617522,194461,'75115','new_theme','font-weight','bold',0,''),(617523,194461,'75115','new_theme','text','<p>If undelivered please return to:</p>',0,''),(617524,194462,'75116','new_theme','font-size','12',0,''),(617525,194463,'75117','new_theme','font-weight','400',0,''),(617526,194463,'75117','new_theme','text-align','center',0,''),(617527,194463,'75117','new_theme','padding-top','0',0,''),(617528,194463,'75117','new_theme','padding-left','20',0,''),(617529,194463,'75117','new_theme','padding-right','20',0,''),(617530,194464,'75118','new_theme','text','<p>Thank you for your order</p>',1,''),(617531,194464,'75118','new_theme','color','$color-8',0,''),(617532,194464,'75118','new_theme','font-size','13',0,''),(617533,194464,'75118','new_theme','font-weight','bold',0,''),(617534,194464,'75118','new_theme','padding-top','5',0,''),(617535,194464,'75118','new_theme','text-align','center',0,''),(617536,194464,'75118','new_theme','text','<p>Thank you for your order</p>',0,''),(617537,194465,'75119','new_theme','text','<p>If something has gone wrong please contact us at:</p>',1,''),(617538,194465,'75119','new_theme','font-size','12',0,''),(617539,194465,'75119','new_theme','font-weight','bold',0,''),(617540,194465,'75119','new_theme','text-align','right',0,''),(617541,194465,'75119','new_theme','text','<p>If something has gone wrong please contact us at:</p>',0,''),(617542,194466,'75120','new_theme','block_type','6',0,''),(617543,194466,'75120','new_theme','font-weight','normal',0,''),(617544,194466,'75120','new_theme','font-size','16',0,''),(617545,194467,'75121','new_theme','text','<p>Email:</p>',1,''),(617546,194467,'75121','new_theme','font-weight','normal',0,''),(617547,194467,'75121','new_theme','text-align','right',0,''),(617548,194467,'75121','new_theme','font-size','12',0,''),(617549,194467,'75121','new_theme','text','<p>Email:</p>',0,''),(617550,194468,'75122','new_theme','font-weight','normal',0,''),(617551,194468,'75122','new_theme','text-align','right',0,''),(617552,194468,'75122','new_theme','font-size','12',0,''),(617553,194469,'75123','new_theme','block_type','6',0,''),(617554,194469,'75123','new_theme','font-weight','normal',0,''),(617555,194469,'75123','new_theme','font-size','16',0,''),(617556,194470,'75124','new_theme','text','<p>Phone:</p>',1,''),(617557,194470,'75124','new_theme','font-weight','normal',0,''),(617558,194470,'75124','new_theme','text-align','right',0,''),(617559,194470,'75124','new_theme','font-size','12',0,''),(617560,194470,'75124','new_theme','text','<p>Phone:</p>',0,''),(617561,194471,'75125','new_theme','font-weight','normal',0,''),(617562,194471,'75125','new_theme','text-align','right',0,''),(617563,194471,'75125','new_theme','font-size','12',0,''),(617564,194472,'75126','new_theme','font-weight','400',0,''),(617565,194472,'75126','new_theme','padding-top','20',0,''),(617566,194472,'75126','new_theme','padding-bottom','0',0,''),(617567,194472,'75126','new_theme','font-size','12',0,''),(617568,194473,'75127','new_theme','block_type','2',0,''),(617569,194473,'75127','new_theme','font-weight','normal',0,''),(617570,194473,'75127','new_theme','padding-bottom','20',0,''),(617571,194474,'75128','new_theme','block_type','11',0,''),(617572,194474,'75128','new_theme','font-weight','normal',0,''),(617573,194475,'75129','new_theme','text','<p>Email:</p>',1,''),(617574,194475,'75129','new_theme','font-weight','normal',0,''),(617575,194475,'75129','new_theme','text-align','right',0,''),(617576,194475,'75129','new_theme','text','<p>Email:</p>',0,''),(617577,194476,'75130','new_theme','font-weight','normal',0,''),(617578,194476,'75130','new_theme','text-align','right',0,''),(617579,194477,'75131','new_theme','block_type','11',0,''),(617580,194477,'75131','new_theme','font-weight','normal',0,''),(617581,194478,'75132','new_theme','text','<p>Web:</p>',1,''),(617582,194478,'75132','new_theme','font-weight','normal',0,''),(617583,194478,'75132','new_theme','text-align','right',0,''),(617584,194478,'75132','new_theme','text','<p>Web:</p>',0,''),(617585,194479,'75133','new_theme','font-weight','normal',0,''),(617586,194479,'75133','new_theme','text-align','right',0,''),(617587,194480,'75134','new_theme','block_type','1',0,''),(617588,194481,'75135','new_theme','font-weight','normal',0,''),(617589,194481,'75135','new_theme','text-align','right',0,''),(617590,194481,'75135','new_theme','padding-bottom','10',0,''),(617591,194481,'75135','new_theme','address_spacer',',',0,''),(617592,194481,'75135','new_theme','font-size','12',0,''),(617593,194482,'75136','new_theme','block_type','11',0,''),(617594,194482,'75136','new_theme','font-weight','normal',0,''),(617595,194483,'75137','new_theme','text','<p>Phone:</p>',1,''),(617596,194483,'75137','new_theme','font-weight','normal',0,''),(617597,194483,'75137','new_theme','text-align','right',0,''),(617598,194483,'75137','new_theme','text','<p>Phone:</p>',0,''),(617599,194484,'75138','new_theme','font-weight','normal',0,''),(617600,194484,'75138','new_theme','text-align','right',0,''),(617601,194485,'75139','new_theme','block_type','4',0,''),(617602,194485,'75139','new_theme','font-weight','normal',0,''),(617603,194485,'75139','new_theme','border-top-width','1',0,''),(617604,194485,'75139','new_theme','border-top-color','$content-border-1',0,''),(617605,194485,'75139','new_theme','border-left-width','1',0,''),(617606,194485,'75139','new_theme','border-left-color','$content-border-1',0,''),(617607,194485,'75139','new_theme','border-right-width','1',0,''),(617608,194485,'75139','new_theme','border-right-color','$content-border-1',0,''),(617609,194485,'75139','new_theme','border-bottom-width','1',0,''),(617610,194485,'75139','new_theme','border-bottom-color','$content-border-1',0,''),(617611,194486,'75140','new_theme','block_type','2',0,''),(617612,194486,'75140','new_theme','font-weight','normal',0,''),(617613,194486,'75140','new_theme','border-top-width','1',0,''),(617614,194486,'75140','new_theme','border-top-color','$content-border-1',0,''),(617615,194486,'75140','new_theme','border-right-width','1',0,''),(617616,194486,'75140','new_theme','border-right-color','$content-border-1',0,''),(617617,194487,'75141','new_theme','block_type','1',0,''),(617618,194487,'75141','new_theme','font-weight','normal',0,''),(617619,194487,'75141','new_theme','padding-top','10',0,''),(617620,194487,'75141','new_theme','padding-left','10',0,''),(617621,194487,'75141','new_theme','padding-right','10',0,''),(617622,194487,'75141','new_theme','padding-bottom','10',0,''),(617623,194487,'75141','new_theme','border-right-width','1',0,''),(617624,194487,'75141','new_theme','border-right-color','$content-border-1',0,''),(617625,194488,'75142','new_theme','text','<p>Shipping via</p>',1,''),(617626,194488,'75142','new_theme','font-weight','bold',0,''),(617627,194488,'75142','new_theme','font-size','14',0,''),(617628,194488,'75142','new_theme','text','<p>Shipping via</p>',0,''),(617629,194490,'75144','new_theme','block_type','1',0,''),(617630,194490,'75144','new_theme','font-weight','normal',0,''),(617631,194490,'75144','new_theme','padding-top','10',0,''),(617632,194490,'75144','new_theme','padding-left','10',0,''),(617633,194490,'75144','new_theme','padding-right','10',0,''),(617634,194490,'75144','new_theme','padding-bottom','10',0,''),(617635,194491,'75145','new_theme','text','<p>Shipping service</p>',1,''),(617636,194491,'75145','new_theme','font-weight','bold',0,''),(617637,194491,'75145','new_theme','font-size','14',0,''),(617638,194491,'75145','new_theme','text','<p>Shipping service</p>',0,''),(617639,194493,'75147','new_theme','block_type','2',0,''),(617640,194493,'75147','new_theme','font-weight','normal',0,''),(617641,194493,'75147','new_theme','border-right-width','1',0,''),(617642,194493,'75147','new_theme','border-right-color','$content-border-1',0,''),(617643,194494,'75148','new_theme','block_type','1',0,''),(617644,194494,'75148','new_theme','font-weight','400',0,''),(617645,194494,'75148','new_theme','background-color','$content-bg-2',0,''),(617646,194494,'75148','new_theme','padding-top','10',0,''),(617647,194494,'75148','new_theme','padding-left','10',0,''),(617648,194494,'75148','new_theme','padding-right','10',0,''),(617649,194494,'75148','new_theme','padding-bottom','30',0,''),(617650,194495,'75149','new_theme','font-size','12',0,''),(617651,194496,'75150','new_theme','text','<p>INVOICE ADDRESS:</p>',1,''),(617652,194496,'75150','new_theme','font-size','14',0,''),(617653,194496,'75150','new_theme','font-weight','bold',0,''),(617654,194496,'75150','new_theme','text','<p>INVOICE ADDRESS:</p>',0,''),(617655,194497,'75151','new_theme','block_type','1',0,''),(617656,194497,'75151','new_theme','font-weight','normal',0,''),(617657,194497,'75151','new_theme','padding-top','10',0,''),(617658,194497,'75151','new_theme','padding-left','10',0,''),(617659,194497,'75151','new_theme','padding-right','10',0,''),(617660,194497,'75151','new_theme','padding-bottom','10',0,''),(617661,194498,'75152','new_theme','font-weight','normal',0,''),(617662,194499,'75153','new_theme','text','<p>PHONE NUMBER:</p>',1,''),(617663,194499,'75153','new_theme','font-size','14',0,''),(617664,194499,'75153','new_theme','font-weight','bold',0,''),(617665,194499,'75153','new_theme','padding-top','10',0,''),(617666,194499,'75153','new_theme','text','<p>PHONE NUMBER:</p>',0,''),(617667,194501,'75155','new_theme','font-weight','normal',0,''),(617668,194502,'75156','new_theme','text','<p>E-MAIL ADDRESS:</p>',1,''),(617669,194502,'75156','new_theme','font-weight','bold',0,''),(617670,194502,'75156','new_theme','font-size','14',0,''),(617671,194502,'75156','new_theme','padding-top','10',0,''),(617672,194502,'75156','new_theme','text','<p>E-MAIL ADDRESS:</p>',0,''),(617673,194503,'75157','new_theme','text','<p>CUSTOMER:</p>',1,''),(617674,194503,'75157','new_theme','font-size','13',0,''),(617675,194503,'75157','new_theme','font-weight','bold',0,''),(617676,194503,'75157','new_theme','text','<p>CUSTOMER:</p>',0,''),(617677,194504,'75158','new_theme','font-weight','normal',0,''),(617678,194504,'75158','new_theme','text-align','center',0,''),(617679,194504,'75158','new_theme','padding-bottom','10',0,''),(617680,194505,'75159','new_theme','text','<p>Payment date:</p>',1,''),(617681,194505,'75159','new_theme','font-weight','bold',0,''),(617682,194505,'75159','new_theme','text-align','center',0,''),(617683,194505,'75159','new_theme','font-size','12',0,''),(617684,194505,'75159','new_theme','text','<p>Payment date:</p>',0,''),(617685,194506,'75160','new_theme','text','<p>Payment Method:</p>',1,''),(617686,194506,'75160','new_theme','font-weight','bold',0,''),(617687,194506,'75160','new_theme','text-align','center',0,''),(617688,194506,'75160','new_theme','text','<p>Payment Method:</p>',0,''),(617689,194507,'75161','new_theme','font-size','14',0,''),(617690,194507,'75161','new_theme','font-weight','bold',0,''),(617691,194507,'75161','new_theme','text-align','center',0,''),(617692,194507,'75161','new_theme','padding-bottom','10',0,''),(617693,194507,'75161','new_theme','padding-top','10',0,''),(617694,194508,'75162','new_theme','font-weight','normal',0,''),(617695,194508,'75162','new_theme','text-align','center',0,''),(617696,194508,'75162','new_theme','padding-bottom','20',0,''),(617697,194509,'75163','new_theme','font-weight','normal',0,''),(617698,194509,'75163','new_theme','text-align','center',0,''),(617699,194510,'75194','new_theme','block_type','1',0,''),(617700,194511,'75195','new_theme','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(617701,194513,'75418','new_theme','block_type','1',0,''),(617702,194514,'75419','new_theme','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(617703,194514,'75419','new_theme','padding-top','100',0,''),(617704,194514,'75419','new_theme','margin-bottom','100',0,''),(617705,194514,'75419','new_theme','text-align','center',0,''),(617706,194514,'75419','new_theme','font-size','20',0,''),(617707,194515,'75420','new_theme','block_type','1',0,''),(617708,194515,'75420','new_theme','background-color','$content-bg-2',0,''),(617709,194515,'75420','new_theme','padding-bottom','30',0,''),(617710,194516,'75421','new_theme','block_type','4',0,''),(617711,194516,'75421','new_theme','schema','4-2',0,'8451'),(617712,194517,'75422','new_theme','block_type','1',0,''),(617713,194517,'75422','new_theme','padding-right','40',0,''),(617714,194517,'75422','new_theme','padding-right','0',0,'8451'),(617715,194518,'75423','new_theme','block_type','2',0,''),(617716,194518,'75423','new_theme','margin-bottom','20',0,''),(617717,194518,'75423','new_theme','schema','2-2',0,'8444'),(617718,194518,'75423','new_theme','background-color','$content-bg-1',0,''),(617719,194519,'75424','new_theme','block_type','1',0,''),(617720,194519,'75424','new_theme','border-right-width','20',0,''),(617721,194519,'75424','new_theme','border-right-color','$content-border-1',0,''),(617722,194519,'75424','new_theme','margin-right','-10',0,''),(617723,194519,'75424','new_theme','padding-right','30',0,''),(617724,194519,'75424','new_theme','padding-top','20',0,''),(617725,194519,'75424','new_theme','padding-left','30',0,''),(617726,194519,'75424','new_theme','padding-bottom','20',0,''),(617727,194519,'75424','new_theme','border-right-width','0',0,'8451'),(617728,194519,'75424','new_theme','margin-right','0',0,'8451'),(617729,194519,'75424','new_theme','margin-bottom','20',0,'8451'),(617730,194519,'75424','new_theme','padding-left','20',0,'8451'),(617731,194519,'75424','new_theme','padding-right','20',0,'8451'),(617732,194521,'75426','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(617733,194521,'75426','new_theme','clear','none',0,''),(617734,194522,'75427','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(617735,194522,'75427','new_theme','clear','none',0,''),(617736,194523,'75428','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(617737,194525,'75430','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(617738,194525,'75430','new_theme','padding-top','20',0,''),(617739,194528,'75433','new_theme','margin-bottom','20',0,''),(617740,194529,'75434','new_theme','block_type','1',0,''),(617741,194529,'75434','new_theme','padding-left','30',0,''),(617742,194529,'75434','new_theme','border-left-width','20',0,''),(617743,194529,'75434','new_theme','border-left-color','$content-border-1',0,''),(617744,194529,'75434','new_theme','margin-left','-10',0,''),(617745,194529,'75434','new_theme','padding-right','30',0,''),(617746,194529,'75434','new_theme','padding-top','20',0,''),(617747,194529,'75434','new_theme','padding-bottom','20',0,''),(617748,194529,'75434','new_theme','border-left-width','0',0,'8451'),(617749,194530,'75435','new_theme','margin-bottom','20',0,''),(617750,194532,'75437','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(617751,194533,'75438','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(617752,194533,'75438','new_theme','clear','none',0,''),(617753,194534,'75439','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(617754,194534,'75439','new_theme','clear','none',0,''),(617755,194535,'75440','new_theme','block_type','1',0,''),(617756,194535,'75440','new_theme','padding-right','30',0,''),(617757,194535,'75440','new_theme','background-color','$content-bg-1',0,''),(617758,194535,'75440','new_theme','padding-top','20',0,''),(617759,194535,'75440','new_theme','padding-left','30',0,''),(617760,194535,'75440','new_theme','padding-bottom','20',0,''),(617761,194535,'75440','new_theme','padding-left','20',0,'8451'),(617762,194535,'75440','new_theme','padding-right','20',0,'8451'),(617763,194537,'75442','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(617764,194538,'75443','new_theme','block_type','1',0,''),(617765,194538,'75443','new_theme','padding-top','20',0,''),(617766,194538,'75443','new_theme','padding-left','20',0,''),(617767,194538,'75443','new_theme','padding-right','20',0,''),(617768,194538,'75443','new_theme','padding-bottom','20',0,''),(617769,194538,'75443','new_theme','background-color','$content-bg-1',0,''),(617770,194538,'75443','new_theme','style_class','order-summary',0,''),(617771,194539,'75444','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(617772,194543,'75448','new_theme','block_type','1',0,''),(617773,194543,'75448','new_theme','background-color','$content-bg-2',0,''),(617774,194543,'75448','new_theme','padding-bottom','30',0,''),(617775,194544,'75449','new_theme','block_type','4',0,''),(617776,194544,'75449','new_theme','schema','4-2',0,'8451'),(617777,194545,'75450','new_theme','block_type','1',0,''),(617778,194545,'75450','new_theme','padding-right','40',0,''),(617779,194545,'75450','new_theme','padding-right','0',0,'8451'),(617780,194546,'75451','new_theme','block_type','2',0,''),(617781,194546,'75451','new_theme','margin-bottom','20',0,''),(617782,194546,'75451','new_theme','schema','2-2',0,'8444'),(617783,194546,'75451','new_theme','background-color','$content-bg-1',0,''),(617784,194547,'75452','new_theme','block_type','1',0,''),(617785,194547,'75452','new_theme','border-right-width','20',0,''),(617786,194547,'75452','new_theme','border-right-color','$content-border-1',0,''),(617787,194547,'75452','new_theme','margin-right','-10',0,''),(617788,194547,'75452','new_theme','padding-right','30',0,''),(617789,194547,'75452','new_theme','padding-top','20',0,''),(617790,194547,'75452','new_theme','padding-left','30',0,''),(617791,194547,'75452','new_theme','padding-bottom','20',0,''),(617792,194547,'75452','new_theme','border-right-width','0',0,'8451'),(617793,194547,'75452','new_theme','margin-right','0',0,'8451'),(617794,194547,'75452','new_theme','margin-bottom','20',0,'8451'),(617795,194547,'75452','new_theme','padding-left','20',0,'8451'),(617796,194547,'75452','new_theme','padding-right','20',0,'8451'),(617797,194548,'75453','new_theme','margin-bottom','20',0,''),(617798,194551,'75456','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(617799,194551,'75456','new_theme','padding-top','20',0,''),(617800,194553,'75458','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(617801,194553,'75458','new_theme','clear','none',0,''),(617802,194555,'75460','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(617803,194556,'75461','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(617804,194556,'75461','new_theme','clear','none',0,''),(617805,194557,'75462','new_theme','block_type','1',0,''),(617806,194557,'75462','new_theme','padding-left','30',0,''),(617807,194557,'75462','new_theme','border-left-width','20',0,''),(617808,194557,'75462','new_theme','border-left-color','$content-border-1',0,''),(617809,194557,'75462','new_theme','margin-left','-10',0,''),(617810,194557,'75462','new_theme','padding-right','30',0,''),(617811,194557,'75462','new_theme','padding-top','20',0,''),(617812,194557,'75462','new_theme','padding-bottom','20',0,''),(617813,194557,'75462','new_theme','border-left-width','0',0,'8451'),(617814,194558,'75463','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(617815,194559,'75464','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(617816,194559,'75464','new_theme','clear','none',0,''),(617817,194560,'75465','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(617818,194560,'75465','new_theme','clear','none',0,''),(617819,194561,'75466','new_theme','margin-bottom','20',0,''),(617820,194563,'75468','new_theme','block_type','1',0,''),(617821,194563,'75468','new_theme','padding-right','30',0,''),(617822,194563,'75468','new_theme','background-color','$content-bg-1',0,''),(617823,194563,'75468','new_theme','padding-top','20',0,''),(617824,194563,'75468','new_theme','padding-left','30',0,''),(617825,194563,'75468','new_theme','padding-bottom','20',0,''),(617826,194563,'75468','new_theme','padding-left','20',0,'8451'),(617827,194563,'75468','new_theme','padding-right','20',0,'8451'),(617828,194564,'75469','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(617829,194566,'75471','new_theme','block_type','1',0,''),(617830,194566,'75471','new_theme','padding-top','20',0,''),(617831,194566,'75471','new_theme','padding-left','20',0,''),(617832,194566,'75471','new_theme','padding-right','20',0,''),(617833,194566,'75471','new_theme','padding-bottom','20',0,''),(617834,194566,'75471','new_theme','background-color','$content-bg-1',0,''),(617835,194566,'75471','new_theme','style_class','order-summary',0,''),(617836,194569,'75474','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(617837,194571,'75540','new_theme','block_type','1',0,''),(617838,194572,'75541','new_theme','block_type','6',0,''),(617839,194572,'75541','new_theme','schema','6-3',0,'8451'),(617840,194573,'75542','new_theme','aria_name','account-menu',0,''),(617841,194574,'73374','new_theme','block_type','1',0,''),(617842,194574,'73374','new_theme','padding-top','70',0,''),(617843,194574,'73374','new_theme','padding-right','30',0,''),(617844,194574,'73374','new_theme','padding-bottom','30',0,''),(617845,194574,'73374','new_theme','padding-top','0',0,'8451'),(617846,194574,'73374','new_theme','padding-left','0',0,'8451'),(617847,194574,'73374','new_theme','padding-right','0',0,'8451'),(617848,194574,'73374','new_theme','padding-bottom','0',0,'8451'),(617849,194575,'73375','new_theme','block_type','1',0,''),(617850,194575,'73375','new_theme','style_class','account-menu',0,''),(617851,194576,'73376','new_theme','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(617852,194576,'73376','new_theme','style_class','heading-settings',0,''),(617853,194577,'73377','new_theme','link','logoff',0,''),(617854,194578,'73378','new_theme','link','delete',0,''),(617855,194578,'73378','new_theme','text','DELETE_ACCOUNT',0,''),(617856,194579,'73379','new_theme','text','TEXT_DASHBOARD',0,''),(617857,194579,'73379','new_theme','font-family','$font-1',0,''),(617858,194579,'73379','new_theme','font-size','18',0,''),(617859,194579,'73379','new_theme','text-transform','uppercase',0,''),(617860,194580,'73380','new_theme','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(617861,194580,'73380','new_theme','style_class','heading-saved-lists',0,''),(617862,194581,'73381','new_theme','link','Personal Catalog',0,''),(617863,194581,'73381','new_theme','text','TEXT_PERSONAL_CATALOG',0,''),(617864,194581,'73381','new_theme','hide_link','personal_catalog',0,''),(617865,194582,'73382','new_theme','link','Order History',0,''),(617866,194582,'73382','new_theme','text','HEADING_ORDER_HISTORY',0,''),(617867,194582,'73382','new_theme','active_link','Order History Info,Order pay',0,''),(617868,194583,'73383','new_theme','link','Address Book',0,''),(617869,194583,'73383','new_theme','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(617870,194584,'73384','new_theme','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(617871,194584,'73384','new_theme','style_class','heading-ordered-items',0,''),(617872,194585,'73385','new_theme','link','Wishlist',0,''),(617873,194585,'73385','new_theme','hide_link','wishlist',0,''),(617874,194585,'73385','new_theme','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(617875,194586,'73386','new_theme','link','My password',0,''),(617876,194586,'73386','new_theme','text','TEXT_MY_PASSWORD',0,''),(617877,194587,'73387','new_theme','link','Samples',0,''),(617878,194587,'73387','new_theme','text','TEXT_HEADING_SAMPLE_CART',0,''),(617879,194587,'73387','new_theme','hide_link','samples',0,''),(617880,194588,'73388','new_theme','link','Review',0,''),(617881,194588,'73388','new_theme','text','REVIEWS',0,''),(617882,194589,'73389','new_theme','link','Quotations',0,''),(617883,194589,'73389','new_theme','hide_link','quotations',0,''),(617884,194589,'73389','new_theme','text','TEXT_HEADING_QUOTE_CART',0,''),(617885,194590,'73390','new_theme','link','Account edit',0,''),(617886,194590,'73390','new_theme','text','ACCOUNT_EDIT',0,''),(617887,194591,'73391','new_theme','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(617888,194591,'73391','new_theme','style_class','heading-settings',0,''),(617889,194592,'73392','new_theme','link','trade_form',0,''),(617890,194592,'73392','new_theme','text','TRADE_FORM',0,''),(617891,194593,'75543','new_theme','margin-bottom','20',0,''),(617892,194594,'75544','new_theme','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(617893,194595,'75545','new_theme','block_type','1',0,''),(617894,194595,'75545','new_theme','padding-top','20',0,''),(617895,194595,'75545','new_theme','padding-bottom','20',0,''),(617896,194597,'75547','new_theme','padding-top','20',0,''),(617897,194597,'75547','new_theme','padding-bottom','20',0,''),(617899,110488,'1683018455.4659','furniture','preload','1',0,''),(617904,179376,'1712674967.356553','furniture','width','159',1,''),(617906,179372,'1712674967.104961','furniture','logo','themes/furniture/img/Logo-4.webp',1,''),(617907,179372,'1712674967.104961','furniture','logo_from','theme',0,''),(617908,110380,'117275','furniture','logo','themes/furniture/img/logonew.jpg',1,''),(617910,110380,'117275','furniture','logo_from','theme',0,''),(617911,110380,'117275','furniture','background-color','$header-bg-1',0,''),(617912,110380,'117275','furniture','padding-left','10',0,''),(617913,110380,'117275','furniture','padding-right','10',0,''),(617914,110492,'1705058746.898727','furniture','lazy_load','1',0,''),(617915,179376,'1712674967.356553','furniture','height','126',1,''),(617916,179376,'1712674967.356553','furniture','lazy_load','1',0,''),(617917,112982,'74507','watch','preload','1',0,''),(617918,115482,'1683025508.153','printshop','preload','1',0,''),(617919,122965,'1683024814.1915','deals','preload','1',0,'');
/*!40000 ALTER TABLE `design_boxes_settings` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `design_boxes_settings_tmp`
--

DROP TABLE IF EXISTS `design_boxes_settings_tmp`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `design_boxes_settings_tmp` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `box_id` int(11) DEFAULT NULL,
  `microtime` varchar(32) NOT NULL,
  `theme_name` varchar(128) CHARACTER SET latin1 COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `setting_name` varchar(64) DEFAULT NULL,
  `setting_value` text,
  `language_id` int(11) NOT NULL DEFAULT '0',
  `visibility` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`),
  UNIQUE KEY `language_box_settingname_visibility` (`language_id`,`box_id`,`setting_name`,`visibility`),
  KEY `box_id` (`box_id`),
  KEY `design_boxes_settings_tmp_microtime` (`microtime`)
) ENGINE=InnoDB AUTO_INCREMENT=617920 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `design_boxes_settings_tmp`
--

LOCK TABLES `design_boxes_settings_tmp` WRITE;
/*!40000 ALTER TABLE `design_boxes_settings_tmp` DISABLE KEYS */;
INSERT INTO `design_boxes_settings_tmp` VALUES (9097,2926,'94814','watch-mobile','text','##TEXT_PAGE_NOT_FOUND##',0,''),(9098,2926,'94814','watch-mobile','text-align','center',0,''),(9099,2926,'94814','watch-mobile','padding-top','100',0,''),(9100,2926,'94814','watch-mobile','padding-bottom','100',0,''),(9101,2927,'94815','watch-mobile','block_type','1',0,''),(9220,2943,'94831','watch-mobile','block_type','1',0,''),(9339,2959,'94847','watch-mobile','block_type','1',0,''),(9458,2975,'94863','watch-mobile','block_type','1',0,''),(9577,2991,'94879','watch-mobile','block_type','1',0,''),(9696,3007,'94895','watch-mobile','block_type','1',0,''),(9815,3023,'94911','watch-mobile','block_type','1',0,''),(9816,3024,'94912','watch-mobile','block_type','6',0,''),(9817,3024,'94912','watch-mobile','schema','6-3',0,''),(9818,3024,'94912','watch-mobile','schema','6-3',0,'299'),(9819,3025,'94913','watch-mobile','aria_name','account-menu',0,''),(9820,3026,'94914','watch-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(9821,3027,'94915','watch-mobile','link','Order History Info',0,''),(9822,3027,'94915','watch-mobile','text','TEXT_VIEW',0,''),(9823,3027,'94915','watch-mobile','max_orders','3',0,''),(9824,3027,'94915','watch-mobile','link_pay','Order pay',0,''),(9825,3027,'94915','watch-mobile','margin-bottom','30',0,''),(9826,3027,'94915','watch-mobile','text_pay','ORDER_PAY',0,''),(9827,3028,'94916','watch-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(9828,3029,'94917','watch-mobile','block_type','15',0,''),(9829,3029,'94917','watch-mobile','margin-bottom','30',0,''),(9830,3029,'94917','watch-mobile','padding-top','20',0,''),(9831,3029,'94917','watch-mobile','padding-left','20',0,''),(9832,3029,'94917','watch-mobile','padding-right','20',0,''),(9833,3029,'94917','watch-mobile','padding-bottom','20',0,''),(9834,3029,'94917','watch-mobile','border-top-width','1',0,''),(9835,3029,'94917','watch-mobile','border-top-color','$border-color-1',0,''),(9836,3029,'94917','watch-mobile','border-left-width','1',0,''),(9837,3029,'94917','watch-mobile','border-right-width','1',0,''),(9838,3029,'94917','watch-mobile','border-bottom-width','1',0,''),(9839,3029,'94917','watch-mobile','border-left-color','$border-color-1',0,''),(9840,3029,'94917','watch-mobile','border-right-color','$border-color-1',0,''),(9841,3029,'94917','watch-mobile','border-bottom-color','$border-color-1',0,''),(9842,3029,'94917','watch-mobile','schema','15-2',0,'299'),(9843,3030,'94918','watch-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(9844,3030,'94918','watch-mobile','font-family','trueloaded',0,'3'),(9845,3030,'94918','watch-mobile','content','\\e920',0,'3'),(9846,3030,'94918','watch-mobile','color','$attention-color',0,'3'),(9847,3030,'94918','watch-mobile','font-size','30',0,'3'),(9848,3030,'94918','watch-mobile','text-align','center',0,'3'),(9849,3030,'94918','watch-mobile','margin-bottom','10',0,'3'),(9850,3030,'94918','watch-mobile','text-align','center',0,''),(9851,3030,'94918','watch-mobile','font-size','16',0,''),(9852,3030,'94918','watch-mobile','text-transform','uppercase',0,''),(9853,3030,'94918','watch-mobile','line-height','1',0,'3'),(9855,3031,'94919','watch-mobile','font-family','$font-1',0,''),(9856,3031,'94919','watch-mobile','color','$attention-color',0,''),(9857,3031,'94919','watch-mobile','font-size','14',0,''),(9858,3031,'94919','watch-mobile','text-align','center',0,''),(9859,3032,'94920','watch-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(9860,3032,'94920','watch-mobile','font-family','trueloaded',0,'3'),(9861,3032,'94920','watch-mobile','content','\\e928',0,'3'),(9862,3032,'94920','watch-mobile','color','$attention-color',0,'3'),(9863,3032,'94920','watch-mobile','font-size','30',0,'3'),(9864,3032,'94920','watch-mobile','text-align','center',0,'3'),(9865,3032,'94920','watch-mobile','text-align','center',0,''),(9866,3032,'94920','watch-mobile','font-size','16',0,''),(9867,3032,'94920','watch-mobile','text-transform','uppercase',0,''),(9868,3032,'94920','watch-mobile','line-height','1',0,'3'),(9870,3033,'94921','watch-mobile','link','download_orders',0,''),(9871,3033,'94921','watch-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(9872,3033,'94921','watch-mobile','hide_link','orders',0,''),(9873,3033,'94921','watch-mobile','text-align','center',0,''),(9874,3033,'94921','watch-mobile','popup','2',0,''),(9875,3033,'94921','watch-mobile','font-size','14',0,''),(9876,3034,'94922','watch-mobile','font-family','$font-1',0,''),(9877,3034,'94922','watch-mobile','color','$attention-color',0,''),(9878,3034,'94922','watch-mobile','font-size','14',0,''),(9879,3034,'94922','watch-mobile','text-align','center',0,''),(9880,3035,'94923','watch-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(9881,3035,'94923','watch-mobile','font-family','trueloaded',0,'3'),(9882,3035,'94923','watch-mobile','content','\\e922',0,'3'),(9883,3035,'94923','watch-mobile','color','$attention-color',0,'3'),(9884,3035,'94923','watch-mobile','font-size','30',0,'3'),(9885,3035,'94923','watch-mobile','line-height','1',0,'3'),(9886,3035,'94923','watch-mobile','font-size','16',0,''),(9887,3035,'94923','watch-mobile','text-align','center',0,''),(9888,3035,'94923','watch-mobile','text-transform','uppercase',0,''),(9890,3036,'94924','watch-mobile','font-family','$font-1',0,''),(9891,3036,'94924','watch-mobile','color','$attention-color',0,''),(9892,3036,'94924','watch-mobile','line-height','1',0,''),(9893,3036,'94924','watch-mobile','text-align','center',0,''),(9894,3036,'94924','watch-mobile','font-size','14',0,''),(9895,3037,'94925','watch-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(9896,3037,'94925','watch-mobile','content','\\e994',0,'3'),(9897,3037,'94925','watch-mobile','font-family','trueloaded',0,'3'),(9898,3037,'94925','watch-mobile','color','$attention-color',0,'3'),(9899,3037,'94925','watch-mobile','font-size','30',0,'3'),(9900,3037,'94925','watch-mobile','line-height','1',0,'3'),(9901,3037,'94925','watch-mobile','font-size','16',0,''),(9902,3037,'94925','watch-mobile','text-align','center',0,''),(9903,3037,'94925','watch-mobile','text-transform','uppercase',0,''),(9905,3038,'94926','watch-mobile','link','Gift Certificate',0,''),(9906,3038,'94926','watch-mobile','text','GIFT_CERTIFICATE',0,''),(9907,3038,'94926','watch-mobile','popup','1',0,''),(9908,3038,'94926','watch-mobile','text-align','center',0,''),(9909,3038,'94926','watch-mobile','font-size','14',0,''),(9910,3039,'94927','watch-mobile','font-family','$font-1',0,''),(9911,3039,'94927','watch-mobile','color','$attention-color',0,''),(9912,3039,'94927','watch-mobile','font-size','14',0,''),(9913,3039,'94927','watch-mobile','text-align','center',0,''),(9914,3040,'94928','watch-mobile','text','TEXT_VIEW_HISTORY',0,''),(9915,3040,'94928','watch-mobile','popup','1',0,''),(9916,3040,'94928','watch-mobile','text-align','center',0,''),(9917,3040,'94928','watch-mobile','link','Points Earnt History',0,''),(9918,3040,'94928','watch-mobile','font-size','14',0,''),(9919,3041,'94929','watch-mobile','font-family','$font-1',0,''),(9920,3041,'94929','watch-mobile','color','$attention-color',0,''),(9921,3041,'94929','watch-mobile','font-size','14',0,''),(9922,3041,'94929','watch-mobile','text-align','center',0,''),(9923,3042,'94930','watch-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(9924,3042,'94930','watch-mobile','content','\\e990',0,'3'),(9925,3042,'94930','watch-mobile','font-family','trueloaded',0,'3'),(9926,3042,'94930','watch-mobile','font-size','30',0,'3'),(9927,3042,'94930','watch-mobile','text-align','center',0,'3'),(9928,3042,'94930','watch-mobile','line-height','1',0,'3'),(9929,3042,'94930','watch-mobile','color','$attention-color',0,'3'),(9930,3042,'94930','watch-mobile','font-size','16',0,''),(9931,3042,'94930','watch-mobile','text-align','center',0,''),(9932,3042,'94930','watch-mobile','text-transform','uppercase',0,''),(9934,3043,'94931','watch-mobile','block_type','1',0,''),(9935,3044,'94932','watch-mobile','hide_parents','2',0,''),(9936,3045,'94933','watch-mobile','text','<div class=\"heading-3\">##TEXT_GIFT_CARDS##</div>',0,''),(9937,3047,'94935','watch-mobile','block_type','1',0,''),(9938,3047,'94935','watch-mobile','padding-top','70',0,''),(9939,3047,'94935','watch-mobile','padding-right','30',0,''),(9940,3047,'94935','watch-mobile','padding-bottom','30',0,''),(9942,3047,'94935','watch-mobile','padding-left','0',0,''),(9945,3048,'94936','watch-mobile','block_type','1',0,''),(9946,3048,'94936','watch-mobile','padding-right','20',0,''),(9947,3048,'94936','watch-mobile','style_class','account-menu',0,''),(9948,3048,'94936','watch-mobile','padding-top','20',0,''),(9949,3048,'94936','watch-mobile','margin-bottom','20',0,''),(9950,3048,'94936','watch-mobile','background-color','$background-6',0,''),(9951,3048,'94936','watch-mobile','padding-left','20',0,''),(9952,3048,'94936','watch-mobile','padding-bottom','20',0,''),(9953,3049,'94937','watch-mobile','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(9954,3049,'94937','watch-mobile','style_class','heading-settings',0,''),(9955,3050,'94938','watch-mobile','link','delete',0,''),(9956,3050,'94938','watch-mobile','text','DELETE_ACCOUNT',0,''),(9957,3051,'94939','watch-mobile','text','TEXT_DASHBOARD',0,''),(9958,3051,'94939','watch-mobile','font-family','$font-1',0,''),(9959,3051,'94939','watch-mobile','font-size','18',0,''),(9960,3051,'94939','watch-mobile','text-transform','uppercase',0,''),(9961,3052,'94940','watch-mobile','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(9962,3052,'94940','watch-mobile','style_class','heading-saved-lists',0,''),(9963,3053,'94941','watch-mobile','link','logoff',0,''),(9964,3054,'94942','watch-mobile','link','Personal Catalog',0,''),(9965,3054,'94942','watch-mobile','text','TEXT_PERSONAL_CATALOG',0,''),(9966,3054,'94942','watch-mobile','hide_link','personal_catalog',0,''),(9967,3055,'94943','watch-mobile','link','Address Book',0,''),(9968,3055,'94943','watch-mobile','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(9969,3056,'94944','watch-mobile','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(9970,3056,'94944','watch-mobile','style_class','heading-ordered-items',0,''),(9971,3057,'94945','watch-mobile','link','Samples',0,''),(9972,3057,'94945','watch-mobile','text','TEXT_HEADING_SAMPLE_CART',0,''),(9973,3057,'94945','watch-mobile','hide_link','samples',0,''),(9974,3058,'94946','watch-mobile','link','Order History',0,''),(9975,3058,'94946','watch-mobile','text','HEADING_ORDER_HISTORY',0,''),(9976,3058,'94946','watch-mobile','active_link','Order History Info,Order pay',0,''),(9977,3059,'94947','watch-mobile','link','My password',0,''),(9978,3059,'94947','watch-mobile','text','TEXT_MY_PASSWORD',0,''),(9979,3060,'94948','watch-mobile','link','Review',0,''),(9980,3060,'94948','watch-mobile','text','REVIEWS',0,''),(9981,3061,'94949','watch-mobile','link','Account edit',0,''),(9982,3061,'94949','watch-mobile','text','ACCOUNT_EDIT',0,''),(9983,3062,'94950','watch-mobile','link','Quotations',0,''),(9984,3062,'94950','watch-mobile','hide_link','quotations',0,''),(9985,3062,'94950','watch-mobile','text','TEXT_HEADING_QUOTE_CART',0,''),(9986,3063,'94951','watch-mobile','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(9987,3063,'94951','watch-mobile','style_class','heading-settings',0,''),(9988,3064,'94952','watch-mobile','link','trade_form',0,''),(9989,3064,'94952','watch-mobile','text','TRADE_FORM',0,''),(9990,3065,'94953','watch-mobile','block_type','1',0,''),(9991,3066,'94954','watch-mobile','block_type','6',0,''),(9992,3066,'94954','watch-mobile','schema','6-3',0,''),(9993,3066,'94954','watch-mobile','schema','6-3',0,'299'),(9994,3067,'94955','watch-mobile','aria_name','account-menu',0,''),(9995,3069,'94957','watch-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(9996,3070,'94958','watch-mobile','text','CANCEL',0,''),(9997,3070,'94958','watch-mobile','like_button','1',0,''),(9998,3070,'94958','watch-mobile','padding-bottom','20',0,''),(9999,3071,'94959','watch-mobile','block_type','1',0,''),(10000,3072,'94960','watch-mobile','block_type','6',0,''),(10001,3072,'94960','watch-mobile','schema','6-3',0,''),(10002,3072,'94960','watch-mobile','schema','6-3',0,'299'),(10003,3073,'94961','watch-mobile','aria_name','account-menu',0,''),(10004,3074,'94962','watch-mobile','padding-top','15',0,''),(10005,3074,'94962','watch-mobile','padding-bottom','15',0,''),(10006,3074,'94962','watch-mobile','link','Address Book Process',0,''),(10007,3074,'94962','watch-mobile','text','EDIT',0,''),(10008,3074,'94962','watch-mobile','link_add','Address Book Process',0,''),(10009,3074,'94962','watch-mobile','like_button_add','2',0,''),(10010,3074,'94962','watch-mobile','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(10011,3075,'94963','watch-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1><div class=\"info-popup bottom-left\">\n<div><ul><li>##PRIMARY_ADDRESS##<br>##PRIMARY_ADDRESS_DESCRIPTION##<br></li><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(10012,3075,'94963','watch-mobile','text-align','center',0,''),(10013,3076,'94964','watch-mobile','block_type','1',0,''),(10014,3077,'94965','watch-mobile','block_type','6',0,''),(10015,3077,'94965','watch-mobile','schema','6-3',0,''),(10016,3077,'94965','watch-mobile','schema','6-3',0,'299'),(10017,3078,'94966','watch-mobile','aria_name','account-menu',0,''),(10018,3080,'94968','watch-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(10019,3081,'94969','watch-mobile','text','CANCEL',0,''),(10020,3081,'94969','watch-mobile','like_button','1',0,''),(10021,3081,'94969','watch-mobile','padding-bottom','20',0,''),(10022,3081,'94969','watch-mobile','link','Address Book',0,''),(10023,3082,'94970','watch-mobile','block_type','1',0,''),(10024,3082,'94970','watch-mobile','style_class','item-holder',0,''),(10025,3082,'94970','watch-mobile','padding-top','25',0,''),(10026,3082,'94970','watch-mobile','padding-bottom','25',0,''),(10027,3082,'94970','watch-mobile','text-align','left',0,''),(10028,3082,'94970','watch-mobile','border-top-color','$border-color-1',0,''),(10029,3082,'94970','watch-mobile','border-top-width','1',0,''),(10030,3083,'94971','watch-mobile','block_type','6',0,''),(10031,3084,'94972','watch-mobile','padding-right','20',0,''),(10032,3085,'94973','watch-mobile','clear','none',0,''),(10033,3087,'94975','watch-mobile','block_type','4',0,''),(10034,3088,'94976','watch-mobile','block_type','2',0,''),(10035,3089,'94977','watch-mobile','margin-bottom','7',0,''),(10036,3090,'94978','watch-mobile','clear','none',0,''),(10037,3091,'94979','watch-mobile','margin-bottom','20',0,''),(10038,3091,'94979','watch-mobile','text-align','right',0,''),(10039,3092,'94980','watch-mobile','description_characters','200',0,''),(10040,3092,'94980','watch-mobile','clear','none',0,''),(10041,3092,'94980','watch-mobile','padding-right','20',0,''),(10042,3093,'94981','watch-mobile','block_type','2',0,''),(10043,3094,'94982','watch-mobile','clear','none',0,''),(10044,3096,'94984','watch-mobile','padding-right','20',0,''),(10045,3097,'94985','watch-mobile','block_type','1',0,''),(10046,3097,'94985','watch-mobile','style_class','item-holder',0,''),(10047,3097,'94985','watch-mobile','padding-top','25',0,''),(10048,3097,'94985','watch-mobile','padding-left','25',0,''),(10049,3097,'94985','watch-mobile','padding-right','25',0,''),(10050,3097,'94985','watch-mobile','padding-bottom','25',0,''),(10051,3097,'94985','watch-mobile','text-align','left',0,''),(10052,3099,'94987','watch-mobile','margin-bottom','7',0,''),(10053,3100,'94988','watch-mobile','clear','both',0,''),(10054,3103,'94991','watch-mobile','block_type','1',0,''),(10055,3103,'94991','watch-mobile','style_class','item-holder',0,''),(10056,3103,'94991','watch-mobile','padding-top','25',0,''),(10057,3103,'94991','watch-mobile','padding-left','25',0,''),(10058,3103,'94991','watch-mobile','padding-right','25',0,''),(10059,3103,'94991','watch-mobile','padding-bottom','25',0,''),(10060,3103,'94991','watch-mobile','text-align','left',0,''),(10061,3104,'94992','watch-mobile','block_type','5',0,''),(10062,3107,'94995','watch-mobile','margin-bottom','7',0,''),(10063,3108,'94996','watch-mobile','clear','both',0,''),(10064,3109,'94997','watch-mobile','block_type','1',0,''),(10065,3110,'94998','watch-mobile','block_type','6',0,''),(10066,3110,'94998','watch-mobile','font-weight','400',0,''),(10067,3110,'94998','watch-mobile','schema','6-2',0,''),(10069,3111,'94999','watch-mobile','font-weight','400',0,''),(10070,3111,'94999','watch-mobile','padding-right','40',0,''),(10073,3112,'95000','watch-mobile','block_type','5',0,''),(10074,3112,'95000','watch-mobile','padding-top','10',0,''),(10075,3112,'95000','watch-mobile','padding-bottom','10',0,''),(10076,3112,'95000','watch-mobile','schema','5-2',0,''),(10077,3112,'95000','watch-mobile','border-top-color','$border-color-1',0,''),(10078,3112,'95000','watch-mobile','border-top-width','1',0,''),(10079,3114,'95002','watch-mobile','float','right',0,''),(10080,3116,'95004','watch-mobile','col_in_row','3',0,''),(10081,3116,'95004','watch-mobile','products_align','left',0,''),(10082,3116,'95004','watch-mobile','font-weight','400',0,''),(10083,3116,'95004','watch-mobile','show_qty_input','0',0,''),(10084,3116,'95004','watch-mobile','listing_type','productListing',0,''),(10085,3116,'95004','watch-mobile','listing_type_rows','no',0,''),(10086,3116,'95004','watch-mobile','show_buy_button_b2b','on',0,''),(10087,3116,'95004','watch-mobile','show_wishlist_button_b2b','1',0,''),(10088,3116,'95004','watch-mobile','show_compare_b2b','1',0,''),(10089,3116,'95004','watch-mobile','show_stock','0',0,''),(10090,3116,'95004','watch-mobile','show_description','0',0,''),(10091,3116,'95004','watch-mobile','show_model','0',0,''),(10092,3116,'95004','watch-mobile','show_properties','0',0,''),(10093,3116,'95004','watch-mobile','show_rating','0',0,''),(10094,3116,'95004','watch-mobile','show_rating_counts','0',0,''),(10095,3116,'95004','watch-mobile','show_price','0',0,''),(10096,3116,'95004','watch-mobile','show_buy_button','0',0,''),(10097,3116,'95004','watch-mobile','show_view_button','0',0,''),(10098,3116,'95004','watch-mobile','show_wishlist_button','0',0,''),(10099,3116,'95004','watch-mobile','show_compare','0',0,''),(10100,3116,'95004','watch-mobile','show_name_rows','0',0,''),(10101,3116,'95004','watch-mobile','show_image_rows','0',0,''),(10102,3116,'95004','watch-mobile','show_stock_rows','0',0,''),(10103,3116,'95004','watch-mobile','show_description_rows','0',0,''),(10104,3116,'95004','watch-mobile','show_model_rows','0',0,''),(10105,3116,'95004','watch-mobile','show_properties_rows','0',0,''),(10106,3116,'95004','watch-mobile','show_rating_rows','0',0,''),(10107,3116,'95004','watch-mobile','show_rating_counts_rows','0',0,''),(10108,3116,'95004','watch-mobile','show_price_rows','0',0,''),(10109,3116,'95004','watch-mobile','show_buy_button_rows','0',0,''),(10110,3116,'95004','watch-mobile','show_qty_input_rows','0',0,''),(10111,3116,'95004','watch-mobile','show_view_button_rows','0',0,''),(10112,3116,'95004','watch-mobile','show_wishlist_button_rows','0',0,''),(10113,3116,'95004','watch-mobile','show_compare_rows','0',0,''),(10114,3116,'95004','watch-mobile','show_name_b2b','0',0,''),(10115,3116,'95004','watch-mobile','show_image_b2b','0',0,''),(10116,3116,'95004','watch-mobile','show_stock_b2b','0',0,''),(10117,3116,'95004','watch-mobile','show_description_b2b','0',0,''),(10118,3116,'95004','watch-mobile','show_model_b2b','0',0,''),(10119,3116,'95004','watch-mobile','show_properties_b2b','0',0,''),(10120,3116,'95004','watch-mobile','show_rating_b2b','0',0,''),(10121,3116,'95004','watch-mobile','show_rating_counts_b2b','0',0,''),(10122,3116,'95004','watch-mobile','show_price_b2b','0',0,''),(10123,3116,'95004','watch-mobile','show_qty_input_b2b','0',0,''),(10124,3116,'95004','watch-mobile','show_view_button_b2b','0',0,''),(10125,3116,'95004','watch-mobile','show_attributes_b2b','0',0,''),(10126,3116,'95004','watch-mobile','items_on_page','9',0,''),(10129,3116,'95004','watch-mobile','product_names_teg','h2',0,''),(10130,3117,'95005','watch-mobile','listing_type','productListing',0,''),(10131,3118,'95006','watch-mobile','block_type','1',0,''),(10132,3118,'95006','watch-mobile','padding-top','10',0,''),(10133,3118,'95006','watch-mobile','padding-bottom','10',0,''),(10134,3118,'95006','watch-mobile','border-bottom-width','1',0,''),(10135,3118,'95006','watch-mobile','border-bottom-color','$border-color-1',0,''),(10136,3118,'95006','watch-mobile','margin-left','0',0,''),(10137,3118,'95006','watch-mobile','margin-right','0',0,''),(10138,3119,'95007','watch-mobile','float','right',0,''),(10139,3119,'95007','watch-mobile','display','none',0,''),(10140,3120,'95008','watch-mobile','margin-right','20',0,''),(10141,3120,'95008','watch-mobile','float','right',0,''),(10142,3120,'95008','watch-mobile','clear','none',0,''),(10143,3120,'95008','watch-mobile','display','none',0,''),(10144,3121,'95009','watch-mobile','float','left',0,''),(10145,3121,'95009','watch-mobile','clear','none',0,''),(10146,3121,'95009','watch-mobile','margin-left','20',0,''),(10147,3121,'95009','watch-mobile','display','none',0,''),(10148,3122,'95010','watch-mobile','float','left',0,''),(10149,3122,'95010','watch-mobile','clear','none',0,''),(10150,3122,'95010','watch-mobile','sort_pos_3','1',0,''),(10151,3122,'95010','watch-mobile','sort_pos_4','2',0,''),(10152,3122,'95010','watch-mobile','sort_pos_10','3',0,''),(10153,3122,'95010','watch-mobile','sort_pos_9','4',0,''),(10154,3122,'95010','watch-mobile','sort_pos_11','5',0,''),(10155,3122,'95010','watch-mobile','sort_pos_12','6',0,''),(10156,3122,'95010','watch-mobile','sort_pos_14','7',0,''),(10157,3122,'95010','watch-mobile','sort_pos_13','8',0,''),(10158,3122,'95010','watch-mobile','sort_pos_8','9',0,''),(10159,3122,'95010','watch-mobile','sort_pos_7','10',0,''),(10160,3122,'95010','watch-mobile','sort_pos_2','11',0,''),(10161,3122,'95010','watch-mobile','sort_pos_1','12',0,''),(10162,3122,'95010','watch-mobile','sort_pos_6','13',0,''),(10163,3122,'95010','watch-mobile','sort_pos_5','14',0,''),(10164,3122,'95010','watch-mobile','sort_pos_0','15',0,''),(10165,3122,'95010','watch-mobile','sort_hide_10','1',0,''),(10166,3122,'95010','watch-mobile','sort_hide_9','1',0,''),(10167,3122,'95010','watch-mobile','hide_icons','1',0,''),(10168,3122,'95010','watch-mobile','sort_hide_16','1',0,''),(10169,3122,'95010','watch-mobile','sort_hide_15','1',0,''),(10170,3122,'95010','watch-mobile','sort_hide_3','0',0,''),(10171,3122,'95010','watch-mobile','sort_hide_4','0',0,''),(10172,3122,'95010','watch-mobile','sort_hide_11','1',0,''),(10173,3122,'95010','watch-mobile','sort_hide_12','1',0,''),(10174,3122,'95010','watch-mobile','sort_hide_14','1',0,''),(10175,3122,'95010','watch-mobile','sort_hide_13','1',0,''),(10176,3122,'95010','watch-mobile','sort_hide_8','0',0,''),(10177,3122,'95010','watch-mobile','sort_hide_7','0',0,''),(10178,3122,'95010','watch-mobile','sort_hide_2','1',0,''),(10179,3122,'95010','watch-mobile','sort_hide_1','1',0,''),(10180,3122,'95010','watch-mobile','sort_hide_6','1',0,''),(10181,3122,'95010','watch-mobile','sort_hide_5','1',0,''),(10182,3122,'95010','watch-mobile','sort_hide_0','1',0,''),(10183,3125,'75559','watch-mobile','block_type','1',0,''),(10184,3126,'75560','watch-mobile','block_type','7',0,''),(10185,3126,'75560','watch-mobile','schema','7-2',0,'317'),(10186,3127,'75561','watch-mobile','padding-top','20',0,''),(10187,3127,'75561','watch-mobile','padding-right','20',0,''),(10188,3128,'75562','watch-mobile','blog_sidebar','1',0,''),(10189,3128,'75562','watch-mobile','padding-top','20',0,''),(10190,3128,'75562','watch-mobile','padding-left','20',0,''),(10191,3129,'113643','watch-mobile','block_type','1',0,''),(10192,3130,'113644','watch-mobile','item_tag','h2',0,''),(10193,3130,'113644','watch-mobile','hTagsInline','inline',0,''),(10194,3134,'115968','watch-mobile','block_type','1',0,''),(10195,3134,'115968','watch-mobile','schema','4-1',0,''),(10197,3134,'115968','watch-mobile','schema','4-1',0,'299'),(10198,3135,'115969','watch-mobile','block_type','1',0,''),(10199,3135,'115969','watch-mobile','background-color','$background-7',0,''),(10200,3135,'115969','watch-mobile','padding-top','20',0,''),(10201,3135,'115969','watch-mobile','padding-bottom','20',0,''),(10202,3135,'115969','watch-mobile','margin-bottom','30',0,''),(10203,3136,'115970','watch-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(10204,3136,'115970','watch-mobile','style_class','bell-ico',0,''),(10205,3137,'115971','watch-mobile','col_in_row','3',0,''),(10206,3137,'115971','watch-mobile','show_description','1',0,''),(10207,3137,'115971','watch-mobile','show_model','1',0,''),(10208,3137,'115971','watch-mobile','show_properties','1',0,''),(10209,3137,'115971','watch-mobile','show_rating','1',0,''),(10210,3137,'115971','watch-mobile','show_rating_counts','1',0,''),(10211,3137,'115971','watch-mobile','show_qty_input','1',0,''),(10212,3137,'115971','watch-mobile','show_view_button','1',0,''),(10213,3137,'115971','watch-mobile','show_wishlist_button','1',0,''),(10214,3137,'115971','watch-mobile','show_compare','1',0,''),(10215,3137,'115971','watch-mobile','view_as','carousel',0,''),(10216,3137,'115971','watch-mobile','hide_parents','2',0,''),(10217,3138,'115972','watch-mobile','block_type','1',0,''),(10218,3138,'115972','watch-mobile','background-color','$background-7',0,''),(10219,3138,'115972','watch-mobile','margin-bottom','30',0,''),(10220,3139,'115973','watch-mobile','padding-top','20',0,''),(10221,3139,'115973','watch-mobile','padding-bottom','20',0,''),(10222,3140,'115974','watch-mobile','block_type','2',0,''),(10223,3140,'115974','watch-mobile','padding-bottom','20',0,''),(10224,3140,'115974','watch-mobile','padding-top','20',0,''),(10225,3140,'115974','watch-mobile','border-bottom-color','$border-color-1',0,''),(10226,3140,'115974','watch-mobile','border-bottom-width','1',0,''),(10227,3140,'115974','watch-mobile','schema','2-2',0,''),(10228,3141,'115976','watch-mobile','padding-top','22',0,''),(10229,3142,'115977','watch-mobile','float','right',0,''),(10230,3142,'115977','watch-mobile','padding-top','26',0,''),(10231,3143,'115975','watch-mobile','float','left',0,''),(10232,3144,'115978','watch-mobile','block_type','1',0,''),(10233,3144,'115978','watch-mobile','padding-top','20',0,''),(10234,3144,'115978','watch-mobile','padding-bottom','20',0,''),(10235,3144,'115978','watch-mobile','background-color','$background-7',0,''),(10236,3144,'115978','watch-mobile','margin-bottom','30',0,''),(10237,3145,'115979','watch-mobile','hide_parents','2',0,''),(10238,3146,'115980','watch-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(10239,3147,'115981','watch-mobile','block_type','1',0,''),(10240,3147,'115981','watch-mobile','background-color','$background-7',0,''),(10241,3147,'115981','watch-mobile','padding-top','20',0,''),(10242,3147,'115981','watch-mobile','padding-bottom','20',0,''),(10243,3147,'115981','watch-mobile','margin-bottom','30',0,''),(10244,3147,'115981','watch-mobile','style_class','closeable-box',0,''),(10245,3148,'115982','watch-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(10246,3148,'115982','watch-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(10247,3149,'115983','watch-mobile','block_type','1',0,''),(10248,3149,'115983','watch-mobile','font-weight','400',0,''),(10249,3149,'115983','watch-mobile','schema','2-2',0,''),(10250,3149,'115983','watch-mobile','style_class','closeable-content',0,''),(10251,3149,'115983','watch-mobile','padding-top','10',0,''),(10252,3150,'115984','watch-mobile','font-weight','400',0,''),(10253,3150,'115984','watch-mobile','padding-top','12',0,''),(10254,3150,'115984','watch-mobile','padding-left','0',0,''),(10255,3153,'115987','watch-mobile','block_type','1',0,''),(10256,3153,'115987','watch-mobile','background-color','$background-7',0,''),(10257,3153,'115987','watch-mobile','padding-top','20',0,''),(10258,3153,'115987','watch-mobile','padding-left','25',0,''),(10259,3153,'115987','watch-mobile','padding-right','25',0,''),(10260,3153,'115987','watch-mobile','padding-bottom','20',0,''),(10261,3153,'115987','watch-mobile','margin-bottom','30',0,''),(10262,3153,'115987','watch-mobile','style_class','closeable-box',0,''),(10263,3153,'115987','watch-mobile','display','none',0,''),(10265,3154,'115988','watch-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(10266,3154,'115988','watch-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(10267,3155,'115989','watch-mobile','font-weight','normal',0,''),(10268,3155,'115989','watch-mobile','style_class','closeable-content',0,''),(10269,3155,'115989','watch-mobile','padding-top','10',0,''),(10270,3155,'115989','watch-mobile','hide_parents','2',0,''),(10271,3156,'115990','watch-mobile','style_class','order-summary',0,''),(10272,3156,'115990','watch-mobile','block_type','1',0,''),(10273,3156,'115990','watch-mobile','margin-left','30',0,''),(10275,3156,'115990','watch-mobile','margin-bottom','30',0,''),(10276,3157,'115991','watch-mobile','block_type','1',0,''),(10277,3157,'115991','watch-mobile','padding-bottom','20',0,''),(10278,3158,'115992','watch-mobile','font-weight','400',0,''),(10279,3158,'115992','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',1,''),(10280,3158,'115992','watch-mobile','padding-top','20',0,''),(10281,3158,'115992','watch-mobile','padding-bottom','10',0,''),(10282,3159,'115993','watch-mobile','font-weight','400',0,''),(10283,3159,'115993','watch-mobile','box_align','4',0,''),(10284,3159,'115993','watch-mobile','text-align','center',0,''),(10285,3159,'115993','watch-mobile','float','none',0,''),(10286,3159,'115993','watch-mobile','width','100',0,''),(10287,3159,'115993','watch-mobile','width_measure','%',0,''),(10288,3161,'115995','watch-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(10289,3162,'113648','watch-mobile','block_type','1',0,''),(10290,3162,'113648','watch-mobile','font-weight','normal',0,''),(10291,3162,'113648','watch-mobile','padding-top','20',0,''),(10292,3162,'113648','watch-mobile','background-color','$background-6',0,''),(10293,3164,'113650','watch-mobile','block_type','4',0,''),(10294,3164,'113650','watch-mobile','schema','4-1',0,''),(10296,3165,'113651','watch-mobile','block_type','1',0,''),(10297,3165,'113651','watch-mobile','background-color','$background-7',0,''),(10298,3165,'113651','watch-mobile','padding-top','20',0,''),(10299,3165,'113651','watch-mobile','padding-bottom','20',0,''),(10300,3165,'113651','watch-mobile','padding-left','25',0,''),(10301,3165,'113651','watch-mobile','padding-right','25',0,''),(10302,3165,'113651','watch-mobile','margin-bottom','30',0,''),(10303,3166,'113652','watch-mobile','col_in_row','3',0,''),(10304,3166,'113652','watch-mobile','show_description','1',0,''),(10305,3166,'113652','watch-mobile','show_model','1',0,''),(10306,3166,'113652','watch-mobile','show_properties','1',0,''),(10307,3166,'113652','watch-mobile','show_rating','1',0,''),(10308,3166,'113652','watch-mobile','show_rating_counts','1',0,''),(10309,3166,'113652','watch-mobile','show_qty_input','1',0,''),(10310,3166,'113652','watch-mobile','show_view_button','1',0,''),(10311,3166,'113652','watch-mobile','show_wishlist_button','1',0,''),(10312,3166,'113652','watch-mobile','show_compare','1',0,''),(10313,3166,'113652','watch-mobile','view_as','carousel',0,''),(10314,3166,'113652','watch-mobile','hide_parents','2',0,''),(10315,3167,'113653','watch-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(10316,3167,'113653','watch-mobile','style_class','bell-ico',0,''),(10317,3168,'113654','watch-mobile','block_type','1',0,''),(10318,3168,'113654','watch-mobile','background-color','$background-7',0,''),(10319,3168,'113654','watch-mobile','margin-bottom','30',0,''),(10320,3169,'113655','watch-mobile','padding-top','20',0,''),(10321,3169,'113655','watch-mobile','padding-left','25',0,''),(10322,3169,'113655','watch-mobile','padding-right','25',0,''),(10323,3169,'113655','watch-mobile','padding-bottom','20',0,''),(10324,3170,'113656','watch-mobile','block_type','2',0,''),(10325,3170,'113656','watch-mobile','padding-bottom','20',0,''),(10326,3170,'113656','watch-mobile','padding-top','20',0,''),(10327,3170,'113656','watch-mobile','padding-left','25',0,''),(10328,3170,'113656','watch-mobile','padding-right','25',0,''),(10329,3170,'113656','watch-mobile','border-bottom-color','$border-color-1',0,''),(10330,3170,'113656','watch-mobile','border-bottom-width','1',0,''),(10331,3170,'113656','watch-mobile','schema','2-2',0,''),(10332,3171,'113657','watch-mobile','float','left',0,''),(10333,3172,'113658','watch-mobile','text-align','right',0,''),(10334,3172,'113658','watch-mobile','clear','none',0,''),(10335,3172,'113658','watch-mobile','float','right',0,''),(10336,3172,'113658','watch-mobile','padding-top','22',0,''),(10337,3173,'113659','watch-mobile','float','right',0,''),(10338,3173,'113659','watch-mobile','padding-top','26',0,''),(10339,3174,'113660','watch-mobile','block_type','1',0,''),(10340,3174,'113660','watch-mobile','padding-top','20',0,''),(10341,3174,'113660','watch-mobile','padding-bottom','20',0,''),(10342,3174,'113660','watch-mobile','padding-left','25',0,''),(10343,3174,'113660','watch-mobile','padding-right','25',0,''),(10344,3174,'113660','watch-mobile','background-color','$background-7',0,''),(10345,3174,'113660','watch-mobile','margin-bottom','30',0,''),(10346,3175,'113661','watch-mobile','hide_parents','2',0,''),(10347,3176,'113662','watch-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(10348,3177,'113663','watch-mobile','block_type','1',0,''),(10349,3177,'113663','watch-mobile','background-color','$background-7',0,''),(10350,3177,'113663','watch-mobile','padding-top','20',0,''),(10351,3177,'113663','watch-mobile','padding-bottom','20',0,''),(10352,3177,'113663','watch-mobile','padding-left','25',0,''),(10353,3177,'113663','watch-mobile','padding-right','25',0,''),(10354,3177,'113663','watch-mobile','margin-bottom','30',0,''),(10355,3177,'113663','watch-mobile','style_class','closeable-box',0,''),(10356,3178,'113664','watch-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(10357,3178,'113664','watch-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(10358,3179,'113665','watch-mobile','block_type','3',0,''),(10359,3179,'113665','watch-mobile','font-weight','400',0,''),(10360,3179,'113665','watch-mobile','schema','2-2',0,''),(10361,3179,'113665','watch-mobile','style_class','closeable-content',0,''),(10362,3179,'113665','watch-mobile','padding-top','10',0,''),(10363,3180,'113666','watch-mobile','font-weight','400',0,''),(10364,3180,'113666','watch-mobile','padding-top','12',0,''),(10365,3180,'113666','watch-mobile','padding-left','0',0,''),(10366,3183,'113669','watch-mobile','block_type','1',0,''),(10367,3183,'113669','watch-mobile','background-color','$background-7',0,''),(10368,3183,'113669','watch-mobile','padding-top','20',0,''),(10369,3183,'113669','watch-mobile','padding-left','25',0,''),(10370,3183,'113669','watch-mobile','padding-right','25',0,''),(10371,3183,'113669','watch-mobile','padding-bottom','20',0,''),(10372,3183,'113669','watch-mobile','margin-bottom','30',0,''),(10373,3183,'113669','watch-mobile','style_class','closeable-box',0,''),(10374,3183,'113669','watch-mobile','display','none',0,''),(10376,3184,'113670','watch-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(10377,3184,'113670','watch-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(10378,3185,'113671','watch-mobile','font-weight','normal',0,''),(10379,3185,'113671','watch-mobile','style_class','closeable-content',0,''),(10380,3185,'113671','watch-mobile','padding-top','10',0,''),(10381,3185,'113671','watch-mobile','hide_parents','2',0,''),(10382,3186,'113672','watch-mobile','style_class','order-summary',0,''),(10383,3186,'113672','watch-mobile','block_type','1',0,''),(10384,3186,'113672','watch-mobile','margin-left','30',0,''),(10386,3186,'113672','watch-mobile','margin-bottom','30',0,''),(10387,3187,'113673','watch-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(10388,3188,'113674','watch-mobile','block_type','1',0,''),(10389,3188,'113674','watch-mobile','padding-left','20',0,''),(10390,3188,'113674','watch-mobile','padding-right','20',0,''),(10391,3188,'113674','watch-mobile','padding-bottom','20',0,''),(10392,3189,'113675','watch-mobile','font-weight','400',0,''),(10393,3189,'113675','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',1,''),(10394,3189,'113675','watch-mobile','padding-top','20',0,''),(10395,3189,'113675','watch-mobile','padding-bottom','10',0,''),(10396,3190,'113676','watch-mobile','font-weight','400',0,''),(10397,3190,'113676','watch-mobile','box_align','4',0,''),(10398,3190,'113676','watch-mobile','text-align','center',0,''),(10399,3190,'113676','watch-mobile','float','none',0,''),(10400,3190,'113676','watch-mobile','width','100',0,''),(10401,3190,'113676','watch-mobile','width_measure','%',0,''),(10402,3192,'75585','watch-mobile','block_type','1',0,''),(10403,3195,'75588','watch-mobile','block_type','1',0,''),(10404,3196,'75589','watch-mobile','col_in_row','2',0,''),(10405,3196,'75589','watch-mobile','products_align','left',0,''),(10406,3196,'75589','watch-mobile','font-weight','400',0,''),(10407,3196,'75589','watch-mobile','show_qty_input','1',0,''),(10408,3196,'75589','watch-mobile','listing_type','productListing',0,''),(10409,3196,'75589','watch-mobile','listing_type_rows','type-1_2',0,''),(10410,3196,'75589','watch-mobile','show_buy_button_b2b','on',0,''),(10411,3196,'75589','watch-mobile','show_wishlist_button_b2b','1',0,''),(10412,3196,'75589','watch-mobile','show_compare_b2b','1',0,''),(10413,3196,'75589','watch-mobile','listing_type_b2b','type-1_3',0,''),(10414,3196,'75589','watch-mobile','show_name','0',0,''),(10415,3196,'75589','watch-mobile','show_image','0',0,''),(10416,3196,'75589','watch-mobile','show_stock','0',0,''),(10417,3196,'75589','watch-mobile','show_description','1',0,''),(10418,3196,'75589','watch-mobile','show_model','1',0,''),(10419,3196,'75589','watch-mobile','show_properties','1',0,''),(10420,3196,'75589','watch-mobile','show_rating_counts','1',0,''),(10421,3196,'75589','watch-mobile','show_price','0',0,''),(10422,3196,'75589','watch-mobile','show_buy_button','1',0,''),(10423,3196,'75589','watch-mobile','show_view_button','1',0,''),(10424,3196,'75589','watch-mobile','show_wishlist_button','1',0,''),(10425,3196,'75589','watch-mobile','show_compare','1',0,''),(10426,3196,'75589','watch-mobile','show_name_rows','0',0,''),(10427,3196,'75589','watch-mobile','show_image_rows','0',0,''),(10428,3196,'75589','watch-mobile','show_stock_rows','0',0,''),(10429,3196,'75589','watch-mobile','show_description_rows','0',0,''),(10430,3196,'75589','watch-mobile','show_model_rows','0',0,''),(10431,3196,'75589','watch-mobile','show_properties_rows','0',0,''),(10432,3196,'75589','watch-mobile','show_rating_rows','0',0,''),(10433,3196,'75589','watch-mobile','show_rating_counts_rows','0',0,''),(10434,3196,'75589','watch-mobile','show_price_rows','0',0,''),(10435,3196,'75589','watch-mobile','show_buy_button_rows','0',0,''),(10436,3196,'75589','watch-mobile','show_qty_input_rows','0',0,''),(10437,3196,'75589','watch-mobile','show_view_button_rows','0',0,''),(10438,3196,'75589','watch-mobile','show_wishlist_button_rows','0',0,''),(10439,3196,'75589','watch-mobile','show_compare_rows','0',0,''),(10440,3196,'75589','watch-mobile','show_name_b2b','0',0,''),(10441,3196,'75589','watch-mobile','show_image_b2b','0',0,''),(10442,3196,'75589','watch-mobile','show_stock_b2b','0',0,''),(10443,3196,'75589','watch-mobile','show_description_b2b','0',0,''),(10444,3196,'75589','watch-mobile','show_model_b2b','0',0,''),(10445,3196,'75589','watch-mobile','show_properties_b2b','0',0,''),(10446,3196,'75589','watch-mobile','show_rating_b2b','0',0,''),(10447,3196,'75589','watch-mobile','show_rating_counts_b2b','0',0,''),(10448,3196,'75589','watch-mobile','show_price_b2b','0',0,''),(10449,3196,'75589','watch-mobile','show_qty_input_b2b','0',0,''),(10450,3196,'75589','watch-mobile','show_view_button_b2b','0',0,''),(10451,3196,'75589','watch-mobile','show_attributes_b2b','0',0,''),(10452,3196,'75589','watch-mobile','items_on_page','10',0,''),(10453,3196,'75589','watch-mobile','product_names_teg','h2',0,''),(10454,3197,'75590','watch-mobile','block_type','2',0,''),(10455,3197,'75590','watch-mobile','margin-bottom','20',0,''),(10456,3198,'75591','watch-mobile','sort_pos_3','1',0,''),(10457,3198,'75591','watch-mobile','sort_pos_4','2',0,''),(10458,3198,'75591','watch-mobile','sort_pos_10','5',0,''),(10459,3198,'75591','watch-mobile','sort_pos_9','6',0,''),(10460,3198,'75591','watch-mobile','sort_pos_11','7',0,''),(10461,3198,'75591','watch-mobile','sort_pos_12','8',0,''),(10462,3198,'75591','watch-mobile','sort_pos_14','9',0,''),(10463,3198,'75591','watch-mobile','sort_pos_13','10',0,''),(10464,3198,'75591','watch-mobile','sort_pos_8','11',0,''),(10465,3198,'75591','watch-mobile','sort_pos_7','12',0,''),(10466,3198,'75591','watch-mobile','sort_pos_2','13',0,''),(10467,3198,'75591','watch-mobile','sort_pos_1','14',0,''),(10468,3198,'75591','watch-mobile','sort_pos_6','15',0,''),(10469,3198,'75591','watch-mobile','sort_pos_5','16',0,''),(10470,3198,'75591','watch-mobile','sort_pos_0','17',0,''),(10471,3198,'75591','watch-mobile','sort_hide_10','1',0,''),(10472,3198,'75591','watch-mobile','sort_hide_9','1',0,''),(10473,3198,'75591','watch-mobile','sort_pos_15','4',0,''),(10474,3198,'75591','watch-mobile','sort_pos_16','3',0,''),(10475,3198,'75591','watch-mobile','sort_hide_3','0',0,''),(10476,3198,'75591','watch-mobile','sort_hide_4','0',0,''),(10477,3198,'75591','watch-mobile','sort_hide_16','1',0,''),(10478,3198,'75591','watch-mobile','sort_hide_15','1',0,''),(10479,3198,'75591','watch-mobile','sort_hide_11','0',0,''),(10480,3198,'75591','watch-mobile','sort_hide_12','0',0,''),(10481,3198,'75591','watch-mobile','sort_hide_14','0',0,''),(10482,3198,'75591','watch-mobile','sort_hide_13','0',0,''),(10483,3198,'75591','watch-mobile','sort_hide_8','0',0,''),(10484,3198,'75591','watch-mobile','sort_hide_7','0',0,''),(10485,3198,'75591','watch-mobile','sort_hide_2','0',0,''),(10486,3198,'75591','watch-mobile','sort_hide_1','0',0,''),(10487,3198,'75591','watch-mobile','sort_hide_6','0',0,''),(10488,3198,'75591','watch-mobile','sort_hide_5','0',0,''),(10489,3198,'75591','watch-mobile','sort_hide_0','0',0,''),(10490,3199,'75592','watch-mobile','text-align','right',0,''),(10491,3199,'75592','watch-mobile','padding-top','10',0,''),(10492,3200,'75593','watch-mobile','text-align','center',0,''),(10493,3200,'75593','watch-mobile','margin-bottom','20',0,''),(10494,3206,'113678','watch-mobile','block_type','1',0,''),(10495,3208,'113680','watch-mobile','block_type','6',0,''),(10496,3208,'113680','watch-mobile','font-weight','400',0,''),(10497,3208,'113680','watch-mobile','schema','6-2',0,''),(10499,3209,'113681','watch-mobile','font-weight','400',0,''),(10500,3209,'113681','watch-mobile','padding-right','40',0,''),(10503,3211,'113683','watch-mobile','col_in_row','3',0,''),(10504,3211,'113683','watch-mobile','products_align','left',0,''),(10505,3211,'113683','watch-mobile','font-weight','400',0,''),(10506,3211,'113683','watch-mobile','show_qty_input','0',0,''),(10507,3211,'113683','watch-mobile','listing_type','productListing',0,''),(10508,3211,'113683','watch-mobile','listing_type_rows','no',0,''),(10509,3211,'113683','watch-mobile','show_buy_button_b2b','on',0,''),(10510,3211,'113683','watch-mobile','show_wishlist_button_b2b','1',0,''),(10511,3211,'113683','watch-mobile','show_compare_b2b','1',0,''),(10512,3211,'113683','watch-mobile','show_stock','0',0,''),(10513,3211,'113683','watch-mobile','show_description','0',0,''),(10514,3211,'113683','watch-mobile','show_model','0',0,''),(10515,3211,'113683','watch-mobile','show_properties','0',0,''),(10516,3211,'113683','watch-mobile','show_rating','0',0,''),(10517,3211,'113683','watch-mobile','show_rating_counts','0',0,''),(10518,3211,'113683','watch-mobile','show_price','0',0,''),(10519,3211,'113683','watch-mobile','show_buy_button','0',0,''),(10520,3211,'113683','watch-mobile','show_view_button','0',0,''),(10521,3211,'113683','watch-mobile','show_wishlist_button','0',0,''),(10522,3211,'113683','watch-mobile','show_compare','0',0,''),(10523,3211,'113683','watch-mobile','show_name_rows','0',0,''),(10524,3211,'113683','watch-mobile','show_image_rows','0',0,''),(10525,3211,'113683','watch-mobile','show_stock_rows','0',0,''),(10526,3211,'113683','watch-mobile','show_description_rows','0',0,''),(10527,3211,'113683','watch-mobile','show_model_rows','0',0,''),(10528,3211,'113683','watch-mobile','show_properties_rows','0',0,''),(10529,3211,'113683','watch-mobile','show_rating_rows','0',0,''),(10530,3211,'113683','watch-mobile','show_rating_counts_rows','0',0,''),(10531,3211,'113683','watch-mobile','show_price_rows','0',0,''),(10532,3211,'113683','watch-mobile','show_buy_button_rows','0',0,''),(10533,3211,'113683','watch-mobile','show_qty_input_rows','0',0,''),(10534,3211,'113683','watch-mobile','show_view_button_rows','0',0,''),(10535,3211,'113683','watch-mobile','show_wishlist_button_rows','0',0,''),(10536,3211,'113683','watch-mobile','show_compare_rows','0',0,''),(10537,3211,'113683','watch-mobile','show_name_b2b','0',0,''),(10538,3211,'113683','watch-mobile','show_image_b2b','0',0,''),(10539,3211,'113683','watch-mobile','show_stock_b2b','0',0,''),(10540,3211,'113683','watch-mobile','show_description_b2b','0',0,''),(10541,3211,'113683','watch-mobile','show_model_b2b','0',0,''),(10542,3211,'113683','watch-mobile','show_properties_b2b','0',0,''),(10543,3211,'113683','watch-mobile','show_rating_b2b','0',0,''),(10544,3211,'113683','watch-mobile','show_rating_counts_b2b','0',0,''),(10545,3211,'113683','watch-mobile','show_price_b2b','0',0,''),(10546,3211,'113683','watch-mobile','show_qty_input_b2b','0',0,''),(10547,3211,'113683','watch-mobile','show_view_button_b2b','0',0,''),(10548,3211,'113683','watch-mobile','show_attributes_b2b','0',0,''),(10549,3211,'113683','watch-mobile','items_on_page','9',0,''),(10552,3211,'113683','watch-mobile','product_names_teg','h2',0,''),(10553,3212,'113684','watch-mobile','block_type','1',0,''),(10554,3212,'113684','watch-mobile','padding-top','10',0,''),(10555,3212,'113684','watch-mobile','padding-bottom','10',0,''),(10556,3212,'113684','watch-mobile','border-bottom-width','1',0,''),(10557,3212,'113684','watch-mobile','border-bottom-color','$border-color-1',0,''),(10558,3212,'113684','watch-mobile','margin-left','0',0,''),(10559,3212,'113684','watch-mobile','margin-right','0',0,''),(10560,3213,'113685','watch-mobile','float','left',0,''),(10561,3213,'113685','watch-mobile','clear','none',0,''),(10562,3213,'113685','watch-mobile','sort_pos_3','1',0,''),(10563,3213,'113685','watch-mobile','sort_pos_4','2',0,''),(10564,3213,'113685','watch-mobile','sort_pos_10','3',0,''),(10565,3213,'113685','watch-mobile','sort_pos_9','4',0,''),(10566,3213,'113685','watch-mobile','sort_pos_11','5',0,''),(10567,3213,'113685','watch-mobile','sort_pos_12','6',0,''),(10568,3213,'113685','watch-mobile','sort_pos_14','7',0,''),(10569,3213,'113685','watch-mobile','sort_pos_13','8',0,''),(10570,3213,'113685','watch-mobile','sort_pos_8','9',0,''),(10571,3213,'113685','watch-mobile','sort_pos_7','10',0,''),(10572,3213,'113685','watch-mobile','sort_pos_2','11',0,''),(10573,3213,'113685','watch-mobile','sort_pos_1','12',0,''),(10574,3213,'113685','watch-mobile','sort_pos_6','13',0,''),(10575,3213,'113685','watch-mobile','sort_pos_5','14',0,''),(10576,3213,'113685','watch-mobile','sort_pos_0','15',0,''),(10577,3213,'113685','watch-mobile','sort_hide_10','1',0,''),(10578,3213,'113685','watch-mobile','sort_hide_9','1',0,''),(10579,3213,'113685','watch-mobile','hide_icons','1',0,''),(10580,3213,'113685','watch-mobile','sort_hide_16','1',0,''),(10581,3213,'113685','watch-mobile','sort_hide_15','1',0,''),(10582,3213,'113685','watch-mobile','sort_hide_3','0',0,''),(10583,3213,'113685','watch-mobile','sort_hide_4','0',0,''),(10584,3213,'113685','watch-mobile','sort_hide_11','1',0,''),(10585,3213,'113685','watch-mobile','sort_hide_12','1',0,''),(10586,3213,'113685','watch-mobile','sort_hide_14','1',0,''),(10587,3213,'113685','watch-mobile','sort_hide_13','1',0,''),(10588,3213,'113685','watch-mobile','sort_hide_8','0',0,''),(10589,3213,'113685','watch-mobile','sort_hide_7','0',0,''),(10590,3213,'113685','watch-mobile','sort_hide_2','1',0,''),(10591,3213,'113685','watch-mobile','sort_hide_1','1',0,''),(10592,3213,'113685','watch-mobile','sort_hide_6','1',0,''),(10593,3213,'113685','watch-mobile','sort_hide_5','1',0,''),(10594,3213,'113685','watch-mobile','sort_hide_0','1',0,''),(10595,3214,'113686','watch-mobile','float','left',0,''),(10596,3214,'113686','watch-mobile','clear','none',0,''),(10597,3214,'113686','watch-mobile','margin-left','20',0,''),(10598,3214,'113686','watch-mobile','display','none',0,''),(10599,3215,'113687','watch-mobile','margin-right','20',0,''),(10600,3215,'113687','watch-mobile','float','right',0,''),(10601,3215,'113687','watch-mobile','clear','none',0,''),(10602,3215,'113687','watch-mobile','display','none',0,''),(10603,3216,'113688','watch-mobile','float','right',0,''),(10604,3216,'113688','watch-mobile','display','none',0,''),(10605,3217,'113689','watch-mobile','listing_type','productListing',0,''),(10606,3219,'113691','watch-mobile','block_type','5',0,''),(10607,3219,'113691','watch-mobile','padding-top','10',0,''),(10608,3219,'113691','watch-mobile','padding-bottom','10',0,''),(10609,3219,'113691','watch-mobile','schema','5-2',0,''),(10610,3219,'113691','watch-mobile','border-top-color','$border-color-1',0,''),(10611,3219,'113691','watch-mobile','border-top-width','1',0,''),(10612,3221,'113693','watch-mobile','float','right',0,''),(10613,3222,'113694','watch-mobile','block_type','1',0,''),(10614,3224,'113696','watch-mobile','block_type','5',0,''),(10615,3224,'113696','watch-mobile','padding-top','10',0,''),(10616,3224,'113696','watch-mobile','padding-bottom','10',0,''),(10617,3224,'113696','watch-mobile','schema','5-2',0,''),(10618,3224,'113696','watch-mobile','border-top-color','$border-color-1',0,''),(10619,3224,'113696','watch-mobile','border-top-width','1',0,''),(10620,3226,'113698','watch-mobile','float','right',0,''),(10621,3227,'113699','watch-mobile','col_in_row','4',0,''),(10622,3227,'113699','watch-mobile','products_align','left',0,''),(10623,3227,'113699','watch-mobile','font-weight','400',0,''),(10624,3227,'113699','watch-mobile','show_qty_input','0',0,''),(10625,3227,'113699','watch-mobile','listing_type','productListing',0,''),(10626,3227,'113699','watch-mobile','listing_type_rows','Rows',0,''),(10627,3227,'113699','watch-mobile','show_buy_button_b2b','on',0,''),(10628,3227,'113699','watch-mobile','show_wishlist_button_b2b','1',0,''),(10629,3227,'113699','watch-mobile','show_compare_b2b','1',0,''),(10630,3227,'113699','watch-mobile','listing_type_b2b','b2b',0,''),(10631,3227,'113699','watch-mobile','show_image','0',0,''),(10632,3227,'113699','watch-mobile','show_stock','0',0,''),(10633,3227,'113699','watch-mobile','show_description','0',0,''),(10634,3227,'113699','watch-mobile','show_model','0',0,''),(10635,3227,'113699','watch-mobile','show_properties','0',0,''),(10636,3227,'113699','watch-mobile','show_rating','0',0,''),(10637,3227,'113699','watch-mobile','show_rating_counts','0',0,''),(10638,3227,'113699','watch-mobile','show_price','0',0,''),(10639,3227,'113699','watch-mobile','show_buy_button','0',0,''),(10640,3227,'113699','watch-mobile','show_view_button','0',0,''),(10641,3227,'113699','watch-mobile','show_wishlist_button','0',0,''),(10642,3227,'113699','watch-mobile','show_compare','0',0,''),(10643,3227,'113699','watch-mobile','show_name_rows','0',0,''),(10644,3227,'113699','watch-mobile','show_image_rows','0',0,''),(10645,3227,'113699','watch-mobile','show_stock_rows','0',0,''),(10646,3227,'113699','watch-mobile','show_description_rows','0',0,''),(10647,3227,'113699','watch-mobile','show_model_rows','0',0,''),(10648,3227,'113699','watch-mobile','show_properties_rows','0',0,''),(10649,3227,'113699','watch-mobile','show_rating_rows','0',0,''),(10650,3227,'113699','watch-mobile','show_rating_counts_rows','0',0,''),(10651,3227,'113699','watch-mobile','show_price_rows','0',0,''),(10652,3227,'113699','watch-mobile','show_buy_button_rows','0',0,''),(10653,3227,'113699','watch-mobile','show_qty_input_rows','0',0,''),(10654,3227,'113699','watch-mobile','show_view_button_rows','0',0,''),(10655,3227,'113699','watch-mobile','show_wishlist_button_rows','0',0,''),(10656,3227,'113699','watch-mobile','show_compare_rows','0',0,''),(10657,3227,'113699','watch-mobile','show_name_b2b','0',0,''),(10658,3227,'113699','watch-mobile','show_image_b2b','0',0,''),(10659,3227,'113699','watch-mobile','show_stock_b2b','0',0,''),(10660,3227,'113699','watch-mobile','show_description_b2b','0',0,''),(10661,3227,'113699','watch-mobile','show_model_b2b','0',0,''),(10662,3227,'113699','watch-mobile','show_properties_b2b','0',0,''),(10663,3227,'113699','watch-mobile','show_rating_b2b','0',0,''),(10664,3227,'113699','watch-mobile','show_rating_counts_b2b','0',0,''),(10665,3227,'113699','watch-mobile','show_price_b2b','0',0,''),(10666,3227,'113699','watch-mobile','show_qty_input_b2b','0',0,''),(10667,3227,'113699','watch-mobile','show_view_button_b2b','0',0,''),(10668,3227,'113699','watch-mobile','show_attributes_b2b','0',0,''),(10669,3227,'113699','watch-mobile','items_on_page','12',0,''),(10672,3227,'113699','watch-mobile','product_names_teg','h2',0,''),(10674,3229,'113701','watch-mobile','block_type','1',0,''),(10675,3229,'113701','watch-mobile','padding-top','10',0,''),(10676,3229,'113701','watch-mobile','padding-bottom','10',0,''),(10677,3229,'113701','watch-mobile','border-bottom-width','1',0,''),(10678,3229,'113701','watch-mobile','border-bottom-color','$border-color-1',0,''),(10679,3229,'113701','watch-mobile','margin-left','0',0,''),(10680,3229,'113701','watch-mobile','margin-right','0',0,''),(10681,3230,'113702','watch-mobile','float','right',0,''),(10682,3230,'113702','watch-mobile','display','none',0,''),(10683,3231,'113703','watch-mobile','margin-right','20',0,''),(10684,3231,'113703','watch-mobile','float','right',0,''),(10685,3231,'113703','watch-mobile','clear','none',0,''),(10686,3231,'113703','watch-mobile','display','none',0,''),(10687,3232,'113704','watch-mobile','clear','none',0,''),(10688,3232,'113704','watch-mobile','float','left',0,''),(10689,3232,'113704','watch-mobile','padding-top','3',0,''),(10690,3232,'113704','watch-mobile','padding-left','20',0,''),(10691,3233,'113705','watch-mobile','float','left',0,''),(10692,3233,'113705','watch-mobile','clear','none',0,''),(10693,3233,'113705','watch-mobile','margin-left','20',0,''),(10694,3233,'113705','watch-mobile','display','none',0,''),(10695,3234,'113706','watch-mobile','float','left',0,''),(10696,3234,'113706','watch-mobile','clear','none',0,''),(10697,3234,'113706','watch-mobile','sort_pos_3','1',0,''),(10698,3234,'113706','watch-mobile','sort_pos_4','2',0,''),(10699,3234,'113706','watch-mobile','sort_pos_10','3',0,''),(10700,3234,'113706','watch-mobile','sort_pos_9','4',0,''),(10701,3234,'113706','watch-mobile','sort_pos_11','5',0,''),(10702,3234,'113706','watch-mobile','sort_pos_12','6',0,''),(10703,3234,'113706','watch-mobile','sort_pos_14','7',0,''),(10704,3234,'113706','watch-mobile','sort_pos_13','8',0,''),(10705,3234,'113706','watch-mobile','sort_pos_8','9',0,''),(10706,3234,'113706','watch-mobile','sort_pos_7','10',0,''),(10707,3234,'113706','watch-mobile','sort_pos_2','11',0,''),(10708,3234,'113706','watch-mobile','sort_pos_1','12',0,''),(10709,3234,'113706','watch-mobile','sort_pos_6','13',0,''),(10710,3234,'113706','watch-mobile','sort_pos_5','14',0,''),(10711,3234,'113706','watch-mobile','sort_pos_0','15',0,''),(10712,3234,'113706','watch-mobile','sort_hide_10','1',0,''),(10713,3234,'113706','watch-mobile','sort_hide_9','1',0,''),(10714,3234,'113706','watch-mobile','hide_icons','1',0,''),(10715,3234,'113706','watch-mobile','sort_hide_16','1',0,''),(10716,3234,'113706','watch-mobile','sort_hide_15','1',0,''),(10717,3234,'113706','watch-mobile','sort_hide_3','0',0,''),(10718,3234,'113706','watch-mobile','sort_hide_4','0',0,''),(10719,3234,'113706','watch-mobile','sort_hide_11','1',0,''),(10720,3234,'113706','watch-mobile','sort_hide_12','1',0,''),(10721,3234,'113706','watch-mobile','sort_hide_14','1',0,''),(10722,3234,'113706','watch-mobile','sort_hide_13','1',0,''),(10723,3234,'113706','watch-mobile','sort_hide_8','0',0,''),(10724,3234,'113706','watch-mobile','sort_hide_7','0',0,''),(10725,3234,'113706','watch-mobile','sort_hide_2','1',0,''),(10726,3234,'113706','watch-mobile','sort_hide_1','1',0,''),(10727,3234,'113706','watch-mobile','sort_hide_6','1',0,''),(10728,3234,'113706','watch-mobile','sort_hide_5','1',0,''),(10729,3234,'113706','watch-mobile','sort_hide_0','1',0,''),(10873,3281,'113753','watch-mobile','block_type','1',0,''),(10874,3282,'113754','watch-mobile','margin-bottom','20',0,''),(10875,3282,'113754','watch-mobile','text-align','center',0,''),(10876,3284,'113756','watch-mobile','block_type','1',0,''),(10877,3284,'113756','watch-mobile','margin-bottom','20',0,''),(10878,3284,'113756','watch-mobile','schema','2-2',0,''),(10879,3285,'113757','watch-mobile','block_type','1',0,''),(10882,3286,'113758','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(10883,3286,'113758','watch-mobile','clear','none',0,''),(10884,3288,'113760','watch-mobile','block_type','1',0,''),(10887,3289,'113761','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(10888,3289,'113761','watch-mobile','clear','none',0,''),(10889,3291,'113763','watch-mobile','text-align','center',0,''),(10890,3291,'113763','watch-mobile','margin-bottom','20',0,''),(10891,3292,'113764','watch-mobile','block_type','1',0,''),(10892,3292,'113764','watch-mobile','margin-bottom','20',0,''),(10893,3292,'113764','watch-mobile','schema','2-2',0,''),(10894,3293,'113765','watch-mobile','block_type','1',0,''),(10897,3294,'113766','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(10898,3294,'113766','watch-mobile','clear','none',0,''),(10900,3296,'113768','watch-mobile','block_type','1',0,''),(10902,3298,'113770','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(10903,3298,'113770','watch-mobile','clear','none',0,''),(10904,3299,'113771','watch-mobile','link','products',0,''),(10905,3299,'113771','watch-mobile','margin-top','-33',0,''),(10906,3299,'113771','watch-mobile','float','right',0,''),(10907,3301,'113773','watch-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(10908,3302,'113774','watch-mobile','block_type','1',0,''),(10909,3303,'113775','watch-mobile','margin-bottom','20',0,''),(10910,3304,'113776','watch-mobile','text-align','right',0,''),(10911,3304,'113776','watch-mobile','margin-bottom','20',0,''),(10912,3305,'113777','watch-mobile','block_type','2',0,''),(10913,3305,'113777','watch-mobile','margin-bottom','20',0,''),(10914,3305,'113777','watch-mobile','schema','2-2',0,''),(10915,3306,'113778','watch-mobile','block_type','1',0,''),(10916,3306,'113778','watch-mobile','padding-right','20',0,''),(10918,3307,'113779','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(10919,3307,'113779','watch-mobile','clear','none',0,''),(10920,3309,'113781','watch-mobile','block_type','1',0,''),(10921,3309,'113781','watch-mobile','padding-left','20',0,''),(10923,3310,'113782','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(10924,3310,'113782','watch-mobile','clear','none',0,''),(10925,3312,'113784','watch-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(10926,3313,'113785','watch-mobile','margin-bottom','20',0,''),(10927,3314,'113786','watch-mobile','margin-bottom','20',0,''),(10928,3314,'113786','watch-mobile','text-align','right',0,''),(10929,3315,'113787','watch-mobile','block_type','1',0,''),(10930,3316,'113788','watch-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(10931,3317,'113789','watch-mobile','margin-bottom','20',0,''),(10932,3317,'113789','watch-mobile','text-align','right',0,''),(10933,3320,'113792','watch-mobile','text-align','right',0,''),(10934,3320,'113792','watch-mobile','margin-bottom','20',0,''),(10935,3321,'113793','watch-mobile','block_type','2',0,''),(10936,3321,'113793','watch-mobile','margin-bottom','20',0,''),(10937,3321,'113793','watch-mobile','schema','2-2',0,''),(10938,3322,'113794','watch-mobile','block_type','1',0,''),(10939,3322,'113794','watch-mobile','padding-right','20',0,''),(10941,3324,'113796','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(10942,3324,'113796','watch-mobile','clear','none',0,''),(10943,3325,'113797','watch-mobile','block_type','1',0,''),(10944,3325,'113797','watch-mobile','padding-left','20',0,''),(10946,3326,'113798','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(10947,3326,'113798','watch-mobile','clear','none',0,''),(10948,3328,'113800','watch-mobile','block_type','1',0,''),(10949,3329,'113801','watch-mobile','block_type','2',0,''),(10950,3329,'113801','watch-mobile','margin-bottom','20',0,''),(10951,3329,'113801','watch-mobile','schema','2-2',0,''),(10952,3330,'113802','watch-mobile','block_type','1',0,''),(10953,3330,'113802','watch-mobile','padding-right','20',0,''),(10955,3332,'113804','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(10956,3332,'113804','watch-mobile','clear','none',0,''),(10957,3333,'113805','watch-mobile','padding-left','20',0,''),(10958,3333,'113805','watch-mobile','block_type','1',0,''),(10960,3334,'113806','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(10961,3334,'113806','watch-mobile','clear','none',0,''),(10962,3336,'113808','watch-mobile','text-align','right',0,''),(10963,3336,'113808','watch-mobile','margin-bottom','20',0,''),(10964,3337,'113809','watch-mobile','margin-bottom','20',0,''),(10965,3337,'113809','watch-mobile','text-align','right',0,''),(10966,3338,'113810','watch-mobile','link','products',0,''),(10967,3338,'113810','watch-mobile','margin-top','-33',0,''),(10968,3338,'113810','watch-mobile','float','right',0,''),(10969,3339,'113811','watch-mobile','margin-bottom','20',0,''),(10970,3340,'113812','watch-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(10971,3341,'113813','watch-mobile','margin-bottom','20',0,''),(10972,3342,'113814','watch-mobile','block_type','2',0,''),(10973,3342,'113814','watch-mobile','margin-bottom','20',0,''),(10974,3342,'113814','watch-mobile','schema','2-2',0,''),(10975,3343,'113815','watch-mobile','block_type','1',0,''),(10976,3343,'113815','watch-mobile','padding-right','20',0,''),(10978,3345,'113817','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(10979,3345,'113817','watch-mobile','clear','none',0,''),(10980,3346,'113818','watch-mobile','block_type','1',0,''),(10981,3346,'113818','watch-mobile','padding-left','20',0,''),(10983,3347,'113819','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(10984,3347,'113819','watch-mobile','clear','none',0,''),(10985,3349,'113821','watch-mobile','text','##TEXT_CONFIRMATION##',0,''),(10986,3350,'113822','watch-mobile','text','##TEXT_CONFIRMATION##',0,''),(10987,3351,'113823','watch-mobile','text','##TEXT_CONFIRMATION##',0,''),(10988,3352,'113824','watch-mobile','text','##TEXT_CONFIRMATION##',0,''),(10989,3353,'113825','watch-mobile','text','##TEXT_CONFIRMATION##',0,''),(10990,3354,'113826','watch-mobile','text','##TEXT_CONFIRMATION##',0,''),(10991,3355,'113827','watch-mobile','block_type','1',0,''),(10992,3356,'113828','watch-mobile','block_type','1',0,''),(10996,3359,'113831','watch-mobile','block_type','1',0,''),(10997,3359,'113831','watch-mobile','padding-right','0',0,''),(10999,3361,'113833','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(11000,3364,'113836','watch-mobile','block_type','1',0,''),(11001,3365,'113837','watch-mobile','block_type','1',0,''),(11003,3366,'113838','watch-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(11004,3368,'113840','watch-mobile','block_type','1',0,''),(11007,3369,'113841','watch-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11008,3371,'113843','watch-mobile','block_type','1',0,''),(11009,3371,'113843','watch-mobile','schema','4-2',0,''),(11010,3372,'113844','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11011,3372,'113844','watch-mobile','text-align','center',0,''),(11012,3372,'113844','watch-mobile','padding-top','10',0,''),(11013,3372,'113844','watch-mobile','font_size_measure','em',0,''),(11014,3372,'113844','watch-mobile','font-size','1.2',0,''),(11015,3373,'113845','watch-mobile','text-align','center',0,''),(11016,3374,'113846','watch-mobile','block_type','2',0,''),(11017,3375,'113847','watch-mobile','block_type','1',0,''),(11018,3375,'113847','watch-mobile','padding-right','20',0,''),(11020,3377,'113849','watch-mobile','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(11021,3378,'113850','watch-mobile','block_type','1',0,''),(11022,3378,'113850','watch-mobile','padding-right','0',0,''),(11023,3378,'113850','watch-mobile','padding-left','20',0,''),(11024,3379,'113851','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(11025,3383,'113855','watch-mobile','block_type','4',0,''),(11026,3383,'113855','watch-mobile','schema','4-2',0,''),(11027,3384,'113856','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11028,3384,'113856','watch-mobile','text-align','right',0,''),(11029,3384,'113856','watch-mobile','padding-top','10',0,''),(11030,3384,'113856','watch-mobile','font_size_measure','em',0,''),(11031,3384,'113856','watch-mobile','font-size','1.2',0,''),(11032,3385,'113857','watch-mobile','text-align','right',0,''),(11033,3386,'113858','watch-mobile','block_type','2',0,''),(11034,3387,'113859','watch-mobile','block_type','1',0,''),(11035,3387,'113859','watch-mobile','padding-right','20',0,''),(11036,3389,'113861','watch-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(11037,3390,'113862','watch-mobile','block_type','1',0,''),(11038,3390,'113862','watch-mobile','padding-left','20',0,''),(11040,3392,'113864','watch-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11041,3393,'113865','watch-mobile','block_type','4',0,''),(11042,3393,'113865','watch-mobile','schema','4-2',0,''),(11043,3394,'113866','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11044,3394,'113866','watch-mobile','text-align','right',0,''),(11045,3394,'113866','watch-mobile','padding-top','10',0,''),(11046,3394,'113866','watch-mobile','font_size_measure','em',0,''),(11047,3394,'113866','watch-mobile','font-size','1.2',0,''),(11048,3395,'113867','watch-mobile','text-align','right',0,''),(11049,3396,'113868','watch-mobile','block_type','2',0,''),(11050,3397,'113869','watch-mobile','block_type','1',0,''),(11051,3397,'113869','watch-mobile','padding-right','20',0,''),(11052,3399,'113871','watch-mobile','block_type','1',0,''),(11053,3399,'113871','watch-mobile','padding-left','20',0,''),(11055,3401,'113873','watch-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11056,3402,'113874','watch-mobile','block_type','2',0,''),(11057,3403,'113875','watch-mobile','block_type','1',0,''),(11058,3403,'113875','watch-mobile','padding-right','20',0,''),(11059,3405,'113877','watch-mobile','block_type','1',0,''),(11060,3405,'113877','watch-mobile','padding-left','20',0,''),(11062,3406,'113878','watch-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11063,3408,'113880','watch-mobile','block_type','4',0,''),(11064,3408,'113880','watch-mobile','schema','4-2',0,''),(11065,3409,'113881','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11066,3409,'113881','watch-mobile','text-align','right',0,''),(11067,3409,'113881','watch-mobile','padding-top','10',0,''),(11068,3409,'113881','watch-mobile','font_size_measure','em',0,''),(11069,3409,'113881','watch-mobile','font-size','1.2',0,''),(11070,3410,'113882','watch-mobile','text-align','right',0,''),(11071,3411,'113883','watch-mobile','text','##DELIVERY_DETAILS##',0,''),(11072,3412,'113884','watch-mobile','text','##DELIVERY_DETAILS##',0,''),(11073,3413,'113885','watch-mobile','text','##CONTACT_INFORMATION##',0,''),(11074,3414,'113886','watch-mobile','text','##CONTACT_INFORMATION##',0,''),(11075,3415,'113887','watch-mobile','text','##DELIVERY_DETAILS##',0,''),(11076,3416,'113888','watch-mobile','text','##DELIVERY_DETAILS##',0,''),(11077,3417,'113889','watch-mobile','block_type','1',0,''),(11078,3417,'113889','watch-mobile','background-color','$background-6',0,''),(11079,3417,'113889','watch-mobile','padding-top','30',0,''),(11080,3417,'113889','watch-mobile','padding-bottom','30',0,''),(11081,3418,'113890','watch-mobile','block_type','1',0,''),(11082,3418,'113890','watch-mobile','schema','4-2',0,''),(11083,3418,'113890','watch-mobile','schema','4-1',0,'299'),(11084,3419,'113891','watch-mobile','block_type','1',0,''),(11085,3419,'113891','watch-mobile','padding-right','40',0,''),(11087,3420,'113892','watch-mobile','background-color','$background-7',0,''),(11088,3420,'113892','watch-mobile','block_type','1',0,''),(11089,3420,'113892','watch-mobile','padding-top','30',0,''),(11090,3420,'113892','watch-mobile','padding-left','30',0,''),(11091,3420,'113892','watch-mobile','padding-right','30',0,''),(11092,3420,'113892','watch-mobile','padding-bottom','30',0,''),(11093,3420,'113892','watch-mobile','margin-bottom','20',0,''),(11094,3420,'113892','watch-mobile','style_class','hiding-box',0,''),(11095,3421,'113893','watch-mobile','background-color','$background-6',0,''),(11096,3421,'113893','watch-mobile','padding-top','10',0,''),(11097,3421,'113893','watch-mobile','padding-left','10',0,''),(11098,3421,'113893','watch-mobile','padding-right','10',0,''),(11099,3421,'113893','watch-mobile','padding-bottom','10',0,''),(11100,3421,'113893','watch-mobile','margin-top','10',0,''),(11101,3422,'113894','watch-mobile','block_type','1',0,''),(11102,3422,'113894','watch-mobile','schema','2-2',0,''),(11103,3422,'113894','watch-mobile','schema','2-1',0,'299'),(11104,3423,'113895','watch-mobile','block_type','1',0,''),(11105,3423,'113895','watch-mobile','padding-left','0',0,''),(11106,3423,'113895','watch-mobile','margin-bottom','20',0,''),(11107,3425,'113897','watch-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(11108,3427,'113899','watch-mobile','block_type','1',0,''),(11109,3427,'113899','watch-mobile','padding-left','20',0,''),(11111,3428,'113900','watch-mobile','border-top-width','1',0,''),(11112,3428,'113900','watch-mobile','border-top-color','$border-color-1',0,''),(11113,3428,'113900','watch-mobile','padding-top','13',0,''),(11114,3428,'113900','watch-mobile','padding-bottom','10',0,''),(11115,3429,'113901','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(11116,3430,'113902','watch-mobile','block_type','1',0,''),(11117,3430,'113902','watch-mobile','content','\\_',0,'3'),(11118,3430,'113902','watch-mobile','border-top-width','1',0,'3'),(11119,3430,'113902','watch-mobile','border-top-color','$border-color-1',0,'3'),(11120,3430,'113902','watch-mobile','display','block',0,'3'),(11121,3430,'113902','watch-mobile','position','absolute',0,'3'),(11122,3430,'113902','watch-mobile','top','19',0,'3'),(11123,3430,'113902','watch-mobile','left','0',0,'3'),(11124,3430,'113902','watch-mobile','right','0',0,'3'),(11125,3430,'113902','watch-mobile','margin-top','-2',0,'3'),(11126,3430,'113902','watch-mobile','position','relative',0,''),(11127,3431,'113903','watch-mobile','box_align','2',0,''),(11128,3431,'113903','watch-mobile','margin-bottom','10',0,''),(11129,3431,'113903','watch-mobile','background-color','$background-7',0,''),(11130,3431,'113903','watch-mobile','position','relative',0,''),(11131,3432,'113904','watch-mobile','block_type','1',0,''),(11132,3432,'113904','watch-mobile','background-color','$background-7',0,''),(11133,3432,'113904','watch-mobile','padding-top','30',0,''),(11134,3432,'113904','watch-mobile','padding-left','30',0,''),(11135,3432,'113904','watch-mobile','padding-right','30',0,''),(11136,3432,'113904','watch-mobile','padding-bottom','14',0,''),(11137,3432,'113904','watch-mobile','margin-bottom','20',0,''),(11138,3432,'113904','watch-mobile','style_class','hiding-box closeable-box',0,''),(11139,3433,'113905','watch-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(11140,3433,'113905','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(11141,3434,'113906','watch-mobile','style_class','closeable-content',0,''),(11142,3434,'113906','watch-mobile','padding-bottom','20',0,''),(11143,3435,'113908','watch-mobile','block_type','1',0,''),(11144,3435,'113908','watch-mobile','background-color','$background-7',0,''),(11145,3435,'113908','watch-mobile','padding-top','30',0,''),(11146,3435,'113908','watch-mobile','padding-left','30',0,''),(11147,3435,'113908','watch-mobile','padding-right','30',0,''),(11148,3435,'113908','watch-mobile','padding-bottom','30',0,''),(11149,3435,'113908','watch-mobile','margin-bottom','20',0,''),(11150,3435,'113908','watch-mobile','style_class','hiding-box',0,''),(11151,3436,'113909','watch-mobile','padding-top','10',0,''),(11152,3436,'113909','watch-mobile','padding-left','20',0,''),(11153,3436,'113909','watch-mobile','padding-right','20',0,''),(11154,3436,'113909','watch-mobile','margin-top','20',0,''),(11155,3436,'113909','watch-mobile','background-color','$background-6',0,''),(11156,3436,'113909','watch-mobile','padding-bottom','8',0,''),(11157,3437,'113910','watch-mobile','margin-bottom','20',0,''),(11158,3438,'113911','watch-mobile','block_type','1',0,''),(11159,3438,'113911','watch-mobile','padding-top','20',0,''),(11160,3438,'113911','watch-mobile','padding-left','20',0,''),(11161,3438,'113911','watch-mobile','padding-right','20',0,''),(11162,3438,'113911','watch-mobile','padding-bottom','20',0,''),(11163,3438,'113911','watch-mobile','background-color','$background-7',0,''),(11164,3438,'113911','watch-mobile','style_class','order-summary',0,''),(11165,3440,'113913','watch-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(11166,3440,'113913','watch-mobile','text-align','center',0,''),(11167,3440,'113913','watch-mobile','font-size','14',0,''),(11168,3440,'113913','watch-mobile','color','$color-font-8',0,''),(11169,3440,'113913','watch-mobile','padding-top','10',0,''),(11170,3441,'116002','watch-mobile','hide_continue_button','1',0,''),(11171,3442,'113914','watch-mobile','block_type','1',0,''),(11172,3442,'113914','watch-mobile','background-color','$background-6',0,''),(11173,3442,'113914','watch-mobile','padding-top','30',0,''),(11174,3442,'113914','watch-mobile','padding-bottom','30',0,''),(11175,3443,'113915','watch-mobile','block_type','4',0,''),(11176,3444,'113916','watch-mobile','block_type','1',0,''),(11177,3444,'113916','watch-mobile','padding-right','40',0,''),(11178,3445,'113917','watch-mobile','block_type','1',0,''),(11179,3445,'113917','watch-mobile','background-color','$background-7',0,''),(11180,3445,'113917','watch-mobile','padding-top','30',0,''),(11181,3445,'113917','watch-mobile','padding-left','30',0,''),(11182,3445,'113917','watch-mobile','padding-right','30',0,''),(11183,3445,'113917','watch-mobile','padding-bottom','14',0,''),(11184,3445,'113917','watch-mobile','margin-bottom','20',0,''),(11185,3445,'113917','watch-mobile','style_class','hiding-box closeable-box',0,''),(11186,3446,'113918','watch-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(11187,3446,'113918','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(11188,3447,'113919','watch-mobile','style_class','closeable-content',0,''),(11189,3447,'113919','watch-mobile','padding-bottom','20',0,''),(11190,3448,'113920','watch-mobile','block_type','1',0,''),(11191,3448,'113920','watch-mobile','padding-top','30',0,''),(11192,3448,'113920','watch-mobile','padding-left','30',0,''),(11193,3448,'113920','watch-mobile','padding-right','30',0,''),(11194,3448,'113920','watch-mobile','padding-bottom','14',0,''),(11195,3448,'113920','watch-mobile','margin-bottom','20',0,''),(11196,3448,'113920','watch-mobile','background-color','$background-7',0,''),(11197,3448,'113920','watch-mobile','style_class','hiding-box closeable-box',0,''),(11198,3449,'113921','watch-mobile','block_type','2',0,''),(11199,3449,'113921','watch-mobile','style_class','closeable-content',0,''),(11200,3450,'113922','watch-mobile','padding-right','20',0,''),(11201,3450,'113922','watch-mobile','padding-bottom','20',0,''),(11202,3451,'113923','watch-mobile','padding-left','20',0,''),(11203,3451,'113923','watch-mobile','padding-bottom','20',0,''),(11204,3452,'113924','watch-mobile','padding-left','20',0,''),(11205,3452,'113924','watch-mobile','padding-bottom','20',0,''),(11206,3453,'113925','watch-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(11207,3453,'113925','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(11208,3454,'113926','watch-mobile','block_type','1',0,''),(11209,3454,'113926','watch-mobile','padding-top','30',0,''),(11210,3454,'113926','watch-mobile','padding-left','30',0,''),(11211,3454,'113926','watch-mobile','padding-right','30',0,''),(11212,3454,'113926','watch-mobile','padding-bottom','23',0,''),(11213,3454,'113926','watch-mobile','margin-bottom','20',0,''),(11214,3454,'113926','watch-mobile','background-color','$background-7',0,''),(11215,3454,'113926','watch-mobile','style_class','hiding-box',0,''),(11216,3455,'113927','watch-mobile','block_type','2',0,''),(11217,3456,'113928','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11218,3457,'113929','watch-mobile','padding-right','20',0,''),(11219,3458,'113930','watch-mobile','block_type','1',0,''),(11220,3458,'113930','watch-mobile','padding-left','20',0,''),(11221,3459,'113931','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11222,3461,'113933','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(11223,3462,'113934','watch-mobile','block_type','1',0,''),(11224,3462,'113934','watch-mobile','background-color','$background-7',0,''),(11225,3462,'113934','watch-mobile','padding-top','30',0,''),(11226,3462,'113934','watch-mobile','padding-left','30',0,''),(11227,3462,'113934','watch-mobile','padding-right','30',0,''),(11228,3462,'113934','watch-mobile','padding-bottom','30',0,''),(11229,3462,'113934','watch-mobile','margin-bottom','20',0,''),(11230,3462,'113934','watch-mobile','style_class','hiding-box',0,''),(11231,3463,'113935','watch-mobile','margin-bottom','20',0,''),(11232,3464,'113936','watch-mobile','padding-top','10',0,''),(11233,3464,'113936','watch-mobile','padding-left','20',0,''),(11234,3464,'113936','watch-mobile','padding-right','20',0,''),(11235,3464,'113936','watch-mobile','margin-top','20',0,''),(11236,3464,'113936','watch-mobile','background-color','$background-6',0,''),(11237,3464,'113936','watch-mobile','padding-bottom','8',0,''),(11238,3465,'113937','watch-mobile','block_type','1',0,''),(11239,3465,'113937','watch-mobile','padding-top','20',0,''),(11240,3465,'113937','watch-mobile','padding-left','20',0,''),(11241,3465,'113937','watch-mobile','padding-right','20',0,''),(11242,3465,'113937','watch-mobile','padding-bottom','20',0,''),(11243,3465,'113937','watch-mobile','background-color','$background-7',0,''),(11244,3465,'113937','watch-mobile','style_class','order-summary hiding-box',0,''),(11245,3466,'113938','watch-mobile','hide_page','1',0,''),(11246,3466,'113938','watch-mobile','hide_continue_button','1',0,''),(11247,3468,'113940','watch-mobile','margin-bottom','10',0,''),(11248,3469,'113941','watch-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(11249,3469,'113941','watch-mobile','text-align','center',0,''),(11250,3469,'113941','watch-mobile','font-size','14',0,''),(11251,3469,'113941','watch-mobile','color','$color-font-8',0,''),(11252,3469,'113941','watch-mobile','padding-top','10',0,''),(11253,3470,'113942','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(11254,3471,'113943','watch-mobile','block_type','1',0,''),(11255,3472,'113944','watch-mobile','margin-bottom','20',0,''),(11256,3473,'113945','watch-mobile','block_type','2',0,''),(11257,3473,'113945','watch-mobile','schema','2-2',0,''),(11258,3474,'113946','watch-mobile','block_type','1',0,''),(11259,3474,'113946','watch-mobile','padding-right','20',0,''),(11261,3476,'113948','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11262,3477,'113949','watch-mobile','block_type','1',0,''),(11263,3477,'113949','watch-mobile','padding-left','20',0,''),(11265,3479,'113951','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11266,3483,'113955','watch-mobile','block_type','2',0,''),(11267,3483,'113955','watch-mobile','schema','2-2',0,''),(11268,3484,'113956','watch-mobile','block_type','1',0,''),(11269,3484,'113956','watch-mobile','padding-right','20',0,''),(11271,3485,'113957','watch-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(11272,3487,'113959','watch-mobile','block_type','1',0,''),(11273,3487,'113959','watch-mobile','padding-left','20',0,''),(11275,3488,'113960','watch-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11276,3490,'113962','watch-mobile','block_type','4',0,''),(11277,3490,'113962','watch-mobile','schema','4-2',0,''),(11278,3491,'113963','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11279,3491,'113963','watch-mobile','text-align','right',0,''),(11280,3491,'113963','watch-mobile','padding-top','10',0,''),(11281,3491,'113963','watch-mobile','font_size_measure','em',0,''),(11282,3491,'113963','watch-mobile','font-size','1.2',0,''),(11283,3492,'113964','watch-mobile','text-align','right',0,''),(11284,3494,'113966','watch-mobile','block_type','1',0,''),(11285,3494,'113966','watch-mobile','background-color','$background-6',0,''),(11286,3494,'113966','watch-mobile','padding-top','30',0,''),(11287,3494,'113966','watch-mobile','padding-bottom','30',0,''),(11288,3495,'113967','watch-mobile','block_type','4',0,''),(11289,3495,'113967','watch-mobile','schema','4-2',0,''),(11290,3496,'113968','watch-mobile','block_type','1',0,''),(11291,3496,'113968','watch-mobile','padding-right','40',0,''),(11293,3497,'113969','watch-mobile','block_type','1',0,''),(11294,3497,'113969','watch-mobile','padding-top','30',0,''),(11295,3497,'113969','watch-mobile','padding-left','30',0,''),(11296,3497,'113969','watch-mobile','padding-right','30',0,''),(11297,3497,'113969','watch-mobile','padding-bottom','23',0,''),(11298,3497,'113969','watch-mobile','margin-bottom','20',0,''),(11299,3497,'113969','watch-mobile','background-color','$background-7',0,''),(11300,3497,'113969','watch-mobile','style_class','hiding-box',0,''),(11301,3498,'113970','watch-mobile','block_type','2',0,''),(11302,3498,'113970','watch-mobile','schema','2-2',0,''),(11303,3499,'113971','watch-mobile','padding-right','20',0,''),(11305,3499,'113971','watch-mobile','padding-bottom','20',0,''),(11306,3500,'113972','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11307,3501,'113973','watch-mobile','block_type','1',0,''),(11308,3501,'113973','watch-mobile','padding-left','20',0,''),(11310,3502,'113974','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11311,3504,'113976','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(11312,3505,'113977','watch-mobile','block_type','1',0,''),(11313,3505,'113977','watch-mobile','background-color','$background-7',0,''),(11314,3505,'113977','watch-mobile','padding-top','30',0,''),(11315,3505,'113977','watch-mobile','padding-left','30',0,''),(11316,3505,'113977','watch-mobile','padding-right','30',0,''),(11317,3505,'113977','watch-mobile','padding-bottom','30',0,''),(11318,3505,'113977','watch-mobile','margin-bottom','20',0,''),(11319,3505,'113977','watch-mobile','style_class','hiding-box',0,''),(11320,3506,'113978','watch-mobile','padding-top','10',0,''),(11321,3506,'113978','watch-mobile','padding-left','20',0,''),(11322,3506,'113978','watch-mobile','padding-right','20',0,''),(11323,3506,'113978','watch-mobile','margin-top','20',0,''),(11324,3506,'113978','watch-mobile','background-color','$background-6',0,''),(11325,3506,'113978','watch-mobile','padding-bottom','8',0,''),(11326,3507,'113979','watch-mobile','margin-bottom','20',0,''),(11327,3508,'113980','watch-mobile','block_type','1',0,''),(11328,3508,'113980','watch-mobile','background-color','$background-7',0,''),(11329,3508,'113980','watch-mobile','padding-top','30',0,''),(11330,3508,'113980','watch-mobile','padding-left','30',0,''),(11331,3508,'113980','watch-mobile','padding-right','30',0,''),(11332,3508,'113980','watch-mobile','padding-bottom','14',0,''),(11333,3508,'113980','watch-mobile','margin-bottom','20',0,''),(11334,3508,'113980','watch-mobile','style_class','hiding-box closeable-box',0,''),(11335,3509,'113981','watch-mobile','style_class','closeable-content',0,''),(11336,3509,'113981','watch-mobile','padding-bottom','20',0,''),(11337,3510,'113982','watch-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(11338,3510,'113982','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(11339,3511,'113983','watch-mobile','background-color','$background-7',0,''),(11340,3511,'113983','watch-mobile','padding-top','30',0,''),(11341,3511,'113983','watch-mobile','padding-left','30',0,''),(11342,3511,'113983','watch-mobile','padding-right','30',0,''),(11343,3511,'113983','watch-mobile','padding-bottom','30',0,''),(11344,3511,'113983','watch-mobile','margin-bottom','20',0,''),(11345,3512,'113984','watch-mobile','block_type','1',0,''),(11346,3512,'113984','watch-mobile','padding-top','20',0,''),(11347,3512,'113984','watch-mobile','padding-left','20',0,''),(11348,3512,'113984','watch-mobile','padding-right','20',0,''),(11349,3512,'113984','watch-mobile','padding-bottom','20',0,''),(11350,3512,'113984','watch-mobile','background-color','$background-7',0,''),(11351,3512,'113984','watch-mobile','style_class','order-summary',0,''),(11352,3513,'113985','watch-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(11353,3513,'113985','watch-mobile','text-align','center',0,''),(11354,3513,'113985','watch-mobile','font-size','14',0,''),(11355,3513,'113985','watch-mobile','color','$color-font-8',0,''),(11356,3513,'113985','watch-mobile','padding-top','10',0,''),(11357,3514,'113986','watch-mobile','margin-bottom','10',0,''),(11358,3516,'113988','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(11359,3517,'113989','watch-mobile','block_type','1',0,''),(11360,3517,'113989','watch-mobile','schema','4-2',0,''),(11361,3518,'113990','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11362,3518,'113990','watch-mobile','text-align','center',0,''),(11363,3518,'113990','watch-mobile','padding-top','10',0,''),(11364,3518,'113990','watch-mobile','font_size_measure','em',0,''),(11365,3518,'113990','watch-mobile','font-size','1.2',0,''),(11366,3519,'113991','watch-mobile','text-align','center',0,''),(11367,3520,'113992','watch-mobile','block_type','1',0,''),(11368,3521,'113993','watch-mobile','block_type','1',0,''),(11369,3521,'113993','watch-mobile','padding-left','0',0,''),(11371,3523,'113995','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11372,3524,'113996','watch-mobile','block_type','1',0,''),(11375,3526,'113998','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11376,3530,'114002','watch-mobile','block_type','2',0,''),(11377,3531,'114003','watch-mobile','block_type','1',0,''),(11378,3531,'114003','watch-mobile','padding-left','0',0,''),(11379,3531,'114003','watch-mobile','padding-right','20',0,''),(11380,3532,'114004','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11381,3534,'114006','watch-mobile','block_type','1',0,''),(11382,3534,'114006','watch-mobile','padding-left','20',0,''),(11384,3536,'114008','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11385,3540,'114012','watch-mobile','block_type','4',0,''),(11386,3540,'114012','watch-mobile','schema','4-2',0,''),(11387,3541,'114013','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11388,3541,'114013','watch-mobile','text-align','right',0,''),(11389,3541,'114013','watch-mobile','padding-top','10',0,''),(11390,3541,'114013','watch-mobile','font_size_measure','em',0,''),(11391,3541,'114013','watch-mobile','font-size','1.2',0,''),(11392,3542,'114014','watch-mobile','text-align','right',0,''),(11393,3543,'114015','watch-mobile','block_type','2',0,''),(11394,3544,'114016','watch-mobile','block_type','1',0,''),(11395,3544,'114016','watch-mobile','padding-left','0',0,''),(11396,3544,'114016','watch-mobile','padding-right','20',0,''),(11397,3545,'114017','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11398,3547,'114019','watch-mobile','block_type','1',0,''),(11399,3547,'114019','watch-mobile','padding-left','20',0,''),(11401,3548,'114020','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11402,3553,'114025','watch-mobile','block_type','4',0,''),(11403,3553,'114025','watch-mobile','schema','4-2',0,''),(11404,3554,'114026','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11405,3554,'114026','watch-mobile','text-align','right',0,''),(11406,3554,'114026','watch-mobile','padding-top','10',0,''),(11407,3554,'114026','watch-mobile','font_size_measure','em',0,''),(11408,3554,'114026','watch-mobile','font-size','1.2',0,''),(11409,3555,'114027','watch-mobile','text-align','right',0,''),(11410,3556,'114028','watch-mobile','block_type','4',0,''),(11411,3556,'114028','watch-mobile','schema','4-2',0,''),(11412,3557,'114029','watch-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(11413,3557,'114029','watch-mobile','text-align','right',0,''),(11414,3557,'114029','watch-mobile','padding-top','10',0,''),(11415,3557,'114029','watch-mobile','font_size_measure','em',0,''),(11416,3557,'114029','watch-mobile','font-size','1.2',0,''),(11417,3558,'114030','watch-mobile','text-align','right',0,''),(11418,3559,'114031','watch-mobile','block_type','2',0,''),(11419,3560,'114032','watch-mobile','block_type','1',0,''),(11420,3560,'114032','watch-mobile','padding-left','0',0,''),(11421,3560,'114032','watch-mobile','padding-right','20',0,''),(11422,3562,'114034','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11423,3563,'114035','watch-mobile','block_type','1',0,''),(11424,3563,'114035','watch-mobile','padding-left','20',0,''),(11426,3565,'114037','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11427,3569,'114041','watch-mobile','text','##PAYMENT_DETAILS##',0,''),(11428,3570,'114042','watch-mobile','text','##PAYMENT_DETAILS##',0,''),(11429,3571,'114043','watch-mobile','text','##PAYMENT_DETAILS##',0,''),(11430,3572,'114044','watch-mobile','text','##PAYMENT_DETAILS##',0,''),(11431,3573,'114045','watch-mobile','text','##PAYMENT_DETAILS##',0,''),(11432,3574,'114046','watch-mobile','text','##PAYMENT_DETAILS##',0,''),(11433,3575,'114047','watch-mobile','block_type','1',0,''),(11434,3575,'114047','watch-mobile','background-color','$background-6',0,''),(11435,3575,'114047','watch-mobile','padding-top','30',0,''),(11436,3575,'114047','watch-mobile','padding-bottom','30',0,''),(11437,3576,'114048','watch-mobile','block_type','1',0,''),(11438,3576,'114048','watch-mobile','schema','4-2',0,''),(11439,3576,'114048','watch-mobile','schema','4-2',0,'299'),(11440,3577,'114049','watch-mobile','block_type','1',0,''),(11441,3577,'114049','watch-mobile','padding-right','40',0,''),(11443,3578,'114050','watch-mobile','block_type','1',0,''),(11444,3578,'114050','watch-mobile','padding-top','30',0,''),(11445,3578,'114050','watch-mobile','padding-left','30',0,''),(11446,3578,'114050','watch-mobile','padding-right','30',0,''),(11447,3578,'114050','watch-mobile','padding-bottom','23',0,''),(11448,3578,'114050','watch-mobile','margin-bottom','20',0,''),(11449,3578,'114050','watch-mobile','background-color','$background-7',0,''),(11450,3578,'114050','watch-mobile','style_class','hiding-box',0,''),(11451,3579,'114051','watch-mobile','block_type','1',0,''),(11452,3579,'114051','watch-mobile','schema','2-2',0,''),(11453,3580,'114052','watch-mobile','padding-right','20',0,''),(11455,3580,'114052','watch-mobile','padding-bottom','20',0,''),(11456,3581,'114053','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11457,3582,'114054','watch-mobile','block_type','1',0,''),(11458,3582,'114054','watch-mobile','padding-left','20',0,''),(11460,3583,'114055','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11461,3585,'114057','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(11462,3586,'114058','watch-mobile','block_type','1',0,''),(11463,3586,'114058','watch-mobile','background-color','$background-7',0,''),(11464,3586,'114058','watch-mobile','padding-top','30',0,''),(11465,3586,'114058','watch-mobile','padding-left','30',0,''),(11466,3586,'114058','watch-mobile','padding-right','30',0,''),(11467,3586,'114058','watch-mobile','padding-bottom','14',0,''),(11468,3586,'114058','watch-mobile','margin-bottom','20',0,''),(11469,3586,'114058','watch-mobile','style_class','hiding-box closeable-box',0,''),(11470,3587,'114059','watch-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(11471,3587,'114059','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(11472,3588,'114060','watch-mobile','style_class','closeable-content',0,''),(11473,3588,'114060','watch-mobile','padding-bottom','20',0,''),(11474,3589,'114062','watch-mobile','background-color','$background-7',0,''),(11475,3589,'114062','watch-mobile','block_type','1',0,''),(11476,3589,'114062','watch-mobile','padding-top','30',0,''),(11477,3589,'114062','watch-mobile','padding-left','30',0,''),(11478,3589,'114062','watch-mobile','padding-right','30',0,''),(11479,3589,'114062','watch-mobile','padding-bottom','30',0,''),(11480,3589,'114062','watch-mobile','margin-bottom','20',0,''),(11481,3589,'114062','watch-mobile','style_class','hiding-box',0,''),(11482,3590,'114063','watch-mobile','block_type','1',0,''),(11483,3590,'114063','watch-mobile','schema','2-2',0,''),(11484,3590,'114063','watch-mobile','schema','2-1',0,'299'),(11485,3591,'114064','watch-mobile','block_type','1',0,''),(11486,3591,'114064','watch-mobile','padding-left','0',0,''),(11487,3591,'114064','watch-mobile','margin-bottom','20',0,''),(11488,3592,'114065','watch-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(11489,3595,'114068','watch-mobile','block_type','1',0,''),(11490,3595,'114068','watch-mobile','padding-left','20',0,''),(11492,3596,'114069','watch-mobile','border-top-width','1',0,''),(11493,3596,'114069','watch-mobile','border-top-color','$border-color-1',0,''),(11494,3596,'114069','watch-mobile','padding-top','13',0,''),(11495,3596,'114069','watch-mobile','padding-bottom','10',0,''),(11496,3597,'114070','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(11497,3599,'114072','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(11498,3600,'114073','watch-mobile','background-color','$background-6',0,''),(11499,3600,'114073','watch-mobile','padding-top','10',0,''),(11500,3600,'114073','watch-mobile','padding-left','10',0,''),(11501,3600,'114073','watch-mobile','padding-right','10',0,''),(11502,3600,'114073','watch-mobile','padding-bottom','10',0,''),(11503,3600,'114073','watch-mobile','margin-top','10',0,''),(11504,3601,'114074','watch-mobile','block_type','1',0,''),(11505,3601,'114074','watch-mobile','content','\\_',0,'3'),(11506,3601,'114074','watch-mobile','border-top-width','1',0,'3'),(11507,3601,'114074','watch-mobile','border-top-color','$border-color-1',0,'3'),(11508,3601,'114074','watch-mobile','display','block',0,'3'),(11509,3601,'114074','watch-mobile','position','absolute',0,'3'),(11510,3601,'114074','watch-mobile','top','19',0,'3'),(11511,3601,'114074','watch-mobile','left','0',0,'3'),(11512,3601,'114074','watch-mobile','right','0',0,'3'),(11513,3601,'114074','watch-mobile','margin-top','-2',0,'3'),(11514,3601,'114074','watch-mobile','position','relative',0,''),(11515,3602,'114075','watch-mobile','box_align','2',0,''),(11516,3602,'114075','watch-mobile','margin-bottom','10',0,''),(11517,3602,'114075','watch-mobile','background-color','$background-7',0,''),(11518,3602,'114075','watch-mobile','position','relative',0,''),(11519,3603,'114076','watch-mobile','block_type','1',0,''),(11520,3603,'114076','watch-mobile','background-color','$background-7',0,''),(11521,3603,'114076','watch-mobile','padding-top','30',0,''),(11522,3603,'114076','watch-mobile','padding-left','30',0,''),(11523,3603,'114076','watch-mobile','padding-right','30',0,''),(11524,3603,'114076','watch-mobile','padding-bottom','30',0,''),(11525,3603,'114076','watch-mobile','margin-bottom','20',0,''),(11526,3603,'114076','watch-mobile','style_class','hiding-box',0,''),(11527,3604,'114077','watch-mobile','margin-bottom','20',0,''),(11528,3605,'114078','watch-mobile','padding-top','10',0,''),(11529,3605,'114078','watch-mobile','padding-left','20',0,''),(11530,3605,'114078','watch-mobile','padding-right','20',0,''),(11531,3605,'114078','watch-mobile','margin-top','20',0,''),(11532,3605,'114078','watch-mobile','background-color','$background-6',0,''),(11533,3605,'114078','watch-mobile','padding-bottom','8',0,''),(11534,3606,'114079','watch-mobile','block_type','1',0,''),(11535,3606,'114079','watch-mobile','padding-top','20',0,''),(11536,3606,'114079','watch-mobile','padding-left','20',0,''),(11537,3606,'114079','watch-mobile','padding-right','20',0,''),(11538,3606,'114079','watch-mobile','padding-bottom','20',0,''),(11539,3606,'114079','watch-mobile','background-color','$background-7',0,''),(11540,3606,'114079','watch-mobile','style_class','order-summary',0,''),(11541,3608,'114081','watch-mobile','margin-bottom','10',0,''),(11542,3609,'114082','watch-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(11543,3609,'114082','watch-mobile','text-align','center',0,''),(11544,3609,'114082','watch-mobile','font-size','14',0,''),(11545,3609,'114082','watch-mobile','color','$color-font-8',0,''),(11546,3609,'114082','watch-mobile','padding-top','10',0,''),(11547,3610,'114083','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(11548,3611,'116000','watch-mobile','hide_continue_button','1',0,''),(11549,3612,'114084','watch-mobile','block_type','1',0,''),(11550,3612,'114084','watch-mobile','padding-top','30',0,''),(11551,3612,'114084','watch-mobile','padding-bottom','30',0,''),(11552,3612,'114084','watch-mobile','background-color','$background-6',0,''),(11553,3613,'114085','watch-mobile','block_type','1',0,''),(11554,3613,'114085','watch-mobile','schema','4-2',0,''),(11555,3613,'114085','watch-mobile','schema','4-1',0,'299'),(11556,3614,'114086','watch-mobile','block_type','1',0,''),(11557,3614,'114086','watch-mobile','padding-right','40',0,''),(11559,3615,'114093','watch-mobile','block_type','1',0,''),(11560,3615,'114093','watch-mobile','padding-top','30',0,''),(11561,3615,'114093','watch-mobile','padding-left','30',0,''),(11562,3615,'114093','watch-mobile','padding-right','30',0,''),(11563,3615,'114093','watch-mobile','padding-bottom','23',0,''),(11564,3615,'114093','watch-mobile','margin-bottom','20',0,''),(11565,3615,'114093','watch-mobile','background-color','$background-7',0,''),(11566,3615,'114093','watch-mobile','style_class','hiding-box',0,''),(11567,3616,'114094','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(11568,3617,'114095','watch-mobile','block_type','1',0,''),(11569,3617,'114095','watch-mobile','schema','2-2',0,''),(11570,3618,'114096','watch-mobile','padding-right','20',0,''),(11572,3618,'114096','watch-mobile','padding-bottom','20',0,''),(11573,3619,'114097','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11574,3620,'114098','watch-mobile','block_type','1',0,''),(11575,3620,'114098','watch-mobile','padding-left','20',0,''),(11577,3622,'114100','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11578,3623,'114101','watch-mobile','block_type','1',0,''),(11579,3623,'114101','watch-mobile','background-color','$background-7',0,''),(11580,3623,'114101','watch-mobile','padding-top','30',0,''),(11581,3623,'114101','watch-mobile','padding-left','30',0,''),(11582,3623,'114101','watch-mobile','padding-right','30',0,''),(11583,3623,'114101','watch-mobile','padding-bottom','14',0,''),(11584,3623,'114101','watch-mobile','margin-bottom','20',0,''),(11585,3623,'114101','watch-mobile','style_class','hiding-box closeable-box',0,''),(11586,3624,'114102','watch-mobile','style_class','closeable-content',0,''),(11587,3624,'114102','watch-mobile','padding-bottom','20',0,''),(11588,3625,'114103','watch-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(11589,3625,'114103','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(11590,3626,'114104','watch-mobile','background-color','$background-7',0,''),(11591,3626,'114104','watch-mobile','block_type','1',0,''),(11592,3626,'114104','watch-mobile','padding-top','30',0,''),(11593,3626,'114104','watch-mobile','padding-left','30',0,''),(11594,3626,'114104','watch-mobile','padding-right','30',0,''),(11595,3626,'114104','watch-mobile','padding-bottom','30',0,''),(11596,3626,'114104','watch-mobile','margin-bottom','20',0,''),(11597,3626,'114104','watch-mobile','style_class','hiding-box',0,''),(11598,3627,'114105','watch-mobile','block_type','1',0,''),(11599,3627,'114105','watch-mobile','content','\\_',0,'3'),(11600,3627,'114105','watch-mobile','border-top-width','1',0,'3'),(11601,3627,'114105','watch-mobile','border-top-color','$border-color-1',0,'3'),(11602,3627,'114105','watch-mobile','display','block',0,'3'),(11603,3627,'114105','watch-mobile','position','absolute',0,'3'),(11604,3627,'114105','watch-mobile','top','19',0,'3'),(11605,3627,'114105','watch-mobile','left','0',0,'3'),(11606,3627,'114105','watch-mobile','right','0',0,'3'),(11607,3627,'114105','watch-mobile','margin-top','-2',0,'3'),(11608,3627,'114105','watch-mobile','position','relative',0,''),(11609,3628,'114106','watch-mobile','box_align','2',0,''),(11610,3628,'114106','watch-mobile','margin-bottom','10',0,''),(11611,3628,'114106','watch-mobile','background-color','$background-7',0,''),(11612,3628,'114106','watch-mobile','position','relative',0,''),(11613,3629,'114107','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(11614,3630,'114108','watch-mobile','block_type','2',0,''),(11615,3630,'114108','watch-mobile','schema','2-2',0,''),(11616,3630,'114108','watch-mobile','schema','2-2',0,'299'),(11617,3631,'114109','watch-mobile','block_type','1',0,''),(11618,3631,'114109','watch-mobile','padding-left','0',0,''),(11619,3631,'114109','watch-mobile','margin-bottom','20',0,''),(11620,3633,'114111','watch-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(11621,3635,'114113','watch-mobile','block_type','1',0,''),(11622,3635,'114113','watch-mobile','padding-left','20',0,''),(11624,3636,'114114','watch-mobile','border-top-width','1',0,''),(11625,3636,'114114','watch-mobile','border-top-color','$border-color-1',0,''),(11626,3636,'114114','watch-mobile','padding-top','13',0,''),(11627,3636,'114114','watch-mobile','padding-bottom','10',0,''),(11628,3637,'114115','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(11629,3639,'114117','watch-mobile','background-color','$background-6',0,''),(11630,3639,'114117','watch-mobile','padding-top','10',0,''),(11631,3639,'114117','watch-mobile','padding-left','10',0,''),(11632,3639,'114117','watch-mobile','padding-right','10',0,''),(11633,3639,'114117','watch-mobile','padding-bottom','10',0,''),(11634,3639,'114117','watch-mobile','margin-top','10',0,''),(11635,3640,'114118','watch-mobile','block_type','1',0,''),(11636,3640,'114118','watch-mobile','background-color','$background-7',0,''),(11637,3640,'114118','watch-mobile','padding-top','30',0,''),(11638,3640,'114118','watch-mobile','padding-left','30',0,''),(11639,3640,'114118','watch-mobile','padding-right','30',0,''),(11640,3640,'114118','watch-mobile','padding-bottom','30',0,''),(11641,3640,'114118','watch-mobile','margin-bottom','20',0,''),(11642,3640,'114118','watch-mobile','style_class','hiding-box',0,''),(11643,3641,'114119','watch-mobile','padding-top','10',0,''),(11644,3641,'114119','watch-mobile','padding-left','20',0,''),(11645,3641,'114119','watch-mobile','padding-right','20',0,''),(11646,3641,'114119','watch-mobile','margin-top','20',0,''),(11647,3641,'114119','watch-mobile','background-color','$background-6',0,''),(11648,3641,'114119','watch-mobile','padding-bottom','8',0,''),(11649,3642,'114120','watch-mobile','margin-bottom','20',0,''),(11650,3643,'114122','watch-mobile','block_type','1',0,''),(11651,3643,'114122','watch-mobile','padding-top','20',0,''),(11652,3643,'114122','watch-mobile','padding-left','20',0,''),(11653,3643,'114122','watch-mobile','padding-right','20',0,''),(11654,3643,'114122','watch-mobile','padding-bottom','20',0,''),(11655,3643,'114122','watch-mobile','background-color','$background-7',0,''),(11656,3643,'114122','watch-mobile','style_class','order-summary',0,''),(11657,3644,'114123','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(11658,3646,'114125','watch-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(11659,3646,'114125','watch-mobile','text-align','center',0,''),(11660,3646,'114125','watch-mobile','font-size','14',0,''),(11661,3646,'114125','watch-mobile','color','$color-font-8',0,''),(11662,3646,'114125','watch-mobile','padding-top','10',0,''),(11663,3647,'114126','watch-mobile','margin-bottom','10',0,''),(11664,3648,'116001','watch-mobile','hide_continue_button','1',0,''),(11665,3651,'114129','watch-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(11666,3654,'114132','watch-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(11667,3655,'114133','watch-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(11668,3658,'114136','watch-mobile','style_class','order-summary',0,''),(11669,3658,'114136','watch-mobile','box_align','3',0,''),(11670,3658,'114136','watch-mobile','width','400',0,''),(11671,3659,'114137','watch-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(11672,3661,'114139','watch-mobile','block_type','1',0,''),(11673,3662,'114140','watch-mobile','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(11674,3663,'114141','watch-mobile','margin-bottom','30',0,''),(11675,3664,'114142','watch-mobile','float','right',0,''),(11676,3664,'114142','watch-mobile','position','relative',0,''),(11677,3664,'114142','watch-mobile','z-index','1',0,''),(11678,3664,'114142','watch-mobile','top','30',0,''),(11679,3664,'114142','watch-mobile','margin-bottom','-20',0,''),(11680,3665,'114143','watch-mobile','block_type','1',0,''),(11681,3666,'114144','watch-mobile','listing_type','Compare Products',0,''),(11682,3667,'114145','watch-mobile','block_type','1',0,''),(11683,3667,'114145','watch-mobile','style_class','item-holder',0,''),(11684,3667,'114145','watch-mobile','padding-top','10',0,''),(11685,3667,'114145','watch-mobile','padding-left','20',0,''),(11686,3667,'114145','watch-mobile','padding-right','20',0,''),(11687,3667,'114145','watch-mobile','padding-bottom','10',0,''),(11688,3667,'114145','watch-mobile','text-align','left',0,''),(11689,3670,'114148','watch-mobile','margin-bottom','10',0,''),(11690,3671,'114149','watch-mobile','block_type','5',0,''),(11691,3673,'114151','watch-mobile','clear','both',0,''),(11692,3674,'114152','watch-mobile','block_type','2',0,''),(11693,3675,'114153','watch-mobile','margin-bottom','7',0,''),(11694,3676,'114154','watch-mobile','text-align','right',0,''),(11695,3676,'114154','watch-mobile','margin-bottom','10',0,''),(11696,3676,'114154','watch-mobile','float','right',0,''),(11697,3677,'114155','watch-mobile','block_type','1',0,''),(11698,3677,'114155','watch-mobile','background-color','$background-6',0,''),(11699,3677,'114155','watch-mobile','padding-bottom','30',0,''),(11700,3678,'114156','watch-mobile','block_type','1',0,''),(11701,3678,'114156','watch-mobile','schema','4-2',0,''),(11702,3678,'114156','watch-mobile','schema','4-2',0,'299'),(11703,3680,'114158','watch-mobile','block_type','1',0,''),(11706,3681,'114159','watch-mobile','block_type','1',0,''),(11707,3681,'114159','watch-mobile','margin-bottom','20',0,''),(11708,3681,'114159','watch-mobile','schema','2-2',0,''),(11709,3681,'114159','watch-mobile','background-color','$background-7',0,''),(11710,3682,'114160','watch-mobile','block_type','1',0,''),(11715,3682,'114160','watch-mobile','padding-top','20',0,''),(11717,3682,'114160','watch-mobile','padding-bottom','20',0,''),(11720,3682,'114160','watch-mobile','margin-bottom','20',0,''),(11723,3683,'114161','watch-mobile','margin-bottom','20',0,''),(11724,3684,'114162','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(11725,3685,'114163','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(11726,3685,'114163','watch-mobile','clear','none',0,''),(11727,3687,'114165','watch-mobile','link','shipping_address',0,''),(11728,3687,'114165','watch-mobile','float','right',0,''),(11729,3687,'114165','watch-mobile','margin-top','-31',0,''),(11730,3688,'114166','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(11731,3688,'114166','watch-mobile','clear','none',0,''),(11732,3690,'114168','watch-mobile','link','contact_information',0,''),(11733,3690,'114168','watch-mobile','margin-top','-31',0,''),(11734,3690,'114168','watch-mobile','float','right',0,''),(11735,3691,'114169','watch-mobile','link','shipping_method',0,''),(11736,3691,'114169','watch-mobile','float','right',0,''),(11737,3691,'114169','watch-mobile','margin-top','-31',0,''),(11738,3692,'114170','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(11739,3692,'114170','watch-mobile','padding-top','20',0,''),(11740,3694,'114172','watch-mobile','block_type','1',0,''),(11741,3694,'114172','watch-mobile','padding-left','30',0,''),(11744,3694,'114172','watch-mobile','margin-left','-10',0,''),(11745,3694,'114172','watch-mobile','padding-right','30',0,''),(11746,3694,'114172','watch-mobile','padding-top','20',0,''),(11747,3694,'114172','watch-mobile','padding-bottom','20',0,''),(11749,3695,'114173','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11750,3695,'114173','watch-mobile','clear','none',0,''),(11751,3696,'114174','watch-mobile','margin-bottom','20',0,''),(11752,3697,'114175','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11753,3697,'114175','watch-mobile','clear','none',0,''),(11754,3699,'114177','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(11755,3700,'114178','watch-mobile','link','billing_address',0,''),(11756,3700,'114178','watch-mobile','float','right',0,''),(11757,3700,'114178','watch-mobile','margin-top','-31',0,''),(11758,3701,'114179','watch-mobile','link','payment_method',0,''),(11759,3701,'114179','watch-mobile','float','right',0,''),(11760,3701,'114179','watch-mobile','margin-top','-31',0,''),(11761,3702,'114180','watch-mobile','block_type','1',0,''),(11762,3702,'114180','watch-mobile','padding-right','30',0,''),(11763,3702,'114180','watch-mobile','background-color','$background-7',0,''),(11764,3702,'114180','watch-mobile','padding-top','20',0,''),(11765,3702,'114180','watch-mobile','padding-left','30',0,''),(11766,3702,'114180','watch-mobile','padding-bottom','20',0,''),(11769,3703,'114181','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(11770,3704,'114182','watch-mobile','link','products',0,''),(11771,3704,'114182','watch-mobile','float','right',0,''),(11772,3704,'114182','watch-mobile','margin-top','-37',0,''),(11773,3706,'114184','watch-mobile','block_type','1',0,''),(11774,3706,'114184','watch-mobile','background-color','$background-7',0,''),(11775,3706,'114184','watch-mobile','padding-top','20',0,''),(11776,3706,'114184','watch-mobile','padding-bottom','20',0,''),(11777,3706,'114184','watch-mobile','padding-left','30',0,''),(11778,3706,'114184','watch-mobile','padding-right','30',0,''),(11779,3706,'114184','watch-mobile','margin-bottom','20',0,''),(11780,3707,'114185','watch-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11781,3708,'114186','watch-mobile','hide_parents','2',0,''),(11782,3709,'114187','watch-mobile','float','right',0,''),(11783,3709,'114187','watch-mobile','margin-top','-37',0,''),(11784,3709,'114187','watch-mobile','link','comments',0,''),(11785,3710,'114188','watch-mobile','block_type','1',0,''),(11786,3710,'114188','watch-mobile','padding-top','20',0,''),(11787,3710,'114188','watch-mobile','padding-left','20',0,''),(11788,3710,'114188','watch-mobile','padding-right','20',0,''),(11789,3710,'114188','watch-mobile','padding-bottom','20',0,''),(11790,3710,'114188','watch-mobile','background-color','$background-7',0,''),(11791,3710,'114188','watch-mobile','style_class','order-summary2 hiding-box',0,''),(11792,3712,'114190','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(11793,3713,'114191','watch-mobile','margin-bottom','20',0,''),(11794,3713,'114191','watch-mobile','text-align','center',0,''),(11795,3714,'114192','watch-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(11796,3715,'114193','watch-mobile','block_type','1',0,''),(11797,3715,'114193','watch-mobile','background-color','$background-6',0,''),(11798,3715,'114193','watch-mobile','padding-bottom','30',0,''),(11799,3716,'114194','watch-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(11800,3717,'114195','watch-mobile','block_type','1',0,''),(11801,3717,'114195','watch-mobile','schema','4-2',0,''),(11802,3717,'114195','watch-mobile','schema','4-1',0,'299'),(11803,3718,'114196','watch-mobile','block_type','1',0,''),(11804,3718,'114196','watch-mobile','padding-right','40',0,''),(11806,3719,'114197','watch-mobile','block_type','1',0,''),(11807,3719,'114197','watch-mobile','margin-bottom','20',0,''),(11808,3719,'114197','watch-mobile','schema','2-2',0,''),(11809,3719,'114197','watch-mobile','background-color','$background-7',0,''),(11810,3720,'114198','watch-mobile','block_type','1',0,''),(11811,3720,'114198','watch-mobile','border-right-width','20',0,''),(11812,3720,'114198','watch-mobile','border-right-color','$border-color-1',0,''),(11813,3720,'114198','watch-mobile','margin-right','-10',0,''),(11814,3720,'114198','watch-mobile','padding-right','30',0,''),(11815,3720,'114198','watch-mobile','padding-top','20',0,''),(11816,3720,'114198','watch-mobile','padding-left','30',0,''),(11817,3720,'114198','watch-mobile','padding-bottom','20',0,''),(11820,3720,'114198','watch-mobile','margin-bottom','20',0,''),(11823,3721,'114199','watch-mobile','link','shipping_method',0,''),(11824,3721,'114199','watch-mobile','float','right',0,''),(11825,3721,'114199','watch-mobile','margin-top','-31',0,''),(11826,3722,'114200','watch-mobile','margin-bottom','20',0,''),(11827,3723,'114201','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(11828,3723,'114201','watch-mobile','clear','none',0,''),(11829,3725,'114203','watch-mobile','link','shipping_address',0,''),(11830,3725,'114203','watch-mobile','float','right',0,''),(11831,3725,'114203','watch-mobile','margin-top','-31',0,''),(11832,3726,'114204','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(11833,3726,'114204','watch-mobile','clear','none',0,''),(11834,3727,'114205','watch-mobile','block_type','1',0,''),(11835,3727,'114205','watch-mobile','padding-left','30',0,''),(11836,3727,'114205','watch-mobile','border-left-width','20',0,''),(11837,3727,'114205','watch-mobile','border-left-color','$border-color-1',0,''),(11838,3727,'114205','watch-mobile','margin-left','-10',0,''),(11839,3727,'114205','watch-mobile','padding-right','30',0,''),(11840,3727,'114205','watch-mobile','padding-top','20',0,''),(11841,3727,'114205','watch-mobile','padding-bottom','20',0,''),(11843,3728,'114206','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(11844,3729,'114207','watch-mobile','link','contact_information',0,''),(11845,3729,'114207','watch-mobile','margin-top','-31',0,''),(11846,3729,'114207','watch-mobile','float','right',0,''),(11847,3732,'114210','watch-mobile','block_type','1',0,''),(11848,3732,'114210','watch-mobile','background-color','$background-7',0,''),(11849,3732,'114210','watch-mobile','padding-top','20',0,''),(11850,3732,'114210','watch-mobile','padding-bottom','20',0,''),(11851,3732,'114210','watch-mobile','padding-left','30',0,''),(11852,3732,'114210','watch-mobile','padding-right','30',0,''),(11853,3732,'114210','watch-mobile','margin-bottom','20',0,''),(11854,3733,'114211','watch-mobile','hide_parents','2',0,''),(11855,3734,'114212','watch-mobile','float','right',0,''),(11856,3734,'114212','watch-mobile','margin-top','-37',0,''),(11857,3734,'114212','watch-mobile','link','comments',0,''),(11858,3735,'114213','watch-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11859,3736,'114214','watch-mobile','block_type','1',0,''),(11860,3736,'114214','watch-mobile','padding-right','30',0,''),(11861,3736,'114214','watch-mobile','background-color','$background-7',0,''),(11862,3736,'114214','watch-mobile','padding-top','20',0,''),(11863,3736,'114214','watch-mobile','padding-left','30',0,''),(11864,3736,'114214','watch-mobile','padding-bottom','20',0,''),(11867,3738,'114216','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(11868,3739,'114217','watch-mobile','link','products',0,''),(11869,3739,'114217','watch-mobile','float','right',0,''),(11870,3739,'114217','watch-mobile','margin-top','-37',0,''),(11871,3740,'114218','watch-mobile','block_type','1',0,''),(11872,3740,'114218','watch-mobile','padding-top','20',0,''),(11873,3740,'114218','watch-mobile','padding-left','20',0,''),(11874,3740,'114218','watch-mobile','padding-right','20',0,''),(11875,3740,'114218','watch-mobile','padding-bottom','20',0,''),(11876,3740,'114218','watch-mobile','background-color','$background-7',0,''),(11877,3740,'114218','watch-mobile','style_class','order-summary',0,''),(11878,3741,'114219','watch-mobile','margin-bottom','20',0,''),(11879,3741,'114219','watch-mobile','text-align','right',0,''),(11880,3742,'114220','watch-mobile','block_type','1',0,''),(11881,3742,'114220','watch-mobile','background-color','$background-6',0,''),(11882,3742,'114220','watch-mobile','padding-bottom','30',0,''),(11883,3743,'114221','watch-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(11884,3744,'114222','watch-mobile','block_type','4',0,''),(11885,3745,'114223','watch-mobile','block_type','1',0,''),(11886,3745,'114223','watch-mobile','padding-right','40',0,''),(11887,3746,'114224','watch-mobile','block_type','1',0,''),(11888,3746,'114224','watch-mobile','padding-right','30',0,''),(11890,3746,'114224','watch-mobile','background-color','$background-7',0,''),(11891,3746,'114224','watch-mobile','padding-top','20',0,''),(11892,3746,'114224','watch-mobile','padding-left','30',0,''),(11893,3746,'114224','watch-mobile','padding-bottom','20',0,''),(11894,3747,'114225','watch-mobile','link','products',0,''),(11895,3747,'114225','watch-mobile','float','right',0,''),(11896,3747,'114225','watch-mobile','margin-top','-37',0,''),(11897,3748,'114226','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(11898,3750,'114228','watch-mobile','block_type','1',0,''),(11899,3750,'114228','watch-mobile','background-color','$background-7',0,''),(11900,3750,'114228','watch-mobile','padding-top','20',0,''),(11901,3750,'114228','watch-mobile','padding-bottom','20',0,''),(11902,3750,'114228','watch-mobile','padding-left','30',0,''),(11903,3750,'114228','watch-mobile','padding-right','30',0,''),(11904,3750,'114228','watch-mobile','margin-bottom','20',0,''),(11905,3751,'114229','watch-mobile','float','right',0,''),(11906,3751,'114229','watch-mobile','margin-top','-37',0,''),(11907,3751,'114229','watch-mobile','link','comments',0,''),(11908,3752,'114230','watch-mobile','hide_parents','2',0,''),(11909,3753,'114231','watch-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(11910,3754,'114232','watch-mobile','block_type','2',0,''),(11911,3754,'114232','watch-mobile','margin-bottom','20',0,''),(11912,3754,'114232','watch-mobile','schema','2-2',0,''),(11913,3754,'114232','watch-mobile','background-color','$background-7',0,''),(11914,3755,'114233','watch-mobile','block_type','1',0,''),(11915,3755,'114233','watch-mobile','padding-right','0',0,''),(11916,3755,'114233','watch-mobile','border-right-width','20',0,''),(11917,3755,'114233','watch-mobile','border-right-color','$border-color-1',0,''),(11918,3755,'114233','watch-mobile','margin-right','-10',0,''),(11920,3755,'114233','watch-mobile','padding-top','20',0,''),(11921,3755,'114233','watch-mobile','padding-left','30',0,''),(11922,3755,'114233','watch-mobile','padding-bottom','20',0,''),(11923,3756,'114234','watch-mobile','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(11924,3756,'114234','watch-mobile','padding-top','20',0,''),(11925,3758,'114236','watch-mobile','link','contact_information',0,''),(11926,3758,'114236','watch-mobile','margin-top','-37',0,''),(11927,3758,'114236','watch-mobile','float','right',0,''),(11928,3759,'114237','watch-mobile','block_type','1',0,''),(11929,3759,'114237','watch-mobile','padding-left','30',0,''),(11931,3759,'114237','watch-mobile','border-left-width','20',0,''),(11932,3759,'114237','watch-mobile','border-left-color','$border-color-1',0,''),(11933,3759,'114237','watch-mobile','margin-left','-10',0,''),(11934,3759,'114237','watch-mobile','padding-right','30',0,''),(11935,3759,'114237','watch-mobile','padding-top','20',0,''),(11936,3759,'114237','watch-mobile','padding-bottom','20',0,''),(11937,3760,'114238','watch-mobile','link','billing_address',0,''),(11938,3760,'114238','watch-mobile','float','right',0,''),(11939,3760,'114238','watch-mobile','margin-top','-31',0,''),(11940,3761,'114239','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(11941,3761,'114239','watch-mobile','clear','none',0,''),(11942,3762,'114240','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(11943,3763,'114241','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(11944,3763,'114241','watch-mobile','clear','none',0,''),(11945,3764,'114242','watch-mobile','margin-bottom','20',0,''),(11946,3766,'114244','watch-mobile','link','payment_method',0,''),(11947,3766,'114244','watch-mobile','float','right',0,''),(11948,3766,'114244','watch-mobile','margin-top','-31',0,''),(11949,3767,'114245','watch-mobile','block_type','1',0,''),(11950,3767,'114245','watch-mobile','padding-top','20',0,''),(11951,3767,'114245','watch-mobile','padding-left','20',0,''),(11952,3767,'114245','watch-mobile','padding-right','20',0,''),(11953,3767,'114245','watch-mobile','padding-bottom','20',0,''),(11954,3767,'114245','watch-mobile','background-color','$background-7',0,''),(11955,3767,'114245','watch-mobile','style_class','order-summary2 hiding-box',0,''),(11956,3768,'114246','watch-mobile','margin-bottom','20',0,''),(11957,3768,'114246','watch-mobile','text-align','right',0,''),(11958,3770,'114248','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(11959,3771,'114249','watch-mobile','block_type','1',0,''),(11960,3771,'114249','watch-mobile','background-color','$background-6',0,''),(11961,3771,'114249','watch-mobile','padding-bottom','30',0,''),(11962,3772,'114250','watch-mobile','block_type','4',0,''),(11963,3772,'114250','watch-mobile','schema','4-2',0,''),(11964,3773,'114251','watch-mobile','block_type','1',0,''),(11965,3773,'114251','watch-mobile','padding-right','40',0,''),(11967,3774,'114252','watch-mobile','block_type','1',0,''),(11968,3774,'114252','watch-mobile','padding-right','30',0,''),(11969,3774,'114252','watch-mobile','background-color','$background-7',0,''),(11970,3774,'114252','watch-mobile','padding-top','20',0,''),(11971,3774,'114252','watch-mobile','padding-left','30',0,''),(11972,3774,'114252','watch-mobile','padding-bottom','20',0,''),(11975,3775,'114253','watch-mobile','margin-bottom','20',0,''),(11976,3776,'114254','watch-mobile','link','products',0,''),(11977,3776,'114254','watch-mobile','float','right',0,''),(11978,3776,'114254','watch-mobile','margin-top','-37',0,''),(11979,3777,'114255','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(11980,3778,'114256','watch-mobile','block_type','2',0,''),(11981,3778,'114256','watch-mobile','margin-bottom','20',0,''),(11982,3778,'114256','watch-mobile','schema','2-2',0,''),(11983,3778,'114256','watch-mobile','background-color','$background-7',0,''),(11984,3779,'114257','watch-mobile','block_type','1',0,''),(11985,3779,'114257','watch-mobile','border-right-width','20',0,''),(11986,3779,'114257','watch-mobile','border-right-color','$border-color-1',0,''),(11987,3779,'114257','watch-mobile','margin-right','-10',0,''),(11988,3779,'114257','watch-mobile','padding-right','30',0,''),(11989,3779,'114257','watch-mobile','padding-top','20',0,''),(11990,3779,'114257','watch-mobile','padding-left','30',0,''),(11991,3779,'114257','watch-mobile','padding-bottom','20',0,''),(11994,3779,'114257','watch-mobile','margin-bottom','20',0,''),(11997,3780,'114258','watch-mobile','link','payment_method',0,''),(11998,3780,'114258','watch-mobile','float','right',0,''),(11999,3780,'114258','watch-mobile','margin-top','-31',0,''),(12000,3781,'114259','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(12001,3781,'114259','watch-mobile','clear','none',0,''),(12002,3782,'114260','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(12003,3782,'114260','watch-mobile','padding-top','20',0,''),(12004,3784,'114262','watch-mobile','link','contact_information',0,''),(12005,3784,'114262','watch-mobile','margin-top','-31',0,''),(12006,3784,'114262','watch-mobile','float','right',0,''),(12007,3786,'114264','watch-mobile','block_type','1',0,''),(12008,3786,'114264','watch-mobile','padding-left','30',0,''),(12009,3786,'114264','watch-mobile','border-left-width','20',0,''),(12010,3786,'114264','watch-mobile','border-left-color','$border-color-1',0,''),(12011,3786,'114264','watch-mobile','margin-left','-10',0,''),(12012,3786,'114264','watch-mobile','padding-right','30',0,''),(12013,3786,'114264','watch-mobile','padding-top','20',0,''),(12014,3786,'114264','watch-mobile','padding-bottom','20',0,''),(12016,3787,'114265','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(12017,3787,'114265','watch-mobile','clear','none',0,''),(12018,3788,'114266','watch-mobile','link','billing_address',0,''),(12019,3788,'114266','watch-mobile','float','right',0,''),(12020,3788,'114266','watch-mobile','margin-top','-31',0,''),(12021,3789,'114267','watch-mobile','margin-bottom','20',0,''),(12022,3790,'114268','watch-mobile','block_type','1',0,''),(12023,3790,'114268','watch-mobile','background-color','$background-7',0,''),(12024,3790,'114268','watch-mobile','padding-top','20',0,''),(12025,3790,'114268','watch-mobile','padding-bottom','20',0,''),(12026,3790,'114268','watch-mobile','padding-left','30',0,''),(12027,3790,'114268','watch-mobile','padding-right','30',0,''),(12028,3790,'114268','watch-mobile','margin-bottom','20',0,''),(12029,3791,'114269','watch-mobile','hide_parents','2',0,''),(12030,3792,'114270','watch-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(12031,3793,'114271','watch-mobile','float','right',0,''),(12032,3793,'114271','watch-mobile','margin-top','-37',0,''),(12033,3793,'114271','watch-mobile','link','comments',0,''),(12034,3794,'114272','watch-mobile','block_type','1',0,''),(12035,3794,'114272','watch-mobile','padding-top','20',0,''),(12036,3794,'114272','watch-mobile','padding-left','20',0,''),(12037,3794,'114272','watch-mobile','padding-right','20',0,''),(12038,3794,'114272','watch-mobile','padding-bottom','20',0,''),(12039,3794,'114272','watch-mobile','background-color','$background-7',0,''),(12040,3794,'114272','watch-mobile','style_class','order-summary',0,''),(12041,3795,'114273','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(12042,3797,'114275','watch-mobile','margin-bottom','20',0,''),(12043,3797,'114275','watch-mobile','text-align','right',0,''),(12044,3798,'114276','watch-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(12045,3799,'114277','watch-mobile','block_type','1',0,''),(12046,3799,'114277','watch-mobile','background-color','$background-6',0,''),(12047,3799,'114277','watch-mobile','padding-bottom','30',0,''),(12048,3800,'114278','watch-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(12049,3801,'114279','watch-mobile','block_type','1',0,''),(12050,3801,'114279','watch-mobile','schema','4-2',0,''),(12051,3801,'114279','watch-mobile','schema','4-1',0,'299'),(12052,3802,'114280','watch-mobile','block_type','1',0,''),(12053,3802,'114280','watch-mobile','padding-right','40',0,''),(12055,3803,'114281','watch-mobile','block_type','1',0,''),(12056,3803,'114281','watch-mobile','padding-right','30',0,''),(12057,3803,'114281','watch-mobile','background-color','$background-7',0,''),(12058,3803,'114281','watch-mobile','padding-top','20',0,''),(12059,3803,'114281','watch-mobile','padding-left','30',0,''),(12060,3803,'114281','watch-mobile','padding-bottom','20',0,''),(12063,3804,'114282','watch-mobile','link','products',0,''),(12064,3804,'114282','watch-mobile','float','right',0,''),(12065,3804,'114282','watch-mobile','margin-top','-37',0,''),(12066,3805,'114283','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(12067,3807,'114285','watch-mobile','block_type','1',0,''),(12068,3807,'114285','watch-mobile','background-color','$background-7',0,''),(12069,3807,'114285','watch-mobile','padding-top','20',0,''),(12070,3807,'114285','watch-mobile','padding-bottom','20',0,''),(12071,3807,'114285','watch-mobile','padding-left','30',0,''),(12072,3807,'114285','watch-mobile','padding-right','30',0,''),(12073,3807,'114285','watch-mobile','margin-bottom','20',0,''),(12074,3808,'114286','watch-mobile','float','right',0,''),(12075,3808,'114286','watch-mobile','margin-top','-37',0,''),(12076,3808,'114286','watch-mobile','link','comments',0,''),(12077,3809,'114287','watch-mobile','hide_parents','2',0,''),(12078,3810,'114288','watch-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(12079,3811,'114289','watch-mobile','block_type','1',0,''),(12080,3811,'114289','watch-mobile','margin-bottom','20',0,''),(12081,3811,'114289','watch-mobile','schema','2-2',0,''),(12082,3811,'114289','watch-mobile','background-color','$background-7',0,''),(12083,3812,'114290','watch-mobile','block_type','1',0,''),(12084,3812,'114290','watch-mobile','border-right-width','20',0,''),(12085,3812,'114290','watch-mobile','border-right-color','$border-color-1',0,''),(12086,3812,'114290','watch-mobile','margin-right','-10',0,''),(12087,3812,'114290','watch-mobile','padding-right','30',0,''),(12088,3812,'114290','watch-mobile','padding-top','20',0,''),(12089,3812,'114290','watch-mobile','padding-left','30',0,''),(12090,3812,'114290','watch-mobile','padding-bottom','20',0,''),(12093,3812,'114290','watch-mobile','margin-bottom','20',0,''),(12096,3813,'114291','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(12097,3813,'114291','watch-mobile','clear','none',0,''),(12098,3814,'114292','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(12099,3814,'114292','watch-mobile','padding-top','20',0,''),(12100,3815,'114293','watch-mobile','link','shipping_method',0,''),(12101,3815,'114293','watch-mobile','float','right',0,''),(12102,3815,'114293','watch-mobile','margin-top','-31',0,''),(12103,3817,'114295','watch-mobile','link','shipping_address',0,''),(12104,3817,'114295','watch-mobile','float','right',0,''),(12105,3817,'114295','watch-mobile','margin-top','-31',0,''),(12106,3819,'114297','watch-mobile','margin-bottom','20',0,''),(12107,3821,'114299','watch-mobile','link','contact_information',0,''),(12108,3821,'114299','watch-mobile','margin-top','-31',0,''),(12109,3821,'114299','watch-mobile','float','right',0,''),(12110,3822,'114300','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(12111,3822,'114300','watch-mobile','clear','none',0,''),(12112,3823,'114301','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(12113,3824,'114302','watch-mobile','block_type','1',0,''),(12114,3824,'114302','watch-mobile','padding-left','30',0,''),(12115,3824,'114302','watch-mobile','border-left-width','20',0,''),(12116,3824,'114302','watch-mobile','border-left-color','$border-color-1',0,''),(12117,3824,'114302','watch-mobile','margin-left','-10',0,''),(12118,3824,'114302','watch-mobile','padding-right','30',0,''),(12119,3824,'114302','watch-mobile','padding-top','20',0,''),(12120,3824,'114302','watch-mobile','padding-bottom','20',0,''),(12122,3825,'114303','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(12123,3826,'114304','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(12124,3826,'114304','watch-mobile','clear','none',0,''),(12125,3828,'114306','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(12126,3828,'114306','watch-mobile','clear','none',0,''),(12127,3829,'114307','watch-mobile','margin-bottom','20',0,''),(12128,3830,'114308','watch-mobile','link','payment_method',0,''),(12129,3830,'114308','watch-mobile','float','right',0,''),(12130,3830,'114308','watch-mobile','margin-top','-31',0,''),(12131,3831,'114309','watch-mobile','link','billing_address',0,''),(12132,3831,'114309','watch-mobile','float','right',0,''),(12133,3831,'114309','watch-mobile','margin-top','-31',0,''),(12134,3832,'114310','watch-mobile','block_type','1',0,''),(12135,3832,'114310','watch-mobile','padding-top','20',0,''),(12136,3832,'114310','watch-mobile','padding-left','20',0,''),(12137,3832,'114310','watch-mobile','padding-right','20',0,''),(12138,3832,'114310','watch-mobile','padding-bottom','20',0,''),(12139,3832,'114310','watch-mobile','background-color','$background-7',0,''),(12140,3832,'114310','watch-mobile','style_class','order-summary',0,''),(12141,3833,'114311','watch-mobile','margin-bottom','20',0,''),(12142,3833,'114311','watch-mobile','text-align','right',0,''),(12143,3834,'114312','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(12144,3836,'114314','watch-mobile','block_type','1',0,''),(12145,3836,'114314','watch-mobile','background-color','$background-6',0,''),(12146,3836,'114314','watch-mobile','padding-bottom','30',0,''),(12147,3837,'114315','watch-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(12148,3838,'114316','watch-mobile','block_type','1',0,''),(12149,3838,'114316','watch-mobile','schema','4-2',0,''),(12150,3838,'114316','watch-mobile','schema','4-1',0,'299'),(12151,3839,'114317','watch-mobile','block_type','1',0,''),(12152,3839,'114317','watch-mobile','padding-right','40',0,''),(12154,3840,'114318','watch-mobile','block_type','1',0,''),(12155,3840,'114318','watch-mobile','background-color','$background-7',0,''),(12156,3840,'114318','watch-mobile','padding-top','20',0,''),(12157,3840,'114318','watch-mobile','padding-bottom','20',0,''),(12158,3840,'114318','watch-mobile','padding-left','30',0,''),(12159,3840,'114318','watch-mobile','padding-right','30',0,''),(12160,3840,'114318','watch-mobile','margin-bottom','20',0,''),(12161,3841,'114319','watch-mobile','hide_parents','2',0,''),(12162,3842,'114320','watch-mobile','float','right',0,''),(12163,3842,'114320','watch-mobile','margin-top','-37',0,''),(12164,3842,'114320','watch-mobile','link','comments',0,''),(12165,3843,'114321','watch-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(12166,3844,'114322','watch-mobile','block_type','1',0,''),(12167,3844,'114322','watch-mobile','padding-right','30',0,''),(12168,3844,'114322','watch-mobile','background-color','$background-7',0,''),(12169,3844,'114322','watch-mobile','padding-top','20',0,''),(12170,3844,'114322','watch-mobile','padding-left','30',0,''),(12171,3844,'114322','watch-mobile','padding-bottom','20',0,''),(12174,3846,'114324','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(12175,3847,'114325','watch-mobile','link','products',0,''),(12176,3847,'114325','watch-mobile','float','right',0,''),(12177,3847,'114325','watch-mobile','margin-top','-37',0,''),(12178,3848,'114326','watch-mobile','block_type','1',0,''),(12179,3848,'114326','watch-mobile','margin-bottom','20',0,''),(12180,3848,'114326','watch-mobile','schema','2-2',0,''),(12181,3848,'114326','watch-mobile','background-color','$background-7',0,''),(12182,3849,'114327','watch-mobile','block_type','1',0,''),(12183,3849,'114327','watch-mobile','border-right-width','20',0,''),(12184,3849,'114327','watch-mobile','border-right-color','$border-color-1',0,''),(12185,3849,'114327','watch-mobile','margin-right','-10',0,''),(12186,3849,'114327','watch-mobile','padding-right','30',0,''),(12187,3849,'114327','watch-mobile','padding-top','20',0,''),(12188,3849,'114327','watch-mobile','padding-left','30',0,''),(12189,3849,'114327','watch-mobile','padding-bottom','20',0,''),(12192,3849,'114327','watch-mobile','margin-bottom','20',0,''),(12195,3850,'114328','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(12196,3850,'114328','watch-mobile','padding-top','20',0,''),(12197,3852,'114330','watch-mobile','link','shipping_method',0,''),(12198,3852,'114330','watch-mobile','float','right',0,''),(12199,3852,'114330','watch-mobile','margin-top','-31',0,''),(12200,3853,'114331','watch-mobile','link','contact_information',0,''),(12201,3853,'114331','watch-mobile','margin-top','-31',0,''),(12202,3853,'114331','watch-mobile','float','right',0,''),(12203,3854,'114332','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(12204,3856,'114334','watch-mobile','link','shipping_address',0,''),(12205,3856,'114334','watch-mobile','float','right',0,''),(12206,3856,'114334','watch-mobile','margin-top','-31',0,''),(12207,3857,'114335','watch-mobile','margin-bottom','20',0,''),(12208,3858,'114336','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(12209,3858,'114336','watch-mobile','clear','none',0,''),(12210,3859,'114337','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(12211,3859,'114337','watch-mobile','clear','none',0,''),(12212,3861,'114339','watch-mobile','block_type','1',0,''),(12213,3861,'114339','watch-mobile','padding-left','30',0,''),(12214,3861,'114339','watch-mobile','border-left-width','20',0,''),(12215,3861,'114339','watch-mobile','border-left-color','$border-color-1',0,''),(12216,3861,'114339','watch-mobile','margin-left','-10',0,''),(12217,3861,'114339','watch-mobile','padding-right','30',0,''),(12218,3861,'114339','watch-mobile','padding-top','20',0,''),(12219,3861,'114339','watch-mobile','padding-bottom','20',0,''),(12221,3862,'114340','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(12222,3862,'114340','watch-mobile','clear','none',0,''),(12223,3863,'114341','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(12224,3864,'114342','watch-mobile','link','payment_method',0,''),(12225,3864,'114342','watch-mobile','float','right',0,''),(12226,3864,'114342','watch-mobile','margin-top','-31',0,''),(12227,3865,'114343','watch-mobile','margin-bottom','20',0,''),(12228,3866,'114344','watch-mobile','link','billing_address',0,''),(12229,3866,'114344','watch-mobile','float','right',0,''),(12230,3866,'114344','watch-mobile','margin-top','-31',0,''),(12231,3867,'114345','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(12232,3867,'114345','watch-mobile','clear','none',0,''),(12233,3869,'114347','watch-mobile','block_type','1',0,''),(12234,3869,'114347','watch-mobile','padding-top','20',0,''),(12235,3869,'114347','watch-mobile','padding-left','20',0,''),(12236,3869,'114347','watch-mobile','padding-right','20',0,''),(12237,3869,'114347','watch-mobile','padding-bottom','20',0,''),(12238,3869,'114347','watch-mobile','background-color','$background-7',0,''),(12239,3869,'114347','watch-mobile','style_class','order-summary',0,''),(12240,3871,'114349','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(12241,3872,'114350','watch-mobile','margin-bottom','20',0,''),(12242,3872,'114350','watch-mobile','text-align','right',0,''),(12243,3873,'75599','watch-mobile','block_type','1',0,''),(12244,3874,'75600','watch-mobile','block_type','2',0,''),(12245,3874,'75600','watch-mobile','font-weight','400',0,''),(12246,3874,'75600','watch-mobile','padding-bottom','20',0,''),(12247,3874,'75600','watch-mobile','schema','2-2',0,''),(12248,3874,'75600','watch-mobile','schema','2-2',0,'291'),(12249,3876,'75602','watch-mobile','street_heading','90',0,''),(12250,3877,'75603','watch-mobile','block_type','2',0,''),(12251,3877,'75603','watch-mobile','font-weight','400',0,''),(12252,3877,'75603','watch-mobile','padding-bottom','20',0,''),(12253,3877,'75603','watch-mobile','schema','2-2',0,'291'),(12254,3878,'75604','watch-mobile','show_captcha','on',0,''),(12255,3879,'75605','watch-mobile','font-weight','400',0,''),(12256,3879,'75605','watch-mobile','padding-left','40',0,''),(12257,3879,'75605','watch-mobile','time_format','24',0,''),(12258,3879,'75605','watch-mobile','show_icons','on',0,''),(12259,3879,'75605','watch-mobile','padding-left','0',0,'291'),(12260,3881,'114351','watch-mobile','block_type','1',0,''),(12261,3882,'114352','watch-mobile','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(12262,3882,'114352','watch-mobile','margin-bottom','40',0,''),(12263,3883,'114353','watch-mobile','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(12264,3884,'114354','watch-mobile','width','680',0,''),(12265,3884,'114354','watch-mobile','font-weight','normal',0,''),(12266,3884,'114354','watch-mobile','font-size','12',0,''),(12267,3884,'114354','watch-mobile','padding-top','20',0,''),(12268,3884,'114354','watch-mobile','padding-bottom','20',0,''),(12269,3884,'114354','watch-mobile','color','$color-font-7',0,''),(12270,3885,'114355','watch-mobile','block_type','4',0,''),(12271,3885,'114355','watch-mobile','font-weight','normal',0,''),(12272,3885,'114355','watch-mobile','border-top-width','1',0,''),(12273,3885,'114355','watch-mobile','border-top-color','$border-color-1',0,''),(12274,3885,'114355','watch-mobile','border-left-width','1',0,''),(12275,3885,'114355','watch-mobile','border-left-color','$border-color-1',0,''),(12276,3885,'114355','watch-mobile','border-right-width','1',0,''),(12277,3885,'114355','watch-mobile','border-right-color','$border-color-1',0,''),(12278,3885,'114355','watch-mobile','border-bottom-width','1',0,''),(12279,3885,'114355','watch-mobile','border-bottom-color','$border-color-1',0,''),(12280,3886,'114356','watch-mobile','block_type','2',0,''),(12281,3886,'114356','watch-mobile','font-weight','normal',0,''),(12282,3886,'114356','watch-mobile','border-top-width','1',0,''),(12283,3886,'114356','watch-mobile','border-top-color','$border-color-1',0,''),(12284,3886,'114356','watch-mobile','border-right-width','1',0,''),(12285,3886,'114356','watch-mobile','border-right-color','$border-color-1',0,''),(12286,3887,'114357','watch-mobile','block_type','1',0,''),(12287,3887,'114357','watch-mobile','font-weight','normal',0,''),(12288,3887,'114357','watch-mobile','padding-top','10',0,''),(12289,3887,'114357','watch-mobile','padding-left','10',0,''),(12290,3887,'114357','watch-mobile','padding-right','10',0,''),(12291,3887,'114357','watch-mobile','padding-bottom','10',0,''),(12292,3887,'114357','watch-mobile','border-right-width','1',0,''),(12293,3887,'114357','watch-mobile','border-right-color','$border-color-1',0,''),(12294,3888,'114358','watch-mobile','text','<p>Shipping via</p>',1,''),(12295,3888,'114358','watch-mobile','font-weight','bold',0,''),(12296,3888,'114358','watch-mobile','font-size','14',0,''),(12297,3890,'114360','watch-mobile','block_type','1',0,''),(12298,3890,'114360','watch-mobile','font-weight','normal',0,''),(12299,3890,'114360','watch-mobile','padding-top','10',0,''),(12300,3890,'114360','watch-mobile','padding-left','10',0,''),(12301,3890,'114360','watch-mobile','padding-right','10',0,''),(12302,3890,'114360','watch-mobile','padding-bottom','10',0,''),(12303,3892,'114362','watch-mobile','text','<p>Shipping service</p>',1,''),(12304,3892,'114362','watch-mobile','font-weight','bold',0,''),(12305,3892,'114362','watch-mobile','font-size','14',0,''),(12306,3893,'114363','watch-mobile','block_type','2',0,''),(12307,3893,'114363','watch-mobile','font-weight','normal',0,''),(12308,3893,'114363','watch-mobile','border-right-width','1',0,''),(12309,3893,'114363','watch-mobile','border-right-color','$border-color-1',0,''),(12310,3894,'114364','watch-mobile','block_type','1',0,''),(12311,3894,'114364','watch-mobile','font-weight','400',0,''),(12312,3894,'114364','watch-mobile','background-color','$background-6',0,''),(12313,3894,'114364','watch-mobile','padding-top','10',0,''),(12314,3894,'114364','watch-mobile','padding-left','10',0,''),(12315,3894,'114364','watch-mobile','padding-right','10',0,''),(12316,3894,'114364','watch-mobile','padding-bottom','30',0,''),(12317,3895,'114365','watch-mobile','font-size','12',0,''),(12318,3896,'114366','watch-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(12319,3896,'114366','watch-mobile','font-size','14',0,''),(12320,3896,'114366','watch-mobile','font-weight','bold',0,''),(12321,3897,'114367','watch-mobile','block_type','1',0,''),(12322,3897,'114367','watch-mobile','font-weight','normal',0,''),(12323,3897,'114367','watch-mobile','padding-top','10',0,''),(12324,3897,'114367','watch-mobile','padding-left','10',0,''),(12325,3897,'114367','watch-mobile','padding-right','10',0,''),(12326,3897,'114367','watch-mobile','padding-bottom','10',0,''),(12327,3898,'114368','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(12328,3898,'114368','watch-mobile','font-weight','bold',0,''),(12329,3898,'114368','watch-mobile','font-size','14',0,''),(12330,3898,'114368','watch-mobile','padding-top','10',0,''),(12331,3899,'114369','watch-mobile','font-weight','normal',0,''),(12332,3901,'114371','watch-mobile','text','<p>PHONE NUMBER:</p>',1,''),(12333,3901,'114371','watch-mobile','font-size','14',0,''),(12334,3901,'114371','watch-mobile','font-weight','bold',0,''),(12335,3901,'114371','watch-mobile','padding-top','10',0,''),(12336,3902,'114372','watch-mobile','text','<p>CUSTOMER:</p>',1,''),(12337,3902,'114372','watch-mobile','font-size','13',0,''),(12338,3902,'114372','watch-mobile','font-weight','bold',0,''),(12339,3903,'114373','watch-mobile','font-weight','normal',0,''),(12340,3904,'114374','watch-mobile','font-weight','normal',0,''),(12341,3904,'114374','watch-mobile','text-align','center',0,''),(12342,3904,'114374','watch-mobile','padding-bottom','10',0,''),(12343,3905,'114375','watch-mobile','text','<p>Payment date:</p>',1,''),(12344,3905,'114375','watch-mobile','font-weight','bold',0,''),(12345,3905,'114375','watch-mobile','text-align','center',0,''),(12346,3905,'114375','watch-mobile','font-size','12',0,''),(12347,3906,'114376','watch-mobile','font-size','14',0,''),(12348,3906,'114376','watch-mobile','font-weight','bold',0,''),(12349,3906,'114376','watch-mobile','text-align','center',0,''),(12350,3906,'114376','watch-mobile','padding-bottom','10',0,''),(12351,3906,'114376','watch-mobile','padding-top','10',0,''),(12352,3907,'114377','watch-mobile','block_type','5',0,''),(12353,3907,'114377','watch-mobile','font-weight','normal',0,''),(12354,3907,'114377','watch-mobile','border-bottom-width','1',0,''),(12355,3907,'114377','watch-mobile','border-bottom-color','$border-color-1',0,''),(12356,3907,'114377','watch-mobile','border-top-width','1',0,''),(12357,3907,'114377','watch-mobile','border-top-color','$border-color-1',0,''),(12358,3907,'114377','watch-mobile','border-left-color','$border-color-1',0,''),(12359,3907,'114377','watch-mobile','border-left-width','1',0,''),(12360,3908,'114378','watch-mobile','block_type','1',0,''),(12361,3908,'114378','watch-mobile','font-weight','normal',0,''),(12362,3908,'114378','watch-mobile','padding-top','10',0,''),(12363,3908,'114378','watch-mobile','padding-left','10',0,''),(12364,3908,'114378','watch-mobile','padding-right','10',0,''),(12365,3909,'114379','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(12366,3909,'114379','watch-mobile','font-size','14',0,''),(12367,3909,'114379','watch-mobile','font-weight','bold',0,''),(12368,3909,'114379','watch-mobile','padding-bottom','10',0,''),(12369,3910,'114380','watch-mobile','font-weight','400',0,''),(12370,3910,'114380','watch-mobile','line-height','120',0,''),(12371,3910,'114380','watch-mobile','line_height_measure','%',0,''),(12372,3910,'114380','watch-mobile','font-size','12',0,''),(12373,3911,'114381','watch-mobile','block_type','1',0,''),(12374,3911,'114381','watch-mobile','background-color','$background-6',0,''),(12375,3911,'114381','watch-mobile','padding-top','20',0,''),(12376,3911,'114381','watch-mobile','padding-left','10',0,''),(12377,3911,'114381','watch-mobile','padding-right','10',0,''),(12378,3911,'114381','watch-mobile','padding-bottom','20',0,''),(12379,3911,'114381','watch-mobile','font-size','14',0,''),(12380,3912,'114382','watch-mobile','block_type','2',0,''),(12381,3912,'114382','watch-mobile','font-weight','normal',0,''),(12382,3912,'114382','watch-mobile','padding-bottom','20',0,''),(12383,3913,'114383','watch-mobile','font-weight','400',0,''),(12384,3913,'114383','watch-mobile','padding-top','20',0,''),(12386,3914,'114384','watch-mobile','block_type','1',0,''),(12387,3915,'114385','watch-mobile','font-weight','normal',0,''),(12388,3915,'114385','watch-mobile','text-align','right',0,''),(12389,3915,'114385','watch-mobile','padding-bottom','10',0,''),(12390,3915,'114385','watch-mobile','address_spacer',',',0,''),(12391,3915,'114385','watch-mobile','font-size','12',0,''),(12392,3916,'114386','watch-mobile','block_type','11',0,''),(12393,3916,'114386','watch-mobile','font-weight','normal',0,''),(12394,3917,'114387','watch-mobile','text','<p>Email:</p>',1,''),(12395,3917,'114387','watch-mobile','font-weight','normal',0,''),(12396,3917,'114387','watch-mobile','text-align','right',0,''),(12397,3918,'114388','watch-mobile','font-weight','normal',0,''),(12398,3918,'114388','watch-mobile','text-align','right',0,''),(12399,3919,'114389','watch-mobile','block_type','11',0,''),(12400,3919,'114389','watch-mobile','font-weight','normal',0,''),(12401,3920,'114390','watch-mobile','text','<p>Phone:</p>',1,''),(12402,3920,'114390','watch-mobile','font-weight','normal',0,''),(12403,3920,'114390','watch-mobile','text-align','right',0,''),(12404,3921,'114391','watch-mobile','font-weight','normal',0,''),(12405,3921,'114391','watch-mobile','text-align','right',0,''),(12406,3922,'114392','watch-mobile','block_type','11',0,''),(12407,3922,'114392','watch-mobile','font-weight','normal',0,''),(12408,3923,'114393','watch-mobile','text','<p>Web:</p>',1,''),(12409,3923,'114393','watch-mobile','font-weight','normal',0,''),(12410,3923,'114393','watch-mobile','text-align','right',0,''),(12411,3924,'114394','watch-mobile','font-weight','normal',0,''),(12412,3924,'114394','watch-mobile','text-align','right',0,''),(12413,3925,'114395','watch-mobile','font-weight','400',0,''),(12414,3925,'114395','watch-mobile','padding-top','20',0,''),(12415,3925,'114395','watch-mobile','padding-bottom','0',0,''),(12416,3925,'114395','watch-mobile','font-size','12',0,''),(12417,3926,'114396','watch-mobile','block_type','3',0,''),(12418,3926,'114396','watch-mobile','font-weight','normal',0,''),(12419,3926,'114396','watch-mobile','padding-top','20',0,''),(12420,3927,'114397','watch-mobile','font-size','12',0,''),(12421,3928,'114398','watch-mobile','text','<p>If undelivered please return to:</p>',1,''),(12422,3928,'114398','watch-mobile','font-size','12',0,''),(12423,3928,'114398','watch-mobile','font-weight','bold',0,''),(12424,3929,'114399','watch-mobile','text','<p>Thank you for your order</p>',1,''),(12425,3929,'114399','watch-mobile','color','$color-font-10',0,''),(12426,3929,'114399','watch-mobile','font-size','13',0,''),(12427,3929,'114399','watch-mobile','font-weight','bold',0,''),(12428,3929,'114399','watch-mobile','padding-top','5',0,''),(12429,3929,'114399','watch-mobile','text-align','center',0,''),(12430,3930,'114400','watch-mobile','font-weight','400',0,''),(12431,3930,'114400','watch-mobile','text-align','center',0,''),(12432,3930,'114400','watch-mobile','padding-top','0',0,''),(12434,3930,'114400','watch-mobile','padding-left','20',0,''),(12435,3930,'114400','watch-mobile','padding-right','20',0,''),(12436,3931,'114401','watch-mobile','block_type','6',0,''),(12437,3931,'114401','watch-mobile','font-weight','normal',0,''),(12438,3931,'114401','watch-mobile','font-size','16',0,''),(12439,3932,'114402','watch-mobile','text','<p>Phone:</p>',1,''),(12440,3932,'114402','watch-mobile','font-weight','normal',0,''),(12441,3932,'114402','watch-mobile','text-align','right',0,''),(12442,3932,'114402','watch-mobile','font-size','12',0,''),(12443,3933,'114403','watch-mobile','font-weight','normal',0,''),(12444,3933,'114403','watch-mobile','text-align','right',0,''),(12445,3933,'114403','watch-mobile','font-size','12',0,''),(12446,3934,'114404','watch-mobile','block_type','6',0,''),(12447,3934,'114404','watch-mobile','font-weight','normal',0,''),(12448,3934,'114404','watch-mobile','font-size','16',0,''),(12449,3935,'114405','watch-mobile','text','<p>Email:</p>',1,''),(12450,3935,'114405','watch-mobile','font-weight','normal',0,''),(12451,3935,'114405','watch-mobile','text-align','right',0,''),(12452,3935,'114405','watch-mobile','font-size','12',0,''),(12453,3936,'114406','watch-mobile','font-weight','normal',0,''),(12454,3936,'114406','watch-mobile','text-align','right',0,''),(12455,3936,'114406','watch-mobile','font-size','12',0,''),(12456,3937,'114407','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(12457,3937,'114407','watch-mobile','font-size','12',0,''),(12458,3937,'114407','watch-mobile','font-weight','bold',0,''),(12459,3937,'114407','watch-mobile','text-align','right',0,''),(12460,3940,'75609','watch-mobile','text-align','center',0,''),(12461,3940,'75609','watch-mobile','padding-top','10',0,''),(12462,3946,'75615','watch-mobile','heading_type','h1',0,''),(12463,3949,'114410','watch-mobile','text-align','center',0,''),(12464,3949,'114410','watch-mobile','padding-top','10',0,''),(12465,3954,'75616','watch-mobile','font-weight','normal',0,''),(12466,3954,'75616','watch-mobile','padding-top','20',0,''),(12467,3954,'75616','watch-mobile','padding-left','10',0,''),(12468,3954,'75616','watch-mobile','padding-right','10',0,''),(12469,3954,'75616','watch-mobile','padding-bottom','20',0,''),(12470,3954,'75616','watch-mobile','color','$color-font-7',0,''),(12471,3954,'75616','watch-mobile','font-size','14',0,''),(12472,3955,'75617','watch-mobile','block_type','2',0,''),(12473,3955,'75617','watch-mobile','font-weight','normal',0,''),(12474,3956,'75618','watch-mobile','font-weight','normal',0,''),(12475,3956,'75618','watch-mobile','padding-bottom','20',0,''),(12476,3956,'75618','watch-mobile','logo','themes/watch-mobile/img/watchlogo-1-1.png',1,''),(12477,3957,'75619','watch-mobile','color','$color-font-7',0,''),(12478,3957,'75619','watch-mobile','font-size','14',0,''),(12479,3957,'75619','watch-mobile','padding-top','20',0,''),(12480,3957,'75619','watch-mobile','padding-bottom','20',0,''),(12481,3957,'75619','watch-mobile','border-top-width','1',0,''),(12482,3957,'75619','watch-mobile','border-top-color','$border-color-10',0,''),(12483,3958,'75620','watch-mobile','block_type','1',0,''),(12484,3959,'75621','watch-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',1,''),(12485,3959,'75621','watch-mobile','font-weight','normal',0,''),(12486,3959,'75621','watch-mobile','color','$color-font-7',0,''),(12487,3959,'75621','watch-mobile','font-size','14',0,''),(12488,3960,'75622','watch-mobile','block_type','2',0,''),(12489,3960,'75622','watch-mobile','font-weight','normal',0,''),(12490,3960,'75622','watch-mobile','background-color','$background-2',0,''),(12491,3960,'75622','watch-mobile','padding-top','5',0,''),(12492,3960,'75622','watch-mobile','padding-left','10',0,''),(12493,3960,'75622','watch-mobile','padding-right','10',0,''),(12494,3960,'75622','watch-mobile','padding-bottom','5',0,''),(12495,3961,'75623','watch-mobile','color','$color-font-1',0,''),(12496,3961,'75623','watch-mobile','font-size','14',0,''),(12497,3961,'75623','watch-mobile','font-weight','normal',0,''),(12498,3962,'75624','watch-mobile','font-weight','normal',0,''),(12499,3962,'75624','watch-mobile','text-align','right',0,''),(12500,3962,'75624','watch-mobile','color','$color-font-1',0,''),(12501,3962,'75624','watch-mobile','font-size','12',0,''),(12502,3963,'114415','watch-mobile','block_type','1',0,''),(12503,3964,'114416','watch-mobile','block_type','1',0,''),(12504,3964,'114416','watch-mobile','max-width','800',0,''),(12505,3964,'114416','watch-mobile','margin','0 auto',0,''),(12506,3964,'114416','watch-mobile','background-color','$background-7',0,''),(12507,3965,'114417','watch-mobile','font-weight','normal',0,''),(12508,3965,'114417','watch-mobile','padding-top','20',0,''),(12509,3965,'114417','watch-mobile','padding-left','10',0,''),(12510,3965,'114417','watch-mobile','padding-right','10',0,''),(12511,3965,'114417','watch-mobile','padding-bottom','20',0,''),(12512,3965,'114417','watch-mobile','color','$color-font-7',0,''),(12513,3965,'114417','watch-mobile','font-size','14',0,''),(12514,3966,'114418','watch-mobile','block_type','7',0,''),(12515,3966,'114418','watch-mobile','font-weight','normal',0,''),(12516,3966,'114418','watch-mobile','background-color','$background-2',0,''),(12517,3966,'114418','watch-mobile','padding-top','5',0,''),(12518,3966,'114418','watch-mobile','padding-left','10',0,''),(12519,3966,'114418','watch-mobile','padding-right','10',0,''),(12520,3966,'114418','watch-mobile','padding-bottom','5',0,''),(12521,3967,'114419','watch-mobile','color','$color-font-1',0,''),(12522,3967,'114419','watch-mobile','font-size','15',0,''),(12523,3967,'114419','watch-mobile','font-weight','700',0,''),(12524,3968,'114420','watch-mobile','font-weight','normal',0,''),(12525,3968,'114420','watch-mobile','text-align','right',0,''),(12526,3968,'114420','watch-mobile','color','$color-font-8',0,''),(12527,3968,'114420','watch-mobile','font-size','12',0,''),(12528,3969,'114421','watch-mobile','color','$color-font-7',0,''),(12529,3969,'114421','watch-mobile','font-size','12',0,''),(12530,3969,'114421','watch-mobile','padding-top','20',0,''),(12531,3969,'114421','watch-mobile','padding-bottom','20',0,''),(12532,3969,'114421','watch-mobile','border-top-width','1',0,''),(12533,3969,'114421','watch-mobile','border-top-color','$border-color-1',0,''),(12534,3970,'114422','watch-mobile','font-weight','normal',0,''),(12535,3970,'114422','watch-mobile','padding-bottom','10',0,''),(12536,3970,'114422','watch-mobile','background-color','$background-2',0,''),(12537,3970,'114422','watch-mobile','logo','themes/watch-mobile/img/logo-white-1.png',1,''),(12538,3970,'114422','watch-mobile','padding-left','20',0,''),(12539,3970,'114422','watch-mobile','padding-top','10',0,''),(12540,3971,'114423','watch-mobile','block_type','1',0,''),(12541,3971,'114423','watch-mobile','background-color','$background-6',0,''),(12542,3972,'114424','watch-mobile','block_type','1',0,''),(12543,3972,'114424','watch-mobile','max-width','800',0,''),(12544,3972,'114424','watch-mobile','margin','0 auto',0,''),(12545,3973,'114425','watch-mobile','font-weight','normal',0,''),(12546,3973,'114425','watch-mobile','padding-bottom','10',0,''),(12547,3973,'114425','watch-mobile','padding-top','10',0,''),(12548,3973,'114425','watch-mobile','text-align','center',0,''),(12549,3973,'114425','watch-mobile','logo_from','theme',0,''),(12550,3974,'114426','watch-mobile','color','$color-font-8',0,''),(12551,3974,'114426','watch-mobile','font-size','12',0,''),(12552,3974,'114426','watch-mobile','padding-top','20',0,''),(12553,3974,'114426','watch-mobile','padding-bottom','20',0,''),(12554,3974,'114426','watch-mobile','text-align','center',0,''),(12555,3975,'114427','watch-mobile','block_type','1',0,''),(12556,3975,'114427','watch-mobile','background-color','$background-7',0,''),(12557,3975,'114427','watch-mobile','padding-top','20',0,''),(12558,3975,'114427','watch-mobile','padding-left','20',0,''),(12559,3975,'114427','watch-mobile','padding-right','20',0,''),(12560,3975,'114427','watch-mobile','padding-bottom','20',0,''),(12561,3976,'114428','watch-mobile','block_type','7',0,''),(12562,3976,'114428','watch-mobile','font-weight','normal',0,''),(12563,3976,'114428','watch-mobile','padding-left','10',0,''),(12564,3976,'114428','watch-mobile','padding-right','10',0,''),(12565,3976,'114428','watch-mobile','padding-bottom','15',0,''),(12566,3976,'114428','watch-mobile','border-bottom-width','1',0,''),(12567,3976,'114428','watch-mobile','border-bottom-color','$border-color-1',0,''),(12568,3977,'114429','watch-mobile','color','$color-font-7',0,''),(12569,3977,'114429','watch-mobile','font-size','14',0,''),(12570,3977,'114429','watch-mobile','font-weight','700',0,''),(12571,3978,'114430','watch-mobile','font-weight','normal',0,''),(12572,3978,'114430','watch-mobile','text-align','right',0,''),(12573,3978,'114430','watch-mobile','color','$color-font-8',0,''),(12574,3978,'114430','watch-mobile','font-size','11',0,''),(12575,3978,'114430','watch-mobile','text-transform','uppercase',0,''),(12576,3979,'114431','watch-mobile','font-weight','normal',0,''),(12577,3979,'114431','watch-mobile','padding-top','20',0,''),(12578,3979,'114431','watch-mobile','padding-bottom','20',0,''),(12579,3979,'114431','watch-mobile','color','$color-font-7',0,''),(12580,3979,'114431','watch-mobile','font-size','14',0,''),(12581,3980,'114432','watch-mobile','block_type','1',0,''),(12582,3980,'114432','watch-mobile','background-color','$background-6',0,''),(12583,3980,'114432','watch-mobile','padding-top','20',0,''),(12584,3980,'114432','watch-mobile','padding-bottom','20',0,''),(12585,3981,'114433','watch-mobile','block_type','1',0,''),(12586,3981,'114433','watch-mobile','max-width','800',0,''),(12587,3981,'114433','watch-mobile','margin','0 auto',0,''),(12588,3982,'114434','watch-mobile','block_type','1',0,''),(12589,3982,'114434','watch-mobile','background-color','$background-7',0,''),(12590,3982,'114434','watch-mobile','padding-top','20',0,''),(12591,3982,'114434','watch-mobile','padding-left','20',0,''),(12592,3982,'114434','watch-mobile','padding-right','20',0,''),(12593,3982,'114434','watch-mobile','padding-bottom','20',0,''),(12594,3982,'114434','watch-mobile','border-top-width','1',0,''),(12595,3982,'114434','watch-mobile','border-left-width','1',0,''),(12596,3982,'114434','watch-mobile','border-right-width','1',0,''),(12597,3982,'114434','watch-mobile','border-bottom-width','1',0,''),(12598,3982,'114434','watch-mobile','border-top-color','$border-color-1',0,''),(12599,3982,'114434','watch-mobile','border-left-color','$border-color-1',0,''),(12600,3982,'114434','watch-mobile','border-bottom-color','$border-color-1',0,''),(12601,3982,'114434','watch-mobile','border-right-color','$border-color-1',0,''),(12602,3983,'114435','watch-mobile','font-weight','normal',0,''),(12603,3983,'114435','watch-mobile','padding-top','20',0,''),(12604,3983,'114435','watch-mobile','padding-bottom','20',0,''),(12605,3983,'114435','watch-mobile','color','$color-font-7',0,''),(12606,3983,'114435','watch-mobile','font-size','14',0,''),(12607,3984,'114436','watch-mobile','block_type','2',0,''),(12608,3985,'114437','watch-mobile','font-weight','normal',0,''),(12609,3985,'114437','watch-mobile','padding-bottom','10',0,''),(12610,3985,'114437','watch-mobile','padding-top','10',0,''),(12611,3985,'114437','watch-mobile','logo_from','theme',0,''),(12612,3986,'114438','watch-mobile','color','$color-font-7',0,''),(12613,3986,'114438','watch-mobile','font-size','14',0,''),(12614,3986,'114438','watch-mobile','font-weight','700',0,''),(12615,3986,'114438','watch-mobile','text-align','right',0,''),(12616,3987,'114439','watch-mobile','font-weight','normal',0,''),(12617,3987,'114439','watch-mobile','text-align','right',0,''),(12618,3987,'114439','watch-mobile','color','$color-font-8',0,''),(12619,3987,'114439','watch-mobile','font-size','11',0,''),(12620,3987,'114439','watch-mobile','text-transform','uppercase',0,''),(12621,3988,'114440','watch-mobile','color','$color-font-8',0,''),(12622,3988,'114440','watch-mobile','font-size','12',0,''),(12623,3988,'114440','watch-mobile','padding-top','20',0,''),(12624,3988,'114440','watch-mobile','padding-bottom','20',0,''),(12625,3988,'114440','watch-mobile','text-align','left',0,''),(12626,3989,'75625','watch-mobile','block_type','1',0,''),(12627,3989,'75625','watch-mobile','font-weight','normal',0,''),(12628,3989,'75625','watch-mobile','margin-top','40',0,''),(12629,3990,'75628','watch-mobile','block_type','1',0,''),(12630,3991,'75629','watch-mobile','text','Account',1,''),(12631,3991,'75629','watch-mobile','style_class','footerTitle',0,''),(12632,3991,'75629','watch-mobile','font-family','$font-1',0,''),(12633,3991,'75629','watch-mobile','font-size','18',0,''),(12634,3991,'75629','watch-mobile','text-transform','uppercase',0,''),(12635,3992,'75630','watch-mobile','class','menu-style-2',0,''),(12636,3992,'75630','watch-mobile','padding-top','10',0,''),(12637,3992,'75630','watch-mobile','padding-bottom','20',0,''),(12638,3993,'75632','watch-mobile','border-top-width','1',0,''),(12639,3993,'75632','watch-mobile','border-top-color','$border-color-1',0,''),(12640,3993,'75632','watch-mobile','padding-top','20',0,''),(12641,3994,'75633','watch-mobile','block_type','1',0,''),(12642,3995,'75634','watch-mobile','class','menu-style-2',0,''),(12643,3995,'75634','watch-mobile','padding-top','10',0,''),(12644,3995,'75634','watch-mobile','padding-bottom','20',0,''),(12645,3996,'75635','watch-mobile','text','Shop',1,''),(12646,3996,'75635','watch-mobile','style_class','footerTitle',0,''),(12649,3996,'75635','watch-mobile','font-family','$font-1',0,''),(12650,3996,'75635','watch-mobile','font-size','18',0,''),(12651,3996,'75635','watch-mobile','text-transform','uppercase',0,''),(12652,3997,'75636','watch-mobile','block_type','1',0,''),(12653,3998,'75637','watch-mobile','text','Products',1,''),(12654,3998,'75637','watch-mobile','style_class','footerTitle',0,''),(12657,3998,'75637','watch-mobile','font-family','$font-1',0,''),(12658,3998,'75637','watch-mobile','text-transform','uppercase',0,''),(12659,3998,'75637','watch-mobile','font-size','18',0,''),(12660,3999,'75638','watch-mobile','class','menu-style-2',0,''),(12661,3999,'75638','watch-mobile','padding-top','10',0,''),(12662,3999,'75638','watch-mobile','padding-bottom','20',0,''),(12663,4000,'75640','watch-mobile','block_type','1',0,''),(12664,4001,'75641','watch-mobile','view_item','address',0,''),(12665,4001,'75641','watch-mobile','address_spacer',',<span> </span>',0,''),(12666,4001,'75641','watch-mobile','padding-top','10',0,''),(12667,4001,'75641','watch-mobile','padding-bottom','20',0,''),(12668,4002,'75642','watch-mobile','text','Contact Us',1,''),(12669,4002,'75642','watch-mobile','style_class','footerTitle',0,''),(12672,4002,'75642','watch-mobile','font-family','$font-1',0,''),(12673,4002,'75642','watch-mobile','font-size','18',0,''),(12674,4002,'75642','watch-mobile','text-transform','uppercase',0,''),(12675,4003,'114441','watch-mobile','block_type','5',0,''),(12676,4004,'114442','watch-mobile','text','##TEXT_LANGUAGE##',0,''),(12677,4006,'114444','watch-mobile','block_type','5',0,''),(12678,4007,'114445','watch-mobile','text','##TEXT_CURRENCY##',0,''),(12679,4009,'75650','watch-mobile','block_type','1',0,''),(12680,4009,'75650','watch-mobile','font-weight','normal',0,''),(12681,4010,'75651','watch-mobile','block_type','2',0,''),(12682,4010,'75651','watch-mobile','font-weight','normal',0,''),(12683,4010,'75651','watch-mobile','padding-bottom','20',0,''),(12684,4011,'75652','watch-mobile','block_type','1',0,''),(12685,4011,'75652','watch-mobile','margin-right','20',0,''),(12686,4012,'75653','watch-mobile','block_type','1',0,''),(12687,4012,'75653','watch-mobile','font-weight','normal',0,''),(12688,4012,'75653','watch-mobile','style_class','gift-card-view',0,''),(12689,4012,'75653','watch-mobile','text-align','center',0,''),(12690,4012,'75653','watch-mobile','padding-bottom','20',0,''),(12691,4012,'75653','watch-mobile','background-color','$background-2',0,''),(12692,4012,'75653','watch-mobile','padding-left','20',0,''),(12693,4012,'75653','watch-mobile','padding-right','20',0,''),(12694,4012,'75653','watch-mobile','color','$color-font-2',0,''),(12695,4013,'75654','watch-mobile','block_type','1',0,''),(12696,4013,'75654','watch-mobile','font-weight','normal',0,''),(12697,4013,'75654','watch-mobile','padding-top','10',0,''),(12698,4014,'75655','watch-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(12699,4014,'75655','watch-mobile','font-weight','normal',0,''),(12700,4014,'75655','watch-mobile','text-align','center',0,''),(12701,4014,'75655','watch-mobile','font-size','12',0,''),(12702,4014,'75655','watch-mobile','padding-top','10',0,''),(12703,4014,'75655','watch-mobile','padding-bottom','5',0,''),(12704,4014,'75655','watch-mobile','border-top-width','1',0,''),(12705,4014,'75655','watch-mobile','border-top-color','$border-color-7',0,''),(12706,4015,'75656','watch-mobile','font-size','12',0,''),(12707,4015,'75656','watch-mobile','font-weight','bold',0,''),(12708,4015,'75656','watch-mobile','text-align','center',0,''),(12709,4015,'75656','watch-mobile','style_class','email',0,''),(12710,4016,'75657','watch-mobile','font-size','12',0,''),(12711,4016,'75657','watch-mobile','font-weight','bold',0,''),(12712,4016,'75657','watch-mobile','text-align','center',0,''),(12713,4016,'75657','watch-mobile','style_class','phone',0,''),(12714,4016,'75657','watch-mobile','padding-bottom','5',0,''),(12715,4017,'75658','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(12716,4017,'75658','watch-mobile','font-weight','normal',0,''),(12717,4017,'75658','watch-mobile','text-align','center',0,''),(12718,4017,'75658','watch-mobile','padding-top','20',0,''),(12719,4017,'75658','watch-mobile','padding-bottom','10',0,''),(12720,4017,'75658','watch-mobile','style_class','question-ico',0,''),(12721,4017,'75658','watch-mobile','border-top-width','1',0,''),(12722,4017,'75658','watch-mobile','border-top-color','$border-color-7',0,''),(12723,4017,'75658','watch-mobile','font-size','18',0,''),(12724,4018,'75659','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(12725,4018,'75659','watch-mobile','font-size','18',0,''),(12726,4018,'75659','watch-mobile','font-weight','normal',0,''),(12727,4018,'75659','watch-mobile','text-align','center',0,''),(12728,4018,'75659','watch-mobile','padding-top','20',0,''),(12729,4018,'75659','watch-mobile','padding-bottom','10',0,''),(12730,4018,'75659','watch-mobile','border-top-width','1',0,''),(12731,4018,'75659','watch-mobile','border-top-color','$border-color-7',0,''),(12732,4019,'75660','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(12733,4019,'75660','watch-mobile','font-weight','normal',0,''),(12734,4019,'75660','watch-mobile','text-align','center',0,''),(12735,4019,'75660','watch-mobile','padding-bottom','10',0,''),(12736,4019,'75660','watch-mobile','font-size','14',0,''),(12737,4020,'75661','watch-mobile','text','<p>GIFT CARD</p>',1,''),(12738,4020,'75661','watch-mobile','font-size','30',0,''),(12739,4020,'75661','watch-mobile','font-weight','normal',0,''),(12740,4020,'75661','watch-mobile','border-top-width','1',0,''),(12741,4020,'75661','watch-mobile','border-top-color','$border-color-7',0,''),(12742,4020,'75661','watch-mobile','style_class','gift-ico',0,''),(12743,4020,'75661','watch-mobile','text-align','center',0,''),(12744,4020,'75661','watch-mobile','padding-top','15',0,''),(12745,4021,'75662','watch-mobile','block_type','4',0,''),(12746,4021,'75662','watch-mobile','color','$color-font-1',0,''),(12747,4021,'75662','watch-mobile','font-size','30',0,''),(12748,4021,'75662','watch-mobile','font-weight','normal',0,''),(12749,4021,'75662','watch-mobile','background-color','$background-5',0,''),(12750,4021,'75662','watch-mobile','padding-top','5',0,''),(12751,4021,'75662','watch-mobile','padding-left','10',0,''),(12752,4021,'75662','watch-mobile','padding-right','10',0,''),(12753,4021,'75662','watch-mobile','padding-bottom','5',0,''),(12754,4022,'75663','watch-mobile','text','<p>Your code is:</p>',1,''),(12755,4022,'75663','watch-mobile','font-weight','normal',0,''),(12756,4024,'75665','watch-mobile','font-weight','normal',0,''),(12757,4024,'75665','watch-mobile','text-align','center',0,''),(12758,4024,'75665','watch-mobile','padding-bottom','20',0,''),(12759,4025,'75666','watch-mobile','font-size','60',0,''),(12760,4025,'75666','watch-mobile','font-weight','bold',0,''),(12761,4025,'75666','watch-mobile','text-align','center',0,''),(12762,4025,'75666','watch-mobile','line-height','100',0,''),(12763,4025,'75666','watch-mobile','padding-bottom','20',0,''),(12764,4025,'75666','watch-mobile','line_height_measure','px',0,''),(12765,4026,'75667','watch-mobile','text','<p>HOLBI</p>',1,''),(12766,4026,'75667','watch-mobile','font-family','$font-1',0,''),(12767,4026,'75667','watch-mobile','font-size','24',0,''),(12768,4026,'75667','watch-mobile','font-weight','normal',0,''),(12769,4026,'75667','watch-mobile','text-align','center',0,''),(12770,4026,'75667','watch-mobile','padding-top','10',0,''),(12771,4026,'75667','watch-mobile','padding-bottom','20',0,''),(12772,4028,'75669','watch-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(12773,4028,'75669','watch-mobile','font-weight','normal',0,''),(12774,4028,'75669','watch-mobile','padding-bottom','20',0,''),(12775,4030,'114447','watch-mobile','block_type','1',0,''),(12776,4030,'114447','watch-mobile','font-weight','normal',0,''),(12777,4030,'114447','watch-mobile','style_class','gift-card-view',0,''),(12778,4030,'114447','watch-mobile','text-align','center',0,''),(12779,4030,'114447','watch-mobile','padding-bottom','20',0,''),(12780,4030,'114447','watch-mobile','background-color','$background-2',0,''),(12781,4030,'114447','watch-mobile','padding-left','20',0,''),(12782,4030,'114447','watch-mobile','padding-right','20',0,''),(12783,4030,'114447','watch-mobile','color','$color-font-2',0,''),(12784,4031,'114448','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(12785,4031,'114448','watch-mobile','font-weight','normal',0,''),(12786,4031,'114448','watch-mobile','text-align','center',0,''),(12787,4031,'114448','watch-mobile','padding-bottom','10',0,''),(12788,4031,'114448','watch-mobile','font-size','14',0,''),(12789,4032,'114449','watch-mobile','text','<p>GIFT CARD</p>',1,''),(12790,4032,'114449','watch-mobile','font-size','30',0,''),(12791,4032,'114449','watch-mobile','font-weight','normal',0,''),(12792,4032,'114449','watch-mobile','border-top-width','1',0,''),(12793,4032,'114449','watch-mobile','border-top-color','$border-color-7',0,''),(12794,4032,'114449','watch-mobile','style_class','gift-ico',0,''),(12795,4032,'114449','watch-mobile','text-align','center',0,''),(12796,4032,'114449','watch-mobile','padding-top','15',0,''),(12797,4033,'114450','watch-mobile','logo','themes/watch-mobile/img/logo-1.png',1,''),(12798,4034,'114451','watch-mobile','logo','themes/watch-mobile/img/bestseller-1.png',1,''),(12799,4035,'114452','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(12800,4035,'114452','watch-mobile','font-size','18',0,''),(12801,4035,'114452','watch-mobile','font-weight','normal',0,''),(12802,4035,'114452','watch-mobile','text-align','center',0,''),(12803,4035,'114452','watch-mobile','padding-top','20',0,''),(12804,4035,'114452','watch-mobile','padding-bottom','10',0,''),(12805,4035,'114452','watch-mobile','border-top-width','1',0,''),(12806,4035,'114452','watch-mobile','border-top-color','$border-color-7',0,''),(12807,4036,'114453','watch-mobile','font-size','60',0,''),(12808,4036,'114453','watch-mobile','font-weight','bold',0,''),(12809,4036,'114453','watch-mobile','text-align','center',0,''),(12810,4036,'114453','watch-mobile','line-height','100',0,''),(12811,4036,'114453','watch-mobile','padding-bottom','20',0,''),(12812,4036,'114453','watch-mobile','line_height_measure','px',0,''),(12813,4037,'114454','watch-mobile','font-weight','normal',0,''),(12814,4037,'114454','watch-mobile','text-align','center',0,''),(12815,4037,'114454','watch-mobile','padding-bottom','20',0,''),(12816,4038,'114455','watch-mobile','block_type','4',0,''),(12817,4038,'114455','watch-mobile','color','$color-font-1',0,''),(12818,4038,'114455','watch-mobile','font-size','30',0,''),(12819,4038,'114455','watch-mobile','font-weight','normal',0,''),(12820,4038,'114455','watch-mobile','background-color','$background-5',0,''),(12821,4038,'114455','watch-mobile','padding-top','5',0,''),(12822,4038,'114455','watch-mobile','padding-left','10',0,''),(12823,4038,'114455','watch-mobile','padding-right','10',0,''),(12824,4038,'114455','watch-mobile','padding-bottom','5',0,''),(12825,4039,'114456','watch-mobile','text','<p>Your code is:</p>',1,''),(12826,4039,'114456','watch-mobile','font-weight','normal',0,''),(12827,4041,'114458','watch-mobile','text','<p>HOLBI</p>',1,''),(12828,4041,'114458','watch-mobile','font-family','$font-1',0,''),(12829,4041,'114458','watch-mobile','font-size','24',0,''),(12830,4041,'114458','watch-mobile','font-weight','normal',0,''),(12831,4041,'114458','watch-mobile','text-align','center',0,''),(12832,4041,'114458','watch-mobile','padding-top','10',0,''),(12833,4041,'114458','watch-mobile','padding-bottom','20',0,''),(12834,4042,'114459','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(12835,4042,'114459','watch-mobile','font-weight','normal',0,''),(12836,4042,'114459','watch-mobile','text-align','center',0,''),(12837,4042,'114459','watch-mobile','padding-top','20',0,''),(12838,4042,'114459','watch-mobile','padding-bottom','10',0,''),(12839,4042,'114459','watch-mobile','style_class','question-ico',0,''),(12840,4042,'114459','watch-mobile','border-top-width','1',0,''),(12841,4042,'114459','watch-mobile','border-top-color','$border-color-7',0,''),(12842,4042,'114459','watch-mobile','font-size','18',0,''),(12843,4043,'114460','watch-mobile','block_type','1',0,''),(12844,4043,'114460','watch-mobile','font-weight','normal',0,''),(12845,4043,'114460','watch-mobile','padding-top','10',0,''),(12846,4044,'114461','watch-mobile','font-size','12',0,''),(12847,4044,'114461','watch-mobile','font-weight','bold',0,''),(12848,4044,'114461','watch-mobile','text-align','center',0,''),(12849,4044,'114461','watch-mobile','style_class','phone',0,''),(12850,4044,'114461','watch-mobile','padding-bottom','5',0,''),(12851,4045,'114462','watch-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(12852,4045,'114462','watch-mobile','font-weight','normal',0,''),(12853,4045,'114462','watch-mobile','text-align','center',0,''),(12854,4045,'114462','watch-mobile','font-size','12',0,''),(12855,4045,'114462','watch-mobile','padding-top','10',0,''),(12856,4045,'114462','watch-mobile','padding-bottom','5',0,''),(12857,4045,'114462','watch-mobile','border-top-width','1',0,''),(12858,4045,'114462','watch-mobile','border-top-color','$border-color-7',0,''),(12859,4046,'114463','watch-mobile','font-size','12',0,''),(12860,4046,'114463','watch-mobile','font-weight','bold',0,''),(12861,4046,'114463','watch-mobile','text-align','center',0,''),(12862,4046,'114463','watch-mobile','style_class','email',0,''),(12863,4047,'114464','watch-mobile','block_type','1',0,''),(12864,4047,'114464','watch-mobile','font-weight','normal',0,''),(12865,4047,'114464','watch-mobile','style_class','gift-card-view',0,''),(12866,4047,'114464','watch-mobile','text-align','center',0,''),(12867,4047,'114464','watch-mobile','padding-bottom','20',0,''),(12868,4047,'114464','watch-mobile','background-color','$background-2',0,''),(12869,4047,'114464','watch-mobile','padding-left','20',0,''),(12870,4047,'114464','watch-mobile','padding-right','20',0,''),(12871,4047,'114464','watch-mobile','color','$color-font-2',0,''),(12872,4048,'114465','watch-mobile','text','<p>HOLBI</p>',1,''),(12873,4048,'114465','watch-mobile','font-family','$font-1',0,''),(12874,4048,'114465','watch-mobile','font-size','24',0,''),(12875,4048,'114465','watch-mobile','font-weight','normal',0,''),(12876,4048,'114465','watch-mobile','text-align','center',0,''),(12877,4048,'114465','watch-mobile','padding-top','10',0,''),(12878,4048,'114465','watch-mobile','padding-bottom','20',0,''),(12879,4049,'114466','watch-mobile','text','<p>GIFT CARD</p>',1,''),(12880,4049,'114466','watch-mobile','font-size','30',0,''),(12881,4049,'114466','watch-mobile','font-weight','normal',0,''),(12882,4049,'114466','watch-mobile','border-top-width','1',0,''),(12883,4049,'114466','watch-mobile','border-top-color','$border-color-7',0,''),(12884,4049,'114466','watch-mobile','style_class','gift-ico',0,''),(12885,4049,'114466','watch-mobile','text-align','center',0,''),(12886,4049,'114466','watch-mobile','padding-top','15',0,''),(12887,4050,'114467','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(12888,4050,'114467','watch-mobile','font-weight','normal',0,''),(12889,4050,'114467','watch-mobile','text-align','center',0,''),(12890,4050,'114467','watch-mobile','padding-top','20',0,''),(12891,4050,'114467','watch-mobile','padding-bottom','10',0,''),(12892,4050,'114467','watch-mobile','style_class','question-ico',0,''),(12893,4050,'114467','watch-mobile','border-top-width','1',0,''),(12894,4050,'114467','watch-mobile','border-top-color','$border-color-7',0,''),(12895,4050,'114467','watch-mobile','font-size','18',0,''),(12896,4051,'114468','watch-mobile','font-weight','normal',0,''),(12897,4051,'114468','watch-mobile','text-align','center',0,''),(12898,4051,'114468','watch-mobile','padding-bottom','20',0,''),(12899,4052,'114469','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(12900,4052,'114469','watch-mobile','font-weight','normal',0,''),(12901,4052,'114469','watch-mobile','text-align','center',0,''),(12902,4052,'114469','watch-mobile','padding-bottom','10',0,''),(12903,4052,'114469','watch-mobile','font-size','14',0,''),(12904,4053,'114470','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(12905,4053,'114470','watch-mobile','font-size','18',0,''),(12906,4053,'114470','watch-mobile','font-weight','normal',0,''),(12907,4053,'114470','watch-mobile','text-align','center',0,''),(12908,4053,'114470','watch-mobile','padding-top','20',0,''),(12909,4053,'114470','watch-mobile','padding-bottom','10',0,''),(12911,4053,'114470','watch-mobile','border-top-color','$border-color-7',0,''),(12912,4054,'114471','watch-mobile','block_type','1',0,''),(12913,4054,'114471','watch-mobile','font-weight','normal',0,''),(12914,4054,'114471','watch-mobile','padding-top','10',0,''),(12915,4055,'114472','watch-mobile','font-size','12',0,''),(12916,4055,'114472','watch-mobile','font-weight','bold',0,''),(12917,4055,'114472','watch-mobile','text-align','center',0,''),(12918,4055,'114472','watch-mobile','style_class','phone',0,''),(12919,4055,'114472','watch-mobile','padding-bottom','5',0,''),(12920,4056,'114473','watch-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(12921,4056,'114473','watch-mobile','font-weight','normal',0,''),(12922,4056,'114473','watch-mobile','text-align','center',0,''),(12923,4056,'114473','watch-mobile','font-size','12',0,''),(12924,4056,'114473','watch-mobile','padding-top','10',0,''),(12925,4056,'114473','watch-mobile','padding-bottom','5',0,''),(12927,4056,'114473','watch-mobile','border-top-color','$border-color-7',0,''),(12928,4057,'114474','watch-mobile','font-size','12',0,''),(12929,4057,'114474','watch-mobile','font-weight','bold',0,''),(12930,4057,'114474','watch-mobile','text-align','center',0,''),(12931,4057,'114474','watch-mobile','style_class','email',0,''),(12932,4058,'114475','watch-mobile','block_type','4',0,''),(12933,4058,'114475','watch-mobile','color','$color-font-1',0,''),(12934,4058,'114475','watch-mobile','font-size','30',0,''),(12935,4058,'114475','watch-mobile','font-weight','normal',0,''),(12936,4058,'114475','watch-mobile','background-color','$background-5',0,''),(12937,4058,'114475','watch-mobile','padding-top','5',0,''),(12938,4058,'114475','watch-mobile','padding-left','10',0,''),(12939,4058,'114475','watch-mobile','padding-right','10',0,''),(12940,4058,'114475','watch-mobile','padding-bottom','5',0,''),(12941,4059,'114476','watch-mobile','text','<p>Your code is:</p>',1,''),(12943,4061,'114478','watch-mobile','font-size','60',0,''),(12944,4061,'114478','watch-mobile','font-weight','bold',0,''),(12945,4061,'114478','watch-mobile','text-align','center',0,''),(12946,4061,'114478','watch-mobile','line-height','100',0,''),(12947,4061,'114478','watch-mobile','padding-bottom','20',0,''),(12948,4061,'114478','watch-mobile','line_height_measure','px',0,''),(12949,4062,'114479','watch-mobile','block_type','1',0,''),(12950,4062,'114479','watch-mobile','font-weight','normal',0,''),(12951,4062,'114479','watch-mobile','style_class','gift-card-view',0,''),(12952,4062,'114479','watch-mobile','text-align','center',0,''),(12953,4062,'114479','watch-mobile','padding-bottom','20',0,''),(12954,4062,'114479','watch-mobile','background-color','$background-2',0,''),(12955,4062,'114479','watch-mobile','padding-left','20',0,''),(12956,4062,'114479','watch-mobile','padding-right','20',0,''),(12957,4062,'114479','watch-mobile','color','$color-font-2',0,''),(12959,4063,'114480','watch-mobile','font-weight','normal',0,''),(12960,4063,'114480','watch-mobile','padding-top','10',0,''),(12961,4064,'114481','watch-mobile','font-size','12',0,''),(12962,4064,'114481','watch-mobile','font-weight','bold',0,''),(12963,4064,'114481','watch-mobile','text-align','center',0,''),(12964,4064,'114481','watch-mobile','style_class','email',0,''),(12965,4064,'114481','watch-mobile','color','$color-font-1',0,''),(12966,4065,'114482','watch-mobile','font-size','12',0,''),(12967,4065,'114482','watch-mobile','font-weight','bold',0,''),(12968,4065,'114482','watch-mobile','text-align','center',0,''),(12969,4065,'114482','watch-mobile','style_class','phone',0,''),(12970,4065,'114482','watch-mobile','padding-bottom','5',0,''),(12971,4065,'114482','watch-mobile','color','$color-font-1',0,''),(12972,4066,'114483','watch-mobile','text','If you require further assistance please contact us',0,''),(12973,4066,'114483','watch-mobile','font-size','12',0,''),(12975,4066,'114483','watch-mobile','text-align','center',0,''),(12976,4066,'114483','watch-mobile','padding-top','10',0,''),(12977,4067,'114484','watch-mobile','block_type','4',0,''),(12978,4067,'114484','watch-mobile','color','$color-font-1',0,''),(12979,4067,'114484','watch-mobile','font-size','30',0,''),(12980,4067,'114484','watch-mobile','font-weight','normal',0,''),(12981,4067,'114484','watch-mobile','background-color','$background-5',0,''),(12982,4067,'114484','watch-mobile','padding-top','5',0,''),(12983,4067,'114484','watch-mobile','padding-left','10',0,''),(12984,4067,'114484','watch-mobile','padding-right','10',0,''),(12985,4067,'114484','watch-mobile','padding-bottom','5',0,''),(12986,4068,'114485','watch-mobile','text','Your code is:',0,''),(12987,4068,'114485','watch-mobile','font-size','30',0,''),(12988,4068,'114485','watch-mobile','color','$color-font-1',0,''),(12989,4069,'114486','watch-mobile','color','$color-font-1',0,''),(12991,4070,'114487','watch-mobile','block_type','1',0,''),(12992,4071,'114488','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(12993,4071,'114488','watch-mobile','font-size','18',0,''),(12994,4071,'114488','watch-mobile','font-weight','normal',0,''),(12995,4071,'114488','watch-mobile','text-align','center',0,''),(12996,4071,'114488','watch-mobile','padding-top','20',0,''),(12997,4071,'114488','watch-mobile','padding-bottom','10',0,''),(12998,4071,'114488','watch-mobile','border-top-width','1',0,''),(12999,4071,'114488','watch-mobile','border-top-color','$border-color-7',0,''),(13000,4072,'114489','watch-mobile','text','HOLBI',0,''),(13001,4072,'114489','watch-mobile','color','$color-font-1',0,''),(13002,4072,'114489','watch-mobile','font-size','24',0,''),(13003,4072,'114489','watch-mobile','padding-top','20',0,''),(13004,4072,'114489','watch-mobile','text-align','center',0,''),(13005,4072,'114489','watch-mobile','padding-bottom','20',0,''),(13006,4073,'114490','watch-mobile','border-top-color','$border-color-7',0,''),(13007,4073,'114490','watch-mobile','border-top-width','1',0,''),(13008,4073,'114490','watch-mobile','padding-top','20',0,''),(13009,4073,'114490','watch-mobile','font-size','30',0,''),(13010,4073,'114490','watch-mobile','text-align','center',0,''),(13011,4073,'114490','watch-mobile','color','$color-font-1',0,''),(13012,4073,'114490','watch-mobile','text','GIFT CARD',0,''),(13013,4074,'114491','watch-mobile','text-align','center',0,''),(13014,4074,'114491','watch-mobile','font-weight','bold',0,''),(13015,4074,'114491','watch-mobile','font-size','60',0,''),(13016,4074,'114491','watch-mobile','color','$color-font-1',0,''),(13017,4075,'114492','watch-mobile','font-size','20',0,''),(13018,4075,'114492','watch-mobile','text-align','center',0,''),(13019,4075,'114492','watch-mobile','color','$color-font-1',0,''),(13020,4075,'114492','watch-mobile','padding-top','20',0,''),(13021,4075,'114492','watch-mobile','padding-bottom','20',0,''),(13022,4076,'114493','watch-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(13023,4076,'114493','watch-mobile','text-align','center',0,''),(13024,4076,'114493','watch-mobile','color','$color-font-1',0,''),(13025,4076,'114493','watch-mobile','font-size','14',0,''),(13026,4076,'114493','watch-mobile','padding-bottom','20',0,''),(13027,4077,'114494','watch-mobile','text','WHAT TO DO NEXT:',0,''),(13028,4077,'114494','watch-mobile','font-size','18',0,''),(13029,4077,'114494','watch-mobile','text-align','center',0,''),(13030,4077,'114494','watch-mobile','color','$color-font-1',0,''),(13031,4077,'114494','watch-mobile','padding-top','20',0,''),(13032,4077,'114494','watch-mobile','padding-bottom','10',0,''),(13033,4077,'114494','watch-mobile','border-top-width','1',0,''),(13034,4077,'114494','watch-mobile','border-top-color','$border-color-7',0,''),(13035,4079,'114496','watch-mobile','block_type','1',0,''),(13036,4079,'114496','watch-mobile','font-weight','normal',0,''),(13037,4079,'114496','watch-mobile','style_class','gift-card-view',0,''),(13038,4079,'114496','watch-mobile','text-align','center',0,''),(13039,4079,'114496','watch-mobile','padding-bottom','20',0,''),(13040,4079,'114496','watch-mobile','background-color','$background-2',0,''),(13041,4079,'114496','watch-mobile','padding-left','20',0,''),(13042,4079,'114496','watch-mobile','padding-right','20',0,''),(13043,4079,'114496','watch-mobile','color','$color-font-2',0,''),(13044,4080,'114497','watch-mobile','block_type','1',0,''),(13045,4080,'114497','watch-mobile','font-weight','normal',0,''),(13046,4080,'114497','watch-mobile','padding-top','10',0,''),(13047,4081,'114498','watch-mobile','font-size','12',0,''),(13048,4081,'114498','watch-mobile','font-weight','bold',0,''),(13049,4081,'114498','watch-mobile','text-align','center',0,''),(13050,4081,'114498','watch-mobile','style_class','email',0,''),(13051,4081,'114498','watch-mobile','color','$color-font-1',0,''),(13052,4082,'114499','watch-mobile','font-size','12',0,''),(13053,4082,'114499','watch-mobile','font-weight','bold',0,''),(13054,4082,'114499','watch-mobile','text-align','center',0,''),(13055,4082,'114499','watch-mobile','style_class','phone',0,''),(13056,4082,'114499','watch-mobile','padding-bottom','5',0,''),(13057,4082,'114499','watch-mobile','color','$color-font-1',0,''),(13058,4083,'114500','watch-mobile','text','If you require further assistance please contact us',0,''),(13059,4083,'114500','watch-mobile','font-size','12',0,''),(13060,4083,'114500','watch-mobile','color','$color-font-1',0,''),(13061,4083,'114500','watch-mobile','text-align','center',0,''),(13062,4083,'114500','watch-mobile','padding-top','10',0,''),(13063,4084,'114501','watch-mobile','block_type','4',0,''),(13064,4084,'114501','watch-mobile','color','$color-font-1',0,''),(13065,4084,'114501','watch-mobile','font-size','30',0,''),(13066,4084,'114501','watch-mobile','font-weight','normal',0,''),(13067,4084,'114501','watch-mobile','background-color','$background-5',0,''),(13068,4084,'114501','watch-mobile','padding-top','5',0,''),(13069,4084,'114501','watch-mobile','padding-left','10',0,''),(13070,4084,'114501','watch-mobile','padding-right','10',0,''),(13071,4084,'114501','watch-mobile','padding-bottom','5',0,''),(13072,4085,'114502','watch-mobile','text','Your code is:',0,''),(13073,4085,'114502','watch-mobile','font-size','30',0,''),(13074,4085,'114502','watch-mobile','color','$color-font-1',0,''),(13075,4086,'114503','watch-mobile','color','$color-font-1',0,''),(13076,4086,'114503','watch-mobile','font-size','30',0,''),(13077,4087,'114504','watch-mobile','block_type','1',0,''),(13078,4088,'114505','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(13079,4088,'114505','watch-mobile','font-size','18',0,''),(13080,4088,'114505','watch-mobile','font-weight','normal',0,''),(13081,4088,'114505','watch-mobile','text-align','center',0,''),(13082,4088,'114505','watch-mobile','padding-top','20',0,''),(13083,4088,'114505','watch-mobile','padding-bottom','10',0,''),(13084,4088,'114505','watch-mobile','border-top-width','1',0,''),(13085,4088,'114505','watch-mobile','border-top-color','$border-color-7',0,''),(13086,4089,'114506','watch-mobile','text','HOLBI',0,''),(13087,4089,'114506','watch-mobile','color','$color-font-1',0,''),(13088,4089,'114506','watch-mobile','font-size','24',0,''),(13089,4089,'114506','watch-mobile','padding-top','20',0,''),(13090,4089,'114506','watch-mobile','text-align','center',0,''),(13091,4089,'114506','watch-mobile','padding-bottom','20',0,''),(13092,4090,'114507','watch-mobile','border-top-color','$border-color-7',0,''),(13093,4090,'114507','watch-mobile','border-top-width','1',0,''),(13094,4090,'114507','watch-mobile','padding-top','20',0,''),(13095,4090,'114507','watch-mobile','font-size','30',0,''),(13096,4090,'114507','watch-mobile','text-align','center',0,''),(13097,4090,'114507','watch-mobile','color','$color-font-1',0,''),(13098,4090,'114507','watch-mobile','text','GIFT CARD',0,''),(13099,4091,'114508','watch-mobile','text-align','center',0,''),(13100,4091,'114508','watch-mobile','font-weight','bold',0,''),(13101,4091,'114508','watch-mobile','font-size','60',0,''),(13102,4091,'114508','watch-mobile','color','$color-font-1',0,''),(13103,4092,'114509','watch-mobile','font-size','20',0,''),(13104,4092,'114509','watch-mobile','text-align','center',0,''),(13105,4092,'114509','watch-mobile','color','$color-font-1',0,''),(13106,4092,'114509','watch-mobile','padding-top','20',0,''),(13107,4092,'114509','watch-mobile','padding-bottom','20',0,''),(13108,4093,'114510','watch-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(13109,4093,'114510','watch-mobile','text-align','center',0,''),(13110,4093,'114510','watch-mobile','color','$color-font-1',0,''),(13111,4093,'114510','watch-mobile','font-size','14',0,''),(13112,4093,'114510','watch-mobile','padding-bottom','20',0,''),(13113,4094,'114511','watch-mobile','text','WHAT TO DO NEXT:',0,''),(13114,4094,'114511','watch-mobile','font-size','18',0,''),(13115,4094,'114511','watch-mobile','text-align','center',0,''),(13116,4094,'114511','watch-mobile','color','$color-font-1',0,''),(13117,4094,'114511','watch-mobile','padding-top','20',0,''),(13118,4094,'114511','watch-mobile','padding-bottom','10',0,''),(13119,4094,'114511','watch-mobile','border-top-width','1',0,''),(13120,4094,'114511','watch-mobile','border-top-color','$border-color-7',0,''),(13121,4096,'114513','watch-mobile','block_type','1',0,''),(13122,4098,'114515','watch-mobile','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(13123,4098,'114515','watch-mobile','text-align','center',0,''),(13124,4099,'114516','watch-mobile','block_type','1',0,''),(13125,4099,'114516','watch-mobile','font-weight','normal',0,''),(13126,4099,'114516','watch-mobile','style_class','gift-card-view',0,''),(13127,4099,'114516','watch-mobile','text-align','center',0,''),(13128,4099,'114516','watch-mobile','padding-bottom','20',0,''),(13129,4099,'114516','watch-mobile','background-color','$message-color',0,''),(13130,4099,'114516','watch-mobile','padding-left','20',0,''),(13131,4099,'114516','watch-mobile','padding-right','20',0,''),(13132,4099,'114516','watch-mobile','color','$color-font-2',0,''),(13133,4100,'114517','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(13134,4100,'114517','watch-mobile','font-weight','normal',0,''),(13135,4100,'114517','watch-mobile','text-align','center',0,''),(13136,4100,'114517','watch-mobile','padding-bottom','10',0,''),(13137,4100,'114517','watch-mobile','font-size','14',0,''),(13138,4101,'114518','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(13139,4101,'114518','watch-mobile','font-size','18',0,''),(13140,4101,'114518','watch-mobile','font-weight','normal',0,''),(13141,4101,'114518','watch-mobile','text-align','center',0,''),(13142,4101,'114518','watch-mobile','padding-top','20',0,''),(13143,4101,'114518','watch-mobile','padding-bottom','10',0,''),(13144,4101,'114518','watch-mobile','border-top-width','1',0,''),(13145,4101,'114518','watch-mobile','border-top-color','$border-color-7',0,''),(13146,4102,'114519','watch-mobile','font-size','60',0,''),(13147,4102,'114519','watch-mobile','font-weight','bold',0,''),(13148,4102,'114519','watch-mobile','text-align','center',0,''),(13149,4102,'114519','watch-mobile','line-height','100',0,''),(13150,4102,'114519','watch-mobile','padding-bottom','20',0,''),(13151,4102,'114519','watch-mobile','line_height_measure','px',0,''),(13152,4103,'114520','watch-mobile','text','<p>GIFT CARD</p>',1,''),(13153,4103,'114520','watch-mobile','font-size','30',0,''),(13154,4103,'114520','watch-mobile','font-weight','normal',0,''),(13155,4103,'114520','watch-mobile','border-top-width','1',0,''),(13156,4103,'114520','watch-mobile','border-top-color','$border-color-7',0,''),(13157,4103,'114520','watch-mobile','style_class','gift-ico',0,''),(13158,4103,'114520','watch-mobile','text-align','center',0,''),(13159,4103,'114520','watch-mobile','padding-top','15',0,''),(13160,4104,'114521','watch-mobile','font-weight','normal',0,''),(13161,4104,'114521','watch-mobile','text-align','center',0,''),(13162,4104,'114521','watch-mobile','padding-bottom','20',0,''),(13163,4105,'114522','watch-mobile','text','<p>HOLBI</p>',1,''),(13164,4105,'114522','watch-mobile','font-family','$font-1',0,''),(13165,4105,'114522','watch-mobile','font-size','24',0,''),(13166,4105,'114522','watch-mobile','font-weight','normal',0,''),(13167,4105,'114522','watch-mobile','text-align','center',0,''),(13168,4105,'114522','watch-mobile','padding-top','10',0,''),(13169,4105,'114522','watch-mobile','padding-bottom','20',0,''),(13170,4106,'114523','watch-mobile','block_type','1',0,''),(13171,4106,'114523','watch-mobile','font-weight','normal',0,''),(13172,4106,'114523','watch-mobile','padding-top','10',0,''),(13173,4107,'114524','watch-mobile','font-size','12',0,''),(13174,4107,'114524','watch-mobile','font-weight','bold',0,''),(13175,4107,'114524','watch-mobile','text-align','center',0,''),(13176,4107,'114524','watch-mobile','style_class','email',0,''),(13177,4108,'114525','watch-mobile','font-size','12',0,''),(13178,4108,'114525','watch-mobile','font-weight','bold',0,''),(13179,4108,'114525','watch-mobile','text-align','center',0,''),(13180,4108,'114525','watch-mobile','style_class','phone',0,''),(13181,4108,'114525','watch-mobile','padding-bottom','5',0,''),(13182,4109,'114526','watch-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(13183,4109,'114526','watch-mobile','font-weight','normal',0,''),(13184,4109,'114526','watch-mobile','text-align','center',0,''),(13185,4109,'114526','watch-mobile','font-size','12',0,''),(13186,4109,'114526','watch-mobile','padding-top','10',0,''),(13187,4109,'114526','watch-mobile','padding-bottom','5',0,''),(13188,4109,'114526','watch-mobile','border-top-width','1',0,''),(13189,4109,'114526','watch-mobile','border-top-color','$border-color-7',0,''),(13190,4110,'114527','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(13191,4110,'114527','watch-mobile','font-weight','normal',0,''),(13192,4110,'114527','watch-mobile','text-align','center',0,''),(13193,4110,'114527','watch-mobile','padding-top','20',0,''),(13194,4110,'114527','watch-mobile','padding-bottom','10',0,''),(13195,4110,'114527','watch-mobile','style_class','question-ico',0,''),(13196,4110,'114527','watch-mobile','border-top-width','1',0,''),(13197,4110,'114527','watch-mobile','border-top-color','$border-color-7',0,''),(13198,4110,'114527','watch-mobile','font-size','18',0,''),(13199,4111,'114528','watch-mobile','block_type','4',0,''),(13200,4111,'114528','watch-mobile','color','$color-font-1',0,''),(13201,4111,'114528','watch-mobile','font-size','30',0,''),(13202,4111,'114528','watch-mobile','font-weight','normal',0,''),(13203,4111,'114528','watch-mobile','background-color','$background-5',0,''),(13204,4111,'114528','watch-mobile','padding-top','5',0,''),(13205,4111,'114528','watch-mobile','padding-left','10',0,''),(13206,4111,'114528','watch-mobile','padding-right','10',0,''),(13207,4111,'114528','watch-mobile','padding-bottom','5',0,''),(13208,4112,'114529','watch-mobile','text','<p>Your code is:</p>',1,''),(13209,4112,'114529','watch-mobile','font-weight','normal',0,''),(13210,4114,'114531','watch-mobile','block_type','1',0,''),(13211,4114,'114531','watch-mobile','font-weight','normal',0,''),(13212,4114,'114531','watch-mobile','style_class','gift-card-view',0,''),(13213,4114,'114531','watch-mobile','text-align','center',0,''),(13214,4114,'114531','watch-mobile','padding-bottom','20',0,''),(13215,4114,'114531','watch-mobile','background-color','$message-color',0,''),(13216,4114,'114531','watch-mobile','padding-left','20',0,''),(13217,4114,'114531','watch-mobile','padding-right','20',0,''),(13218,4114,'114531','watch-mobile','color','$color-font-2',0,''),(13219,4115,'114532','watch-mobile','block_type','1',0,''),(13220,4115,'114532','watch-mobile','font-weight','normal',0,''),(13221,4115,'114532','watch-mobile','padding-top','10',0,''),(13222,4116,'114533','watch-mobile','font-size','12',0,''),(13223,4116,'114533','watch-mobile','font-weight','bold',0,''),(13224,4116,'114533','watch-mobile','text-align','center',0,''),(13225,4116,'114533','watch-mobile','style_class','email',0,''),(13226,4116,'114533','watch-mobile','color','$color-font-1',0,''),(13227,4117,'114534','watch-mobile','font-size','12',0,''),(13228,4117,'114534','watch-mobile','font-weight','bold',0,''),(13229,4117,'114534','watch-mobile','text-align','center',0,''),(13230,4117,'114534','watch-mobile','style_class','phone',0,''),(13231,4117,'114534','watch-mobile','padding-bottom','5',0,''),(13232,4117,'114534','watch-mobile','color','$color-font-1',0,''),(13233,4118,'114535','watch-mobile','text','If you require further assistance please contact us',0,''),(13234,4118,'114535','watch-mobile','font-size','12',0,''),(13235,4118,'114535','watch-mobile','color','$color-font-1',0,''),(13236,4118,'114535','watch-mobile','text-align','center',0,''),(13237,4118,'114535','watch-mobile','padding-top','10',0,''),(13238,4119,'114536','watch-mobile','block_type','4',0,''),(13239,4119,'114536','watch-mobile','color','$color-font-1',0,''),(13240,4119,'114536','watch-mobile','font-size','30',0,''),(13241,4119,'114536','watch-mobile','font-weight','normal',0,''),(13242,4119,'114536','watch-mobile','background-color','$background-5',0,''),(13243,4119,'114536','watch-mobile','padding-top','5',0,''),(13244,4119,'114536','watch-mobile','padding-left','10',0,''),(13245,4119,'114536','watch-mobile','padding-right','10',0,''),(13246,4119,'114536','watch-mobile','padding-bottom','5',0,''),(13247,4120,'114537','watch-mobile','text','Your code is:',0,''),(13248,4120,'114537','watch-mobile','font-size','30',0,''),(13249,4120,'114537','watch-mobile','color','$color-font-1',0,''),(13250,4121,'114538','watch-mobile','color','$color-font-1',0,''),(13251,4121,'114538','watch-mobile','font-size','30',0,''),(13252,4122,'114539','watch-mobile','block_type','1',0,''),(13253,4123,'114540','watch-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(13254,4123,'114540','watch-mobile','font-size','18',0,''),(13255,4123,'114540','watch-mobile','font-weight','normal',0,''),(13256,4123,'114540','watch-mobile','text-align','center',0,''),(13257,4123,'114540','watch-mobile','padding-top','20',0,''),(13258,4123,'114540','watch-mobile','padding-bottom','10',0,''),(13259,4123,'114540','watch-mobile','border-top-width','1',0,''),(13260,4123,'114540','watch-mobile','border-top-color','$border-color-7',0,''),(13261,4124,'114541','watch-mobile','text','HOLBI',0,''),(13262,4124,'114541','watch-mobile','color','$color-font-1',0,''),(13263,4124,'114541','watch-mobile','font-size','24',0,''),(13264,4124,'114541','watch-mobile','padding-top','20',0,''),(13265,4124,'114541','watch-mobile','text-align','center',0,''),(13266,4124,'114541','watch-mobile','padding-bottom','20',0,''),(13267,4125,'114542','watch-mobile','border-top-color','$border-color-7',0,''),(13268,4125,'114542','watch-mobile','border-top-width','1',0,''),(13269,4125,'114542','watch-mobile','padding-top','20',0,''),(13270,4125,'114542','watch-mobile','font-size','30',0,''),(13271,4125,'114542','watch-mobile','text-align','center',0,''),(13272,4125,'114542','watch-mobile','color','$color-font-1',0,''),(13273,4125,'114542','watch-mobile','text','GIFT CARD',0,''),(13274,4126,'114543','watch-mobile','text-align','center',0,''),(13275,4126,'114543','watch-mobile','font-weight','bold',0,''),(13276,4126,'114543','watch-mobile','font-size','60',0,''),(13277,4126,'114543','watch-mobile','color','$color-font-1',0,''),(13278,4127,'114544','watch-mobile','font-size','20',0,''),(13279,4127,'114544','watch-mobile','text-align','center',0,''),(13280,4127,'114544','watch-mobile','color','$color-font-1',0,''),(13281,4127,'114544','watch-mobile','padding-top','20',0,''),(13282,4127,'114544','watch-mobile','padding-bottom','20',0,''),(13283,4128,'114545','watch-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(13284,4128,'114545','watch-mobile','text-align','center',0,''),(13285,4128,'114545','watch-mobile','color','$color-font-1',0,''),(13286,4128,'114545','watch-mobile','font-size','14',0,''),(13287,4128,'114545','watch-mobile','padding-bottom','20',0,''),(13288,4129,'114546','watch-mobile','text','WHAT TO DO NEXT:',0,''),(13289,4129,'114546','watch-mobile','font-size','18',0,''),(13290,4129,'114546','watch-mobile','text-align','center',0,''),(13291,4129,'114546','watch-mobile','color','$color-font-1',0,''),(13292,4129,'114546','watch-mobile','padding-top','20',0,''),(13293,4129,'114546','watch-mobile','padding-bottom','10',0,''),(13294,4129,'114546','watch-mobile','border-top-width','1',0,''),(13295,4129,'114546','watch-mobile','border-top-color','$border-color-7',0,''),(13296,4130,'75671','watch-mobile','logo','themes/watch-mobile/img/oscommerce_logo.png',1,''),(13297,4130,'75671','watch-mobile','text-align','center',0,''),(13298,4130,'75671','watch-mobile','padding-top','10',0,''),(13299,4130,'75671','watch-mobile','padding-left','60',0,''),(13300,4130,'75671','watch-mobile','padding-right','60',0,''),(13301,4130,'75671','watch-mobile','padding-bottom','10',0,''),(13302,4131,'75672','watch-mobile','text-align','center',0,''),(13303,4131,'75672','watch-mobile','margin-bottom','20',0,''),(13304,4132,'75681','watch-mobile','block_type','14',0,''),(13305,4132,'75681','watch-mobile','font-weight','400',0,''),(13306,4132,'75681','watch-mobile','background-color','$background-2',0,''),(13307,4133,'75682','watch-mobile','class','menu-style-1',0,''),(13308,4133,'75682','watch-mobile','box_align','4',0,''),(13309,4133,'75682','watch-mobile','font-weight','400',0,''),(13310,4133,'75682','watch-mobile','hide_menu','on',0,''),(13311,4133,'75682','watch-mobile','color','$color-font-1',0,''),(13312,4133,'75682','watch-mobile','hide_menu','1',0,'292'),(13313,4133,'75682','watch-mobile','show_new','1',0,''),(13314,4137,'75686','watch-mobile','block_type','1',0,''),(13315,4140,'75689','watch-mobile','width','680',0,''),(13316,4140,'75689','watch-mobile','font-weight','normal',0,''),(13317,4140,'75689','watch-mobile','font-size','12',0,''),(13318,4140,'75689','watch-mobile','padding-top','20',0,''),(13319,4140,'75689','watch-mobile','padding-bottom','20',0,''),(13320,4140,'75689','watch-mobile','color','$color-font-7',0,''),(13321,4141,'75690','watch-mobile','block_type','5',0,''),(13322,4141,'75690','watch-mobile','font-weight','normal',0,''),(13323,4141,'75690','watch-mobile','border-bottom-width','1',0,''),(13324,4141,'75690','watch-mobile','border-bottom-color','$border-color-1',0,''),(13325,4141,'75690','watch-mobile','border-top-width','1',0,''),(13326,4141,'75690','watch-mobile','border-top-color','$border-color-1',0,''),(13327,4141,'75690','watch-mobile','border-left-color','$border-color-1',0,''),(13328,4141,'75690','watch-mobile','border-left-width','1',0,''),(13329,4142,'75691','watch-mobile','block_type','1',0,''),(13330,4142,'75691','watch-mobile','font-weight','normal',0,''),(13331,4142,'75691','watch-mobile','padding-top','10',0,''),(13332,4142,'75691','watch-mobile','padding-left','10',0,''),(13333,4142,'75691','watch-mobile','padding-right','10',0,''),(13334,4143,'75692','watch-mobile','font-weight','400',0,''),(13335,4143,'75692','watch-mobile','line-height','120',0,''),(13336,4143,'75692','watch-mobile','line_height_measure','%',0,''),(13337,4144,'75693','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(13338,4144,'75693','watch-mobile','font-size','14',0,''),(13339,4144,'75693','watch-mobile','font-weight','bold',0,''),(13340,4144,'75693','watch-mobile','padding-bottom','10',0,''),(13341,4145,'75694','watch-mobile','block_type','1',0,''),(13342,4145,'75694','watch-mobile','background-color','$background-6',0,''),(13343,4145,'75694','watch-mobile','padding-top','40',0,''),(13344,4145,'75694','watch-mobile','padding-left','10',0,''),(13345,4145,'75694','watch-mobile','padding-right','10',0,''),(13346,4145,'75694','watch-mobile','padding-bottom','40',0,''),(13347,4146,'75695','watch-mobile','font-weight','normal',0,''),(13348,4146,'75695','watch-mobile','line-height','200',0,''),(13349,4146,'75695','watch-mobile','text-align','right',0,''),(13350,4146,'75695','watch-mobile','font-size','14',0,''),(13351,4146,'75695','watch-mobile','box_align','3',0,''),(13352,4147,'75696','watch-mobile','font-weight','400',0,''),(13353,4147,'75696','watch-mobile','padding-top','20',0,''),(13354,4147,'75696','watch-mobile','padding-bottom','20',0,''),(13355,4147,'75696','watch-mobile','font-size','12',0,''),(13356,4148,'75697','watch-mobile','block_type','2',0,''),(13357,4148,'75697','watch-mobile','font-weight','normal',0,''),(13358,4148,'75697','watch-mobile','padding-bottom','20',0,''),(13359,4149,'75698','watch-mobile','font-weight','400',0,''),(13360,4149,'75698','watch-mobile','padding-top','20',0,''),(13361,4149,'75698','watch-mobile','logo','themes/watch-mobile/img/watchlogo-2-1.png',1,''),(13362,4150,'75699','watch-mobile','block_type','11',0,''),(13363,4150,'75699','watch-mobile','font-weight','normal',0,''),(13364,4151,'75700','watch-mobile','text','<p>Phone:</p>',1,''),(13365,4151,'75700','watch-mobile','font-weight','normal',0,''),(13366,4151,'75700','watch-mobile','text-align','right',0,''),(13367,4152,'75701','watch-mobile','font-weight','normal',0,''),(13368,4152,'75701','watch-mobile','text-align','right',0,''),(13369,4153,'75702','watch-mobile','block_type','1',0,''),(13370,4154,'75703','watch-mobile','font-weight','normal',0,''),(13371,4154,'75703','watch-mobile','text-align','right',0,''),(13372,4154,'75703','watch-mobile','padding-bottom','10',0,''),(13373,4154,'75703','watch-mobile','address_spacer',',',0,''),(13374,4155,'75704','watch-mobile','block_type','11',0,''),(13375,4155,'75704','watch-mobile','font-weight','normal',0,''),(13376,4156,'75705','watch-mobile','text','<p>Web:</p>',1,''),(13377,4156,'75705','watch-mobile','font-weight','normal',0,''),(13378,4156,'75705','watch-mobile','text-align','right',0,''),(13379,4157,'75706','watch-mobile','font-weight','normal',0,''),(13380,4157,'75706','watch-mobile','text-align','right',0,''),(13381,4158,'75707','watch-mobile','block_type','11',0,''),(13382,4158,'75707','watch-mobile','font-weight','normal',0,''),(13383,4159,'75708','watch-mobile','text','<p>Email:</p>',1,''),(13384,4159,'75708','watch-mobile','font-weight','normal',0,''),(13385,4159,'75708','watch-mobile','text-align','right',0,''),(13386,4160,'75709','watch-mobile','font-weight','normal',0,''),(13387,4160,'75709','watch-mobile','text-align','right',0,''),(13388,4161,'75710','watch-mobile','block_type','3',0,''),(13389,4161,'75710','watch-mobile','font-weight','normal',0,''),(13390,4161,'75710','watch-mobile','padding-top','20',0,''),(13391,4162,'75711','watch-mobile','text','<p>If undelivered please return to:</p>',1,''),(13392,4162,'75711','watch-mobile','font-size','15',0,''),(13393,4162,'75711','watch-mobile','font-weight','bold',0,''),(13394,4163,'75712','watch-mobile','font-size','14',0,''),(13395,4164,'75713','watch-mobile','text','<p>Thank you for your order</p>',1,''),(13396,4164,'75713','watch-mobile','color','$color-font-10',0,''),(13397,4164,'75713','watch-mobile','font-size','16',0,''),(13398,4164,'75713','watch-mobile','font-weight','bold',0,''),(13399,4164,'75713','watch-mobile','padding-top','5',0,''),(13400,4164,'75713','watch-mobile','text-align','center',0,''),(13401,4165,'75714','watch-mobile','font-weight','400',0,''),(13402,4165,'75714','watch-mobile','text-align','center',0,''),(13403,4165,'75714','watch-mobile','padding-top','0',0,''),(13405,4165,'75714','watch-mobile','padding-left','20',0,''),(13406,4165,'75714','watch-mobile','padding-right','20',0,''),(13407,4166,'75715','watch-mobile','block_type','6',0,''),(13408,4166,'75715','watch-mobile','font-weight','normal',0,''),(13409,4166,'75715','watch-mobile','font-size','16',0,''),(13410,4167,'75716','watch-mobile','text','<p>Email:</p>',1,''),(13411,4167,'75716','watch-mobile','font-weight','normal',0,''),(13412,4167,'75716','watch-mobile','text-align','right',0,''),(13413,4167,'75716','watch-mobile','font-size','14',0,''),(13414,4168,'75717','watch-mobile','font-weight','normal',0,''),(13415,4168,'75717','watch-mobile','text-align','right',0,''),(13416,4168,'75717','watch-mobile','font-size','14',0,''),(13417,4169,'75718','watch-mobile','block_type','6',0,''),(13418,4169,'75718','watch-mobile','font-weight','normal',0,''),(13419,4169,'75718','watch-mobile','font-size','16',0,''),(13420,4170,'75719','watch-mobile','text','<p>Phone:</p>',1,''),(13421,4170,'75719','watch-mobile','font-weight','normal',0,''),(13422,4170,'75719','watch-mobile','text-align','right',0,''),(13423,4170,'75719','watch-mobile','font-size','14',0,''),(13424,4171,'75720','watch-mobile','font-weight','normal',0,''),(13425,4171,'75720','watch-mobile','text-align','right',0,''),(13426,4171,'75720','watch-mobile','font-size','14',0,''),(13427,4172,'75721','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(13428,4172,'75721','watch-mobile','font-size','14',0,''),(13429,4172,'75721','watch-mobile','font-weight','bold',0,''),(13430,4172,'75721','watch-mobile','text-align','right',0,''),(13431,4173,'75722','watch-mobile','block_type','4',0,''),(13432,4173,'75722','watch-mobile','font-weight','normal',0,''),(13433,4173,'75722','watch-mobile','border-top-width','1',0,''),(13434,4173,'75722','watch-mobile','border-top-color','$border-color-1',0,''),(13435,4173,'75722','watch-mobile','border-left-width','1',0,''),(13436,4173,'75722','watch-mobile','border-left-color','$border-color-1',0,''),(13437,4173,'75722','watch-mobile','border-right-width','1',0,''),(13438,4173,'75722','watch-mobile','border-right-color','$border-color-1',0,''),(13439,4173,'75722','watch-mobile','border-bottom-width','1',0,''),(13440,4173,'75722','watch-mobile','border-bottom-color','$border-color-1',0,''),(13441,4174,'75723','watch-mobile','block_type','2',0,''),(13442,4174,'75723','watch-mobile','font-weight','normal',0,''),(13443,4174,'75723','watch-mobile','border-top-width','1',0,''),(13444,4174,'75723','watch-mobile','border-top-color','$border-color-1',0,''),(13445,4174,'75723','watch-mobile','border-right-width','1',0,''),(13446,4174,'75723','watch-mobile','border-right-color','$border-color-1',0,''),(13447,4175,'75724','watch-mobile','block_type','1',0,''),(13448,4175,'75724','watch-mobile','font-weight','normal',0,''),(13449,4175,'75724','watch-mobile','padding-top','10',0,''),(13450,4175,'75724','watch-mobile','padding-left','10',0,''),(13451,4175,'75724','watch-mobile','padding-right','10',0,''),(13452,4175,'75724','watch-mobile','padding-bottom','10',0,''),(13453,4175,'75724','watch-mobile','border-right-width','1',0,''),(13454,4175,'75724','watch-mobile','border-right-color','$border-color-1',0,''),(13455,4176,'75725','watch-mobile','text','<p>Shipping via</p>',1,''),(13456,4176,'75725','watch-mobile','font-weight','bold',0,''),(13457,4178,'75727','watch-mobile','block_type','1',0,''),(13458,4178,'75727','watch-mobile','font-weight','normal',0,''),(13459,4178,'75727','watch-mobile','padding-top','10',0,''),(13460,4178,'75727','watch-mobile','padding-left','10',0,''),(13461,4178,'75727','watch-mobile','padding-right','10',0,''),(13462,4178,'75727','watch-mobile','padding-bottom','10',0,''),(13463,4180,'75729','watch-mobile','text','<p>Shipping service</p>',1,''),(13464,4180,'75729','watch-mobile','font-weight','bold',0,''),(13465,4181,'75730','watch-mobile','block_type','2',0,''),(13466,4181,'75730','watch-mobile','font-weight','normal',0,''),(13467,4181,'75730','watch-mobile','border-right-width','1',0,''),(13468,4181,'75730','watch-mobile','border-right-color','$border-color-1',0,''),(13469,4182,'75731','watch-mobile','block_type','1',0,''),(13470,4182,'75731','watch-mobile','font-weight','400',0,''),(13471,4182,'75731','watch-mobile','background-color','$background-6',0,''),(13472,4182,'75731','watch-mobile','padding-top','10',0,''),(13473,4182,'75731','watch-mobile','padding-left','10',0,''),(13474,4182,'75731','watch-mobile','padding-right','10',0,''),(13475,4182,'75731','watch-mobile','padding-bottom','50',0,''),(13476,4183,'75732','watch-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(13477,4183,'75732','watch-mobile','font-size','16',0,''),(13478,4183,'75732','watch-mobile','font-weight','bold',0,''),(13479,4185,'75734','watch-mobile','block_type','1',0,''),(13480,4185,'75734','watch-mobile','font-weight','normal',0,''),(13481,4185,'75734','watch-mobile','padding-top','10',0,''),(13482,4185,'75734','watch-mobile','padding-left','10',0,''),(13483,4185,'75734','watch-mobile','padding-right','10',0,''),(13484,4185,'75734','watch-mobile','padding-bottom','10',0,''),(13485,4186,'75735','watch-mobile','font-weight','normal',0,''),(13486,4187,'75736','watch-mobile','text','<p>CUSTOMER:</p>',1,''),(13487,4187,'75736','watch-mobile','font-size','14',0,''),(13488,4187,'75736','watch-mobile','font-weight','bold',0,''),(13489,4188,'75737','watch-mobile','font-weight','normal',0,''),(13490,4189,'75738','watch-mobile','text','<p>PHONE NUMBER:</p>',1,''),(13491,4189,'75738','watch-mobile','font-size','14',0,''),(13492,4189,'75738','watch-mobile','font-weight','bold',0,''),(13493,4189,'75738','watch-mobile','padding-top','10',0,''),(13494,4190,'75739','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(13495,4190,'75739','watch-mobile','font-weight','bold',0,''),(13496,4190,'75739','watch-mobile','font-size','14',0,''),(13497,4190,'75739','watch-mobile','padding-top','10',0,''),(13498,4192,'75741','watch-mobile','font-weight','normal',0,''),(13499,4192,'75741','watch-mobile','text-align','center',0,''),(13500,4192,'75741','watch-mobile','padding-bottom','20',0,''),(13501,4193,'75742','watch-mobile','font-weight','normal',0,''),(13502,4193,'75742','watch-mobile','text-align','center',0,''),(13503,4193,'75742','watch-mobile','padding-bottom','10',0,''),(13504,4194,'75743','watch-mobile','font-size','16',0,''),(13505,4194,'75743','watch-mobile','font-weight','bold',0,''),(13506,4194,'75743','watch-mobile','text-align','center',0,''),(13507,4194,'75743','watch-mobile','padding-bottom','10',0,''),(13508,4194,'75743','watch-mobile','padding-top','10',0,''),(13509,4195,'75744','watch-mobile','font-weight','normal',0,''),(13510,4195,'75744','watch-mobile','text-align','center',0,''),(13511,4196,'75745','watch-mobile','text','<p>Payment date:</p>',1,''),(13512,4196,'75745','watch-mobile','font-weight','bold',0,''),(13513,4196,'75745','watch-mobile','text-align','center',0,''),(13514,4197,'75746','watch-mobile','text','<p>Payment Method:</p>',1,''),(13515,4197,'75746','watch-mobile','font-weight','bold',0,''),(13516,4197,'75746','watch-mobile','text-align','center',0,''),(13517,4198,'94802','watch-mobile','block_type','1',0,''),(13518,4198,'94802','watch-mobile','padding-top','20',0,''),(13519,4199,'94803','watch-mobile','tab_1','RETURNING CUSTOMER',1,''),(13520,4199,'94803','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(13521,4202,'94810','watch-mobile','block_type','1',0,''),(13522,4203,'94811','watch-mobile','text','##TEXT_OR##',0,''),(13523,4203,'94811','watch-mobile','font-size','18',0,''),(13524,4203,'94811','watch-mobile','font-weight','700',0,''),(13525,4203,'94811','watch-mobile','padding-top','15',0,''),(13526,4203,'94811','watch-mobile','text-align','center',0,''),(13527,4203,'94811','watch-mobile','content','\\_',0,'3'),(13528,4203,'94811','watch-mobile','height','5',0,'3'),(13529,4203,'94811','watch-mobile','width','70',0,'3'),(13530,4203,'94811','watch-mobile','display','inline-block',0,'3'),(13531,4203,'94811','watch-mobile','border-top-width','1',0,'3'),(13532,4203,'94811','watch-mobile','border-top-color','$border-color-1',0,'3'),(13533,4203,'94811','watch-mobile','margin-left','10',0,'3'),(13534,4203,'94811','watch-mobile','margin-right','10',0,'3'),(13535,4203,'94811','watch-mobile','content','\\_',0,'4'),(13536,4203,'94811','watch-mobile','display','inline-block',0,'4'),(13537,4203,'94811','watch-mobile','width','70',0,'4'),(13538,4203,'94811','watch-mobile','height','5',0,'4'),(13539,4203,'94811','watch-mobile','border-top-width','1',0,'4'),(13540,4203,'94811','watch-mobile','border-top-color','$border-color-1',0,'4'),(13541,4203,'94811','watch-mobile','margin-left','10',0,'4'),(13542,4203,'94811','watch-mobile','margin-right','10',0,'4'),(13543,4203,'94811','watch-mobile','position','relative',0,''),(13544,4203,'94811','watch-mobile','top','-10',0,''),(13545,4204,'94812','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13546,4204,'94812','watch-mobile','font-size','26',0,''),(13547,4204,'94812','watch-mobile','font-family','$font-1',0,''),(13548,4204,'94812','watch-mobile','padding-top','15',0,''),(13549,4204,'94812','watch-mobile','padding-bottom','15',0,''),(13550,4204,'94812','watch-mobile','text-align','center',0,''),(13551,4205,'94813','watch-mobile','text-align','center',0,''),(13552,4205,'94813','watch-mobile','hide_parents','2',0,''),(13553,4206,'114547','watch-mobile','block_type','1',0,''),(13554,4206,'114547','watch-mobile','padding-top','40',0,''),(13555,4206,'114547','watch-mobile','background-color','$background-6',0,''),(13556,4206,'114547','watch-mobile','padding-bottom','40',0,''),(13557,4207,'114548','watch-mobile','block_type','1',0,''),(13558,4207,'114548','watch-mobile','background-color','$background-7',0,''),(13559,4207,'114548','watch-mobile','max-width','830',0,''),(13560,4207,'114548','watch-mobile','margin_left_measure','auto',0,''),(13561,4207,'114548','watch-mobile','margin_right_measure','auto',0,''),(13562,4207,'114548','watch-mobile','padding-top','40',0,''),(13563,4207,'114548','watch-mobile','padding-bottom','40',0,''),(13564,4207,'114548','watch-mobile','schema','2-3',0,''),(13565,4208,'114549','watch-mobile','text','##NEW_CUSTOMER##',0,''),(13566,4208,'114549','watch-mobile','font-size','18',0,''),(13567,4208,'114549','watch-mobile','font-family','$font-1',0,''),(13568,4208,'114549','watch-mobile','text-align','center',0,''),(13569,4208,'114549','watch-mobile','text-transform','uppercase',0,''),(13570,4208,'114549','watch-mobile','margin-bottom','10',0,''),(13571,4209,'114550','watch-mobile','text-align','center',0,''),(13572,4209,'114550','watch-mobile','margin-bottom','40',0,''),(13573,4210,'114551','watch-mobile','text-align','center',0,''),(13574,4211,'114552','watch-mobile','text','##TEXT_OR##',0,''),(13575,4211,'114552','watch-mobile','font-size','18',0,''),(13576,4211,'114552','watch-mobile','font-weight','700',0,''),(13577,4211,'114552','watch-mobile','text-align','center',0,''),(13578,4211,'114552','watch-mobile','content','\\_',0,'3'),(13579,4211,'114552','watch-mobile','height','5',0,'3'),(13580,4211,'114552','watch-mobile','width','70',0,'3'),(13581,4211,'114552','watch-mobile','display','inline-block',0,'3'),(13582,4211,'114552','watch-mobile','border-top-width','1',0,'3'),(13583,4211,'114552','watch-mobile','border-top-color','$border-color-1',0,'3'),(13584,4211,'114552','watch-mobile','margin-left','10',0,'3'),(13585,4211,'114552','watch-mobile','margin-right','10',0,'3'),(13586,4211,'114552','watch-mobile','content','\\_',0,'4'),(13587,4211,'114552','watch-mobile','display','inline-block',0,'4'),(13588,4211,'114552','watch-mobile','width','70',0,'4'),(13589,4211,'114552','watch-mobile','height','5',0,'4'),(13590,4211,'114552','watch-mobile','border-top-width','1',0,'4'),(13591,4211,'114552','watch-mobile','border-top-color','$border-color-1',0,'4'),(13592,4211,'114552','watch-mobile','margin-left','10',0,'4'),(13593,4211,'114552','watch-mobile','margin-right','10',0,'4'),(13594,4211,'114552','watch-mobile','position','relative',0,''),(13595,4211,'114552','watch-mobile','padding-top','10',0,''),(13596,4211,'114552','watch-mobile','padding-bottom','10',0,''),(13597,4212,'114553','watch-mobile','block_type','1',0,''),(13598,4213,'114554','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13599,4213,'114554','watch-mobile','font-size','18',0,''),(13600,4213,'114554','watch-mobile','font-family','$font-1',0,''),(13601,4213,'114554','watch-mobile','padding-top','15',0,''),(13602,4213,'114554','watch-mobile','padding-bottom','15',0,''),(13603,4213,'114554','watch-mobile','text-align','center',0,''),(13604,4213,'114554','watch-mobile','text-transform','uppercase',0,''),(13605,4214,'114555','watch-mobile','text-align','center',0,''),(13606,4214,'114555','watch-mobile','hide_parents','2',0,''),(13607,4215,'114556','watch-mobile','max-width','230',0,''),(13608,4215,'114556','watch-mobile','margin_left_measure','auto',0,''),(13609,4215,'114556','watch-mobile','margin_right_measure','auto',0,''),(13610,4216,'114557','watch-mobile','text','##RETURNING_CUSTOMER##',0,''),(13611,4216,'114557','watch-mobile','font-size','18',0,''),(13612,4216,'114557','watch-mobile','font-family','$font-1',0,''),(13613,4216,'114557','watch-mobile','text-transform','uppercase',0,''),(13614,4216,'114557','watch-mobile','text-align','center',0,''),(13615,4217,'114558','watch-mobile','block_type','1',0,''),(13616,4217,'114558','watch-mobile','padding-top','20',0,''),(13617,4218,'114559','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13618,4218,'114559','watch-mobile','font-size','26',0,''),(13619,4218,'114559','watch-mobile','font-family','$font-1',0,''),(13620,4218,'114559','watch-mobile','padding-top','15',0,''),(13621,4218,'114559','watch-mobile','padding-bottom','15',0,''),(13622,4218,'114559','watch-mobile','text-align','center',0,''),(13623,4219,'114560','watch-mobile','text','##TEXT_OR##',0,''),(13624,4219,'114560','watch-mobile','font-size','18',0,''),(13625,4219,'114560','watch-mobile','font-weight','700',0,''),(13626,4219,'114560','watch-mobile','padding-top','15',0,''),(13627,4219,'114560','watch-mobile','text-align','center',0,''),(13628,4219,'114560','watch-mobile','content','\\_',0,'3'),(13629,4219,'114560','watch-mobile','height','5',0,'3'),(13630,4219,'114560','watch-mobile','width','70',0,'3'),(13631,4219,'114560','watch-mobile','display','inline-block',0,'3'),(13632,4219,'114560','watch-mobile','border-top-width','1',0,'3'),(13633,4219,'114560','watch-mobile','border-top-color','$border-color-1',0,'3'),(13634,4219,'114560','watch-mobile','margin-left','10',0,'3'),(13635,4219,'114560','watch-mobile','margin-right','10',0,'3'),(13636,4219,'114560','watch-mobile','content','\\_',0,'4'),(13637,4219,'114560','watch-mobile','display','inline-block',0,'4'),(13638,4219,'114560','watch-mobile','width','70',0,'4'),(13639,4219,'114560','watch-mobile','height','5',0,'4'),(13640,4219,'114560','watch-mobile','border-top-width','1',0,'4'),(13641,4219,'114560','watch-mobile','border-top-color','$border-color-1',0,'4'),(13642,4219,'114560','watch-mobile','margin-left','10',0,'4'),(13643,4219,'114560','watch-mobile','margin-right','10',0,'4'),(13644,4219,'114560','watch-mobile','position','relative',0,''),(13645,4219,'114560','watch-mobile','top','-10',0,''),(13646,4220,'114561','watch-mobile','text-align','center',0,''),(13647,4221,'114562','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(13648,4221,'114562','watch-mobile','tab_2','RETURNING CUSTOMER',1,''),(13649,4221,'114562','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(13650,4222,'114563','watch-mobile','block_type','8',0,''),(13651,4223,'114564','watch-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(13652,4224,'114565','watch-mobile','block_type','1',0,''),(13653,4224,'114565','watch-mobile','padding-left','20',0,''),(13654,4224,'114565','watch-mobile','padding-right','20',0,''),(13655,4225,'114566','watch-mobile','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(13656,4225,'114566','watch-mobile','border-top-width','1',0,''),(13657,4225,'114566','watch-mobile','border-top-color','$border-color-1',0,''),(13658,4228,'114569','watch-mobile','block_type','8',0,''),(13659,4229,'114570','watch-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(13660,4230,'114571','watch-mobile','block_type','1',0,''),(13661,4230,'114571','watch-mobile','padding-left','20',0,''),(13662,4230,'114571','watch-mobile','padding-right','20',0,''),(13663,4232,'114573','watch-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(13664,4233,'114574','watch-mobile','block_type','1',0,''),(13665,4233,'114574','watch-mobile','padding-top','20',0,''),(13666,4234,'114575','watch-mobile','text-align','center',0,''),(13667,4235,'114576','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13668,4235,'114576','watch-mobile','font-size','26',0,''),(13669,4235,'114576','watch-mobile','font-family','$font-1',0,''),(13670,4235,'114576','watch-mobile','padding-top','15',0,''),(13671,4235,'114576','watch-mobile','padding-bottom','15',0,''),(13672,4235,'114576','watch-mobile','text-align','center',0,''),(13673,4236,'114577','watch-mobile','text','##TEXT_OR##',0,''),(13674,4236,'114577','watch-mobile','font-size','18',0,''),(13675,4236,'114577','watch-mobile','font-weight','700',0,''),(13676,4236,'114577','watch-mobile','padding-top','15',0,''),(13677,4236,'114577','watch-mobile','text-align','center',0,''),(13678,4236,'114577','watch-mobile','content','\\_',0,'3'),(13679,4236,'114577','watch-mobile','height','5',0,'3'),(13680,4236,'114577','watch-mobile','width','70',0,'3'),(13681,4236,'114577','watch-mobile','display','inline-block',0,'3'),(13682,4236,'114577','watch-mobile','border-top-width','1',0,'3'),(13683,4236,'114577','watch-mobile','border-top-color','$border-color-1',0,'3'),(13684,4236,'114577','watch-mobile','margin-left','10',0,'3'),(13685,4236,'114577','watch-mobile','margin-right','10',0,'3'),(13686,4236,'114577','watch-mobile','content','\\_',0,'4'),(13687,4236,'114577','watch-mobile','display','inline-block',0,'4'),(13688,4236,'114577','watch-mobile','width','70',0,'4'),(13689,4236,'114577','watch-mobile','height','5',0,'4'),(13690,4236,'114577','watch-mobile','border-top-width','1',0,'4'),(13691,4236,'114577','watch-mobile','border-top-color','$border-color-1',0,'4'),(13692,4236,'114577','watch-mobile','margin-left','10',0,'4'),(13693,4236,'114577','watch-mobile','margin-right','10',0,'4'),(13694,4236,'114577','watch-mobile','position','relative',0,''),(13695,4236,'114577','watch-mobile','top','-10',0,''),(13696,4237,'114578','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(13697,4237,'114578','watch-mobile','tab_2','RETURNING CUSTOMER',1,''),(13698,4237,'114578','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(13699,4238,'114579','watch-mobile','block_type','8',0,''),(13700,4239,'114580','watch-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(13701,4242,'114583','watch-mobile','block_type','8',0,''),(13702,4243,'114584','watch-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(13703,4245,'114586','watch-mobile','block_type','1',0,''),(13704,4245,'114586','watch-mobile','padding-left','20',0,''),(13705,4245,'114586','watch-mobile','padding-right','20',0,''),(13706,4246,'114587','watch-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(13707,4248,'114589','watch-mobile','block_type','1',0,''),(13708,4248,'114589','watch-mobile','padding-top','20',0,''),(13709,4249,'114590','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13710,4249,'114590','watch-mobile','font-size','26',0,''),(13711,4249,'114590','watch-mobile','font-family','$font-1',0,''),(13712,4249,'114590','watch-mobile','padding-top','15',0,''),(13713,4249,'114590','watch-mobile','padding-bottom','15',0,''),(13714,4249,'114590','watch-mobile','text-align','center',0,''),(13715,4250,'114591','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(13716,4250,'114591','watch-mobile','tab_2','RETURNING CUSTOMER',1,''),(13717,4250,'114591','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(13718,4251,'114592','watch-mobile','block_type','8',0,''),(13719,4252,'114593','watch-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(13720,4255,'114596','watch-mobile','block_type','8',0,''),(13721,4256,'114597','watch-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(13722,4257,'114598','watch-mobile','block_type','1',0,''),(13723,4257,'114598','watch-mobile','padding-left','20',0,''),(13724,4257,'114598','watch-mobile','padding-right','20',0,''),(13725,4258,'114599','watch-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(13726,4260,'114601','watch-mobile','text-align','center',0,''),(13727,4261,'114602','watch-mobile','text','##TEXT_OR##',0,''),(13728,4261,'114602','watch-mobile','font-size','18',0,''),(13729,4261,'114602','watch-mobile','font-weight','700',0,''),(13730,4261,'114602','watch-mobile','padding-top','15',0,''),(13731,4261,'114602','watch-mobile','text-align','center',0,''),(13732,4261,'114602','watch-mobile','content','\\_',0,'3'),(13733,4261,'114602','watch-mobile','height','5',0,'3'),(13734,4261,'114602','watch-mobile','width','70',0,'3'),(13735,4261,'114602','watch-mobile','display','inline-block',0,'3'),(13736,4261,'114602','watch-mobile','border-top-width','1',0,'3'),(13737,4261,'114602','watch-mobile','border-top-color','$border-color-1',0,'3'),(13738,4261,'114602','watch-mobile','margin-left','10',0,'3'),(13739,4261,'114602','watch-mobile','margin-right','10',0,'3'),(13740,4261,'114602','watch-mobile','content','\\_',0,'4'),(13741,4261,'114602','watch-mobile','display','inline-block',0,'4'),(13742,4261,'114602','watch-mobile','width','70',0,'4'),(13743,4261,'114602','watch-mobile','height','5',0,'4'),(13744,4261,'114602','watch-mobile','border-top-width','1',0,'4'),(13745,4261,'114602','watch-mobile','border-top-color','$border-color-1',0,'4'),(13746,4261,'114602','watch-mobile','margin-left','10',0,'4'),(13747,4261,'114602','watch-mobile','margin-right','10',0,'4'),(13748,4261,'114602','watch-mobile','position','relative',0,''),(13749,4261,'114602','watch-mobile','top','-10',0,''),(13750,4262,'114603','watch-mobile','block_type','1',0,''),(13751,4262,'114603','watch-mobile','padding-top','40',0,''),(13752,4262,'114603','watch-mobile','background-color','$background-6',0,''),(13753,4262,'114603','watch-mobile','padding-bottom','40',0,''),(13754,4263,'114604','watch-mobile','block_type','2',0,''),(13755,4263,'114604','watch-mobile','background-color','$background-7',0,''),(13756,4263,'114604','watch-mobile','max-width','830',0,''),(13757,4263,'114604','watch-mobile','margin_left_measure','auto',0,''),(13758,4263,'114604','watch-mobile','margin_right_measure','auto',0,''),(13759,4263,'114604','watch-mobile','padding-top','40',0,''),(13760,4263,'114604','watch-mobile','padding-bottom','40',0,''),(13761,4264,'114605','watch-mobile','text-align','center',0,''),(13762,4264,'114605','watch-mobile','margin-bottom','40',0,''),(13763,4265,'114606','watch-mobile','text-align','center',0,''),(13764,4266,'114607','watch-mobile','text','##NEW_CUSTOMER##',0,''),(13765,4266,'114607','watch-mobile','font-size','18',0,''),(13766,4266,'114607','watch-mobile','font-family','$font-1',0,''),(13767,4266,'114607','watch-mobile','text-align','center',0,''),(13768,4266,'114607','watch-mobile','text-transform','uppercase',0,''),(13769,4266,'114607','watch-mobile','margin-bottom','10',0,''),(13770,4267,'114608','watch-mobile','text','##TEXT_OR##',0,''),(13771,4267,'114608','watch-mobile','font-size','18',0,''),(13772,4267,'114608','watch-mobile','font-weight','700',0,''),(13773,4267,'114608','watch-mobile','text-align','center',0,''),(13774,4267,'114608','watch-mobile','content','\\_',0,'3'),(13775,4267,'114608','watch-mobile','height','5',0,'3'),(13776,4267,'114608','watch-mobile','width','70',0,'3'),(13777,4267,'114608','watch-mobile','display','inline-block',0,'3'),(13778,4267,'114608','watch-mobile','border-top-width','1',0,'3'),(13779,4267,'114608','watch-mobile','border-top-color','$border-color-1',0,'3'),(13780,4267,'114608','watch-mobile','margin-left','10',0,'3'),(13781,4267,'114608','watch-mobile','margin-right','10',0,'3'),(13782,4267,'114608','watch-mobile','content','\\_',0,'4'),(13783,4267,'114608','watch-mobile','display','inline-block',0,'4'),(13784,4267,'114608','watch-mobile','width','70',0,'4'),(13785,4267,'114608','watch-mobile','height','5',0,'4'),(13786,4267,'114608','watch-mobile','border-top-width','1',0,'4'),(13787,4267,'114608','watch-mobile','border-top-color','$border-color-1',0,'4'),(13788,4267,'114608','watch-mobile','margin-left','10',0,'4'),(13789,4267,'114608','watch-mobile','margin-right','10',0,'4'),(13790,4267,'114608','watch-mobile','position','relative',0,''),(13791,4267,'114608','watch-mobile','padding-top','10',0,''),(13792,4267,'114608','watch-mobile','padding-bottom','10',0,''),(13793,4268,'114609','watch-mobile','block_type','1',0,''),(13794,4269,'114610','watch-mobile','text-align','center',0,''),(13795,4269,'114610','watch-mobile','hide_parents','2',0,''),(13796,4270,'114611','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13797,4270,'114611','watch-mobile','font-size','18',0,''),(13798,4270,'114611','watch-mobile','font-family','$font-1',0,''),(13799,4270,'114611','watch-mobile','padding-top','15',0,''),(13800,4270,'114611','watch-mobile','padding-bottom','15',0,''),(13801,4270,'114611','watch-mobile','text-align','center',0,''),(13802,4270,'114611','watch-mobile','text-transform','uppercase',0,''),(13803,4271,'114612','watch-mobile','max-width','230',0,''),(13804,4271,'114612','watch-mobile','margin_left_measure','auto',0,''),(13805,4271,'114612','watch-mobile','margin_right_measure','auto',0,''),(13806,4272,'114613','watch-mobile','text','##RETURNING_CUSTOMER##',0,''),(13807,4272,'114613','watch-mobile','font-size','18',0,''),(13808,4272,'114613','watch-mobile','font-family','$font-1',0,''),(13809,4272,'114613','watch-mobile','text-transform','uppercase',0,''),(13810,4272,'114613','watch-mobile','text-align','center',0,''),(13811,4273,'114614','watch-mobile','block_type','1',0,''),(13812,4273,'114614','watch-mobile','padding-top','40',0,''),(13813,4273,'114614','watch-mobile','background-color','$background-6',0,''),(13814,4273,'114614','watch-mobile','padding-bottom','40',0,''),(13815,4274,'114615','watch-mobile','block_type','2',0,''),(13816,4274,'114615','watch-mobile','background-color','$background-7',0,''),(13817,4274,'114615','watch-mobile','max-width','830',0,''),(13818,4274,'114615','watch-mobile','margin_left_measure','auto',0,''),(13819,4274,'114615','watch-mobile','margin_right_measure','auto',0,''),(13820,4274,'114615','watch-mobile','padding-top','40',0,''),(13821,4274,'114615','watch-mobile','padding-bottom','40',0,''),(13822,4275,'114616','watch-mobile','block_type','1',0,''),(13823,4276,'114617','watch-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(13824,4276,'114617','watch-mobile','font-size','18',0,''),(13825,4276,'114617','watch-mobile','font-family','$font-1',0,''),(13826,4276,'114617','watch-mobile','padding-top','15',0,''),(13827,4276,'114617','watch-mobile','padding-bottom','15',0,''),(13828,4276,'114617','watch-mobile','text-align','center',0,''),(13829,4276,'114617','watch-mobile','text-transform','uppercase',0,''),(13830,4277,'114618','watch-mobile','text-align','center',0,''),(13831,4277,'114618','watch-mobile','hide_parents','2',0,''),(13832,4278,'114619','watch-mobile','text','##TEXT_OR##',0,''),(13833,4278,'114619','watch-mobile','font-size','18',0,''),(13834,4278,'114619','watch-mobile','font-weight','700',0,''),(13835,4278,'114619','watch-mobile','text-align','center',0,''),(13836,4278,'114619','watch-mobile','content','\\_',0,'3'),(13837,4278,'114619','watch-mobile','height','5',0,'3'),(13838,4278,'114619','watch-mobile','width','70',0,'3'),(13839,4278,'114619','watch-mobile','display','inline-block',0,'3'),(13840,4278,'114619','watch-mobile','border-top-width','1',0,'3'),(13841,4278,'114619','watch-mobile','border-top-color','$border-color-1',0,'3'),(13842,4278,'114619','watch-mobile','margin-left','10',0,'3'),(13843,4278,'114619','watch-mobile','margin-right','10',0,'3'),(13844,4278,'114619','watch-mobile','content','\\_',0,'4'),(13845,4278,'114619','watch-mobile','display','inline-block',0,'4'),(13846,4278,'114619','watch-mobile','width','70',0,'4'),(13847,4278,'114619','watch-mobile','height','5',0,'4'),(13848,4278,'114619','watch-mobile','border-top-width','1',0,'4'),(13849,4278,'114619','watch-mobile','border-top-color','$border-color-1',0,'4'),(13850,4278,'114619','watch-mobile','margin-left','10',0,'4'),(13851,4278,'114619','watch-mobile','margin-right','10',0,'4'),(13852,4278,'114619','watch-mobile','position','relative',0,''),(13853,4278,'114619','watch-mobile','padding-top','10',0,''),(13854,4278,'114619','watch-mobile','padding-bottom','10',0,''),(13855,4279,'114620','watch-mobile','text-align','center',0,''),(13856,4279,'114620','watch-mobile','margin-bottom','40',0,''),(13857,4280,'114621','watch-mobile','text','##NEW_CUSTOMER##',0,''),(13858,4280,'114621','watch-mobile','font-size','18',0,''),(13859,4280,'114621','watch-mobile','font-family','$font-1',0,''),(13860,4280,'114621','watch-mobile','text-align','center',0,''),(13861,4280,'114621','watch-mobile','text-transform','uppercase',0,''),(13862,4280,'114621','watch-mobile','margin-bottom','10',0,''),(13863,4281,'114622','watch-mobile','text-align','center',0,''),(13864,4282,'114623','watch-mobile','text','##RETURNING_CUSTOMER##',0,''),(13865,4282,'114623','watch-mobile','font-size','18',0,''),(13866,4282,'114623','watch-mobile','font-family','$font-1',0,''),(13867,4282,'114623','watch-mobile','text-transform','uppercase',0,''),(13868,4282,'114623','watch-mobile','text-align','center',0,''),(13869,4283,'114624','watch-mobile','max-width','230',0,''),(13870,4283,'114624','watch-mobile','margin_left_measure','auto',0,''),(13871,4283,'114624','watch-mobile','margin_right_measure','auto',0,''),(13872,4284,'114625','watch-mobile','block_type','1',0,''),(13873,4285,'114626','watch-mobile','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(13874,4285,'114626','watch-mobile','margin-bottom','30',0,''),(13875,4286,'114627','watch-mobile','block_type','1',0,''),(13876,4287,'114628','watch-mobile','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(13877,4287,'114628','watch-mobile','margin-bottom','30',0,''),(13878,4288,'75747','watch-mobile','block_type','1',0,''),(13879,4288,'75747','watch-mobile','font-weight','normal',0,''),(13880,4290,'75749','watch-mobile','box_align','4',0,''),(13881,4290,'75749','watch-mobile','margin-bottom','30',0,''),(13882,4291,'75750','watch-mobile','tab_1','New products',1,''),(13883,4291,'75750','watch-mobile','tab_2','Specials products',1,''),(13884,4291,'75750','watch-mobile','font-weight','normal',0,''),(13885,4291,'75750','watch-mobile','tab_3','Featured',1,''),(13886,4291,'75750','watch-mobile','accordion','1',0,'290'),(13887,4292,'75751','watch-mobile','font-weight','400',0,''),(13888,4292,'75751','watch-mobile','listing_type','productListing',0,''),(13889,4292,'75751','watch-mobile','show_compare','1',0,''),(13890,4292,'75751','watch-mobile','show_model','1',0,''),(13891,4292,'75751','watch-mobile','show_properties','1',0,''),(13892,4292,'75751','watch-mobile','col_in_row','2',0,''),(13893,4292,'75751','watch-mobile','show_name','0',0,''),(13894,4292,'75751','watch-mobile','show_image','0',0,''),(13895,4292,'75751','watch-mobile','show_stock','0',0,''),(13896,4292,'75751','watch-mobile','show_description','0',0,''),(13897,4292,'75751','watch-mobile','show_rating','0',0,''),(13898,4292,'75751','watch-mobile','show_rating_counts','0',0,''),(13899,4292,'75751','watch-mobile','show_price','0',0,''),(13900,4292,'75751','watch-mobile','show_buy_button','0',0,''),(13901,4292,'75751','watch-mobile','show_qty_input','0',0,''),(13902,4292,'75751','watch-mobile','show_view_button','0',0,''),(13903,4292,'75751','watch-mobile','show_wishlist_button','0',0,''),(13904,4292,'75751','watch-mobile','col_in_row','2',0,'291'),(13905,4292,'75751','watch-mobile','col_in_row','1',0,'315'),(13906,4292,'75751','watch-mobile','view_as','carousel',0,''),(13907,4292,'75751','watch-mobile','col_in_row','3',0,'299'),(13908,4293,'75752','watch-mobile','font-weight','400',0,''),(13909,4293,'75752','watch-mobile','show_compare','1',0,''),(13910,4293,'75752','watch-mobile','listing_type','productListing',0,''),(13911,4293,'75752','watch-mobile','show_model','1',0,''),(13912,4293,'75752','watch-mobile','show_properties','1',0,''),(13913,4293,'75752','watch-mobile','col_in_row','2',0,''),(13914,4293,'75752','watch-mobile','show_name','0',0,''),(13915,4293,'75752','watch-mobile','show_image','0',0,''),(13916,4293,'75752','watch-mobile','show_stock','0',0,''),(13917,4293,'75752','watch-mobile','show_description','0',0,''),(13918,4293,'75752','watch-mobile','show_rating','0',0,''),(13919,4293,'75752','watch-mobile','show_rating_counts','0',0,''),(13920,4293,'75752','watch-mobile','show_price','0',0,''),(13921,4293,'75752','watch-mobile','show_buy_button','0',0,''),(13922,4293,'75752','watch-mobile','show_qty_input','0',0,''),(13923,4293,'75752','watch-mobile','show_view_button','0',0,''),(13924,4293,'75752','watch-mobile','show_wishlist_button','0',0,''),(13925,4293,'75752','watch-mobile','col_in_row','2',0,'291'),(13926,4293,'75752','watch-mobile','col_in_row','1',0,'315'),(13927,4293,'75752','watch-mobile','view_as','carousel',0,''),(13928,4293,'75752','watch-mobile','col_in_row','3',0,'299'),(13929,4293,'75752','watch-mobile','product_names_teg','h2',0,''),(13930,4294,'75753','watch-mobile','font-weight','400',0,''),(13931,4294,'75753','watch-mobile','show_compare','1',0,''),(13932,4294,'75753','watch-mobile','listing_type','productListing',0,''),(13933,4294,'75753','watch-mobile','show_model','1',0,''),(13934,4294,'75753','watch-mobile','show_properties','1',0,''),(13935,4294,'75753','watch-mobile','col_in_row','2',0,''),(13936,4294,'75753','watch-mobile','show_name','0',0,''),(13937,4294,'75753','watch-mobile','show_image','0',0,''),(13938,4294,'75753','watch-mobile','show_stock','0',0,''),(13939,4294,'75753','watch-mobile','show_description','0',0,''),(13940,4294,'75753','watch-mobile','show_rating','0',0,''),(13941,4294,'75753','watch-mobile','show_rating_counts','0',0,''),(13942,4294,'75753','watch-mobile','show_price','0',0,''),(13943,4294,'75753','watch-mobile','show_buy_button','0',0,''),(13944,4294,'75753','watch-mobile','show_qty_input','0',0,''),(13945,4294,'75753','watch-mobile','show_view_button','0',0,''),(13946,4294,'75753','watch-mobile','show_wishlist_button','0',0,''),(13947,4294,'75753','watch-mobile','col_in_row','2',0,'291'),(13948,4294,'75753','watch-mobile','col_in_row','1',0,'315'),(13949,4294,'75753','watch-mobile','view_as','carousel',0,''),(13950,4294,'75753','watch-mobile','col_in_row','3',0,'299'),(13951,4295,'75754','watch-mobile','heading_type','h1',0,''),(13952,4296,'75755','watch-mobile','block_type','1',0,''),(13953,4296,'75755','watch-mobile','background-color','$background-6',0,''),(13954,4296,'75755','watch-mobile','padding-top','20',0,''),(13955,4296,'75755','watch-mobile','padding-bottom','20',0,''),(13956,4296,'75755','watch-mobile','font-weight','400',0,''),(13957,4296,'75755','watch-mobile','visibility_product','1',0,''),(13958,4296,'75755','watch-mobile','visibility_catalog','1',0,''),(13959,4296,'75755','watch-mobile','visibility_info','1',0,''),(13960,4296,'75755','watch-mobile','visibility_cart','1',0,''),(13961,4296,'75755','watch-mobile','visibility_checkout','1',0,''),(13962,4296,'75755','watch-mobile','visibility_success','1',0,''),(13963,4296,'75755','watch-mobile','visibility_account','1',0,''),(13964,4296,'75755','watch-mobile','visibility_login','1',0,''),(13965,4296,'75755','watch-mobile','visibility_other','1',0,''),(13966,4296,'75755','watch-mobile','margin-bottom','20',0,''),(13967,4296,'75755','watch-mobile','display_none','on',0,'291'),(13968,4297,'75756','watch-mobile','block_type','2',0,''),(13969,4297,'75756','watch-mobile','font-weight','normal',0,''),(13970,4298,'75757','watch-mobile','font-weight','400',0,''),(13971,4298,'75757','watch-mobile','visibility_product','1',0,''),(13972,4298,'75757','watch-mobile','show_name','0',0,''),(13973,4298,'75757','watch-mobile','show_image','1',0,''),(13974,4298,'75757','watch-mobile','show_stock','1',0,''),(13975,4298,'75757','watch-mobile','show_description','1',0,''),(13976,4298,'75757','watch-mobile','show_model','1',0,''),(13977,4298,'75757','watch-mobile','show_rating','1',0,''),(13978,4298,'75757','watch-mobile','show_rating_counts','1',0,''),(13979,4298,'75757','watch-mobile','show_price','1',0,''),(13980,4298,'75757','watch-mobile','show_buy_button','1',0,''),(13981,4298,'75757','watch-mobile','show_qty_input','1',0,''),(13982,4298,'75757','watch-mobile','show_view_button','1',0,''),(13983,4298,'75757','watch-mobile','show_wishlist_button','1',0,''),(13984,4298,'75757','watch-mobile','show_compare','1',0,''),(13985,4298,'75757','watch-mobile','listing_type','type-1',0,''),(13986,4298,'75757','watch-mobile','show_properties','1',0,''),(13987,4299,'75758','watch-mobile','font-weight','normal',0,''),(13988,4299,'75758','watch-mobile','visibility_product','1',0,''),(13989,4300,'114629','watch-mobile','block_type','1',0,''),(13990,4301,'114630','watch-mobile','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(13991,4303,'114632','watch-mobile','block_type','1',0,''),(13992,4303,'114632','watch-mobile','padding-top','40',0,''),(13993,4303,'114632','watch-mobile','padding-bottom','80',0,''),(13994,4304,'114633','watch-mobile','block_type','6',0,''),(13995,4305,'114634','watch-mobile','block_type','1',0,''),(13996,4305,'114634','watch-mobile','padding-top','20',0,''),(13997,4305,'114634','watch-mobile','padding-left','20',0,''),(13998,4305,'114634','watch-mobile','padding-right','20',0,''),(13999,4305,'114634','watch-mobile','padding-bottom','20',0,''),(14000,4305,'114634','watch-mobile','border-top-width','1',0,''),(14001,4305,'114634','watch-mobile','border-left-width','1',0,''),(14002,4305,'114634','watch-mobile','border-right-width','1',0,''),(14003,4305,'114634','watch-mobile','border-bottom-width','1',0,''),(14004,4305,'114634','watch-mobile','border-top-color','$border-color-1',0,''),(14005,4305,'114634','watch-mobile','border-left-color','$border-color-1',0,''),(14006,4305,'114634','watch-mobile','border-right-color','$border-color-1',0,''),(14007,4305,'114634','watch-mobile','border-bottom-color','$border-color-1',0,''),(14008,4305,'114634','watch-mobile','margin-right','20',0,''),(14009,4308,'114637','watch-mobile','block_type','1',0,''),(14010,4308,'114637','watch-mobile','padding-top','20',0,''),(14011,4309,'114638','watch-mobile','block_type','6',0,''),(14012,4310,'114639','watch-mobile','padding-right','20',0,''),(14013,4312,'114641','watch-mobile','block_type','1',0,''),(14014,4312,'114641','watch-mobile','padding-top','20',0,''),(14015,4313,'114642','watch-mobile','block_type','6',0,''),(14016,4314,'114643','watch-mobile','padding-right','20',0,''),(14017,4316,'114645','watch-mobile','block_type','1',0,''),(14018,4317,'114646','watch-mobile','block_type','6',0,''),(14019,4317,'114646','watch-mobile','schema','6-3',0,''),(14020,4317,'114646','watch-mobile','schema','6-3',0,'299'),(14021,4318,'114647','watch-mobile','aria_name','account-menu',0,''),(14022,4320,'114649','watch-mobile','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(14023,4321,'114650','watch-mobile','text','CANCEL',0,''),(14024,4321,'114650','watch-mobile','like_button','1',0,''),(14025,4321,'114650','watch-mobile','padding-bottom','20',0,''),(14026,4322,'114651','watch-mobile','block_type','1',0,''),(14027,4322,'114651','watch-mobile','padding-top','20',0,''),(14028,4323,'114652','watch-mobile','block_type','1',0,''),(14029,4324,'114653','watch-mobile','tab_1','RETURNING CUSTOMER',1,''),(14030,4324,'114653','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(14031,4326,'114655','watch-mobile','block_type','8',0,''),(14032,4327,'114656','watch-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(14033,4328,'114657','watch-mobile','block_type','1',0,''),(14034,4328,'114657','watch-mobile','padding-left','20',0,''),(14035,4328,'114657','watch-mobile','padding-right','20',0,''),(14036,4330,'114659','watch-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(14037,4331,'114660','watch-mobile','block_type','1',0,''),(14038,4332,'114661','watch-mobile','margin-bottom','30',0,''),(14039,4333,'114662','watch-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(14040,4334,'114663','watch-mobile','margin_left_measure','auto',0,''),(14041,4334,'114663','watch-mobile','margin_right_measure','auto',0,''),(14042,4334,'114663','watch-mobile','max-width','560',0,''),(14043,4335,'114664','watch-mobile','block_type','1',0,''),(14044,4337,'114666','watch-mobile','block_type','6',0,''),(14045,4337,'114666','watch-mobile','font-weight','400',0,''),(14046,4337,'114666','watch-mobile','schema','6-2',0,''),(14048,4338,'114667','watch-mobile','font-weight','400',0,''),(14049,4338,'114667','watch-mobile','padding-right','40',0,''),(14052,4339,'114668','watch-mobile','col_in_row','3',0,''),(14053,4339,'114668','watch-mobile','products_align','left',0,''),(14054,4339,'114668','watch-mobile','font-weight','400',0,''),(14055,4339,'114668','watch-mobile','show_qty_input','0',0,''),(14056,4339,'114668','watch-mobile','listing_type','productListing',0,''),(14057,4339,'114668','watch-mobile','listing_type_rows','no',0,''),(14058,4339,'114668','watch-mobile','show_buy_button_b2b','on',0,''),(14059,4339,'114668','watch-mobile','show_wishlist_button_b2b','1',0,''),(14060,4339,'114668','watch-mobile','show_compare_b2b','1',0,''),(14061,4339,'114668','watch-mobile','show_stock','0',0,''),(14062,4339,'114668','watch-mobile','show_description','0',0,''),(14063,4339,'114668','watch-mobile','show_model','0',0,''),(14064,4339,'114668','watch-mobile','show_properties','0',0,''),(14065,4339,'114668','watch-mobile','show_rating','0',0,''),(14066,4339,'114668','watch-mobile','show_rating_counts','0',0,''),(14067,4339,'114668','watch-mobile','show_price','0',0,''),(14068,4339,'114668','watch-mobile','show_buy_button','0',0,''),(14069,4339,'114668','watch-mobile','show_view_button','0',0,''),(14070,4339,'114668','watch-mobile','show_wishlist_button','0',0,''),(14071,4339,'114668','watch-mobile','show_compare','0',0,''),(14072,4339,'114668','watch-mobile','show_name_rows','0',0,''),(14073,4339,'114668','watch-mobile','show_image_rows','0',0,''),(14074,4339,'114668','watch-mobile','show_stock_rows','0',0,''),(14075,4339,'114668','watch-mobile','show_description_rows','0',0,''),(14076,4339,'114668','watch-mobile','show_model_rows','0',0,''),(14077,4339,'114668','watch-mobile','show_properties_rows','0',0,''),(14078,4339,'114668','watch-mobile','show_rating_rows','0',0,''),(14079,4339,'114668','watch-mobile','show_rating_counts_rows','0',0,''),(14080,4339,'114668','watch-mobile','show_price_rows','0',0,''),(14081,4339,'114668','watch-mobile','show_buy_button_rows','0',0,''),(14082,4339,'114668','watch-mobile','show_qty_input_rows','0',0,''),(14083,4339,'114668','watch-mobile','show_view_button_rows','0',0,''),(14084,4339,'114668','watch-mobile','show_wishlist_button_rows','0',0,''),(14085,4339,'114668','watch-mobile','show_compare_rows','0',0,''),(14086,4339,'114668','watch-mobile','show_name_b2b','0',0,''),(14087,4339,'114668','watch-mobile','show_image_b2b','0',0,''),(14088,4339,'114668','watch-mobile','show_stock_b2b','0',0,''),(14089,4339,'114668','watch-mobile','show_description_b2b','0',0,''),(14090,4339,'114668','watch-mobile','show_model_b2b','0',0,''),(14091,4339,'114668','watch-mobile','show_properties_b2b','0',0,''),(14092,4339,'114668','watch-mobile','show_rating_b2b','0',0,''),(14093,4339,'114668','watch-mobile','show_rating_counts_b2b','0',0,''),(14094,4339,'114668','watch-mobile','show_price_b2b','0',0,''),(14095,4339,'114668','watch-mobile','show_qty_input_b2b','0',0,''),(14096,4339,'114668','watch-mobile','show_view_button_b2b','0',0,''),(14097,4339,'114668','watch-mobile','show_attributes_b2b','0',0,''),(14098,4339,'114668','watch-mobile','items_on_page','9',0,''),(14101,4339,'114668','watch-mobile','product_names_teg','h2',0,''),(14102,4341,'114670','watch-mobile','block_type','5',0,''),(14103,4341,'114670','watch-mobile','padding-top','10',0,''),(14104,4341,'114670','watch-mobile','padding-bottom','10',0,''),(14105,4341,'114670','watch-mobile','schema','5-2',0,''),(14106,4341,'114670','watch-mobile','border-top-color','$border-color-1',0,''),(14107,4341,'114670','watch-mobile','border-top-width','1',0,''),(14108,4343,'114672','watch-mobile','float','right',0,''),(14109,4344,'114673','watch-mobile','listing_type','productListing',0,''),(14110,4346,'114675','watch-mobile','block_type','1',0,''),(14111,4346,'114675','watch-mobile','padding-top','10',0,''),(14112,4346,'114675','watch-mobile','padding-bottom','10',0,''),(14113,4346,'114675','watch-mobile','border-bottom-width','1',0,''),(14114,4346,'114675','watch-mobile','border-bottom-color','$border-color-1',0,''),(14115,4346,'114675','watch-mobile','margin-left','0',0,''),(14116,4346,'114675','watch-mobile','margin-right','0',0,''),(14117,4347,'114676','watch-mobile','float','right',0,''),(14118,4347,'114676','watch-mobile','display','none',0,''),(14119,4348,'114677','watch-mobile','float','left',0,''),(14120,4348,'114677','watch-mobile','clear','none',0,''),(14121,4348,'114677','watch-mobile','margin-left','20',0,''),(14122,4348,'114677','watch-mobile','display','none',0,''),(14123,4349,'114678','watch-mobile','margin-right','20',0,''),(14124,4349,'114678','watch-mobile','float','right',0,''),(14125,4349,'114678','watch-mobile','clear','none',0,''),(14126,4349,'114678','watch-mobile','display','none',0,''),(14127,4350,'114679','watch-mobile','float','left',0,''),(14128,4350,'114679','watch-mobile','clear','none',0,''),(14129,4350,'114679','watch-mobile','sort_pos_3','1',0,''),(14130,4350,'114679','watch-mobile','sort_pos_4','2',0,''),(14131,4350,'114679','watch-mobile','sort_pos_10','3',0,''),(14132,4350,'114679','watch-mobile','sort_pos_9','4',0,''),(14133,4350,'114679','watch-mobile','sort_pos_11','5',0,''),(14134,4350,'114679','watch-mobile','sort_pos_12','6',0,''),(14135,4350,'114679','watch-mobile','sort_pos_14','7',0,''),(14136,4350,'114679','watch-mobile','sort_pos_13','8',0,''),(14137,4350,'114679','watch-mobile','sort_pos_8','9',0,''),(14138,4350,'114679','watch-mobile','sort_pos_7','10',0,''),(14139,4350,'114679','watch-mobile','sort_pos_2','11',0,''),(14140,4350,'114679','watch-mobile','sort_pos_1','12',0,''),(14141,4350,'114679','watch-mobile','sort_pos_6','13',0,''),(14142,4350,'114679','watch-mobile','sort_pos_5','14',0,''),(14143,4350,'114679','watch-mobile','sort_pos_0','15',0,''),(14144,4350,'114679','watch-mobile','sort_hide_10','1',0,''),(14145,4350,'114679','watch-mobile','sort_hide_9','1',0,''),(14146,4350,'114679','watch-mobile','hide_icons','1',0,''),(14147,4350,'114679','watch-mobile','sort_hide_16','1',0,''),(14148,4350,'114679','watch-mobile','sort_hide_15','1',0,''),(14149,4350,'114679','watch-mobile','sort_hide_3','0',0,''),(14150,4350,'114679','watch-mobile','sort_hide_4','0',0,''),(14151,4350,'114679','watch-mobile','sort_hide_11','1',0,''),(14152,4350,'114679','watch-mobile','sort_hide_12','1',0,''),(14153,4350,'114679','watch-mobile','sort_hide_14','1',0,''),(14154,4350,'114679','watch-mobile','sort_hide_13','1',0,''),(14155,4350,'114679','watch-mobile','sort_hide_8','0',0,''),(14156,4350,'114679','watch-mobile','sort_hide_7','0',0,''),(14157,4350,'114679','watch-mobile','sort_hide_2','1',0,''),(14158,4350,'114679','watch-mobile','sort_hide_1','1',0,''),(14159,4350,'114679','watch-mobile','sort_hide_6','1',0,''),(14160,4350,'114679','watch-mobile','sort_hide_5','1',0,''),(14161,4350,'114679','watch-mobile','sort_hide_0','1',0,''),(14162,4351,'114680','watch-mobile','block_type','1',0,''),(14163,4352,'114681','watch-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(14164,4353,'114682','watch-mobile','margin-bottom','30',0,''),(14165,4354,'114683','watch-mobile','block_type','1',0,''),(14166,4355,'114684','watch-mobile','block_type','1',0,''),(14167,4356,'114685','watch-mobile','margin-bottom','20',0,''),(14168,4357,'114686','watch-mobile','block_type','1',0,''),(14169,4357,'114686','watch-mobile','padding-top','10',0,''),(14170,4357,'114686','watch-mobile','padding-bottom','10',0,''),(14171,4357,'114686','watch-mobile','border-bottom-width','1',0,''),(14172,4357,'114686','watch-mobile','border-bottom-color','$border-color-1',0,''),(14173,4357,'114686','watch-mobile','margin-left','0',0,''),(14174,4357,'114686','watch-mobile','margin-right','0',0,''),(14175,4358,'114687','watch-mobile','float','left',0,''),(14176,4358,'114687','watch-mobile','clear','none',0,''),(14177,4358,'114687','watch-mobile','sort_pos_3','2',0,''),(14178,4358,'114687','watch-mobile','sort_pos_4','1',0,''),(14179,4358,'114687','watch-mobile','sort_pos_10','5',0,''),(14180,4358,'114687','watch-mobile','sort_pos_9','6',0,''),(14181,4358,'114687','watch-mobile','sort_pos_11','7',0,''),(14182,4358,'114687','watch-mobile','sort_pos_12','8',0,''),(14183,4358,'114687','watch-mobile','sort_pos_14','9',0,''),(14184,4358,'114687','watch-mobile','sort_pos_13','10',0,''),(14185,4358,'114687','watch-mobile','sort_pos_8','11',0,''),(14186,4358,'114687','watch-mobile','sort_pos_7','12',0,''),(14187,4358,'114687','watch-mobile','sort_pos_2','13',0,''),(14188,4358,'114687','watch-mobile','sort_pos_1','14',0,''),(14189,4358,'114687','watch-mobile','sort_pos_6','15',0,''),(14190,4358,'114687','watch-mobile','sort_pos_5','16',0,''),(14191,4358,'114687','watch-mobile','sort_pos_0','17',0,''),(14192,4358,'114687','watch-mobile','sort_hide_10','1',0,''),(14193,4358,'114687','watch-mobile','sort_hide_9','1',0,''),(14194,4358,'114687','watch-mobile','sort_pos_15','4',0,''),(14195,4358,'114687','watch-mobile','sort_pos_16','3',0,''),(14196,4358,'114687','watch-mobile','sort_hide_4','0',0,''),(14197,4358,'114687','watch-mobile','sort_hide_3','0',0,''),(14198,4358,'114687','watch-mobile','sort_hide_16','1',0,''),(14199,4358,'114687','watch-mobile','sort_hide_15','1',0,''),(14200,4358,'114687','watch-mobile','sort_hide_11','1',0,''),(14201,4358,'114687','watch-mobile','sort_hide_12','1',0,''),(14202,4358,'114687','watch-mobile','sort_hide_14','1',0,''),(14203,4358,'114687','watch-mobile','sort_hide_13','1',0,''),(14204,4358,'114687','watch-mobile','sort_hide_8','0',0,''),(14205,4358,'114687','watch-mobile','sort_hide_7','0',0,''),(14206,4358,'114687','watch-mobile','sort_hide_2','1',0,''),(14207,4358,'114687','watch-mobile','sort_hide_1','1',0,''),(14208,4358,'114687','watch-mobile','sort_hide_6','1',0,''),(14209,4358,'114687','watch-mobile','sort_hide_5','1',0,''),(14210,4358,'114687','watch-mobile','sort_hide_0','1',0,''),(14211,4358,'114687','watch-mobile','hide_icons','1',0,''),(14212,4359,'114688','watch-mobile','float','left',0,''),(14213,4359,'114688','watch-mobile','clear','none',0,''),(14214,4359,'114688','watch-mobile','margin-left','20',0,''),(14215,4359,'114688','watch-mobile','display','none',0,''),(14216,4360,'114689','watch-mobile','clear','none',0,''),(14217,4360,'114689','watch-mobile','float','left',0,''),(14218,4360,'114689','watch-mobile','padding-top','3',0,''),(14219,4360,'114689','watch-mobile','margin-left','20',0,''),(14220,4361,'114690','watch-mobile','margin-right','20',0,''),(14221,4361,'114690','watch-mobile','float','right',0,''),(14222,4361,'114690','watch-mobile','clear','none',0,''),(14223,4361,'114690','watch-mobile','display','none',0,''),(14224,4362,'114691','watch-mobile','float','right',0,''),(14225,4362,'114691','watch-mobile','display','none',0,''),(14226,4363,'114692','watch-mobile','block_type','5',0,''),(14227,4363,'114692','watch-mobile','padding-top','10',0,''),(14228,4363,'114692','watch-mobile','padding-bottom','10',0,''),(14229,4363,'114692','watch-mobile','schema','5-2',0,''),(14230,4363,'114692','watch-mobile','border-top-color','$border-color-1',0,''),(14231,4363,'114692','watch-mobile','border-top-width','1',0,''),(14232,4364,'114693','watch-mobile','padding-top','3',0,''),(14233,4365,'114694','watch-mobile','float','right',0,''),(14234,4365,'114694','watch-mobile','height','31',0,''),(14235,4368,'114697','watch-mobile','col_in_row','4',0,''),(14236,4368,'114697','watch-mobile','products_align','left',0,''),(14237,4368,'114697','watch-mobile','font-weight','400',0,''),(14238,4368,'114697','watch-mobile','listing_type','productListing',0,''),(14239,4368,'114697','watch-mobile','listing_type_rows','Rows',0,''),(14240,4368,'114697','watch-mobile','show_buy_button_b2b','on',0,''),(14241,4368,'114697','watch-mobile','show_wishlist_button_b2b','1',0,''),(14242,4368,'114697','watch-mobile','show_compare_b2b','1',0,''),(14243,4368,'114697','watch-mobile','listing_type_b2b','b2b',0,''),(14244,4368,'114697','watch-mobile','show_image','0',0,''),(14245,4368,'114697','watch-mobile','show_stock','0',0,''),(14246,4368,'114697','watch-mobile','show_description','0',0,''),(14247,4368,'114697','watch-mobile','show_model','0',0,''),(14248,4368,'114697','watch-mobile','show_properties','0',0,''),(14249,4368,'114697','watch-mobile','show_rating','0',0,''),(14250,4368,'114697','watch-mobile','show_rating_counts','0',0,''),(14251,4368,'114697','watch-mobile','show_price','0',0,''),(14252,4368,'114697','watch-mobile','show_buy_button','0',0,''),(14253,4368,'114697','watch-mobile','show_view_button','0',0,''),(14254,4368,'114697','watch-mobile','show_wishlist_button','0',0,''),(14255,4368,'114697','watch-mobile','show_compare','0',0,''),(14256,4368,'114697','watch-mobile','show_name_rows','0',0,''),(14257,4368,'114697','watch-mobile','show_image_rows','0',0,''),(14258,4368,'114697','watch-mobile','show_stock_rows','0',0,''),(14259,4368,'114697','watch-mobile','show_description_rows','0',0,''),(14260,4368,'114697','watch-mobile','show_model_rows','0',0,''),(14261,4368,'114697','watch-mobile','show_properties_rows','0',0,''),(14262,4368,'114697','watch-mobile','show_rating_rows','0',0,''),(14263,4368,'114697','watch-mobile','show_rating_counts_rows','0',0,''),(14264,4368,'114697','watch-mobile','show_price_rows','0',0,''),(14265,4368,'114697','watch-mobile','show_buy_button_rows','0',0,''),(14266,4368,'114697','watch-mobile','show_qty_input_rows','0',0,''),(14267,4368,'114697','watch-mobile','show_view_button_rows','0',0,''),(14268,4368,'114697','watch-mobile','show_wishlist_button_rows','0',0,''),(14269,4368,'114697','watch-mobile','show_compare_rows','0',0,''),(14270,4368,'114697','watch-mobile','show_name_b2b','0',0,''),(14271,4368,'114697','watch-mobile','show_image_b2b','0',0,''),(14272,4368,'114697','watch-mobile','show_stock_b2b','0',0,''),(14273,4368,'114697','watch-mobile','show_description_b2b','0',0,''),(14274,4368,'114697','watch-mobile','show_model_b2b','0',0,''),(14275,4368,'114697','watch-mobile','show_properties_b2b','0',0,''),(14276,4368,'114697','watch-mobile','show_rating_b2b','0',0,''),(14277,4368,'114697','watch-mobile','show_rating_counts_b2b','0',0,''),(14278,4368,'114697','watch-mobile','show_price_b2b','0',0,''),(14279,4368,'114697','watch-mobile','show_qty_input_b2b','0',0,''),(14280,4368,'114697','watch-mobile','show_view_button_b2b','0',0,''),(14281,4368,'114697','watch-mobile','show_attributes_b2b','0',0,''),(14282,4368,'114697','watch-mobile','items_on_page','12',0,''),(14285,4368,'114697','watch-mobile','product_names_teg','h2',0,''),(14286,4369,'114698','watch-mobile','block_type','1',0,''),(14287,4370,'114699','watch-mobile','block_type','6',0,''),(14288,4370,'114699','watch-mobile','schema','6-3',0,''),(14289,4370,'114699','watch-mobile','schema','6-3',0,'299'),(14290,4371,'114700','watch-mobile','aria_name','account-menu',0,''),(14291,4372,'114701','watch-mobile','link','Order History Info',0,''),(14292,4372,'114701','watch-mobile','text','TEXT_VIEW',0,''),(14293,4372,'114701','watch-mobile','show_pagenation','1',0,''),(14294,4372,'114701','watch-mobile','link_pay','Order pay',0,''),(14295,4372,'114701','watch-mobile','margin-bottom','20',0,''),(14296,4373,'114702','watch-mobile','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(14297,4374,'114703','watch-mobile','block_type','1',0,''),(14298,4375,'114704','watch-mobile','block_type','6',0,''),(14299,4375,'114704','watch-mobile','schema','6-3',0,'299'),(14300,4376,'114705','watch-mobile','aria_name','account-menu',0,''),(14301,4377,'114706','watch-mobile','float','left',0,''),(14302,4378,'114707','watch-mobile','block_type','3',0,''),(14303,4378,'114707','watch-mobile','clear','both',0,''),(14304,4378,'114707','watch-mobile','padding-top','20',0,''),(14305,4378,'114707','watch-mobile','schema','3-4',0,'299'),(14306,4379,'114708','watch-mobile','block_type','1',0,''),(14307,4379,'114708','watch-mobile','padding-right','20',0,''),(14308,4379,'114708','watch-mobile','margin-bottom','20',0,''),(14309,4380,'114709','watch-mobile','link','Tracking numbers',0,''),(14310,4380,'114709','watch-mobile','text','MORE_TRACKING_NUMBER',0,''),(14311,4380,'114709','watch-mobile','popup','1',0,''),(14312,4380,'114709','watch-mobile','order_id','1',0,''),(14313,4380,'114709','watch-mobile','popup_class','tracking-numbers-popup',0,''),(14314,4380,'114709','watch-mobile','font-weight','700',0,''),(14315,4380,'114709','watch-mobile','font-size','18',0,''),(14316,4381,'114710','watch-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(14317,4382,'114711','watch-mobile','short_view','1',0,''),(14318,4382,'114711','watch-mobile','hide_parents','2',0,''),(14319,4383,'114712','watch-mobile','block_type','1',0,''),(14320,4383,'114712','watch-mobile','margin-bottom','20',0,''),(14321,4383,'114712','watch-mobile','padding-right','20',0,''),(14322,4384,'114713','watch-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(14323,4385,'114714','watch-mobile','padding-left','30',0,''),(14324,4385,'114714','watch-mobile','orders_data','telephone',0,''),(14325,4385,'114714','watch-mobile','hide_parents','2',0,''),(14326,4386,'114715','watch-mobile','block_type','1',0,''),(14327,4386,'114715','watch-mobile','padding-right','20',0,''),(14328,4386,'114715','watch-mobile','padding-bottom','20',0,''),(14329,4387,'114716','watch-mobile','orders_data','name',0,''),(14330,4387,'114716','watch-mobile','padding-left','30',0,''),(14331,4388,'114717','watch-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(14332,4389,'114718','watch-mobile','block_type','1',0,''),(14333,4389,'114718','watch-mobile','padding-right','20',0,''),(14334,4389,'114718','watch-mobile','padding-bottom','20',0,''),(14335,4390,'114719','watch-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(14336,4391,'114720','watch-mobile','orders_data','delivery_address',0,''),(14337,4391,'114720','watch-mobile','padding-left','30',0,''),(14338,4392,'114721','watch-mobile','block_type','1',0,''),(14339,4392,'114721','watch-mobile','padding-right','20',0,''),(14340,4393,'114722','watch-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(14341,4394,'114723','watch-mobile','orders_data','shipping_method',0,''),(14342,4394,'114723','watch-mobile','padding-left','30',0,''),(14343,4395,'114724','watch-mobile','block_type','1',0,''),(14344,4395,'114724','watch-mobile','padding-bottom','20',0,''),(14345,4396,'114725','watch-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(14346,4397,'114726','watch-mobile','orders_data','billing_address',0,''),(14347,4397,'114726','watch-mobile','padding-left','30',0,''),(14348,4398,'114727','watch-mobile','block_type','1',0,''),(14349,4399,'114728','watch-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(14350,4400,'114729','watch-mobile','orders_data','payment_method',0,''),(14351,4400,'114729','watch-mobile','padding-left','30',0,''),(14352,4401,'114730','watch-mobile','float','right',0,''),(14353,4403,'114732','watch-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(14354,4406,'114735','watch-mobile','float','right',0,''),(14355,4406,'114735','watch-mobile','clear','none',0,''),(14356,4406,'114735','watch-mobile','margin-left','20',0,''),(14357,4407,'114736','watch-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(14358,4409,'114738','watch-mobile','float','right',0,''),(14359,4409,'114738','watch-mobile','clear','none',0,''),(14360,4409,'114738','watch-mobile','like_button','2',0,''),(14361,4409,'114738','watch-mobile','link','Order pay',0,''),(14362,4410,'114739','watch-mobile','float','right',0,''),(14363,4410,'114739','watch-mobile','clear','none',0,''),(14364,4410,'114739','watch-mobile','margin-left','20',0,''),(14365,4411,'114740','watch-mobile','block_type','2',0,''),(14366,4411,'114740','watch-mobile','padding-top','20',0,''),(14367,4411,'114740','watch-mobile','margin-bottom','20',0,''),(14368,4412,'114741','watch-mobile','like_button','1',0,''),(14369,4412,'114741','watch-mobile','text','IMAGE_BUTTON_BACK',0,''),(14370,4412,'114741','watch-mobile','link','Order History',0,''),(14371,4413,'114742','watch-mobile','text-align','right',0,''),(14372,4414,'114743','watch-mobile','block_type','1',0,''),(14373,4415,'114744','watch-mobile','block_type','6',0,''),(14374,4415,'114744','watch-mobile','schema','6-3',0,''),(14375,4415,'114744','watch-mobile','schema','6-3',0,'299'),(14376,4416,'114745','watch-mobile','aria_name','account-menu',0,''),(14377,4419,'114748','watch-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(14378,4420,'114749','watch-mobile','margin-bottom','20',0,''),(14379,4421,'114750','watch-mobile','block_type','3',0,''),(14380,4421,'114750','watch-mobile','schema','3-4',0,'299'),(14381,4422,'114751','watch-mobile','block_type','1',0,''),(14382,4423,'114752','watch-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(14383,4424,'114753','watch-mobile','padding-left','30',0,''),(14384,4425,'114754','watch-mobile','block_type','1',0,''),(14385,4425,'114754','watch-mobile','padding-right','20',0,''),(14386,4425,'114754','watch-mobile','padding-bottom','20',0,''),(14387,4426,'114755','watch-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(14388,4427,'114756','watch-mobile','orders_data','name',0,''),(14389,4427,'114756','watch-mobile','padding-left','30',0,''),(14390,4428,'114757','watch-mobile','block_type','1',0,''),(14391,4428,'114757','watch-mobile','padding-right','20',0,''),(14392,4429,'114758','watch-mobile','orders_data','shipping_method',0,''),(14393,4429,'114758','watch-mobile','padding-left','30',0,''),(14394,4430,'114759','watch-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(14395,4431,'114760','watch-mobile','block_type','1',0,''),(14396,4431,'114760','watch-mobile','padding-right','20',0,''),(14397,4431,'114760','watch-mobile','padding-bottom','20',0,''),(14398,4432,'114761','watch-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(14399,4433,'114762','watch-mobile','orders_data','delivery_address',0,''),(14400,4433,'114762','watch-mobile','padding-left','30',0,''),(14401,4434,'114763','watch-mobile','block_type','1',0,''),(14402,4435,'114764','watch-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(14403,4436,'114765','watch-mobile','orders_data','payment_method',0,''),(14404,4436,'114765','watch-mobile','padding-left','30',0,''),(14405,4437,'114766','watch-mobile','block_type','1',0,''),(14406,4437,'114766','watch-mobile','padding-bottom','20',0,''),(14407,4438,'114767','watch-mobile','orders_data','billing_address',0,''),(14408,4438,'114767','watch-mobile','padding-left','30',0,''),(14409,4439,'114768','watch-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(14410,4441,'75759','watch-mobile','width','680',0,''),(14411,4441,'75759','watch-mobile','font-weight','400',0,''),(14412,4441,'75759','watch-mobile','font-size','12',0,''),(14413,4441,'75759','watch-mobile','padding-top','20',0,''),(14414,4441,'75759','watch-mobile','padding-bottom','20',0,''),(14415,4442,'75760','watch-mobile','font-weight','normal',0,''),(14416,4442,'75760','watch-mobile','padding-top','20',0,''),(14417,4442,'75760','watch-mobile','font-size','12',0,''),(14418,4443,'75761','watch-mobile','block_type','4',0,''),(14419,4443,'75761','watch-mobile','font-weight','400',0,''),(14420,4443,'75761','watch-mobile','border-top-width','1',0,''),(14421,4443,'75761','watch-mobile','border-top-color','$border-color-1',0,''),(14422,4443,'75761','watch-mobile','border-left-width','1',0,''),(14423,4443,'75761','watch-mobile','border-left-color','$border-color-1',0,''),(14424,4443,'75761','watch-mobile','border-right-width','1',0,''),(14425,4443,'75761','watch-mobile','border-right-color','$border-color-1',0,''),(14426,4443,'75761','watch-mobile','border-bottom-width','1',0,''),(14427,4443,'75761','watch-mobile','border-bottom-color','$border-color-1',0,''),(14428,4444,'75762','watch-mobile','block_type','2',0,''),(14429,4444,'75762','watch-mobile','font-weight','normal',0,''),(14430,4444,'75762','watch-mobile','border-right-width','1',0,''),(14431,4444,'75762','watch-mobile','border-right-color','$border-color-1',0,''),(14432,4445,'75763','watch-mobile','block_type','1',0,''),(14433,4445,'75763','watch-mobile','font-weight','normal',0,''),(14434,4445,'75763','watch-mobile','border-right-width','1',0,''),(14435,4445,'75763','watch-mobile','border-right-color','$border-color-1',0,''),(14436,4445,'75763','watch-mobile','background-color','$background-6',0,''),(14437,4445,'75763','watch-mobile','padding-top','10',0,''),(14438,4445,'75763','watch-mobile','padding-left','10',0,''),(14439,4445,'75763','watch-mobile','padding-right','10',0,''),(14440,4445,'75763','watch-mobile','padding-bottom','10',0,''),(14441,4446,'75764','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(14442,4446,'75764','watch-mobile','font-size','16',0,''),(14443,4446,'75764','watch-mobile','font-weight','bold',0,''),(14444,4446,'75764','watch-mobile','padding-bottom','10',0,''),(14445,4447,'75765','watch-mobile','font-size','16',0,''),(14446,4447,'75765','watch-mobile','font-weight','normal',0,''),(14447,4448,'75766','watch-mobile','block_type','1',0,''),(14448,4448,'75766','watch-mobile','font-weight','normal',0,''),(14449,4448,'75766','watch-mobile','padding-top','10',0,''),(14450,4448,'75766','watch-mobile','padding-left','10',0,''),(14451,4448,'75766','watch-mobile','padding-right','10',0,''),(14452,4448,'75766','watch-mobile','padding-bottom','10',0,''),(14453,4452,'75770','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(14454,4452,'75770','watch-mobile','font-size','14',0,''),(14455,4452,'75770','watch-mobile','font-weight','bold',0,''),(14456,4452,'75770','watch-mobile','padding-top','10',0,''),(14457,4453,'75771','watch-mobile','text','<p>CUSTOMER:</p>',1,''),(14458,4453,'75771','watch-mobile','font-size','14',0,''),(14459,4453,'75771','watch-mobile','font-weight','bold',0,''),(14460,4454,'75772','watch-mobile','text','<p>PHONE NUMBER:</p>',1,''),(14461,4454,'75772','watch-mobile','font-size','14',0,''),(14462,4454,'75772','watch-mobile','font-weight','bold',0,''),(14463,4454,'75772','watch-mobile','padding-top','10',0,''),(14464,4455,'75773','watch-mobile','block_type','2',0,''),(14465,4455,'75773','watch-mobile','font-weight','normal',0,''),(14466,4455,'75773','watch-mobile','border-right-width','1',0,''),(14467,4455,'75773','watch-mobile','border-right-color','$border-color-1',0,''),(14468,4455,'75773','watch-mobile','border-top-width','1',0,''),(14469,4455,'75773','watch-mobile','border-top-color','$border-color-1',0,''),(14470,4456,'75774','watch-mobile','block_type','1',0,''),(14471,4456,'75774','watch-mobile','font-weight','normal',0,''),(14472,4456,'75774','watch-mobile','padding-top','10',0,''),(14473,4456,'75774','watch-mobile','padding-left','10',0,''),(14474,4456,'75774','watch-mobile','padding-right','10',0,''),(14475,4456,'75774','watch-mobile','padding-bottom','10',0,''),(14476,4456,'75774','watch-mobile','border-right-width','1',0,''),(14477,4456,'75774','watch-mobile','border-right-color','$border-color-1',0,''),(14478,4458,'75776','watch-mobile','text','<p>Shipping via</p>',1,''),(14479,4458,'75776','watch-mobile','font-weight','bold',0,''),(14480,4459,'75777','watch-mobile','block_type','1',0,''),(14481,4459,'75777','watch-mobile','font-weight','normal',0,''),(14482,4459,'75777','watch-mobile','padding-top','10',0,''),(14483,4459,'75777','watch-mobile','padding-left','10',0,''),(14484,4459,'75777','watch-mobile','padding-right','10',0,''),(14485,4459,'75777','watch-mobile','padding-bottom','10',0,''),(14486,4460,'75778','watch-mobile','text','<p>Shipping service</p>',1,''),(14487,4460,'75778','watch-mobile','font-weight','bold',0,''),(14488,4462,'75780','watch-mobile','font-weight','normal',0,''),(14489,4462,'75780','watch-mobile','text-align','center',0,''),(14490,4462,'75780','watch-mobile','padding-top','40',0,''),(14491,4463,'75781','watch-mobile','block_type','1',0,''),(14492,4463,'75781','watch-mobile','font-weight','normal',0,''),(14493,4463,'75781','watch-mobile','padding-top','10',0,''),(14494,4463,'75781','watch-mobile','padding-bottom','10',0,''),(14495,4464,'75782','watch-mobile','text','<p>If undelivered please return to:</p>',1,''),(14496,4464,'75782','watch-mobile','font-weight','bold',0,''),(14497,4466,'75784','watch-mobile','block_type','2',0,''),(14498,4466,'75784','watch-mobile','font-weight','normal',0,''),(14499,4466,'75784','watch-mobile','padding-bottom','20',0,''),(14500,4467,'75785','watch-mobile','font-weight','400',0,''),(14501,4467,'75785','watch-mobile','text-align','center',0,''),(14502,4467,'75785','watch-mobile','padding-top','10',0,''),(14503,4467,'75785','watch-mobile','logo','themes/watch-mobile/img/watchlogo-3.png',1,''),(14504,4468,'75786','watch-mobile','block_type','1',0,''),(14505,4469,'75787','watch-mobile','font-weight','400',0,''),(14506,4469,'75787','watch-mobile','text-align','right',0,''),(14507,4469,'75787','watch-mobile','padding-bottom','10',0,''),(14508,4469,'75787','watch-mobile','address_spacer',',',0,''),(14509,4470,'75788','watch-mobile','block_type','11',0,''),(14510,4470,'75788','watch-mobile','font-weight','normal',0,''),(14511,4471,'75789','watch-mobile','text','<p>Phone:</p>',1,''),(14512,4471,'75789','watch-mobile','font-weight','normal',0,''),(14513,4471,'75789','watch-mobile','text-align','right',0,''),(14514,4472,'75790','watch-mobile','font-weight','normal',0,''),(14515,4472,'75790','watch-mobile','text-align','right',0,''),(14516,4473,'75791','watch-mobile','block_type','11',0,''),(14517,4473,'75791','watch-mobile','font-weight','400',0,''),(14518,4474,'75792','watch-mobile','text','<p>Web:</p>',1,''),(14519,4474,'75792','watch-mobile','font-weight','400',0,''),(14520,4474,'75792','watch-mobile','text-align','right',0,''),(14521,4475,'75793','watch-mobile','font-weight','normal',0,''),(14522,4475,'75793','watch-mobile','text-align','right',0,''),(14523,4476,'75794','watch-mobile','block_type','11',0,''),(14524,4476,'75794','watch-mobile','font-weight','normal',0,''),(14525,4477,'75795','watch-mobile','text','<p>Email:</p>',1,''),(14526,4477,'75795','watch-mobile','font-weight','normal',0,''),(14527,4477,'75795','watch-mobile','text-align','right',0,''),(14528,4478,'75796','watch-mobile','font-weight','normal',0,''),(14529,4478,'75796','watch-mobile','text-align','right',0,''),(14530,4479,'114770','watch-mobile','block_type','1',0,''),(14531,4480,'114771','watch-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(14532,4481,'114772','watch-mobile','block_type','8',0,''),(14533,4482,'114773','watch-mobile','margin-bottom','20',0,''),(14534,4483,'114774','watch-mobile','text','##TEXT_MAIN##',0,''),(14535,4483,'114774','watch-mobile','margin-bottom','20',0,''),(14536,4483,'114774','watch-mobile','text-align','center',0,''),(14537,4485,'75798','watch-mobile','block_type','2',0,''),(14538,4486,'75799','watch-mobile','block_type','1',0,''),(14539,4486,'75799','watch-mobile','style_class','product',0,''),(14540,4486,'75799','watch-mobile','padding-right','10',0,''),(14541,4486,'75799','watch-mobile','padding-bottom','20',0,''),(14542,4487,'75800','watch-mobile','block_type','2',0,''),(14543,4488,'75801','watch-mobile','product_element','image',0,''),(14544,4488,'75801','watch-mobile','padding-right','10',0,''),(14545,4489,'75802','watch-mobile','product_element','products_price_old',0,''),(14546,4489,'75802','watch-mobile','font-family','$font-1',0,''),(14547,4489,'75802','watch-mobile','font-size','14',0,''),(14548,4489,'75802','watch-mobile','text-decoration','line-through',0,''),(14549,4490,'75803','watch-mobile','product_element','products_price',0,''),(14550,4490,'75803','watch-mobile','font-family','$font-1',0,''),(14551,4490,'75803','watch-mobile','font-size','20',0,''),(14552,4490,'75803','watch-mobile','padding-top','20',0,''),(14553,4491,'75804','watch-mobile','block_type','1',0,''),(14554,4492,'75805','watch-mobile','product_element','products_name',0,''),(14555,4492,'75805','watch-mobile','font-family','$font-1',0,''),(14556,4492,'75805','watch-mobile','padding-bottom','10',0,''),(14557,4492,'75805','watch-mobile','font-size','16',0,''),(14558,4493,'75806','watch-mobile','block_type','1',0,''),(14559,4493,'75806','watch-mobile','style_class','product',0,''),(14560,4493,'75806','watch-mobile','padding-left','10',0,''),(14561,4493,'75806','watch-mobile','padding-bottom','20',0,''),(14562,4494,'75807','watch-mobile','block_type','1',0,''),(14563,4495,'75808','watch-mobile','product_element','products_name',0,''),(14564,4495,'75808','watch-mobile','font-family','$font-1',0,''),(14565,4495,'75808','watch-mobile','font-size','16',0,''),(14566,4495,'75808','watch-mobile','padding-bottom','10',0,''),(14567,4496,'75809','watch-mobile','block_type','2',0,''),(14568,4497,'75810','watch-mobile','product_element','image',0,''),(14569,4497,'75810','watch-mobile','padding-right','10',0,''),(14570,4498,'75811','watch-mobile','font-size','14',0,''),(14571,4498,'75811','watch-mobile','font-family','$font-1',0,''),(14572,4498,'75811','watch-mobile','text-decoration','line-through',0,''),(14573,4498,'75811','watch-mobile','product_element','products_price_old',0,''),(14574,4499,'75812','watch-mobile','product_element','products_price',0,''),(14575,4499,'75812','watch-mobile','font-family','$font-1',0,''),(14576,4499,'75812','watch-mobile','font-size','20',0,''),(14577,4499,'75812','watch-mobile','padding-top','20',0,''),(14578,4500,'75813','watch-mobile','font-size','30',0,''),(14579,4500,'75813','watch-mobile','font-family','$font-1',0,''),(14580,4500,'75813','watch-mobile','text-align','center',0,''),(14581,4500,'75813','watch-mobile','padding-bottom','50',0,''),(14582,4501,'75814','watch-mobile','padding-bottom','20',0,''),(14583,4501,'75814','watch-mobile','text-align','center',0,''),(14584,4502,'75815','watch-mobile','width','680',0,''),(14585,4503,'75816','watch-mobile','padding-top','200',0,''),(14586,4503,'75816','watch-mobile','padding-left','200',0,''),(14588,4504,'75817','watch-mobile','text','osCommerce 4',1,''),(14589,4504,'75817','watch-mobile','font-family','$font-1',0,''),(14590,4504,'75817','watch-mobile','font-size','40',0,''),(14591,4504,'75817','watch-mobile','padding-top','50',0,''),(14592,4504,'75817','watch-mobile','text-align','center',0,''),(14593,4505,'75818','watch-mobile','block_type','2',0,''),(14594,4505,'75818','watch-mobile','border-top-width','1',0,''),(14595,4505,'75818','watch-mobile','border-top-color','$border-color-1',0,''),(14596,4506,'75819','watch-mobile','text-align','right',0,''),(14597,4506,'75819','watch-mobile','padding-top','15',0,''),(14598,4506,'75819','watch-mobile','padding-bottom','15',0,''),(14599,4506,'75819','watch-mobile','font-size','14',0,''),(14600,4507,'75820','watch-mobile','font-family','$font-1',0,''),(14601,4507,'75820','watch-mobile','text-align','center',0,''),(14602,4507,'75820','watch-mobile','font-size','20',0,''),(14603,4507,'75820','watch-mobile','color','$color-font-6',0,''),(14604,4507,'75820','watch-mobile','border-bottom-width','1',0,''),(14605,4507,'75820','watch-mobile','border-bottom-color','$border-color-10',0,''),(14606,4507,'75820','watch-mobile','padding-top','10',0,''),(14607,4507,'75820','watch-mobile','padding-bottom','10',0,''),(14608,4508,'114775','watch-mobile','block_type','1',0,''),(14609,4509,'114776','watch-mobile','block_type','6',0,''),(14610,4509,'114776','watch-mobile','schema','6-3',0,''),(14611,4509,'114776','watch-mobile','schema','6-3',0,'299'),(14612,4510,'114777','watch-mobile','aria_name','account-menu',0,''),(14613,4511,'114778','watch-mobile','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(14614,4512,'114779','watch-mobile','max_items','10',0,''),(14615,4513,'114780','watch-mobile','block_type','1',0,''),(14616,4513,'114780','watch-mobile','padding-top','20',0,''),(14617,4513,'114780','watch-mobile','padding-left','20',0,''),(14618,4513,'114780','watch-mobile','padding-right','20',0,''),(14619,4513,'114780','watch-mobile','padding-bottom','20',0,''),(14620,4514,'114781','watch-mobile','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(14621,4516,'114783','watch-mobile','block_type','1',0,''),(14622,4517,'114784','watch-mobile','margin_left_measure','auto',0,''),(14623,4517,'114784','watch-mobile','margin_right_measure','auto',0,''),(14624,4517,'114784','watch-mobile','max-width','560',0,''),(14625,4518,'114785','watch-mobile','margin-bottom','30',0,''),(14626,4519,'114786','watch-mobile','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(14627,4520,'75821','watch-mobile','block_type','1',0,''),(14628,4521,'75822','watch-mobile','block_type','2',0,''),(14629,4521,'75822','watch-mobile','border-top-width','1',0,''),(14630,4521,'75822','watch-mobile','border-top-color','$border-color-1',0,''),(14631,4521,'75822','watch-mobile','padding-top','15',0,''),(14632,4521,'75822','watch-mobile','padding-bottom','15',0,''),(14633,4523,'75824','watch-mobile','font-size','30',0,''),(14634,4523,'75824','watch-mobile','font-weight','400',0,''),(14635,4523,'75824','watch-mobile','line-height','35',0,''),(14636,4523,'75824','watch-mobile','font-family','$font-1',0,''),(14637,4523,'75824','watch-mobile','line_height_measure','px',0,''),(14638,4524,'75825','watch-mobile','font-weight','400',0,''),(14639,4525,'75826','watch-mobile','font-weight','normal',0,''),(14640,4525,'75826','watch-mobile','padding-bottom','20',0,''),(14641,4526,'75827','watch-mobile','padding-right','0',0,''),(14642,4526,'75827','watch-mobile','align_position','horizontal',0,''),(14643,4528,'75829','watch-mobile','text-align','right',0,''),(14644,4528,'75829','watch-mobile','width','100',0,'290'),(14645,4528,'75829','watch-mobile','width_measure','%',0,'290'),(14646,4528,'75829','watch-mobile','float','none',0,'290'),(14647,4528,'75829','watch-mobile','margin-bottom','20',0,''),(14648,4529,'75830','watch-mobile','font-weight','400',0,''),(14649,4529,'75830','watch-mobile','box_align','4',0,''),(14650,4529,'75830','watch-mobile','align_position','horizontal',0,''),(14651,4529,'75830','watch-mobile','margin-bottom','30',0,''),(14652,4530,'75831','watch-mobile','font-weight','400',0,''),(14653,4531,'75832','watch-mobile','block_type','1',0,''),(14654,4531,'75832','watch-mobile','style_class','personal-buttons',0,''),(14655,4531,'75832','watch-mobile','margin-bottom','20',0,''),(14656,4531,'75832','watch-mobile','border-bottom-width','1',0,''),(14657,4531,'75832','watch-mobile','border-bottom-color','$border-color-1',0,''),(14658,4531,'75832','watch-mobile','padding-left','30',0,''),(14659,4536,'75837','watch-mobile','font-weight','normal',0,''),(14660,4536,'75837','watch-mobile','padding-bottom','20',0,''),(14661,4536,'75837','watch-mobile','show_qty_input','1',0,''),(14662,4536,'75837','watch-mobile','show_compare','1',0,''),(14663,4536,'75837','watch-mobile','col_in_row','1',0,''),(14664,4536,'75837','watch-mobile','view_as','carousel',0,''),(14665,4536,'75837','watch-mobile','listing_type','productListing',0,''),(14666,4537,'75838','watch-mobile','font-weight','400',0,''),(14667,4537,'75838','watch-mobile','padding-bottom','20',0,''),(14668,4537,'75838','watch-mobile','show_qty_input','1',0,''),(14669,4537,'75838','watch-mobile','show_compare','1',0,''),(14670,4537,'75838','watch-mobile','listing_type','type-1',0,''),(14671,4537,'75838','watch-mobile','view_as','carousel',0,''),(14672,4537,'75838','watch-mobile','show_name','0',0,''),(14673,4537,'75838','watch-mobile','show_image','0',0,''),(14674,4537,'75838','watch-mobile','show_stock','0',0,''),(14675,4537,'75838','watch-mobile','show_description','0',0,''),(14676,4537,'75838','watch-mobile','show_model','0',0,''),(14677,4537,'75838','watch-mobile','show_properties','0',0,''),(14678,4537,'75838','watch-mobile','show_rating','0',0,''),(14679,4537,'75838','watch-mobile','show_rating_counts','0',0,''),(14680,4537,'75838','watch-mobile','show_price','0',0,''),(14681,4537,'75838','watch-mobile','show_buy_button','0',0,''),(14682,4537,'75838','watch-mobile','show_view_button','0',0,''),(14683,4537,'75838','watch-mobile','show_wishlist_button','0',0,''),(14684,4537,'75838','watch-mobile','display','none',0,'291'),(14685,4537,'75838','watch-mobile','product_names_teg','h2',0,''),(14686,4538,'75839','watch-mobile','font-weight','normal',0,''),(14687,4538,'75839','watch-mobile','padding-bottom','20',0,''),(14688,4539,'75840','watch-mobile','tab_1','Description',1,''),(14689,4539,'75840','watch-mobile','tab_2','Reviews',1,''),(14690,4539,'75840','watch-mobile','font-weight','400',0,''),(14691,4539,'75840','watch-mobile','margin-top','20',0,''),(14692,4542,'75843','watch-mobile','padding-bottom','10',0,''),(14693,4542,'75843','watch-mobile','padding-top','5',0,''),(14694,4543,'75844','watch-mobile','font-weight','normal',0,''),(14695,4543,'75844','watch-mobile','padding-top','20',0,''),(14696,4543,'75844','watch-mobile','padding-bottom','20',0,''),(14697,4543,'75844','watch-mobile','border-top-width','1',0,''),(14698,4543,'75844','watch-mobile','border-top-color','$border-color-10',0,''),(14699,4545,'75846','watch-mobile','font-weight','400',0,''),(14700,4545,'75846','watch-mobile','padding-bottom','20',0,''),(14701,4545,'75846','watch-mobile','show_qty_input','1',0,''),(14702,4545,'75846','watch-mobile','show_compare','1',0,''),(14703,4545,'75846','watch-mobile','show_name','0',0,''),(14704,4545,'75846','watch-mobile','show_image','0',0,''),(14705,4545,'75846','watch-mobile','show_stock','0',0,''),(14706,4545,'75846','watch-mobile','show_description','0',0,''),(14707,4545,'75846','watch-mobile','show_model','0',0,''),(14708,4545,'75846','watch-mobile','show_properties','0',0,''),(14709,4545,'75846','watch-mobile','show_rating','0',0,''),(14710,4545,'75846','watch-mobile','show_rating_counts','0',0,''),(14711,4545,'75846','watch-mobile','show_price','0',0,''),(14712,4545,'75846','watch-mobile','show_buy_button','0',0,''),(14713,4545,'75846','watch-mobile','show_view_button','0',0,''),(14714,4545,'75846','watch-mobile','show_wishlist_button','0',0,''),(14715,4545,'75846','watch-mobile','listing_type','productListing',0,''),(14716,4545,'75846','watch-mobile','col_in_row','1',0,''),(14717,4545,'75846','watch-mobile','view_as','carousel',0,''),(14718,4556,'75888','watch-mobile','block_type','1',0,''),(14719,4556,'75888','watch-mobile','style_class','item-holder',0,''),(14720,4556,'75888','watch-mobile','padding-top','25',0,''),(14721,4556,'75888','watch-mobile','padding-left','25',0,''),(14722,4556,'75888','watch-mobile','padding-right','25',0,''),(14723,4556,'75888','watch-mobile','padding-bottom','25',0,''),(14724,4556,'75888','watch-mobile','text-align','left',0,''),(14725,4559,'75892','watch-mobile','description_characters','90',0,''),(14726,4560,'75893','watch-mobile','text-align','right',0,''),(14727,4560,'75893','watch-mobile','margin-bottom','10',0,''),(14728,4561,'75894','watch-mobile','text-align','right',0,''),(14729,4561,'75894','watch-mobile','clear','none',0,''),(14730,4561,'75894','watch-mobile','float','left',0,''),(14731,4563,'75896','watch-mobile','block_type','2',0,''),(14732,4564,'75897','watch-mobile','margin-bottom','7',0,''),(14733,4565,'75898','watch-mobile','margin-bottom','10',0,''),(14734,4565,'75898','watch-mobile','text-align','right',0,''),(14735,4565,'75898','watch-mobile','float','right',0,''),(14736,4566,'75899','watch-mobile','clear','both',0,''),(14737,4567,'75900','watch-mobile','float','left',0,''),(14738,4567,'75900','watch-mobile','margin-right','20',0,''),(14739,4567,'75900','watch-mobile','margin-bottom','5',0,''),(14740,4568,'75857','watch-mobile','block_type','1',0,''),(14741,4569,'75858','watch-mobile','font-weight','400',0,''),(14742,4569,'75858','watch-mobile','padding-right','40',0,''),(14743,4569,'75858','watch-mobile','padding-right','0',0,'315'),(14744,4569,'75858','watch-mobile','padding-right','0',0,'317'),(14745,4569,'75858','watch-mobile','margin-bottom','20',0,''),(14746,4570,'75859','watch-mobile','text-align','center',0,''),(14747,4570,'75859','watch-mobile','margin-bottom','20',0,''),(14748,4572,'75861','watch-mobile','margin-bottom','20',0,''),(14749,4572,'75861','watch-mobile','text-align','center',0,''),(14750,4573,'75862','watch-mobile','block_type','2',0,''),(14751,4573,'75862','watch-mobile','margin-bottom','20',0,''),(14752,4574,'75863','watch-mobile','sort_pos_3','1',0,''),(14753,4574,'75863','watch-mobile','sort_pos_4','2',0,''),(14754,4574,'75863','watch-mobile','sort_pos_10','5',0,''),(14755,4574,'75863','watch-mobile','sort_pos_9','6',0,''),(14756,4574,'75863','watch-mobile','sort_pos_11','7',0,''),(14757,4574,'75863','watch-mobile','sort_pos_12','8',0,''),(14758,4574,'75863','watch-mobile','sort_pos_14','9',0,''),(14759,4574,'75863','watch-mobile','sort_pos_13','10',0,''),(14760,4574,'75863','watch-mobile','sort_pos_8','11',0,''),(14761,4574,'75863','watch-mobile','sort_pos_7','12',0,''),(14762,4574,'75863','watch-mobile','sort_pos_2','13',0,''),(14763,4574,'75863','watch-mobile','sort_pos_1','14',0,''),(14764,4574,'75863','watch-mobile','sort_pos_6','15',0,''),(14765,4574,'75863','watch-mobile','sort_pos_5','16',0,''),(14766,4574,'75863','watch-mobile','sort_pos_0','17',0,''),(14767,4574,'75863','watch-mobile','sort_hide_10','1',0,''),(14768,4574,'75863','watch-mobile','sort_hide_9','1',0,''),(14769,4574,'75863','watch-mobile','sort_pos_15','4',0,''),(14770,4574,'75863','watch-mobile','sort_pos_16','3',0,''),(14771,4574,'75863','watch-mobile','sort_hide_3','0',0,''),(14772,4574,'75863','watch-mobile','sort_hide_4','0',0,''),(14773,4574,'75863','watch-mobile','sort_hide_16','1',0,''),(14774,4574,'75863','watch-mobile','sort_hide_15','1',0,''),(14775,4574,'75863','watch-mobile','sort_hide_11','0',0,''),(14776,4574,'75863','watch-mobile','sort_hide_12','0',0,''),(14777,4574,'75863','watch-mobile','sort_hide_14','0',0,''),(14778,4574,'75863','watch-mobile','sort_hide_13','0',0,''),(14779,4574,'75863','watch-mobile','sort_hide_8','0',0,''),(14780,4574,'75863','watch-mobile','sort_hide_7','0',0,''),(14781,4574,'75863','watch-mobile','sort_hide_2','0',0,''),(14782,4574,'75863','watch-mobile','sort_hide_1','0',0,''),(14783,4574,'75863','watch-mobile','sort_hide_6','0',0,''),(14784,4574,'75863','watch-mobile','sort_hide_5','0',0,''),(14785,4574,'75863','watch-mobile','sort_hide_0','0',0,''),(14786,4575,'75864','watch-mobile','text-align','right',0,''),(14787,4575,'75864','watch-mobile','padding-top','10',0,''),(14788,4576,'75865','watch-mobile','col_in_row','2',0,''),(14789,4576,'75865','watch-mobile','products_align','left',0,''),(14790,4576,'75865','watch-mobile','font-weight','400',0,''),(14791,4576,'75865','watch-mobile','show_qty_input','1',0,''),(14792,4576,'75865','watch-mobile','listing_type','productListing',0,''),(14793,4576,'75865','watch-mobile','listing_type_rows','type-1_2',0,''),(14794,4576,'75865','watch-mobile','show_buy_button_b2b','on',0,''),(14795,4576,'75865','watch-mobile','show_wishlist_button_b2b','1',0,''),(14796,4576,'75865','watch-mobile','show_compare_b2b','1',0,''),(14797,4576,'75865','watch-mobile','listing_type_b2b','type-1_3',0,''),(14798,4576,'75865','watch-mobile','show_name','0',0,''),(14799,4576,'75865','watch-mobile','show_image','0',0,''),(14800,4576,'75865','watch-mobile','show_stock','0',0,''),(14801,4576,'75865','watch-mobile','show_description','1',0,''),(14802,4576,'75865','watch-mobile','show_model','1',0,''),(14803,4576,'75865','watch-mobile','show_properties','1',0,''),(14804,4576,'75865','watch-mobile','show_rating_counts','1',0,''),(14805,4576,'75865','watch-mobile','show_price','0',0,''),(14806,4576,'75865','watch-mobile','show_buy_button','1',0,''),(14807,4576,'75865','watch-mobile','show_view_button','1',0,''),(14808,4576,'75865','watch-mobile','show_wishlist_button','1',0,''),(14809,4576,'75865','watch-mobile','show_compare','1',0,''),(14810,4576,'75865','watch-mobile','show_name_rows','0',0,''),(14811,4576,'75865','watch-mobile','show_image_rows','0',0,''),(14812,4576,'75865','watch-mobile','show_stock_rows','0',0,''),(14813,4576,'75865','watch-mobile','show_description_rows','0',0,''),(14814,4576,'75865','watch-mobile','show_model_rows','0',0,''),(14815,4576,'75865','watch-mobile','show_properties_rows','0',0,''),(14816,4576,'75865','watch-mobile','show_rating_rows','0',0,''),(14817,4576,'75865','watch-mobile','show_rating_counts_rows','0',0,''),(14818,4576,'75865','watch-mobile','show_price_rows','0',0,''),(14819,4576,'75865','watch-mobile','show_buy_button_rows','0',0,''),(14820,4576,'75865','watch-mobile','show_qty_input_rows','0',0,''),(14821,4576,'75865','watch-mobile','show_view_button_rows','0',0,''),(14822,4576,'75865','watch-mobile','show_wishlist_button_rows','0',0,''),(14823,4576,'75865','watch-mobile','show_compare_rows','0',0,''),(14824,4576,'75865','watch-mobile','show_name_b2b','0',0,''),(14825,4576,'75865','watch-mobile','show_image_b2b','0',0,''),(14826,4576,'75865','watch-mobile','show_stock_b2b','0',0,''),(14827,4576,'75865','watch-mobile','show_description_b2b','0',0,''),(14828,4576,'75865','watch-mobile','show_model_b2b','0',0,''),(14829,4576,'75865','watch-mobile','show_properties_b2b','0',0,''),(14830,4576,'75865','watch-mobile','show_rating_b2b','0',0,''),(14831,4576,'75865','watch-mobile','show_rating_counts_b2b','0',0,''),(14832,4576,'75865','watch-mobile','show_price_b2b','0',0,''),(14833,4576,'75865','watch-mobile','show_qty_input_b2b','0',0,''),(14834,4576,'75865','watch-mobile','show_view_button_b2b','0',0,''),(14835,4576,'75865','watch-mobile','show_attributes_b2b','0',0,''),(14836,4576,'75865','watch-mobile','items_on_page','10',0,''),(14837,4576,'75865','watch-mobile','product_names_teg','h2',0,''),(14838,4578,'114788','watch-mobile','block_type','1',0,''),(14839,4580,'114790','watch-mobile','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(14840,4581,'114791','watch-mobile','width','680',0,''),(14841,4581,'114791','watch-mobile','font-weight','normal',0,''),(14842,4581,'114791','watch-mobile','font-size','12',0,''),(14843,4581,'114791','watch-mobile','padding-top','20',0,''),(14844,4581,'114791','watch-mobile','padding-bottom','20',0,''),(14845,4581,'114791','watch-mobile','color','$color-font-7',0,''),(14846,4582,'114792','watch-mobile','block_type','5',0,''),(14847,4582,'114792','watch-mobile','font-weight','normal',0,''),(14848,4582,'114792','watch-mobile','border-bottom-width','1',0,''),(14849,4582,'114792','watch-mobile','border-bottom-color','$border-color-1',0,''),(14850,4582,'114792','watch-mobile','border-top-width','1',0,''),(14851,4582,'114792','watch-mobile','border-top-color','$border-color-1',0,''),(14852,4582,'114792','watch-mobile','border-left-color','$border-color-1',0,''),(14853,4582,'114792','watch-mobile','border-left-width','1',0,''),(14854,4583,'114793','watch-mobile','block_type','1',0,''),(14855,4583,'114793','watch-mobile','font-weight','normal',0,''),(14856,4583,'114793','watch-mobile','padding-top','10',0,''),(14857,4583,'114793','watch-mobile','padding-left','10',0,''),(14858,4583,'114793','watch-mobile','padding-right','10',0,''),(14859,4584,'114794','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(14860,4584,'114794','watch-mobile','font-size','14',0,''),(14861,4584,'114794','watch-mobile','font-weight','bold',0,''),(14862,4584,'114794','watch-mobile','padding-bottom','10',0,''),(14863,4585,'114795','watch-mobile','font-weight','400',0,''),(14864,4585,'114795','watch-mobile','line-height','120',0,''),(14865,4585,'114795','watch-mobile','line_height_measure','%',0,''),(14866,4585,'114795','watch-mobile','font-size','12',0,''),(14867,4586,'114796','watch-mobile','block_type','4',0,''),(14868,4586,'114796','watch-mobile','font-weight','normal',0,''),(14869,4586,'114796','watch-mobile','border-top-width','1',0,''),(14870,4586,'114796','watch-mobile','border-top-color','$border-color-1',0,''),(14871,4586,'114796','watch-mobile','border-left-width','1',0,''),(14872,4586,'114796','watch-mobile','border-left-color','$border-color-1',0,''),(14873,4586,'114796','watch-mobile','border-right-width','1',0,''),(14874,4586,'114796','watch-mobile','border-right-color','$border-color-1',0,''),(14875,4586,'114796','watch-mobile','border-bottom-width','1',0,''),(14876,4586,'114796','watch-mobile','border-bottom-color','$border-color-1',0,''),(14877,4587,'114797','watch-mobile','block_type','2',0,''),(14878,4587,'114797','watch-mobile','font-weight','normal',0,''),(14879,4587,'114797','watch-mobile','border-right-width','1',0,''),(14880,4587,'114797','watch-mobile','border-right-color','$border-color-1',0,''),(14881,4588,'114798','watch-mobile','block_type','1',0,''),(14882,4588,'114798','watch-mobile','font-weight','400',0,''),(14883,4588,'114798','watch-mobile','background-color','$background-6',0,''),(14884,4588,'114798','watch-mobile','padding-top','10',0,''),(14885,4588,'114798','watch-mobile','padding-left','10',0,''),(14886,4588,'114798','watch-mobile','padding-right','10',0,''),(14887,4588,'114798','watch-mobile','padding-bottom','30',0,''),(14888,4589,'114799','watch-mobile','text','<p>ADDRESS:</p>\n',1,''),(14889,4589,'114799','watch-mobile','font-size','14',0,''),(14890,4589,'114799','watch-mobile','font-weight','bold',0,''),(14891,4590,'114800','watch-mobile','font-size','12',0,''),(14892,4591,'114801','watch-mobile','block_type','1',0,''),(14893,4591,'114801','watch-mobile','font-weight','normal',0,''),(14894,4591,'114801','watch-mobile','padding-top','10',0,''),(14895,4591,'114801','watch-mobile','padding-left','10',0,''),(14896,4591,'114801','watch-mobile','padding-right','10',0,''),(14897,4591,'114801','watch-mobile','padding-bottom','10',0,''),(14898,4592,'114802','watch-mobile','text','<p>CUSTOMER:</p>',1,''),(14899,4592,'114802','watch-mobile','font-size','13',0,''),(14900,4592,'114802','watch-mobile','font-weight','bold',0,''),(14901,4593,'114803','watch-mobile','text','<p>PHONE NUMBER:</p>',1,''),(14902,4593,'114803','watch-mobile','font-size','14',0,''),(14903,4593,'114803','watch-mobile','font-weight','bold',0,''),(14904,4593,'114803','watch-mobile','padding-top','10',0,''),(14905,4594,'114804','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(14906,4594,'114804','watch-mobile','font-weight','bold',0,''),(14907,4594,'114804','watch-mobile','font-size','14',0,''),(14908,4594,'114804','watch-mobile','padding-top','10',0,''),(14909,4595,'114805','watch-mobile','font-weight','normal',0,''),(14910,4596,'114806','watch-mobile','font-weight','normal',0,''),(14911,4598,'114808','watch-mobile','text','<p>Order date:</p>\n',1,''),(14912,4598,'114808','watch-mobile','font-weight','bold',0,''),(14913,4598,'114808','watch-mobile','text-align','center',0,''),(14914,4598,'114808','watch-mobile','font-size','12',0,''),(14915,4599,'114809','watch-mobile','font-weight','normal',0,''),(14916,4599,'114809','watch-mobile','text-align','center',0,''),(14917,4599,'114809','watch-mobile','padding-bottom','10',0,''),(14918,4600,'114810','watch-mobile','font-size','14',0,''),(14919,4600,'114810','watch-mobile','font-weight','bold',0,''),(14920,4600,'114810','watch-mobile','text-align','center',0,''),(14921,4600,'114810','watch-mobile','padding-bottom','10',0,''),(14922,4600,'114810','watch-mobile','padding-top','10',0,''),(14923,4601,'114811','watch-mobile','block_type','2',0,''),(14924,4601,'114811','watch-mobile','font-weight','normal',0,''),(14925,4601,'114811','watch-mobile','padding-bottom','20',0,''),(14926,4602,'114812','watch-mobile','font-weight','400',0,''),(14927,4602,'114812','watch-mobile','padding-top','20',0,''),(14929,4603,'114813','watch-mobile','block_type','1',0,''),(14930,4604,'114814','watch-mobile','font-weight','normal',0,''),(14931,4604,'114814','watch-mobile','text-align','right',0,''),(14932,4604,'114814','watch-mobile','padding-bottom','10',0,''),(14933,4604,'114814','watch-mobile','address_spacer',',',0,''),(14934,4604,'114814','watch-mobile','font-size','12',0,''),(14935,4605,'114815','watch-mobile','block_type','11',0,''),(14936,4605,'114815','watch-mobile','font-weight','normal',0,''),(14937,4606,'114816','watch-mobile','text','<p>Email:</p>',1,''),(14938,4606,'114816','watch-mobile','font-weight','normal',0,''),(14939,4606,'114816','watch-mobile','text-align','right',0,''),(14940,4607,'114817','watch-mobile','font-weight','normal',0,''),(14941,4607,'114817','watch-mobile','text-align','right',0,''),(14942,4608,'114818','watch-mobile','block_type','11',0,''),(14943,4608,'114818','watch-mobile','font-weight','normal',0,''),(14944,4609,'114819','watch-mobile','text','<p>Web:</p>',1,''),(14945,4609,'114819','watch-mobile','font-weight','normal',0,''),(14946,4609,'114819','watch-mobile','text-align','right',0,''),(14947,4610,'114820','watch-mobile','font-weight','normal',0,''),(14948,4610,'114820','watch-mobile','text-align','right',0,''),(14949,4611,'114821','watch-mobile','block_type','11',0,''),(14950,4611,'114821','watch-mobile','font-weight','normal',0,''),(14951,4612,'114822','watch-mobile','text','<p>Phone:</p>',1,''),(14952,4612,'114822','watch-mobile','font-weight','normal',0,''),(14953,4612,'114822','watch-mobile','text-align','right',0,''),(14954,4613,'114823','watch-mobile','font-weight','normal',0,''),(14955,4613,'114823','watch-mobile','text-align','right',0,''),(14956,4614,'114824','watch-mobile','block_type','3',0,''),(14957,4614,'114824','watch-mobile','font-weight','normal',0,''),(14958,4614,'114824','watch-mobile','padding-top','20',0,''),(14959,4615,'114825','watch-mobile','font-size','12',0,''),(14960,4616,'114826','watch-mobile','text','<p>If undelivered please return to:</p>',1,''),(14961,4616,'114826','watch-mobile','font-size','12',0,''),(14962,4616,'114826','watch-mobile','font-weight','bold',0,''),(14963,4617,'114827','watch-mobile','text','<p>Thank you for your order</p>',1,''),(14964,4617,'114827','watch-mobile','color','$color-font-10',0,''),(14965,4617,'114827','watch-mobile','font-size','13',0,''),(14966,4617,'114827','watch-mobile','font-weight','bold',0,''),(14967,4617,'114827','watch-mobile','padding-top','5',0,''),(14968,4617,'114827','watch-mobile','text-align','center',0,''),(14969,4618,'114828','watch-mobile','font-weight','400',0,''),(14970,4618,'114828','watch-mobile','text-align','center',0,''),(14971,4618,'114828','watch-mobile','padding-top','0',0,''),(14973,4618,'114828','watch-mobile','padding-left','20',0,''),(14974,4618,'114828','watch-mobile','padding-right','20',0,''),(14975,4619,'114829','watch-mobile','block_type','6',0,''),(14976,4619,'114829','watch-mobile','font-weight','normal',0,''),(14977,4619,'114829','watch-mobile','font-size','16',0,''),(14978,4620,'114830','watch-mobile','text','<p>Phone:</p>',1,''),(14979,4620,'114830','watch-mobile','font-weight','normal',0,''),(14980,4620,'114830','watch-mobile','text-align','right',0,''),(14981,4620,'114830','watch-mobile','font-size','12',0,''),(14982,4621,'114831','watch-mobile','font-weight','normal',0,''),(14983,4621,'114831','watch-mobile','text-align','right',0,''),(14984,4621,'114831','watch-mobile','font-size','12',0,''),(14985,4622,'114832','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(14986,4622,'114832','watch-mobile','font-size','12',0,''),(14987,4622,'114832','watch-mobile','font-weight','bold',0,''),(14988,4622,'114832','watch-mobile','text-align','right',0,''),(14989,4623,'114833','watch-mobile','block_type','6',0,''),(14990,4623,'114833','watch-mobile','font-weight','normal',0,''),(14991,4623,'114833','watch-mobile','font-size','16',0,''),(14992,4624,'114834','watch-mobile','text','<p>Email:</p>',1,''),(14993,4624,'114834','watch-mobile','font-weight','normal',0,''),(14994,4624,'114834','watch-mobile','text-align','right',0,''),(14995,4624,'114834','watch-mobile','font-size','12',0,''),(14996,4625,'114835','watch-mobile','font-weight','normal',0,''),(14997,4625,'114835','watch-mobile','text-align','right',0,''),(14998,4625,'114835','watch-mobile','font-size','12',0,''),(14999,4626,'114836','watch-mobile','font-weight','400',0,''),(15000,4626,'114836','watch-mobile','padding-top','20',0,''),(15001,4626,'114836','watch-mobile','padding-bottom','0',0,''),(15002,4626,'114836','watch-mobile','font-size','12',0,''),(15003,4627,'114837','watch-mobile','block_type','1',0,''),(15004,4628,'114838','watch-mobile','block_type','6',0,''),(15005,4628,'114838','watch-mobile','schema','6-3',0,'299'),(15006,4629,'114839','watch-mobile','aria_name','account-menu',0,''),(15007,4630,'114840','watch-mobile','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(15008,4631,'114841','watch-mobile','link','Quotation Info',0,''),(15009,4631,'114841','watch-mobile','margin-bottom','20',0,''),(15010,4632,'114842','watch-mobile','block_type','1',0,''),(15011,4633,'114843','watch-mobile','block_type','6',0,''),(15012,4633,'114843','watch-mobile','schema','6-3',0,''),(15013,4633,'114843','watch-mobile','schema','6-3',0,'299'),(15014,4634,'114844','watch-mobile','aria_name','account-menu',0,''),(15015,4637,'114847','watch-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(15016,4638,'114848','watch-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(15017,4640,'114850','watch-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(15018,4641,'114851','watch-mobile','block_type','2',0,''),(15019,4641,'114851','watch-mobile','padding-top','20',0,''),(15020,4641,'114851','watch-mobile','margin-bottom','20',0,''),(15021,4642,'114852','watch-mobile','like_button','1',0,''),(15022,4642,'114852','watch-mobile','text','IMAGE_BUTTON_BACK',0,''),(15023,4642,'114852','watch-mobile','link','Quotations',0,''),(15024,4643,'114853','watch-mobile','block_type','3',0,''),(15025,4643,'114853','watch-mobile','schema','3-4',0,'299'),(15026,4644,'114854','watch-mobile','block_type','1',0,''),(15027,4644,'114854','watch-mobile','padding-right','20',0,''),(15028,4644,'114854','watch-mobile','padding-bottom','20',0,''),(15029,4645,'114855','watch-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(15030,4646,'114856','watch-mobile','orders_data','telephone',0,''),(15031,4647,'114857','watch-mobile','block_type','1',0,''),(15032,4647,'114857','watch-mobile','padding-right','20',0,''),(15033,4647,'114857','watch-mobile','padding-bottom','20',0,''),(15034,4648,'114858','watch-mobile','orders_data','name',0,''),(15035,4649,'114859','watch-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(15036,4650,'114860','watch-mobile','block_type','1',0,''),(15037,4650,'114860','watch-mobile','padding-right','20',0,''),(15038,4651,'114861','watch-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(15039,4652,'114862','watch-mobile','orders_data','shipping_method',0,''),(15040,4653,'114863','watch-mobile','block_type','1',0,''),(15041,4653,'114863','watch-mobile','padding-right','20',0,''),(15042,4653,'114863','watch-mobile','padding-bottom','20',0,''),(15043,4654,'114864','watch-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(15044,4655,'114865','watch-mobile','orders_data','delivery_address',0,''),(15045,4656,'114866','watch-mobile','block_type','1',0,''),(15046,4656,'114866','watch-mobile','padding-bottom','20',0,''),(15047,4657,'114867','watch-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(15048,4658,'114868','watch-mobile','orders_data','billing_address',0,''),(15049,4659,'114869','watch-mobile','block_type','1',0,''),(15050,4660,'114870','watch-mobile','orders_data','payment_method',0,''),(15051,4661,'114871','watch-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(15052,4664,'75868','watch-mobile','text','<h1>Quotations</h1>',1,''),(15053,4665,'114872','watch-mobile','block_type','1',0,''),(15054,4666,'114873','watch-mobile','block_type','6',0,''),(15055,4666,'114873','watch-mobile','schema','6-3',0,''),(15056,4666,'114873','watch-mobile','schema','6-3',0,'299'),(15057,4667,'114874','watch-mobile','aria_name','account-menu',0,''),(15058,4668,'114875','watch-mobile','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(15059,4669,'114876','watch-mobile','margin-bottom','20',0,''),(15060,4670,'114877','watch-mobile','block_type','1',0,''),(15061,4671,'114878','watch-mobile','pagination','bottom',0,''),(15062,4673,'114880','watch-mobile','width','800',0,''),(15063,4674,'114881','watch-mobile','block_type','1',0,''),(15064,4674,'114881','watch-mobile','border-top-width','1',0,''),(15065,4674,'114881','watch-mobile','border-left-width','1',0,''),(15066,4674,'114881','watch-mobile','border-right-width','1',0,''),(15067,4674,'114881','watch-mobile','border-bottom-width','1',0,''),(15068,4674,'114881','watch-mobile','border-top-color','$border-color-6',0,''),(15069,4674,'114881','watch-mobile','border-left-color','$border-color-6',0,''),(15070,4674,'114881','watch-mobile','border-right-color','$border-color-6',0,''),(15071,4674,'114881','watch-mobile','border-bottom-color','$border-color-6',0,''),(15072,4675,'114882','watch-mobile','block_type','11',0,''),(15073,4676,'114883','watch-mobile','block_type','1',0,''),(15074,4676,'114883','watch-mobile','padding-top','10',0,''),(15075,4676,'114883','watch-mobile','padding-right','10',0,''),(15076,4676,'114883','watch-mobile','padding-bottom','10',0,''),(15077,4676,'114883','watch-mobile','border-right-width','1',0,''),(15078,4676,'114883','watch-mobile','border-right-color','$border-color-6',0,''),(15079,4677,'114884','watch-mobile','block_type','1',0,''),(15080,4677,'114884','watch-mobile','padding-left','10',0,''),(15081,4677,'114884','watch-mobile','padding-right','10',0,''),(15082,4677,'114884','watch-mobile','padding-bottom','10',0,''),(15083,4678,'114885','watch-mobile','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(15084,4678,'114885','watch-mobile','font-size','11',0,''),(15085,4678,'114885','watch-mobile','font-style','italic',0,''),(15086,4679,'114886','watch-mobile','block_type','9',0,''),(15087,4680,'114887','watch-mobile','text','2.',0,''),(15088,4680,'114887','watch-mobile','font-size','12',0,''),(15089,4680,'114887','watch-mobile','text-align','right',0,''),(15090,4680,'114887','watch-mobile','padding-right','5',0,''),(15091,4681,'114888','watch-mobile','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(15092,4681,'114888','watch-mobile','font-size','12',0,''),(15093,4681,'114888','watch-mobile','padding-bottom','10',0,''),(15094,4682,'114889','watch-mobile','block_type','1',0,''),(15095,4683,'114890','watch-mobile','text','Shipping Instructions:',0,''),(15096,4683,'114890','watch-mobile','font-weight','bold',0,''),(15097,4683,'114890','watch-mobile','font-size','14',0,''),(15098,4683,'114890','watch-mobile','padding-bottom','5',0,''),(15099,4683,'114890','watch-mobile','padding-left','10',0,''),(15100,4684,'114891','watch-mobile','block_type','9',0,''),(15101,4685,'114892','watch-mobile','text','1.',0,''),(15102,4685,'114892','watch-mobile','font-size','12',0,''),(15103,4685,'114892','watch-mobile','text-align','right',0,''),(15104,4685,'114892','watch-mobile','padding-right','5',0,''),(15105,4686,'114893','watch-mobile','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(15106,4686,'114893','watch-mobile','font-size','12',0,''),(15107,4686,'114893','watch-mobile','padding-bottom','10',0,''),(15108,4687,'114894','watch-mobile','block_type','9',0,''),(15109,4688,'114895','watch-mobile','text','3.',0,''),(15110,4688,'114895','watch-mobile','font-size','12',0,''),(15111,4688,'114895','watch-mobile','text-align','right',0,''),(15112,4688,'114895','watch-mobile','padding-right','5',0,''),(15113,4689,'114896','watch-mobile','text','Ship only the items that are authorized.',0,''),(15114,4689,'114896','watch-mobile','font-size','12',0,''),(15115,4689,'114896','watch-mobile','padding-bottom','10',0,''),(15116,4690,'114897','watch-mobile','block_type','9',0,''),(15117,4691,'114898','watch-mobile','text','4.',0,''),(15118,4691,'114898','watch-mobile','font-size','12',0,''),(15119,4691,'114898','watch-mobile','text-align','right',0,''),(15120,4691,'114898','watch-mobile','padding-right','5',0,''),(15121,4692,'114899','watch-mobile','text','Ship returned items to:',0,''),(15122,4692,'114899','watch-mobile','font-size','12',0,''),(15123,4692,'114899','watch-mobile','padding-bottom','5',0,''),(15124,4693,'114900','watch-mobile','font-size','11',0,''),(15125,4693,'114900','watch-mobile','font-style','italic',0,''),(15126,4693,'114900','watch-mobile','padding-bottom','5',0,''),(15127,4694,'114901','watch-mobile','block_type','3',0,''),(15128,4694,'114901','watch-mobile','padding-right','10',0,''),(15129,4695,'114902','watch-mobile','text','Customer Signature:',0,''),(15130,4695,'114902','watch-mobile','font-weight','bold',0,''),(15131,4695,'114902','watch-mobile','font-size','11',0,''),(15132,4695,'114902','watch-mobile','padding-top','5',0,''),(15133,4695,'114902','watch-mobile','padding-left','10',0,''),(15134,4696,'114903','watch-mobile','text','&nbsp;',0,''),(15135,4696,'114903','watch-mobile','border-bottom-width','1',0,''),(15136,4696,'114903','watch-mobile','border-bottom-color','$border-color-6',0,''),(15137,4697,'114904','watch-mobile','block_type','5',0,''),(15138,4698,'114905','watch-mobile','text','Date:',0,''),(15139,4698,'114905','watch-mobile','padding-top','5',0,''),(15140,4698,'114905','watch-mobile','font-size','11',0,''),(15141,4698,'114905','watch-mobile','font-weight','bold',0,''),(15142,4698,'114905','watch-mobile','padding-left','5',0,''),(15143,4699,'114906','watch-mobile','text','&nbsp;',0,''),(15144,4699,'114906','watch-mobile','border-bottom-width','1',0,''),(15145,4699,'114906','watch-mobile','border-bottom-color','$border-color-6',0,''),(15146,4700,'114907','watch-mobile','block_type','3',0,''),(15147,4700,'114907','watch-mobile','padding-top','10',0,''),(15148,4700,'114907','watch-mobile','padding-bottom','10',0,''),(15149,4700,'114907','watch-mobile','padding-right','10',0,''),(15150,4701,'114908','watch-mobile','font-size','11',0,''),(15151,4701,'114908','watch-mobile','font-weight','bold',0,''),(15152,4701,'114908','watch-mobile','text','Return Approval:',0,''),(15153,4701,'114908','watch-mobile','padding-top','5',0,''),(15154,4701,'114908','watch-mobile','padding-left','10',0,''),(15155,4702,'114909','watch-mobile','border-bottom-width','1',0,''),(15156,4702,'114909','watch-mobile','border-bottom-color','$border-color-6',0,''),(15157,4702,'114909','watch-mobile','text','&nbsp;',0,''),(15158,4703,'114910','watch-mobile','block_type','5',0,''),(15159,4704,'114911','watch-mobile','text','Date:',0,''),(15160,4704,'114911','watch-mobile','padding-top','5',0,''),(15161,4704,'114911','watch-mobile','font-size','11',0,''),(15162,4704,'114911','watch-mobile','font-weight','bold',0,''),(15163,4704,'114911','watch-mobile','padding-left','5',0,''),(15164,4705,'114912','watch-mobile','text','&nbsp;',0,''),(15165,4705,'114912','watch-mobile','border-bottom-width','1',0,''),(15166,4705,'114912','watch-mobile','border-bottom-color','$border-color-6',0,''),(15167,4706,'114913','watch-mobile','block_type','1',0,''),(15168,4706,'114913','watch-mobile','padding-left','10',0,''),(15169,4706,'114913','watch-mobile','padding-right','10',0,''),(15170,4706,'114913','watch-mobile','padding-bottom','10',0,''),(15171,4707,'114914','watch-mobile','text','Use this space for additional Comments:',0,''),(15172,4707,'114914','watch-mobile','font-size','11',0,''),(15173,4707,'114914','watch-mobile','font-style','italic',0,''),(15174,4708,'114915','watch-mobile','text','&nbsp;',0,''),(15175,4708,'114915','watch-mobile','border-bottom-width','1',0,''),(15176,4708,'114915','watch-mobile','border-bottom-color','$border-color-6',0,''),(15177,4709,'114916','watch-mobile','text','&nbsp;',0,''),(15178,4709,'114916','watch-mobile','border-bottom-width','1',0,''),(15179,4709,'114916','watch-mobile','border-bottom-color','$border-color-6',0,''),(15180,4709,'114916','watch-mobile','padding-top','5',0,''),(15181,4710,'114917','watch-mobile','text','&nbsp;',0,''),(15182,4710,'114917','watch-mobile','border-bottom-width','1',0,''),(15183,4710,'114917','watch-mobile','border-bottom-color','$border-color-6',0,''),(15184,4710,'114917','watch-mobile','padding-top','5',0,''),(15185,4711,'114918','watch-mobile','text','&nbsp;',0,''),(15186,4711,'114918','watch-mobile','border-bottom-width','1',0,''),(15187,4711,'114918','watch-mobile','border-bottom-color','$border-color-6',0,''),(15188,4711,'114918','watch-mobile','padding-top','5',0,''),(15189,4712,'114919','watch-mobile','block_type','1',0,''),(15190,4712,'114919','watch-mobile','padding-top','10',0,''),(15191,4712,'114919','watch-mobile','padding-left','40',0,''),(15192,4712,'114919','watch-mobile','padding-right','40',0,''),(15193,4712,'114919','watch-mobile','padding-bottom','10',0,''),(15194,4713,'114920','watch-mobile','block_type','1',0,''),(15195,4713,'114920','watch-mobile','padding-top','10',0,''),(15196,4713,'114920','watch-mobile','padding-left','10',0,''),(15197,4713,'114920','watch-mobile','padding-right','10',0,''),(15198,4713,'114920','watch-mobile','padding-bottom','10',0,''),(15199,4713,'114920','watch-mobile','border-top-width','1',0,''),(15200,4713,'114920','watch-mobile','border-left-width','1',0,''),(15201,4713,'114920','watch-mobile','border-right-width','1',0,''),(15202,4713,'114920','watch-mobile','border-bottom-width','1',0,''),(15203,4713,'114920','watch-mobile','border-top-color','$border-color-6',0,''),(15204,4713,'114920','watch-mobile','border-left-color','$border-color-6',0,''),(15205,4713,'114920','watch-mobile','border-right-color','$border-color-6',0,''),(15206,4713,'114920','watch-mobile','border-bottom-color','$border-color-6',0,''),(15207,4714,'114921','watch-mobile','block_type','3',0,''),(15208,4715,'114922','watch-mobile','data','rrDelivery_name',0,''),(15209,4715,'114922','watch-mobile','font-size','9',0,''),(15210,4716,'114923','watch-mobile','block_type','2',0,''),(15211,4717,'114924','watch-mobile','text','RMA#:',0,''),(15212,4717,'114924','watch-mobile','font-size','10',0,''),(15213,4718,'114925','watch-mobile','data','rrNumber',0,''),(15214,4718,'114925','watch-mobile','font-size','9',0,''),(15215,4719,'114926','watch-mobile','block_type','5',0,''),(15216,4720,'114927','watch-mobile','font-size','9',0,''),(15217,4721,'114928','watch-mobile','block_type','1',0,''),(15218,4723,'114930','watch-mobile','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(15219,4723,'114930','watch-mobile','font-size','12',0,''),(15220,4723,'114930','watch-mobile','font-style','italic',0,''),(15221,4723,'114930','watch-mobile','padding-bottom','20',0,''),(15222,4724,'114931','watch-mobile','block_type','11',0,''),(15223,4724,'114931','watch-mobile','border-top-width','1',0,''),(15224,4724,'114931','watch-mobile','border-left-width','1',0,''),(15225,4724,'114931','watch-mobile','border-right-width','1',0,''),(15226,4724,'114931','watch-mobile','border-bottom-width','1',0,''),(15227,4724,'114931','watch-mobile','border-top-color','$border-color-6',0,''),(15228,4724,'114931','watch-mobile','border-left-color','$border-color-6',0,''),(15229,4724,'114931','watch-mobile','border-right-color','$border-color-6',0,''),(15230,4724,'114931','watch-mobile','border-bottom-color','$border-color-6',0,''),(15231,4725,'114932','watch-mobile','block_type','1',0,''),(15232,4725,'114932','watch-mobile','border-right-width','1',0,''),(15233,4725,'114932','watch-mobile','border-right-color','$border-color-6',0,''),(15234,4725,'114932','watch-mobile','padding-top','10',0,''),(15235,4725,'114932','watch-mobile','padding-right','10',0,''),(15236,4725,'114932','watch-mobile','padding-bottom','10',0,''),(15237,4726,'114933','watch-mobile','block_type','1',0,''),(15238,4726,'114933','watch-mobile','padding-left','15',0,''),(15239,4727,'114934','watch-mobile','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(15240,4727,'114934','watch-mobile','font-size','11',0,''),(15241,4727,'114934','watch-mobile','font-style','italic',0,''),(15242,4727,'114934','watch-mobile','padding-bottom','5',0,''),(15243,4728,'114935','watch-mobile','text','Replacement Policy:',0,''),(15244,4728,'114935','watch-mobile','font-size','14',0,''),(15245,4728,'114935','watch-mobile','padding-bottom','5',0,''),(15246,4728,'114935','watch-mobile','font-weight','bold',0,''),(15247,4729,'114936','watch-mobile','block_type','9',0,''),(15248,4730,'114937','watch-mobile','text','2.',0,''),(15249,4730,'114937','watch-mobile','font-size','12',0,''),(15250,4730,'114937','watch-mobile','text-align','right',0,''),(15251,4730,'114937','watch-mobile','margin-right','5',0,''),(15252,4731,'114938','watch-mobile','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(15253,4731,'114938','watch-mobile','font-size','12',0,''),(15254,4731,'114938','watch-mobile','padding-bottom','5',0,''),(15255,4732,'114939','watch-mobile','block_type','9',0,''),(15256,4733,'114940','watch-mobile','text','1.',0,''),(15257,4733,'114940','watch-mobile','font-size','12',0,''),(15258,4733,'114940','watch-mobile','text-align','right',0,''),(15259,4733,'114940','watch-mobile','padding-right','5',0,''),(15260,4734,'114941','watch-mobile','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(15261,4734,'114941','watch-mobile','font-size','12',0,''),(15262,4734,'114941','watch-mobile','padding-bottom','5',0,''),(15263,4735,'114942','watch-mobile','block_type','9',0,''),(15264,4736,'114943','watch-mobile','text','3.',0,''),(15265,4736,'114943','watch-mobile','font-size','12',0,''),(15266,4736,'114943','watch-mobile','text-align','right',0,''),(15267,4736,'114943','watch-mobile','margin-right','5',0,''),(15268,4737,'114944','watch-mobile','text','Return the authorized item(s) per shipping instructions.',0,''),(15269,4737,'114944','watch-mobile','font-size','12',0,''),(15270,4737,'114944','watch-mobile','padding-bottom','5',0,''),(15271,4738,'114945','watch-mobile','block_type','9',0,''),(15272,4739,'114946','watch-mobile','text','4.',0,''),(15273,4739,'114946','watch-mobile','font-size','12',0,''),(15274,4739,'114946','watch-mobile','text-align','right',0,''),(15275,4739,'114946','watch-mobile','margin-right','5',0,''),(15276,4740,'114947','watch-mobile','text','Our Replacement Department will process your request.',0,''),(15277,4740,'114947','watch-mobile','font-size','12',0,''),(15278,4740,'114947','watch-mobile','padding-bottom','5',0,''),(15279,4741,'114948','watch-mobile','block_type','2',0,''),(15280,4741,'114948','watch-mobile','padding-left','10',0,''),(15281,4741,'114948','watch-mobile','padding-top','20',0,''),(15282,4741,'114948','watch-mobile','padding-right','10',0,''),(15283,4742,'114949','watch-mobile','block_type','5',0,''),(15284,4743,'114950','watch-mobile','text','RMA No:',0,''),(15285,4743,'114950','watch-mobile','font-size','12',0,''),(15286,4743,'114950','watch-mobile','font-weight','bold',0,''),(15287,4744,'114951','watch-mobile','data','rrNumber',0,''),(15288,4744,'114951','watch-mobile','font-size','12',0,''),(15289,4744,'114951','watch-mobile','font-weight','bold',0,''),(15290,4745,'114952','watch-mobile','block_type','2',0,''),(15291,4746,'114953','watch-mobile','text','Date Issued:',0,''),(15292,4746,'114953','watch-mobile','font-size','12',0,''),(15293,4746,'114953','watch-mobile','font-weight','bold',0,''),(15294,4747,'114954','watch-mobile','data','rrDateCreate',0,''),(15295,4747,'114954','watch-mobile','font-size','12',0,''),(15296,4747,'114954','watch-mobile','font-weight','bold',0,''),(15297,4748,'114955','watch-mobile','block_type','1',0,''),(15298,4748,'114955','watch-mobile','padding-top','10',0,''),(15299,4748,'114955','watch-mobile','padding-left','10',0,''),(15300,4748,'114955','watch-mobile','padding-right','10',0,''),(15301,4748,'114955','watch-mobile','padding-bottom','10',0,''),(15302,4749,'114956','watch-mobile','block_type','2',0,''),(15303,4750,'114957','watch-mobile','block_type','11',0,''),(15304,4751,'114958','watch-mobile','text','Company:',0,''),(15305,4751,'114958','watch-mobile','font-size','12',0,''),(15306,4752,'114959','watch-mobile','data','rrDelivery_company',0,''),(15307,4752,'114959','watch-mobile','font-size','12',0,''),(15308,4753,'114960','watch-mobile','block_type','2',0,''),(15309,4754,'114961','watch-mobile','text','Contact Name:',0,''),(15310,4754,'114961','watch-mobile','font-size','12',0,''),(15311,4755,'114962','watch-mobile','data','rrDelivery_name',0,''),(15312,4755,'114962','watch-mobile','font-size','12',0,''),(15313,4756,'114963','watch-mobile','block_type','9',0,''),(15314,4756,'114963','watch-mobile','padding-top','5',0,''),(15315,4757,'114964','watch-mobile','text','Address:',0,''),(15316,4757,'114964','watch-mobile','font-size','12',0,''),(15317,4758,'114965','watch-mobile','data','rrDelivery_street_address',0,''),(15318,4758,'114965','watch-mobile','font-size','12',0,''),(15319,4759,'114966','watch-mobile','block_type','2',0,''),(15320,4759,'114966','watch-mobile','padding-top','5',0,''),(15321,4760,'114967','watch-mobile','block_type','11',0,''),(15322,4761,'114968','watch-mobile','text','City:',0,''),(15323,4761,'114968','watch-mobile','font-size','12',0,''),(15324,4762,'114969','watch-mobile','data','rrDelivery_city',0,''),(15325,4762,'114969','watch-mobile','font-size','12',0,''),(15326,4763,'114970','watch-mobile','block_type','11',0,''),(15327,4764,'114971','watch-mobile','text','State:',0,''),(15328,4764,'114971','watch-mobile','font-size','12',0,''),(15329,4765,'114972','watch-mobile','data','rrDelivery_state',0,''),(15330,4765,'114972','watch-mobile','font-size','12',0,''),(15331,4766,'114973','watch-mobile','block_type','2',0,''),(15332,4766,'114973','watch-mobile','padding-top','5',0,''),(15333,4767,'114974','watch-mobile','block_type','11',0,''),(15334,4768,'114975','watch-mobile','text','Country:',0,''),(15335,4768,'114975','watch-mobile','font-size','12',0,''),(15336,4769,'114976','watch-mobile','data','rrDelivery_country',0,''),(15337,4769,'114976','watch-mobile','font-size','12',0,''),(15338,4770,'114977','watch-mobile','block_type','11',0,''),(15339,4771,'114978','watch-mobile','text','Postcode:',0,''),(15340,4771,'114978','watch-mobile','font-size','12',0,''),(15341,4772,'114979','watch-mobile','data','rrDelivery_postcode',0,''),(15342,4772,'114979','watch-mobile','font-size','12',0,''),(15343,4773,'114980','watch-mobile','block_type','2',0,''),(15344,4773,'114980','watch-mobile','padding-top','5',0,''),(15345,4774,'114981','watch-mobile','block_type','11',0,''),(15346,4775,'114982','watch-mobile','text','Email:',0,''),(15347,4775,'114982','watch-mobile','font-size','12',0,''),(15348,4776,'114983','watch-mobile','data','rrDelivery_email_address',0,''),(15349,4776,'114983','watch-mobile','font-size','12',0,''),(15350,4777,'114984','watch-mobile','block_type','11',0,''),(15351,4778,'114985','watch-mobile','text','Phone:',0,''),(15352,4778,'114985','watch-mobile','font-size','12',0,''),(15353,4779,'114986','watch-mobile','data','rrDelivery_telephone',0,''),(15354,4779,'114986','watch-mobile','font-size','12',0,''),(15355,4780,'114987','watch-mobile','block_type','1',0,''),(15356,4780,'114987','watch-mobile','border-bottom-width','1',0,''),(15357,4780,'114987','watch-mobile','border-bottom-color','$border-color-6',0,''),(15358,4781,'114988','watch-mobile','text-align','center',0,''),(15359,4781,'114988','watch-mobile','logo','themes/watch-mobile/img/Furntech-1.jpg',1,''),(15360,4781,'114988','watch-mobile','padding-top','10',0,''),(15361,4781,'114988','watch-mobile','padding-bottom','10',0,''),(15362,4782,'114989','watch-mobile','text','Return Material Authorization (RMA) Form',0,''),(15363,4782,'114989','watch-mobile','text-align','center',0,''),(15364,4782,'114989','watch-mobile','font-size','12',0,''),(15365,4782,'114989','watch-mobile','font-weight','bold',0,''),(15366,4782,'114989','watch-mobile','font-family','$font-1',0,''),(15367,4783,'114990','watch-mobile','block_type','1',0,''),(15368,4783,'114990','watch-mobile','style_class','item-holder',0,''),(15369,4783,'114990','watch-mobile','padding-top','25',0,''),(15370,4783,'114990','watch-mobile','padding-bottom','25',0,''),(15371,4783,'114990','watch-mobile','text-align','left',0,''),(15372,4783,'114990','watch-mobile','border-top-width','1',0,''),(15373,4783,'114990','watch-mobile','border-top-color','$border-color-1',0,''),(15374,4784,'114991','watch-mobile','block_type','7',0,''),(15375,4784,'114991','watch-mobile','schema','7-2',0,''),(15376,4785,'114992','watch-mobile','block_type','5',0,''),(15377,4785,'114992','watch-mobile','schema','5-2',0,''),(15378,4786,'114993','watch-mobile','block_type','1',0,''),(15379,4787,'114994','watch-mobile','text-align','right',0,''),(15380,4787,'114994','watch-mobile','margin-top','4',0,''),(15381,4787,'114994','watch-mobile','margin-bottom','7',0,''),(15382,4787,'114994','watch-mobile','float','left',0,''),(15383,4788,'114995','watch-mobile','padding-top','6',0,''),(15384,4788,'114995','watch-mobile','padding-left','5',0,''),(15385,4788,'114995','watch-mobile','float','left',0,''),(15386,4788,'114995','watch-mobile','clear','none',0,''),(15387,4789,'114996','watch-mobile','clear','none',0,''),(15388,4789,'114996','watch-mobile','padding-right','20',0,''),(15389,4790,'114997','watch-mobile','padding-right','20',0,''),(15390,4790,'114997','watch-mobile','max-width','300',0,''),(15391,4790,'114997','watch-mobile','margin_left_measure','auto',0,''),(15392,4790,'114997','watch-mobile','margin_right_measure','auto',0,''),(15393,4791,'114998','watch-mobile','clear','none',0,''),(15394,4792,'114999','watch-mobile','padding-right','20',0,''),(15395,4793,'115000','watch-mobile','description_characters','200',0,''),(15396,4793,'115000','watch-mobile','clear','none',0,''),(15397,4793,'115000','watch-mobile','padding-right','20',0,''),(15398,4794,'115001','watch-mobile','margin-bottom','20',0,''),(15399,4795,'115002','watch-mobile','block_type','1',0,''),(15400,4795,'115002','watch-mobile','padding-left','40',0,''),(15401,4795,'115002','watch-mobile','style_class','right-aria',0,''),(15403,4796,'115003','watch-mobile','text-align','right',0,''),(15404,4796,'115003','watch-mobile','margin-bottom','10',0,''),(15405,4797,'115004','watch-mobile','margin-bottom','10',0,''),(15406,4797,'115004','watch-mobile','text-align','right',0,''),(15407,4799,'115006','watch-mobile','margin-bottom','15',0,''),(15408,4799,'115006','watch-mobile','text-align','right',0,''),(15409,4800,'115007','watch-mobile','margin-bottom','10',0,''),(15410,4801,'115008','watch-mobile','text-align','right',0,''),(15411,4801,'115008','watch-mobile','margin-bottom','15',0,''),(15412,4802,'75869','watch-mobile','block_type','1',0,''),(15413,4803,'75870','watch-mobile','padding-bottom','20',0,''),(15414,4804,'75871','watch-mobile','text-align','right',0,''),(15415,4804,'75871','watch-mobile','margin-bottom','40',0,''),(15416,4805,'75872','watch-mobile','text','<h1>Samples</h1>',1,''),(15417,4806,'115009','watch-mobile','block_type','1',0,''),(15418,4807,'115010','watch-mobile','block_type','6',0,''),(15419,4807,'115010','watch-mobile','schema','6-3',0,''),(15420,4807,'115010','watch-mobile','schema','6-3',0,'299'),(15421,4808,'115011','watch-mobile','aria_name','account-menu',0,''),(15422,4809,'115012','watch-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(15423,4810,'115013','watch-mobile','show_pagenation','1',0,''),(15424,4810,'115013','watch-mobile','link','Sample Info',0,''),(15425,4810,'115013','watch-mobile','margin-bottom','20',0,''),(15426,4811,'115014','watch-mobile','block_type','1',0,''),(15427,4812,'115015','watch-mobile','block_type','6',0,''),(15428,4813,'115016','watch-mobile','aria_name','account-menu',0,''),(15429,4814,'115017','watch-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(15430,4815,'115018','watch-mobile','block_type','3',0,''),(15431,4816,'115019','watch-mobile','block_type','1',0,''),(15432,4816,'115019','watch-mobile','padding-right','20',0,''),(15433,4816,'115019','watch-mobile','padding-bottom','20',0,''),(15434,4817,'115020','watch-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(15435,4818,'115021','watch-mobile','orders_data','telephone',0,''),(15436,4819,'115022','watch-mobile','block_type','1',0,''),(15437,4819,'115022','watch-mobile','padding-right','20',0,''),(15438,4819,'115022','watch-mobile','padding-bottom','20',0,''),(15439,4820,'115023','watch-mobile','orders_data','name',0,''),(15440,4821,'115024','watch-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(15441,4822,'115025','watch-mobile','block_type','1',0,''),(15442,4822,'115025','watch-mobile','padding-right','20',0,''),(15443,4822,'115025','watch-mobile','padding-bottom','20',0,''),(15444,4823,'115026','watch-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(15445,4824,'115027','watch-mobile','orders_data','delivery_address',0,''),(15446,4825,'115028','watch-mobile','block_type','1',0,''),(15447,4825,'115028','watch-mobile','padding-right','20',0,''),(15448,4826,'115029','watch-mobile','orders_data','shipping_method',0,''),(15449,4827,'115030','watch-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(15450,4828,'115031','watch-mobile','block_type','1',0,''),(15451,4828,'115031','watch-mobile','padding-bottom','20',0,''),(15452,4829,'115032','watch-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(15453,4830,'115033','watch-mobile','orders_data','billing_address',0,''),(15454,4831,'115034','watch-mobile','block_type','1',0,''),(15455,4832,'115035','watch-mobile','orders_data','payment_method',0,''),(15456,4833,'115036','watch-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(15457,4834,'115037','watch-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(15458,4837,'115040','watch-mobile','block_type','2',0,''),(15459,4837,'115040','watch-mobile','padding-top','20',0,''),(15460,4837,'115040','watch-mobile','margin-bottom','20',0,''),(15461,4838,'115041','watch-mobile','like_button','1',0,''),(15462,4838,'115041','watch-mobile','text','IMAGE_BUTTON_BACK',0,''),(15463,4838,'115041','watch-mobile','link','Samples',0,''),(15464,4840,'115043','watch-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(15465,4841,'115715','watch-mobile','block_type','1',0,''),(15466,4842,'115716','watch-mobile','block_type','6',0,''),(15467,4842,'115716','watch-mobile','schema','6-3',0,''),(15468,4842,'115716','watch-mobile','schema','6-3',0,'299'),(15469,4843,'115717','watch-mobile','aria_name','account-menu',0,''),(15470,4844,'115718','watch-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(15471,4845,'115719','watch-mobile','link','Order History Info',0,''),(15472,4845,'115719','watch-mobile','text','TEXT_VIEW',0,''),(15473,4845,'115719','watch-mobile','max_orders','3',0,''),(15474,4845,'115719','watch-mobile','link_pay','Order pay',0,''),(15475,4845,'115719','watch-mobile','margin-bottom','30',0,''),(15476,4845,'115719','watch-mobile','text_pay','ORDER_PAY',0,''),(15477,4846,'115720','watch-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(15478,4847,'115721','watch-mobile','block_type','15',0,''),(15479,4847,'115721','watch-mobile','margin-bottom','30',0,''),(15480,4847,'115721','watch-mobile','padding-top','20',0,''),(15481,4847,'115721','watch-mobile','padding-left','20',0,''),(15482,4847,'115721','watch-mobile','padding-right','20',0,''),(15483,4847,'115721','watch-mobile','padding-bottom','20',0,''),(15484,4847,'115721','watch-mobile','border-top-width','1',0,''),(15485,4847,'115721','watch-mobile','border-top-color','$border-color-1',0,''),(15486,4847,'115721','watch-mobile','border-left-width','1',0,''),(15487,4847,'115721','watch-mobile','border-right-width','1',0,''),(15488,4847,'115721','watch-mobile','border-bottom-width','1',0,''),(15489,4847,'115721','watch-mobile','border-left-color','$border-color-1',0,''),(15490,4847,'115721','watch-mobile','border-right-color','$border-color-1',0,''),(15491,4847,'115721','watch-mobile','border-bottom-color','$border-color-1',0,''),(15492,4847,'115721','watch-mobile','schema','15-2',0,'299'),(15493,4848,'115722','watch-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(15494,4848,'115722','watch-mobile','font-family','trueloaded',0,'3'),(15495,4848,'115722','watch-mobile','content','\\e920',0,'3'),(15496,4848,'115722','watch-mobile','color','$attention-color',0,'3'),(15497,4848,'115722','watch-mobile','font-size','30',0,'3'),(15498,4848,'115722','watch-mobile','text-align','center',0,'3'),(15499,4848,'115722','watch-mobile','margin-bottom','10',0,'3'),(15500,4848,'115722','watch-mobile','text-align','center',0,''),(15501,4848,'115722','watch-mobile','font-size','16',0,''),(15502,4848,'115722','watch-mobile','text-transform','uppercase',0,''),(15503,4848,'115722','watch-mobile','line-height','1',0,'3'),(15505,4849,'115723','watch-mobile','font-family','$font-1',0,''),(15506,4849,'115723','watch-mobile','color','$attention-color',0,''),(15507,4849,'115723','watch-mobile','font-size','14',0,''),(15508,4849,'115723','watch-mobile','text-align','center',0,''),(15509,4850,'115724','watch-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(15510,4850,'115724','watch-mobile','font-family','trueloaded',0,'3'),(15511,4850,'115724','watch-mobile','content','\\e928',0,'3'),(15512,4850,'115724','watch-mobile','color','$attention-color',0,'3'),(15513,4850,'115724','watch-mobile','font-size','30',0,'3'),(15514,4850,'115724','watch-mobile','text-align','center',0,'3'),(15515,4850,'115724','watch-mobile','text-align','center',0,''),(15516,4850,'115724','watch-mobile','font-size','16',0,''),(15517,4850,'115724','watch-mobile','text-transform','uppercase',0,''),(15518,4850,'115724','watch-mobile','line-height','1',0,'3'),(15520,4851,'115725','watch-mobile','link','download_orders',0,''),(15521,4851,'115725','watch-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(15522,4851,'115725','watch-mobile','hide_link','orders',0,''),(15523,4851,'115725','watch-mobile','text-align','center',0,''),(15524,4851,'115725','watch-mobile','popup','2',0,''),(15525,4851,'115725','watch-mobile','font-size','14',0,''),(15526,4852,'115726','watch-mobile','font-family','$font-1',0,''),(15527,4852,'115726','watch-mobile','color','$attention-color',0,''),(15528,4852,'115726','watch-mobile','font-size','14',0,''),(15529,4852,'115726','watch-mobile','text-align','center',0,''),(15530,4853,'115727','watch-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(15531,4853,'115727','watch-mobile','font-family','trueloaded',0,'3'),(15532,4853,'115727','watch-mobile','content','\\e922',0,'3'),(15533,4853,'115727','watch-mobile','color','$attention-color',0,'3'),(15534,4853,'115727','watch-mobile','font-size','30',0,'3'),(15535,4853,'115727','watch-mobile','line-height','1',0,'3'),(15536,4853,'115727','watch-mobile','font-size','16',0,''),(15537,4853,'115727','watch-mobile','text-align','center',0,''),(15538,4853,'115727','watch-mobile','text-transform','uppercase',0,''),(15540,4854,'115728','watch-mobile','font-family','$font-1',0,''),(15541,4854,'115728','watch-mobile','color','$attention-color',0,''),(15542,4854,'115728','watch-mobile','line-height','1',0,''),(15543,4854,'115728','watch-mobile','text-align','center',0,''),(15544,4854,'115728','watch-mobile','font-size','14',0,''),(15545,4855,'115729','watch-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(15546,4855,'115729','watch-mobile','content','\\e994',0,'3'),(15547,4855,'115729','watch-mobile','font-family','trueloaded',0,'3'),(15548,4855,'115729','watch-mobile','color','$attention-color',0,'3'),(15549,4855,'115729','watch-mobile','font-size','30',0,'3'),(15550,4855,'115729','watch-mobile','line-height','1',0,'3'),(15551,4855,'115729','watch-mobile','font-size','16',0,''),(15552,4855,'115729','watch-mobile','text-align','center',0,''),(15553,4855,'115729','watch-mobile','text-transform','uppercase',0,''),(15555,4856,'115730','watch-mobile','link','Gift Certificate',0,''),(15556,4856,'115730','watch-mobile','text','GIFT_CERTIFICATE',0,''),(15557,4856,'115730','watch-mobile','popup','1',0,''),(15558,4856,'115730','watch-mobile','text-align','center',0,''),(15559,4856,'115730','watch-mobile','font-size','14',0,''),(15560,4857,'115731','watch-mobile','font-family','$font-1',0,''),(15561,4857,'115731','watch-mobile','color','$attention-color',0,''),(15562,4857,'115731','watch-mobile','font-size','14',0,''),(15563,4857,'115731','watch-mobile','text-align','center',0,''),(15564,4858,'115732','watch-mobile','text','TEXT_VIEW_HISTORY',0,''),(15565,4858,'115732','watch-mobile','popup','1',0,''),(15566,4858,'115732','watch-mobile','text-align','center',0,''),(15567,4858,'115732','watch-mobile','link','Points Earnt History',0,''),(15568,4858,'115732','watch-mobile','font-size','14',0,''),(15569,4859,'115733','watch-mobile','font-family','$font-1',0,''),(15570,4859,'115733','watch-mobile','color','$attention-color',0,''),(15571,4859,'115733','watch-mobile','font-size','14',0,''),(15572,4859,'115733','watch-mobile','text-align','center',0,''),(15573,4860,'115734','watch-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(15574,4860,'115734','watch-mobile','content','\\e990',0,'3'),(15575,4860,'115734','watch-mobile','font-family','trueloaded',0,'3'),(15576,4860,'115734','watch-mobile','font-size','30',0,'3'),(15577,4860,'115734','watch-mobile','text-align','center',0,'3'),(15578,4860,'115734','watch-mobile','line-height','1',0,'3'),(15579,4860,'115734','watch-mobile','color','$attention-color',0,'3'),(15580,4860,'115734','watch-mobile','font-size','16',0,''),(15581,4860,'115734','watch-mobile','text-align','center',0,''),(15582,4860,'115734','watch-mobile','text-transform','uppercase',0,''),(15584,4861,'115735','watch-mobile','block_type','1',0,''),(15585,4862,'115736','watch-mobile','hide_parents','2',0,''),(15586,4863,'115737','watch-mobile','text','<div class=\"heading-3\">##TEXT_GIFT_CARDS##</div>',0,''),(15587,4865,'115044','watch-mobile','block_type','1',0,''),(15588,4866,'115045','watch-mobile','block_type','6',0,''),(15589,4867,'115046','watch-mobile','class','menu-simple',0,''),(15590,4869,'115048','watch-mobile','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(15591,4871,'115050','watch-mobile','text','<div class=\"heading-4\">Categories</div>',0,''),(15592,4872,'115051','watch-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(15593,4873,'115052','watch-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(15594,4875,'115054','watch-mobile','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(15595,4876,'115055','watch-mobile','block_type','1',0,''),(15596,4877,'115056','watch-mobile','style_class','middle-form',0,''),(15597,4877,'115056','watch-mobile','margin-bottom','30',0,''),(15598,4878,'115057','watch-mobile','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(15599,4879,'115058','watch-mobile','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(15600,4879,'115058','watch-mobile','style_class','middle-form',0,''),(15601,4880,'115059','watch-mobile','style_class','middle-form',0,''),(15602,4881,'115060','watch-mobile','block_type','1',0,''),(15603,4882,'115061','watch-mobile','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(15604,4882,'115061','watch-mobile','padding-top','100',0,''),(15605,4882,'115061','watch-mobile','margin-bottom','100',0,''),(15606,4882,'115061','watch-mobile','text-align','center',0,''),(15607,4882,'115061','watch-mobile','font-size','20',0,''),(15608,4883,'115062','watch-mobile','block_type','1',0,''),(15609,4884,'115063','watch-mobile','block_type','6',0,''),(15610,4884,'115063','watch-mobile','schema','6-3',0,''),(15611,4884,'115063','watch-mobile','schema','6-3',0,'299'),(15612,4885,'115064','watch-mobile','aria_name','account-menu',0,''),(15613,4886,'115065','watch-mobile','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(15614,4887,'115066','watch-mobile','text','##SUBSCRIPTION_TEXT##',0,''),(15615,4889,'75873','watch-mobile','block_type','1',0,''),(15616,4890,'75874','watch-mobile','block_type','1',0,''),(15617,4890,'75874','watch-mobile','font-weight','normal',0,''),(15618,4891,'75875','watch-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',1,''),(15619,4891,'75875','watch-mobile','font-weight','400',0,''),(15620,4892,'75876','watch-mobile','block_type','3',0,''),(15621,4892,'75876','watch-mobile','font-weight','400',0,''),(15622,4892,'75876','watch-mobile','schema','3-4',0,'291'),(15623,4893,'75877','watch-mobile','text','&nbsp;',0,''),(15624,4893,'75877','watch-mobile','font-weight','normal',0,''),(15625,4894,'75878','watch-mobile','font-weight','normal',0,''),(15626,4894,'75878','watch-mobile','box_align','2',0,''),(15627,4894,'75878','watch-mobile','padding-top','40',0,''),(15628,4895,'75879','watch-mobile','font-weight','400',0,''),(15629,4895,'75879','watch-mobile','text-align','right',0,''),(15630,4895,'75879','watch-mobile','padding-top','40',0,''),(15631,4895,'75879','watch-mobile','padding-bottom','100',0,''),(15632,4895,'75879','watch-mobile','text-align','center',0,'291'),(15633,4895,'75879','watch-mobile','float','none',0,'291'),(15634,4896,'115068','watch-mobile','block_type','1',0,''),(15635,4897,'115069','watch-mobile','block_type','1',0,''),(15636,4897,'115069','watch-mobile','font-weight','normal',0,''),(15637,4898,'115070','watch-mobile','block_type','1',0,''),(15638,4898,'115070','watch-mobile','text-align','center',0,''),(15639,4898,'115070','watch-mobile','padding-top','30',0,''),(15640,4898,'115070','watch-mobile','margin-bottom','200',0,''),(15641,4899,'115071','watch-mobile','display','inline-block',0,''),(15642,4900,'115072','watch-mobile','display','inline-block',0,''),(15643,4900,'115072','watch-mobile','clear','none',0,''),(15644,4900,'115072','watch-mobile','margin-left','20',0,''),(15645,4901,'115073','watch-mobile','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(15647,4905,'115074','watch-mobile','width','680',0,''),(15648,4905,'115074','watch-mobile','font-weight','normal',0,''),(15649,4905,'115074','watch-mobile','font-size','12',0,''),(15650,4905,'115074','watch-mobile','padding-top','20',0,''),(15651,4905,'115074','watch-mobile','padding-bottom','20',0,''),(15652,4905,'115074','watch-mobile','color','$color-font-7',0,''),(15653,4906,'115075','watch-mobile','block_type','2',0,''),(15654,4906,'115075','watch-mobile','font-weight','normal',0,''),(15655,4906,'115075','watch-mobile','padding-bottom','20',0,''),(15656,4907,'115076','watch-mobile','block_type','1',0,''),(15657,4908,'115077','watch-mobile','font-weight','normal',0,''),(15658,4908,'115077','watch-mobile','text-align','right',0,''),(15659,4908,'115077','watch-mobile','padding-bottom','10',0,''),(15660,4908,'115077','watch-mobile','address_spacer',',',0,''),(15661,4908,'115077','watch-mobile','font-size','12',0,''),(15662,4909,'115078','watch-mobile','block_type','11',0,''),(15663,4909,'115078','watch-mobile','font-weight','normal',0,''),(15664,4910,'115079','watch-mobile','text','<p>Phone:</p>',1,''),(15665,4910,'115079','watch-mobile','font-weight','normal',0,''),(15666,4910,'115079','watch-mobile','text-align','right',0,''),(15667,4911,'115080','watch-mobile','font-weight','normal',0,''),(15668,4911,'115080','watch-mobile','text-align','right',0,''),(15669,4912,'115081','watch-mobile','block_type','11',0,''),(15670,4912,'115081','watch-mobile','font-weight','normal',0,''),(15671,4913,'115082','watch-mobile','text','<p>Web:</p>',1,''),(15672,4913,'115082','watch-mobile','font-weight','normal',0,''),(15673,4913,'115082','watch-mobile','text-align','right',0,''),(15674,4914,'115083','watch-mobile','font-weight','normal',0,''),(15675,4914,'115083','watch-mobile','text-align','right',0,''),(15676,4915,'115084','watch-mobile','block_type','11',0,''),(15677,4915,'115084','watch-mobile','font-weight','normal',0,''),(15678,4916,'115085','watch-mobile','text','<p>Email:</p>',1,''),(15679,4916,'115085','watch-mobile','font-weight','normal',0,''),(15680,4916,'115085','watch-mobile','text-align','right',0,''),(15681,4917,'115086','watch-mobile','font-weight','normal',0,''),(15682,4917,'115086','watch-mobile','text-align','right',0,''),(15683,4918,'115087','watch-mobile','block_type','4',0,''),(15684,4918,'115087','watch-mobile','font-weight','normal',0,''),(15685,4918,'115087','watch-mobile','border-top-width','1',0,''),(15686,4918,'115087','watch-mobile','border-top-color','$border-color-1',0,''),(15687,4918,'115087','watch-mobile','border-left-width','1',0,''),(15688,4918,'115087','watch-mobile','border-left-color','$border-color-1',0,''),(15689,4918,'115087','watch-mobile','border-right-width','1',0,''),(15690,4918,'115087','watch-mobile','border-right-color','$border-color-1',0,''),(15691,4918,'115087','watch-mobile','border-bottom-width','1',0,''),(15692,4918,'115087','watch-mobile','border-bottom-color','$border-color-1',0,''),(15693,4919,'115088','watch-mobile','block_type','2',0,''),(15694,4919,'115088','watch-mobile','font-weight','normal',0,''),(15695,4919,'115088','watch-mobile','border-right-width','1',0,''),(15696,4919,'115088','watch-mobile','border-right-color','$border-color-1',0,''),(15697,4920,'115089','watch-mobile','block_type','1',0,''),(15698,4920,'115089','watch-mobile','font-weight','400',0,''),(15699,4920,'115089','watch-mobile','background-color','$background-6',0,''),(15700,4920,'115089','watch-mobile','padding-top','10',0,''),(15701,4920,'115089','watch-mobile','padding-left','10',0,''),(15702,4920,'115089','watch-mobile','padding-right','10',0,''),(15703,4920,'115089','watch-mobile','padding-bottom','30',0,''),(15704,4921,'115090','watch-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(15705,4921,'115090','watch-mobile','font-size','14',0,''),(15706,4921,'115090','watch-mobile','font-weight','bold',0,''),(15707,4922,'115091','watch-mobile','font-size','12',0,''),(15708,4923,'115092','watch-mobile','block_type','1',0,''),(15709,4923,'115092','watch-mobile','font-weight','normal',0,''),(15710,4923,'115092','watch-mobile','padding-top','10',0,''),(15711,4923,'115092','watch-mobile','padding-left','10',0,''),(15712,4923,'115092','watch-mobile','padding-right','10',0,''),(15713,4923,'115092','watch-mobile','padding-bottom','10',0,''),(15714,4924,'115093','watch-mobile','text','<p>PHONE NUMBER:</p>',1,''),(15715,4924,'115093','watch-mobile','font-size','14',0,''),(15716,4924,'115093','watch-mobile','font-weight','bold',0,''),(15717,4924,'115093','watch-mobile','padding-top','10',0,''),(15718,4925,'115094','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(15719,4925,'115094','watch-mobile','font-weight','bold',0,''),(15720,4925,'115094','watch-mobile','font-size','14',0,''),(15721,4925,'115094','watch-mobile','padding-top','10',0,''),(15722,4926,'115095','watch-mobile','text','<p>CUSTOMER:</p>',1,''),(15723,4926,'115095','watch-mobile','font-size','13',0,''),(15724,4926,'115095','watch-mobile','font-weight','bold',0,''),(15725,4927,'115096','watch-mobile','font-weight','normal',0,''),(15726,4928,'115097','watch-mobile','font-weight','normal',0,''),(15727,4930,'115099','watch-mobile','block_type','2',0,''),(15728,4930,'115099','watch-mobile','font-weight','normal',0,''),(15729,4930,'115099','watch-mobile','border-top-width','1',0,''),(15730,4930,'115099','watch-mobile','border-top-color','$border-color-1',0,''),(15731,4930,'115099','watch-mobile','border-right-width','1',0,''),(15732,4930,'115099','watch-mobile','border-right-color','$border-color-1',0,''),(15733,4931,'115100','watch-mobile','block_type','1',0,''),(15734,4931,'115100','watch-mobile','font-weight','normal',0,''),(15735,4931,'115100','watch-mobile','padding-top','10',0,''),(15736,4931,'115100','watch-mobile','padding-left','10',0,''),(15737,4931,'115100','watch-mobile','padding-right','10',0,''),(15738,4931,'115100','watch-mobile','padding-bottom','10',0,''),(15739,4931,'115100','watch-mobile','border-right-width','1',0,''),(15740,4931,'115100','watch-mobile','border-right-color','$border-color-1',0,''),(15741,4932,'115101','watch-mobile','text','<p>Shipping via</p>',1,''),(15742,4932,'115101','watch-mobile','font-weight','bold',0,''),(15743,4932,'115101','watch-mobile','font-size','14',0,''),(15744,4934,'115103','watch-mobile','block_type','1',0,''),(15745,4934,'115103','watch-mobile','font-weight','normal',0,''),(15746,4934,'115103','watch-mobile','padding-top','10',0,''),(15747,4934,'115103','watch-mobile','padding-left','10',0,''),(15748,4934,'115103','watch-mobile','padding-right','10',0,''),(15749,4934,'115103','watch-mobile','padding-bottom','10',0,''),(15750,4936,'115105','watch-mobile','text','<p>Shipping service</p>',1,''),(15751,4936,'115105','watch-mobile','font-weight','bold',0,''),(15752,4936,'115105','watch-mobile','font-size','14',0,''),(15753,4937,'115106','watch-mobile','text','<p>Payment date:</p>',1,''),(15754,4937,'115106','watch-mobile','font-weight','bold',0,''),(15755,4937,'115106','watch-mobile','text-align','center',0,''),(15756,4937,'115106','watch-mobile','font-size','12',0,''),(15757,4938,'115107','watch-mobile','font-weight','normal',0,''),(15758,4938,'115107','watch-mobile','text-align','center',0,''),(15759,4939,'115108','watch-mobile','text','<p>Payment Method:</p>',1,''),(15760,4939,'115108','watch-mobile','font-weight','bold',0,''),(15761,4939,'115108','watch-mobile','text-align','center',0,''),(15762,4940,'115109','watch-mobile','font-size','14',0,''),(15763,4940,'115109','watch-mobile','font-weight','bold',0,''),(15764,4940,'115109','watch-mobile','text-align','center',0,''),(15765,4940,'115109','watch-mobile','padding-bottom','10',0,''),(15766,4940,'115109','watch-mobile','padding-top','10',0,''),(15767,4941,'115110','watch-mobile','font-weight','normal',0,''),(15768,4941,'115110','watch-mobile','text-align','center',0,''),(15769,4941,'115110','watch-mobile','padding-bottom','10',0,''),(15770,4942,'115111','watch-mobile','font-weight','normal',0,''),(15771,4942,'115111','watch-mobile','text-align','center',0,''),(15772,4942,'115111','watch-mobile','padding-bottom','20',0,''),(15773,4943,'115112','watch-mobile','block_type','3',0,''),(15774,4943,'115112','watch-mobile','font-weight','normal',0,''),(15775,4943,'115112','watch-mobile','padding-top','20',0,''),(15776,4944,'115113','watch-mobile','text','<p>If undelivered please return to:</p>',1,''),(15777,4944,'115113','watch-mobile','font-size','12',0,''),(15778,4944,'115113','watch-mobile','font-weight','bold',0,''),(15779,4945,'115114','watch-mobile','font-size','12',0,''),(15780,4946,'115115','watch-mobile','font-weight','400',0,''),(15781,4946,'115115','watch-mobile','text-align','center',0,''),(15782,4946,'115115','watch-mobile','padding-top','0',0,''),(15784,4946,'115115','watch-mobile','padding-left','20',0,''),(15785,4946,'115115','watch-mobile','padding-right','20',0,''),(15786,4947,'115116','watch-mobile','text','<p>Thank you for your order</p>',1,''),(15787,4947,'115116','watch-mobile','color','$color-font-10',0,''),(15788,4947,'115116','watch-mobile','font-size','13',0,''),(15789,4947,'115116','watch-mobile','font-weight','bold',0,''),(15790,4947,'115116','watch-mobile','padding-top','5',0,''),(15791,4947,'115116','watch-mobile','text-align','center',0,''),(15792,4948,'115117','watch-mobile','block_type','6',0,''),(15793,4948,'115117','watch-mobile','font-weight','normal',0,''),(15794,4948,'115117','watch-mobile','font-size','16',0,''),(15795,4949,'115118','watch-mobile','text','<p>Phone:</p>',1,''),(15796,4949,'115118','watch-mobile','font-weight','normal',0,''),(15797,4949,'115118','watch-mobile','text-align','right',0,''),(15798,4949,'115118','watch-mobile','font-size','12',0,''),(15799,4950,'115119','watch-mobile','font-weight','normal',0,''),(15800,4950,'115119','watch-mobile','text-align','right',0,''),(15801,4950,'115119','watch-mobile','font-size','12',0,''),(15802,4951,'115120','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(15803,4951,'115120','watch-mobile','font-size','12',0,''),(15804,4951,'115120','watch-mobile','font-weight','bold',0,''),(15805,4951,'115120','watch-mobile','text-align','right',0,''),(15806,4952,'115121','watch-mobile','block_type','6',0,''),(15807,4952,'115121','watch-mobile','font-weight','normal',0,''),(15808,4952,'115121','watch-mobile','font-size','16',0,''),(15809,4953,'115122','watch-mobile','text','<p>Email:</p>',1,''),(15810,4953,'115122','watch-mobile','font-weight','normal',0,''),(15811,4953,'115122','watch-mobile','text-align','right',0,''),(15812,4953,'115122','watch-mobile','font-size','12',0,''),(15813,4954,'115123','watch-mobile','font-weight','normal',0,''),(15814,4954,'115123','watch-mobile','text-align','right',0,''),(15815,4954,'115123','watch-mobile','font-size','12',0,''),(15816,4955,'115124','watch-mobile','font-weight','400',0,''),(15817,4955,'115124','watch-mobile','padding-top','20',0,''),(15818,4955,'115124','watch-mobile','padding-bottom','0',0,''),(15819,4955,'115124','watch-mobile','font-size','12',0,''),(15820,4956,'115125','watch-mobile','block_type','5',0,''),(15821,4956,'115125','watch-mobile','font-weight','normal',0,''),(15822,4956,'115125','watch-mobile','border-bottom-width','1',0,''),(15823,4956,'115125','watch-mobile','border-bottom-color','$border-color-1',0,''),(15824,4956,'115125','watch-mobile','border-top-width','1',0,''),(15825,4956,'115125','watch-mobile','border-top-color','$border-color-1',0,''),(15826,4956,'115125','watch-mobile','border-left-color','$border-color-1',0,''),(15827,4956,'115125','watch-mobile','border-left-width','1',0,''),(15828,4957,'115126','watch-mobile','block_type','1',0,''),(15829,4957,'115126','watch-mobile','font-weight','normal',0,''),(15830,4957,'115126','watch-mobile','padding-top','10',0,''),(15831,4957,'115126','watch-mobile','padding-left','10',0,''),(15832,4957,'115126','watch-mobile','padding-right','10',0,''),(15833,4958,'115127','watch-mobile','font-weight','400',0,''),(15834,4958,'115127','watch-mobile','line-height','120',0,''),(15835,4958,'115127','watch-mobile','line_height_measure','%',0,''),(15836,4958,'115127','watch-mobile','font-size','12',0,''),(15837,4959,'115128','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(15838,4959,'115128','watch-mobile','font-size','14',0,''),(15839,4959,'115128','watch-mobile','font-weight','bold',0,''),(15840,4959,'115128','watch-mobile','padding-bottom','10',0,''),(15841,4960,'115129','watch-mobile','block_type','1',0,''),(15842,4960,'115129','watch-mobile','background-color','$background-6',0,''),(15843,4960,'115129','watch-mobile','padding-top','20',0,''),(15844,4960,'115129','watch-mobile','padding-left','10',0,''),(15845,4960,'115129','watch-mobile','padding-right','10',0,''),(15846,4960,'115129','watch-mobile','padding-bottom','20',0,''),(15847,4960,'115129','watch-mobile','font-size','14',0,''),(15848,4961,'115130','watch-mobile','font-weight','normal',0,''),(15849,4961,'115130','watch-mobile','text-align','right',0,''),(15850,4961,'115130','watch-mobile','font-size','14',0,''),(15851,4961,'115130','watch-mobile','box_align','3',0,''),(15852,4962,'115131','watch-mobile','block_type','1',0,''),(15853,4962,'115131','watch-mobile','padding-top','35',0,''),(15854,4962,'115131','watch-mobile','padding-bottom','35',0,''),(15855,4963,'115132','watch-mobile','block_type','7',0,''),(15856,4963,'115132','watch-mobile','schema','7-2',0,''),(15857,4964,'115133','watch-mobile','block_type','1',0,''),(15858,4964,'115133','watch-mobile','style_class','blog_list_content',0,''),(15859,4966,'115135','watch-mobile','text-align','center',0,''),(15860,4967,'115136','watch-mobile','aria_name','blogsidebar',0,''),(15861,4967,'115136','watch-mobile','style_class','blogsidebar',0,''),(15862,4968,'115137','watch-mobile','block_type','1',0,''),(15863,4968,'115137','watch-mobile','padding-top','35',0,''),(15864,4968,'115137','watch-mobile','padding-bottom','35',0,''),(15865,4969,'115138','watch-mobile','block_type','7',0,''),(15866,4969,'115138','watch-mobile','schema','7-1',0,''),(15868,4970,'115139','watch-mobile','block_type','1',0,''),(15869,4970,'115139','watch-mobile','style_class','blog_list_content',0,''),(15870,4971,'115140','watch-mobile','items_on_page','12',0,''),(15871,4971,'115140','watch-mobile','items_cut_off','200',0,''),(15872,4972,'115141','watch-mobile','text-align','center',0,''),(15873,4972,'115141','watch-mobile','hide_parents','1',0,''),(15874,4973,'115142','watch-mobile','aria_name','blogsidebar',0,''),(15875,4973,'115142','watch-mobile','padding-left','35',0,''),(15876,4973,'115142','watch-mobile','style_class','blogsidebar',0,''),(15878,4974,'115143','watch-mobile','banners_group','blog',0,''),(15879,4974,'115143','watch-mobile','margin-bottom','40',0,''),(15880,4975,'115144','watch-mobile','block_type','1',0,''),(15881,4975,'115144','watch-mobile','padding-top','35',0,''),(15882,4975,'115144','watch-mobile','padding-bottom','35',0,''),(15883,4976,'115145','watch-mobile','block_type','7',0,''),(15884,4976,'115145','watch-mobile','schema','7-2',0,''),(15885,4978,'115147','watch-mobile','block_type','1',0,''),(15886,4979,'115148','watch-mobile','text','<div class=\"heading-3\">##TEXT_BLOG_RELATED_PRODUCTS##</div>',0,''),(15887,4980,'115149','watch-mobile','count_products','8',0,''),(15888,4980,'115149','watch-mobile','col_in_row','4',0,''),(15889,4980,'115149','watch-mobile','view_as','carousel',0,''),(15890,4980,'115149','watch-mobile','show_stock','1',0,''),(15891,4980,'115149','watch-mobile','show_description','1',0,''),(15892,4980,'115149','watch-mobile','show_properties','1',0,''),(15893,4980,'115149','watch-mobile','show_rating','1',0,''),(15894,4980,'115149','watch-mobile','show_rating_counts','1',0,''),(15895,4980,'115149','watch-mobile','show_qty_input','1',0,''),(15896,4980,'115149','watch-mobile','show_wishlist_button','1',0,''),(15897,4980,'115149','watch-mobile','show_compare','1',0,''),(15901,4980,'115149','watch-mobile','listing_type','productListing',0,''),(15902,4980,'115149','watch-mobile','hide_parents','2',0,''),(15903,4981,'115150','watch-mobile','block_type','1',0,''),(15904,4981,'115150','watch-mobile','style_class','blog-white-bg',0,''),(15905,4981,'115150','watch-mobile','padding-bottom','20',0,''),(15906,4985,'115154','watch-mobile','block_type','1',0,''),(15907,4985,'115154','watch-mobile','padding-top','20',0,''),(15908,4985,'115154','watch-mobile','margin-top','20',0,''),(15909,4985,'115154','watch-mobile','border-top-width','1',0,''),(15910,4985,'115154','watch-mobile','border-top-color','$border-color-1',0,''),(15911,4985,'115154','watch-mobile','clear','both',0,''),(15912,4986,'115155','watch-mobile','box_align','4',0,''),(15913,4986,'115155','watch-mobile','text-align','center',0,''),(15914,4987,'115156','watch-mobile','text-align','center',0,''),(15915,4988,'115157','watch-mobile','aria_name','blogsidebar',0,''),(15916,4988,'115157','watch-mobile','style_class','blogsidebar',0,''),(15917,4989,'115158','watch-mobile','block_type','1',0,''),(15918,4989,'115158','watch-mobile','padding-top','35',0,''),(15919,4989,'115158','watch-mobile','padding-bottom','35',0,''),(15920,4990,'115159','watch-mobile','block_type','7',0,''),(15921,4990,'115159','watch-mobile','schema','7-2',0,''),(15922,4991,'115160','watch-mobile','block_type','1',0,''),(15923,4991,'115160','watch-mobile','style_class','blog_list_content',0,''),(15924,4993,'115162','watch-mobile','text-align','center',0,''),(15925,4993,'115162','watch-mobile','hide_parents','1',0,''),(15926,4994,'115163','watch-mobile','aria_name','blogsidebar',0,''),(15927,4994,'115163','watch-mobile','style_class','blogsidebar',0,''),(15928,4995,'115164','watch-mobile','block_type','1',0,''),(15929,4997,'115166','watch-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(15930,4998,'115167','watch-mobile','block_type','1',0,''),(15931,4999,'115168','watch-mobile','block_type','2',0,''),(15932,4999,'115168','watch-mobile','margin-bottom','20',0,''),(15933,5000,'115169','watch-mobile','block_type','1',0,''),(15934,5000,'115169','watch-mobile','padding-right','20',0,''),(15935,5001,'115170','watch-mobile','field','50',0,''),(15936,5002,'115171','watch-mobile','field','49',0,''),(15937,5003,'115172','watch-mobile','block_type','2',0,''),(15938,5005,'115174','watch-mobile','float','right',0,''),(15939,5005,'115174','watch-mobile','clear','none',0,''),(15940,5006,'115175','watch-mobile','float','right',0,''),(15941,5006,'115175','watch-mobile','margin-left','20',0,''),(15942,5007,'115176','watch-mobile','block_type','2',0,''),(15943,5007,'115176','watch-mobile','margin-bottom','20',0,''),(15944,5008,'115177','watch-mobile','block_type','1',0,''),(15945,5008,'115177','watch-mobile','padding-right','20',0,''),(15946,5009,'115178','watch-mobile','field','66',0,''),(15947,5010,'115179','watch-mobile','block_type','1',0,''),(15948,5010,'115179','watch-mobile','padding-left','20',0,''),(15949,5011,'115180','watch-mobile','field','67',0,''),(15950,5012,'115181','watch-mobile','text','<div class=\"heading-2\">##TRADE_REFERENCES##</div>',0,''),(15951,5012,'115181','watch-mobile','text-align','center',0,''),(15952,5013,'115182','watch-mobile','text','<div class=\"heading-2\">##BANK_ACCOUNT_DETAILS##</div>',0,''),(15953,5013,'115182','watch-mobile','text-align','center',0,''),(15954,5014,'115183','watch-mobile','text','<div class=\"heading-2\">##TEXT_DECLARATION##</div>',0,''),(15955,5014,'115183','watch-mobile','text-align','center',0,''),(15956,5015,'115184','watch-mobile','block_type','2',0,''),(15957,5015,'115184','watch-mobile','margin-bottom','20',0,''),(15958,5016,'115185','watch-mobile','block_type','1',0,''),(15959,5016,'115185','watch-mobile','padding-right','20',0,''),(15960,5017,'115186','watch-mobile','field','62',0,''),(15961,5018,'115187','watch-mobile','field','60',0,''),(15962,5019,'115188','watch-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 1</div>',0,''),(15963,5020,'115189','watch-mobile','field','61',0,''),(15964,5021,'115190','watch-mobile','block_type','1',0,''),(15965,5021,'115190','watch-mobile','padding-left','20',0,''),(15966,5022,'115191','watch-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 2</div>',0,''),(15967,5023,'115192','watch-mobile','field','64',0,''),(15968,5024,'115193','watch-mobile','field','63',0,''),(15969,5025,'115194','watch-mobile','field','65',0,''),(15970,5026,'115195','watch-mobile','block_type','2',0,''),(15971,5026,'115195','watch-mobile','margin-bottom','20',0,''),(15972,5027,'115196','watch-mobile','block_type','1',0,''),(15973,5027,'115196','watch-mobile','padding-right','20',0,''),(15974,5028,'115197','watch-mobile','field','52',0,''),(15975,5029,'115198','watch-mobile','field','51',0,''),(15976,5030,'115199','watch-mobile','block_type','2',0,''),(15977,5031,'115200','watch-mobile','block_type','1',0,''),(15978,5031,'115200','watch-mobile','padding-right','20',0,''),(15979,5032,'115201','watch-mobile','group','15',0,''),(15980,5033,'115202','watch-mobile','text','<div class=\"heading-3\">##CATEGORY_COMPANY##</div>',0,''),(15981,5035,'115204','watch-mobile','block_type','2',0,''),(15982,5036,'115205','watch-mobile','field','68',0,''),(15983,5036,'115205','watch-mobile','padding-right','10',0,''),(15984,5037,'115206','watch-mobile','block_type','2',0,''),(15985,5037,'115206','watch-mobile','border-bottom-width','1',0,''),(15986,5037,'115206','watch-mobile','border-bottom-color','$border-color-1',0,''),(15987,5037,'115206','watch-mobile','padding-bottom','10',0,''),(15988,5037,'115206','watch-mobile','margin-bottom','20',0,''),(15989,5038,'115207','watch-mobile','block_type','1',0,''),(15990,5038,'115207','watch-mobile','padding-right','10',0,''),(15991,5039,'115208','watch-mobile','field','69',0,''),(15992,5040,'115209','watch-mobile','field','75',0,''),(15993,5041,'115210','watch-mobile','field','71',0,''),(15994,5042,'115211','watch-mobile','field','73',0,''),(15995,5043,'115212','watch-mobile','block_type','1',0,''),(15996,5043,'115212','watch-mobile','padding-left','10',0,''),(15997,5044,'115213','watch-mobile','field','76',0,''),(15998,5045,'115214','watch-mobile','field','74',0,''),(15999,5046,'115215','watch-mobile','field','72',0,''),(16000,5047,'115216','watch-mobile','field','70',0,''),(16001,5048,'115217','watch-mobile','block_type','1',0,''),(16002,5048,'115217','watch-mobile','padding-left','20',0,''),(16003,5049,'115218','watch-mobile','group','16',0,''),(16004,5050,'115219','watch-mobile','block_type','2',0,''),(16005,5051,'115220','watch-mobile','block_type','1',0,''),(16006,5051,'115220','watch-mobile','padding-right','10',0,''),(16007,5052,'115221','watch-mobile','field','77',0,''),(16008,5053,'115222','watch-mobile','field','79',0,''),(16009,5054,'115223','watch-mobile','block_type','1',0,''),(16010,5054,'115223','watch-mobile','padding-left','10',0,''),(16011,5055,'115224','watch-mobile','field','78',0,''),(16012,5056,'115225','watch-mobile','block_type','2',0,''),(16013,5057,'115226','watch-mobile','block_type','1',0,''),(16014,5057,'115226','watch-mobile','padding-right','10',0,''),(16015,5058,'115227','watch-mobile','field','82',0,''),(16016,5059,'115228','watch-mobile','field','80',0,''),(16017,5060,'115229','watch-mobile','field','84',0,''),(16018,5061,'115230','watch-mobile','block_type','1',0,''),(16019,5061,'115230','watch-mobile','padding-left','10',0,''),(16020,5062,'115231','watch-mobile','field','83',0,''),(16021,5063,'115232','watch-mobile','field','81',0,''),(16022,5064,'115233','watch-mobile','field','85',0,''),(16023,5065,'115234','watch-mobile','text','<div class=\"heading-3\">##OWNERS_DETAILS##</div>',0,''),(16024,5066,'115235','watch-mobile','block_type','2',0,''),(16025,5066,'115235','watch-mobile','margin-bottom','20',0,''),(16026,5067,'115236','watch-mobile','block_type','1',0,''),(16027,5067,'115236','watch-mobile','padding-right','20',0,''),(16028,5068,'115237','watch-mobile','field','53',0,''),(16029,5069,'115238','watch-mobile','field','54',0,''),(16030,5070,'115239','watch-mobile','block_type','1',0,''),(16031,5070,'115239','watch-mobile','padding-left','20',0,''),(16032,5071,'115240','watch-mobile','field','55',0,''),(16033,5072,'115241','watch-mobile','text','<div class=\"heading-2\">##TEXT_CUSTOMER_DETAILS##</div>',0,''),(16034,5072,'115241','watch-mobile','text-align','center',0,''),(16035,5073,'115242','watch-mobile','block_type','2',0,''),(16036,5073,'115242','watch-mobile','margin-bottom','20',0,''),(16037,5074,'115243','watch-mobile','block_type','1',0,''),(16038,5074,'115243','watch-mobile','padding-right','20',0,''),(16039,5075,'115244','watch-mobile','field','56',0,''),(16040,5076,'115245','watch-mobile','field','57',0,''),(16041,5077,'115246','watch-mobile','block_type','1',0,''),(16042,5077,'115246','watch-mobile','padding-left','20',0,''),(16043,5078,'115247','watch-mobile','field','58',0,''),(16044,5079,'115248','watch-mobile','field','59',0,''),(16045,5080,'115249','watch-mobile','text','<h1>##TRADE_FORM##</h1>',0,''),(16046,5081,'115250','watch-mobile','text','<div class=\"heading-2\">##DISCOUNT##</div>',0,''),(16047,5081,'115250','watch-mobile','text-align','center',0,''),(16048,5082,'115251','watch-mobile','block_type','1',0,''),(16049,5083,'115252','watch-mobile','block_type','6',0,''),(16050,5084,'115253','watch-mobile','text','Telephone No.',0,''),(16051,5084,'115253','watch-mobile','text-align','right',0,''),(16052,5085,'115254','watch-mobile','field','79',0,''),(16053,5085,'115254','watch-mobile','border-bottom-width','1',0,''),(16054,5085,'115254','watch-mobile','border-bottom-color','$border-color-6',0,''),(16055,5085,'115254','watch-mobile','padding-left','10',0,''),(16056,5086,'115255','watch-mobile','block_type','6',0,''),(16057,5087,'115256','watch-mobile','text','Address',0,''),(16058,5087,'115256','watch-mobile','text-align','right',0,''),(16059,5088,'115257','watch-mobile','fields','company_street_address, company_suburb, company_city',0,''),(16060,5088,'115257','watch-mobile','padding-left','10',0,''),(16061,5088,'115257','watch-mobile','border-bottom-width','1',0,''),(16062,5088,'115257','watch-mobile','border-bottom-color','$border-color-6',0,''),(16063,5089,'115258','watch-mobile','block_type','6',0,''),(16064,5090,'115259','watch-mobile','text','Postcode',0,''),(16065,5090,'115259','watch-mobile','text-align','right',0,''),(16066,5091,'115260','watch-mobile','field','80',0,''),(16067,5091,'115260','watch-mobile','border-bottom-width','1',0,''),(16068,5091,'115260','watch-mobile','border-bottom-color','$border-color-6',0,''),(16069,5091,'115260','watch-mobile','padding-left','10',0,''),(16070,5092,'115261','watch-mobile','block_type','6',0,''),(16071,5093,'115262','watch-mobile','text','Address',0,''),(16072,5093,'115262','watch-mobile','text-align','right',0,''),(16073,5094,'115263','watch-mobile','fields','oner_street_address, owner_suburb, owner_city',0,''),(16074,5094,'115263','watch-mobile','padding-left','10',0,''),(16075,5094,'115263','watch-mobile','border-bottom-width','1',0,''),(16076,5094,'115263','watch-mobile','border-bottom-color','$border-color-6',0,''),(16077,5095,'115264','watch-mobile','block_type','6',0,''),(16078,5095,'115264','watch-mobile','margin-top','20',0,''),(16079,5096,'115265','watch-mobile','text','Owner’s Name',0,''),(16080,5096,'115265','watch-mobile','text-align','right',0,''),(16081,5097,'115266','watch-mobile','fields','owner_firstname owner_lastname',0,''),(16082,5097,'115266','watch-mobile','padding-left','10',0,''),(16083,5097,'115266','watch-mobile','border-bottom-width','1',0,''),(16084,5097,'115266','watch-mobile','border-bottom-color','$border-color-6',0,''),(16085,5098,'115267','watch-mobile','block_type','6',0,''),(16086,5099,'115268','watch-mobile','text','Email',0,''),(16087,5099,'115268','watch-mobile','text-align','right',0,''),(16088,5100,'115269','watch-mobile','field','70',0,''),(16089,5100,'115269','watch-mobile','border-bottom-width','1',0,''),(16090,5100,'115269','watch-mobile','border-bottom-color','$border-color-6',0,''),(16091,5100,'115269','watch-mobile','padding-left','10',0,''),(16092,5101,'115270','watch-mobile','block_type','6',0,''),(16093,5101,'115270','watch-mobile','padding-bottom','20',0,''),(16094,5102,'115271','watch-mobile','text','Telephone No.',0,''),(16095,5102,'115271','watch-mobile','text-align','right',0,''),(16096,5103,'115272','watch-mobile','block_type','11',0,''),(16097,5104,'115273','watch-mobile','field','69',0,''),(16098,5104,'115273','watch-mobile','border-bottom-width','1',0,''),(16099,5104,'115273','watch-mobile','border-bottom-color','$border-color-6',0,''),(16100,5104,'115273','watch-mobile','padding-left','10',0,''),(16101,5105,'115274','watch-mobile','block_type','5',0,''),(16102,5106,'115275','watch-mobile','text','Fax No.',0,''),(16103,5106,'115275','watch-mobile','text-align','right',0,''),(16104,5107,'115276','watch-mobile','field','51',0,''),(16105,5107,'115276','watch-mobile','padding-left','10',0,''),(16106,5107,'115276','watch-mobile','border-bottom-width','1',0,''),(16107,5107,'115276','watch-mobile','border-bottom-color','$border-color-6',0,''),(16108,5108,'115277','watch-mobile','block_type','1',0,''),(16109,5109,'115278','watch-mobile','background-color','$background-1',0,''),(16110,5109,'115278','watch-mobile','color','$color-font-1',0,''),(16111,5109,'115278','watch-mobile','font-size','20',0,''),(16112,5109,'115278','watch-mobile','text','Customer Details',0,''),(16113,5109,'115278','watch-mobile','padding-left','10',0,''),(16114,5109,'115278','watch-mobile','padding-right','10',0,''),(16115,5110,'115279','watch-mobile','block_type','2',0,''),(16116,5110,'115279','watch-mobile','color','$color-font-1',0,''),(16117,5110,'115279','watch-mobile','background-color','$background-1',0,''),(16118,5111,'115280','watch-mobile','view_item','name',0,''),(16119,5111,'115280','watch-mobile','color','$color-font-1',0,''),(16120,5111,'115280','watch-mobile','font-size','40',0,''),(16121,5112,'115281','watch-mobile','text','New Account Form',0,''),(16122,5112,'115281','watch-mobile','font-size','20',0,''),(16123,5112,'115281','watch-mobile','color','$color-font-1',0,''),(16124,5112,'115281','watch-mobile','padding-top','20',0,''),(16125,5113,'115282','watch-mobile','block_type','2',0,''),(16126,5114,'115283','watch-mobile','block_type','2',0,''),(16127,5114,'115283','watch-mobile','padding-top','5',0,''),(16128,5115,'115284','watch-mobile','block_type','10',0,''),(16129,5116,'115285','watch-mobile','text','Limited Company',0,''),(16130,5116,'115285','watch-mobile','font-size','16',0,''),(16131,5117,'115286','watch-mobile','field','49',0,''),(16132,5117,'115286','watch-mobile','padding-left','5',0,''),(16133,5118,'115287','watch-mobile','block_type','10',0,''),(16134,5119,'115288','watch-mobile','text','Sole Trader',0,''),(16135,5119,'115288','watch-mobile','text-align','center',0,''),(16136,5120,'115289','watch-mobile','field','50',0,''),(16137,5120,'115289','watch-mobile','padding-left','5',0,''),(16138,5121,'115290','watch-mobile','block_type','5',0,''),(16139,5122,'115291','watch-mobile','view_item','data_format',0,''),(16140,5122,'115291','watch-mobile','data_format_content','##STREET_ADDRESS##, ##SUBURB##,\n##CITY##, ##POSTCODE##\nTel: ##TELEPHONE##\nEmail: ##EMAIL_ADDRESS##\n',0,''),(16141,5122,'115291','watch-mobile','font-size','14',0,''),(16142,5123,'115292','watch-mobile','block_type','6',0,''),(16143,5124,'115293','watch-mobile','text','Postcode',0,''),(16144,5124,'115293','watch-mobile','text-align','right',0,''),(16145,5125,'115294','watch-mobile','field','71',0,''),(16146,5125,'115294','watch-mobile','border-bottom-width','1',0,''),(16147,5125,'115294','watch-mobile','border-bottom-color','$border-color-6',0,''),(16148,5125,'115294','watch-mobile','padding-left','10',0,''),(16149,5126,'115295','watch-mobile','block_type','6',0,''),(16150,5127,'115296','watch-mobile','text','Business Name',0,''),(16151,5127,'115296','watch-mobile','text-align','right',0,''),(16152,5128,'115297','watch-mobile','field','68',0,''),(16153,5128,'115297','watch-mobile','border-bottom-width','1',0,''),(16154,5128,'115297','watch-mobile','border-bottom-color','$border-color-6',0,''),(16155,5128,'115297','watch-mobile','padding-left','10',0,''),(16156,5129,'115298','watch-mobile','block_type','6',0,''),(16157,5129,'115298','watch-mobile','padding-bottom','20',0,''),(16158,5130,'115299','watch-mobile','text','Nature of Business',0,''),(16159,5130,'115299','watch-mobile','text-align','right',0,''),(16160,5131,'115300','watch-mobile','field','52',0,''),(16161,5131,'115300','watch-mobile','border-bottom-width','1',0,''),(16162,5131,'115300','watch-mobile','border-bottom-color','$border-color-6',0,''),(16163,5131,'115300','watch-mobile','padding-left','10',0,''),(16164,5132,'115301','watch-mobile','block_type','6',0,''),(16165,5133,'115302','watch-mobile','text','Bank Name',0,''),(16166,5133,'115302','watch-mobile','text-align','right',0,''),(16167,5133,'115302','watch-mobile','font-size','16',0,''),(16168,5134,'115303','watch-mobile','field','53',0,''),(16169,5134,'115303','watch-mobile','border-bottom-width','1',0,''),(16170,5134,'115303','watch-mobile','border-bottom-color','$border-color-6',0,''),(16171,5134,'115303','watch-mobile','padding-left','10',0,''),(16172,5135,'115304','watch-mobile','block_type','1',0,''),(16173,5135,'115304','watch-mobile','padding-top','20',0,''),(16174,5135,'115304','watch-mobile','padding-bottom','10',0,''),(16175,5136,'115305','watch-mobile','background-color','$background-1',0,''),(16176,5136,'115305','watch-mobile','color','$color-font-1',0,''),(16177,5136,'115305','watch-mobile','font-size','20',0,''),(16178,5136,'115305','watch-mobile','text','Discount (%)',0,''),(16179,5136,'115305','watch-mobile','padding-left','10',0,''),(16180,5136,'115305','watch-mobile','padding-right','10',0,''),(16181,5137,'115306','watch-mobile','block_type','1',0,''),(16182,5137,'115306','watch-mobile','padding-bottom','10',0,''),(16183,5138,'115307','watch-mobile','background-color','$background-1',0,''),(16184,5138,'115307','watch-mobile','color','$color-font-1',0,''),(16185,5138,'115307','watch-mobile','font-size','20',0,''),(16186,5138,'115307','watch-mobile','text','Bank Account Details',0,''),(16187,5138,'115307','watch-mobile','padding-left','10',0,''),(16188,5138,'115307','watch-mobile','padding-right','10',0,''),(16189,5139,'115308','watch-mobile','block_type','6',0,''),(16190,5139,'115308','watch-mobile','padding-bottom','20',0,''),(16191,5140,'115309','watch-mobile','text','Account No',0,''),(16192,5140,'115309','watch-mobile','text-align','right',0,''),(16193,5141,'115310','watch-mobile','field','54',0,''),(16194,5141,'115310','watch-mobile','border-bottom-width','1',0,''),(16195,5141,'115310','watch-mobile','border-bottom-color','$border-color-6',0,''),(16196,5141,'115310','watch-mobile','padding-left','10',0,''),(16197,5142,'115311','watch-mobile','block_type','6',0,''),(16198,5143,'115312','watch-mobile','text','Address',0,''),(16199,5143,'115312','watch-mobile','text-align','right',0,''),(16200,5144,'115313','watch-mobile','field','55',0,''),(16201,5144,'115313','watch-mobile','border-bottom-width','1',0,''),(16202,5144,'115313','watch-mobile','border-bottom-color','$border-color-6',0,''),(16203,5144,'115313','watch-mobile','padding-left','10',0,''),(16204,5145,'115314','watch-mobile','block_type','14',0,''),(16205,5145,'115314','watch-mobile','padding-bottom','20',0,''),(16206,5146,'115315','watch-mobile','text','33.33% Sale or Return',0,''),(16207,5146,'115315','watch-mobile','text-align','right',0,''),(16208,5146,'115315','watch-mobile','font-size','16',0,''),(16209,5147,'115316','watch-mobile','block_type','13',0,''),(16210,5148,'115317','watch-mobile','field','56',0,''),(16211,5148,'115317','watch-mobile','padding-left','10',0,''),(16212,5149,'115318','watch-mobile','text','35% Firm',0,''),(16213,5149,'115318','watch-mobile','text-align','right',0,''),(16214,5150,'115319','watch-mobile','field','58',0,''),(16215,5150,'115319','watch-mobile','padding-left','10',0,''),(16216,5151,'115320','watch-mobile','block_type','10',0,''),(16217,5152,'115321','watch-mobile','block_type','6',0,''),(16218,5153,'115322','watch-mobile','text','Address',0,''),(16219,5153,'115322','watch-mobile','text-align','right',0,''),(16220,5154,'115323','watch-mobile','field','61',0,''),(16221,5154,'115323','watch-mobile','border-bottom-width','1',0,''),(16222,5154,'115323','watch-mobile','border-bottom-color','$border-color-6',0,''),(16223,5154,'115323','watch-mobile','padding-left','10',0,''),(16224,5155,'115324','watch-mobile','block_type','1',0,''),(16225,5155,'115324','watch-mobile','padding-bottom','10',0,''),(16226,5156,'115325','watch-mobile','background-color','$background-1',0,''),(16227,5156,'115325','watch-mobile','color','$color-font-1',0,''),(16228,5156,'115325','watch-mobile','font-size','20',0,''),(16229,5156,'115325','watch-mobile','text','Trade References',0,''),(16230,5156,'115325','watch-mobile','padding-left','10',0,''),(16231,5156,'115325','watch-mobile','padding-right','10',0,''),(16232,5157,'115326','watch-mobile','block_type','1',0,''),(16233,5158,'115327','watch-mobile','text','I would like to open a trade account with Vladislav B. Malyshev and agree to abide by their General Terms & Conditions –\na signed copy of which is returned to them with this form in the supplied SAE. I have retained a copy for my reference. I\nam authorised to sign on behalf of the company I represent.',0,''),(16234,5158,'115327','watch-mobile','font-size','15',0,''),(16235,5158,'115327','watch-mobile','padding-left','10',0,''),(16236,5158,'115327','watch-mobile','padding-right','10',0,''),(16237,5159,'115328','watch-mobile','block_type','6',0,''),(16238,5159,'115328','watch-mobile','padding-bottom','20',0,''),(16239,5160,'115329','watch-mobile','text','Telephone No.',0,''),(16240,5160,'115329','watch-mobile','text-align','right',0,''),(16241,5161,'115330','watch-mobile','field','62',0,''),(16242,5161,'115330','watch-mobile','border-bottom-width','1',0,''),(16243,5161,'115330','watch-mobile','border-bottom-color','$border-color-6',0,''),(16244,5161,'115330','watch-mobile','padding-left','10',0,''),(16245,5162,'115331','watch-mobile','block_type','1',0,''),(16246,5162,'115331','watch-mobile','padding-bottom','10',0,''),(16247,5163,'115332','watch-mobile','background-color','$background-1',0,''),(16248,5163,'115332','watch-mobile','color','$color-font-1',0,''),(16249,5163,'115332','watch-mobile','font-size','20',0,''),(16250,5163,'115332','watch-mobile','text','Customer Details',0,''),(16251,5163,'115332','watch-mobile','padding-left','10',0,''),(16252,5163,'115332','watch-mobile','padding-right','10',0,''),(16253,5164,'115333','watch-mobile','block_type','6',0,''),(16254,5165,'115334','watch-mobile','text','Name',0,''),(16255,5165,'115334','watch-mobile','text-align','right',0,''),(16256,5165,'115334','watch-mobile','font-size','16',0,''),(16257,5166,'115335','watch-mobile','field','60',0,''),(16258,5166,'115335','watch-mobile','border-bottom-width','1',0,''),(16259,5166,'115335','watch-mobile','border-bottom-color','$border-color-6',0,''),(16260,5166,'115335','watch-mobile','padding-left','10',0,''),(16261,5167,'115336','watch-mobile','block_type','14',0,''),(16262,5168,'115337','watch-mobile','text','Signed',0,''),(16263,5168,'115337','watch-mobile','text-align','right',0,''),(16264,5169,'115338','watch-mobile','text','&nbsp;',0,''),(16265,5169,'115338','watch-mobile','border-bottom-width','1',0,''),(16266,5169,'115338','watch-mobile','border-bottom-color','$border-color-6',0,''),(16267,5170,'115339','watch-mobile','text','Date',0,''),(16268,5170,'115339','watch-mobile','text-align','right',0,''),(16269,5171,'115340','watch-mobile','text','&nbsp;',0,''),(16270,5171,'115340','watch-mobile','border-bottom-width','1',0,''),(16271,5171,'115340','watch-mobile','border-bottom-color','$border-color-6',0,''),(16272,5172,'115341','watch-mobile','block_type','14',0,''),(16273,5173,'115342','watch-mobile','text','Name in Full',0,''),(16274,5173,'115342','watch-mobile','text-align','right',0,''),(16275,5174,'115343','watch-mobile','field','66',0,''),(16276,5174,'115343','watch-mobile','padding-left','10',0,''),(16277,5174,'115343','watch-mobile','border-bottom-width','1',0,''),(16278,5174,'115343','watch-mobile','border-bottom-color','$border-color-6',0,''),(16279,5175,'115344','watch-mobile','text','Position',0,''),(16280,5175,'115344','watch-mobile','text-align','right',0,''),(16281,5176,'115345','watch-mobile','field','67',0,''),(16282,5176,'115345','watch-mobile','border-bottom-width','1',0,''),(16283,5176,'115345','watch-mobile','border-bottom-color','$border-color-6',0,''),(16284,5176,'115345','watch-mobile','padding-left','10',0,''),(16285,5177,'115346','watch-mobile','block_type','1',0,''),(16286,5178,'115347','watch-mobile','text','Scottish books of exceptional value',0,''),(16287,5178,'115347','watch-mobile','font-size','20',0,''),(16288,5178,'115347','watch-mobile','text-align','center',0,''),(16289,5178,'115347','watch-mobile','padding-top','20',0,''),(16290,5179,'115348','watch-mobile','block_type','1',0,''),(16291,5180,'115349','watch-mobile','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(16292,5180,'115349','watch-mobile','padding-top','100',0,''),(16293,5180,'115349','watch-mobile','margin-bottom','100',0,''),(16294,5180,'115349','watch-mobile','text-align','center',0,''),(16295,5180,'115349','watch-mobile','font-size','20',0,''),(16296,5181,'115350','watch-mobile','block_type','1',0,''),(16297,5181,'115350','watch-mobile','background-color','$background-6',0,''),(16298,5181,'115350','watch-mobile','padding-bottom','30',0,''),(16299,5182,'115351','watch-mobile','block_type','4',0,''),(16300,5182,'115351','watch-mobile','schema','4-2',0,''),(16301,5183,'115352','watch-mobile','block_type','1',0,''),(16302,5183,'115352','watch-mobile','padding-right','40',0,''),(16304,5184,'115353','watch-mobile','block_type','2',0,''),(16305,5184,'115353','watch-mobile','margin-bottom','20',0,''),(16306,5184,'115353','watch-mobile','schema','2-2',0,''),(16307,5184,'115353','watch-mobile','background-color','$background-7',0,''),(16308,5185,'115354','watch-mobile','block_type','1',0,''),(16309,5185,'115354','watch-mobile','border-right-width','20',0,''),(16310,5185,'115354','watch-mobile','border-right-color','$border-color-1',0,''),(16311,5185,'115354','watch-mobile','margin-right','-10',0,''),(16312,5185,'115354','watch-mobile','padding-right','30',0,''),(16313,5185,'115354','watch-mobile','padding-top','20',0,''),(16314,5185,'115354','watch-mobile','padding-left','30',0,''),(16315,5185,'115354','watch-mobile','padding-bottom','20',0,''),(16318,5185,'115354','watch-mobile','margin-bottom','20',0,''),(16321,5186,'115355','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(16322,5186,'115355','watch-mobile','clear','none',0,''),(16323,5187,'115356','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(16324,5187,'115356','watch-mobile','clear','none',0,''),(16325,5188,'115357','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(16326,5190,'115359','watch-mobile','margin-bottom','20',0,''),(16327,5194,'115363','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(16328,5194,'115363','watch-mobile','padding-top','20',0,''),(16329,5195,'115364','watch-mobile','block_type','1',0,''),(16330,5195,'115364','watch-mobile','padding-left','30',0,''),(16331,5195,'115364','watch-mobile','border-left-width','20',0,''),(16332,5195,'115364','watch-mobile','border-left-color','$border-color-1',0,''),(16333,5195,'115364','watch-mobile','margin-left','-10',0,''),(16334,5195,'115364','watch-mobile','padding-right','30',0,''),(16335,5195,'115364','watch-mobile','padding-top','20',0,''),(16336,5195,'115364','watch-mobile','padding-bottom','20',0,''),(16338,5196,'115365','watch-mobile','margin-bottom','20',0,''),(16339,5198,'115367','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(16340,5199,'115368','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(16341,5199,'115368','watch-mobile','clear','none',0,''),(16342,5200,'115369','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(16343,5200,'115369','watch-mobile','clear','none',0,''),(16344,5201,'115370','watch-mobile','block_type','1',0,''),(16345,5201,'115370','watch-mobile','padding-right','30',0,''),(16346,5201,'115370','watch-mobile','background-color','$background-7',0,''),(16347,5201,'115370','watch-mobile','padding-top','20',0,''),(16348,5201,'115370','watch-mobile','padding-left','30',0,''),(16349,5201,'115370','watch-mobile','padding-bottom','20',0,''),(16352,5203,'115372','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(16353,5204,'115373','watch-mobile','block_type','1',0,''),(16354,5204,'115373','watch-mobile','padding-top','20',0,''),(16355,5204,'115373','watch-mobile','padding-left','20',0,''),(16356,5204,'115373','watch-mobile','padding-right','20',0,''),(16357,5204,'115373','watch-mobile','padding-bottom','20',0,''),(16358,5204,'115373','watch-mobile','background-color','$background-7',0,''),(16359,5204,'115373','watch-mobile','style_class','order-summary',0,''),(16360,5205,'115374','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(16361,5209,'115378','watch-mobile','block_type','1',0,''),(16362,5209,'115378','watch-mobile','background-color','$background-6',0,''),(16363,5209,'115378','watch-mobile','padding-bottom','30',0,''),(16364,5210,'115379','watch-mobile','block_type','4',0,''),(16365,5210,'115379','watch-mobile','schema','4-2',0,''),(16366,5211,'115380','watch-mobile','block_type','1',0,''),(16367,5211,'115380','watch-mobile','padding-right','40',0,''),(16369,5212,'115381','watch-mobile','block_type','1',0,''),(16370,5212,'115381','watch-mobile','padding-right','30',0,''),(16371,5212,'115381','watch-mobile','background-color','$background-7',0,''),(16372,5212,'115381','watch-mobile','padding-top','20',0,''),(16373,5212,'115381','watch-mobile','padding-left','30',0,''),(16374,5212,'115381','watch-mobile','padding-bottom','20',0,''),(16377,5213,'115382','watch-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(16378,5215,'115384','watch-mobile','block_type','2',0,''),(16379,5215,'115384','watch-mobile','margin-bottom','20',0,''),(16380,5215,'115384','watch-mobile','schema','2-2',0,''),(16381,5215,'115384','watch-mobile','background-color','$background-7',0,''),(16382,5216,'115385','watch-mobile','block_type','1',0,''),(16383,5216,'115385','watch-mobile','border-right-width','20',0,''),(16384,5216,'115385','watch-mobile','border-right-color','$border-color-1',0,''),(16385,5216,'115385','watch-mobile','margin-right','-10',0,''),(16386,5216,'115385','watch-mobile','padding-right','30',0,''),(16387,5216,'115385','watch-mobile','padding-top','20',0,''),(16388,5216,'115385','watch-mobile','padding-left','30',0,''),(16389,5216,'115385','watch-mobile','padding-bottom','20',0,''),(16392,5216,'115385','watch-mobile','margin-bottom','20',0,''),(16395,5219,'115388','watch-mobile','margin-bottom','20',0,''),(16396,5220,'115389','watch-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(16397,5220,'115389','watch-mobile','padding-top','20',0,''),(16398,5222,'115391','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(16399,5222,'115391','watch-mobile','clear','none',0,''),(16400,5224,'115393','watch-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(16401,5224,'115393','watch-mobile','clear','none',0,''),(16402,5225,'115394','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(16403,5226,'115395','watch-mobile','block_type','1',0,''),(16404,5226,'115395','watch-mobile','padding-left','30',0,''),(16405,5226,'115395','watch-mobile','border-left-width','20',0,''),(16406,5226,'115395','watch-mobile','border-left-color','$border-color-1',0,''),(16407,5226,'115395','watch-mobile','margin-left','-10',0,''),(16408,5226,'115395','watch-mobile','padding-right','30',0,''),(16409,5226,'115395','watch-mobile','padding-top','20',0,''),(16410,5226,'115395','watch-mobile','padding-bottom','20',0,''),(16412,5227,'115396','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(16413,5227,'115396','watch-mobile','clear','none',0,''),(16414,5228,'115397','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(16415,5229,'115398','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(16416,5229,'115398','watch-mobile','clear','none',0,''),(16417,5230,'115399','watch-mobile','margin-bottom','20',0,''),(16418,5232,'115401','watch-mobile','block_type','1',0,''),(16419,5232,'115401','watch-mobile','padding-top','20',0,''),(16420,5232,'115401','watch-mobile','padding-left','20',0,''),(16421,5232,'115401','watch-mobile','padding-right','20',0,''),(16422,5232,'115401','watch-mobile','padding-bottom','20',0,''),(16423,5232,'115401','watch-mobile','background-color','$background-7',0,''),(16424,5232,'115401','watch-mobile','style_class','order-summary',0,''),(16425,5234,'115403','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(16426,5237,'115406','watch-mobile','block_type','1',0,''),(16427,5237,'115406','watch-mobile','background_image','themes/watch-mobile/img/wedding-registry-page-1-1.jpg',0,''),(16428,5237,'115406','watch-mobile','background-position','top center',0,''),(16429,5237,'115406','watch-mobile','background-repeat','no-repeat',0,''),(16430,5237,'115406','watch-mobile','background-size','cover',0,''),(16431,5237,'115406','watch-mobile','padding-top','50',0,''),(16432,5237,'115406','watch-mobile','padding-bottom','50',0,''),(16433,5237,'115406','watch-mobile','margin-bottom','30',0,''),(16434,5238,'115407','watch-mobile','background-color','$background-7',0,''),(16435,5238,'115407','watch-mobile','block_type','1',0,''),(16436,5238,'115407','watch-mobile','max-width','700',0,''),(16437,5238,'115407','watch-mobile','margin_left_measure','auto',0,''),(16438,5238,'115407','watch-mobile','margin_right_measure','auto',0,''),(16439,5239,'115408','watch-mobile','text-align','center',0,''),(16440,5239,'115408','watch-mobile','margin-bottom','30',0,''),(16441,5240,'115409','watch-mobile','padding-bottom','30',0,''),(16442,5240,'115409','watch-mobile','text-align','center',0,''),(16443,5241,'115410','watch-mobile','heading_type','h1',0,''),(16444,5242,'115411','watch-mobile','block_type','13',0,''),(16445,5242,'115411','watch-mobile','margin-bottom','20',0,''),(16446,5242,'115411','watch-mobile','schema','13-2',0,''),(16447,5243,'115412','watch-mobile','position','relative',0,''),(16448,5243,'115412','watch-mobile','margin-top','-100',0,''),(16450,5244,'115413','watch-mobile','font-family','$font-1',0,''),(16451,5244,'115413','watch-mobile','font-size','30',0,''),(16452,5244,'115413','watch-mobile','text-transform','uppercase',0,''),(16453,5244,'115413','watch-mobile','text-align','center',0,''),(16455,5245,'115414','watch-mobile','block_type','1',0,''),(16456,5245,'115414','watch-mobile','float','left',0,''),(16458,5246,'115415','watch-mobile','display','inline-block',0,''),(16459,5246,'115415','watch-mobile','font-weight','700',0,''),(16460,5247,'115416','watch-mobile','clear','none',0,''),(16461,5247,'115416','watch-mobile','padding-left','20',0,''),(16462,5247,'115416','watch-mobile','font-weight','700',0,''),(16463,5247,'115416','watch-mobile','display','inline-block',0,''),(16464,5248,'115417','watch-mobile','font-weight','700',0,''),(16465,5248,'115417','watch-mobile','clear','none',0,''),(16466,5248,'115417','watch-mobile','padding-left','20',0,''),(16467,5248,'115417','watch-mobile','display','inline-block',0,''),(16468,5249,'115418','watch-mobile','font-family','$font-1',0,''),(16469,5249,'115418','watch-mobile','font-size','18',0,''),(16470,5249,'115418','watch-mobile','margin-bottom','10',0,''),(16471,5249,'115418','watch-mobile','text-align','center',0,''),(16472,5250,'115419','watch-mobile','font-weight','700',0,''),(16473,5250,'115419','watch-mobile','text-align','right',0,''),(16474,5250,'115419','watch-mobile','max-width','110',0,''),(16475,5250,'115419','watch-mobile','float','right',0,''),(16476,5251,'115420','watch-mobile','margin-bottom','10',0,''),(16477,5252,'115421','watch-mobile','like_button','1',0,''),(16478,5252,'115421','watch-mobile','text-align','center',0,''),(16479,5252,'115421','watch-mobile','margin-bottom','20',0,''),(16480,5252,'115421','watch-mobile','margin-top','20',0,''),(16481,5252,'115421','watch-mobile','padding-top','30',0,''),(16482,5252,'115421','watch-mobile','border-top-width','1',0,''),(16483,5252,'115421','watch-mobile','border-top-color','$border-color-1',0,''),(16491,5257,'115423','watch-mobile','block_type','1',0,''),(16492,5257,'115423','watch-mobile','padding-top','20',0,''),(16493,5257,'115423','watch-mobile','padding-bottom','20',0,''),(16494,5259,'115425','watch-mobile','padding-top','10',0,''),(16495,5259,'115425','watch-mobile','padding-bottom','10',0,''),(16496,5259,'115425','watch-mobile','border-top-width','1',0,''),(16497,5259,'115425','watch-mobile','border-top-color','$border-color-1',0,''),(16498,5259,'115425','watch-mobile','text-align','right',0,''),(16499,5260,'115426','watch-mobile','block_type','1',0,''),(16500,5260,'115426','watch-mobile','border-top-width','1',0,''),(16501,5260,'115426','watch-mobile','border-left-width','1',0,''),(16502,5260,'115426','watch-mobile','border-right-width','1',0,''),(16503,5260,'115426','watch-mobile','border-bottom-width','1',0,''),(16504,5260,'115426','watch-mobile','border-top-color','$border-color-1',0,''),(16505,5260,'115426','watch-mobile','border-left-color','$border-color-1',0,''),(16506,5260,'115426','watch-mobile','border-right-color','$border-color-1',0,''),(16507,5260,'115426','watch-mobile','border-bottom-color','$border-color-1',0,''),(16508,5260,'115426','watch-mobile','padding-top','15',0,''),(16509,5260,'115426','watch-mobile','padding-left','15',0,''),(16510,5260,'115426','watch-mobile','padding-right','15',0,''),(16511,5260,'115426','watch-mobile','padding-bottom','15',0,''),(16512,5260,'115426','watch-mobile','margin-bottom','50',0,''),(16513,5261,'115427','watch-mobile','block_type','1',0,''),(16514,5261,'115427','watch-mobile','padding-top','20',0,''),(16515,5261,'115427','watch-mobile','padding-left','20',0,''),(16516,5261,'115427','watch-mobile','padding-right','20',0,''),(16517,5261,'115427','watch-mobile','background-color','$background-7',0,''),(16518,5263,'115429','watch-mobile','text','<h1>##FIND_REGISTRY##</h1>',0,''),(16519,5264,'115430','watch-mobile','block_type','1',0,''),(16520,5265,'115431','watch-mobile','block_type','8',0,''),(16521,5265,'115431','watch-mobile','schema','8-6',0,''),(16522,5266,'115432','watch-mobile','text','<div class=\"heading-3\">##INVITE_GUESTS##</div>',0,''),(16523,5267,'115433','watch-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_PERSONALIZED_URL##</div>',0,''),(16524,5268,'115434','watch-mobile','margin-bottom','30',0,''),(16525,5271,'115437','watch-mobile','margin-top','-100',0,''),(16526,5272,'115438','watch-mobile','text','<h1>##SHARE_YOUR_WEDDING_REGISTRY##</h1>',0,''),(16527,5272,'115438','watch-mobile','margin-top','-80',0,''),(16529,5273,'115439','watch-mobile','text','<h1>##CREATE_WR_SUCCESS_MESSAGE##</h1>',0,''),(16530,5275,'115441','watch-mobile','block_type','2',0,''),(16531,5275,'115441','watch-mobile','schema','2-2',0,''),(16532,5276,'115442','watch-mobile','block_type','1',0,''),(16533,5276,'115442','watch-mobile','padding-right','15',0,''),(16535,5277,'115443','watch-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_REGISTRY##</div>',0,''),(16536,5278,'115444','watch-mobile','text','<div class=\"heading-3\">##TEXT_WEDDING_DETAILS##</div>',0,''),(16537,5279,'115445','watch-mobile','margin-bottom','20',0,''),(16538,5280,'115446','watch-mobile','margin-bottom','20',0,''),(16539,5281,'115447','watch-mobile','text','<div class=\"heading-3\">##TEXT_NAMES##</div>',0,''),(16540,5282,'115448','watch-mobile','padding-bottom','20',0,''),(16541,5283,'115449','watch-mobile','block_type','1',0,''),(16542,5283,'115449','watch-mobile','padding-left','15',0,''),(16544,5284,'115450','watch-mobile','margin-bottom','20',0,''),(16545,5285,'115451','watch-mobile','text','<div class=\"heading-3\">##TEXT_SHIPPING_DETAILS##</div>',0,''),(16546,5286,'115452','watch-mobile','text','<div class=\"heading-3\">##UPLOAD_PHOTO##</div>',0,''),(16547,5287,'115453','watch-mobile','margin-bottom','20',0,''),(16548,5287,'115453','watch-mobile','padding-left','1',0,''),(16549,5288,'115454','watch-mobile','text','<div class=\"heading-3\">##TEXT_ADDITIONAL_INFORMATION##</div>',0,''),(16550,5289,'115455','watch-mobile','margin-bottom','20',0,''),(16551,5290,'115456','watch-mobile','text','<h1>##WEDDING_REGISTRY_FORM_HEADING##</h1>',0,''),(16552,5291,'115457','watch-mobile','block_type','2',0,''),(16553,5291,'115457','watch-mobile','margin-bottom','20',0,''),(16554,5293,'115459','watch-mobile','text-align','right',0,''),(16555,5295,'115461','watch-mobile','block_type','13',0,''),(16556,5295,'115461','watch-mobile','margin-bottom','20',0,''),(16557,5296,'115462','watch-mobile','position','relative',0,''),(16558,5296,'115462','watch-mobile','margin-top','-100',0,''),(16559,5297,'115463','watch-mobile','font-family','$font-1',0,''),(16560,5297,'115463','watch-mobile','font-size','18',0,''),(16561,5297,'115463','watch-mobile','margin-bottom','10',0,''),(16562,5298,'115464','watch-mobile','font-family','$font-1',0,''),(16563,5298,'115464','watch-mobile','font-size','30',0,''),(16564,5298,'115464','watch-mobile','text-transform','uppercase',0,''),(16565,5299,'115465','watch-mobile','font-weight','700',0,''),(16566,5299,'115465','watch-mobile','text-align','right',0,''),(16567,5301,'115467','watch-mobile','block_type','1',0,''),(16568,5302,'115468','watch-mobile','block_type','6',0,''),(16569,5302,'115468','watch-mobile','schema','6-3',0,''),(16570,5303,'115469','watch-mobile','aria_name','account-menu',0,''),(16571,5304,'115470','watch-mobile','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(16572,5305,'115471','watch-mobile','margin-bottom','20',0,''),(16573,5306,'115472','watch-mobile','block_type','1',0,''),(16574,5306,'115472','watch-mobile','padding-top','20',0,''),(16575,5306,'115472','watch-mobile','padding-bottom','20',0,''),(16576,5308,'115474','watch-mobile','padding-top','20',0,''),(16577,5308,'115474','watch-mobile','padding-bottom','20',0,''),(40273,12909,'118459','printshop-mobile','text','##TEXT_PAGE_NOT_FOUND##',0,''),(40274,12909,'118459','printshop-mobile','text-align','center',0,''),(40275,12909,'118459','printshop-mobile','padding-top','100',0,''),(40276,12909,'118459','printshop-mobile','padding-bottom','100',0,''),(40277,12910,'118460','printshop-mobile','block_type','1',0,''),(40396,12926,'118476','printshop-mobile','block_type','1',0,''),(40515,12942,'118492','printshop-mobile','block_type','1',0,''),(40634,12958,'118508','printshop-mobile','block_type','1',0,''),(40753,12974,'118524','printshop-mobile','block_type','1',0,''),(40872,12990,'118540','printshop-mobile','block_type','1',0,''),(40991,13006,'118556','printshop-mobile','block_type','1',0,''),(40992,13007,'118557','printshop-mobile','block_type','6',0,''),(40993,13007,'118557','printshop-mobile','schema','6-3',0,''),(40994,13007,'118557','printshop-mobile','schema','6-3',0,'702'),(40995,13008,'118558','printshop-mobile','aria_name','account-menu',0,''),(40996,13009,'118559','printshop-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(40997,13010,'118560','printshop-mobile','link','Order History Info',0,''),(40998,13010,'118560','printshop-mobile','text','TEXT_VIEW',0,''),(40999,13010,'118560','printshop-mobile','max_orders','3',0,''),(41000,13010,'118560','printshop-mobile','link_pay','Order pay',0,''),(41001,13010,'118560','printshop-mobile','margin-bottom','30',0,''),(41002,13010,'118560','printshop-mobile','text_pay','ORDER_PAY',0,''),(41003,13011,'118561','printshop-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(41004,13012,'118562','printshop-mobile','block_type','15',0,''),(41005,13012,'118562','printshop-mobile','margin-bottom','30',0,''),(41006,13012,'118562','printshop-mobile','padding-top','20',0,''),(41007,13012,'118562','printshop-mobile','padding-left','20',0,''),(41008,13012,'118562','printshop-mobile','padding-right','20',0,''),(41009,13012,'118562','printshop-mobile','padding-bottom','20',0,''),(41010,13012,'118562','printshop-mobile','border-top-width','1',0,''),(41011,13012,'118562','printshop-mobile','border-top-color','#e0e0e0',0,''),(41012,13012,'118562','printshop-mobile','border-left-width','1',0,''),(41013,13012,'118562','printshop-mobile','border-right-width','1',0,''),(41014,13012,'118562','printshop-mobile','border-bottom-width','1',0,''),(41015,13012,'118562','printshop-mobile','border-left-color','#e0e0e0',0,''),(41016,13012,'118562','printshop-mobile','border-right-color','#e0e0e0',0,''),(41017,13012,'118562','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(41018,13012,'118562','printshop-mobile','schema','15-2',0,'702'),(41019,13013,'118563','printshop-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(41020,13013,'118563','printshop-mobile','font-family','trueloaded',0,'3'),(41021,13013,'118563','printshop-mobile','content','\\e920',0,'3'),(41022,13013,'118563','printshop-mobile','color','#ee4225',0,'3'),(41023,13013,'118563','printshop-mobile','font-size','30',0,'3'),(41024,13013,'118563','printshop-mobile','text-align','center',0,'3'),(41025,13013,'118563','printshop-mobile','margin-bottom','10',0,'3'),(41026,13013,'118563','printshop-mobile','text-align','center',0,''),(41027,13013,'118563','printshop-mobile','font-size','16',0,''),(41028,13013,'118563','printshop-mobile','text-transform','uppercase',0,''),(41029,13013,'118563','printshop-mobile','line-height','1',0,'3'),(41031,13014,'118564','printshop-mobile','font-family','Varela Round',0,''),(41032,13014,'118564','printshop-mobile','color','#ee4225',0,''),(41033,13014,'118564','printshop-mobile','font-size','14',0,''),(41034,13014,'118564','printshop-mobile','text-align','center',0,''),(41035,13015,'118565','printshop-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(41036,13015,'118565','printshop-mobile','font-family','trueloaded',0,'3'),(41037,13015,'118565','printshop-mobile','content','\\e928',0,'3'),(41038,13015,'118565','printshop-mobile','color','#ee4225',0,'3'),(41039,13015,'118565','printshop-mobile','font-size','30',0,'3'),(41040,13015,'118565','printshop-mobile','text-align','center',0,'3'),(41041,13015,'118565','printshop-mobile','text-align','center',0,''),(41042,13015,'118565','printshop-mobile','font-size','16',0,''),(41043,13015,'118565','printshop-mobile','text-transform','uppercase',0,''),(41044,13015,'118565','printshop-mobile','line-height','1',0,'3'),(41046,13016,'118566','printshop-mobile','link','download_orders',0,''),(41047,13016,'118566','printshop-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(41048,13016,'118566','printshop-mobile','hide_link','orders',0,''),(41049,13016,'118566','printshop-mobile','text-align','center',0,''),(41050,13016,'118566','printshop-mobile','popup','2',0,''),(41051,13016,'118566','printshop-mobile','font-size','14',0,''),(41052,13017,'118567','printshop-mobile','font-family','Varela Round',0,''),(41053,13017,'118567','printshop-mobile','color','#ee4225',0,''),(41054,13017,'118567','printshop-mobile','font-size','14',0,''),(41055,13017,'118567','printshop-mobile','text-align','center',0,''),(41056,13018,'118568','printshop-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(41057,13018,'118568','printshop-mobile','font-family','trueloaded',0,'3'),(41058,13018,'118568','printshop-mobile','content','\\e922',0,'3'),(41059,13018,'118568','printshop-mobile','color','#ee4225',0,'3'),(41060,13018,'118568','printshop-mobile','font-size','30',0,'3'),(41061,13018,'118568','printshop-mobile','line-height','1',0,'3'),(41062,13018,'118568','printshop-mobile','font-size','16',0,''),(41063,13018,'118568','printshop-mobile','text-align','center',0,''),(41064,13018,'118568','printshop-mobile','text-transform','uppercase',0,''),(41066,13019,'118569','printshop-mobile','font-family','Varela Round',0,''),(41067,13019,'118569','printshop-mobile','color','#ee4225',0,''),(41068,13019,'118569','printshop-mobile','line-height','1',0,''),(41069,13019,'118569','printshop-mobile','text-align','center',0,''),(41070,13019,'118569','printshop-mobile','font-size','14',0,''),(41071,13020,'118570','printshop-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(41072,13020,'118570','printshop-mobile','content','\\e994',0,'3'),(41073,13020,'118570','printshop-mobile','font-family','trueloaded',0,'3'),(41074,13020,'118570','printshop-mobile','color','#ee4225',0,'3'),(41075,13020,'118570','printshop-mobile','font-size','30',0,'3'),(41076,13020,'118570','printshop-mobile','line-height','1',0,'3'),(41077,13020,'118570','printshop-mobile','font-size','16',0,''),(41078,13020,'118570','printshop-mobile','text-align','center',0,''),(41079,13020,'118570','printshop-mobile','text-transform','uppercase',0,''),(41081,13021,'118571','printshop-mobile','link','Gift Certificate',0,''),(41082,13021,'118571','printshop-mobile','text','GIFT_CERTIFICATE',0,''),(41083,13021,'118571','printshop-mobile','popup','1',0,''),(41084,13021,'118571','printshop-mobile','text-align','center',0,''),(41085,13021,'118571','printshop-mobile','font-size','14',0,''),(41086,13022,'118572','printshop-mobile','font-family','Varela Round',0,''),(41087,13022,'118572','printshop-mobile','color','#ee4225',0,''),(41088,13022,'118572','printshop-mobile','font-size','14',0,''),(41089,13022,'118572','printshop-mobile','text-align','center',0,''),(41090,13023,'118573','printshop-mobile','text','TEXT_VIEW_HISTORY',0,''),(41091,13023,'118573','printshop-mobile','popup','1',0,''),(41092,13023,'118573','printshop-mobile','text-align','center',0,''),(41093,13023,'118573','printshop-mobile','link','Points Earnt History',0,''),(41094,13023,'118573','printshop-mobile','font-size','14',0,''),(41095,13024,'118574','printshop-mobile','font-family','Varela Round',0,''),(41096,13024,'118574','printshop-mobile','color','#ee4225',0,''),(41097,13024,'118574','printshop-mobile','font-size','14',0,''),(41098,13024,'118574','printshop-mobile','text-align','center',0,''),(41099,13025,'118575','printshop-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(41100,13025,'118575','printshop-mobile','content','\\e990',0,'3'),(41101,13025,'118575','printshop-mobile','font-family','trueloaded',0,'3'),(41102,13025,'118575','printshop-mobile','font-size','30',0,'3'),(41103,13025,'118575','printshop-mobile','text-align','center',0,'3'),(41104,13025,'118575','printshop-mobile','line-height','1',0,'3'),(41105,13025,'118575','printshop-mobile','color','#ee4225',0,'3'),(41106,13025,'118575','printshop-mobile','font-size','16',0,''),(41107,13025,'118575','printshop-mobile','text-align','center',0,''),(41108,13025,'118575','printshop-mobile','text-transform','uppercase',0,''),(41110,13026,'118576','printshop-mobile','block_type','1',0,''),(41111,13027,'118577','printshop-mobile','hide_parents','2',0,''),(41112,13028,'118578','printshop-mobile','text','<div class=\"heading-3\">##TEXT_GIFT_CARDS##</div>',0,''),(41113,13030,'118580','printshop-mobile','block_type','1',0,''),(41114,13030,'118580','printshop-mobile','padding-top','70',0,''),(41115,13030,'118580','printshop-mobile','padding-right','30',0,''),(41116,13030,'118580','printshop-mobile','padding-bottom','30',0,''),(41118,13030,'118580','printshop-mobile','padding-left','0',0,''),(41121,13031,'118581','printshop-mobile','block_type','1',0,''),(41122,13031,'118581','printshop-mobile','padding-right','20',0,''),(41123,13031,'118581','printshop-mobile','style_class','account-menu',0,''),(41124,13031,'118581','printshop-mobile','padding-top','20',0,''),(41125,13031,'118581','printshop-mobile','margin-bottom','20',0,''),(41126,13031,'118581','printshop-mobile','background-color','#eeeeee',0,''),(41127,13031,'118581','printshop-mobile','padding-left','20',0,''),(41128,13031,'118581','printshop-mobile','padding-bottom','20',0,''),(41129,13032,'118582','printshop-mobile','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(41130,13032,'118582','printshop-mobile','style_class','heading-settings',0,''),(41131,13033,'118583','printshop-mobile','link','delete',0,''),(41132,13033,'118583','printshop-mobile','text','DELETE_ACCOUNT',0,''),(41133,13034,'118584','printshop-mobile','text','TEXT_DASHBOARD',0,''),(41134,13034,'118584','printshop-mobile','font-family','Varela Round',0,''),(41135,13034,'118584','printshop-mobile','font-size','18',0,''),(41136,13034,'118584','printshop-mobile','text-transform','uppercase',0,''),(41137,13035,'118585','printshop-mobile','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(41138,13035,'118585','printshop-mobile','style_class','heading-saved-lists',0,''),(41139,13036,'118586','printshop-mobile','link','logoff',0,''),(41140,13037,'118587','printshop-mobile','link','Personal Catalog',0,''),(41141,13037,'118587','printshop-mobile','text','TEXT_PERSONAL_CATALOG',0,''),(41142,13037,'118587','printshop-mobile','hide_link','personal_catalog',0,''),(41143,13038,'118588','printshop-mobile','link','Address Book',0,''),(41144,13038,'118588','printshop-mobile','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(41145,13039,'118589','printshop-mobile','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(41146,13039,'118589','printshop-mobile','style_class','heading-ordered-items',0,''),(41147,13040,'118590','printshop-mobile','link','Samples',0,''),(41148,13040,'118590','printshop-mobile','text','TEXT_HEADING_SAMPLE_CART',0,''),(41149,13040,'118590','printshop-mobile','hide_link','samples',0,''),(41150,13041,'118591','printshop-mobile','link','Order History',0,''),(41151,13041,'118591','printshop-mobile','text','HEADING_ORDER_HISTORY',0,''),(41152,13041,'118591','printshop-mobile','active_link','Order History Info,Order pay',0,''),(41153,13042,'118592','printshop-mobile','link','My password',0,''),(41154,13042,'118592','printshop-mobile','text','TEXT_MY_PASSWORD',0,''),(41155,13043,'118593','printshop-mobile','link','Review',0,''),(41156,13043,'118593','printshop-mobile','text','REVIEWS',0,''),(41157,13044,'118594','printshop-mobile','link','Account edit',0,''),(41158,13044,'118594','printshop-mobile','text','ACCOUNT_EDIT',0,''),(41159,13045,'118595','printshop-mobile','link','Quotations',0,''),(41160,13045,'118595','printshop-mobile','hide_link','quotations',0,''),(41161,13045,'118595','printshop-mobile','text','TEXT_HEADING_QUOTE_CART',0,''),(41162,13046,'118596','printshop-mobile','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(41163,13046,'118596','printshop-mobile','style_class','heading-settings',0,''),(41164,13047,'118597','printshop-mobile','link','trade_form',0,''),(41165,13047,'118597','printshop-mobile','text','TRADE_FORM',0,''),(41166,13048,'118598','printshop-mobile','block_type','1',0,''),(41167,13049,'118599','printshop-mobile','block_type','6',0,''),(41168,13049,'118599','printshop-mobile','schema','6-3',0,''),(41169,13049,'118599','printshop-mobile','schema','6-3',0,'702'),(41170,13050,'118600','printshop-mobile','aria_name','account-menu',0,''),(41171,13052,'118602','printshop-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(41172,13053,'118603','printshop-mobile','text','CANCEL',0,''),(41173,13053,'118603','printshop-mobile','like_button','1',0,''),(41174,13053,'118603','printshop-mobile','padding-bottom','20',0,''),(41175,13054,'118604','printshop-mobile','block_type','1',0,''),(41176,13055,'118605','printshop-mobile','block_type','6',0,''),(41177,13055,'118605','printshop-mobile','schema','6-3',0,''),(41178,13055,'118605','printshop-mobile','schema','6-3',0,'702'),(41179,13056,'118606','printshop-mobile','aria_name','account-menu',0,''),(41180,13057,'118607','printshop-mobile','padding-top','15',0,''),(41181,13057,'118607','printshop-mobile','padding-bottom','15',0,''),(41182,13057,'118607','printshop-mobile','link','Address Book Process',0,''),(41183,13057,'118607','printshop-mobile','text','EDIT',0,''),(41184,13057,'118607','printshop-mobile','link_add','Address Book Process',0,''),(41185,13057,'118607','printshop-mobile','like_button_add','2',0,''),(41186,13057,'118607','printshop-mobile','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(41187,13058,'118608','printshop-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1><div class=\"info-popup bottom-left\">\n<div><ul><li>##PRIMARY_ADDRESS##<br>##PRIMARY_ADDRESS_DESCRIPTION##<br></li><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(41188,13058,'118608','printshop-mobile','text-align','center',0,''),(41189,13059,'118609','printshop-mobile','block_type','1',0,''),(41190,13060,'118610','printshop-mobile','block_type','6',0,''),(41191,13060,'118610','printshop-mobile','schema','6-3',0,''),(41192,13060,'118610','printshop-mobile','schema','6-3',0,'702'),(41193,13061,'118611','printshop-mobile','aria_name','account-menu',0,''),(41194,13063,'118613','printshop-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(41195,13064,'118614','printshop-mobile','text','CANCEL',0,''),(41196,13064,'118614','printshop-mobile','like_button','1',0,''),(41197,13064,'118614','printshop-mobile','padding-bottom','20',0,''),(41198,13064,'118614','printshop-mobile','link','Address Book',0,''),(41199,13065,'118615','printshop-mobile','block_type','1',0,''),(41200,13065,'118615','printshop-mobile','style_class','item-holder',0,''),(41201,13065,'118615','printshop-mobile','padding-top','25',0,''),(41202,13065,'118615','printshop-mobile','padding-bottom','25',0,''),(41203,13065,'118615','printshop-mobile','text-align','left',0,''),(41204,13065,'118615','printshop-mobile','border-top-color','#e0e0e0',0,''),(41205,13065,'118615','printshop-mobile','border-top-width','1',0,''),(41206,13066,'118616','printshop-mobile','block_type','6',0,''),(41207,13067,'118617','printshop-mobile','padding-right','20',0,''),(41208,13068,'118618','printshop-mobile','clear','none',0,''),(41209,13070,'118620','printshop-mobile','block_type','4',0,''),(41210,13071,'118621','printshop-mobile','block_type','2',0,''),(41211,13072,'118622','printshop-mobile','margin-bottom','7',0,''),(41212,13073,'118623','printshop-mobile','clear','none',0,''),(41213,13074,'118624','printshop-mobile','margin-bottom','20',0,''),(41214,13074,'118624','printshop-mobile','text-align','right',0,''),(41215,13075,'118625','printshop-mobile','description_characters','200',0,''),(41216,13075,'118625','printshop-mobile','clear','none',0,''),(41217,13075,'118625','printshop-mobile','padding-right','20',0,''),(41218,13076,'118626','printshop-mobile','block_type','2',0,''),(41219,13077,'118627','printshop-mobile','clear','none',0,''),(41220,13079,'118629','printshop-mobile','padding-right','20',0,''),(41221,13080,'118630','printshop-mobile','block_type','1',0,''),(41222,13080,'118630','printshop-mobile','style_class','item-holder',0,''),(41223,13080,'118630','printshop-mobile','padding-top','25',0,''),(41224,13080,'118630','printshop-mobile','padding-left','25',0,''),(41225,13080,'118630','printshop-mobile','padding-right','25',0,''),(41226,13080,'118630','printshop-mobile','padding-bottom','25',0,''),(41227,13080,'118630','printshop-mobile','text-align','left',0,''),(41228,13082,'118632','printshop-mobile','margin-bottom','7',0,''),(41229,13083,'118633','printshop-mobile','clear','both',0,''),(41230,13086,'118636','printshop-mobile','block_type','1',0,''),(41231,13086,'118636','printshop-mobile','style_class','item-holder',0,''),(41232,13086,'118636','printshop-mobile','padding-top','25',0,''),(41233,13086,'118636','printshop-mobile','padding-left','25',0,''),(41234,13086,'118636','printshop-mobile','padding-right','25',0,''),(41235,13086,'118636','printshop-mobile','padding-bottom','25',0,''),(41236,13086,'118636','printshop-mobile','text-align','left',0,''),(41237,13087,'118637','printshop-mobile','block_type','5',0,''),(41238,13090,'118640','printshop-mobile','margin-bottom','7',0,''),(41239,13091,'118641','printshop-mobile','clear','both',0,''),(41240,13092,'118642','printshop-mobile','block_type','1',0,''),(41241,13093,'118643','printshop-mobile','block_type','6',0,''),(41242,13093,'118643','printshop-mobile','font-weight','400',0,''),(41243,13093,'118643','printshop-mobile','schema','6-2',0,''),(41245,13094,'118644','printshop-mobile','font-weight','400',0,''),(41246,13094,'118644','printshop-mobile','padding-right','40',0,''),(41249,13095,'118645','printshop-mobile','block_type','5',0,''),(41250,13095,'118645','printshop-mobile','padding-top','10',0,''),(41251,13095,'118645','printshop-mobile','padding-bottom','10',0,''),(41252,13095,'118645','printshop-mobile','schema','5-2',0,''),(41253,13095,'118645','printshop-mobile','border-top-color','#e0e0e0',0,''),(41254,13095,'118645','printshop-mobile','border-top-width','1',0,''),(41255,13097,'118647','printshop-mobile','float','right',0,''),(41256,13099,'118649','printshop-mobile','col_in_row','3',0,''),(41257,13099,'118649','printshop-mobile','products_align','left',0,''),(41258,13099,'118649','printshop-mobile','font-weight','400',0,''),(41259,13099,'118649','printshop-mobile','show_qty_input','0',0,''),(41260,13099,'118649','printshop-mobile','listing_type','productListing',0,''),(41261,13099,'118649','printshop-mobile','listing_type_rows','no',0,''),(41262,13099,'118649','printshop-mobile','show_buy_button_b2b','on',0,''),(41263,13099,'118649','printshop-mobile','show_wishlist_button_b2b','1',0,''),(41264,13099,'118649','printshop-mobile','show_compare_b2b','1',0,''),(41265,13099,'118649','printshop-mobile','show_stock','0',0,''),(41266,13099,'118649','printshop-mobile','show_description','0',0,''),(41267,13099,'118649','printshop-mobile','show_model','0',0,''),(41268,13099,'118649','printshop-mobile','show_properties','0',0,''),(41269,13099,'118649','printshop-mobile','show_rating','0',0,''),(41270,13099,'118649','printshop-mobile','show_rating_counts','0',0,''),(41271,13099,'118649','printshop-mobile','show_price','0',0,''),(41272,13099,'118649','printshop-mobile','show_buy_button','0',0,''),(41273,13099,'118649','printshop-mobile','show_view_button','0',0,''),(41274,13099,'118649','printshop-mobile','show_wishlist_button','0',0,''),(41275,13099,'118649','printshop-mobile','show_compare','0',0,''),(41276,13099,'118649','printshop-mobile','show_name_rows','0',0,''),(41277,13099,'118649','printshop-mobile','show_image_rows','0',0,''),(41278,13099,'118649','printshop-mobile','show_stock_rows','0',0,''),(41279,13099,'118649','printshop-mobile','show_description_rows','0',0,''),(41280,13099,'118649','printshop-mobile','show_model_rows','0',0,''),(41281,13099,'118649','printshop-mobile','show_properties_rows','0',0,''),(41282,13099,'118649','printshop-mobile','show_rating_rows','0',0,''),(41283,13099,'118649','printshop-mobile','show_rating_counts_rows','0',0,''),(41284,13099,'118649','printshop-mobile','show_price_rows','0',0,''),(41285,13099,'118649','printshop-mobile','show_buy_button_rows','0',0,''),(41286,13099,'118649','printshop-mobile','show_qty_input_rows','0',0,''),(41287,13099,'118649','printshop-mobile','show_view_button_rows','0',0,''),(41288,13099,'118649','printshop-mobile','show_wishlist_button_rows','0',0,''),(41289,13099,'118649','printshop-mobile','show_compare_rows','0',0,''),(41290,13099,'118649','printshop-mobile','show_name_b2b','0',0,''),(41291,13099,'118649','printshop-mobile','show_image_b2b','0',0,''),(41292,13099,'118649','printshop-mobile','show_stock_b2b','0',0,''),(41293,13099,'118649','printshop-mobile','show_description_b2b','0',0,''),(41294,13099,'118649','printshop-mobile','show_model_b2b','0',0,''),(41295,13099,'118649','printshop-mobile','show_properties_b2b','0',0,''),(41296,13099,'118649','printshop-mobile','show_rating_b2b','0',0,''),(41297,13099,'118649','printshop-mobile','show_rating_counts_b2b','0',0,''),(41298,13099,'118649','printshop-mobile','show_price_b2b','0',0,''),(41299,13099,'118649','printshop-mobile','show_qty_input_b2b','0',0,''),(41300,13099,'118649','printshop-mobile','show_view_button_b2b','0',0,''),(41301,13099,'118649','printshop-mobile','show_attributes_b2b','0',0,''),(41302,13099,'118649','printshop-mobile','items_on_page','9',0,''),(41305,13099,'118649','printshop-mobile','product_names_teg','h2',0,''),(41306,13100,'118650','printshop-mobile','listing_type','productListing',0,''),(41307,13101,'118651','printshop-mobile','block_type','1',0,''),(41308,13101,'118651','printshop-mobile','padding-top','10',0,''),(41309,13101,'118651','printshop-mobile','padding-bottom','10',0,''),(41310,13101,'118651','printshop-mobile','border-bottom-width','1',0,''),(41311,13101,'118651','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(41312,13101,'118651','printshop-mobile','margin-left','0',0,''),(41313,13101,'118651','printshop-mobile','margin-right','0',0,''),(41314,13102,'118652','printshop-mobile','float','right',0,''),(41315,13102,'118652','printshop-mobile','display','none',0,''),(41316,13103,'118653','printshop-mobile','margin-right','20',0,''),(41317,13103,'118653','printshop-mobile','float','right',0,''),(41318,13103,'118653','printshop-mobile','clear','none',0,''),(41319,13103,'118653','printshop-mobile','display','none',0,''),(41320,13104,'118654','printshop-mobile','float','left',0,''),(41321,13104,'118654','printshop-mobile','clear','none',0,''),(41322,13104,'118654','printshop-mobile','margin-left','20',0,''),(41323,13104,'118654','printshop-mobile','display','none',0,''),(41324,13105,'118655','printshop-mobile','float','left',0,''),(41325,13105,'118655','printshop-mobile','clear','none',0,''),(41326,13105,'118655','printshop-mobile','sort_pos_3','1',0,''),(41327,13105,'118655','printshop-mobile','sort_pos_4','2',0,''),(41328,13105,'118655','printshop-mobile','sort_pos_10','3',0,''),(41329,13105,'118655','printshop-mobile','sort_pos_9','4',0,''),(41330,13105,'118655','printshop-mobile','sort_pos_11','5',0,''),(41331,13105,'118655','printshop-mobile','sort_pos_12','6',0,''),(41332,13105,'118655','printshop-mobile','sort_pos_14','7',0,''),(41333,13105,'118655','printshop-mobile','sort_pos_13','8',0,''),(41334,13105,'118655','printshop-mobile','sort_pos_8','9',0,''),(41335,13105,'118655','printshop-mobile','sort_pos_7','10',0,''),(41336,13105,'118655','printshop-mobile','sort_pos_2','11',0,''),(41337,13105,'118655','printshop-mobile','sort_pos_1','12',0,''),(41338,13105,'118655','printshop-mobile','sort_pos_6','13',0,''),(41339,13105,'118655','printshop-mobile','sort_pos_5','14',0,''),(41340,13105,'118655','printshop-mobile','sort_pos_0','15',0,''),(41341,13105,'118655','printshop-mobile','sort_hide_10','1',0,''),(41342,13105,'118655','printshop-mobile','sort_hide_9','1',0,''),(41343,13105,'118655','printshop-mobile','hide_icons','1',0,''),(41344,13105,'118655','printshop-mobile','sort_hide_16','1',0,''),(41345,13105,'118655','printshop-mobile','sort_hide_15','1',0,''),(41346,13105,'118655','printshop-mobile','sort_hide_3','0',0,''),(41347,13105,'118655','printshop-mobile','sort_hide_4','0',0,''),(41348,13105,'118655','printshop-mobile','sort_hide_11','1',0,''),(41349,13105,'118655','printshop-mobile','sort_hide_12','1',0,''),(41350,13105,'118655','printshop-mobile','sort_hide_14','1',0,''),(41351,13105,'118655','printshop-mobile','sort_hide_13','1',0,''),(41352,13105,'118655','printshop-mobile','sort_hide_8','0',0,''),(41353,13105,'118655','printshop-mobile','sort_hide_7','0',0,''),(41354,13105,'118655','printshop-mobile','sort_hide_2','1',0,''),(41355,13105,'118655','printshop-mobile','sort_hide_1','1',0,''),(41356,13105,'118655','printshop-mobile','sort_hide_6','1',0,''),(41357,13105,'118655','printshop-mobile','sort_hide_5','1',0,''),(41358,13105,'118655','printshop-mobile','sort_hide_0','1',0,''),(41359,13108,'118658','printshop-mobile','block_type','1',0,''),(41360,13109,'118659','printshop-mobile','block_type','7',0,''),(41361,13109,'118659','printshop-mobile','schema','7-2',0,'720'),(41362,13110,'118660','printshop-mobile','padding-top','20',0,''),(41363,13110,'118660','printshop-mobile','padding-right','20',0,''),(41364,13111,'118661','printshop-mobile','blog_sidebar','1',0,''),(41365,13111,'118661','printshop-mobile','padding-top','20',0,''),(41366,13111,'118661','printshop-mobile','padding-left','20',0,''),(41367,13112,'118662','printshop-mobile','block_type','1',0,''),(41368,13113,'118663','printshop-mobile','item_tag','h2',0,''),(41369,13113,'118663','printshop-mobile','hTagsInline','inline',0,''),(41370,13117,'118667','printshop-mobile','block_type','1',0,''),(41371,13117,'118667','printshop-mobile','schema','4-1',0,''),(41373,13117,'118667','printshop-mobile','schema','4-1',0,'702'),(41374,13118,'118668','printshop-mobile','block_type','1',0,''),(41375,13118,'118668','printshop-mobile','background-color','#ffffff',0,''),(41376,13118,'118668','printshop-mobile','padding-top','20',0,''),(41377,13118,'118668','printshop-mobile','padding-bottom','20',0,''),(41378,13118,'118668','printshop-mobile','margin-bottom','30',0,''),(41379,13119,'118669','printshop-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(41380,13119,'118669','printshop-mobile','style_class','bell-ico',0,''),(41381,13120,'118670','printshop-mobile','col_in_row','3',0,''),(41382,13120,'118670','printshop-mobile','show_description','1',0,''),(41383,13120,'118670','printshop-mobile','show_model','1',0,''),(41384,13120,'118670','printshop-mobile','show_properties','1',0,''),(41385,13120,'118670','printshop-mobile','show_rating','1',0,''),(41386,13120,'118670','printshop-mobile','show_rating_counts','1',0,''),(41387,13120,'118670','printshop-mobile','show_qty_input','1',0,''),(41388,13120,'118670','printshop-mobile','show_view_button','1',0,''),(41389,13120,'118670','printshop-mobile','show_wishlist_button','1',0,''),(41390,13120,'118670','printshop-mobile','show_compare','1',0,''),(41391,13120,'118670','printshop-mobile','view_as','carousel',0,''),(41392,13120,'118670','printshop-mobile','hide_parents','2',0,''),(41393,13121,'118671','printshop-mobile','block_type','1',0,''),(41394,13121,'118671','printshop-mobile','background-color','#ffffff',0,''),(41395,13121,'118671','printshop-mobile','margin-bottom','30',0,''),(41396,13122,'118672','printshop-mobile','padding-top','20',0,''),(41397,13122,'118672','printshop-mobile','padding-bottom','20',0,''),(41398,13123,'118673','printshop-mobile','block_type','2',0,''),(41399,13123,'118673','printshop-mobile','padding-bottom','20',0,''),(41400,13123,'118673','printshop-mobile','padding-top','20',0,''),(41401,13123,'118673','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(41402,13123,'118673','printshop-mobile','border-bottom-width','1',0,''),(41403,13123,'118673','printshop-mobile','schema','2-2',0,''),(41404,13124,'118674','printshop-mobile','padding-top','22',0,''),(41405,13125,'118675','printshop-mobile','float','right',0,''),(41406,13125,'118675','printshop-mobile','padding-top','26',0,''),(41407,13126,'118676','printshop-mobile','float','left',0,''),(41408,13127,'118677','printshop-mobile','block_type','1',0,''),(41409,13127,'118677','printshop-mobile','padding-top','20',0,''),(41410,13127,'118677','printshop-mobile','padding-bottom','20',0,''),(41411,13127,'118677','printshop-mobile','background-color','#ffffff',0,''),(41412,13127,'118677','printshop-mobile','margin-bottom','30',0,''),(41413,13128,'118678','printshop-mobile','hide_parents','2',0,''),(41414,13129,'118679','printshop-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(41415,13130,'118680','printshop-mobile','block_type','1',0,''),(41416,13130,'118680','printshop-mobile','background-color','#ffffff',0,''),(41417,13130,'118680','printshop-mobile','padding-top','20',0,''),(41418,13130,'118680','printshop-mobile','padding-bottom','20',0,''),(41419,13130,'118680','printshop-mobile','margin-bottom','30',0,''),(41420,13130,'118680','printshop-mobile','style_class','closeable-box',0,''),(41421,13131,'118681','printshop-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(41422,13131,'118681','printshop-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(41423,13132,'118682','printshop-mobile','block_type','1',0,''),(41424,13132,'118682','printshop-mobile','font-weight','400',0,''),(41425,13132,'118682','printshop-mobile','schema','2-2',0,''),(41426,13132,'118682','printshop-mobile','style_class','closeable-content',0,''),(41427,13132,'118682','printshop-mobile','padding-top','10',0,''),(41428,13133,'118683','printshop-mobile','font-weight','400',0,''),(41429,13133,'118683','printshop-mobile','padding-top','12',0,''),(41430,13133,'118683','printshop-mobile','padding-left','0',0,''),(41431,13136,'118686','printshop-mobile','block_type','1',0,''),(41432,13136,'118686','printshop-mobile','background-color','#ffffff',0,''),(41433,13136,'118686','printshop-mobile','padding-top','20',0,''),(41434,13136,'118686','printshop-mobile','padding-left','25',0,''),(41435,13136,'118686','printshop-mobile','padding-right','25',0,''),(41436,13136,'118686','printshop-mobile','padding-bottom','20',0,''),(41437,13136,'118686','printshop-mobile','margin-bottom','30',0,''),(41438,13136,'118686','printshop-mobile','style_class','closeable-box',0,''),(41439,13136,'118686','printshop-mobile','display','none',0,''),(41441,13137,'118687','printshop-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(41442,13137,'118687','printshop-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(41443,13138,'118688','printshop-mobile','font-weight','normal',0,''),(41444,13138,'118688','printshop-mobile','style_class','closeable-content',0,''),(41445,13138,'118688','printshop-mobile','padding-top','10',0,''),(41446,13138,'118688','printshop-mobile','hide_parents','2',0,''),(41447,13139,'118689','printshop-mobile','style_class','order-summary',0,''),(41448,13139,'118689','printshop-mobile','block_type','1',0,''),(41449,13139,'118689','printshop-mobile','margin-left','30',0,''),(41451,13139,'118689','printshop-mobile','margin-bottom','30',0,''),(41452,13140,'118690','printshop-mobile','block_type','1',0,''),(41453,13140,'118690','printshop-mobile','padding-bottom','20',0,''),(41454,13141,'118691','printshop-mobile','font-weight','400',0,''),(41455,13141,'118691','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',1,''),(41456,13141,'118691','printshop-mobile','padding-top','20',0,''),(41457,13141,'118691','printshop-mobile','padding-bottom','10',0,''),(41458,13142,'118692','printshop-mobile','font-weight','400',0,''),(41459,13142,'118692','printshop-mobile','box_align','4',0,''),(41460,13142,'118692','printshop-mobile','text-align','center',0,''),(41461,13142,'118692','printshop-mobile','float','none',0,''),(41462,13142,'118692','printshop-mobile','width','100',0,''),(41463,13142,'118692','printshop-mobile','width_measure','%',0,''),(41464,13144,'118694','printshop-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(41465,13145,'118695','printshop-mobile','block_type','1',0,''),(41466,13145,'118695','printshop-mobile','font-weight','normal',0,''),(41467,13145,'118695','printshop-mobile','padding-top','20',0,''),(41468,13145,'118695','printshop-mobile','background-color','#eeeeee',0,''),(41469,13147,'118697','printshop-mobile','block_type','4',0,''),(41470,13147,'118697','printshop-mobile','schema','4-1',0,''),(41472,13148,'118698','printshop-mobile','block_type','1',0,''),(41473,13148,'118698','printshop-mobile','background-color','#ffffff',0,''),(41474,13148,'118698','printshop-mobile','padding-top','20',0,''),(41475,13148,'118698','printshop-mobile','padding-bottom','20',0,''),(41476,13148,'118698','printshop-mobile','padding-left','25',0,''),(41477,13148,'118698','printshop-mobile','padding-right','25',0,''),(41478,13148,'118698','printshop-mobile','margin-bottom','30',0,''),(41479,13149,'118699','printshop-mobile','col_in_row','3',0,''),(41480,13149,'118699','printshop-mobile','show_description','1',0,''),(41481,13149,'118699','printshop-mobile','show_model','1',0,''),(41482,13149,'118699','printshop-mobile','show_properties','1',0,''),(41483,13149,'118699','printshop-mobile','show_rating','1',0,''),(41484,13149,'118699','printshop-mobile','show_rating_counts','1',0,''),(41485,13149,'118699','printshop-mobile','show_qty_input','1',0,''),(41486,13149,'118699','printshop-mobile','show_view_button','1',0,''),(41487,13149,'118699','printshop-mobile','show_wishlist_button','1',0,''),(41488,13149,'118699','printshop-mobile','show_compare','1',0,''),(41489,13149,'118699','printshop-mobile','view_as','carousel',0,''),(41490,13149,'118699','printshop-mobile','hide_parents','2',0,''),(41491,13150,'118700','printshop-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(41492,13150,'118700','printshop-mobile','style_class','bell-ico',0,''),(41493,13151,'118701','printshop-mobile','block_type','1',0,''),(41494,13151,'118701','printshop-mobile','background-color','#ffffff',0,''),(41495,13151,'118701','printshop-mobile','margin-bottom','30',0,''),(41496,13152,'118702','printshop-mobile','padding-top','20',0,''),(41497,13152,'118702','printshop-mobile','padding-left','25',0,''),(41498,13152,'118702','printshop-mobile','padding-right','25',0,''),(41499,13152,'118702','printshop-mobile','padding-bottom','20',0,''),(41500,13153,'118703','printshop-mobile','block_type','2',0,''),(41501,13153,'118703','printshop-mobile','padding-bottom','20',0,''),(41502,13153,'118703','printshop-mobile','padding-top','20',0,''),(41503,13153,'118703','printshop-mobile','padding-left','25',0,''),(41504,13153,'118703','printshop-mobile','padding-right','25',0,''),(41505,13153,'118703','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(41506,13153,'118703','printshop-mobile','border-bottom-width','1',0,''),(41507,13153,'118703','printshop-mobile','schema','2-2',0,''),(41508,13154,'118704','printshop-mobile','float','left',0,''),(41509,13155,'118705','printshop-mobile','text-align','right',0,''),(41510,13155,'118705','printshop-mobile','clear','none',0,''),(41511,13155,'118705','printshop-mobile','float','right',0,''),(41512,13155,'118705','printshop-mobile','padding-top','22',0,''),(41513,13156,'118706','printshop-mobile','float','right',0,''),(41514,13156,'118706','printshop-mobile','padding-top','26',0,''),(41515,13157,'118707','printshop-mobile','block_type','1',0,''),(41516,13157,'118707','printshop-mobile','padding-top','20',0,''),(41517,13157,'118707','printshop-mobile','padding-bottom','20',0,''),(41518,13157,'118707','printshop-mobile','padding-left','25',0,''),(41519,13157,'118707','printshop-mobile','padding-right','25',0,''),(41520,13157,'118707','printshop-mobile','background-color','#ffffff',0,''),(41521,13157,'118707','printshop-mobile','margin-bottom','30',0,''),(41522,13158,'118708','printshop-mobile','hide_parents','2',0,''),(41523,13159,'118709','printshop-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(41524,13160,'118710','printshop-mobile','block_type','1',0,''),(41525,13160,'118710','printshop-mobile','background-color','#ffffff',0,''),(41526,13160,'118710','printshop-mobile','padding-top','20',0,''),(41527,13160,'118710','printshop-mobile','padding-bottom','20',0,''),(41528,13160,'118710','printshop-mobile','padding-left','25',0,''),(41529,13160,'118710','printshop-mobile','padding-right','25',0,''),(41530,13160,'118710','printshop-mobile','margin-bottom','30',0,''),(41531,13160,'118710','printshop-mobile','style_class','closeable-box',0,''),(41532,13161,'118711','printshop-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(41533,13161,'118711','printshop-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(41534,13162,'118712','printshop-mobile','block_type','3',0,''),(41535,13162,'118712','printshop-mobile','font-weight','400',0,''),(41536,13162,'118712','printshop-mobile','schema','2-2',0,''),(41537,13162,'118712','printshop-mobile','style_class','closeable-content',0,''),(41538,13162,'118712','printshop-mobile','padding-top','10',0,''),(41539,13163,'118713','printshop-mobile','font-weight','400',0,''),(41540,13163,'118713','printshop-mobile','padding-top','12',0,''),(41541,13163,'118713','printshop-mobile','padding-left','0',0,''),(41542,13166,'118716','printshop-mobile','block_type','1',0,''),(41543,13166,'118716','printshop-mobile','background-color','#ffffff',0,''),(41544,13166,'118716','printshop-mobile','padding-top','20',0,''),(41545,13166,'118716','printshop-mobile','padding-left','25',0,''),(41546,13166,'118716','printshop-mobile','padding-right','25',0,''),(41547,13166,'118716','printshop-mobile','padding-bottom','20',0,''),(41548,13166,'118716','printshop-mobile','margin-bottom','30',0,''),(41549,13166,'118716','printshop-mobile','style_class','closeable-box',0,''),(41550,13166,'118716','printshop-mobile','display','none',0,''),(41552,13167,'118717','printshop-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(41553,13167,'118717','printshop-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(41554,13168,'118718','printshop-mobile','font-weight','normal',0,''),(41555,13168,'118718','printshop-mobile','style_class','closeable-content',0,''),(41556,13168,'118718','printshop-mobile','padding-top','10',0,''),(41557,13168,'118718','printshop-mobile','hide_parents','2',0,''),(41558,13169,'118719','printshop-mobile','style_class','order-summary',0,''),(41559,13169,'118719','printshop-mobile','block_type','1',0,''),(41560,13169,'118719','printshop-mobile','margin-left','30',0,''),(41562,13169,'118719','printshop-mobile','margin-bottom','30',0,''),(41563,13170,'118720','printshop-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(41564,13171,'118721','printshop-mobile','block_type','1',0,''),(41565,13171,'118721','printshop-mobile','padding-left','20',0,''),(41566,13171,'118721','printshop-mobile','padding-right','20',0,''),(41567,13171,'118721','printshop-mobile','padding-bottom','20',0,''),(41568,13172,'118722','printshop-mobile','font-weight','400',0,''),(41569,13172,'118722','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',1,''),(41570,13172,'118722','printshop-mobile','padding-top','20',0,''),(41571,13172,'118722','printshop-mobile','padding-bottom','10',0,''),(41572,13173,'118723','printshop-mobile','font-weight','400',0,''),(41573,13173,'118723','printshop-mobile','box_align','4',0,''),(41574,13173,'118723','printshop-mobile','text-align','center',0,''),(41575,13173,'118723','printshop-mobile','float','none',0,''),(41576,13173,'118723','printshop-mobile','width','100',0,''),(41577,13173,'118723','printshop-mobile','width_measure','%',0,''),(41578,13175,'118725','printshop-mobile','block_type','1',0,''),(41579,13178,'118728','printshop-mobile','block_type','1',0,''),(41580,13179,'118729','printshop-mobile','col_in_row','2',0,''),(41581,13179,'118729','printshop-mobile','products_align','left',0,''),(41582,13179,'118729','printshop-mobile','font-weight','400',0,''),(41583,13179,'118729','printshop-mobile','show_qty_input','1',0,''),(41584,13179,'118729','printshop-mobile','listing_type','productListing',0,''),(41585,13179,'118729','printshop-mobile','listing_type_rows','type-1_2',0,''),(41586,13179,'118729','printshop-mobile','show_buy_button_b2b','on',0,''),(41587,13179,'118729','printshop-mobile','show_wishlist_button_b2b','1',0,''),(41588,13179,'118729','printshop-mobile','show_compare_b2b','1',0,''),(41589,13179,'118729','printshop-mobile','listing_type_b2b','type-1_3',0,''),(41590,13179,'118729','printshop-mobile','show_name','0',0,''),(41591,13179,'118729','printshop-mobile','show_image','0',0,''),(41592,13179,'118729','printshop-mobile','show_stock','0',0,''),(41593,13179,'118729','printshop-mobile','show_description','1',0,''),(41594,13179,'118729','printshop-mobile','show_model','1',0,''),(41595,13179,'118729','printshop-mobile','show_properties','1',0,''),(41596,13179,'118729','printshop-mobile','show_rating_counts','1',0,''),(41597,13179,'118729','printshop-mobile','show_price','0',0,''),(41598,13179,'118729','printshop-mobile','show_buy_button','1',0,''),(41599,13179,'118729','printshop-mobile','show_view_button','1',0,''),(41600,13179,'118729','printshop-mobile','show_wishlist_button','1',0,''),(41601,13179,'118729','printshop-mobile','show_compare','1',0,''),(41602,13179,'118729','printshop-mobile','show_name_rows','0',0,''),(41603,13179,'118729','printshop-mobile','show_image_rows','0',0,''),(41604,13179,'118729','printshop-mobile','show_stock_rows','0',0,''),(41605,13179,'118729','printshop-mobile','show_description_rows','0',0,''),(41606,13179,'118729','printshop-mobile','show_model_rows','0',0,''),(41607,13179,'118729','printshop-mobile','show_properties_rows','0',0,''),(41608,13179,'118729','printshop-mobile','show_rating_rows','0',0,''),(41609,13179,'118729','printshop-mobile','show_rating_counts_rows','0',0,''),(41610,13179,'118729','printshop-mobile','show_price_rows','0',0,''),(41611,13179,'118729','printshop-mobile','show_buy_button_rows','0',0,''),(41612,13179,'118729','printshop-mobile','show_qty_input_rows','0',0,''),(41613,13179,'118729','printshop-mobile','show_view_button_rows','0',0,''),(41614,13179,'118729','printshop-mobile','show_wishlist_button_rows','0',0,''),(41615,13179,'118729','printshop-mobile','show_compare_rows','0',0,''),(41616,13179,'118729','printshop-mobile','show_name_b2b','0',0,''),(41617,13179,'118729','printshop-mobile','show_image_b2b','0',0,''),(41618,13179,'118729','printshop-mobile','show_stock_b2b','0',0,''),(41619,13179,'118729','printshop-mobile','show_description_b2b','0',0,''),(41620,13179,'118729','printshop-mobile','show_model_b2b','0',0,''),(41621,13179,'118729','printshop-mobile','show_properties_b2b','0',0,''),(41622,13179,'118729','printshop-mobile','show_rating_b2b','0',0,''),(41623,13179,'118729','printshop-mobile','show_rating_counts_b2b','0',0,''),(41624,13179,'118729','printshop-mobile','show_price_b2b','0',0,''),(41625,13179,'118729','printshop-mobile','show_qty_input_b2b','0',0,''),(41626,13179,'118729','printshop-mobile','show_view_button_b2b','0',0,''),(41627,13179,'118729','printshop-mobile','show_attributes_b2b','0',0,''),(41628,13179,'118729','printshop-mobile','items_on_page','10',0,''),(41629,13179,'118729','printshop-mobile','product_names_teg','h2',0,''),(41630,13180,'118730','printshop-mobile','block_type','2',0,''),(41631,13180,'118730','printshop-mobile','margin-bottom','20',0,''),(41632,13181,'118731','printshop-mobile','sort_pos_3','1',0,''),(41633,13181,'118731','printshop-mobile','sort_pos_4','2',0,''),(41634,13181,'118731','printshop-mobile','sort_pos_10','5',0,''),(41635,13181,'118731','printshop-mobile','sort_pos_9','6',0,''),(41636,13181,'118731','printshop-mobile','sort_pos_11','7',0,''),(41637,13181,'118731','printshop-mobile','sort_pos_12','8',0,''),(41638,13181,'118731','printshop-mobile','sort_pos_14','9',0,''),(41639,13181,'118731','printshop-mobile','sort_pos_13','10',0,''),(41640,13181,'118731','printshop-mobile','sort_pos_8','11',0,''),(41641,13181,'118731','printshop-mobile','sort_pos_7','12',0,''),(41642,13181,'118731','printshop-mobile','sort_pos_2','13',0,''),(41643,13181,'118731','printshop-mobile','sort_pos_1','14',0,''),(41644,13181,'118731','printshop-mobile','sort_pos_6','15',0,''),(41645,13181,'118731','printshop-mobile','sort_pos_5','16',0,''),(41646,13181,'118731','printshop-mobile','sort_pos_0','17',0,''),(41647,13181,'118731','printshop-mobile','sort_hide_10','1',0,''),(41648,13181,'118731','printshop-mobile','sort_hide_9','1',0,''),(41649,13181,'118731','printshop-mobile','sort_pos_15','4',0,''),(41650,13181,'118731','printshop-mobile','sort_pos_16','3',0,''),(41651,13181,'118731','printshop-mobile','sort_hide_3','0',0,''),(41652,13181,'118731','printshop-mobile','sort_hide_4','0',0,''),(41653,13181,'118731','printshop-mobile','sort_hide_16','1',0,''),(41654,13181,'118731','printshop-mobile','sort_hide_15','1',0,''),(41655,13181,'118731','printshop-mobile','sort_hide_11','0',0,''),(41656,13181,'118731','printshop-mobile','sort_hide_12','0',0,''),(41657,13181,'118731','printshop-mobile','sort_hide_14','0',0,''),(41658,13181,'118731','printshop-mobile','sort_hide_13','0',0,''),(41659,13181,'118731','printshop-mobile','sort_hide_8','0',0,''),(41660,13181,'118731','printshop-mobile','sort_hide_7','0',0,''),(41661,13181,'118731','printshop-mobile','sort_hide_2','0',0,''),(41662,13181,'118731','printshop-mobile','sort_hide_1','0',0,''),(41663,13181,'118731','printshop-mobile','sort_hide_6','0',0,''),(41664,13181,'118731','printshop-mobile','sort_hide_5','0',0,''),(41665,13181,'118731','printshop-mobile','sort_hide_0','0',0,''),(41666,13182,'118732','printshop-mobile','text-align','right',0,''),(41667,13182,'118732','printshop-mobile','padding-top','10',0,''),(41668,13183,'118733','printshop-mobile','text-align','center',0,''),(41669,13183,'118733','printshop-mobile','margin-bottom','20',0,''),(41670,13189,'118739','printshop-mobile','block_type','1',0,''),(41671,13191,'118741','printshop-mobile','block_type','6',0,''),(41672,13191,'118741','printshop-mobile','font-weight','400',0,''),(41673,13191,'118741','printshop-mobile','schema','6-2',0,''),(41675,13192,'118742','printshop-mobile','font-weight','400',0,''),(41676,13192,'118742','printshop-mobile','padding-right','40',0,''),(41679,13194,'118744','printshop-mobile','col_in_row','3',0,''),(41680,13194,'118744','printshop-mobile','products_align','left',0,''),(41681,13194,'118744','printshop-mobile','font-weight','400',0,''),(41682,13194,'118744','printshop-mobile','show_qty_input','0',0,''),(41683,13194,'118744','printshop-mobile','listing_type','productListing',0,''),(41684,13194,'118744','printshop-mobile','listing_type_rows','no',0,''),(41685,13194,'118744','printshop-mobile','show_buy_button_b2b','on',0,''),(41686,13194,'118744','printshop-mobile','show_wishlist_button_b2b','1',0,''),(41687,13194,'118744','printshop-mobile','show_compare_b2b','1',0,''),(41688,13194,'118744','printshop-mobile','show_stock','0',0,''),(41689,13194,'118744','printshop-mobile','show_description','0',0,''),(41690,13194,'118744','printshop-mobile','show_model','0',0,''),(41691,13194,'118744','printshop-mobile','show_properties','0',0,''),(41692,13194,'118744','printshop-mobile','show_rating','0',0,''),(41693,13194,'118744','printshop-mobile','show_rating_counts','0',0,''),(41694,13194,'118744','printshop-mobile','show_price','0',0,''),(41695,13194,'118744','printshop-mobile','show_buy_button','0',0,''),(41696,13194,'118744','printshop-mobile','show_view_button','0',0,''),(41697,13194,'118744','printshop-mobile','show_wishlist_button','0',0,''),(41698,13194,'118744','printshop-mobile','show_compare','0',0,''),(41699,13194,'118744','printshop-mobile','show_name_rows','0',0,''),(41700,13194,'118744','printshop-mobile','show_image_rows','0',0,''),(41701,13194,'118744','printshop-mobile','show_stock_rows','0',0,''),(41702,13194,'118744','printshop-mobile','show_description_rows','0',0,''),(41703,13194,'118744','printshop-mobile','show_model_rows','0',0,''),(41704,13194,'118744','printshop-mobile','show_properties_rows','0',0,''),(41705,13194,'118744','printshop-mobile','show_rating_rows','0',0,''),(41706,13194,'118744','printshop-mobile','show_rating_counts_rows','0',0,''),(41707,13194,'118744','printshop-mobile','show_price_rows','0',0,''),(41708,13194,'118744','printshop-mobile','show_buy_button_rows','0',0,''),(41709,13194,'118744','printshop-mobile','show_qty_input_rows','0',0,''),(41710,13194,'118744','printshop-mobile','show_view_button_rows','0',0,''),(41711,13194,'118744','printshop-mobile','show_wishlist_button_rows','0',0,''),(41712,13194,'118744','printshop-mobile','show_compare_rows','0',0,''),(41713,13194,'118744','printshop-mobile','show_name_b2b','0',0,''),(41714,13194,'118744','printshop-mobile','show_image_b2b','0',0,''),(41715,13194,'118744','printshop-mobile','show_stock_b2b','0',0,''),(41716,13194,'118744','printshop-mobile','show_description_b2b','0',0,''),(41717,13194,'118744','printshop-mobile','show_model_b2b','0',0,''),(41718,13194,'118744','printshop-mobile','show_properties_b2b','0',0,''),(41719,13194,'118744','printshop-mobile','show_rating_b2b','0',0,''),(41720,13194,'118744','printshop-mobile','show_rating_counts_b2b','0',0,''),(41721,13194,'118744','printshop-mobile','show_price_b2b','0',0,''),(41722,13194,'118744','printshop-mobile','show_qty_input_b2b','0',0,''),(41723,13194,'118744','printshop-mobile','show_view_button_b2b','0',0,''),(41724,13194,'118744','printshop-mobile','show_attributes_b2b','0',0,''),(41725,13194,'118744','printshop-mobile','items_on_page','9',0,''),(41728,13194,'118744','printshop-mobile','product_names_teg','h2',0,''),(41729,13195,'118745','printshop-mobile','block_type','1',0,''),(41730,13195,'118745','printshop-mobile','padding-top','10',0,''),(41731,13195,'118745','printshop-mobile','padding-bottom','10',0,''),(41732,13195,'118745','printshop-mobile','border-bottom-width','1',0,''),(41733,13195,'118745','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(41734,13195,'118745','printshop-mobile','margin-left','0',0,''),(41735,13195,'118745','printshop-mobile','margin-right','0',0,''),(41736,13196,'118746','printshop-mobile','float','left',0,''),(41737,13196,'118746','printshop-mobile','clear','none',0,''),(41738,13196,'118746','printshop-mobile','sort_pos_3','1',0,''),(41739,13196,'118746','printshop-mobile','sort_pos_4','2',0,''),(41740,13196,'118746','printshop-mobile','sort_pos_10','3',0,''),(41741,13196,'118746','printshop-mobile','sort_pos_9','4',0,''),(41742,13196,'118746','printshop-mobile','sort_pos_11','5',0,''),(41743,13196,'118746','printshop-mobile','sort_pos_12','6',0,''),(41744,13196,'118746','printshop-mobile','sort_pos_14','7',0,''),(41745,13196,'118746','printshop-mobile','sort_pos_13','8',0,''),(41746,13196,'118746','printshop-mobile','sort_pos_8','9',0,''),(41747,13196,'118746','printshop-mobile','sort_pos_7','10',0,''),(41748,13196,'118746','printshop-mobile','sort_pos_2','11',0,''),(41749,13196,'118746','printshop-mobile','sort_pos_1','12',0,''),(41750,13196,'118746','printshop-mobile','sort_pos_6','13',0,''),(41751,13196,'118746','printshop-mobile','sort_pos_5','14',0,''),(41752,13196,'118746','printshop-mobile','sort_pos_0','15',0,''),(41753,13196,'118746','printshop-mobile','sort_hide_10','1',0,''),(41754,13196,'118746','printshop-mobile','sort_hide_9','1',0,''),(41755,13196,'118746','printshop-mobile','hide_icons','1',0,''),(41756,13196,'118746','printshop-mobile','sort_hide_16','1',0,''),(41757,13196,'118746','printshop-mobile','sort_hide_15','1',0,''),(41758,13196,'118746','printshop-mobile','sort_hide_3','0',0,''),(41759,13196,'118746','printshop-mobile','sort_hide_4','0',0,''),(41760,13196,'118746','printshop-mobile','sort_hide_11','1',0,''),(41761,13196,'118746','printshop-mobile','sort_hide_12','1',0,''),(41762,13196,'118746','printshop-mobile','sort_hide_14','1',0,''),(41763,13196,'118746','printshop-mobile','sort_hide_13','1',0,''),(41764,13196,'118746','printshop-mobile','sort_hide_8','0',0,''),(41765,13196,'118746','printshop-mobile','sort_hide_7','0',0,''),(41766,13196,'118746','printshop-mobile','sort_hide_2','1',0,''),(41767,13196,'118746','printshop-mobile','sort_hide_1','1',0,''),(41768,13196,'118746','printshop-mobile','sort_hide_6','1',0,''),(41769,13196,'118746','printshop-mobile','sort_hide_5','1',0,''),(41770,13196,'118746','printshop-mobile','sort_hide_0','1',0,''),(41771,13197,'118747','printshop-mobile','float','left',0,''),(41772,13197,'118747','printshop-mobile','clear','none',0,''),(41773,13197,'118747','printshop-mobile','margin-left','20',0,''),(41774,13197,'118747','printshop-mobile','display','none',0,''),(41775,13198,'118748','printshop-mobile','margin-right','20',0,''),(41776,13198,'118748','printshop-mobile','float','right',0,''),(41777,13198,'118748','printshop-mobile','clear','none',0,''),(41778,13198,'118748','printshop-mobile','display','none',0,''),(41779,13199,'118749','printshop-mobile','float','right',0,''),(41780,13199,'118749','printshop-mobile','display','none',0,''),(41781,13200,'118750','printshop-mobile','listing_type','productListing',0,''),(41782,13202,'118752','printshop-mobile','block_type','5',0,''),(41783,13202,'118752','printshop-mobile','padding-top','10',0,''),(41784,13202,'118752','printshop-mobile','padding-bottom','10',0,''),(41785,13202,'118752','printshop-mobile','schema','5-2',0,''),(41786,13202,'118752','printshop-mobile','border-top-color','#e0e0e0',0,''),(41787,13202,'118752','printshop-mobile','border-top-width','1',0,''),(41788,13204,'118754','printshop-mobile','float','right',0,''),(41789,13205,'118755','printshop-mobile','block_type','1',0,''),(41790,13207,'118757','printshop-mobile','block_type','5',0,''),(41791,13207,'118757','printshop-mobile','padding-top','10',0,''),(41792,13207,'118757','printshop-mobile','padding-bottom','10',0,''),(41793,13207,'118757','printshop-mobile','schema','5-2',0,''),(41794,13207,'118757','printshop-mobile','border-top-color','#e0e0e0',0,''),(41795,13207,'118757','printshop-mobile','border-top-width','1',0,''),(41796,13209,'118759','printshop-mobile','float','right',0,''),(41797,13210,'118760','printshop-mobile','col_in_row','4',0,''),(41798,13210,'118760','printshop-mobile','products_align','left',0,''),(41799,13210,'118760','printshop-mobile','font-weight','400',0,''),(41800,13210,'118760','printshop-mobile','show_qty_input','0',0,''),(41801,13210,'118760','printshop-mobile','listing_type','productListing',0,''),(41802,13210,'118760','printshop-mobile','listing_type_rows','Rows',0,''),(41803,13210,'118760','printshop-mobile','show_buy_button_b2b','on',0,''),(41804,13210,'118760','printshop-mobile','show_wishlist_button_b2b','1',0,''),(41805,13210,'118760','printshop-mobile','show_compare_b2b','1',0,''),(41806,13210,'118760','printshop-mobile','listing_type_b2b','b2b',0,''),(41807,13210,'118760','printshop-mobile','show_image','0',0,''),(41808,13210,'118760','printshop-mobile','show_stock','0',0,''),(41809,13210,'118760','printshop-mobile','show_description','0',0,''),(41810,13210,'118760','printshop-mobile','show_model','0',0,''),(41811,13210,'118760','printshop-mobile','show_properties','0',0,''),(41812,13210,'118760','printshop-mobile','show_rating','0',0,''),(41813,13210,'118760','printshop-mobile','show_rating_counts','0',0,''),(41814,13210,'118760','printshop-mobile','show_price','0',0,''),(41815,13210,'118760','printshop-mobile','show_buy_button','0',0,''),(41816,13210,'118760','printshop-mobile','show_view_button','0',0,''),(41817,13210,'118760','printshop-mobile','show_wishlist_button','0',0,''),(41818,13210,'118760','printshop-mobile','show_compare','0',0,''),(41819,13210,'118760','printshop-mobile','show_name_rows','0',0,''),(41820,13210,'118760','printshop-mobile','show_image_rows','0',0,''),(41821,13210,'118760','printshop-mobile','show_stock_rows','0',0,''),(41822,13210,'118760','printshop-mobile','show_description_rows','0',0,''),(41823,13210,'118760','printshop-mobile','show_model_rows','0',0,''),(41824,13210,'118760','printshop-mobile','show_properties_rows','0',0,''),(41825,13210,'118760','printshop-mobile','show_rating_rows','0',0,''),(41826,13210,'118760','printshop-mobile','show_rating_counts_rows','0',0,''),(41827,13210,'118760','printshop-mobile','show_price_rows','0',0,''),(41828,13210,'118760','printshop-mobile','show_buy_button_rows','0',0,''),(41829,13210,'118760','printshop-mobile','show_qty_input_rows','0',0,''),(41830,13210,'118760','printshop-mobile','show_view_button_rows','0',0,''),(41831,13210,'118760','printshop-mobile','show_wishlist_button_rows','0',0,''),(41832,13210,'118760','printshop-mobile','show_compare_rows','0',0,''),(41833,13210,'118760','printshop-mobile','show_name_b2b','0',0,''),(41834,13210,'118760','printshop-mobile','show_image_b2b','0',0,''),(41835,13210,'118760','printshop-mobile','show_stock_b2b','0',0,''),(41836,13210,'118760','printshop-mobile','show_description_b2b','0',0,''),(41837,13210,'118760','printshop-mobile','show_model_b2b','0',0,''),(41838,13210,'118760','printshop-mobile','show_properties_b2b','0',0,''),(41839,13210,'118760','printshop-mobile','show_rating_b2b','0',0,''),(41840,13210,'118760','printshop-mobile','show_rating_counts_b2b','0',0,''),(41841,13210,'118760','printshop-mobile','show_price_b2b','0',0,''),(41842,13210,'118760','printshop-mobile','show_qty_input_b2b','0',0,''),(41843,13210,'118760','printshop-mobile','show_view_button_b2b','0',0,''),(41844,13210,'118760','printshop-mobile','show_attributes_b2b','0',0,''),(41845,13210,'118760','printshop-mobile','items_on_page','12',0,''),(41848,13210,'118760','printshop-mobile','product_names_teg','h2',0,''),(41850,13212,'118762','printshop-mobile','block_type','1',0,''),(41851,13212,'118762','printshop-mobile','padding-top','10',0,''),(41852,13212,'118762','printshop-mobile','padding-bottom','10',0,''),(41853,13212,'118762','printshop-mobile','border-bottom-width','1',0,''),(41854,13212,'118762','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(41855,13212,'118762','printshop-mobile','margin-left','0',0,''),(41856,13212,'118762','printshop-mobile','margin-right','0',0,''),(41857,13213,'118763','printshop-mobile','float','right',0,''),(41858,13213,'118763','printshop-mobile','display','none',0,''),(41859,13214,'118764','printshop-mobile','margin-right','20',0,''),(41860,13214,'118764','printshop-mobile','float','right',0,''),(41861,13214,'118764','printshop-mobile','clear','none',0,''),(41862,13214,'118764','printshop-mobile','display','none',0,''),(41863,13215,'118765','printshop-mobile','clear','none',0,''),(41864,13215,'118765','printshop-mobile','float','left',0,''),(41865,13215,'118765','printshop-mobile','padding-top','3',0,''),(41866,13215,'118765','printshop-mobile','padding-left','20',0,''),(41867,13216,'118766','printshop-mobile','float','left',0,''),(41868,13216,'118766','printshop-mobile','clear','none',0,''),(41869,13216,'118766','printshop-mobile','margin-left','20',0,''),(41870,13216,'118766','printshop-mobile','display','none',0,''),(41871,13217,'118767','printshop-mobile','float','left',0,''),(41872,13217,'118767','printshop-mobile','clear','none',0,''),(41873,13217,'118767','printshop-mobile','sort_pos_3','1',0,''),(41874,13217,'118767','printshop-mobile','sort_pos_4','2',0,''),(41875,13217,'118767','printshop-mobile','sort_pos_10','3',0,''),(41876,13217,'118767','printshop-mobile','sort_pos_9','4',0,''),(41877,13217,'118767','printshop-mobile','sort_pos_11','5',0,''),(41878,13217,'118767','printshop-mobile','sort_pos_12','6',0,''),(41879,13217,'118767','printshop-mobile','sort_pos_14','7',0,''),(41880,13217,'118767','printshop-mobile','sort_pos_13','8',0,''),(41881,13217,'118767','printshop-mobile','sort_pos_8','9',0,''),(41882,13217,'118767','printshop-mobile','sort_pos_7','10',0,''),(41883,13217,'118767','printshop-mobile','sort_pos_2','11',0,''),(41884,13217,'118767','printshop-mobile','sort_pos_1','12',0,''),(41885,13217,'118767','printshop-mobile','sort_pos_6','13',0,''),(41886,13217,'118767','printshop-mobile','sort_pos_5','14',0,''),(41887,13217,'118767','printshop-mobile','sort_pos_0','15',0,''),(41888,13217,'118767','printshop-mobile','sort_hide_10','1',0,''),(41889,13217,'118767','printshop-mobile','sort_hide_9','1',0,''),(41890,13217,'118767','printshop-mobile','hide_icons','1',0,''),(41891,13217,'118767','printshop-mobile','sort_hide_16','1',0,''),(41892,13217,'118767','printshop-mobile','sort_hide_15','1',0,''),(41893,13217,'118767','printshop-mobile','sort_hide_3','0',0,''),(41894,13217,'118767','printshop-mobile','sort_hide_4','0',0,''),(41895,13217,'118767','printshop-mobile','sort_hide_11','1',0,''),(41896,13217,'118767','printshop-mobile','sort_hide_12','1',0,''),(41897,13217,'118767','printshop-mobile','sort_hide_14','1',0,''),(41898,13217,'118767','printshop-mobile','sort_hide_13','1',0,''),(41899,13217,'118767','printshop-mobile','sort_hide_8','0',0,''),(41900,13217,'118767','printshop-mobile','sort_hide_7','0',0,''),(41901,13217,'118767','printshop-mobile','sort_hide_2','1',0,''),(41902,13217,'118767','printshop-mobile','sort_hide_1','1',0,''),(41903,13217,'118767','printshop-mobile','sort_hide_6','1',0,''),(41904,13217,'118767','printshop-mobile','sort_hide_5','1',0,''),(41905,13217,'118767','printshop-mobile','sort_hide_0','1',0,''),(41906,13220,'118770','printshop-mobile','block_type','1',0,''),(41907,13220,'118770','printshop-mobile','background-color','#eeeeee',0,''),(41908,13220,'118770','printshop-mobile','padding-top','30',0,''),(41909,13220,'118770','printshop-mobile','padding-bottom','30',0,''),(41910,13221,'118771','printshop-mobile','block_type','1',0,''),(41911,13221,'118771','printshop-mobile','schema','4-2',0,''),(41912,13221,'118771','printshop-mobile','schema','4-1',0,'702'),(41913,13222,'118772','printshop-mobile','block_type','1',0,''),(41914,13222,'118772','printshop-mobile','padding-right','40',0,''),(41916,13223,'118773','printshop-mobile','block_type','1',0,''),(41917,13223,'118773','printshop-mobile','padding-top','30',0,''),(41918,13223,'118773','printshop-mobile','padding-left','30',0,''),(41919,13223,'118773','printshop-mobile','padding-right','30',0,''),(41920,13223,'118773','printshop-mobile','padding-bottom','23',0,''),(41921,13223,'118773','printshop-mobile','margin-bottom','20',0,''),(41922,13223,'118773','printshop-mobile','background-color','#ffffff',0,''),(41923,13223,'118773','printshop-mobile','style_class','hiding-box',0,''),(41924,13224,'118774','printshop-mobile','block_type','2',0,''),(41925,13224,'118774','printshop-mobile','schema','2-2',0,''),(41926,13224,'118774','printshop-mobile','schema','2-2',0,'702'),(41927,13225,'118775','printshop-mobile','padding-right','20',0,''),(41929,13225,'118775','printshop-mobile','padding-bottom','20',0,''),(41930,13225,'118775','printshop-mobile','address_in','popup',0,''),(41931,13226,'118776','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(41932,13227,'118777','printshop-mobile','block_type','1',0,''),(41933,13227,'118777','printshop-mobile','padding-left','20',0,''),(41935,13228,'118778','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(41936,13230,'118780','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(41937,13231,'118781','printshop-mobile','block_type','1',0,''),(41938,13231,'118781','printshop-mobile','background-color','#ffffff',0,''),(41939,13231,'118781','printshop-mobile','padding-top','30',0,''),(41940,13231,'118781','printshop-mobile','padding-left','30',0,''),(41941,13231,'118781','printshop-mobile','padding-right','30',0,''),(41942,13231,'118781','printshop-mobile','padding-bottom','30',0,''),(41943,13231,'118781','printshop-mobile','margin-bottom','20',0,''),(41944,13231,'118781','printshop-mobile','style_class','hiding-box',0,''),(41945,13232,'118782','printshop-mobile','padding-top','10',0,''),(41946,13232,'118782','printshop-mobile','padding-left','20',0,''),(41947,13232,'118782','printshop-mobile','padding-right','20',0,''),(41948,13232,'118782','printshop-mobile','margin-top','20',0,''),(41949,13232,'118782','printshop-mobile','background-color','#eeeeee',0,''),(41950,13232,'118782','printshop-mobile','padding-bottom','8',0,''),(41951,13233,'118783','printshop-mobile','margin-bottom','20',0,''),(41952,13234,'118784','printshop-mobile','background-color','#ffffff',0,''),(41953,13234,'118784','printshop-mobile','block_type','1',0,''),(41954,13234,'118784','printshop-mobile','padding-top','30',0,''),(41955,13234,'118784','printshop-mobile','padding-left','30',0,''),(41956,13234,'118784','printshop-mobile','padding-right','30',0,''),(41957,13234,'118784','printshop-mobile','padding-bottom','30',0,''),(41958,13234,'118784','printshop-mobile','margin-bottom','20',0,''),(41959,13234,'118784','printshop-mobile','style_class','hiding-box',0,''),(41960,13235,'118785','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(41961,13236,'118786','printshop-mobile','block_type','1',0,''),(41962,13236,'118786','printshop-mobile','schema','2-2',0,''),(41963,13236,'118786','printshop-mobile','schema','2-1',0,'702'),(41964,13237,'118787','printshop-mobile','block_type','1',0,''),(41965,13237,'118787','printshop-mobile','padding-left','0',0,''),(41966,13237,'118787','printshop-mobile','margin-bottom','20',0,''),(41967,13240,'118790','printshop-mobile','address_in','popup',0,''),(41968,13241,'118791','printshop-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(41969,13242,'118792','printshop-mobile','block_type','1',0,''),(41970,13242,'118792','printshop-mobile','padding-left','20',0,''),(41972,13243,'118793','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(41973,13244,'118794','printshop-mobile','border-top-width','1',0,''),(41974,13244,'118794','printshop-mobile','border-top-color','#e0e0e0',0,''),(41975,13244,'118794','printshop-mobile','padding-top','13',0,''),(41976,13244,'118794','printshop-mobile','padding-bottom','10',0,''),(41977,13246,'118796','printshop-mobile','background-color','#eeeeee',0,''),(41978,13246,'118796','printshop-mobile','padding-top','10',0,''),(41979,13246,'118796','printshop-mobile','padding-left','10',0,''),(41980,13246,'118796','printshop-mobile','padding-right','10',0,''),(41981,13246,'118796','printshop-mobile','padding-bottom','10',0,''),(41982,13246,'118796','printshop-mobile','margin-top','10',0,''),(41983,13247,'118797','printshop-mobile','block_type','1',0,''),(41984,13247,'118797','printshop-mobile','content','\\_',0,'3'),(41985,13247,'118797','printshop-mobile','border-top-width','1',0,'3'),(41986,13247,'118797','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(41987,13247,'118797','printshop-mobile','display','block',0,'3'),(41988,13247,'118797','printshop-mobile','position','absolute',0,'3'),(41989,13247,'118797','printshop-mobile','top','19',0,'3'),(41990,13247,'118797','printshop-mobile','left','0',0,'3'),(41991,13247,'118797','printshop-mobile','right','0',0,'3'),(41992,13247,'118797','printshop-mobile','margin-top','-2',0,'3'),(41993,13247,'118797','printshop-mobile','position','relative',0,''),(41994,13248,'118798','printshop-mobile','box_align','2',0,''),(41995,13248,'118798','printshop-mobile','margin-bottom','10',0,''),(41996,13248,'118798','printshop-mobile','background-color','#ffffff',0,''),(41997,13248,'118798','printshop-mobile','position','relative',0,''),(41998,13249,'118799','printshop-mobile','block_type','1',0,''),(41999,13249,'118799','printshop-mobile','padding-top','30',0,''),(42000,13249,'118799','printshop-mobile','padding-left','30',0,''),(42001,13249,'118799','printshop-mobile','padding-right','30',0,''),(42002,13249,'118799','printshop-mobile','padding-bottom','14',0,''),(42003,13249,'118799','printshop-mobile','margin-bottom','20',0,''),(42004,13249,'118799','printshop-mobile','background-color','#ffffff',0,''),(42005,13249,'118799','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42006,13250,'118800','printshop-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(42007,13250,'118800','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42008,13251,'118801','printshop-mobile','block_type','2',0,''),(42009,13251,'118801','printshop-mobile','style_class','closeable-content',0,''),(42010,13251,'118801','printshop-mobile','schema','2-2',0,''),(42011,13251,'118801','printshop-mobile','schema','2-2',0,'702'),(42012,13252,'118802','printshop-mobile','padding-right','20',0,''),(42013,13252,'118802','printshop-mobile','padding-bottom','20',0,''),(42015,13253,'118803','printshop-mobile','padding-left','20',0,''),(42016,13253,'118803','printshop-mobile','padding-bottom','20',0,''),(42018,13254,'118804','printshop-mobile','padding-left','20',0,''),(42019,13254,'118804','printshop-mobile','padding-bottom','20',0,''),(42021,13255,'118805','printshop-mobile','block_type','1',0,''),(42022,13255,'118805','printshop-mobile','background-color','#ffffff',0,''),(42023,13255,'118805','printshop-mobile','padding-top','30',0,''),(42024,13255,'118805','printshop-mobile','padding-left','30',0,''),(42025,13255,'118805','printshop-mobile','padding-right','30',0,''),(42026,13255,'118805','printshop-mobile','padding-bottom','14',0,''),(42027,13255,'118805','printshop-mobile','margin-bottom','20',0,''),(42028,13255,'118805','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42029,13256,'118806','printshop-mobile','style_class','closeable-content',0,''),(42030,13256,'118806','printshop-mobile','padding-bottom','20',0,''),(42031,13257,'118807','printshop-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(42032,13257,'118807','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42033,13258,'118808','printshop-mobile','block_type','1',0,''),(42034,13258,'118808','printshop-mobile','padding-top','20',0,''),(42035,13258,'118808','printshop-mobile','padding-left','20',0,''),(42036,13258,'118808','printshop-mobile','padding-right','20',0,''),(42037,13258,'118808','printshop-mobile','padding-bottom','20',0,''),(42038,13258,'118808','printshop-mobile','background-color','#ffffff',0,''),(42039,13258,'118808','printshop-mobile','style_class','order-summary',0,''),(42040,13259,'118809','printshop-mobile','margin-bottom','10',0,''),(42041,13261,'118811','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(42042,13262,'118812','printshop-mobile','hide_page','1',0,''),(42043,13262,'118812','printshop-mobile','hide_continue_button','1',0,''),(42044,13263,'118813','printshop-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(42045,13263,'118813','printshop-mobile','text-align','center',0,''),(42046,13263,'118813','printshop-mobile','font-size','14',0,''),(42047,13263,'118813','printshop-mobile','color','#757575',0,''),(42048,13263,'118813','printshop-mobile','padding-top','10',0,''),(42049,13264,'118814','printshop-mobile','block_type','1',0,''),(42050,13265,'118815','printshop-mobile','margin-bottom','20',0,''),(42051,13265,'118815','printshop-mobile','text-align','right',0,''),(42052,13267,'118817','printshop-mobile','block_type','2',0,''),(42053,13267,'118817','printshop-mobile','margin-bottom','20',0,''),(42054,13267,'118817','printshop-mobile','schema','2-2',0,''),(42055,13268,'118818','printshop-mobile','block_type','1',0,''),(42056,13268,'118818','printshop-mobile','padding-right','20',0,''),(42058,13269,'118819','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(42059,13269,'118819','printshop-mobile','clear','none',0,''),(42060,13271,'118821','printshop-mobile','block_type','1',0,''),(42061,13271,'118821','printshop-mobile','padding-left','20',0,''),(42063,13272,'118822','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42064,13272,'118822','printshop-mobile','clear','none',0,''),(42065,13274,'118824','printshop-mobile','text-align','right',0,''),(42066,13274,'118824','printshop-mobile','margin-bottom','20',0,''),(42067,13275,'118825','printshop-mobile','block_type','2',0,''),(42068,13275,'118825','printshop-mobile','margin-bottom','20',0,''),(42069,13275,'118825','printshop-mobile','schema','2-2',0,''),(42070,13276,'118826','printshop-mobile','block_type','1',0,''),(42071,13276,'118826','printshop-mobile','padding-right','20',0,''),(42073,13277,'118827','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42074,13277,'118827','printshop-mobile','clear','none',0,''),(42075,13279,'118829','printshop-mobile','padding-left','20',0,''),(42076,13279,'118829','printshop-mobile','block_type','1',0,''),(42078,13281,'118831','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42079,13281,'118831','printshop-mobile','clear','none',0,''),(42080,13282,'118832','printshop-mobile','link','products',0,''),(42081,13282,'118832','printshop-mobile','margin-top','-33',0,''),(42082,13282,'118832','printshop-mobile','float','right',0,''),(42083,13284,'118834','printshop-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(42084,13285,'118835','printshop-mobile','block_type','1',0,''),(42085,13286,'118836','printshop-mobile','margin-bottom','20',0,''),(42086,13287,'118837','printshop-mobile','text-align','right',0,''),(42087,13287,'118837','printshop-mobile','margin-bottom','20',0,''),(42088,13288,'118838','printshop-mobile','block_type','2',0,''),(42089,13288,'118838','printshop-mobile','margin-bottom','20',0,''),(42090,13288,'118838','printshop-mobile','schema','2-2',0,''),(42091,13289,'118839','printshop-mobile','block_type','1',0,''),(42092,13289,'118839','printshop-mobile','padding-right','20',0,''),(42094,13290,'118840','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42095,13290,'118840','printshop-mobile','clear','none',0,''),(42096,13292,'118842','printshop-mobile','block_type','1',0,''),(42097,13292,'118842','printshop-mobile','padding-left','20',0,''),(42099,13293,'118843','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42100,13293,'118843','printshop-mobile','clear','none',0,''),(42101,13295,'118845','printshop-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(42102,13296,'118846','printshop-mobile','margin-bottom','20',0,''),(42103,13297,'118847','printshop-mobile','margin-bottom','20',0,''),(42104,13297,'118847','printshop-mobile','text-align','right',0,''),(42105,13298,'118848','printshop-mobile','block_type','1',0,''),(42106,13299,'118849','printshop-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(42107,13300,'118850','printshop-mobile','margin-bottom','20',0,''),(42108,13300,'118850','printshop-mobile','text-align','right',0,''),(42109,13303,'118853','printshop-mobile','text-align','right',0,''),(42110,13303,'118853','printshop-mobile','margin-bottom','20',0,''),(42111,13304,'118854','printshop-mobile','block_type','2',0,''),(42112,13304,'118854','printshop-mobile','margin-bottom','20',0,''),(42113,13304,'118854','printshop-mobile','schema','2-2',0,''),(42114,13305,'118855','printshop-mobile','block_type','1',0,''),(42115,13305,'118855','printshop-mobile','padding-right','20',0,''),(42117,13307,'118857','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42118,13307,'118857','printshop-mobile','clear','none',0,''),(42119,13308,'118858','printshop-mobile','block_type','1',0,''),(42120,13308,'118858','printshop-mobile','padding-left','20',0,''),(42122,13309,'118859','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42123,13309,'118859','printshop-mobile','clear','none',0,''),(42124,13311,'118861','printshop-mobile','block_type','1',0,''),(42125,13312,'118862','printshop-mobile','block_type','2',0,''),(42126,13312,'118862','printshop-mobile','margin-bottom','20',0,''),(42127,13312,'118862','printshop-mobile','schema','2-2',0,''),(42128,13313,'118863','printshop-mobile','block_type','1',0,''),(42129,13313,'118863','printshop-mobile','padding-right','20',0,''),(42131,13315,'118865','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42132,13315,'118865','printshop-mobile','clear','none',0,''),(42133,13316,'118866','printshop-mobile','padding-left','20',0,''),(42134,13316,'118866','printshop-mobile','block_type','1',0,''),(42136,13317,'118867','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42137,13317,'118867','printshop-mobile','clear','none',0,''),(42138,13319,'118869','printshop-mobile','text-align','right',0,''),(42139,13319,'118869','printshop-mobile','margin-bottom','20',0,''),(42140,13320,'118870','printshop-mobile','margin-bottom','20',0,''),(42141,13320,'118870','printshop-mobile','text-align','right',0,''),(42142,13321,'118871','printshop-mobile','link','products',0,''),(42143,13321,'118871','printshop-mobile','margin-top','-33',0,''),(42144,13321,'118871','printshop-mobile','float','right',0,''),(42145,13322,'118872','printshop-mobile','margin-bottom','20',0,''),(42146,13323,'118873','printshop-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(42147,13324,'118874','printshop-mobile','margin-bottom','20',0,''),(42148,13325,'118875','printshop-mobile','block_type','2',0,''),(42149,13325,'118875','printshop-mobile','margin-bottom','20',0,''),(42150,13325,'118875','printshop-mobile','schema','2-2',0,''),(42151,13326,'118876','printshop-mobile','block_type','1',0,''),(42152,13326,'118876','printshop-mobile','padding-right','20',0,''),(42154,13328,'118878','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(42155,13328,'118878','printshop-mobile','clear','none',0,''),(42156,13329,'118879','printshop-mobile','block_type','1',0,''),(42157,13329,'118879','printshop-mobile','padding-left','20',0,''),(42159,13330,'118880','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42160,13330,'118880','printshop-mobile','clear','none',0,''),(42161,13332,'118882','printshop-mobile','text','##TEXT_CONFIRMATION##',0,''),(42162,13333,'118883','printshop-mobile','text','##TEXT_CONFIRMATION##',0,''),(42163,13334,'118884','printshop-mobile','text','##TEXT_CONFIRMATION##',0,''),(42164,13335,'118885','printshop-mobile','text','##TEXT_CONFIRMATION##',0,''),(42165,13336,'118886','printshop-mobile','text','##TEXT_CONFIRMATION##',0,''),(42166,13337,'118887','printshop-mobile','text','##TEXT_CONFIRMATION##',0,''),(42167,13338,'118888','printshop-mobile','block_type','2',0,''),(42168,13339,'118889','printshop-mobile','block_type','1',0,''),(42169,13339,'118889','printshop-mobile','padding-right','20',0,''),(42171,13341,'118891','printshop-mobile','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(42172,13342,'118892','printshop-mobile','block_type','1',0,''),(42173,13342,'118892','printshop-mobile','padding-right','0',0,''),(42174,13342,'118892','printshop-mobile','padding-left','20',0,''),(42175,13344,'118894','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42176,13347,'118897','printshop-mobile','block_type','2',0,''),(42177,13348,'118898','printshop-mobile','block_type','1',0,''),(42178,13348,'118898','printshop-mobile','padding-right','20',0,''),(42179,13349,'118899','printshop-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(42180,13351,'118901','printshop-mobile','block_type','1',0,''),(42181,13351,'118901','printshop-mobile','padding-left','20',0,''),(42183,13352,'118902','printshop-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(42184,13354,'118904','printshop-mobile','block_type','4',0,''),(42185,13354,'118904','printshop-mobile','schema','4-2',0,''),(42186,13355,'118905','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42187,13355,'118905','printshop-mobile','text-align','right',0,''),(42188,13355,'118905','printshop-mobile','padding-top','10',0,''),(42189,13355,'118905','printshop-mobile','font_size_measure','em',0,''),(42190,13355,'118905','printshop-mobile','font-size','1.2',0,''),(42191,13356,'118906','printshop-mobile','text-align','right',0,''),(42192,13357,'118907','printshop-mobile','block_type','2',0,''),(42193,13358,'118908','printshop-mobile','block_type','1',0,''),(42194,13358,'118908','printshop-mobile','padding-right','20',0,''),(42196,13360,'118910','printshop-mobile','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(42197,13361,'118911','printshop-mobile','block_type','1',0,''),(42198,13361,'118911','printshop-mobile','padding-right','0',0,''),(42199,13361,'118911','printshop-mobile','padding-left','20',0,''),(42200,13362,'118912','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42201,13366,'118916','printshop-mobile','block_type','4',0,''),(42202,13366,'118916','printshop-mobile','schema','4-2',0,''),(42203,13367,'118917','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42204,13367,'118917','printshop-mobile','text-align','right',0,''),(42205,13367,'118917','printshop-mobile','padding-top','10',0,''),(42206,13367,'118917','printshop-mobile','font_size_measure','em',0,''),(42207,13367,'118917','printshop-mobile','font-size','1.2',0,''),(42208,13368,'118918','printshop-mobile','text-align','right',0,''),(42209,13369,'118919','printshop-mobile','block_type','2',0,''),(42210,13370,'118920','printshop-mobile','block_type','1',0,''),(42211,13370,'118920','printshop-mobile','padding-right','20',0,''),(42212,13372,'118922','printshop-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(42213,13373,'118923','printshop-mobile','block_type','1',0,''),(42214,13373,'118923','printshop-mobile','padding-left','20',0,''),(42216,13375,'118925','printshop-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(42217,13376,'118926','printshop-mobile','block_type','4',0,''),(42218,13376,'118926','printshop-mobile','schema','4-2',0,''),(42219,13377,'118927','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42220,13377,'118927','printshop-mobile','text-align','right',0,''),(42221,13377,'118927','printshop-mobile','padding-top','10',0,''),(42222,13377,'118927','printshop-mobile','font_size_measure','em',0,''),(42223,13377,'118927','printshop-mobile','font-size','1.2',0,''),(42224,13378,'118928','printshop-mobile','text-align','right',0,''),(42225,13379,'118929','printshop-mobile','block_type','2',0,''),(42226,13380,'118930','printshop-mobile','block_type','1',0,''),(42227,13380,'118930','printshop-mobile','padding-right','20',0,''),(42228,13382,'118932','printshop-mobile','block_type','1',0,''),(42229,13382,'118932','printshop-mobile','padding-left','20',0,''),(42231,13384,'118934','printshop-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(42232,13385,'118935','printshop-mobile','block_type','2',0,''),(42233,13386,'118936','printshop-mobile','block_type','1',0,''),(42234,13386,'118936','printshop-mobile','padding-right','20',0,''),(42235,13388,'118938','printshop-mobile','block_type','1',0,''),(42236,13388,'118938','printshop-mobile','padding-left','20',0,''),(42238,13389,'118939','printshop-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(42239,13391,'118941','printshop-mobile','block_type','4',0,''),(42240,13391,'118941','printshop-mobile','schema','4-2',0,''),(42241,13392,'118942','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42242,13392,'118942','printshop-mobile','text-align','right',0,''),(42243,13392,'118942','printshop-mobile','padding-top','10',0,''),(42244,13392,'118942','printshop-mobile','font_size_measure','em',0,''),(42245,13392,'118942','printshop-mobile','font-size','1.2',0,''),(42246,13393,'118943','printshop-mobile','text-align','right',0,''),(42247,13394,'118944','printshop-mobile','text','##DELIVERY_DETAILS##',0,''),(42248,13395,'118945','printshop-mobile','text','##DELIVERY_DETAILS##',0,''),(42249,13396,'118946','printshop-mobile','text','##CONTACT_INFORMATION##',0,''),(42250,13397,'118947','printshop-mobile','text','##CONTACT_INFORMATION##',0,''),(42251,13398,'118948','printshop-mobile','text','##DELIVERY_DETAILS##',0,''),(42252,13399,'118949','printshop-mobile','text','##DELIVERY_DETAILS##',0,''),(42253,13400,'118950','printshop-mobile','block_type','1',0,''),(42254,13400,'118950','printshop-mobile','background-color','#eeeeee',0,''),(42255,13400,'118950','printshop-mobile','padding-top','30',0,''),(42256,13400,'118950','printshop-mobile','padding-bottom','30',0,''),(42257,13401,'118951','printshop-mobile','block_type','4',0,''),(42258,13401,'118951','printshop-mobile','schema','4-2',0,''),(42259,13402,'118952','printshop-mobile','block_type','1',0,''),(42260,13402,'118952','printshop-mobile','padding-right','40',0,''),(42262,13403,'118953','printshop-mobile','background-color','#ffffff',0,''),(42263,13403,'118953','printshop-mobile','block_type','1',0,''),(42264,13403,'118953','printshop-mobile','padding-top','30',0,''),(42265,13403,'118953','printshop-mobile','padding-left','30',0,''),(42266,13403,'118953','printshop-mobile','padding-right','30',0,''),(42267,13403,'118953','printshop-mobile','padding-bottom','30',0,''),(42268,13403,'118953','printshop-mobile','margin-bottom','20',0,''),(42269,13403,'118953','printshop-mobile','style_class','hiding-box',0,''),(42270,13404,'118954','printshop-mobile','background-color','#eeeeee',0,''),(42271,13404,'118954','printshop-mobile','padding-top','10',0,''),(42272,13404,'118954','printshop-mobile','padding-left','10',0,''),(42273,13404,'118954','printshop-mobile','padding-right','10',0,''),(42274,13404,'118954','printshop-mobile','padding-bottom','10',0,''),(42275,13404,'118954','printshop-mobile','margin-top','10',0,''),(42276,13405,'118955','printshop-mobile','block_type','2',0,''),(42277,13405,'118955','printshop-mobile','schema','2-2',0,''),(42278,13406,'118956','printshop-mobile','block_type','1',0,''),(42279,13406,'118956','printshop-mobile','padding-right','20',0,''),(42280,13406,'118956','printshop-mobile','padding-left','0',0,''),(42281,13406,'118956','printshop-mobile','margin-bottom','20',0,''),(42282,13408,'118958','printshop-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(42283,13410,'118960','printshop-mobile','block_type','1',0,''),(42284,13410,'118960','printshop-mobile','padding-left','20',0,''),(42286,13411,'118961','printshop-mobile','border-top-width','1',0,''),(42287,13411,'118961','printshop-mobile','border-top-color','#e0e0e0',0,''),(42288,13411,'118961','printshop-mobile','padding-top','13',0,''),(42289,13411,'118961','printshop-mobile','padding-bottom','10',0,''),(42290,13412,'118962','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(42291,13413,'118963','printshop-mobile','block_type','1',0,''),(42292,13413,'118963','printshop-mobile','content','\\_',0,'3'),(42293,13413,'118963','printshop-mobile','border-top-width','1',0,'3'),(42294,13413,'118963','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(42295,13413,'118963','printshop-mobile','display','block',0,'3'),(42296,13413,'118963','printshop-mobile','position','absolute',0,'3'),(42297,13413,'118963','printshop-mobile','top','19',0,'3'),(42298,13413,'118963','printshop-mobile','left','0',0,'3'),(42299,13413,'118963','printshop-mobile','right','0',0,'3'),(42300,13413,'118963','printshop-mobile','margin-top','-2',0,'3'),(42301,13413,'118963','printshop-mobile','position','relative',0,''),(42302,13414,'118964','printshop-mobile','box_align','2',0,''),(42303,13414,'118964','printshop-mobile','margin-bottom','10',0,''),(42304,13414,'118964','printshop-mobile','background-color','#ffffff',0,''),(42305,13414,'118964','printshop-mobile','position','relative',0,''),(42306,13415,'118965','printshop-mobile','block_type','1',0,''),(42307,13415,'118965','printshop-mobile','background-color','#ffffff',0,''),(42308,13415,'118965','printshop-mobile','padding-top','30',0,''),(42309,13415,'118965','printshop-mobile','padding-left','30',0,''),(42310,13415,'118965','printshop-mobile','padding-right','30',0,''),(42311,13415,'118965','printshop-mobile','padding-bottom','14',0,''),(42312,13415,'118965','printshop-mobile','margin-bottom','20',0,''),(42313,13415,'118965','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42314,13416,'118966','printshop-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(42315,13416,'118966','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42316,13417,'118967','printshop-mobile','style_class','closeable-content',0,''),(42317,13417,'118967','printshop-mobile','padding-bottom','20',0,''),(42318,13418,'118968','printshop-mobile','background-color','#ffffff',0,''),(42319,13418,'118968','printshop-mobile','padding-top','30',0,''),(42320,13418,'118968','printshop-mobile','padding-left','30',0,''),(42321,13418,'118968','printshop-mobile','padding-right','30',0,''),(42322,13418,'118968','printshop-mobile','padding-bottom','30',0,''),(42323,13418,'118968','printshop-mobile','margin-bottom','20',0,''),(42324,13419,'118969','printshop-mobile','block_type','1',0,''),(42325,13419,'118969','printshop-mobile','background-color','#ffffff',0,''),(42326,13419,'118969','printshop-mobile','padding-top','30',0,''),(42327,13419,'118969','printshop-mobile','padding-left','30',0,''),(42328,13419,'118969','printshop-mobile','padding-right','30',0,''),(42329,13419,'118969','printshop-mobile','padding-bottom','30',0,''),(42330,13419,'118969','printshop-mobile','margin-bottom','20',0,''),(42331,13419,'118969','printshop-mobile','style_class','hiding-box',0,''),(42332,13420,'118970','printshop-mobile','padding-top','10',0,''),(42333,13420,'118970','printshop-mobile','padding-left','20',0,''),(42334,13420,'118970','printshop-mobile','padding-right','20',0,''),(42335,13420,'118970','printshop-mobile','margin-top','20',0,''),(42336,13420,'118970','printshop-mobile','background-color','#eeeeee',0,''),(42337,13420,'118970','printshop-mobile','padding-bottom','8',0,''),(42338,13421,'118971','printshop-mobile','margin-bottom','20',0,''),(42339,13422,'118972','printshop-mobile','block_type','1',0,''),(42340,13422,'118972','printshop-mobile','padding-top','20',0,''),(42341,13422,'118972','printshop-mobile','padding-left','20',0,''),(42342,13422,'118972','printshop-mobile','padding-right','20',0,''),(42343,13422,'118972','printshop-mobile','padding-bottom','20',0,''),(42344,13422,'118972','printshop-mobile','background-color','#ffffff',0,''),(42345,13422,'118972','printshop-mobile','style_class','order-summary',0,''),(42346,13424,'118974','printshop-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(42347,13424,'118974','printshop-mobile','text-align','center',0,''),(42348,13424,'118974','printshop-mobile','font-size','14',0,''),(42349,13424,'118974','printshop-mobile','color','#757575',0,''),(42350,13424,'118974','printshop-mobile','padding-top','10',0,''),(42351,13425,'118975','printshop-mobile','block_type','1',0,''),(42352,13425,'118975','printshop-mobile','background-color','#eeeeee',0,''),(42353,13425,'118975','printshop-mobile','padding-top','30',0,''),(42354,13425,'118975','printshop-mobile','padding-bottom','30',0,''),(42355,13426,'118976','printshop-mobile','block_type','4',0,''),(42356,13427,'118977','printshop-mobile','block_type','1',0,''),(42357,13427,'118977','printshop-mobile','padding-right','40',0,''),(42358,13428,'118978','printshop-mobile','block_type','1',0,''),(42359,13428,'118978','printshop-mobile','background-color','#ffffff',0,''),(42360,13428,'118978','printshop-mobile','padding-top','30',0,''),(42361,13428,'118978','printshop-mobile','padding-left','30',0,''),(42362,13428,'118978','printshop-mobile','padding-right','30',0,''),(42363,13428,'118978','printshop-mobile','padding-bottom','14',0,''),(42364,13428,'118978','printshop-mobile','margin-bottom','20',0,''),(42365,13428,'118978','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42366,13429,'118979','printshop-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(42367,13429,'118979','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42368,13430,'118980','printshop-mobile','style_class','closeable-content',0,''),(42369,13430,'118980','printshop-mobile','padding-bottom','20',0,''),(42370,13431,'118981','printshop-mobile','block_type','1',0,''),(42371,13431,'118981','printshop-mobile','padding-top','30',0,''),(42372,13431,'118981','printshop-mobile','padding-left','30',0,''),(42373,13431,'118981','printshop-mobile','padding-right','30',0,''),(42374,13431,'118981','printshop-mobile','padding-bottom','14',0,''),(42375,13431,'118981','printshop-mobile','margin-bottom','20',0,''),(42376,13431,'118981','printshop-mobile','background-color','#ffffff',0,''),(42377,13431,'118981','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42378,13432,'118982','printshop-mobile','block_type','2',0,''),(42379,13432,'118982','printshop-mobile','style_class','closeable-content',0,''),(42380,13433,'118983','printshop-mobile','padding-right','20',0,''),(42381,13433,'118983','printshop-mobile','padding-bottom','20',0,''),(42382,13434,'118984','printshop-mobile','padding-left','20',0,''),(42383,13434,'118984','printshop-mobile','padding-bottom','20',0,''),(42384,13435,'118985','printshop-mobile','padding-left','20',0,''),(42385,13435,'118985','printshop-mobile','padding-bottom','20',0,''),(42386,13436,'118986','printshop-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(42387,13436,'118986','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42388,13437,'118987','printshop-mobile','block_type','1',0,''),(42389,13437,'118987','printshop-mobile','padding-top','30',0,''),(42390,13437,'118987','printshop-mobile','padding-left','30',0,''),(42391,13437,'118987','printshop-mobile','padding-right','30',0,''),(42392,13437,'118987','printshop-mobile','padding-bottom','23',0,''),(42393,13437,'118987','printshop-mobile','margin-bottom','20',0,''),(42394,13437,'118987','printshop-mobile','background-color','#ffffff',0,''),(42395,13437,'118987','printshop-mobile','style_class','hiding-box',0,''),(42396,13438,'118988','printshop-mobile','block_type','2',0,''),(42397,13439,'118989','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42398,13440,'118990','printshop-mobile','padding-right','20',0,''),(42399,13441,'118991','printshop-mobile','block_type','1',0,''),(42400,13441,'118991','printshop-mobile','padding-left','20',0,''),(42401,13442,'118992','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42402,13444,'118994','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(42403,13445,'118995','printshop-mobile','block_type','1',0,''),(42404,13445,'118995','printshop-mobile','background-color','#ffffff',0,''),(42405,13445,'118995','printshop-mobile','padding-top','30',0,''),(42406,13445,'118995','printshop-mobile','padding-left','30',0,''),(42407,13445,'118995','printshop-mobile','padding-right','30',0,''),(42408,13445,'118995','printshop-mobile','padding-bottom','30',0,''),(42409,13445,'118995','printshop-mobile','margin-bottom','20',0,''),(42410,13445,'118995','printshop-mobile','style_class','hiding-box',0,''),(42411,13446,'118996','printshop-mobile','margin-bottom','20',0,''),(42412,13447,'118997','printshop-mobile','padding-top','10',0,''),(42413,13447,'118997','printshop-mobile','padding-left','20',0,''),(42414,13447,'118997','printshop-mobile','padding-right','20',0,''),(42415,13447,'118997','printshop-mobile','margin-top','20',0,''),(42416,13447,'118997','printshop-mobile','background-color','#eeeeee',0,''),(42417,13447,'118997','printshop-mobile','padding-bottom','8',0,''),(42418,13448,'118998','printshop-mobile','block_type','1',0,''),(42419,13448,'118998','printshop-mobile','padding-top','20',0,''),(42420,13448,'118998','printshop-mobile','padding-left','20',0,''),(42421,13448,'118998','printshop-mobile','padding-right','20',0,''),(42422,13448,'118998','printshop-mobile','padding-bottom','20',0,''),(42423,13448,'118998','printshop-mobile','background-color','#ffffff',0,''),(42424,13448,'118998','printshop-mobile','style_class','order-summary hiding-box',0,''),(42425,13449,'118999','printshop-mobile','hide_page','1',0,''),(42426,13449,'118999','printshop-mobile','hide_continue_button','1',0,''),(42427,13451,'119001','printshop-mobile','margin-bottom','10',0,''),(42428,13452,'119002','printshop-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(42429,13452,'119002','printshop-mobile','text-align','center',0,''),(42430,13452,'119002','printshop-mobile','font-size','14',0,''),(42431,13452,'119002','printshop-mobile','color','#757575',0,''),(42432,13452,'119002','printshop-mobile','padding-top','10',0,''),(42433,13453,'119003','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(42434,13454,'119004','printshop-mobile','block_type','1',0,''),(42435,13455,'119005','printshop-mobile','margin-bottom','20',0,''),(42436,13456,'119006','printshop-mobile','block_type','2',0,''),(42437,13456,'119006','printshop-mobile','schema','2-2',0,''),(42438,13457,'119007','printshop-mobile','block_type','1',0,''),(42439,13457,'119007','printshop-mobile','padding-right','20',0,''),(42441,13459,'119009','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42442,13460,'119010','printshop-mobile','block_type','1',0,''),(42443,13460,'119010','printshop-mobile','padding-left','20',0,''),(42445,13462,'119012','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42446,13466,'119016','printshop-mobile','block_type','2',0,''),(42447,13466,'119016','printshop-mobile','schema','2-2',0,''),(42448,13467,'119017','printshop-mobile','block_type','1',0,''),(42449,13467,'119017','printshop-mobile','padding-right','20',0,''),(42451,13468,'119018','printshop-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(42452,13470,'119020','printshop-mobile','block_type','1',0,''),(42453,13470,'119020','printshop-mobile','padding-left','20',0,''),(42455,13471,'119021','printshop-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(42456,13473,'119023','printshop-mobile','block_type','4',0,''),(42457,13473,'119023','printshop-mobile','schema','4-2',0,''),(42458,13474,'119024','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42459,13474,'119024','printshop-mobile','text-align','right',0,''),(42460,13474,'119024','printshop-mobile','padding-top','10',0,''),(42461,13474,'119024','printshop-mobile','font_size_measure','em',0,''),(42462,13474,'119024','printshop-mobile','font-size','1.2',0,''),(42463,13475,'119025','printshop-mobile','text-align','right',0,''),(42464,13477,'119027','printshop-mobile','block_type','1',0,''),(42465,13477,'119027','printshop-mobile','background-color','#eeeeee',0,''),(42466,13477,'119027','printshop-mobile','padding-top','30',0,''),(42467,13477,'119027','printshop-mobile','padding-bottom','30',0,''),(42468,13478,'119028','printshop-mobile','block_type','4',0,''),(42469,13478,'119028','printshop-mobile','schema','4-2',0,''),(42470,13479,'119029','printshop-mobile','block_type','1',0,''),(42471,13479,'119029','printshop-mobile','padding-right','40',0,''),(42473,13480,'119030','printshop-mobile','block_type','1',0,''),(42474,13480,'119030','printshop-mobile','padding-top','30',0,''),(42475,13480,'119030','printshop-mobile','padding-left','30',0,''),(42476,13480,'119030','printshop-mobile','padding-right','30',0,''),(42477,13480,'119030','printshop-mobile','padding-bottom','23',0,''),(42478,13480,'119030','printshop-mobile','margin-bottom','20',0,''),(42479,13480,'119030','printshop-mobile','background-color','#ffffff',0,''),(42480,13480,'119030','printshop-mobile','style_class','hiding-box',0,''),(42481,13481,'119031','printshop-mobile','block_type','2',0,''),(42482,13481,'119031','printshop-mobile','schema','2-2',0,''),(42483,13482,'119032','printshop-mobile','padding-right','20',0,''),(42485,13482,'119032','printshop-mobile','padding-bottom','20',0,''),(42486,13483,'119033','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42487,13484,'119034','printshop-mobile','block_type','1',0,''),(42488,13484,'119034','printshop-mobile','padding-left','20',0,''),(42490,13485,'119035','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42491,13487,'119037','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(42492,13488,'119038','printshop-mobile','block_type','1',0,''),(42493,13488,'119038','printshop-mobile','background-color','#ffffff',0,''),(42494,13488,'119038','printshop-mobile','padding-top','30',0,''),(42495,13488,'119038','printshop-mobile','padding-left','30',0,''),(42496,13488,'119038','printshop-mobile','padding-right','30',0,''),(42497,13488,'119038','printshop-mobile','padding-bottom','30',0,''),(42498,13488,'119038','printshop-mobile','margin-bottom','20',0,''),(42499,13488,'119038','printshop-mobile','style_class','hiding-box',0,''),(42500,13489,'119039','printshop-mobile','padding-top','10',0,''),(42501,13489,'119039','printshop-mobile','padding-left','20',0,''),(42502,13489,'119039','printshop-mobile','padding-right','20',0,''),(42503,13489,'119039','printshop-mobile','margin-top','20',0,''),(42504,13489,'119039','printshop-mobile','background-color','#eeeeee',0,''),(42505,13489,'119039','printshop-mobile','padding-bottom','8',0,''),(42506,13490,'119040','printshop-mobile','margin-bottom','20',0,''),(42507,13491,'119041','printshop-mobile','block_type','1',0,''),(42508,13491,'119041','printshop-mobile','background-color','#ffffff',0,''),(42509,13491,'119041','printshop-mobile','padding-top','30',0,''),(42510,13491,'119041','printshop-mobile','padding-left','30',0,''),(42511,13491,'119041','printshop-mobile','padding-right','30',0,''),(42512,13491,'119041','printshop-mobile','padding-bottom','14',0,''),(42513,13491,'119041','printshop-mobile','margin-bottom','20',0,''),(42514,13491,'119041','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42515,13492,'119042','printshop-mobile','style_class','closeable-content',0,''),(42516,13492,'119042','printshop-mobile','padding-bottom','20',0,''),(42517,13493,'119043','printshop-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(42518,13493,'119043','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42519,13494,'119044','printshop-mobile','background-color','#ffffff',0,''),(42520,13494,'119044','printshop-mobile','padding-top','30',0,''),(42521,13494,'119044','printshop-mobile','padding-left','30',0,''),(42522,13494,'119044','printshop-mobile','padding-right','30',0,''),(42523,13494,'119044','printshop-mobile','padding-bottom','30',0,''),(42524,13494,'119044','printshop-mobile','margin-bottom','20',0,''),(42525,13495,'119045','printshop-mobile','block_type','1',0,''),(42526,13495,'119045','printshop-mobile','padding-top','20',0,''),(42527,13495,'119045','printshop-mobile','padding-left','20',0,''),(42528,13495,'119045','printshop-mobile','padding-right','20',0,''),(42529,13495,'119045','printshop-mobile','padding-bottom','20',0,''),(42530,13495,'119045','printshop-mobile','background-color','#ffffff',0,''),(42531,13495,'119045','printshop-mobile','style_class','order-summary',0,''),(42532,13496,'119046','printshop-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(42533,13496,'119046','printshop-mobile','text-align','center',0,''),(42534,13496,'119046','printshop-mobile','font-size','14',0,''),(42535,13496,'119046','printshop-mobile','color','#757575',0,''),(42536,13496,'119046','printshop-mobile','padding-top','10',0,''),(42537,13497,'119047','printshop-mobile','margin-bottom','10',0,''),(42538,13499,'119049','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(42539,13500,'119050','printshop-mobile','block_type','4',0,''),(42540,13500,'119050','printshop-mobile','schema','4-2',0,''),(42541,13501,'119051','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42542,13501,'119051','printshop-mobile','text-align','right',0,''),(42543,13501,'119051','printshop-mobile','padding-top','10',0,''),(42544,13501,'119051','printshop-mobile','font_size_measure','em',0,''),(42545,13501,'119051','printshop-mobile','font-size','1.2',0,''),(42546,13502,'119052','printshop-mobile','text-align','right',0,''),(42547,13503,'119053','printshop-mobile','block_type','2',0,''),(42548,13504,'119054','printshop-mobile','block_type','1',0,''),(42549,13504,'119054','printshop-mobile','padding-left','0',0,''),(42550,13504,'119054','printshop-mobile','padding-right','20',0,''),(42551,13506,'119056','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42552,13507,'119057','printshop-mobile','block_type','1',0,''),(42553,13507,'119057','printshop-mobile','padding-left','20',0,''),(42555,13509,'119059','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42556,13513,'119063','printshop-mobile','block_type','2',0,''),(42557,13514,'119064','printshop-mobile','block_type','1',0,''),(42558,13514,'119064','printshop-mobile','padding-left','0',0,''),(42559,13514,'119064','printshop-mobile','padding-right','20',0,''),(42560,13515,'119065','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42561,13517,'119067','printshop-mobile','block_type','1',0,''),(42562,13517,'119067','printshop-mobile','padding-left','20',0,''),(42564,13519,'119069','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42565,13523,'119073','printshop-mobile','block_type','4',0,''),(42566,13523,'119073','printshop-mobile','schema','4-2',0,''),(42567,13524,'119074','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42568,13524,'119074','printshop-mobile','text-align','right',0,''),(42569,13524,'119074','printshop-mobile','padding-top','10',0,''),(42570,13524,'119074','printshop-mobile','font_size_measure','em',0,''),(42571,13524,'119074','printshop-mobile','font-size','1.2',0,''),(42572,13525,'119075','printshop-mobile','text-align','right',0,''),(42573,13526,'119076','printshop-mobile','block_type','2',0,''),(42574,13527,'119077','printshop-mobile','block_type','1',0,''),(42575,13527,'119077','printshop-mobile','padding-left','0',0,''),(42576,13527,'119077','printshop-mobile','padding-right','20',0,''),(42577,13528,'119078','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42578,13530,'119080','printshop-mobile','block_type','1',0,''),(42579,13530,'119080','printshop-mobile','padding-left','20',0,''),(42581,13531,'119081','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42582,13536,'119086','printshop-mobile','block_type','4',0,''),(42583,13536,'119086','printshop-mobile','schema','4-2',0,''),(42584,13537,'119087','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42585,13537,'119087','printshop-mobile','text-align','right',0,''),(42586,13537,'119087','printshop-mobile','padding-top','10',0,''),(42587,13537,'119087','printshop-mobile','font_size_measure','em',0,''),(42588,13537,'119087','printshop-mobile','font-size','1.2',0,''),(42589,13538,'119088','printshop-mobile','text-align','right',0,''),(42590,13539,'119089','printshop-mobile','block_type','4',0,''),(42591,13539,'119089','printshop-mobile','schema','4-2',0,''),(42592,13540,'119090','printshop-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(42593,13540,'119090','printshop-mobile','text-align','right',0,''),(42594,13540,'119090','printshop-mobile','padding-top','10',0,''),(42595,13540,'119090','printshop-mobile','font_size_measure','em',0,''),(42596,13540,'119090','printshop-mobile','font-size','1.2',0,''),(42597,13541,'119091','printshop-mobile','text-align','right',0,''),(42598,13542,'119092','printshop-mobile','block_type','2',0,''),(42599,13543,'119093','printshop-mobile','block_type','1',0,''),(42600,13543,'119093','printshop-mobile','padding-left','0',0,''),(42601,13543,'119093','printshop-mobile','padding-right','20',0,''),(42602,13545,'119095','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42603,13546,'119096','printshop-mobile','block_type','1',0,''),(42604,13546,'119096','printshop-mobile','padding-left','20',0,''),(42606,13548,'119098','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42607,13552,'119102','printshop-mobile','text','##PAYMENT_DETAILS##',0,''),(42608,13553,'119103','printshop-mobile','text','##PAYMENT_DETAILS##',0,''),(42609,13554,'119104','printshop-mobile','text','##PAYMENT_DETAILS##',0,''),(42610,13555,'119105','printshop-mobile','text','##PAYMENT_DETAILS##',0,''),(42611,13556,'119106','printshop-mobile','text','##PAYMENT_DETAILS##',0,''),(42612,13557,'119107','printshop-mobile','text','##PAYMENT_DETAILS##',0,''),(42613,13558,'119108','printshop-mobile','block_type','1',0,''),(42614,13558,'119108','printshop-mobile','background-color','#eeeeee',0,''),(42615,13558,'119108','printshop-mobile','padding-top','30',0,''),(42616,13558,'119108','printshop-mobile','padding-bottom','30',0,''),(42617,13559,'119109','printshop-mobile','block_type','4',0,''),(42618,13559,'119109','printshop-mobile','schema','4-2',0,''),(42619,13560,'119110','printshop-mobile','block_type','1',0,''),(42620,13560,'119110','printshop-mobile','padding-right','40',0,''),(42622,13561,'119111','printshop-mobile','block_type','1',0,''),(42623,13561,'119111','printshop-mobile','padding-top','30',0,''),(42624,13561,'119111','printshop-mobile','padding-left','30',0,''),(42625,13561,'119111','printshop-mobile','padding-right','30',0,''),(42626,13561,'119111','printshop-mobile','padding-bottom','23',0,''),(42627,13561,'119111','printshop-mobile','margin-bottom','20',0,''),(42628,13561,'119111','printshop-mobile','background-color','#ffffff',0,''),(42629,13561,'119111','printshop-mobile','style_class','hiding-box',0,''),(42630,13562,'119112','printshop-mobile','block_type','2',0,''),(42631,13562,'119112','printshop-mobile','schema','2-2',0,''),(42632,13563,'119113','printshop-mobile','padding-right','20',0,''),(42634,13563,'119113','printshop-mobile','padding-bottom','20',0,''),(42635,13564,'119114','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42636,13565,'119115','printshop-mobile','block_type','1',0,''),(42637,13565,'119115','printshop-mobile','padding-left','20',0,''),(42639,13566,'119116','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42640,13568,'119118','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(42641,13569,'119119','printshop-mobile','block_type','1',0,''),(42642,13569,'119119','printshop-mobile','background-color','#ffffff',0,''),(42643,13569,'119119','printshop-mobile','padding-top','30',0,''),(42644,13569,'119119','printshop-mobile','padding-left','30',0,''),(42645,13569,'119119','printshop-mobile','padding-right','30',0,''),(42646,13569,'119119','printshop-mobile','padding-bottom','14',0,''),(42647,13569,'119119','printshop-mobile','margin-bottom','20',0,''),(42648,13569,'119119','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42649,13570,'119120','printshop-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(42650,13570,'119120','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42651,13571,'119121','printshop-mobile','style_class','closeable-content',0,''),(42652,13571,'119121','printshop-mobile','padding-bottom','20',0,''),(42653,13572,'119122','printshop-mobile','background-color','#ffffff',0,''),(42654,13572,'119122','printshop-mobile','padding-top','30',0,''),(42655,13572,'119122','printshop-mobile','padding-left','30',0,''),(42656,13572,'119122','printshop-mobile','padding-right','30',0,''),(42657,13572,'119122','printshop-mobile','padding-bottom','30',0,''),(42658,13572,'119122','printshop-mobile','margin-bottom','20',0,''),(42659,13573,'119123','printshop-mobile','background-color','#ffffff',0,''),(42660,13573,'119123','printshop-mobile','block_type','1',0,''),(42661,13573,'119123','printshop-mobile','padding-top','30',0,''),(42662,13573,'119123','printshop-mobile','padding-left','30',0,''),(42663,13573,'119123','printshop-mobile','padding-right','30',0,''),(42664,13573,'119123','printshop-mobile','padding-bottom','30',0,''),(42665,13573,'119123','printshop-mobile','margin-bottom','20',0,''),(42666,13573,'119123','printshop-mobile','style_class','hiding-box',0,''),(42667,13574,'119124','printshop-mobile','block_type','2',0,''),(42668,13574,'119124','printshop-mobile','schema','2-2',0,''),(42669,13575,'119125','printshop-mobile','block_type','1',0,''),(42670,13575,'119125','printshop-mobile','padding-right','20',0,''),(42671,13575,'119125','printshop-mobile','padding-left','0',0,''),(42672,13575,'119125','printshop-mobile','margin-bottom','20',0,''),(42673,13576,'119126','printshop-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(42674,13579,'119129','printshop-mobile','block_type','1',0,''),(42675,13579,'119129','printshop-mobile','padding-left','20',0,''),(42677,13580,'119130','printshop-mobile','border-top-width','1',0,''),(42678,13580,'119130','printshop-mobile','border-top-color','#e0e0e0',0,''),(42679,13580,'119130','printshop-mobile','padding-top','13',0,''),(42680,13580,'119130','printshop-mobile','padding-bottom','10',0,''),(42681,13581,'119131','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42682,13583,'119133','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(42683,13584,'119134','printshop-mobile','background-color','#eeeeee',0,''),(42684,13584,'119134','printshop-mobile','padding-top','10',0,''),(42685,13584,'119134','printshop-mobile','padding-left','10',0,''),(42686,13584,'119134','printshop-mobile','padding-right','10',0,''),(42687,13584,'119134','printshop-mobile','padding-bottom','10',0,''),(42688,13584,'119134','printshop-mobile','margin-top','10',0,''),(42689,13585,'119135','printshop-mobile','block_type','1',0,''),(42690,13585,'119135','printshop-mobile','content','\\_',0,'3'),(42691,13585,'119135','printshop-mobile','border-top-width','1',0,'3'),(42692,13585,'119135','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(42693,13585,'119135','printshop-mobile','display','block',0,'3'),(42694,13585,'119135','printshop-mobile','position','absolute',0,'3'),(42695,13585,'119135','printshop-mobile','top','19',0,'3'),(42696,13585,'119135','printshop-mobile','left','0',0,'3'),(42697,13585,'119135','printshop-mobile','right','0',0,'3'),(42698,13585,'119135','printshop-mobile','margin-top','-2',0,'3'),(42699,13585,'119135','printshop-mobile','position','relative',0,''),(42700,13586,'119136','printshop-mobile','box_align','2',0,''),(42701,13586,'119136','printshop-mobile','margin-bottom','10',0,''),(42702,13586,'119136','printshop-mobile','background-color','#ffffff',0,''),(42703,13586,'119136','printshop-mobile','position','relative',0,''),(42704,13587,'119137','printshop-mobile','block_type','1',0,''),(42705,13587,'119137','printshop-mobile','background-color','#ffffff',0,''),(42706,13587,'119137','printshop-mobile','padding-top','30',0,''),(42707,13587,'119137','printshop-mobile','padding-left','30',0,''),(42708,13587,'119137','printshop-mobile','padding-right','30',0,''),(42709,13587,'119137','printshop-mobile','padding-bottom','30',0,''),(42710,13587,'119137','printshop-mobile','margin-bottom','20',0,''),(42711,13587,'119137','printshop-mobile','style_class','hiding-box',0,''),(42712,13588,'119138','printshop-mobile','margin-bottom','20',0,''),(42713,13589,'119139','printshop-mobile','padding-top','10',0,''),(42714,13589,'119139','printshop-mobile','padding-left','20',0,''),(42715,13589,'119139','printshop-mobile','padding-right','20',0,''),(42716,13589,'119139','printshop-mobile','margin-top','20',0,''),(42717,13589,'119139','printshop-mobile','background-color','#eeeeee',0,''),(42718,13589,'119139','printshop-mobile','padding-bottom','8',0,''),(42719,13590,'119140','printshop-mobile','block_type','1',0,''),(42720,13590,'119140','printshop-mobile','padding-top','20',0,''),(42721,13590,'119140','printshop-mobile','padding-left','20',0,''),(42722,13590,'119140','printshop-mobile','padding-right','20',0,''),(42723,13590,'119140','printshop-mobile','padding-bottom','20',0,''),(42724,13590,'119140','printshop-mobile','background-color','#ffffff',0,''),(42725,13590,'119140','printshop-mobile','style_class','order-summary',0,''),(42726,13592,'119142','printshop-mobile','margin-bottom','10',0,''),(42727,13593,'119143','printshop-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(42728,13593,'119143','printshop-mobile','text-align','center',0,''),(42729,13593,'119143','printshop-mobile','font-size','14',0,''),(42730,13593,'119143','printshop-mobile','color','#757575',0,''),(42731,13593,'119143','printshop-mobile','padding-top','10',0,''),(42732,13594,'119144','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(42733,13595,'119145','printshop-mobile','block_type','1',0,''),(42734,13595,'119145','printshop-mobile','padding-top','30',0,''),(42735,13595,'119145','printshop-mobile','padding-bottom','30',0,''),(42736,13595,'119145','printshop-mobile','background-color','#eeeeeh',0,''),(42737,13596,'119146','printshop-mobile','block_type','4',0,''),(42738,13596,'119146','printshop-mobile','schema','4-2',0,''),(42739,13597,'119147','printshop-mobile','block_type','1',0,''),(42740,13597,'119147','printshop-mobile','padding-right','40',0,''),(42742,13598,'119148','printshop-mobile','block_type','1',0,''),(42743,13598,'119148','printshop-mobile','padding-top','30',0,''),(42744,13598,'119148','printshop-mobile','padding-left','30',0,''),(42745,13598,'119148','printshop-mobile','padding-right','30',0,''),(42746,13598,'119148','printshop-mobile','padding-bottom','14',0,''),(42747,13598,'119148','printshop-mobile','margin-bottom','20',0,''),(42748,13598,'119148','printshop-mobile','background-color','#ffffff',0,''),(42749,13598,'119148','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42750,13599,'119149','printshop-mobile','block_type','2',0,''),(42751,13599,'119149','printshop-mobile','style_class','closeable-content',0,''),(42752,13599,'119149','printshop-mobile','schema','2-2',0,''),(42753,13600,'119150','printshop-mobile','padding-right','20',0,''),(42754,13600,'119150','printshop-mobile','padding-bottom','20',0,''),(42756,13601,'119151','printshop-mobile','padding-left','20',0,''),(42757,13601,'119151','printshop-mobile','padding-bottom','20',0,''),(42759,13602,'119152','printshop-mobile','padding-left','20',0,''),(42760,13602,'119152','printshop-mobile','padding-bottom','20',0,''),(42762,13603,'119153','printshop-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(42763,13603,'119153','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42764,13604,'119154','printshop-mobile','block_type','1',0,''),(42765,13604,'119154','printshop-mobile','padding-top','30',0,''),(42766,13604,'119154','printshop-mobile','padding-left','30',0,''),(42767,13604,'119154','printshop-mobile','padding-right','30',0,''),(42768,13604,'119154','printshop-mobile','padding-bottom','23',0,''),(42769,13604,'119154','printshop-mobile','margin-bottom','20',0,''),(42770,13604,'119154','printshop-mobile','background-color','#ffffff',0,''),(42771,13604,'119154','printshop-mobile','style_class','hiding-box',0,''),(42772,13605,'119155','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(42773,13606,'119156','printshop-mobile','block_type','2',0,''),(42774,13606,'119156','printshop-mobile','schema','2-2',0,''),(42775,13607,'119157','printshop-mobile','padding-right','20',0,''),(42777,13607,'119157','printshop-mobile','padding-bottom','20',0,''),(42778,13608,'119158','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42779,13609,'119159','printshop-mobile','block_type','1',0,''),(42780,13609,'119159','printshop-mobile','padding-left','20',0,''),(42782,13611,'119161','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42783,13612,'119162','printshop-mobile','block_type','1',0,''),(42784,13612,'119162','printshop-mobile','background-color','#ffffff',0,''),(42785,13612,'119162','printshop-mobile','padding-top','30',0,''),(42786,13612,'119162','printshop-mobile','padding-left','30',0,''),(42787,13612,'119162','printshop-mobile','padding-right','30',0,''),(42788,13612,'119162','printshop-mobile','padding-bottom','14',0,''),(42789,13612,'119162','printshop-mobile','margin-bottom','20',0,''),(42790,13612,'119162','printshop-mobile','style_class','hiding-box closeable-box',0,''),(42791,13613,'119163','printshop-mobile','style_class','closeable-content',0,''),(42792,13613,'119163','printshop-mobile','padding-bottom','20',0,''),(42793,13614,'119164','printshop-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(42794,13614,'119164','printshop-mobile','style_class','closeable-heading closeable-event closed',0,''),(42795,13615,'119165','printshop-mobile','background-color','#ffffff',0,''),(42796,13615,'119165','printshop-mobile','block_type','1',0,''),(42797,13615,'119165','printshop-mobile','padding-top','30',0,''),(42798,13615,'119165','printshop-mobile','padding-left','30',0,''),(42799,13615,'119165','printshop-mobile','padding-right','30',0,''),(42800,13615,'119165','printshop-mobile','padding-bottom','30',0,''),(42801,13615,'119165','printshop-mobile','margin-bottom','20',0,''),(42802,13615,'119165','printshop-mobile','style_class','hiding-box',0,''),(42803,13616,'119166','printshop-mobile','block_type','1',0,''),(42804,13616,'119166','printshop-mobile','content','\\_',0,'3'),(42805,13616,'119166','printshop-mobile','border-top-width','1',0,'3'),(42806,13616,'119166','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(42807,13616,'119166','printshop-mobile','display','block',0,'3'),(42808,13616,'119166','printshop-mobile','position','absolute',0,'3'),(42809,13616,'119166','printshop-mobile','top','19',0,'3'),(42810,13616,'119166','printshop-mobile','left','0',0,'3'),(42811,13616,'119166','printshop-mobile','right','0',0,'3'),(42812,13616,'119166','printshop-mobile','margin-top','-2',0,'3'),(42813,13616,'119166','printshop-mobile','position','relative',0,''),(42814,13617,'119167','printshop-mobile','box_align','2',0,''),(42815,13617,'119167','printshop-mobile','margin-bottom','10',0,''),(42816,13617,'119167','printshop-mobile','background-color','#ffffff',0,''),(42817,13617,'119167','printshop-mobile','position','relative',0,''),(42818,13618,'119168','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(42819,13619,'119169','printshop-mobile','block_type','2',0,''),(42820,13619,'119169','printshop-mobile','schema','2-2',0,''),(42821,13620,'119170','printshop-mobile','block_type','1',0,''),(42822,13620,'119170','printshop-mobile','padding-right','20',0,''),(42823,13620,'119170','printshop-mobile','padding-left','0',0,''),(42824,13620,'119170','printshop-mobile','margin-bottom','20',0,''),(42825,13622,'119172','printshop-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(42826,13624,'119174','printshop-mobile','block_type','1',0,''),(42827,13624,'119174','printshop-mobile','padding-left','20',0,''),(42829,13625,'119175','printshop-mobile','border-top-width','1',0,''),(42830,13625,'119175','printshop-mobile','border-top-color','#e0e0e0',0,''),(42831,13625,'119175','printshop-mobile','padding-top','13',0,''),(42832,13625,'119175','printshop-mobile','padding-bottom','10',0,''),(42833,13626,'119176','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42834,13628,'119178','printshop-mobile','background-color','#eeeeee',0,''),(42835,13628,'119178','printshop-mobile','padding-top','10',0,''),(42836,13628,'119178','printshop-mobile','padding-left','10',0,''),(42837,13628,'119178','printshop-mobile','padding-right','10',0,''),(42838,13628,'119178','printshop-mobile','padding-bottom','10',0,''),(42839,13628,'119178','printshop-mobile','margin-top','10',0,''),(42840,13629,'119179','printshop-mobile','block_type','1',0,''),(42841,13629,'119179','printshop-mobile','background-color','#ffffff',0,''),(42842,13629,'119179','printshop-mobile','padding-top','30',0,''),(42843,13629,'119179','printshop-mobile','padding-left','30',0,''),(42844,13629,'119179','printshop-mobile','padding-right','30',0,''),(42845,13629,'119179','printshop-mobile','padding-bottom','30',0,''),(42846,13629,'119179','printshop-mobile','margin-bottom','20',0,''),(42847,13629,'119179','printshop-mobile','style_class','hiding-box',0,''),(42848,13630,'119180','printshop-mobile','padding-top','10',0,''),(42849,13630,'119180','printshop-mobile','padding-left','20',0,''),(42850,13630,'119180','printshop-mobile','padding-right','20',0,''),(42851,13630,'119180','printshop-mobile','margin-top','20',0,''),(42852,13630,'119180','printshop-mobile','background-color','#eeeeee',0,''),(42853,13630,'119180','printshop-mobile','padding-bottom','8',0,''),(42854,13631,'119181','printshop-mobile','margin-bottom','20',0,''),(42855,13632,'119182','printshop-mobile','background-color','#ffffff',0,''),(42856,13632,'119182','printshop-mobile','padding-top','30',0,''),(42857,13632,'119182','printshop-mobile','padding-left','30',0,''),(42858,13632,'119182','printshop-mobile','padding-right','30',0,''),(42859,13632,'119182','printshop-mobile','padding-bottom','30',0,''),(42860,13632,'119182','printshop-mobile','margin-bottom','20',0,''),(42861,13633,'119183','printshop-mobile','block_type','1',0,''),(42862,13633,'119183','printshop-mobile','padding-top','20',0,''),(42863,13633,'119183','printshop-mobile','padding-left','20',0,''),(42864,13633,'119183','printshop-mobile','padding-right','20',0,''),(42865,13633,'119183','printshop-mobile','padding-bottom','20',0,''),(42866,13633,'119183','printshop-mobile','background-color','#ffffff',0,''),(42867,13633,'119183','printshop-mobile','style_class','order-summary',0,''),(42868,13634,'119184','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(42869,13636,'119186','printshop-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(42870,13636,'119186','printshop-mobile','text-align','center',0,''),(42871,13636,'119186','printshop-mobile','font-size','14',0,''),(42872,13636,'119186','printshop-mobile','color','#757575',0,''),(42873,13636,'119186','printshop-mobile','padding-top','10',0,''),(42874,13637,'119187','printshop-mobile','margin-bottom','10',0,''),(42875,13640,'119190','printshop-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(42876,13643,'119193','printshop-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(42877,13644,'119194','printshop-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(42878,13647,'119197','printshop-mobile','style_class','order-summary',0,''),(42879,13647,'119197','printshop-mobile','box_align','3',0,''),(42880,13647,'119197','printshop-mobile','width','400',0,''),(42881,13648,'119198','printshop-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(42882,13650,'119200','printshop-mobile','block_type','1',0,''),(42883,13651,'119201','printshop-mobile','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(42884,13652,'119202','printshop-mobile','margin-bottom','30',0,''),(42885,13653,'119203','printshop-mobile','float','right',0,''),(42886,13653,'119203','printshop-mobile','position','relative',0,''),(42887,13653,'119203','printshop-mobile','z-index','1',0,''),(42888,13653,'119203','printshop-mobile','top','30',0,''),(42889,13653,'119203','printshop-mobile','margin-bottom','-20',0,''),(42890,13654,'119204','printshop-mobile','block_type','1',0,''),(42891,13655,'119205','printshop-mobile','listing_type','Compare Products',0,''),(42892,13656,'119206','printshop-mobile','block_type','1',0,''),(42893,13656,'119206','printshop-mobile','style_class','item-holder',0,''),(42894,13656,'119206','printshop-mobile','padding-top','10',0,''),(42895,13656,'119206','printshop-mobile','padding-left','20',0,''),(42896,13656,'119206','printshop-mobile','padding-right','20',0,''),(42897,13656,'119206','printshop-mobile','padding-bottom','10',0,''),(42898,13656,'119206','printshop-mobile','text-align','left',0,''),(42899,13659,'119209','printshop-mobile','margin-bottom','10',0,''),(42900,13660,'119210','printshop-mobile','block_type','5',0,''),(42901,13662,'119212','printshop-mobile','clear','both',0,''),(42902,13663,'119213','printshop-mobile','block_type','2',0,''),(42903,13664,'119214','printshop-mobile','margin-bottom','7',0,''),(42904,13665,'119215','printshop-mobile','text-align','right',0,''),(42905,13665,'119215','printshop-mobile','margin-bottom','10',0,''),(42906,13665,'119215','printshop-mobile','float','right',0,''),(42907,13666,'119216','printshop-mobile','block_type','1',0,''),(42908,13666,'119216','printshop-mobile','background-color','#eeeeee',0,''),(42909,13666,'119216','printshop-mobile','padding-bottom','30',0,''),(42910,13667,'119217','printshop-mobile','block_type','1',0,''),(42911,13667,'119217','printshop-mobile','schema','4-2',0,''),(42912,13667,'119217','printshop-mobile','schema','4-2',0,'702'),(42913,13669,'119219','printshop-mobile','block_type','1',0,''),(42914,13669,'119219','printshop-mobile','padding-right','40',0,''),(42916,13670,'119220','printshop-mobile','block_type','1',0,''),(42917,13670,'119220','printshop-mobile','margin-bottom','20',0,''),(42918,13670,'119220','printshop-mobile','schema','2-2',0,''),(42919,13670,'119220','printshop-mobile','background-color','#ffffff',0,''),(42920,13671,'119221','printshop-mobile','block_type','1',0,''),(42921,13671,'119221','printshop-mobile','border-right-width','20',0,''),(42922,13671,'119221','printshop-mobile','border-right-color','#e0e0e0',0,''),(42923,13671,'119221','printshop-mobile','margin-right','-10',0,''),(42924,13671,'119221','printshop-mobile','padding-right','30',0,''),(42925,13671,'119221','printshop-mobile','padding-top','20',0,''),(42926,13671,'119221','printshop-mobile','padding-left','30',0,''),(42927,13671,'119221','printshop-mobile','padding-bottom','20',0,''),(42930,13671,'119221','printshop-mobile','margin-bottom','20',0,''),(42933,13672,'119222','printshop-mobile','margin-bottom','20',0,''),(42934,13673,'119223','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(42935,13674,'119224','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(42936,13674,'119224','printshop-mobile','clear','none',0,''),(42937,13676,'119226','printshop-mobile','link','shipping_address',0,''),(42938,13676,'119226','printshop-mobile','float','right',0,''),(42939,13676,'119226','printshop-mobile','margin-top','-31',0,''),(42940,13677,'119227','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(42941,13677,'119227','printshop-mobile','clear','none',0,''),(42942,13679,'119229','printshop-mobile','link','contact_information',0,''),(42943,13679,'119229','printshop-mobile','margin-top','-31',0,''),(42944,13679,'119229','printshop-mobile','float','right',0,''),(42945,13680,'119230','printshop-mobile','link','shipping_method',0,''),(42946,13680,'119230','printshop-mobile','float','right',0,''),(42947,13680,'119230','printshop-mobile','margin-top','-31',0,''),(42948,13681,'119231','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(42949,13681,'119231','printshop-mobile','padding-top','20',0,''),(42950,13683,'119233','printshop-mobile','block_type','1',0,''),(42951,13683,'119233','printshop-mobile','padding-left','30',0,''),(42952,13683,'119233','printshop-mobile','border-left-width','20',0,''),(42953,13683,'119233','printshop-mobile','border-left-color','#e0e0e0',0,''),(42954,13683,'119233','printshop-mobile','margin-left','-10',0,''),(42955,13683,'119233','printshop-mobile','padding-right','30',0,''),(42956,13683,'119233','printshop-mobile','padding-top','20',0,''),(42957,13683,'119233','printshop-mobile','padding-bottom','20',0,''),(42959,13684,'119234','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(42960,13684,'119234','printshop-mobile','clear','none',0,''),(42961,13685,'119235','printshop-mobile','margin-bottom','20',0,''),(42962,13686,'119236','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(42963,13686,'119236','printshop-mobile','clear','none',0,''),(42964,13688,'119238','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(42965,13689,'119239','printshop-mobile','link','billing_address',0,''),(42966,13689,'119239','printshop-mobile','float','right',0,''),(42967,13689,'119239','printshop-mobile','margin-top','-31',0,''),(42968,13690,'119240','printshop-mobile','link','payment_method',0,''),(42969,13690,'119240','printshop-mobile','float','right',0,''),(42970,13690,'119240','printshop-mobile','margin-top','-31',0,''),(42971,13691,'119241','printshop-mobile','block_type','1',0,''),(42972,13691,'119241','printshop-mobile','padding-right','30',0,''),(42973,13691,'119241','printshop-mobile','background-color','#ffffff',0,''),(42974,13691,'119241','printshop-mobile','padding-top','20',0,''),(42975,13691,'119241','printshop-mobile','padding-left','30',0,''),(42976,13691,'119241','printshop-mobile','padding-bottom','20',0,''),(42979,13692,'119242','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(42980,13693,'119243','printshop-mobile','link','products',0,''),(42981,13693,'119243','printshop-mobile','float','right',0,''),(42982,13693,'119243','printshop-mobile','margin-top','-37',0,''),(42983,13695,'119245','printshop-mobile','block_type','1',0,''),(42984,13695,'119245','printshop-mobile','background-color','#ffffff',0,''),(42985,13695,'119245','printshop-mobile','padding-top','20',0,''),(42986,13695,'119245','printshop-mobile','padding-bottom','20',0,''),(42987,13695,'119245','printshop-mobile','padding-left','30',0,''),(42988,13695,'119245','printshop-mobile','padding-right','30',0,''),(42989,13695,'119245','printshop-mobile','margin-bottom','20',0,''),(42990,13696,'119246','printshop-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(42991,13697,'119247','printshop-mobile','hide_parents','2',0,''),(42992,13698,'119248','printshop-mobile','float','right',0,''),(42993,13698,'119248','printshop-mobile','margin-top','-37',0,''),(42994,13698,'119248','printshop-mobile','link','comments',0,''),(42995,13699,'119249','printshop-mobile','block_type','1',0,''),(42996,13699,'119249','printshop-mobile','padding-top','20',0,''),(42997,13699,'119249','printshop-mobile','padding-left','20',0,''),(42998,13699,'119249','printshop-mobile','padding-right','20',0,''),(42999,13699,'119249','printshop-mobile','padding-bottom','20',0,''),(43000,13699,'119249','printshop-mobile','background-color','#ffffff',0,''),(43001,13699,'119249','printshop-mobile','style_class','order-summary2 hiding-box',0,''),(43002,13701,'119251','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(43003,13702,'119252','printshop-mobile','margin-bottom','20',0,''),(43004,13702,'119252','printshop-mobile','text-align','right',0,''),(43005,13703,'119253','printshop-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(43006,13704,'119254','printshop-mobile','block_type','1',0,''),(43007,13704,'119254','printshop-mobile','background-color','#eeeeee',0,''),(43008,13704,'119254','printshop-mobile','padding-bottom','30',0,''),(43009,13705,'119255','printshop-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(43010,13706,'119256','printshop-mobile','block_type','4',0,''),(43011,13706,'119256','printshop-mobile','schema','4-2',0,''),(43012,13707,'119257','printshop-mobile','block_type','1',0,''),(43013,13707,'119257','printshop-mobile','padding-right','40',0,''),(43015,13708,'119258','printshop-mobile','block_type','2',0,''),(43016,13708,'119258','printshop-mobile','margin-bottom','20',0,''),(43017,13708,'119258','printshop-mobile','schema','2-2',0,''),(43018,13708,'119258','printshop-mobile','background-color','#ffffff',0,''),(43019,13709,'119259','printshop-mobile','block_type','1',0,''),(43020,13709,'119259','printshop-mobile','border-right-width','20',0,''),(43021,13709,'119259','printshop-mobile','border-right-color','#e0e0e0',0,''),(43022,13709,'119259','printshop-mobile','margin-right','-10',0,''),(43023,13709,'119259','printshop-mobile','padding-right','30',0,''),(43024,13709,'119259','printshop-mobile','padding-top','20',0,''),(43025,13709,'119259','printshop-mobile','padding-left','30',0,''),(43026,13709,'119259','printshop-mobile','padding-bottom','20',0,''),(43029,13709,'119259','printshop-mobile','margin-bottom','20',0,''),(43032,13710,'119260','printshop-mobile','link','shipping_method',0,''),(43033,13710,'119260','printshop-mobile','float','right',0,''),(43034,13710,'119260','printshop-mobile','margin-top','-31',0,''),(43035,13711,'119261','printshop-mobile','margin-bottom','20',0,''),(43036,13712,'119262','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(43037,13712,'119262','printshop-mobile','clear','none',0,''),(43038,13714,'119264','printshop-mobile','link','shipping_address',0,''),(43039,13714,'119264','printshop-mobile','float','right',0,''),(43040,13714,'119264','printshop-mobile','margin-top','-31',0,''),(43041,13715,'119265','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(43042,13715,'119265','printshop-mobile','clear','none',0,''),(43043,13716,'119266','printshop-mobile','block_type','1',0,''),(43044,13716,'119266','printshop-mobile','padding-left','30',0,''),(43045,13716,'119266','printshop-mobile','border-left-width','20',0,''),(43046,13716,'119266','printshop-mobile','border-left-color','#e0e0e0',0,''),(43047,13716,'119266','printshop-mobile','margin-left','-10',0,''),(43048,13716,'119266','printshop-mobile','padding-right','30',0,''),(43049,13716,'119266','printshop-mobile','padding-top','20',0,''),(43050,13716,'119266','printshop-mobile','padding-bottom','20',0,''),(43052,13717,'119267','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(43053,13718,'119268','printshop-mobile','link','contact_information',0,''),(43054,13718,'119268','printshop-mobile','margin-top','-31',0,''),(43055,13718,'119268','printshop-mobile','float','right',0,''),(43056,13721,'119271','printshop-mobile','block_type','1',0,''),(43057,13721,'119271','printshop-mobile','background-color','#ffffff',0,''),(43058,13721,'119271','printshop-mobile','padding-top','20',0,''),(43059,13721,'119271','printshop-mobile','padding-bottom','20',0,''),(43060,13721,'119271','printshop-mobile','padding-left','30',0,''),(43061,13721,'119271','printshop-mobile','padding-right','30',0,''),(43062,13721,'119271','printshop-mobile','margin-bottom','20',0,''),(43063,13722,'119272','printshop-mobile','hide_parents','2',0,''),(43064,13723,'119273','printshop-mobile','float','right',0,''),(43065,13723,'119273','printshop-mobile','margin-top','-37',0,''),(43066,13723,'119273','printshop-mobile','link','comments',0,''),(43067,13724,'119274','printshop-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(43068,13725,'119275','printshop-mobile','block_type','1',0,''),(43069,13725,'119275','printshop-mobile','padding-right','30',0,''),(43070,13725,'119275','printshop-mobile','background-color','#ffffff',0,''),(43071,13725,'119275','printshop-mobile','padding-top','20',0,''),(43072,13725,'119275','printshop-mobile','padding-left','30',0,''),(43073,13725,'119275','printshop-mobile','padding-bottom','20',0,''),(43076,13727,'119277','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(43077,13728,'119278','printshop-mobile','link','products',0,''),(43078,13728,'119278','printshop-mobile','float','right',0,''),(43079,13728,'119278','printshop-mobile','margin-top','-37',0,''),(43080,13729,'119279','printshop-mobile','block_type','1',0,''),(43081,13729,'119279','printshop-mobile','padding-top','20',0,''),(43082,13729,'119279','printshop-mobile','padding-left','20',0,''),(43083,13729,'119279','printshop-mobile','padding-right','20',0,''),(43084,13729,'119279','printshop-mobile','padding-bottom','20',0,''),(43085,13729,'119279','printshop-mobile','background-color','#ffffff',0,''),(43086,13729,'119279','printshop-mobile','style_class','order-summary',0,''),(43087,13730,'119280','printshop-mobile','margin-bottom','20',0,''),(43088,13730,'119280','printshop-mobile','text-align','right',0,''),(43089,13731,'119281','printshop-mobile','block_type','1',0,''),(43090,13731,'119281','printshop-mobile','background-color','#eeeeee',0,''),(43091,13731,'119281','printshop-mobile','padding-bottom','30',0,''),(43092,13732,'119282','printshop-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(43093,13733,'119283','printshop-mobile','block_type','4',0,''),(43094,13734,'119284','printshop-mobile','block_type','1',0,''),(43095,13734,'119284','printshop-mobile','padding-right','40',0,''),(43096,13735,'119285','printshop-mobile','block_type','1',0,''),(43097,13735,'119285','printshop-mobile','padding-right','30',0,''),(43099,13735,'119285','printshop-mobile','background-color','#ffffff',0,''),(43100,13735,'119285','printshop-mobile','padding-top','20',0,''),(43101,13735,'119285','printshop-mobile','padding-left','30',0,''),(43102,13735,'119285','printshop-mobile','padding-bottom','20',0,''),(43103,13736,'119286','printshop-mobile','link','products',0,''),(43104,13736,'119286','printshop-mobile','float','right',0,''),(43105,13736,'119286','printshop-mobile','margin-top','-37',0,''),(43106,13737,'119287','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(43107,13739,'119289','printshop-mobile','block_type','1',0,''),(43108,13739,'119289','printshop-mobile','background-color','#ffffff',0,''),(43109,13739,'119289','printshop-mobile','padding-top','20',0,''),(43110,13739,'119289','printshop-mobile','padding-bottom','20',0,''),(43111,13739,'119289','printshop-mobile','padding-left','30',0,''),(43112,13739,'119289','printshop-mobile','padding-right','30',0,''),(43113,13739,'119289','printshop-mobile','margin-bottom','20',0,''),(43114,13740,'119290','printshop-mobile','float','right',0,''),(43115,13740,'119290','printshop-mobile','margin-top','-37',0,''),(43116,13740,'119290','printshop-mobile','link','comments',0,''),(43117,13741,'119291','printshop-mobile','hide_parents','2',0,''),(43118,13742,'119292','printshop-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(43119,13743,'119293','printshop-mobile','block_type','2',0,''),(43120,13743,'119293','printshop-mobile','margin-bottom','20',0,''),(43121,13743,'119293','printshop-mobile','schema','2-2',0,''),(43122,13743,'119293','printshop-mobile','background-color','#ffffff',0,''),(43123,13744,'119294','printshop-mobile','block_type','1',0,''),(43124,13744,'119294','printshop-mobile','padding-right','0',0,''),(43125,13744,'119294','printshop-mobile','border-right-width','20',0,''),(43126,13744,'119294','printshop-mobile','border-right-color','#e0e0e0',0,''),(43127,13744,'119294','printshop-mobile','margin-right','-10',0,''),(43129,13744,'119294','printshop-mobile','padding-top','20',0,''),(43130,13744,'119294','printshop-mobile','padding-left','30',0,''),(43131,13744,'119294','printshop-mobile','padding-bottom','20',0,''),(43132,13745,'119295','printshop-mobile','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(43133,13745,'119295','printshop-mobile','padding-top','20',0,''),(43134,13747,'119297','printshop-mobile','link','contact_information',0,''),(43135,13747,'119297','printshop-mobile','margin-top','-37',0,''),(43136,13747,'119297','printshop-mobile','float','right',0,''),(43137,13748,'119298','printshop-mobile','block_type','1',0,''),(43138,13748,'119298','printshop-mobile','padding-left','30',0,''),(43140,13748,'119298','printshop-mobile','border-left-width','20',0,''),(43141,13748,'119298','printshop-mobile','border-left-color','#e0e0e0',0,''),(43142,13748,'119298','printshop-mobile','margin-left','-10',0,''),(43143,13748,'119298','printshop-mobile','padding-right','30',0,''),(43144,13748,'119298','printshop-mobile','padding-top','20',0,''),(43145,13748,'119298','printshop-mobile','padding-bottom','20',0,''),(43146,13749,'119299','printshop-mobile','link','billing_address',0,''),(43147,13749,'119299','printshop-mobile','float','right',0,''),(43148,13749,'119299','printshop-mobile','margin-top','-31',0,''),(43149,13750,'119300','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(43150,13750,'119300','printshop-mobile','clear','none',0,''),(43151,13751,'119301','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(43152,13752,'119302','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(43153,13752,'119302','printshop-mobile','clear','none',0,''),(43154,13753,'119303','printshop-mobile','margin-bottom','20',0,''),(43155,13755,'119305','printshop-mobile','link','payment_method',0,''),(43156,13755,'119305','printshop-mobile','float','right',0,''),(43157,13755,'119305','printshop-mobile','margin-top','-31',0,''),(43158,13756,'119306','printshop-mobile','block_type','1',0,''),(43159,13756,'119306','printshop-mobile','padding-top','20',0,''),(43160,13756,'119306','printshop-mobile','padding-left','20',0,''),(43161,13756,'119306','printshop-mobile','padding-right','20',0,''),(43162,13756,'119306','printshop-mobile','padding-bottom','20',0,''),(43163,13756,'119306','printshop-mobile','background-color','#ffffff',0,''),(43164,13756,'119306','printshop-mobile','style_class','order-summary2 hiding-box',0,''),(43165,13757,'119307','printshop-mobile','margin-bottom','20',0,''),(43166,13757,'119307','printshop-mobile','text-align','right',0,''),(43167,13759,'119309','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(43168,13760,'119310','printshop-mobile','block_type','1',0,''),(43169,13760,'119310','printshop-mobile','background-color','#eeeeee',0,''),(43170,13760,'119310','printshop-mobile','padding-bottom','30',0,''),(43171,13761,'119311','printshop-mobile','block_type','4',0,''),(43172,13761,'119311','printshop-mobile','schema','4-2',0,''),(43173,13762,'119312','printshop-mobile','block_type','1',0,''),(43174,13762,'119312','printshop-mobile','padding-right','40',0,''),(43176,13763,'119313','printshop-mobile','block_type','1',0,''),(43177,13763,'119313','printshop-mobile','padding-right','30',0,''),(43178,13763,'119313','printshop-mobile','background-color','#ffffff',0,''),(43179,13763,'119313','printshop-mobile','padding-top','20',0,''),(43180,13763,'119313','printshop-mobile','padding-left','30',0,''),(43181,13763,'119313','printshop-mobile','padding-bottom','20',0,''),(43184,13764,'119314','printshop-mobile','margin-bottom','20',0,''),(43185,13765,'119315','printshop-mobile','link','products',0,''),(43186,13765,'119315','printshop-mobile','float','right',0,''),(43187,13765,'119315','printshop-mobile','margin-top','-37',0,''),(43188,13766,'119316','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(43189,13767,'119317','printshop-mobile','block_type','2',0,''),(43190,13767,'119317','printshop-mobile','margin-bottom','20',0,''),(43191,13767,'119317','printshop-mobile','schema','2-2',0,''),(43192,13767,'119317','printshop-mobile','background-color','#ffffff',0,''),(43193,13768,'119318','printshop-mobile','block_type','1',0,''),(43194,13768,'119318','printshop-mobile','border-right-width','20',0,''),(43195,13768,'119318','printshop-mobile','border-right-color','#e0e0e0',0,''),(43196,13768,'119318','printshop-mobile','margin-right','-10',0,''),(43197,13768,'119318','printshop-mobile','padding-right','30',0,''),(43198,13768,'119318','printshop-mobile','padding-top','20',0,''),(43199,13768,'119318','printshop-mobile','padding-left','30',0,''),(43200,13768,'119318','printshop-mobile','padding-bottom','20',0,''),(43203,13768,'119318','printshop-mobile','margin-bottom','20',0,''),(43206,13769,'119319','printshop-mobile','link','payment_method',0,''),(43207,13769,'119319','printshop-mobile','float','right',0,''),(43208,13769,'119319','printshop-mobile','margin-top','-31',0,''),(43209,13770,'119320','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(43210,13770,'119320','printshop-mobile','clear','none',0,''),(43211,13771,'119321','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(43212,13771,'119321','printshop-mobile','padding-top','20',0,''),(43213,13773,'119323','printshop-mobile','link','contact_information',0,''),(43214,13773,'119323','printshop-mobile','margin-top','-31',0,''),(43215,13773,'119323','printshop-mobile','float','right',0,''),(43216,13775,'119325','printshop-mobile','block_type','1',0,''),(43217,13775,'119325','printshop-mobile','padding-left','30',0,''),(43218,13775,'119325','printshop-mobile','border-left-width','20',0,''),(43219,13775,'119325','printshop-mobile','border-left-color','#e0e0e0',0,''),(43220,13775,'119325','printshop-mobile','margin-left','-10',0,''),(43221,13775,'119325','printshop-mobile','padding-right','30',0,''),(43222,13775,'119325','printshop-mobile','padding-top','20',0,''),(43223,13775,'119325','printshop-mobile','padding-bottom','20',0,''),(43225,13776,'119326','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(43226,13776,'119326','printshop-mobile','clear','none',0,''),(43227,13777,'119327','printshop-mobile','link','billing_address',0,''),(43228,13777,'119327','printshop-mobile','float','right',0,''),(43229,13777,'119327','printshop-mobile','margin-top','-31',0,''),(43230,13778,'119328','printshop-mobile','margin-bottom','20',0,''),(43231,13779,'119329','printshop-mobile','block_type','1',0,''),(43232,13779,'119329','printshop-mobile','background-color','#ffffff',0,''),(43233,13779,'119329','printshop-mobile','padding-top','20',0,''),(43234,13779,'119329','printshop-mobile','padding-bottom','20',0,''),(43235,13779,'119329','printshop-mobile','padding-left','30',0,''),(43236,13779,'119329','printshop-mobile','padding-right','30',0,''),(43237,13779,'119329','printshop-mobile','margin-bottom','20',0,''),(43238,13780,'119330','printshop-mobile','hide_parents','2',0,''),(43239,13781,'119331','printshop-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(43240,13782,'119332','printshop-mobile','float','right',0,''),(43241,13782,'119332','printshop-mobile','margin-top','-37',0,''),(43242,13782,'119332','printshop-mobile','link','comments',0,''),(43243,13783,'119333','printshop-mobile','block_type','1',0,''),(43244,13783,'119333','printshop-mobile','padding-top','20',0,''),(43245,13783,'119333','printshop-mobile','padding-left','20',0,''),(43246,13783,'119333','printshop-mobile','padding-right','20',0,''),(43247,13783,'119333','printshop-mobile','padding-bottom','20',0,''),(43248,13783,'119333','printshop-mobile','background-color','#ffffff',0,''),(43249,13783,'119333','printshop-mobile','style_class','order-summary',0,''),(43250,13784,'119334','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(43251,13786,'119336','printshop-mobile','margin-bottom','20',0,''),(43252,13786,'119336','printshop-mobile','text-align','right',0,''),(43253,13787,'119337','printshop-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(43254,13788,'119338','printshop-mobile','block_type','1',0,''),(43255,13788,'119338','printshop-mobile','background-color','#eeeeee',0,''),(43256,13788,'119338','printshop-mobile','padding-bottom','30',0,''),(43257,13789,'119339','printshop-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(43258,13790,'119340','printshop-mobile','block_type','4',0,''),(43259,13790,'119340','printshop-mobile','schema','4-2',0,''),(43260,13791,'119341','printshop-mobile','block_type','1',0,''),(43261,13791,'119341','printshop-mobile','padding-right','40',0,''),(43263,13792,'119342','printshop-mobile','block_type','1',0,''),(43264,13792,'119342','printshop-mobile','padding-right','30',0,''),(43265,13792,'119342','printshop-mobile','background-color','#ffffff',0,''),(43266,13792,'119342','printshop-mobile','padding-top','20',0,''),(43267,13792,'119342','printshop-mobile','padding-left','30',0,''),(43268,13792,'119342','printshop-mobile','padding-bottom','20',0,''),(43271,13793,'119343','printshop-mobile','link','products',0,''),(43272,13793,'119343','printshop-mobile','float','right',0,''),(43273,13793,'119343','printshop-mobile','margin-top','-37',0,''),(43274,13794,'119344','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(43275,13796,'119346','printshop-mobile','block_type','1',0,''),(43276,13796,'119346','printshop-mobile','background-color','#ffffff',0,''),(43277,13796,'119346','printshop-mobile','padding-top','20',0,''),(43278,13796,'119346','printshop-mobile','padding-bottom','20',0,''),(43279,13796,'119346','printshop-mobile','padding-left','30',0,''),(43280,13796,'119346','printshop-mobile','padding-right','30',0,''),(43281,13796,'119346','printshop-mobile','margin-bottom','20',0,''),(43282,13797,'119347','printshop-mobile','float','right',0,''),(43283,13797,'119347','printshop-mobile','margin-top','-37',0,''),(43284,13797,'119347','printshop-mobile','link','comments',0,''),(43285,13798,'119348','printshop-mobile','hide_parents','2',0,''),(43286,13799,'119349','printshop-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(43287,13800,'119350','printshop-mobile','block_type','2',0,''),(43288,13800,'119350','printshop-mobile','margin-bottom','20',0,''),(43289,13800,'119350','printshop-mobile','schema','2-2',0,''),(43290,13800,'119350','printshop-mobile','background-color','#ffffff',0,''),(43291,13801,'119351','printshop-mobile','block_type','1',0,''),(43292,13801,'119351','printshop-mobile','border-right-width','20',0,''),(43293,13801,'119351','printshop-mobile','border-right-color','#e0e0e0',0,''),(43294,13801,'119351','printshop-mobile','margin-right','-10',0,''),(43295,13801,'119351','printshop-mobile','padding-right','30',0,''),(43296,13801,'119351','printshop-mobile','padding-top','20',0,''),(43297,13801,'119351','printshop-mobile','padding-left','30',0,''),(43298,13801,'119351','printshop-mobile','padding-bottom','20',0,''),(43301,13801,'119351','printshop-mobile','margin-bottom','20',0,''),(43304,13802,'119352','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(43305,13802,'119352','printshop-mobile','clear','none',0,''),(43306,13803,'119353','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(43307,13803,'119353','printshop-mobile','padding-top','20',0,''),(43308,13804,'119354','printshop-mobile','link','shipping_method',0,''),(43309,13804,'119354','printshop-mobile','float','right',0,''),(43310,13804,'119354','printshop-mobile','margin-top','-31',0,''),(43311,13806,'119356','printshop-mobile','link','shipping_address',0,''),(43312,13806,'119356','printshop-mobile','float','right',0,''),(43313,13806,'119356','printshop-mobile','margin-top','-31',0,''),(43314,13808,'119358','printshop-mobile','margin-bottom','20',0,''),(43315,13810,'119360','printshop-mobile','link','contact_information',0,''),(43316,13810,'119360','printshop-mobile','margin-top','-31',0,''),(43317,13810,'119360','printshop-mobile','float','right',0,''),(43318,13811,'119361','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(43319,13811,'119361','printshop-mobile','clear','none',0,''),(43320,13812,'119362','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(43321,13813,'119363','printshop-mobile','block_type','1',0,''),(43322,13813,'119363','printshop-mobile','padding-left','30',0,''),(43323,13813,'119363','printshop-mobile','border-left-width','20',0,''),(43324,13813,'119363','printshop-mobile','border-left-color','#e0e0e0',0,''),(43325,13813,'119363','printshop-mobile','margin-left','-10',0,''),(43326,13813,'119363','printshop-mobile','padding-right','30',0,''),(43327,13813,'119363','printshop-mobile','padding-top','20',0,''),(43328,13813,'119363','printshop-mobile','padding-bottom','20',0,''),(43330,13814,'119364','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(43331,13815,'119365','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(43332,13815,'119365','printshop-mobile','clear','none',0,''),(43333,13817,'119367','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(43334,13817,'119367','printshop-mobile','clear','none',0,''),(43335,13818,'119368','printshop-mobile','margin-bottom','20',0,''),(43336,13819,'119369','printshop-mobile','link','payment_method',0,''),(43337,13819,'119369','printshop-mobile','float','right',0,''),(43338,13819,'119369','printshop-mobile','margin-top','-31',0,''),(43339,13820,'119370','printshop-mobile','link','billing_address',0,''),(43340,13820,'119370','printshop-mobile','float','right',0,''),(43341,13820,'119370','printshop-mobile','margin-top','-31',0,''),(43342,13821,'119371','printshop-mobile','block_type','1',0,''),(43343,13821,'119371','printshop-mobile','padding-top','20',0,''),(43344,13821,'119371','printshop-mobile','padding-left','20',0,''),(43345,13821,'119371','printshop-mobile','padding-right','20',0,''),(43346,13821,'119371','printshop-mobile','padding-bottom','20',0,''),(43347,13821,'119371','printshop-mobile','background-color','#ffffff',0,''),(43348,13821,'119371','printshop-mobile','style_class','order-summary',0,''),(43349,13822,'119372','printshop-mobile','margin-bottom','20',0,''),(43350,13822,'119372','printshop-mobile','text-align','right',0,''),(43351,13823,'119373','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(43352,13825,'119375','printshop-mobile','block_type','1',0,''),(43353,13825,'119375','printshop-mobile','background-color','#eeeeee',0,''),(43354,13825,'119375','printshop-mobile','padding-bottom','30',0,''),(43355,13826,'119376','printshop-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(43356,13827,'119377','printshop-mobile','block_type','4',0,''),(43357,13827,'119377','printshop-mobile','schema','4-2',0,''),(43358,13828,'119378','printshop-mobile','block_type','1',0,''),(43359,13828,'119378','printshop-mobile','padding-right','40',0,''),(43361,13829,'119379','printshop-mobile','block_type','1',0,''),(43362,13829,'119379','printshop-mobile','background-color','#ffffff',0,''),(43363,13829,'119379','printshop-mobile','padding-top','20',0,''),(43364,13829,'119379','printshop-mobile','padding-bottom','20',0,''),(43365,13829,'119379','printshop-mobile','padding-left','30',0,''),(43366,13829,'119379','printshop-mobile','padding-right','30',0,''),(43367,13829,'119379','printshop-mobile','margin-bottom','20',0,''),(43368,13830,'119380','printshop-mobile','hide_parents','2',0,''),(43369,13831,'119381','printshop-mobile','float','right',0,''),(43370,13831,'119381','printshop-mobile','margin-top','-37',0,''),(43371,13831,'119381','printshop-mobile','link','comments',0,''),(43372,13832,'119382','printshop-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(43373,13833,'119383','printshop-mobile','block_type','1',0,''),(43374,13833,'119383','printshop-mobile','padding-right','30',0,''),(43375,13833,'119383','printshop-mobile','background-color','#ffffff',0,''),(43376,13833,'119383','printshop-mobile','padding-top','20',0,''),(43377,13833,'119383','printshop-mobile','padding-left','30',0,''),(43378,13833,'119383','printshop-mobile','padding-bottom','20',0,''),(43381,13835,'119385','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(43382,13836,'119386','printshop-mobile','link','products',0,''),(43383,13836,'119386','printshop-mobile','float','right',0,''),(43384,13836,'119386','printshop-mobile','margin-top','-37',0,''),(43385,13837,'119387','printshop-mobile','block_type','2',0,''),(43386,13837,'119387','printshop-mobile','margin-bottom','20',0,''),(43387,13837,'119387','printshop-mobile','schema','2-2',0,''),(43388,13837,'119387','printshop-mobile','background-color','#ffffff',0,''),(43389,13838,'119388','printshop-mobile','block_type','1',0,''),(43390,13838,'119388','printshop-mobile','border-right-width','20',0,''),(43391,13838,'119388','printshop-mobile','border-right-color','#e0e0e0',0,''),(43392,13838,'119388','printshop-mobile','margin-right','-10',0,''),(43393,13838,'119388','printshop-mobile','padding-right','30',0,''),(43394,13838,'119388','printshop-mobile','padding-top','20',0,''),(43395,13838,'119388','printshop-mobile','padding-left','30',0,''),(43396,13838,'119388','printshop-mobile','padding-bottom','20',0,''),(43399,13838,'119388','printshop-mobile','margin-bottom','20',0,''),(43402,13839,'119389','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(43403,13839,'119389','printshop-mobile','padding-top','20',0,''),(43404,13841,'119391','printshop-mobile','link','shipping_method',0,''),(43405,13841,'119391','printshop-mobile','float','right',0,''),(43406,13841,'119391','printshop-mobile','margin-top','-31',0,''),(43407,13842,'119392','printshop-mobile','link','contact_information',0,''),(43408,13842,'119392','printshop-mobile','margin-top','-31',0,''),(43409,13842,'119392','printshop-mobile','float','right',0,''),(43410,13843,'119393','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(43411,13845,'119395','printshop-mobile','link','shipping_address',0,''),(43412,13845,'119395','printshop-mobile','float','right',0,''),(43413,13845,'119395','printshop-mobile','margin-top','-31',0,''),(43414,13846,'119396','printshop-mobile','margin-bottom','20',0,''),(43415,13847,'119397','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(43416,13847,'119397','printshop-mobile','clear','none',0,''),(43417,13848,'119398','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(43418,13848,'119398','printshop-mobile','clear','none',0,''),(43419,13850,'119400','printshop-mobile','block_type','1',0,''),(43420,13850,'119400','printshop-mobile','padding-left','30',0,''),(43421,13850,'119400','printshop-mobile','border-left-width','20',0,''),(43422,13850,'119400','printshop-mobile','border-left-color','#e0e0e0',0,''),(43423,13850,'119400','printshop-mobile','margin-left','-10',0,''),(43424,13850,'119400','printshop-mobile','padding-right','30',0,''),(43425,13850,'119400','printshop-mobile','padding-top','20',0,''),(43426,13850,'119400','printshop-mobile','padding-bottom','20',0,''),(43428,13851,'119401','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(43429,13851,'119401','printshop-mobile','clear','none',0,''),(43430,13852,'119402','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(43431,13853,'119403','printshop-mobile','link','payment_method',0,''),(43432,13853,'119403','printshop-mobile','float','right',0,''),(43433,13853,'119403','printshop-mobile','margin-top','-31',0,''),(43434,13854,'119404','printshop-mobile','margin-bottom','20',0,''),(43435,13855,'119405','printshop-mobile','link','billing_address',0,''),(43436,13855,'119405','printshop-mobile','float','right',0,''),(43437,13855,'119405','printshop-mobile','margin-top','-31',0,''),(43438,13856,'119406','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(43439,13856,'119406','printshop-mobile','clear','none',0,''),(43440,13858,'119408','printshop-mobile','block_type','1',0,''),(43441,13858,'119408','printshop-mobile','padding-top','20',0,''),(43442,13858,'119408','printshop-mobile','padding-left','20',0,''),(43443,13858,'119408','printshop-mobile','padding-right','20',0,''),(43444,13858,'119408','printshop-mobile','padding-bottom','20',0,''),(43445,13858,'119408','printshop-mobile','background-color','#ffffff',0,''),(43446,13858,'119408','printshop-mobile','style_class','order-summary',0,''),(43447,13860,'119410','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(43448,13861,'119411','printshop-mobile','margin-bottom','20',0,''),(43449,13861,'119411','printshop-mobile','text-align','right',0,''),(43450,13862,'119412','printshop-mobile','block_type','1',0,''),(43451,13863,'119413','printshop-mobile','block_type','2',0,''),(43452,13863,'119413','printshop-mobile','font-weight','400',0,''),(43453,13863,'119413','printshop-mobile','padding-bottom','20',0,''),(43454,13863,'119413','printshop-mobile','schema','2-2',0,''),(43455,13863,'119413','printshop-mobile','schema','2-2',0,'694'),(43456,13865,'119415','printshop-mobile','street_heading','90',0,''),(43457,13866,'119416','printshop-mobile','block_type','2',0,''),(43458,13866,'119416','printshop-mobile','font-weight','400',0,''),(43459,13866,'119416','printshop-mobile','padding-bottom','20',0,''),(43460,13866,'119416','printshop-mobile','schema','2-2',0,'694'),(43461,13867,'119417','printshop-mobile','show_captcha','on',0,''),(43462,13868,'119418','printshop-mobile','font-weight','400',0,''),(43463,13868,'119418','printshop-mobile','padding-left','40',0,''),(43464,13868,'119418','printshop-mobile','time_format','24',0,''),(43465,13868,'119418','printshop-mobile','show_icons','on',0,''),(43466,13868,'119418','printshop-mobile','padding-left','0',0,'694'),(43467,13870,'119420','printshop-mobile','block_type','1',0,''),(43468,13871,'119421','printshop-mobile','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(43469,13871,'119421','printshop-mobile','margin-bottom','40',0,''),(43470,13872,'119422','printshop-mobile','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(43471,13873,'119423','printshop-mobile','width','680',0,''),(43472,13873,'119423','printshop-mobile','font-weight','normal',0,''),(43473,13873,'119423','printshop-mobile','font-size','12',0,''),(43474,13873,'119423','printshop-mobile','padding-top','20',0,''),(43475,13873,'119423','printshop-mobile','padding-bottom','20',0,''),(43476,13873,'119423','printshop-mobile','color','#424242',0,''),(43477,13874,'119424','printshop-mobile','block_type','4',0,''),(43478,13874,'119424','printshop-mobile','font-weight','normal',0,''),(43479,13874,'119424','printshop-mobile','border-top-width','1',0,''),(43480,13874,'119424','printshop-mobile','border-top-color','#e0e0e0',0,''),(43481,13874,'119424','printshop-mobile','border-left-width','1',0,''),(43482,13874,'119424','printshop-mobile','border-left-color','#e0e0e0',0,''),(43483,13874,'119424','printshop-mobile','border-right-width','1',0,''),(43484,13874,'119424','printshop-mobile','border-right-color','#e0e0e0',0,''),(43485,13874,'119424','printshop-mobile','border-bottom-width','1',0,''),(43486,13874,'119424','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(43487,13875,'119425','printshop-mobile','block_type','2',0,''),(43488,13875,'119425','printshop-mobile','font-weight','normal',0,''),(43489,13875,'119425','printshop-mobile','border-top-width','1',0,''),(43490,13875,'119425','printshop-mobile','border-top-color','#e0e0e0',0,''),(43491,13875,'119425','printshop-mobile','border-right-width','1',0,''),(43492,13875,'119425','printshop-mobile','border-right-color','#e0e0e0',0,''),(43493,13876,'119426','printshop-mobile','block_type','1',0,''),(43494,13876,'119426','printshop-mobile','font-weight','normal',0,''),(43495,13876,'119426','printshop-mobile','padding-top','10',0,''),(43496,13876,'119426','printshop-mobile','padding-left','10',0,''),(43497,13876,'119426','printshop-mobile','padding-right','10',0,''),(43498,13876,'119426','printshop-mobile','padding-bottom','10',0,''),(43499,13876,'119426','printshop-mobile','border-right-width','1',0,''),(43500,13876,'119426','printshop-mobile','border-right-color','#e0e0e0',0,''),(43501,13877,'119427','printshop-mobile','text','<p>Shipping via</p>',1,''),(43502,13877,'119427','printshop-mobile','font-weight','bold',0,''),(43503,13877,'119427','printshop-mobile','font-size','14',0,''),(43504,13879,'119429','printshop-mobile','block_type','1',0,''),(43505,13879,'119429','printshop-mobile','font-weight','normal',0,''),(43506,13879,'119429','printshop-mobile','padding-top','10',0,''),(43507,13879,'119429','printshop-mobile','padding-left','10',0,''),(43508,13879,'119429','printshop-mobile','padding-right','10',0,''),(43509,13879,'119429','printshop-mobile','padding-bottom','10',0,''),(43510,13881,'119431','printshop-mobile','text','<p>Shipping service</p>',1,''),(43511,13881,'119431','printshop-mobile','font-weight','bold',0,''),(43512,13881,'119431','printshop-mobile','font-size','14',0,''),(43513,13882,'119432','printshop-mobile','block_type','2',0,''),(43514,13882,'119432','printshop-mobile','font-weight','normal',0,''),(43515,13882,'119432','printshop-mobile','border-right-width','1',0,''),(43516,13882,'119432','printshop-mobile','border-right-color','#e0e0e0',0,''),(43517,13883,'119433','printshop-mobile','block_type','1',0,''),(43518,13883,'119433','printshop-mobile','font-weight','400',0,''),(43519,13883,'119433','printshop-mobile','background-color','#eeeeee',0,''),(43520,13883,'119433','printshop-mobile','padding-top','10',0,''),(43521,13883,'119433','printshop-mobile','padding-left','10',0,''),(43522,13883,'119433','printshop-mobile','padding-right','10',0,''),(43523,13883,'119433','printshop-mobile','padding-bottom','30',0,''),(43524,13884,'119434','printshop-mobile','font-size','12',0,''),(43525,13885,'119435','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(43526,13885,'119435','printshop-mobile','font-size','14',0,''),(43527,13885,'119435','printshop-mobile','font-weight','bold',0,''),(43528,13886,'119436','printshop-mobile','block_type','1',0,''),(43529,13886,'119436','printshop-mobile','font-weight','normal',0,''),(43530,13886,'119436','printshop-mobile','padding-top','10',0,''),(43531,13886,'119436','printshop-mobile','padding-left','10',0,''),(43532,13886,'119436','printshop-mobile','padding-right','10',0,''),(43533,13886,'119436','printshop-mobile','padding-bottom','10',0,''),(43534,13887,'119437','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(43535,13887,'119437','printshop-mobile','font-weight','bold',0,''),(43536,13887,'119437','printshop-mobile','font-size','14',0,''),(43537,13887,'119437','printshop-mobile','padding-top','10',0,''),(43538,13888,'119438','printshop-mobile','font-weight','normal',0,''),(43539,13890,'119440','printshop-mobile','text','<p>PHONE NUMBER:</p>',1,''),(43540,13890,'119440','printshop-mobile','font-size','14',0,''),(43541,13890,'119440','printshop-mobile','font-weight','bold',0,''),(43542,13890,'119440','printshop-mobile','padding-top','10',0,''),(43543,13891,'119441','printshop-mobile','text','<p>CUSTOMER:</p>',1,''),(43544,13891,'119441','printshop-mobile','font-size','13',0,''),(43545,13891,'119441','printshop-mobile','font-weight','bold',0,''),(43546,13892,'119442','printshop-mobile','font-weight','normal',0,''),(43547,13893,'119443','printshop-mobile','font-weight','normal',0,''),(43548,13893,'119443','printshop-mobile','text-align','center',0,''),(43549,13893,'119443','printshop-mobile','padding-bottom','10',0,''),(43550,13894,'119444','printshop-mobile','text','<p>Payment date:</p>',1,''),(43551,13894,'119444','printshop-mobile','font-weight','bold',0,''),(43552,13894,'119444','printshop-mobile','text-align','center',0,''),(43553,13894,'119444','printshop-mobile','font-size','12',0,''),(43554,13895,'119445','printshop-mobile','font-size','14',0,''),(43555,13895,'119445','printshop-mobile','font-weight','bold',0,''),(43556,13895,'119445','printshop-mobile','text-align','center',0,''),(43557,13895,'119445','printshop-mobile','padding-bottom','10',0,''),(43558,13895,'119445','printshop-mobile','padding-top','10',0,''),(43559,13896,'119446','printshop-mobile','block_type','5',0,''),(43560,13896,'119446','printshop-mobile','font-weight','normal',0,''),(43561,13896,'119446','printshop-mobile','border-bottom-width','1',0,''),(43562,13896,'119446','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(43563,13896,'119446','printshop-mobile','border-top-width','1',0,''),(43564,13896,'119446','printshop-mobile','border-top-color','#e0e0e0',0,''),(43565,13896,'119446','printshop-mobile','border-left-color','#e0e0e0',0,''),(43566,13896,'119446','printshop-mobile','border-left-width','1',0,''),(43567,13897,'119447','printshop-mobile','block_type','1',0,''),(43568,13897,'119447','printshop-mobile','font-weight','normal',0,''),(43569,13897,'119447','printshop-mobile','padding-top','10',0,''),(43570,13897,'119447','printshop-mobile','padding-left','10',0,''),(43571,13897,'119447','printshop-mobile','padding-right','10',0,''),(43572,13898,'119448','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(43573,13898,'119448','printshop-mobile','font-size','14',0,''),(43574,13898,'119448','printshop-mobile','font-weight','bold',0,''),(43575,13898,'119448','printshop-mobile','padding-bottom','10',0,''),(43576,13899,'119449','printshop-mobile','font-weight','400',0,''),(43577,13899,'119449','printshop-mobile','line-height','120',0,''),(43578,13899,'119449','printshop-mobile','line_height_measure','%',0,''),(43579,13899,'119449','printshop-mobile','font-size','12',0,''),(43580,13900,'119450','printshop-mobile','block_type','1',0,''),(43581,13900,'119450','printshop-mobile','background-color','#eeeeee',0,''),(43582,13900,'119450','printshop-mobile','padding-top','20',0,''),(43583,13900,'119450','printshop-mobile','padding-left','10',0,''),(43584,13900,'119450','printshop-mobile','padding-right','10',0,''),(43585,13900,'119450','printshop-mobile','padding-bottom','20',0,''),(43586,13900,'119450','printshop-mobile','font-size','14',0,''),(43587,13901,'119451','printshop-mobile','block_type','2',0,''),(43588,13901,'119451','printshop-mobile','font-weight','normal',0,''),(43589,13901,'119451','printshop-mobile','padding-bottom','20',0,''),(43590,13902,'119452','printshop-mobile','font-weight','400',0,''),(43591,13902,'119452','printshop-mobile','padding-top','20',0,''),(43593,13903,'119453','printshop-mobile','block_type','1',0,''),(43594,13904,'119454','printshop-mobile','font-weight','normal',0,''),(43595,13904,'119454','printshop-mobile','text-align','right',0,''),(43596,13904,'119454','printshop-mobile','padding-bottom','10',0,''),(43597,13904,'119454','printshop-mobile','address_spacer',',',0,''),(43598,13904,'119454','printshop-mobile','font-size','12',0,''),(43599,13905,'119455','printshop-mobile','block_type','11',0,''),(43600,13905,'119455','printshop-mobile','font-weight','normal',0,''),(43601,13906,'119456','printshop-mobile','text','<p>Email:</p>',1,''),(43602,13906,'119456','printshop-mobile','font-weight','normal',0,''),(43603,13906,'119456','printshop-mobile','text-align','right',0,''),(43604,13907,'119457','printshop-mobile','font-weight','normal',0,''),(43605,13907,'119457','printshop-mobile','text-align','right',0,''),(43606,13908,'119458','printshop-mobile','block_type','11',0,''),(43607,13908,'119458','printshop-mobile','font-weight','normal',0,''),(43608,13909,'119459','printshop-mobile','text','<p>Phone:</p>',1,''),(43609,13909,'119459','printshop-mobile','font-weight','normal',0,''),(43610,13909,'119459','printshop-mobile','text-align','right',0,''),(43611,13910,'119460','printshop-mobile','font-weight','normal',0,''),(43612,13910,'119460','printshop-mobile','text-align','right',0,''),(43613,13911,'119461','printshop-mobile','block_type','11',0,''),(43614,13911,'119461','printshop-mobile','font-weight','normal',0,''),(43615,13912,'119462','printshop-mobile','text','<p>Web:</p>',1,''),(43616,13912,'119462','printshop-mobile','font-weight','normal',0,''),(43617,13912,'119462','printshop-mobile','text-align','right',0,''),(43618,13913,'119463','printshop-mobile','font-weight','normal',0,''),(43619,13913,'119463','printshop-mobile','text-align','right',0,''),(43620,13914,'119464','printshop-mobile','font-weight','400',0,''),(43621,13914,'119464','printshop-mobile','padding-top','20',0,''),(43622,13914,'119464','printshop-mobile','padding-bottom','0',0,''),(43623,13914,'119464','printshop-mobile','font-size','12',0,''),(43624,13915,'119465','printshop-mobile','block_type','3',0,''),(43625,13915,'119465','printshop-mobile','font-weight','normal',0,''),(43626,13915,'119465','printshop-mobile','padding-top','20',0,''),(43627,13916,'119466','printshop-mobile','font-size','12',0,''),(43628,13917,'119467','printshop-mobile','text','<p>If undelivered please return to:</p>',1,''),(43629,13917,'119467','printshop-mobile','font-size','12',0,''),(43630,13917,'119467','printshop-mobile','font-weight','bold',0,''),(43631,13918,'119468','printshop-mobile','text','<p>Thank you for your order</p>',1,''),(43632,13918,'119468','printshop-mobile','color','#1da1f2',0,''),(43633,13918,'119468','printshop-mobile','font-size','13',0,''),(43634,13918,'119468','printshop-mobile','font-weight','bold',0,''),(43635,13918,'119468','printshop-mobile','padding-top','5',0,''),(43636,13918,'119468','printshop-mobile','text-align','center',0,''),(43637,13919,'119469','printshop-mobile','font-weight','400',0,''),(43638,13919,'119469','printshop-mobile','text-align','center',0,''),(43639,13919,'119469','printshop-mobile','padding-top','0',0,''),(43641,13919,'119469','printshop-mobile','padding-left','20',0,''),(43642,13919,'119469','printshop-mobile','padding-right','20',0,''),(43643,13920,'119470','printshop-mobile','block_type','6',0,''),(43644,13920,'119470','printshop-mobile','font-weight','normal',0,''),(43645,13920,'119470','printshop-mobile','font-size','16',0,''),(43646,13921,'119471','printshop-mobile','text','<p>Phone:</p>',1,''),(43647,13921,'119471','printshop-mobile','font-weight','normal',0,''),(43648,13921,'119471','printshop-mobile','text-align','right',0,''),(43649,13921,'119471','printshop-mobile','font-size','12',0,''),(43650,13922,'119472','printshop-mobile','font-weight','normal',0,''),(43651,13922,'119472','printshop-mobile','text-align','right',0,''),(43652,13922,'119472','printshop-mobile','font-size','12',0,''),(43653,13923,'119473','printshop-mobile','block_type','6',0,''),(43654,13923,'119473','printshop-mobile','font-weight','normal',0,''),(43655,13923,'119473','printshop-mobile','font-size','16',0,''),(43656,13924,'119474','printshop-mobile','text','<p>Email:</p>',1,''),(43657,13924,'119474','printshop-mobile','font-weight','normal',0,''),(43658,13924,'119474','printshop-mobile','text-align','right',0,''),(43659,13924,'119474','printshop-mobile','font-size','12',0,''),(43660,13925,'119475','printshop-mobile','font-weight','normal',0,''),(43661,13925,'119475','printshop-mobile','text-align','right',0,''),(43662,13925,'119475','printshop-mobile','font-size','12',0,''),(43663,13926,'119476','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(43664,13926,'119476','printshop-mobile','font-size','12',0,''),(43665,13926,'119476','printshop-mobile','font-weight','bold',0,''),(43666,13926,'119476','printshop-mobile','text-align','right',0,''),(43667,13929,'119479','printshop-mobile','text-align','center',0,''),(43668,13929,'119479','printshop-mobile','padding-top','10',0,''),(43669,13935,'119485','printshop-mobile','heading_type','h1',0,''),(43670,13938,'119488','printshop-mobile','text-align','center',0,''),(43671,13938,'119488','printshop-mobile','padding-top','10',0,''),(43672,13943,'119493','printshop-mobile','font-weight','normal',0,''),(43673,13943,'119493','printshop-mobile','padding-top','20',0,''),(43674,13943,'119493','printshop-mobile','padding-left','10',0,''),(43675,13943,'119493','printshop-mobile','padding-right','10',0,''),(43676,13943,'119493','printshop-mobile','padding-bottom','20',0,''),(43677,13943,'119493','printshop-mobile','color','#444444',0,''),(43678,13943,'119493','printshop-mobile','font-size','14',0,''),(43679,13944,'119494','printshop-mobile','block_type','2',0,''),(43680,13944,'119494','printshop-mobile','font-weight','normal',0,''),(43681,13945,'119495','printshop-mobile','font-weight','normal',0,''),(43682,13945,'119495','printshop-mobile','padding-bottom','20',0,''),(43683,13946,'119496','printshop-mobile','color','#444444',0,''),(43684,13946,'119496','printshop-mobile','font-size','14',0,''),(43685,13946,'119496','printshop-mobile','padding-top','20',0,''),(43686,13946,'119496','printshop-mobile','padding-bottom','20',0,''),(43687,13946,'119496','printshop-mobile','border-top-width','1',0,''),(43688,13946,'119496','printshop-mobile','border-top-color','#cccccc',0,''),(43689,13947,'119497','printshop-mobile','block_type','1',0,''),(43690,13948,'119498','printshop-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',1,''),(43691,13948,'119498','printshop-mobile','font-weight','normal',0,''),(43692,13948,'119498','printshop-mobile','color','#444444',0,''),(43693,13948,'119498','printshop-mobile','font-size','14',0,''),(43694,13949,'119499','printshop-mobile','block_type','2',0,''),(43695,13949,'119499','printshop-mobile','font-weight','normal',0,''),(43696,13949,'119499','printshop-mobile','background-color','#092964',0,''),(43697,13949,'119499','printshop-mobile','padding-top','5',0,''),(43698,13949,'119499','printshop-mobile','padding-left','10',0,''),(43699,13949,'119499','printshop-mobile','padding-right','10',0,''),(43700,13949,'119499','printshop-mobile','padding-bottom','5',0,''),(43701,13950,'119500','printshop-mobile','color','#ffffff',0,''),(43702,13950,'119500','printshop-mobile','font-size','14',0,''),(43703,13950,'119500','printshop-mobile','font-weight','normal',0,''),(43704,13951,'119501','printshop-mobile','font-weight','normal',0,''),(43705,13951,'119501','printshop-mobile','text-align','right',0,''),(43706,13951,'119501','printshop-mobile','color','#ffffff',0,''),(43707,13951,'119501','printshop-mobile','font-size','12',0,''),(43708,13952,'119502','printshop-mobile','block_type','1',0,''),(43709,13953,'119503','printshop-mobile','block_type','1',0,''),(43710,13953,'119503','printshop-mobile','max-width','800',0,''),(43711,13953,'119503','printshop-mobile','margin','0 auto',0,''),(43712,13953,'119503','printshop-mobile','background-color','#ffffff',0,''),(43713,13954,'119504','printshop-mobile','font-weight','normal',0,''),(43714,13954,'119504','printshop-mobile','padding-top','20',0,''),(43715,13954,'119504','printshop-mobile','padding-left','10',0,''),(43716,13954,'119504','printshop-mobile','padding-right','10',0,''),(43717,13954,'119504','printshop-mobile','padding-bottom','20',0,''),(43718,13954,'119504','printshop-mobile','color','#424242',0,''),(43719,13954,'119504','printshop-mobile','font-size','14',0,''),(43720,13955,'119505','printshop-mobile','block_type','7',0,''),(43721,13955,'119505','printshop-mobile','font-weight','normal',0,''),(43722,13955,'119505','printshop-mobile','background-color','#183d78',0,''),(43723,13955,'119505','printshop-mobile','padding-top','5',0,''),(43724,13955,'119505','printshop-mobile','padding-left','10',0,''),(43725,13955,'119505','printshop-mobile','padding-right','10',0,''),(43726,13955,'119505','printshop-mobile','padding-bottom','5',0,''),(43727,13956,'119506','printshop-mobile','color','#ffffff',0,''),(43728,13956,'119506','printshop-mobile','font-size','15',0,''),(43729,13956,'119506','printshop-mobile','font-weight','700',0,''),(43730,13957,'119507','printshop-mobile','font-weight','normal',0,''),(43731,13957,'119507','printshop-mobile','text-align','right',0,''),(43732,13957,'119507','printshop-mobile','color','#757575',0,''),(43733,13957,'119507','printshop-mobile','font-size','12',0,''),(43734,13958,'119508','printshop-mobile','color','#424242',0,''),(43735,13958,'119508','printshop-mobile','font-size','12',0,''),(43736,13958,'119508','printshop-mobile','padding-top','20',0,''),(43737,13958,'119508','printshop-mobile','padding-bottom','20',0,''),(43738,13958,'119508','printshop-mobile','border-top-width','1',0,''),(43739,13958,'119508','printshop-mobile','border-top-color','#e0e0e0',0,''),(43740,13959,'119509','printshop-mobile','font-weight','normal',0,''),(43741,13959,'119509','printshop-mobile','padding-bottom','10',0,''),(43742,13959,'119509','printshop-mobile','background-color','#183d78',0,''),(43743,13959,'119509','printshop-mobile','logo','themes/printshop-mobile/img/logo-white-1.png',1,''),(43744,13959,'119509','printshop-mobile','padding-left','20',0,''),(43745,13959,'119509','printshop-mobile','padding-top','10',0,''),(43746,13960,'119510','printshop-mobile','block_type','1',0,''),(43747,13960,'119510','printshop-mobile','background-color','#eeeeee',0,''),(43748,13961,'119511','printshop-mobile','block_type','1',0,''),(43749,13961,'119511','printshop-mobile','max-width','800',0,''),(43750,13961,'119511','printshop-mobile','margin','0 auto',0,''),(43751,13962,'119512','printshop-mobile','font-weight','normal',0,''),(43752,13962,'119512','printshop-mobile','padding-bottom','10',0,''),(43753,13962,'119512','printshop-mobile','padding-top','10',0,''),(43754,13962,'119512','printshop-mobile','text-align','center',0,''),(43755,13962,'119512','printshop-mobile','logo_from','theme',0,''),(43756,13963,'119513','printshop-mobile','color','#757575',0,''),(43757,13963,'119513','printshop-mobile','font-size','12',0,''),(43758,13963,'119513','printshop-mobile','padding-top','20',0,''),(43759,13963,'119513','printshop-mobile','padding-bottom','20',0,''),(43760,13963,'119513','printshop-mobile','text-align','center',0,''),(43761,13964,'119514','printshop-mobile','block_type','1',0,''),(43762,13964,'119514','printshop-mobile','background-color','#ffffff',0,''),(43763,13964,'119514','printshop-mobile','padding-top','20',0,''),(43764,13964,'119514','printshop-mobile','padding-left','20',0,''),(43765,13964,'119514','printshop-mobile','padding-right','20',0,''),(43766,13964,'119514','printshop-mobile','padding-bottom','20',0,''),(43767,13965,'119515','printshop-mobile','block_type','7',0,''),(43768,13965,'119515','printshop-mobile','font-weight','normal',0,''),(43769,13965,'119515','printshop-mobile','padding-left','10',0,''),(43770,13965,'119515','printshop-mobile','padding-right','10',0,''),(43771,13965,'119515','printshop-mobile','padding-bottom','15',0,''),(43772,13965,'119515','printshop-mobile','border-bottom-width','1',0,''),(43773,13965,'119515','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(43774,13966,'119516','printshop-mobile','color','#424242',0,''),(43775,13966,'119516','printshop-mobile','font-size','14',0,''),(43776,13966,'119516','printshop-mobile','font-weight','700',0,''),(43777,13967,'119517','printshop-mobile','font-weight','normal',0,''),(43778,13967,'119517','printshop-mobile','text-align','right',0,''),(43779,13967,'119517','printshop-mobile','color','#757575',0,''),(43780,13967,'119517','printshop-mobile','font-size','11',0,''),(43781,13967,'119517','printshop-mobile','text-transform','uppercase',0,''),(43782,13968,'119518','printshop-mobile','font-weight','normal',0,''),(43783,13968,'119518','printshop-mobile','padding-top','20',0,''),(43784,13968,'119518','printshop-mobile','padding-bottom','20',0,''),(43785,13968,'119518','printshop-mobile','color','#424242',0,''),(43786,13968,'119518','printshop-mobile','font-size','14',0,''),(43787,13969,'119519','printshop-mobile','block_type','1',0,''),(43788,13969,'119519','printshop-mobile','background-color','#eeeeee',0,''),(43789,13969,'119519','printshop-mobile','padding-top','20',0,''),(43790,13969,'119519','printshop-mobile','padding-bottom','20',0,''),(43791,13970,'119520','printshop-mobile','block_type','1',0,''),(43792,13970,'119520','printshop-mobile','max-width','800',0,''),(43793,13970,'119520','printshop-mobile','margin','0 auto',0,''),(43794,13971,'119521','printshop-mobile','block_type','1',0,''),(43795,13971,'119521','printshop-mobile','background-color','#ffffff',0,''),(43796,13971,'119521','printshop-mobile','padding-top','20',0,''),(43797,13971,'119521','printshop-mobile','padding-left','20',0,''),(43798,13971,'119521','printshop-mobile','padding-right','20',0,''),(43799,13971,'119521','printshop-mobile','padding-bottom','20',0,''),(43800,13971,'119521','printshop-mobile','border-top-width','1',0,''),(43801,13971,'119521','printshop-mobile','border-left-width','1',0,''),(43802,13971,'119521','printshop-mobile','border-right-width','1',0,''),(43803,13971,'119521','printshop-mobile','border-bottom-width','1',0,''),(43804,13971,'119521','printshop-mobile','border-top-color','#e0e0e0',0,''),(43805,13971,'119521','printshop-mobile','border-left-color','#e0e0e0',0,''),(43806,13971,'119521','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(43807,13971,'119521','printshop-mobile','border-right-color','#e0e0e0',0,''),(43808,13972,'119522','printshop-mobile','font-weight','normal',0,''),(43809,13972,'119522','printshop-mobile','padding-top','20',0,''),(43810,13972,'119522','printshop-mobile','padding-bottom','20',0,''),(43811,13972,'119522','printshop-mobile','color','#424242',0,''),(43812,13972,'119522','printshop-mobile','font-size','14',0,''),(43813,13973,'119523','printshop-mobile','block_type','2',0,''),(43814,13974,'119524','printshop-mobile','font-weight','normal',0,''),(43815,13974,'119524','printshop-mobile','padding-bottom','10',0,''),(43816,13974,'119524','printshop-mobile','padding-top','10',0,''),(43817,13974,'119524','printshop-mobile','logo_from','theme',0,''),(43818,13975,'119525','printshop-mobile','color','#424242',0,''),(43819,13975,'119525','printshop-mobile','font-size','14',0,''),(43820,13975,'119525','printshop-mobile','font-weight','700',0,''),(43821,13975,'119525','printshop-mobile','text-align','right',0,''),(43822,13976,'119526','printshop-mobile','font-weight','normal',0,''),(43823,13976,'119526','printshop-mobile','text-align','right',0,''),(43824,13976,'119526','printshop-mobile','color','#757575',0,''),(43825,13976,'119526','printshop-mobile','font-size','11',0,''),(43826,13976,'119526','printshop-mobile','text-transform','uppercase',0,''),(43827,13977,'119527','printshop-mobile','color','#757575',0,''),(43828,13977,'119527','printshop-mobile','font-size','12',0,''),(43829,13977,'119527','printshop-mobile','padding-top','20',0,''),(43830,13977,'119527','printshop-mobile','padding-bottom','20',0,''),(43831,13977,'119527','printshop-mobile','text-align','left',0,''),(43832,13978,'119528','printshop-mobile','block_type','1',0,''),(43833,13978,'119528','printshop-mobile','font-weight','normal',0,''),(43834,13978,'119528','printshop-mobile','margin-top','40',0,''),(43835,13979,'119529','printshop-mobile','block_type','1',0,''),(43836,13980,'119530','printshop-mobile','text','Account',1,''),(43837,13980,'119530','printshop-mobile','style_class','footerTitle',0,''),(43838,13980,'119530','printshop-mobile','font-family','Varela Round',0,''),(43839,13980,'119530','printshop-mobile','font-size','18',0,''),(43840,13980,'119530','printshop-mobile','text-transform','uppercase',0,''),(43841,13981,'119531','printshop-mobile','class','menu-style-2',0,''),(43842,13981,'119531','printshop-mobile','padding-top','10',0,''),(43843,13981,'119531','printshop-mobile','padding-bottom','20',0,''),(43844,13982,'119532','printshop-mobile','border-top-width','1',0,''),(43845,13982,'119532','printshop-mobile','border-top-color','#e0e0e0',0,''),(43846,13982,'119532','printshop-mobile','padding-top','20',0,''),(43847,13983,'119533','printshop-mobile','block_type','1',0,''),(43848,13984,'119534','printshop-mobile','class','menu-style-2',0,''),(43849,13984,'119534','printshop-mobile','padding-top','10',0,''),(43850,13984,'119534','printshop-mobile','padding-bottom','20',0,''),(43851,13985,'119535','printshop-mobile','text','Account',1,''),(43852,13985,'119535','printshop-mobile','style_class','footerTitle',0,''),(43855,13985,'119535','printshop-mobile','font-family','Varela Round',0,''),(43856,13985,'119535','printshop-mobile','font-size','18',0,''),(43857,13985,'119535','printshop-mobile','text-transform','uppercase',0,''),(43858,13986,'119536','printshop-mobile','block_type','1',0,''),(43859,13987,'119537','printshop-mobile','text','Account',1,''),(43860,13987,'119537','printshop-mobile','style_class','footerTitle',0,''),(43863,13987,'119537','printshop-mobile','font-family','Varela Round',0,''),(43864,13987,'119537','printshop-mobile','text-transform','uppercase',0,''),(43865,13987,'119537','printshop-mobile','font-size','18',0,''),(43866,13988,'119538','printshop-mobile','class','menu-style-2',0,''),(43867,13988,'119538','printshop-mobile','padding-top','10',0,''),(43868,13988,'119538','printshop-mobile','padding-bottom','20',0,''),(43869,13989,'119539','printshop-mobile','block_type','1',0,''),(43870,13990,'119540','printshop-mobile','view_item','address',0,''),(43871,13990,'119540','printshop-mobile','address_spacer',',<span> </span>',0,''),(43872,13990,'119540','printshop-mobile','padding-top','10',0,''),(43873,13990,'119540','printshop-mobile','padding-bottom','20',0,''),(43874,13991,'119541','printshop-mobile','text','Account',1,''),(43875,13991,'119541','printshop-mobile','style_class','footerTitle',0,''),(43878,13991,'119541','printshop-mobile','font-family','Varela Round',0,''),(43879,13991,'119541','printshop-mobile','font-size','18',0,''),(43880,13991,'119541','printshop-mobile','text-transform','uppercase',0,''),(43881,13992,'119542','printshop-mobile','block_type','5',0,''),(43882,13993,'119543','printshop-mobile','text','##TEXT_LANGUAGE##',0,''),(43883,13995,'119545','printshop-mobile','block_type','5',0,''),(43884,13996,'119546','printshop-mobile','text','##TEXT_CURRENCY##',0,''),(43885,13998,'119548','printshop-mobile','block_type','1',0,''),(43886,13998,'119548','printshop-mobile','font-weight','normal',0,''),(43887,13999,'119549','printshop-mobile','block_type','2',0,''),(43888,13999,'119549','printshop-mobile','font-weight','normal',0,''),(43889,13999,'119549','printshop-mobile','padding-bottom','20',0,''),(43890,14000,'119550','printshop-mobile','block_type','1',0,''),(43891,14000,'119550','printshop-mobile','margin-right','20',0,''),(43892,14001,'119551','printshop-mobile','block_type','1',0,''),(43893,14001,'119551','printshop-mobile','font-weight','normal',0,''),(43894,14001,'119551','printshop-mobile','style_class','gift-card-view',0,''),(43895,14001,'119551','printshop-mobile','text-align','center',0,''),(43896,14001,'119551','printshop-mobile','padding-bottom','20',0,''),(43897,14001,'119551','printshop-mobile','background-color','#4546e2',0,''),(43898,14001,'119551','printshop-mobile','padding-left','20',0,''),(43899,14001,'119551','printshop-mobile','padding-right','20',0,''),(43900,14001,'119551','printshop-mobile','color','#f4f2f2',0,''),(43901,14002,'119552','printshop-mobile','block_type','1',0,''),(43902,14002,'119552','printshop-mobile','font-weight','normal',0,''),(43903,14002,'119552','printshop-mobile','padding-top','10',0,''),(43904,14003,'119553','printshop-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(43905,14003,'119553','printshop-mobile','font-weight','normal',0,''),(43906,14003,'119553','printshop-mobile','text-align','center',0,''),(43907,14003,'119553','printshop-mobile','font-size','12',0,''),(43908,14003,'119553','printshop-mobile','padding-top','10',0,''),(43909,14003,'119553','printshop-mobile','padding-bottom','5',0,''),(43910,14003,'119553','printshop-mobile','border-top-width','1',0,''),(43911,14003,'119553','printshop-mobile','border-top-color','#dfa82a',0,''),(43912,14004,'119554','printshop-mobile','font-size','12',0,''),(43913,14004,'119554','printshop-mobile','font-weight','bold',0,''),(43914,14004,'119554','printshop-mobile','text-align','center',0,''),(43915,14004,'119554','printshop-mobile','style_class','email',0,''),(43916,14005,'119555','printshop-mobile','font-size','12',0,''),(43917,14005,'119555','printshop-mobile','font-weight','bold',0,''),(43918,14005,'119555','printshop-mobile','text-align','center',0,''),(43919,14005,'119555','printshop-mobile','style_class','phone',0,''),(43920,14005,'119555','printshop-mobile','padding-bottom','5',0,''),(43921,14006,'119556','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(43922,14006,'119556','printshop-mobile','font-weight','normal',0,''),(43923,14006,'119556','printshop-mobile','text-align','center',0,''),(43924,14006,'119556','printshop-mobile','padding-top','20',0,''),(43925,14006,'119556','printshop-mobile','padding-bottom','10',0,''),(43926,14006,'119556','printshop-mobile','style_class','question-ico',0,''),(43927,14006,'119556','printshop-mobile','border-top-width','1',0,''),(43928,14006,'119556','printshop-mobile','border-top-color','#dfa82a',0,''),(43929,14006,'119556','printshop-mobile','font-size','18',0,''),(43930,14007,'119557','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(43931,14007,'119557','printshop-mobile','font-size','18',0,''),(43932,14007,'119557','printshop-mobile','font-weight','normal',0,''),(43933,14007,'119557','printshop-mobile','text-align','center',0,''),(43934,14007,'119557','printshop-mobile','padding-top','20',0,''),(43935,14007,'119557','printshop-mobile','padding-bottom','10',0,''),(43936,14007,'119557','printshop-mobile','border-top-width','1',0,''),(43937,14007,'119557','printshop-mobile','border-top-color','#dfa82a',0,''),(43938,14008,'119558','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(43939,14008,'119558','printshop-mobile','font-weight','normal',0,''),(43940,14008,'119558','printshop-mobile','text-align','center',0,''),(43941,14008,'119558','printshop-mobile','padding-bottom','10',0,''),(43942,14008,'119558','printshop-mobile','font-size','14',0,''),(43943,14009,'119559','printshop-mobile','text','<p>GIFT CARD</p>',1,''),(43944,14009,'119559','printshop-mobile','font-size','30',0,''),(43945,14009,'119559','printshop-mobile','font-weight','normal',0,''),(43946,14009,'119559','printshop-mobile','border-top-width','1',0,''),(43947,14009,'119559','printshop-mobile','border-top-color','#dfa82a',0,''),(43948,14009,'119559','printshop-mobile','style_class','gift-ico',0,''),(43949,14009,'119559','printshop-mobile','text-align','center',0,''),(43950,14009,'119559','printshop-mobile','padding-top','15',0,''),(43951,14010,'119560','printshop-mobile','block_type','4',0,''),(43952,14010,'119560','printshop-mobile','color','#ffffff',0,''),(43953,14010,'119560','printshop-mobile','font-size','30',0,''),(43954,14010,'119560','printshop-mobile','font-weight','normal',0,''),(43955,14010,'119560','printshop-mobile','background-color','#ee4225',0,''),(43956,14010,'119560','printshop-mobile','padding-top','5',0,''),(43957,14010,'119560','printshop-mobile','padding-left','10',0,''),(43958,14010,'119560','printshop-mobile','padding-right','10',0,''),(43959,14010,'119560','printshop-mobile','padding-bottom','5',0,''),(43960,14011,'119561','printshop-mobile','text','<p>Your code is:</p>',1,''),(43961,14011,'119561','printshop-mobile','font-weight','normal',0,''),(43962,14013,'119563','printshop-mobile','font-weight','normal',0,''),(43963,14013,'119563','printshop-mobile','text-align','center',0,''),(43964,14013,'119563','printshop-mobile','padding-bottom','20',0,''),(43965,14014,'119564','printshop-mobile','font-size','60',0,''),(43966,14014,'119564','printshop-mobile','font-weight','bold',0,''),(43967,14014,'119564','printshop-mobile','text-align','center',0,''),(43968,14014,'119564','printshop-mobile','line-height','100',0,''),(43969,14014,'119564','printshop-mobile','padding-bottom','20',0,''),(43970,14014,'119564','printshop-mobile','line_height_measure','px',0,''),(43971,14015,'119565','printshop-mobile','text','<p>HOLBI</p>',1,''),(43972,14015,'119565','printshop-mobile','font-family','Varela Round',0,''),(43973,14015,'119565','printshop-mobile','font-size','24',0,''),(43974,14015,'119565','printshop-mobile','font-weight','normal',0,''),(43975,14015,'119565','printshop-mobile','text-align','center',0,''),(43976,14015,'119565','printshop-mobile','padding-top','10',0,''),(43977,14015,'119565','printshop-mobile','padding-bottom','20',0,''),(43978,14017,'119567','printshop-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(43979,14017,'119567','printshop-mobile','font-weight','normal',0,''),(43980,14017,'119567','printshop-mobile','padding-bottom','20',0,''),(43981,14019,'119569','printshop-mobile','block_type','1',0,''),(43982,14019,'119569','printshop-mobile','font-weight','normal',0,''),(43983,14019,'119569','printshop-mobile','style_class','gift-card-view',0,''),(43984,14019,'119569','printshop-mobile','text-align','center',0,''),(43985,14019,'119569','printshop-mobile','padding-bottom','20',0,''),(43986,14019,'119569','printshop-mobile','background-color','#183d78',0,''),(43987,14019,'119569','printshop-mobile','padding-left','20',0,''),(43988,14019,'119569','printshop-mobile','padding-right','20',0,''),(43989,14019,'119569','printshop-mobile','color','#cccccc',0,''),(43990,14020,'119570','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(43991,14020,'119570','printshop-mobile','font-weight','normal',0,''),(43992,14020,'119570','printshop-mobile','text-align','center',0,''),(43993,14020,'119570','printshop-mobile','padding-bottom','10',0,''),(43994,14020,'119570','printshop-mobile','font-size','14',0,''),(43995,14021,'119571','printshop-mobile','text','<p>GIFT CARD</p>',1,''),(43996,14021,'119571','printshop-mobile','font-size','30',0,''),(43997,14021,'119571','printshop-mobile','font-weight','normal',0,''),(43998,14021,'119571','printshop-mobile','border-top-width','1',0,''),(43999,14021,'119571','printshop-mobile','border-top-color','#dfa82a',0,''),(44000,14021,'119571','printshop-mobile','style_class','gift-ico',0,''),(44001,14021,'119571','printshop-mobile','text-align','center',0,''),(44002,14021,'119571','printshop-mobile','padding-top','15',0,''),(44003,14022,'119572','printshop-mobile','logo','themes/printshop-mobile/img/logo-1.png',1,''),(44004,14023,'119573','printshop-mobile','logo','themes/printshop-mobile/img/bestseller-1.png',1,''),(44005,14024,'119574','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(44006,14024,'119574','printshop-mobile','font-size','18',0,''),(44007,14024,'119574','printshop-mobile','font-weight','normal',0,''),(44008,14024,'119574','printshop-mobile','text-align','center',0,''),(44009,14024,'119574','printshop-mobile','padding-top','20',0,''),(44010,14024,'119574','printshop-mobile','padding-bottom','10',0,''),(44011,14024,'119574','printshop-mobile','border-top-width','1',0,''),(44012,14024,'119574','printshop-mobile','border-top-color','#dfa82a',0,''),(44013,14025,'119575','printshop-mobile','font-size','60',0,''),(44014,14025,'119575','printshop-mobile','font-weight','bold',0,''),(44015,14025,'119575','printshop-mobile','text-align','center',0,''),(44016,14025,'119575','printshop-mobile','line-height','100',0,''),(44017,14025,'119575','printshop-mobile','padding-bottom','20',0,''),(44018,14025,'119575','printshop-mobile','line_height_measure','px',0,''),(44019,14026,'119576','printshop-mobile','font-weight','normal',0,''),(44020,14026,'119576','printshop-mobile','text-align','center',0,''),(44021,14026,'119576','printshop-mobile','padding-bottom','20',0,''),(44022,14027,'119577','printshop-mobile','block_type','4',0,''),(44023,14027,'119577','printshop-mobile','color','#ffffff',0,''),(44024,14027,'119577','printshop-mobile','font-size','30',0,''),(44025,14027,'119577','printshop-mobile','font-weight','normal',0,''),(44026,14027,'119577','printshop-mobile','background-color','#ee4225',0,''),(44027,14027,'119577','printshop-mobile','padding-top','5',0,''),(44028,14027,'119577','printshop-mobile','padding-left','10',0,''),(44029,14027,'119577','printshop-mobile','padding-right','10',0,''),(44030,14027,'119577','printshop-mobile','padding-bottom','5',0,''),(44031,14028,'119578','printshop-mobile','text','<p>Your code is:</p>',1,''),(44032,14028,'119578','printshop-mobile','font-weight','normal',0,''),(44033,14030,'119580','printshop-mobile','text','<p>HOLBI</p>',1,''),(44034,14030,'119580','printshop-mobile','font-family','Varela Round',0,''),(44035,14030,'119580','printshop-mobile','font-size','24',0,''),(44036,14030,'119580','printshop-mobile','font-weight','normal',0,''),(44037,14030,'119580','printshop-mobile','text-align','center',0,''),(44038,14030,'119580','printshop-mobile','padding-top','10',0,''),(44039,14030,'119580','printshop-mobile','padding-bottom','20',0,''),(44040,14031,'119581','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(44041,14031,'119581','printshop-mobile','font-weight','normal',0,''),(44042,14031,'119581','printshop-mobile','text-align','center',0,''),(44043,14031,'119581','printshop-mobile','padding-top','20',0,''),(44044,14031,'119581','printshop-mobile','padding-bottom','10',0,''),(44045,14031,'119581','printshop-mobile','style_class','question-ico',0,''),(44046,14031,'119581','printshop-mobile','border-top-width','1',0,''),(44047,14031,'119581','printshop-mobile','border-top-color','#dfa82a',0,''),(44048,14031,'119581','printshop-mobile','font-size','18',0,''),(44049,14032,'119582','printshop-mobile','block_type','1',0,''),(44050,14032,'119582','printshop-mobile','font-weight','normal',0,''),(44051,14032,'119582','printshop-mobile','padding-top','10',0,''),(44052,14033,'119583','printshop-mobile','font-size','12',0,''),(44053,14033,'119583','printshop-mobile','font-weight','bold',0,''),(44054,14033,'119583','printshop-mobile','text-align','center',0,''),(44055,14033,'119583','printshop-mobile','style_class','phone',0,''),(44056,14033,'119583','printshop-mobile','padding-bottom','5',0,''),(44057,14034,'119584','printshop-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(44058,14034,'119584','printshop-mobile','font-weight','normal',0,''),(44059,14034,'119584','printshop-mobile','text-align','center',0,''),(44060,14034,'119584','printshop-mobile','font-size','12',0,''),(44061,14034,'119584','printshop-mobile','padding-top','10',0,''),(44062,14034,'119584','printshop-mobile','padding-bottom','5',0,''),(44063,14034,'119584','printshop-mobile','border-top-width','1',0,''),(44064,14034,'119584','printshop-mobile','border-top-color','#dfa82a',0,''),(44065,14035,'119585','printshop-mobile','font-size','12',0,''),(44066,14035,'119585','printshop-mobile','font-weight','bold',0,''),(44067,14035,'119585','printshop-mobile','text-align','center',0,''),(44068,14035,'119585','printshop-mobile','style_class','email',0,''),(44069,14036,'119586','printshop-mobile','block_type','1',0,''),(44070,14036,'119586','printshop-mobile','font-weight','normal',0,''),(44071,14036,'119586','printshop-mobile','style_class','gift-card-view',0,''),(44072,14036,'119586','printshop-mobile','text-align','center',0,''),(44073,14036,'119586','printshop-mobile','padding-bottom','20',0,''),(44074,14036,'119586','printshop-mobile','background-color','#5289a4',0,''),(44075,14036,'119586','printshop-mobile','padding-left','20',0,''),(44076,14036,'119586','printshop-mobile','padding-right','20',0,''),(44077,14036,'119586','printshop-mobile','color','#cccccc',0,''),(44078,14037,'119587','printshop-mobile','text','<p>HOLBI</p>',1,''),(44079,14037,'119587','printshop-mobile','font-family','Varela Round',0,''),(44080,14037,'119587','printshop-mobile','font-size','24',0,''),(44081,14037,'119587','printshop-mobile','font-weight','normal',0,''),(44082,14037,'119587','printshop-mobile','text-align','center',0,''),(44083,14037,'119587','printshop-mobile','padding-top','10',0,''),(44084,14037,'119587','printshop-mobile','padding-bottom','20',0,''),(44085,14038,'119588','printshop-mobile','text','<p>GIFT CARD</p>',1,''),(44086,14038,'119588','printshop-mobile','font-size','30',0,''),(44087,14038,'119588','printshop-mobile','font-weight','normal',0,''),(44088,14038,'119588','printshop-mobile','border-top-width','1',0,''),(44089,14038,'119588','printshop-mobile','border-top-color','#dfa82a',0,''),(44090,14038,'119588','printshop-mobile','style_class','gift-ico',0,''),(44091,14038,'119588','printshop-mobile','text-align','center',0,''),(44092,14038,'119588','printshop-mobile','padding-top','15',0,''),(44093,14039,'119589','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(44094,14039,'119589','printshop-mobile','font-weight','normal',0,''),(44095,14039,'119589','printshop-mobile','text-align','center',0,''),(44096,14039,'119589','printshop-mobile','padding-top','20',0,''),(44097,14039,'119589','printshop-mobile','padding-bottom','10',0,''),(44098,14039,'119589','printshop-mobile','style_class','question-ico',0,''),(44099,14039,'119589','printshop-mobile','border-top-width','1',0,''),(44100,14039,'119589','printshop-mobile','border-top-color','#dfa82a',0,''),(44101,14039,'119589','printshop-mobile','font-size','18',0,''),(44102,14040,'119590','printshop-mobile','font-weight','normal',0,''),(44103,14040,'119590','printshop-mobile','text-align','center',0,''),(44104,14040,'119590','printshop-mobile','padding-bottom','20',0,''),(44105,14041,'119591','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(44106,14041,'119591','printshop-mobile','font-weight','normal',0,''),(44107,14041,'119591','printshop-mobile','text-align','center',0,''),(44108,14041,'119591','printshop-mobile','padding-bottom','10',0,''),(44109,14041,'119591','printshop-mobile','font-size','14',0,''),(44110,14042,'119592','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(44111,14042,'119592','printshop-mobile','font-size','18',0,''),(44112,14042,'119592','printshop-mobile','font-weight','normal',0,''),(44113,14042,'119592','printshop-mobile','text-align','center',0,''),(44114,14042,'119592','printshop-mobile','padding-top','20',0,''),(44115,14042,'119592','printshop-mobile','padding-bottom','10',0,''),(44116,14042,'119592','printshop-mobile','border-top-width','1',0,''),(44117,14042,'119592','printshop-mobile','border-top-color','#dfa82a',0,''),(44118,14043,'119593','printshop-mobile','block_type','1',0,''),(44119,14043,'119593','printshop-mobile','font-weight','normal',0,''),(44120,14043,'119593','printshop-mobile','padding-top','10',0,''),(44121,14044,'119594','printshop-mobile','font-size','12',0,''),(44122,14044,'119594','printshop-mobile','font-weight','bold',0,''),(44123,14044,'119594','printshop-mobile','text-align','center',0,''),(44124,14044,'119594','printshop-mobile','style_class','phone',0,''),(44125,14044,'119594','printshop-mobile','padding-bottom','5',0,''),(44126,14045,'119595','printshop-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(44127,14045,'119595','printshop-mobile','font-weight','normal',0,''),(44128,14045,'119595','printshop-mobile','text-align','center',0,''),(44129,14045,'119595','printshop-mobile','font-size','12',0,''),(44130,14045,'119595','printshop-mobile','padding-top','10',0,''),(44131,14045,'119595','printshop-mobile','padding-bottom','5',0,''),(44132,14045,'119595','printshop-mobile','border-top-width','1',0,''),(44133,14045,'119595','printshop-mobile','border-top-color','#dfa82a',0,''),(44134,14046,'119596','printshop-mobile','font-size','12',0,''),(44135,14046,'119596','printshop-mobile','font-weight','bold',0,''),(44136,14046,'119596','printshop-mobile','text-align','center',0,''),(44137,14046,'119596','printshop-mobile','style_class','email',0,''),(44138,14047,'119597','printshop-mobile','block_type','4',0,''),(44139,14047,'119597','printshop-mobile','color','#ffffff',0,''),(44140,14047,'119597','printshop-mobile','font-size','30',0,''),(44141,14047,'119597','printshop-mobile','font-weight','normal',0,''),(44142,14047,'119597','printshop-mobile','background-color','#ee4225',0,''),(44143,14047,'119597','printshop-mobile','padding-top','5',0,''),(44144,14047,'119597','printshop-mobile','padding-left','10',0,''),(44145,14047,'119597','printshop-mobile','padding-right','10',0,''),(44146,14047,'119597','printshop-mobile','padding-bottom','5',0,''),(44147,14048,'119598','printshop-mobile','text','<p>Your code is:</p>',1,''),(44148,14048,'119598','printshop-mobile','font-weight','normal',0,''),(44149,14050,'119600','printshop-mobile','font-size','60',0,''),(44150,14050,'119600','printshop-mobile','font-weight','bold',0,''),(44151,14050,'119600','printshop-mobile','text-align','center',0,''),(44152,14050,'119600','printshop-mobile','line-height','100',0,''),(44153,14050,'119600','printshop-mobile','padding-bottom','20',0,''),(44154,14050,'119600','printshop-mobile','line_height_measure','px',0,''),(44155,14051,'119601','printshop-mobile','block_type','1',0,''),(44156,14051,'119601','printshop-mobile','font-weight','normal',0,''),(44157,14051,'119601','printshop-mobile','style_class','gift-card-view',0,''),(44158,14051,'119601','printshop-mobile','text-align','center',0,''),(44159,14051,'119601','printshop-mobile','padding-bottom','20',0,''),(44160,14051,'119601','printshop-mobile','background-color','#5289a4',0,''),(44161,14051,'119601','printshop-mobile','padding-left','20',0,''),(44162,14051,'119601','printshop-mobile','padding-right','20',0,''),(44163,14051,'119601','printshop-mobile','color','#cccccc',0,''),(44164,14052,'119602','printshop-mobile','block_type','1',0,''),(44165,14052,'119602','printshop-mobile','font-weight','normal',0,''),(44166,14052,'119602','printshop-mobile','padding-top','10',0,''),(44167,14053,'119603','printshop-mobile','font-size','12',0,''),(44168,14053,'119603','printshop-mobile','font-weight','bold',0,''),(44169,14053,'119603','printshop-mobile','text-align','center',0,''),(44170,14053,'119603','printshop-mobile','style_class','email',0,''),(44171,14053,'119603','printshop-mobile','color','#ffffff',0,''),(44172,14054,'119604','printshop-mobile','font-size','12',0,''),(44173,14054,'119604','printshop-mobile','font-weight','bold',0,''),(44174,14054,'119604','printshop-mobile','text-align','center',0,''),(44175,14054,'119604','printshop-mobile','style_class','phone',0,''),(44176,14054,'119604','printshop-mobile','padding-bottom','5',0,''),(44177,14054,'119604','printshop-mobile','color','#ffffff',0,''),(44178,14055,'119605','printshop-mobile','text','If you require further assistance please contact us',0,''),(44179,14055,'119605','printshop-mobile','font-size','12',0,''),(44180,14055,'119605','printshop-mobile','color','#ffffff',0,''),(44181,14055,'119605','printshop-mobile','text-align','center',0,''),(44182,14055,'119605','printshop-mobile','padding-top','10',0,''),(44183,14056,'119606','printshop-mobile','block_type','4',0,''),(44184,14056,'119606','printshop-mobile','color','#ffffff',0,''),(44185,14056,'119606','printshop-mobile','font-size','30',0,''),(44186,14056,'119606','printshop-mobile','font-weight','normal',0,''),(44187,14056,'119606','printshop-mobile','background-color','#ee4225',0,''),(44188,14056,'119606','printshop-mobile','padding-top','5',0,''),(44189,14056,'119606','printshop-mobile','padding-left','10',0,''),(44190,14056,'119606','printshop-mobile','padding-right','10',0,''),(44191,14056,'119606','printshop-mobile','padding-bottom','5',0,''),(44192,14057,'119607','printshop-mobile','text','Your code is:',0,''),(44193,14057,'119607','printshop-mobile','font-size','30',0,''),(44194,14057,'119607','printshop-mobile','color','#ffffff',0,''),(44195,14058,'119608','printshop-mobile','color','#ffffff',0,''),(44196,14058,'119608','printshop-mobile','font-size','30',0,''),(44197,14059,'119609','printshop-mobile','block_type','1',0,''),(44198,14060,'119610','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(44199,14060,'119610','printshop-mobile','font-size','18',0,''),(44200,14060,'119610','printshop-mobile','font-weight','normal',0,''),(44201,14060,'119610','printshop-mobile','text-align','center',0,''),(44202,14060,'119610','printshop-mobile','padding-top','20',0,''),(44203,14060,'119610','printshop-mobile','padding-bottom','10',0,''),(44204,14060,'119610','printshop-mobile','border-top-width','1',0,''),(44205,14060,'119610','printshop-mobile','border-top-color','#dfa82a',0,''),(44206,14061,'119611','printshop-mobile','text','HOLBI',0,''),(44207,14061,'119611','printshop-mobile','color','#ffffff',0,''),(44208,14061,'119611','printshop-mobile','font-size','24',0,''),(44209,14061,'119611','printshop-mobile','padding-top','20',0,''),(44210,14061,'119611','printshop-mobile','text-align','center',0,''),(44211,14061,'119611','printshop-mobile','padding-bottom','20',0,''),(44212,14062,'119612','printshop-mobile','border-top-color','#dfa82a',0,''),(44213,14062,'119612','printshop-mobile','border-top-width','1',0,''),(44214,14062,'119612','printshop-mobile','padding-top','20',0,''),(44215,14062,'119612','printshop-mobile','font-size','30',0,''),(44216,14062,'119612','printshop-mobile','text-align','center',0,''),(44217,14062,'119612','printshop-mobile','color','#ffffff',0,''),(44218,14062,'119612','printshop-mobile','text','GIFT CARD',0,''),(44219,14063,'119613','printshop-mobile','text-align','center',0,''),(44220,14063,'119613','printshop-mobile','font-weight','bold',0,''),(44221,14063,'119613','printshop-mobile','font-size','60',0,''),(44222,14063,'119613','printshop-mobile','color','#ffffff',0,''),(44223,14064,'119614','printshop-mobile','font-size','20',0,''),(44224,14064,'119614','printshop-mobile','text-align','center',0,''),(44225,14064,'119614','printshop-mobile','color','#ffffff',0,''),(44226,14064,'119614','printshop-mobile','padding-top','20',0,''),(44227,14064,'119614','printshop-mobile','padding-bottom','20',0,''),(44228,14065,'119615','printshop-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(44229,14065,'119615','printshop-mobile','text-align','center',0,''),(44230,14065,'119615','printshop-mobile','color','#ffffff',0,''),(44231,14065,'119615','printshop-mobile','font-size','14',0,''),(44232,14065,'119615','printshop-mobile','padding-bottom','20',0,''),(44233,14066,'119616','printshop-mobile','text','WHAT TO DO NEXT:',0,''),(44234,14066,'119616','printshop-mobile','font-size','18',0,''),(44235,14066,'119616','printshop-mobile','text-align','center',0,''),(44236,14066,'119616','printshop-mobile','color','#ffffff',0,''),(44237,14066,'119616','printshop-mobile','padding-top','20',0,''),(44238,14066,'119616','printshop-mobile','padding-bottom','10',0,''),(44239,14066,'119616','printshop-mobile','border-top-width','1',0,''),(44240,14066,'119616','printshop-mobile','border-top-color','#dfa82a',0,''),(44241,14068,'119618','printshop-mobile','block_type','1',0,''),(44242,14068,'119618','printshop-mobile','font-weight','normal',0,''),(44243,14068,'119618','printshop-mobile','style_class','gift-card-view',0,''),(44244,14068,'119618','printshop-mobile','text-align','center',0,''),(44245,14068,'119618','printshop-mobile','padding-bottom','20',0,''),(44246,14068,'119618','printshop-mobile','background-color','#183d78',0,''),(44247,14068,'119618','printshop-mobile','padding-left','20',0,''),(44248,14068,'119618','printshop-mobile','padding-right','20',0,''),(44249,14068,'119618','printshop-mobile','color','#cccccc',0,''),(44250,14069,'119619','printshop-mobile','block_type','1',0,''),(44251,14069,'119619','printshop-mobile','font-weight','normal',0,''),(44252,14069,'119619','printshop-mobile','padding-top','10',0,''),(44253,14070,'119620','printshop-mobile','font-size','12',0,''),(44254,14070,'119620','printshop-mobile','font-weight','bold',0,''),(44255,14070,'119620','printshop-mobile','text-align','center',0,''),(44256,14070,'119620','printshop-mobile','style_class','email',0,''),(44257,14070,'119620','printshop-mobile','color','#ffffff',0,''),(44258,14071,'119621','printshop-mobile','font-size','12',0,''),(44259,14071,'119621','printshop-mobile','font-weight','bold',0,''),(44260,14071,'119621','printshop-mobile','text-align','center',0,''),(44261,14071,'119621','printshop-mobile','style_class','phone',0,''),(44262,14071,'119621','printshop-mobile','padding-bottom','5',0,''),(44263,14071,'119621','printshop-mobile','color','#ffffff',0,''),(44264,14072,'119622','printshop-mobile','text','If you require further assistance please contact us',0,''),(44265,14072,'119622','printshop-mobile','font-size','12',0,''),(44266,14072,'119622','printshop-mobile','color','#ffffff',0,''),(44267,14072,'119622','printshop-mobile','text-align','center',0,''),(44268,14072,'119622','printshop-mobile','padding-top','10',0,''),(44269,14073,'119623','printshop-mobile','block_type','4',0,''),(44270,14073,'119623','printshop-mobile','color','#ffffff',0,''),(44271,14073,'119623','printshop-mobile','font-size','30',0,''),(44272,14073,'119623','printshop-mobile','font-weight','normal',0,''),(44273,14073,'119623','printshop-mobile','background-color','#ee4225',0,''),(44274,14073,'119623','printshop-mobile','padding-top','5',0,''),(44275,14073,'119623','printshop-mobile','padding-left','10',0,''),(44276,14073,'119623','printshop-mobile','padding-right','10',0,''),(44277,14073,'119623','printshop-mobile','padding-bottom','5',0,''),(44278,14074,'119624','printshop-mobile','text','Your code is:',0,''),(44279,14074,'119624','printshop-mobile','font-size','30',0,''),(44280,14074,'119624','printshop-mobile','color','#ffffff',0,''),(44281,14075,'119625','printshop-mobile','color','#ffffff',0,''),(44282,14075,'119625','printshop-mobile','font-size','30',0,''),(44283,14076,'119626','printshop-mobile','block_type','1',0,''),(44284,14077,'119627','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(44285,14077,'119627','printshop-mobile','font-size','18',0,''),(44286,14077,'119627','printshop-mobile','font-weight','normal',0,''),(44287,14077,'119627','printshop-mobile','text-align','center',0,''),(44288,14077,'119627','printshop-mobile','padding-top','20',0,''),(44289,14077,'119627','printshop-mobile','padding-bottom','10',0,''),(44290,14077,'119627','printshop-mobile','border-top-width','1',0,''),(44291,14077,'119627','printshop-mobile','border-top-color','#dfa82a',0,''),(44292,14078,'119628','printshop-mobile','text','HOLBI',0,''),(44293,14078,'119628','printshop-mobile','color','#ffffff',0,''),(44294,14078,'119628','printshop-mobile','font-size','24',0,''),(44295,14078,'119628','printshop-mobile','padding-top','20',0,''),(44296,14078,'119628','printshop-mobile','text-align','center',0,''),(44297,14078,'119628','printshop-mobile','padding-bottom','20',0,''),(44298,14079,'119629','printshop-mobile','border-top-color','#dfa82a',0,''),(44299,14079,'119629','printshop-mobile','border-top-width','1',0,''),(44300,14079,'119629','printshop-mobile','padding-top','20',0,''),(44301,14079,'119629','printshop-mobile','font-size','30',0,''),(44302,14079,'119629','printshop-mobile','text-align','center',0,''),(44303,14079,'119629','printshop-mobile','color','#ffffff',0,''),(44304,14079,'119629','printshop-mobile','text','GIFT CARD',0,''),(44305,14080,'119630','printshop-mobile','text-align','center',0,''),(44306,14080,'119630','printshop-mobile','font-weight','bold',0,''),(44307,14080,'119630','printshop-mobile','font-size','60',0,''),(44308,14080,'119630','printshop-mobile','color','#ffffff',0,''),(44309,14081,'119631','printshop-mobile','font-size','20',0,''),(44310,14081,'119631','printshop-mobile','text-align','center',0,''),(44311,14081,'119631','printshop-mobile','color','#ffffff',0,''),(44312,14081,'119631','printshop-mobile','padding-top','20',0,''),(44313,14081,'119631','printshop-mobile','padding-bottom','20',0,''),(44314,14082,'119632','printshop-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(44315,14082,'119632','printshop-mobile','text-align','center',0,''),(44316,14082,'119632','printshop-mobile','color','#ffffff',0,''),(44317,14082,'119632','printshop-mobile','font-size','14',0,''),(44318,14082,'119632','printshop-mobile','padding-bottom','20',0,''),(44319,14083,'119633','printshop-mobile','text','WHAT TO DO NEXT:',0,''),(44320,14083,'119633','printshop-mobile','font-size','18',0,''),(44321,14083,'119633','printshop-mobile','text-align','center',0,''),(44322,14083,'119633','printshop-mobile','color','#ffffff',0,''),(44323,14083,'119633','printshop-mobile','padding-top','20',0,''),(44324,14083,'119633','printshop-mobile','padding-bottom','10',0,''),(44325,14083,'119633','printshop-mobile','border-top-width','1',0,''),(44326,14083,'119633','printshop-mobile','border-top-color','#dfa82a',0,''),(44327,14085,'119635','printshop-mobile','block_type','1',0,''),(44328,14087,'119637','printshop-mobile','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(44329,14087,'119637','printshop-mobile','text-align','center',0,''),(44330,14088,'119638','printshop-mobile','block_type','1',0,''),(44331,14088,'119638','printshop-mobile','font-weight','normal',0,''),(44332,14088,'119638','printshop-mobile','style_class','gift-card-view',0,''),(44333,14088,'119638','printshop-mobile','text-align','center',0,''),(44334,14088,'119638','printshop-mobile','padding-bottom','20',0,''),(44335,14088,'119638','printshop-mobile','background-color','#47a793',0,''),(44336,14088,'119638','printshop-mobile','padding-left','20',0,''),(44337,14088,'119638','printshop-mobile','padding-right','20',0,''),(44338,14088,'119638','printshop-mobile','color','#cccccc',0,''),(44339,14089,'119639','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(44340,14089,'119639','printshop-mobile','font-weight','normal',0,''),(44341,14089,'119639','printshop-mobile','text-align','center',0,''),(44342,14089,'119639','printshop-mobile','padding-bottom','10',0,''),(44343,14089,'119639','printshop-mobile','font-size','14',0,''),(44344,14090,'119640','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(44345,14090,'119640','printshop-mobile','font-size','18',0,''),(44346,14090,'119640','printshop-mobile','font-weight','normal',0,''),(44347,14090,'119640','printshop-mobile','text-align','center',0,''),(44348,14090,'119640','printshop-mobile','padding-top','20',0,''),(44349,14090,'119640','printshop-mobile','padding-bottom','10',0,''),(44350,14090,'119640','printshop-mobile','border-top-width','1',0,''),(44351,14090,'119640','printshop-mobile','border-top-color','#dfa82a',0,''),(44352,14091,'119641','printshop-mobile','font-size','60',0,''),(44353,14091,'119641','printshop-mobile','font-weight','bold',0,''),(44354,14091,'119641','printshop-mobile','text-align','center',0,''),(44355,14091,'119641','printshop-mobile','line-height','100',0,''),(44356,14091,'119641','printshop-mobile','padding-bottom','20',0,''),(44357,14091,'119641','printshop-mobile','line_height_measure','px',0,''),(44358,14092,'119642','printshop-mobile','text','<p>GIFT CARD</p>',1,''),(44359,14092,'119642','printshop-mobile','font-size','30',0,''),(44360,14092,'119642','printshop-mobile','font-weight','normal',0,''),(44361,14092,'119642','printshop-mobile','border-top-width','1',0,''),(44362,14092,'119642','printshop-mobile','border-top-color','#dfa82a',0,''),(44363,14092,'119642','printshop-mobile','style_class','gift-ico',0,''),(44364,14092,'119642','printshop-mobile','text-align','center',0,''),(44365,14092,'119642','printshop-mobile','padding-top','15',0,''),(44366,14093,'119643','printshop-mobile','font-weight','normal',0,''),(44367,14093,'119643','printshop-mobile','text-align','center',0,''),(44368,14093,'119643','printshop-mobile','padding-bottom','20',0,''),(44369,14094,'119644','printshop-mobile','text','<p>HOLBI</p>',1,''),(44370,14094,'119644','printshop-mobile','font-family','Varela Round',0,''),(44371,14094,'119644','printshop-mobile','font-size','24',0,''),(44372,14094,'119644','printshop-mobile','font-weight','normal',0,''),(44373,14094,'119644','printshop-mobile','text-align','center',0,''),(44374,14094,'119644','printshop-mobile','padding-top','10',0,''),(44375,14094,'119644','printshop-mobile','padding-bottom','20',0,''),(44376,14095,'119645','printshop-mobile','block_type','1',0,''),(44377,14095,'119645','printshop-mobile','font-weight','normal',0,''),(44378,14095,'119645','printshop-mobile','padding-top','10',0,''),(44379,14096,'119646','printshop-mobile','font-size','12',0,''),(44380,14096,'119646','printshop-mobile','font-weight','bold',0,''),(44381,14096,'119646','printshop-mobile','text-align','center',0,''),(44382,14096,'119646','printshop-mobile','style_class','email',0,''),(44383,14097,'119647','printshop-mobile','font-size','12',0,''),(44384,14097,'119647','printshop-mobile','font-weight','bold',0,''),(44385,14097,'119647','printshop-mobile','text-align','center',0,''),(44386,14097,'119647','printshop-mobile','style_class','phone',0,''),(44387,14097,'119647','printshop-mobile','padding-bottom','5',0,''),(44388,14098,'119648','printshop-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(44389,14098,'119648','printshop-mobile','font-weight','normal',0,''),(44390,14098,'119648','printshop-mobile','text-align','center',0,''),(44391,14098,'119648','printshop-mobile','font-size','12',0,''),(44392,14098,'119648','printshop-mobile','padding-top','10',0,''),(44393,14098,'119648','printshop-mobile','padding-bottom','5',0,''),(44394,14098,'119648','printshop-mobile','border-top-width','1',0,''),(44395,14098,'119648','printshop-mobile','border-top-color','#dfa82a',0,''),(44396,14099,'119649','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(44397,14099,'119649','printshop-mobile','font-weight','normal',0,''),(44398,14099,'119649','printshop-mobile','text-align','center',0,''),(44399,14099,'119649','printshop-mobile','padding-top','20',0,''),(44400,14099,'119649','printshop-mobile','padding-bottom','10',0,''),(44401,14099,'119649','printshop-mobile','style_class','question-ico',0,''),(44402,14099,'119649','printshop-mobile','border-top-width','1',0,''),(44403,14099,'119649','printshop-mobile','border-top-color','#dfa82a',0,''),(44404,14099,'119649','printshop-mobile','font-size','18',0,''),(44405,14100,'119650','printshop-mobile','block_type','4',0,''),(44406,14100,'119650','printshop-mobile','color','#ffffff',0,''),(44407,14100,'119650','printshop-mobile','font-size','30',0,''),(44408,14100,'119650','printshop-mobile','font-weight','normal',0,''),(44409,14100,'119650','printshop-mobile','background-color','#ee4225',0,''),(44410,14100,'119650','printshop-mobile','padding-top','5',0,''),(44411,14100,'119650','printshop-mobile','padding-left','10',0,''),(44412,14100,'119650','printshop-mobile','padding-right','10',0,''),(44413,14100,'119650','printshop-mobile','padding-bottom','5',0,''),(44414,14101,'119651','printshop-mobile','text','<p>Your code is:</p>',1,''),(44415,14101,'119651','printshop-mobile','font-weight','normal',0,''),(44416,14103,'119653','printshop-mobile','block_type','1',0,''),(44417,14103,'119653','printshop-mobile','font-weight','normal',0,''),(44418,14103,'119653','printshop-mobile','style_class','gift-card-view',0,''),(44419,14103,'119653','printshop-mobile','text-align','center',0,''),(44420,14103,'119653','printshop-mobile','padding-bottom','20',0,''),(44421,14103,'119653','printshop-mobile','background-color','#47a793',0,''),(44422,14103,'119653','printshop-mobile','padding-left','20',0,''),(44423,14103,'119653','printshop-mobile','padding-right','20',0,''),(44424,14103,'119653','printshop-mobile','color','#cccccc',0,''),(44425,14104,'119654','printshop-mobile','block_type','1',0,''),(44426,14104,'119654','printshop-mobile','font-weight','normal',0,''),(44427,14104,'119654','printshop-mobile','padding-top','10',0,''),(44428,14105,'119655','printshop-mobile','font-size','12',0,''),(44429,14105,'119655','printshop-mobile','font-weight','bold',0,''),(44430,14105,'119655','printshop-mobile','text-align','center',0,''),(44431,14105,'119655','printshop-mobile','style_class','email',0,''),(44432,14105,'119655','printshop-mobile','color','#ffffff',0,''),(44433,14106,'119656','printshop-mobile','font-size','12',0,''),(44434,14106,'119656','printshop-mobile','font-weight','bold',0,''),(44435,14106,'119656','printshop-mobile','text-align','center',0,''),(44436,14106,'119656','printshop-mobile','style_class','phone',0,''),(44437,14106,'119656','printshop-mobile','padding-bottom','5',0,''),(44438,14106,'119656','printshop-mobile','color','#ffffff',0,''),(44439,14107,'119657','printshop-mobile','text','If you require further assistance please contact us',0,''),(44440,14107,'119657','printshop-mobile','font-size','12',0,''),(44441,14107,'119657','printshop-mobile','color','#ffffff',0,''),(44442,14107,'119657','printshop-mobile','text-align','center',0,''),(44443,14107,'119657','printshop-mobile','padding-top','10',0,''),(44444,14108,'119658','printshop-mobile','block_type','4',0,''),(44445,14108,'119658','printshop-mobile','color','#ffffff',0,''),(44446,14108,'119658','printshop-mobile','font-size','30',0,''),(44447,14108,'119658','printshop-mobile','font-weight','normal',0,''),(44448,14108,'119658','printshop-mobile','background-color','#ee4225',0,''),(44449,14108,'119658','printshop-mobile','padding-top','5',0,''),(44450,14108,'119658','printshop-mobile','padding-left','10',0,''),(44451,14108,'119658','printshop-mobile','padding-right','10',0,''),(44452,14108,'119658','printshop-mobile','padding-bottom','5',0,''),(44453,14109,'119659','printshop-mobile','text','Your code is:',0,''),(44454,14109,'119659','printshop-mobile','font-size','30',0,''),(44455,14109,'119659','printshop-mobile','color','#ffffff',0,''),(44456,14110,'119660','printshop-mobile','color','#ffffff',0,''),(44457,14110,'119660','printshop-mobile','font-size','30',0,''),(44458,14111,'119661','printshop-mobile','block_type','1',0,''),(44459,14112,'119662','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(44460,14112,'119662','printshop-mobile','font-size','18',0,''),(44461,14112,'119662','printshop-mobile','font-weight','normal',0,''),(44462,14112,'119662','printshop-mobile','text-align','center',0,''),(44463,14112,'119662','printshop-mobile','padding-top','20',0,''),(44464,14112,'119662','printshop-mobile','padding-bottom','10',0,''),(44465,14112,'119662','printshop-mobile','border-top-width','1',0,''),(44466,14112,'119662','printshop-mobile','border-top-color','#dfa82a',0,''),(44467,14113,'119663','printshop-mobile','text','HOLBI',0,''),(44468,14113,'119663','printshop-mobile','color','#ffffff',0,''),(44469,14113,'119663','printshop-mobile','font-size','24',0,''),(44470,14113,'119663','printshop-mobile','padding-top','20',0,''),(44471,14113,'119663','printshop-mobile','text-align','center',0,''),(44472,14113,'119663','printshop-mobile','padding-bottom','20',0,''),(44473,14114,'119664','printshop-mobile','border-top-color','#dfa82a',0,''),(44474,14114,'119664','printshop-mobile','border-top-width','1',0,''),(44475,14114,'119664','printshop-mobile','padding-top','20',0,''),(44476,14114,'119664','printshop-mobile','font-size','30',0,''),(44477,14114,'119664','printshop-mobile','text-align','center',0,''),(44478,14114,'119664','printshop-mobile','color','#ffffff',0,''),(44479,14114,'119664','printshop-mobile','text','GIFT CARD',0,''),(44480,14115,'119665','printshop-mobile','text-align','center',0,''),(44481,14115,'119665','printshop-mobile','font-weight','bold',0,''),(44482,14115,'119665','printshop-mobile','font-size','60',0,''),(44483,14115,'119665','printshop-mobile','color','#ffffff',0,''),(44484,14116,'119666','printshop-mobile','font-size','20',0,''),(44485,14116,'119666','printshop-mobile','text-align','center',0,''),(44486,14116,'119666','printshop-mobile','color','#ffffff',0,''),(44487,14116,'119666','printshop-mobile','padding-top','20',0,''),(44488,14116,'119666','printshop-mobile','padding-bottom','20',0,''),(44489,14117,'119667','printshop-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(44490,14117,'119667','printshop-mobile','text-align','center',0,''),(44491,14117,'119667','printshop-mobile','color','#ffffff',0,''),(44492,14117,'119667','printshop-mobile','font-size','14',0,''),(44493,14117,'119667','printshop-mobile','padding-bottom','20',0,''),(44494,14118,'119668','printshop-mobile','text','WHAT TO DO NEXT:',0,''),(44495,14118,'119668','printshop-mobile','font-size','18',0,''),(44496,14118,'119668','printshop-mobile','text-align','center',0,''),(44497,14118,'119668','printshop-mobile','color','#ffffff',0,''),(44498,14118,'119668','printshop-mobile','padding-top','20',0,''),(44499,14118,'119668','printshop-mobile','padding-bottom','10',0,''),(44500,14118,'119668','printshop-mobile','border-top-width','1',0,''),(44501,14118,'119668','printshop-mobile','border-top-color','#dfa82a',0,''),(44502,14119,'119669','printshop-mobile','logo','themes/printshop-mobile/img/oscommerce_logo.png',1,''),(44503,14119,'119669','printshop-mobile','text-align','center',0,''),(44504,14119,'119669','printshop-mobile','padding-top','10',0,''),(44505,14119,'119669','printshop-mobile','padding-left','60',0,''),(44506,14119,'119669','printshop-mobile','padding-right','60',0,''),(44507,14119,'119669','printshop-mobile','padding-bottom','10',0,''),(44508,14120,'119670','printshop-mobile','text-align','center',0,''),(44509,14120,'119670','printshop-mobile','margin-bottom','20',0,''),(44510,14121,'119671','printshop-mobile','block_type','1',0,''),(44511,14121,'119671','printshop-mobile','background-color','#eeeeee',0,''),(44512,14121,'119671','printshop-mobile','border-bottom-width','1',0,''),(44513,14121,'119671','printshop-mobile','border-bottom-color','#dedede',0,''),(44514,14121,'119671','printshop-mobile','display_none','on',0,'694'),(44515,14122,'119672','printshop-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',1,''),(44516,14122,'119672','printshop-mobile','float','right',0,''),(44517,14122,'119672','printshop-mobile','max-width','450',0,''),(44518,14122,'119672','printshop-mobile','font-size','13',0,''),(44519,14122,'119672','printshop-mobile','padding-top','5',0,''),(44520,14122,'119672','printshop-mobile','padding-bottom','5',0,''),(44521,14122,'119672','printshop-mobile','width','350',0,'701'),(44522,14123,'119673','printshop-mobile','block_type','4',0,''),(44523,14123,'119673','printshop-mobile','display','inline-block',0,''),(44524,14123,'119673','printshop-mobile','width','650',0,''),(44525,14123,'119673','printshop-mobile','vertical-align','middle',0,''),(44526,14123,'119673','printshop-mobile','float','left',0,''),(44527,14123,'119673','printshop-mobile','clear','none',0,''),(44528,14123,'119673','printshop-mobile','text-align','left',0,''),(44529,14123,'119673','printshop-mobile','padding-top','10',0,''),(44530,14123,'119673','printshop-mobile','padding-bottom','10',0,''),(44531,14123,'119673','printshop-mobile','schema','4-2',0,'701'),(44532,14123,'119673','printshop-mobile','width','350',0,'701'),(44533,14123,'119673','printshop-mobile','padding-top','0',0,'701'),(44534,14124,'119674','printshop-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',1,''),(44535,14124,'119674','printshop-mobile','font-family','Hind',0,''),(44536,14124,'119674','printshop-mobile','font-size','22',0,''),(44537,14124,'119674','printshop-mobile','color','#00a858',0,''),(44538,14124,'119674','printshop-mobile','padding-top','7',0,''),(44539,14124,'119674','printshop-mobile','display','inline-block',0,''),(44540,14124,'119674','printshop-mobile','float','left',0,''),(44541,14124,'119674','printshop-mobile','clear','none',0,''),(44542,14124,'119674','printshop-mobile','font-size','20',0,'701'),(44543,14125,'119675','printshop-mobile','logo','themes/printshop-mobile/img/check-2.png',1,''),(44544,14125,'119675','printshop-mobile','display','inline-block',0,''),(44545,14125,'119675','printshop-mobile','vertical-align','top',0,''),(44546,14125,'119675','printshop-mobile','padding-top','10',0,''),(44547,14125,'119675','printshop-mobile','padding-right','10',0,''),(44548,14125,'119675','printshop-mobile','float','left',0,''),(44549,14125,'119675','printshop-mobile','clear','none',0,''),(44550,14126,'119676','printshop-mobile','block_type','2',0,''),(44551,14127,'119677','printshop-mobile','text','<a class=\"secure-1_\" href=\"//www.securitymetrics.com/site_certificate?id=1442870&tk=4964ae06eb42dd2462f57cde979b3228\" target=\"_blank\"><img src=\"images/security.jpg\" alt=\"SecurityMetrics Credit Card Safe\" /></a>',0,''),(44552,14127,'119677','printshop-mobile','text-align','center',0,''),(44553,14128,'119678','printshop-mobile','text','<a href=\"//www.securitymetrics.com/site_certificate?id=1442870&tk=4964ae06eb42dd2462f57cde979b3228\" target=\"_blank\"><img src=\"images/security2.jpg\" alt=\"SecurityMetrics Credit Card Safe\" /></a>',0,''),(44554,14128,'119678','printshop-mobile','text-align','center',0,''),(44555,14129,'119679','printshop-mobile','block_type','14',0,''),(44556,14129,'119679','printshop-mobile','font-weight','400',0,''),(44557,14129,'119679','printshop-mobile','background-color','#183d78',0,''),(44558,14130,'119680','printshop-mobile','class','menu-style-1',0,''),(44559,14130,'119680','printshop-mobile','box_align','4',0,''),(44560,14130,'119680','printshop-mobile','font-weight','400',0,''),(44561,14130,'119680','printshop-mobile','hide_menu','on',0,''),(44562,14130,'119680','printshop-mobile','color','#ffffff',0,''),(44563,14130,'119680','printshop-mobile','hide_menu','1',0,'695'),(44564,14134,'119684','printshop-mobile','block_type','1',0,''),(44565,14137,'119687','printshop-mobile','width','680',0,''),(44566,14137,'119687','printshop-mobile','font-weight','normal',0,''),(44567,14137,'119687','printshop-mobile','font-size','12',0,''),(44568,14137,'119687','printshop-mobile','padding-top','20',0,''),(44569,14137,'119687','printshop-mobile','padding-bottom','20',0,''),(44570,14137,'119687','printshop-mobile','color','#000000',0,''),(44571,14138,'119688','printshop-mobile','block_type','5',0,''),(44572,14138,'119688','printshop-mobile','font-weight','normal',0,''),(44573,14138,'119688','printshop-mobile','border-bottom-width','1',0,''),(44574,14138,'119688','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(44575,14138,'119688','printshop-mobile','border-top-width','1',0,''),(44576,14138,'119688','printshop-mobile','border-top-color','#e0e0e0',0,''),(44577,14138,'119688','printshop-mobile','border-left-color','#e0e0e0',0,''),(44578,14138,'119688','printshop-mobile','border-left-width','1',0,''),(44579,14139,'119689','printshop-mobile','block_type','1',0,''),(44580,14139,'119689','printshop-mobile','font-weight','normal',0,''),(44581,14139,'119689','printshop-mobile','padding-top','10',0,''),(44582,14139,'119689','printshop-mobile','padding-left','10',0,''),(44583,14139,'119689','printshop-mobile','padding-right','10',0,''),(44584,14140,'119690','printshop-mobile','font-weight','400',0,''),(44585,14140,'119690','printshop-mobile','line-height','120',0,''),(44586,14140,'119690','printshop-mobile','line_height_measure','%',0,''),(44587,14141,'119691','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(44588,14141,'119691','printshop-mobile','font-size','14',0,''),(44589,14141,'119691','printshop-mobile','font-weight','bold',0,''),(44590,14141,'119691','printshop-mobile','padding-bottom','10',0,''),(44591,14142,'119692','printshop-mobile','block_type','1',0,''),(44592,14142,'119692','printshop-mobile','background-color','#e0e0e0',0,''),(44593,14142,'119692','printshop-mobile','padding-top','40',0,''),(44594,14142,'119692','printshop-mobile','padding-left','10',0,''),(44595,14142,'119692','printshop-mobile','padding-right','10',0,''),(44596,14142,'119692','printshop-mobile','padding-bottom','40',0,''),(44597,14143,'119693','printshop-mobile','font-weight','normal',0,''),(44598,14143,'119693','printshop-mobile','line-height','200',0,''),(44599,14143,'119693','printshop-mobile','text-align','right',0,''),(44600,14143,'119693','printshop-mobile','font-size','14',0,''),(44601,14143,'119693','printshop-mobile','box_align','3',0,''),(44602,14144,'119694','printshop-mobile','font-weight','400',0,''),(44603,14144,'119694','printshop-mobile','padding-top','20',0,''),(44604,14144,'119694','printshop-mobile','padding-bottom','20',0,''),(44605,14144,'119694','printshop-mobile','font-size','12',0,''),(44606,14145,'119695','printshop-mobile','block_type','2',0,''),(44607,14145,'119695','printshop-mobile','font-weight','normal',0,''),(44608,14145,'119695','printshop-mobile','padding-bottom','20',0,''),(44609,14146,'119696','printshop-mobile','font-weight','400',0,''),(44610,14146,'119696','printshop-mobile','padding-top','20',0,''),(44612,14147,'119697','printshop-mobile','block_type','11',0,''),(44613,14147,'119697','printshop-mobile','font-weight','normal',0,''),(44614,14148,'119698','printshop-mobile','text','<p>Phone:</p>',1,''),(44615,14148,'119698','printshop-mobile','font-weight','normal',0,''),(44616,14148,'119698','printshop-mobile','text-align','right',0,''),(44617,14149,'119699','printshop-mobile','font-weight','normal',0,''),(44618,14149,'119699','printshop-mobile','text-align','right',0,''),(44619,14150,'119700','printshop-mobile','block_type','1',0,''),(44620,14151,'119701','printshop-mobile','font-weight','normal',0,''),(44621,14151,'119701','printshop-mobile','text-align','right',0,''),(44622,14151,'119701','printshop-mobile','padding-bottom','10',0,''),(44623,14151,'119701','printshop-mobile','address_spacer',',',0,''),(44624,14152,'119702','printshop-mobile','block_type','11',0,''),(44625,14152,'119702','printshop-mobile','font-weight','normal',0,''),(44626,14153,'119703','printshop-mobile','text','<p>Web:</p>',1,''),(44627,14153,'119703','printshop-mobile','font-weight','normal',0,''),(44628,14153,'119703','printshop-mobile','text-align','right',0,''),(44629,14154,'119704','printshop-mobile','font-weight','normal',0,''),(44630,14154,'119704','printshop-mobile','text-align','right',0,''),(44631,14155,'119705','printshop-mobile','block_type','11',0,''),(44632,14155,'119705','printshop-mobile','font-weight','normal',0,''),(44633,14156,'119706','printshop-mobile','text','<p>Email:</p>',1,''),(44634,14156,'119706','printshop-mobile','font-weight','normal',0,''),(44635,14156,'119706','printshop-mobile','text-align','right',0,''),(44636,14157,'119707','printshop-mobile','font-weight','normal',0,''),(44637,14157,'119707','printshop-mobile','text-align','right',0,''),(44638,14158,'119708','printshop-mobile','block_type','3',0,''),(44639,14158,'119708','printshop-mobile','font-weight','normal',0,''),(44640,14158,'119708','printshop-mobile','padding-top','20',0,''),(44641,14159,'119709','printshop-mobile','text','<p>If undelivered please return to:</p>',1,''),(44642,14159,'119709','printshop-mobile','font-size','15',0,''),(44643,14159,'119709','printshop-mobile','font-weight','bold',0,''),(44644,14160,'119710','printshop-mobile','font-size','14',0,''),(44645,14161,'119711','printshop-mobile','text','<p>Thank you for your order</p>',1,''),(44646,14161,'119711','printshop-mobile','color','#008fe9',0,''),(44647,14161,'119711','printshop-mobile','font-size','16',0,''),(44648,14161,'119711','printshop-mobile','font-weight','bold',0,''),(44649,14161,'119711','printshop-mobile','padding-top','5',0,''),(44650,14161,'119711','printshop-mobile','text-align','center',0,''),(44651,14162,'119712','printshop-mobile','font-weight','400',0,''),(44652,14162,'119712','printshop-mobile','text-align','center',0,''),(44653,14162,'119712','printshop-mobile','padding-top','0',0,''),(44655,14162,'119712','printshop-mobile','padding-left','20',0,''),(44656,14162,'119712','printshop-mobile','padding-right','20',0,''),(44657,14163,'119713','printshop-mobile','block_type','6',0,''),(44658,14163,'119713','printshop-mobile','font-weight','normal',0,''),(44659,14163,'119713','printshop-mobile','font-size','16',0,''),(44660,14164,'119714','printshop-mobile','text','<p>Email:</p>',1,''),(44661,14164,'119714','printshop-mobile','font-weight','normal',0,''),(44662,14164,'119714','printshop-mobile','text-align','right',0,''),(44663,14164,'119714','printshop-mobile','font-size','14',0,''),(44664,14165,'119715','printshop-mobile','font-weight','normal',0,''),(44665,14165,'119715','printshop-mobile','text-align','right',0,''),(44666,14165,'119715','printshop-mobile','font-size','14',0,''),(44667,14166,'119716','printshop-mobile','block_type','6',0,''),(44668,14166,'119716','printshop-mobile','font-weight','normal',0,''),(44669,14166,'119716','printshop-mobile','font-size','16',0,''),(44670,14167,'119717','printshop-mobile','text','<p>Phone:</p>',1,''),(44671,14167,'119717','printshop-mobile','font-weight','normal',0,''),(44672,14167,'119717','printshop-mobile','text-align','right',0,''),(44673,14167,'119717','printshop-mobile','font-size','14',0,''),(44674,14168,'119718','printshop-mobile','font-weight','normal',0,''),(44675,14168,'119718','printshop-mobile','text-align','right',0,''),(44676,14168,'119718','printshop-mobile','font-size','14',0,''),(44677,14169,'119719','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(44678,14169,'119719','printshop-mobile','font-size','14',0,''),(44679,14169,'119719','printshop-mobile','font-weight','bold',0,''),(44680,14169,'119719','printshop-mobile','text-align','right',0,''),(44681,14170,'119720','printshop-mobile','block_type','4',0,''),(44682,14170,'119720','printshop-mobile','font-weight','normal',0,''),(44683,14170,'119720','printshop-mobile','border-top-width','1',0,''),(44684,14170,'119720','printshop-mobile','border-top-color','#e0e0e0',0,''),(44685,14170,'119720','printshop-mobile','border-left-width','1',0,''),(44686,14170,'119720','printshop-mobile','border-left-color','#e0e0e0',0,''),(44687,14170,'119720','printshop-mobile','border-right-width','1',0,''),(44688,14170,'119720','printshop-mobile','border-right-color','#e0e0e0',0,''),(44689,14170,'119720','printshop-mobile','border-bottom-width','1',0,''),(44690,14170,'119720','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(44691,14171,'119721','printshop-mobile','block_type','2',0,''),(44692,14171,'119721','printshop-mobile','font-weight','normal',0,''),(44693,14171,'119721','printshop-mobile','border-top-width','1',0,''),(44694,14171,'119721','printshop-mobile','border-top-color','#e0e0e0',0,''),(44695,14171,'119721','printshop-mobile','border-right-width','1',0,''),(44696,14171,'119721','printshop-mobile','border-right-color','#e0e0e0',0,''),(44697,14172,'119722','printshop-mobile','block_type','1',0,''),(44698,14172,'119722','printshop-mobile','font-weight','normal',0,''),(44699,14172,'119722','printshop-mobile','padding-top','10',0,''),(44700,14172,'119722','printshop-mobile','padding-left','10',0,''),(44701,14172,'119722','printshop-mobile','padding-right','10',0,''),(44702,14172,'119722','printshop-mobile','padding-bottom','10',0,''),(44703,14172,'119722','printshop-mobile','border-right-width','1',0,''),(44704,14172,'119722','printshop-mobile','border-right-color','#e0e0e0',0,''),(44705,14173,'119723','printshop-mobile','text','<p>Shipping via</p>',1,''),(44706,14173,'119723','printshop-mobile','font-weight','bold',0,''),(44707,14175,'119725','printshop-mobile','block_type','1',0,''),(44708,14175,'119725','printshop-mobile','font-weight','normal',0,''),(44709,14175,'119725','printshop-mobile','padding-top','10',0,''),(44710,14175,'119725','printshop-mobile','padding-left','10',0,''),(44711,14175,'119725','printshop-mobile','padding-right','10',0,''),(44712,14175,'119725','printshop-mobile','padding-bottom','10',0,''),(44713,14177,'119727','printshop-mobile','text','<p>Shipping service</p>',1,''),(44714,14177,'119727','printshop-mobile','font-weight','bold',0,''),(44715,14178,'119728','printshop-mobile','block_type','2',0,''),(44716,14178,'119728','printshop-mobile','font-weight','normal',0,''),(44717,14178,'119728','printshop-mobile','border-right-width','1',0,''),(44718,14178,'119728','printshop-mobile','border-right-color','#e0e0e0',0,''),(44719,14179,'119729','printshop-mobile','block_type','1',0,''),(44720,14179,'119729','printshop-mobile','font-weight','400',0,''),(44721,14179,'119729','printshop-mobile','background-color','#e0e0e0',0,''),(44722,14179,'119729','printshop-mobile','padding-top','10',0,''),(44723,14179,'119729','printshop-mobile','padding-left','10',0,''),(44724,14179,'119729','printshop-mobile','padding-right','10',0,''),(44725,14179,'119729','printshop-mobile','padding-bottom','50',0,''),(44726,14180,'119730','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(44727,14180,'119730','printshop-mobile','font-size','16',0,''),(44728,14180,'119730','printshop-mobile','font-weight','bold',0,''),(44729,14182,'119732','printshop-mobile','block_type','1',0,''),(44730,14182,'119732','printshop-mobile','font-weight','normal',0,''),(44731,14182,'119732','printshop-mobile','padding-top','10',0,''),(44732,14182,'119732','printshop-mobile','padding-left','10',0,''),(44733,14182,'119732','printshop-mobile','padding-right','10',0,''),(44734,14182,'119732','printshop-mobile','padding-bottom','10',0,''),(44735,14183,'119733','printshop-mobile','font-weight','normal',0,''),(44736,14184,'119734','printshop-mobile','text','<p>CUSTOMER:</p>',1,''),(44737,14184,'119734','printshop-mobile','font-size','14',0,''),(44738,14184,'119734','printshop-mobile','font-weight','bold',0,''),(44739,14185,'119735','printshop-mobile','font-weight','normal',0,''),(44740,14186,'119736','printshop-mobile','text','<p>PHONE NUMBER:</p>',1,''),(44741,14186,'119736','printshop-mobile','font-size','14',0,''),(44742,14186,'119736','printshop-mobile','font-weight','bold',0,''),(44743,14186,'119736','printshop-mobile','padding-top','10',0,''),(44744,14187,'119737','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(44745,14187,'119737','printshop-mobile','font-weight','bold',0,''),(44746,14187,'119737','printshop-mobile','font-size','14',0,''),(44747,14187,'119737','printshop-mobile','padding-top','10',0,''),(44748,14189,'119739','printshop-mobile','font-weight','normal',0,''),(44749,14189,'119739','printshop-mobile','text-align','center',0,''),(44750,14189,'119739','printshop-mobile','padding-bottom','20',0,''),(44751,14190,'119740','printshop-mobile','font-weight','normal',0,''),(44752,14190,'119740','printshop-mobile','text-align','center',0,''),(44753,14190,'119740','printshop-mobile','padding-bottom','10',0,''),(44754,14191,'119741','printshop-mobile','font-size','16',0,''),(44755,14191,'119741','printshop-mobile','font-weight','bold',0,''),(44756,14191,'119741','printshop-mobile','text-align','center',0,''),(44757,14191,'119741','printshop-mobile','padding-bottom','10',0,''),(44758,14191,'119741','printshop-mobile','padding-top','10',0,''),(44759,14192,'119742','printshop-mobile','font-weight','normal',0,''),(44760,14192,'119742','printshop-mobile','text-align','center',0,''),(44761,14193,'119743','printshop-mobile','text','<p>Payment date:</p>',1,''),(44762,14193,'119743','printshop-mobile','font-weight','bold',0,''),(44763,14193,'119743','printshop-mobile','text-align','center',0,''),(44764,14194,'119744','printshop-mobile','text','<p>Payment Method:</p>',1,''),(44765,14194,'119744','printshop-mobile','font-weight','bold',0,''),(44766,14194,'119744','printshop-mobile','text-align','center',0,''),(44767,14195,'119745','printshop-mobile','block_type','1',0,''),(44768,14195,'119745','printshop-mobile','padding-top','20',0,''),(44769,14196,'119746','printshop-mobile','tab_1','RETURNING CUSTOMER',1,''),(44770,14196,'119746','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(44771,14199,'119749','printshop-mobile','block_type','1',0,''),(44772,14200,'119750','printshop-mobile','text','##TEXT_OR##',0,''),(44773,14200,'119750','printshop-mobile','font-size','18',0,''),(44774,14200,'119750','printshop-mobile','font-weight','700',0,''),(44775,14200,'119750','printshop-mobile','padding-top','15',0,''),(44776,14200,'119750','printshop-mobile','text-align','center',0,''),(44777,14200,'119750','printshop-mobile','content','\\_',0,'3'),(44778,14200,'119750','printshop-mobile','height','5',0,'3'),(44779,14200,'119750','printshop-mobile','width','70',0,'3'),(44780,14200,'119750','printshop-mobile','display','inline-block',0,'3'),(44781,14200,'119750','printshop-mobile','border-top-width','1',0,'3'),(44782,14200,'119750','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(44783,14200,'119750','printshop-mobile','margin-left','10',0,'3'),(44784,14200,'119750','printshop-mobile','margin-right','10',0,'3'),(44785,14200,'119750','printshop-mobile','content','\\_',0,'4'),(44786,14200,'119750','printshop-mobile','display','inline-block',0,'4'),(44787,14200,'119750','printshop-mobile','width','70',0,'4'),(44788,14200,'119750','printshop-mobile','height','5',0,'4'),(44789,14200,'119750','printshop-mobile','border-top-width','1',0,'4'),(44790,14200,'119750','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(44791,14200,'119750','printshop-mobile','margin-left','10',0,'4'),(44792,14200,'119750','printshop-mobile','margin-right','10',0,'4'),(44793,14200,'119750','printshop-mobile','position','relative',0,''),(44794,14200,'119750','printshop-mobile','top','-10',0,''),(44795,14201,'119751','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(44796,14201,'119751','printshop-mobile','font-size','26',0,''),(44797,14201,'119751','printshop-mobile','font-family','Varela Round',0,''),(44798,14201,'119751','printshop-mobile','padding-top','15',0,''),(44799,14201,'119751','printshop-mobile','padding-bottom','15',0,''),(44800,14201,'119751','printshop-mobile','text-align','center',0,''),(44801,14202,'119752','printshop-mobile','text-align','center',0,''),(44802,14202,'119752','printshop-mobile','hide_parents','2',0,''),(44803,14203,'119753','printshop-mobile','block_type','1',0,''),(44804,14203,'119753','printshop-mobile','padding-top','40',0,''),(44805,14203,'119753','printshop-mobile','background-color','#eeeeee',0,''),(44806,14203,'119753','printshop-mobile','padding-bottom','40',0,''),(44807,14204,'119754','printshop-mobile','block_type','1',0,''),(44808,14204,'119754','printshop-mobile','background-color','#ffffff',0,''),(44809,14204,'119754','printshop-mobile','max-width','830',0,''),(44810,14204,'119754','printshop-mobile','margin_left_measure','auto',0,''),(44811,14204,'119754','printshop-mobile','margin_right_measure','auto',0,''),(44812,14204,'119754','printshop-mobile','padding-top','40',0,''),(44813,14204,'119754','printshop-mobile','padding-bottom','40',0,''),(44814,14204,'119754','printshop-mobile','schema','2-3',0,''),(44815,14205,'119755','printshop-mobile','text','##NEW_CUSTOMER##',0,''),(44816,14205,'119755','printshop-mobile','font-size','18',0,''),(44817,14205,'119755','printshop-mobile','font-family','Varela Round',0,''),(44818,14205,'119755','printshop-mobile','text-align','center',0,''),(44819,14205,'119755','printshop-mobile','text-transform','uppercase',0,''),(44820,14205,'119755','printshop-mobile','margin-bottom','10',0,''),(44821,14206,'119756','printshop-mobile','text-align','center',0,''),(44822,14206,'119756','printshop-mobile','margin-bottom','40',0,''),(44823,14207,'119757','printshop-mobile','text-align','center',0,''),(44824,14208,'119758','printshop-mobile','text','##TEXT_OR##',0,''),(44825,14208,'119758','printshop-mobile','font-size','18',0,''),(44826,14208,'119758','printshop-mobile','font-weight','700',0,''),(44827,14208,'119758','printshop-mobile','text-align','center',0,''),(44828,14208,'119758','printshop-mobile','content','\\_',0,'3'),(44829,14208,'119758','printshop-mobile','height','5',0,'3'),(44830,14208,'119758','printshop-mobile','width','70',0,'3'),(44831,14208,'119758','printshop-mobile','display','inline-block',0,'3'),(44832,14208,'119758','printshop-mobile','border-top-width','1',0,'3'),(44833,14208,'119758','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(44834,14208,'119758','printshop-mobile','margin-left','10',0,'3'),(44835,14208,'119758','printshop-mobile','margin-right','10',0,'3'),(44836,14208,'119758','printshop-mobile','content','\\_',0,'4'),(44837,14208,'119758','printshop-mobile','display','inline-block',0,'4'),(44838,14208,'119758','printshop-mobile','width','70',0,'4'),(44839,14208,'119758','printshop-mobile','height','5',0,'4'),(44840,14208,'119758','printshop-mobile','border-top-width','1',0,'4'),(44841,14208,'119758','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(44842,14208,'119758','printshop-mobile','margin-left','10',0,'4'),(44843,14208,'119758','printshop-mobile','margin-right','10',0,'4'),(44844,14208,'119758','printshop-mobile','position','relative',0,''),(44845,14208,'119758','printshop-mobile','padding-top','10',0,''),(44846,14208,'119758','printshop-mobile','padding-bottom','10',0,''),(44847,14209,'119759','printshop-mobile','block_type','1',0,''),(44848,14210,'119760','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(44849,14210,'119760','printshop-mobile','font-size','18',0,''),(44850,14210,'119760','printshop-mobile','font-family','Varela Round',0,''),(44851,14210,'119760','printshop-mobile','padding-top','15',0,''),(44852,14210,'119760','printshop-mobile','padding-bottom','15',0,''),(44853,14210,'119760','printshop-mobile','text-align','center',0,''),(44854,14210,'119760','printshop-mobile','text-transform','uppercase',0,''),(44855,14211,'119761','printshop-mobile','text-align','center',0,''),(44856,14211,'119761','printshop-mobile','hide_parents','2',0,''),(44857,14212,'119762','printshop-mobile','max-width','230',0,''),(44858,14212,'119762','printshop-mobile','margin_left_measure','auto',0,''),(44859,14212,'119762','printshop-mobile','margin_right_measure','auto',0,''),(44860,14213,'119763','printshop-mobile','text','##RETURNING_CUSTOMER##',0,''),(44861,14213,'119763','printshop-mobile','font-size','18',0,''),(44862,14213,'119763','printshop-mobile','font-family','Varela Round',0,''),(44863,14213,'119763','printshop-mobile','text-transform','uppercase',0,''),(44864,14213,'119763','printshop-mobile','text-align','center',0,''),(44865,14214,'119764','printshop-mobile','block_type','1',0,''),(44866,14214,'119764','printshop-mobile','padding-top','20',0,''),(44867,14215,'119765','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(44868,14215,'119765','printshop-mobile','font-size','26',0,''),(44869,14215,'119765','printshop-mobile','font-family','Varela Round',0,''),(44870,14215,'119765','printshop-mobile','padding-top','15',0,''),(44871,14215,'119765','printshop-mobile','padding-bottom','15',0,''),(44872,14215,'119765','printshop-mobile','text-align','center',0,''),(44873,14216,'119766','printshop-mobile','text','##TEXT_OR##',0,''),(44874,14216,'119766','printshop-mobile','font-size','18',0,''),(44875,14216,'119766','printshop-mobile','font-weight','700',0,''),(44876,14216,'119766','printshop-mobile','padding-top','15',0,''),(44877,14216,'119766','printshop-mobile','text-align','center',0,''),(44878,14216,'119766','printshop-mobile','content','\\_',0,'3'),(44879,14216,'119766','printshop-mobile','height','5',0,'3'),(44880,14216,'119766','printshop-mobile','width','70',0,'3'),(44881,14216,'119766','printshop-mobile','display','inline-block',0,'3'),(44882,14216,'119766','printshop-mobile','border-top-width','1',0,'3'),(44883,14216,'119766','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(44884,14216,'119766','printshop-mobile','margin-left','10',0,'3'),(44885,14216,'119766','printshop-mobile','margin-right','10',0,'3'),(44886,14216,'119766','printshop-mobile','content','\\_',0,'4'),(44887,14216,'119766','printshop-mobile','display','inline-block',0,'4'),(44888,14216,'119766','printshop-mobile','width','70',0,'4'),(44889,14216,'119766','printshop-mobile','height','5',0,'4'),(44890,14216,'119766','printshop-mobile','border-top-width','1',0,'4'),(44891,14216,'119766','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(44892,14216,'119766','printshop-mobile','margin-left','10',0,'4'),(44893,14216,'119766','printshop-mobile','margin-right','10',0,'4'),(44894,14216,'119766','printshop-mobile','position','relative',0,''),(44895,14216,'119766','printshop-mobile','top','-10',0,''),(44896,14217,'119767','printshop-mobile','text-align','center',0,''),(44897,14218,'119768','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(44898,14218,'119768','printshop-mobile','tab_2','RETURNING CUSTOMER',1,''),(44899,14218,'119768','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(44900,14219,'119769','printshop-mobile','block_type','8',0,''),(44901,14220,'119770','printshop-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(44902,14221,'119771','printshop-mobile','block_type','1',0,''),(44903,14221,'119771','printshop-mobile','padding-left','20',0,''),(44904,14221,'119771','printshop-mobile','padding-right','20',0,''),(44905,14222,'119772','printshop-mobile','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(44906,14222,'119772','printshop-mobile','border-top-width','1',0,''),(44907,14222,'119772','printshop-mobile','border-top-color','#e0e0e0',0,''),(44908,14225,'119775','printshop-mobile','block_type','8',0,''),(44909,14226,'119776','printshop-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(44910,14227,'119777','printshop-mobile','block_type','1',0,''),(44911,14227,'119777','printshop-mobile','padding-left','20',0,''),(44912,14227,'119777','printshop-mobile','padding-right','20',0,''),(44913,14229,'119779','printshop-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(44914,14230,'119780','printshop-mobile','block_type','1',0,''),(44915,14230,'119780','printshop-mobile','padding-top','20',0,''),(44916,14231,'119781','printshop-mobile','text-align','center',0,''),(44917,14232,'119782','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(44918,14232,'119782','printshop-mobile','font-size','26',0,''),(44919,14232,'119782','printshop-mobile','font-family','Varela Round',0,''),(44920,14232,'119782','printshop-mobile','padding-top','15',0,''),(44921,14232,'119782','printshop-mobile','padding-bottom','15',0,''),(44922,14232,'119782','printshop-mobile','text-align','center',0,''),(44923,14233,'119783','printshop-mobile','text','##TEXT_OR##',0,''),(44924,14233,'119783','printshop-mobile','font-size','18',0,''),(44925,14233,'119783','printshop-mobile','font-weight','700',0,''),(44926,14233,'119783','printshop-mobile','padding-top','15',0,''),(44927,14233,'119783','printshop-mobile','text-align','center',0,''),(44928,14233,'119783','printshop-mobile','content','\\_',0,'3'),(44929,14233,'119783','printshop-mobile','height','5',0,'3'),(44930,14233,'119783','printshop-mobile','width','70',0,'3'),(44931,14233,'119783','printshop-mobile','display','inline-block',0,'3'),(44932,14233,'119783','printshop-mobile','border-top-width','1',0,'3'),(44933,14233,'119783','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(44934,14233,'119783','printshop-mobile','margin-left','10',0,'3'),(44935,14233,'119783','printshop-mobile','margin-right','10',0,'3'),(44936,14233,'119783','printshop-mobile','content','\\_',0,'4'),(44937,14233,'119783','printshop-mobile','display','inline-block',0,'4'),(44938,14233,'119783','printshop-mobile','width','70',0,'4'),(44939,14233,'119783','printshop-mobile','height','5',0,'4'),(44940,14233,'119783','printshop-mobile','border-top-width','1',0,'4'),(44941,14233,'119783','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(44942,14233,'119783','printshop-mobile','margin-left','10',0,'4'),(44943,14233,'119783','printshop-mobile','margin-right','10',0,'4'),(44944,14233,'119783','printshop-mobile','position','relative',0,''),(44945,14233,'119783','printshop-mobile','top','-10',0,''),(44946,14234,'119784','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(44947,14234,'119784','printshop-mobile','tab_2','RETURNING CUSTOMER',1,''),(44948,14234,'119784','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(44949,14235,'119785','printshop-mobile','block_type','8',0,''),(44950,14236,'119786','printshop-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(44951,14239,'119789','printshop-mobile','block_type','8',0,''),(44952,14240,'119790','printshop-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(44953,14242,'119792','printshop-mobile','block_type','1',0,''),(44954,14242,'119792','printshop-mobile','padding-left','20',0,''),(44955,14242,'119792','printshop-mobile','padding-right','20',0,''),(44956,14243,'119793','printshop-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(44957,14245,'119795','printshop-mobile','block_type','1',0,''),(44958,14245,'119795','printshop-mobile','padding-top','20',0,''),(44959,14246,'119796','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(44960,14246,'119796','printshop-mobile','font-size','26',0,''),(44961,14246,'119796','printshop-mobile','font-family','Varela Round',0,''),(44962,14246,'119796','printshop-mobile','padding-top','15',0,''),(44963,14246,'119796','printshop-mobile','padding-bottom','15',0,''),(44964,14246,'119796','printshop-mobile','text-align','center',0,''),(44965,14247,'119797','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(44966,14247,'119797','printshop-mobile','tab_2','RETURNING CUSTOMER',1,''),(44967,14247,'119797','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(44968,14248,'119798','printshop-mobile','block_type','8',0,''),(44969,14249,'119799','printshop-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(44970,14252,'119802','printshop-mobile','block_type','8',0,''),(44971,14253,'119803','printshop-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(44972,14254,'119804','printshop-mobile','block_type','1',0,''),(44973,14254,'119804','printshop-mobile','padding-left','20',0,''),(44974,14254,'119804','printshop-mobile','padding-right','20',0,''),(44975,14255,'119805','printshop-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(44976,14257,'119807','printshop-mobile','text-align','center',0,''),(44977,14258,'119808','printshop-mobile','text','##TEXT_OR##',0,''),(44978,14258,'119808','printshop-mobile','font-size','18',0,''),(44979,14258,'119808','printshop-mobile','font-weight','700',0,''),(44980,14258,'119808','printshop-mobile','padding-top','15',0,''),(44981,14258,'119808','printshop-mobile','text-align','center',0,''),(44982,14258,'119808','printshop-mobile','content','\\_',0,'3'),(44983,14258,'119808','printshop-mobile','height','5',0,'3'),(44984,14258,'119808','printshop-mobile','width','70',0,'3'),(44985,14258,'119808','printshop-mobile','display','inline-block',0,'3'),(44986,14258,'119808','printshop-mobile','border-top-width','1',0,'3'),(44987,14258,'119808','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(44988,14258,'119808','printshop-mobile','margin-left','10',0,'3'),(44989,14258,'119808','printshop-mobile','margin-right','10',0,'3'),(44990,14258,'119808','printshop-mobile','content','\\_',0,'4'),(44991,14258,'119808','printshop-mobile','display','inline-block',0,'4'),(44992,14258,'119808','printshop-mobile','width','70',0,'4'),(44993,14258,'119808','printshop-mobile','height','5',0,'4'),(44994,14258,'119808','printshop-mobile','border-top-width','1',0,'4'),(44995,14258,'119808','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(44996,14258,'119808','printshop-mobile','margin-left','10',0,'4'),(44997,14258,'119808','printshop-mobile','margin-right','10',0,'4'),(44998,14258,'119808','printshop-mobile','position','relative',0,''),(44999,14258,'119808','printshop-mobile','top','-10',0,''),(45000,14259,'119809','printshop-mobile','block_type','1',0,''),(45001,14259,'119809','printshop-mobile','padding-top','40',0,''),(45002,14259,'119809','printshop-mobile','background-color','#eeeeee',0,''),(45003,14259,'119809','printshop-mobile','padding-bottom','40',0,''),(45004,14260,'119810','printshop-mobile','block_type','2',0,''),(45005,14260,'119810','printshop-mobile','background-color','#ffffff',0,''),(45006,14260,'119810','printshop-mobile','max-width','830',0,''),(45007,14260,'119810','printshop-mobile','margin_left_measure','auto',0,''),(45008,14260,'119810','printshop-mobile','margin_right_measure','auto',0,''),(45009,14260,'119810','printshop-mobile','padding-top','40',0,''),(45010,14260,'119810','printshop-mobile','padding-bottom','40',0,''),(45011,14261,'119811','printshop-mobile','text-align','center',0,''),(45012,14261,'119811','printshop-mobile','margin-bottom','40',0,''),(45013,14262,'119812','printshop-mobile','text-align','center',0,''),(45014,14263,'119813','printshop-mobile','text','##NEW_CUSTOMER##',0,''),(45015,14263,'119813','printshop-mobile','font-size','18',0,''),(45016,14263,'119813','printshop-mobile','font-family','Varela Round',0,''),(45017,14263,'119813','printshop-mobile','text-align','center',0,''),(45018,14263,'119813','printshop-mobile','text-transform','uppercase',0,''),(45019,14263,'119813','printshop-mobile','margin-bottom','10',0,''),(45020,14264,'119814','printshop-mobile','text','##TEXT_OR##',0,''),(45021,14264,'119814','printshop-mobile','font-size','18',0,''),(45022,14264,'119814','printshop-mobile','font-weight','700',0,''),(45023,14264,'119814','printshop-mobile','text-align','center',0,''),(45024,14264,'119814','printshop-mobile','content','\\_',0,'3'),(45025,14264,'119814','printshop-mobile','height','5',0,'3'),(45026,14264,'119814','printshop-mobile','width','70',0,'3'),(45027,14264,'119814','printshop-mobile','display','inline-block',0,'3'),(45028,14264,'119814','printshop-mobile','border-top-width','1',0,'3'),(45029,14264,'119814','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(45030,14264,'119814','printshop-mobile','margin-left','10',0,'3'),(45031,14264,'119814','printshop-mobile','margin-right','10',0,'3'),(45032,14264,'119814','printshop-mobile','content','\\_',0,'4'),(45033,14264,'119814','printshop-mobile','display','inline-block',0,'4'),(45034,14264,'119814','printshop-mobile','width','70',0,'4'),(45035,14264,'119814','printshop-mobile','height','5',0,'4'),(45036,14264,'119814','printshop-mobile','border-top-width','1',0,'4'),(45037,14264,'119814','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(45038,14264,'119814','printshop-mobile','margin-left','10',0,'4'),(45039,14264,'119814','printshop-mobile','margin-right','10',0,'4'),(45040,14264,'119814','printshop-mobile','position','relative',0,''),(45041,14264,'119814','printshop-mobile','padding-top','10',0,''),(45042,14264,'119814','printshop-mobile','padding-bottom','10',0,''),(45043,14265,'119815','printshop-mobile','block_type','1',0,''),(45044,14266,'119816','printshop-mobile','text-align','center',0,''),(45045,14266,'119816','printshop-mobile','hide_parents','2',0,''),(45046,14267,'119817','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(45047,14267,'119817','printshop-mobile','font-size','18',0,''),(45048,14267,'119817','printshop-mobile','font-family','Varela Round',0,''),(45049,14267,'119817','printshop-mobile','padding-top','15',0,''),(45050,14267,'119817','printshop-mobile','padding-bottom','15',0,''),(45051,14267,'119817','printshop-mobile','text-align','center',0,''),(45052,14267,'119817','printshop-mobile','text-transform','uppercase',0,''),(45053,14268,'119818','printshop-mobile','max-width','230',0,''),(45054,14268,'119818','printshop-mobile','margin_left_measure','auto',0,''),(45055,14268,'119818','printshop-mobile','margin_right_measure','auto',0,''),(45056,14269,'119819','printshop-mobile','text','##RETURNING_CUSTOMER##',0,''),(45057,14269,'119819','printshop-mobile','font-size','18',0,''),(45058,14269,'119819','printshop-mobile','font-family','Varela Round',0,''),(45059,14269,'119819','printshop-mobile','text-transform','uppercase',0,''),(45060,14269,'119819','printshop-mobile','text-align','center',0,''),(45061,14270,'119820','printshop-mobile','block_type','1',0,''),(45062,14270,'119820','printshop-mobile','padding-top','40',0,''),(45063,14270,'119820','printshop-mobile','background-color','#eeeeee',0,''),(45064,14270,'119820','printshop-mobile','padding-bottom','40',0,''),(45065,14271,'119821','printshop-mobile','block_type','2',0,''),(45066,14271,'119821','printshop-mobile','background-color','#ffffff',0,''),(45067,14271,'119821','printshop-mobile','max-width','830',0,''),(45068,14271,'119821','printshop-mobile','margin_left_measure','auto',0,''),(45069,14271,'119821','printshop-mobile','margin_right_measure','auto',0,''),(45070,14271,'119821','printshop-mobile','padding-top','40',0,''),(45071,14271,'119821','printshop-mobile','padding-bottom','40',0,''),(45072,14272,'119822','printshop-mobile','block_type','1',0,''),(45073,14273,'119823','printshop-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(45074,14273,'119823','printshop-mobile','font-size','18',0,''),(45075,14273,'119823','printshop-mobile','font-family','Varela Round',0,''),(45076,14273,'119823','printshop-mobile','padding-top','15',0,''),(45077,14273,'119823','printshop-mobile','padding-bottom','15',0,''),(45078,14273,'119823','printshop-mobile','text-align','center',0,''),(45079,14273,'119823','printshop-mobile','text-transform','uppercase',0,''),(45080,14274,'119824','printshop-mobile','text-align','center',0,''),(45081,14274,'119824','printshop-mobile','hide_parents','2',0,''),(45082,14275,'119825','printshop-mobile','text','##TEXT_OR##',0,''),(45083,14275,'119825','printshop-mobile','font-size','18',0,''),(45084,14275,'119825','printshop-mobile','font-weight','700',0,''),(45085,14275,'119825','printshop-mobile','text-align','center',0,''),(45086,14275,'119825','printshop-mobile','content','\\_',0,'3'),(45087,14275,'119825','printshop-mobile','height','5',0,'3'),(45088,14275,'119825','printshop-mobile','width','70',0,'3'),(45089,14275,'119825','printshop-mobile','display','inline-block',0,'3'),(45090,14275,'119825','printshop-mobile','border-top-width','1',0,'3'),(45091,14275,'119825','printshop-mobile','border-top-color','#e0e0e0',0,'3'),(45092,14275,'119825','printshop-mobile','margin-left','10',0,'3'),(45093,14275,'119825','printshop-mobile','margin-right','10',0,'3'),(45094,14275,'119825','printshop-mobile','content','\\_',0,'4'),(45095,14275,'119825','printshop-mobile','display','inline-block',0,'4'),(45096,14275,'119825','printshop-mobile','width','70',0,'4'),(45097,14275,'119825','printshop-mobile','height','5',0,'4'),(45098,14275,'119825','printshop-mobile','border-top-width','1',0,'4'),(45099,14275,'119825','printshop-mobile','border-top-color','#e0e0e0',0,'4'),(45100,14275,'119825','printshop-mobile','margin-left','10',0,'4'),(45101,14275,'119825','printshop-mobile','margin-right','10',0,'4'),(45102,14275,'119825','printshop-mobile','position','relative',0,''),(45103,14275,'119825','printshop-mobile','padding-top','10',0,''),(45104,14275,'119825','printshop-mobile','padding-bottom','10',0,''),(45105,14276,'119826','printshop-mobile','text-align','center',0,''),(45106,14276,'119826','printshop-mobile','margin-bottom','40',0,''),(45107,14277,'119827','printshop-mobile','text','##NEW_CUSTOMER##',0,''),(45108,14277,'119827','printshop-mobile','font-size','18',0,''),(45109,14277,'119827','printshop-mobile','font-family','Varela Round',0,''),(45110,14277,'119827','printshop-mobile','text-align','center',0,''),(45111,14277,'119827','printshop-mobile','text-transform','uppercase',0,''),(45112,14277,'119827','printshop-mobile','margin-bottom','10',0,''),(45113,14278,'119828','printshop-mobile','text-align','center',0,''),(45114,14279,'119829','printshop-mobile','text','##RETURNING_CUSTOMER##',0,''),(45115,14279,'119829','printshop-mobile','font-size','18',0,''),(45116,14279,'119829','printshop-mobile','font-family','Varela Round',0,''),(45117,14279,'119829','printshop-mobile','text-transform','uppercase',0,''),(45118,14279,'119829','printshop-mobile','text-align','center',0,''),(45119,14280,'119830','printshop-mobile','max-width','230',0,''),(45120,14280,'119830','printshop-mobile','margin_left_measure','auto',0,''),(45121,14280,'119830','printshop-mobile','margin_right_measure','auto',0,''),(45122,14281,'119831','printshop-mobile','block_type','1',0,''),(45123,14282,'119832','printshop-mobile','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(45124,14282,'119832','printshop-mobile','margin-bottom','30',0,''),(45125,14283,'119833','printshop-mobile','block_type','1',0,''),(45126,14284,'119834','printshop-mobile','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(45127,14284,'119834','printshop-mobile','margin-bottom','30',0,''),(45128,14285,'119835','printshop-mobile','block_type','1',0,''),(45129,14285,'119835','printshop-mobile','font-weight','normal',0,''),(45130,14287,'119837','printshop-mobile','box_align','4',0,''),(45131,14287,'119837','printshop-mobile','margin-bottom','30',0,''),(45132,14288,'119838','printshop-mobile','tab_1','New products',1,''),(45133,14288,'119838','printshop-mobile','tab_2','Specials products',1,''),(45134,14288,'119838','printshop-mobile','font-weight','normal',0,''),(45135,14288,'119838','printshop-mobile','tab_3','Featured',1,''),(45136,14288,'119838','printshop-mobile','accordion','1',0,'693'),(45137,14289,'119839','printshop-mobile','font-weight','400',0,''),(45138,14289,'119839','printshop-mobile','listing_type','productListing',0,''),(45139,14289,'119839','printshop-mobile','show_compare','1',0,''),(45140,14289,'119839','printshop-mobile','show_model','1',0,''),(45141,14289,'119839','printshop-mobile','show_properties','1',0,''),(45142,14289,'119839','printshop-mobile','col_in_row','2',0,''),(45143,14289,'119839','printshop-mobile','show_name','0',0,''),(45144,14289,'119839','printshop-mobile','show_image','0',0,''),(45145,14289,'119839','printshop-mobile','show_stock','0',0,''),(45146,14289,'119839','printshop-mobile','show_description','0',0,''),(45147,14289,'119839','printshop-mobile','show_rating','0',0,''),(45148,14289,'119839','printshop-mobile','show_rating_counts','0',0,''),(45149,14289,'119839','printshop-mobile','show_price','0',0,''),(45150,14289,'119839','printshop-mobile','show_buy_button','0',0,''),(45151,14289,'119839','printshop-mobile','show_qty_input','0',0,''),(45152,14289,'119839','printshop-mobile','show_view_button','0',0,''),(45153,14289,'119839','printshop-mobile','show_wishlist_button','0',0,''),(45154,14289,'119839','printshop-mobile','col_in_row','2',0,'694'),(45155,14289,'119839','printshop-mobile','col_in_row','1',0,'718'),(45156,14289,'119839','printshop-mobile','view_as','carousel',0,''),(45157,14289,'119839','printshop-mobile','col_in_row','3',0,'702'),(45158,14290,'119840','printshop-mobile','font-weight','400',0,''),(45159,14290,'119840','printshop-mobile','show_compare','1',0,''),(45160,14290,'119840','printshop-mobile','listing_type','productListing',0,''),(45161,14290,'119840','printshop-mobile','show_model','1',0,''),(45162,14290,'119840','printshop-mobile','show_properties','1',0,''),(45163,14290,'119840','printshop-mobile','col_in_row','2',0,''),(45164,14290,'119840','printshop-mobile','show_name','0',0,''),(45165,14290,'119840','printshop-mobile','show_image','0',0,''),(45166,14290,'119840','printshop-mobile','show_stock','0',0,''),(45167,14290,'119840','printshop-mobile','show_description','0',0,''),(45168,14290,'119840','printshop-mobile','show_rating','0',0,''),(45169,14290,'119840','printshop-mobile','show_rating_counts','0',0,''),(45170,14290,'119840','printshop-mobile','show_price','0',0,''),(45171,14290,'119840','printshop-mobile','show_buy_button','0',0,''),(45172,14290,'119840','printshop-mobile','show_qty_input','0',0,''),(45173,14290,'119840','printshop-mobile','show_view_button','0',0,''),(45174,14290,'119840','printshop-mobile','show_wishlist_button','0',0,''),(45175,14290,'119840','printshop-mobile','col_in_row','2',0,'694'),(45176,14290,'119840','printshop-mobile','col_in_row','1',0,'718'),(45177,14290,'119840','printshop-mobile','view_as','carousel',0,''),(45178,14290,'119840','printshop-mobile','col_in_row','3',0,'702'),(45179,14290,'119840','printshop-mobile','product_names_teg','h2',0,''),(45180,14291,'119841','printshop-mobile','font-weight','400',0,''),(45181,14291,'119841','printshop-mobile','show_compare','1',0,''),(45182,14291,'119841','printshop-mobile','listing_type','productListing',0,''),(45183,14291,'119841','printshop-mobile','show_model','1',0,''),(45184,14291,'119841','printshop-mobile','show_properties','1',0,''),(45185,14291,'119841','printshop-mobile','col_in_row','2',0,''),(45186,14291,'119841','printshop-mobile','show_name','0',0,''),(45187,14291,'119841','printshop-mobile','show_image','0',0,''),(45188,14291,'119841','printshop-mobile','show_stock','0',0,''),(45189,14291,'119841','printshop-mobile','show_description','0',0,''),(45190,14291,'119841','printshop-mobile','show_rating','0',0,''),(45191,14291,'119841','printshop-mobile','show_rating_counts','0',0,''),(45192,14291,'119841','printshop-mobile','show_price','0',0,''),(45193,14291,'119841','printshop-mobile','show_buy_button','0',0,''),(45194,14291,'119841','printshop-mobile','show_qty_input','0',0,''),(45195,14291,'119841','printshop-mobile','show_view_button','0',0,''),(45196,14291,'119841','printshop-mobile','show_wishlist_button','0',0,''),(45197,14291,'119841','printshop-mobile','col_in_row','2',0,'694'),(45198,14291,'119841','printshop-mobile','col_in_row','1',0,'718'),(45199,14291,'119841','printshop-mobile','view_as','carousel',0,''),(45200,14291,'119841','printshop-mobile','col_in_row','3',0,'702'),(45201,14292,'119842','printshop-mobile','heading_type','h1',0,''),(45202,14293,'119843','printshop-mobile','block_type','1',0,''),(45203,14293,'119843','printshop-mobile','background-color','#eeeeee',0,''),(45204,14293,'119843','printshop-mobile','padding-top','20',0,''),(45205,14293,'119843','printshop-mobile','padding-bottom','20',0,''),(45206,14293,'119843','printshop-mobile','font-weight','400',0,''),(45207,14293,'119843','printshop-mobile','visibility_product','1',0,''),(45208,14293,'119843','printshop-mobile','visibility_catalog','1',0,''),(45209,14293,'119843','printshop-mobile','visibility_info','1',0,''),(45210,14293,'119843','printshop-mobile','visibility_cart','1',0,''),(45211,14293,'119843','printshop-mobile','visibility_checkout','1',0,''),(45212,14293,'119843','printshop-mobile','visibility_success','1',0,''),(45213,14293,'119843','printshop-mobile','visibility_account','1',0,''),(45214,14293,'119843','printshop-mobile','visibility_login','1',0,''),(45215,14293,'119843','printshop-mobile','visibility_other','1',0,''),(45216,14293,'119843','printshop-mobile','margin-bottom','20',0,''),(45217,14293,'119843','printshop-mobile','display_none','on',0,'694'),(45218,14294,'119844','printshop-mobile','block_type','2',0,''),(45219,14294,'119844','printshop-mobile','font-weight','normal',0,''),(45220,14295,'119845','printshop-mobile','font-weight','400',0,''),(45221,14295,'119845','printshop-mobile','visibility_product','1',0,''),(45222,14295,'119845','printshop-mobile','show_name','0',0,''),(45223,14295,'119845','printshop-mobile','show_image','1',0,''),(45224,14295,'119845','printshop-mobile','show_stock','1',0,''),(45225,14295,'119845','printshop-mobile','show_description','1',0,''),(45226,14295,'119845','printshop-mobile','show_model','1',0,''),(45227,14295,'119845','printshop-mobile','show_rating','1',0,''),(45228,14295,'119845','printshop-mobile','show_rating_counts','1',0,''),(45229,14295,'119845','printshop-mobile','show_price','1',0,''),(45230,14295,'119845','printshop-mobile','show_buy_button','1',0,''),(45231,14295,'119845','printshop-mobile','show_qty_input','1',0,''),(45232,14295,'119845','printshop-mobile','show_view_button','1',0,''),(45233,14295,'119845','printshop-mobile','show_wishlist_button','1',0,''),(45234,14295,'119845','printshop-mobile','show_compare','1',0,''),(45235,14295,'119845','printshop-mobile','listing_type','type-1',0,''),(45236,14295,'119845','printshop-mobile','show_properties','1',0,''),(45237,14296,'119846','printshop-mobile','font-weight','normal',0,''),(45238,14296,'119846','printshop-mobile','visibility_product','1',0,''),(45239,14297,'119847','printshop-mobile','block_type','1',0,''),(45240,14298,'119848','printshop-mobile','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(45241,14300,'119850','printshop-mobile','block_type','1',0,''),(45242,14300,'119850','printshop-mobile','padding-top','40',0,''),(45243,14300,'119850','printshop-mobile','padding-bottom','80',0,''),(45244,14301,'119851','printshop-mobile','block_type','6',0,''),(45245,14302,'119852','printshop-mobile','block_type','1',0,''),(45246,14302,'119852','printshop-mobile','padding-top','20',0,''),(45247,14302,'119852','printshop-mobile','padding-left','20',0,''),(45248,14302,'119852','printshop-mobile','padding-right','20',0,''),(45249,14302,'119852','printshop-mobile','padding-bottom','20',0,''),(45250,14302,'119852','printshop-mobile','border-top-width','1',0,''),(45251,14302,'119852','printshop-mobile','border-left-width','1',0,''),(45252,14302,'119852','printshop-mobile','border-right-width','1',0,''),(45253,14302,'119852','printshop-mobile','border-bottom-width','1',0,''),(45254,14302,'119852','printshop-mobile','border-top-color','#e0e0e0',0,''),(45255,14302,'119852','printshop-mobile','border-left-color','#e0e0e0',0,''),(45256,14302,'119852','printshop-mobile','border-right-color','#e0e0e0',0,''),(45257,14302,'119852','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(45258,14302,'119852','printshop-mobile','margin-right','20',0,''),(45259,14305,'119855','printshop-mobile','block_type','1',0,''),(45260,14305,'119855','printshop-mobile','padding-top','20',0,''),(45261,14306,'119856','printshop-mobile','block_type','6',0,''),(45262,14307,'119857','printshop-mobile','padding-right','20',0,''),(45263,14309,'119859','printshop-mobile','block_type','1',0,''),(45264,14309,'119859','printshop-mobile','padding-top','20',0,''),(45265,14310,'119860','printshop-mobile','block_type','6',0,''),(45266,14311,'119861','printshop-mobile','padding-right','20',0,''),(45267,14313,'119863','printshop-mobile','block_type','1',0,''),(45268,14314,'119864','printshop-mobile','block_type','6',0,''),(45269,14314,'119864','printshop-mobile','schema','6-3',0,''),(45270,14314,'119864','printshop-mobile','schema','6-3',0,'702'),(45271,14315,'119865','printshop-mobile','aria_name','account-menu',0,''),(45272,14317,'119867','printshop-mobile','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(45273,14318,'119868','printshop-mobile','text','CANCEL',0,''),(45274,14318,'119868','printshop-mobile','like_button','1',0,''),(45275,14318,'119868','printshop-mobile','padding-bottom','20',0,''),(45276,14319,'119869','printshop-mobile','block_type','1',0,''),(45277,14319,'119869','printshop-mobile','padding-top','20',0,''),(45278,14320,'119870','printshop-mobile','block_type','1',0,''),(45279,14321,'119871','printshop-mobile','tab_1','RETURNING CUSTOMER',1,''),(45280,14321,'119871','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(45281,14323,'119873','printshop-mobile','block_type','8',0,''),(45282,14324,'119874','printshop-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(45283,14325,'119875','printshop-mobile','block_type','1',0,''),(45284,14325,'119875','printshop-mobile','padding-left','20',0,''),(45285,14325,'119875','printshop-mobile','padding-right','20',0,''),(45286,14327,'119877','printshop-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(45287,14328,'119878','printshop-mobile','block_type','1',0,''),(45288,14329,'119879','printshop-mobile','margin-bottom','30',0,''),(45289,14330,'119880','printshop-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(45290,14331,'119881','printshop-mobile','margin_left_measure','auto',0,''),(45291,14331,'119881','printshop-mobile','margin_right_measure','auto',0,''),(45292,14331,'119881','printshop-mobile','max-width','560',0,''),(45293,14332,'119882','printshop-mobile','block_type','1',0,''),(45294,14334,'119884','printshop-mobile','block_type','6',0,''),(45295,14334,'119884','printshop-mobile','font-weight','400',0,''),(45296,14334,'119884','printshop-mobile','schema','6-2',0,''),(45298,14335,'119885','printshop-mobile','font-weight','400',0,''),(45299,14335,'119885','printshop-mobile','padding-right','40',0,''),(45302,14336,'119886','printshop-mobile','col_in_row','3',0,''),(45303,14336,'119886','printshop-mobile','products_align','left',0,''),(45304,14336,'119886','printshop-mobile','font-weight','400',0,''),(45305,14336,'119886','printshop-mobile','show_qty_input','0',0,''),(45306,14336,'119886','printshop-mobile','listing_type','productListing',0,''),(45307,14336,'119886','printshop-mobile','listing_type_rows','no',0,''),(45308,14336,'119886','printshop-mobile','show_buy_button_b2b','on',0,''),(45309,14336,'119886','printshop-mobile','show_wishlist_button_b2b','1',0,''),(45310,14336,'119886','printshop-mobile','show_compare_b2b','1',0,''),(45311,14336,'119886','printshop-mobile','show_stock','0',0,''),(45312,14336,'119886','printshop-mobile','show_description','0',0,''),(45313,14336,'119886','printshop-mobile','show_model','0',0,''),(45314,14336,'119886','printshop-mobile','show_properties','0',0,''),(45315,14336,'119886','printshop-mobile','show_rating','0',0,''),(45316,14336,'119886','printshop-mobile','show_rating_counts','0',0,''),(45317,14336,'119886','printshop-mobile','show_price','0',0,''),(45318,14336,'119886','printshop-mobile','show_buy_button','0',0,''),(45319,14336,'119886','printshop-mobile','show_view_button','0',0,''),(45320,14336,'119886','printshop-mobile','show_wishlist_button','0',0,''),(45321,14336,'119886','printshop-mobile','show_compare','0',0,''),(45322,14336,'119886','printshop-mobile','show_name_rows','0',0,''),(45323,14336,'119886','printshop-mobile','show_image_rows','0',0,''),(45324,14336,'119886','printshop-mobile','show_stock_rows','0',0,''),(45325,14336,'119886','printshop-mobile','show_description_rows','0',0,''),(45326,14336,'119886','printshop-mobile','show_model_rows','0',0,''),(45327,14336,'119886','printshop-mobile','show_properties_rows','0',0,''),(45328,14336,'119886','printshop-mobile','show_rating_rows','0',0,''),(45329,14336,'119886','printshop-mobile','show_rating_counts_rows','0',0,''),(45330,14336,'119886','printshop-mobile','show_price_rows','0',0,''),(45331,14336,'119886','printshop-mobile','show_buy_button_rows','0',0,''),(45332,14336,'119886','printshop-mobile','show_qty_input_rows','0',0,''),(45333,14336,'119886','printshop-mobile','show_view_button_rows','0',0,''),(45334,14336,'119886','printshop-mobile','show_wishlist_button_rows','0',0,''),(45335,14336,'119886','printshop-mobile','show_compare_rows','0',0,''),(45336,14336,'119886','printshop-mobile','show_name_b2b','0',0,''),(45337,14336,'119886','printshop-mobile','show_image_b2b','0',0,''),(45338,14336,'119886','printshop-mobile','show_stock_b2b','0',0,''),(45339,14336,'119886','printshop-mobile','show_description_b2b','0',0,''),(45340,14336,'119886','printshop-mobile','show_model_b2b','0',0,''),(45341,14336,'119886','printshop-mobile','show_properties_b2b','0',0,''),(45342,14336,'119886','printshop-mobile','show_rating_b2b','0',0,''),(45343,14336,'119886','printshop-mobile','show_rating_counts_b2b','0',0,''),(45344,14336,'119886','printshop-mobile','show_price_b2b','0',0,''),(45345,14336,'119886','printshop-mobile','show_qty_input_b2b','0',0,''),(45346,14336,'119886','printshop-mobile','show_view_button_b2b','0',0,''),(45347,14336,'119886','printshop-mobile','show_attributes_b2b','0',0,''),(45348,14336,'119886','printshop-mobile','items_on_page','9',0,''),(45351,14336,'119886','printshop-mobile','product_names_teg','h2',0,''),(45352,14338,'119888','printshop-mobile','block_type','5',0,''),(45353,14338,'119888','printshop-mobile','padding-top','10',0,''),(45354,14338,'119888','printshop-mobile','padding-bottom','10',0,''),(45355,14338,'119888','printshop-mobile','schema','5-2',0,''),(45356,14338,'119888','printshop-mobile','border-top-color','#e0e0e0',0,''),(45357,14338,'119888','printshop-mobile','border-top-width','1',0,''),(45358,14340,'119890','printshop-mobile','float','right',0,''),(45359,14341,'119891','printshop-mobile','listing_type','productListing',0,''),(45360,14343,'119893','printshop-mobile','block_type','1',0,''),(45361,14343,'119893','printshop-mobile','padding-top','10',0,''),(45362,14343,'119893','printshop-mobile','padding-bottom','10',0,''),(45363,14343,'119893','printshop-mobile','border-bottom-width','1',0,''),(45364,14343,'119893','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(45365,14343,'119893','printshop-mobile','margin-left','0',0,''),(45366,14343,'119893','printshop-mobile','margin-right','0',0,''),(45367,14344,'119894','printshop-mobile','float','right',0,''),(45368,14344,'119894','printshop-mobile','display','none',0,''),(45369,14345,'119895','printshop-mobile','float','left',0,''),(45370,14345,'119895','printshop-mobile','clear','none',0,''),(45371,14345,'119895','printshop-mobile','margin-left','20',0,''),(45372,14345,'119895','printshop-mobile','display','none',0,''),(45373,14346,'119896','printshop-mobile','margin-right','20',0,''),(45374,14346,'119896','printshop-mobile','float','right',0,''),(45375,14346,'119896','printshop-mobile','clear','none',0,''),(45376,14346,'119896','printshop-mobile','display','none',0,''),(45377,14347,'119897','printshop-mobile','float','left',0,''),(45378,14347,'119897','printshop-mobile','clear','none',0,''),(45379,14347,'119897','printshop-mobile','sort_pos_3','1',0,''),(45380,14347,'119897','printshop-mobile','sort_pos_4','2',0,''),(45381,14347,'119897','printshop-mobile','sort_pos_10','3',0,''),(45382,14347,'119897','printshop-mobile','sort_pos_9','4',0,''),(45383,14347,'119897','printshop-mobile','sort_pos_11','5',0,''),(45384,14347,'119897','printshop-mobile','sort_pos_12','6',0,''),(45385,14347,'119897','printshop-mobile','sort_pos_14','7',0,''),(45386,14347,'119897','printshop-mobile','sort_pos_13','8',0,''),(45387,14347,'119897','printshop-mobile','sort_pos_8','9',0,''),(45388,14347,'119897','printshop-mobile','sort_pos_7','10',0,''),(45389,14347,'119897','printshop-mobile','sort_pos_2','11',0,''),(45390,14347,'119897','printshop-mobile','sort_pos_1','12',0,''),(45391,14347,'119897','printshop-mobile','sort_pos_6','13',0,''),(45392,14347,'119897','printshop-mobile','sort_pos_5','14',0,''),(45393,14347,'119897','printshop-mobile','sort_pos_0','15',0,''),(45394,14347,'119897','printshop-mobile','sort_hide_10','1',0,''),(45395,14347,'119897','printshop-mobile','sort_hide_9','1',0,''),(45396,14347,'119897','printshop-mobile','hide_icons','1',0,''),(45397,14347,'119897','printshop-mobile','sort_hide_16','1',0,''),(45398,14347,'119897','printshop-mobile','sort_hide_15','1',0,''),(45399,14347,'119897','printshop-mobile','sort_hide_3','0',0,''),(45400,14347,'119897','printshop-mobile','sort_hide_4','0',0,''),(45401,14347,'119897','printshop-mobile','sort_hide_11','1',0,''),(45402,14347,'119897','printshop-mobile','sort_hide_12','1',0,''),(45403,14347,'119897','printshop-mobile','sort_hide_14','1',0,''),(45404,14347,'119897','printshop-mobile','sort_hide_13','1',0,''),(45405,14347,'119897','printshop-mobile','sort_hide_8','0',0,''),(45406,14347,'119897','printshop-mobile','sort_hide_7','0',0,''),(45407,14347,'119897','printshop-mobile','sort_hide_2','1',0,''),(45408,14347,'119897','printshop-mobile','sort_hide_1','1',0,''),(45409,14347,'119897','printshop-mobile','sort_hide_6','1',0,''),(45410,14347,'119897','printshop-mobile','sort_hide_5','1',0,''),(45411,14347,'119897','printshop-mobile','sort_hide_0','1',0,''),(45412,14348,'119898','printshop-mobile','block_type','1',0,''),(45413,14349,'119899','printshop-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(45414,14350,'119900','printshop-mobile','margin-bottom','30',0,''),(45415,14351,'119901','printshop-mobile','block_type','1',0,''),(45416,14352,'119902','printshop-mobile','block_type','1',0,''),(45417,14353,'119903','printshop-mobile','margin-bottom','20',0,''),(45418,14354,'119904','printshop-mobile','block_type','1',0,''),(45419,14354,'119904','printshop-mobile','padding-top','10',0,''),(45420,14354,'119904','printshop-mobile','padding-bottom','10',0,''),(45421,14354,'119904','printshop-mobile','border-bottom-width','1',0,''),(45422,14354,'119904','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(45423,14354,'119904','printshop-mobile','margin-left','0',0,''),(45424,14354,'119904','printshop-mobile','margin-right','0',0,''),(45425,14355,'119905','printshop-mobile','float','left',0,''),(45426,14355,'119905','printshop-mobile','clear','none',0,''),(45427,14355,'119905','printshop-mobile','sort_pos_3','2',0,''),(45428,14355,'119905','printshop-mobile','sort_pos_4','1',0,''),(45429,14355,'119905','printshop-mobile','sort_pos_10','5',0,''),(45430,14355,'119905','printshop-mobile','sort_pos_9','6',0,''),(45431,14355,'119905','printshop-mobile','sort_pos_11','7',0,''),(45432,14355,'119905','printshop-mobile','sort_pos_12','8',0,''),(45433,14355,'119905','printshop-mobile','sort_pos_14','9',0,''),(45434,14355,'119905','printshop-mobile','sort_pos_13','10',0,''),(45435,14355,'119905','printshop-mobile','sort_pos_8','11',0,''),(45436,14355,'119905','printshop-mobile','sort_pos_7','12',0,''),(45437,14355,'119905','printshop-mobile','sort_pos_2','13',0,''),(45438,14355,'119905','printshop-mobile','sort_pos_1','14',0,''),(45439,14355,'119905','printshop-mobile','sort_pos_6','15',0,''),(45440,14355,'119905','printshop-mobile','sort_pos_5','16',0,''),(45441,14355,'119905','printshop-mobile','sort_pos_0','17',0,''),(45442,14355,'119905','printshop-mobile','sort_hide_10','1',0,''),(45443,14355,'119905','printshop-mobile','sort_hide_9','1',0,''),(45444,14355,'119905','printshop-mobile','sort_pos_15','4',0,''),(45445,14355,'119905','printshop-mobile','sort_pos_16','3',0,''),(45446,14355,'119905','printshop-mobile','sort_hide_4','0',0,''),(45447,14355,'119905','printshop-mobile','sort_hide_3','0',0,''),(45448,14355,'119905','printshop-mobile','sort_hide_16','1',0,''),(45449,14355,'119905','printshop-mobile','sort_hide_15','1',0,''),(45450,14355,'119905','printshop-mobile','sort_hide_11','1',0,''),(45451,14355,'119905','printshop-mobile','sort_hide_12','1',0,''),(45452,14355,'119905','printshop-mobile','sort_hide_14','1',0,''),(45453,14355,'119905','printshop-mobile','sort_hide_13','1',0,''),(45454,14355,'119905','printshop-mobile','sort_hide_8','0',0,''),(45455,14355,'119905','printshop-mobile','sort_hide_7','0',0,''),(45456,14355,'119905','printshop-mobile','sort_hide_2','1',0,''),(45457,14355,'119905','printshop-mobile','sort_hide_1','1',0,''),(45458,14355,'119905','printshop-mobile','sort_hide_6','1',0,''),(45459,14355,'119905','printshop-mobile','sort_hide_5','1',0,''),(45460,14355,'119905','printshop-mobile','sort_hide_0','1',0,''),(45461,14355,'119905','printshop-mobile','hide_icons','1',0,''),(45462,14356,'119906','printshop-mobile','float','left',0,''),(45463,14356,'119906','printshop-mobile','clear','none',0,''),(45464,14356,'119906','printshop-mobile','margin-left','20',0,''),(45465,14356,'119906','printshop-mobile','display','none',0,''),(45466,14357,'119907','printshop-mobile','clear','none',0,''),(45467,14357,'119907','printshop-mobile','float','left',0,''),(45468,14357,'119907','printshop-mobile','padding-top','3',0,''),(45469,14357,'119907','printshop-mobile','margin-left','20',0,''),(45470,14358,'119908','printshop-mobile','margin-right','20',0,''),(45471,14358,'119908','printshop-mobile','float','right',0,''),(45472,14358,'119908','printshop-mobile','clear','none',0,''),(45473,14358,'119908','printshop-mobile','display','none',0,''),(45474,14359,'119909','printshop-mobile','float','right',0,''),(45475,14359,'119909','printshop-mobile','display','none',0,''),(45476,14360,'119910','printshop-mobile','block_type','5',0,''),(45477,14360,'119910','printshop-mobile','padding-top','10',0,''),(45478,14360,'119910','printshop-mobile','padding-bottom','10',0,''),(45479,14360,'119910','printshop-mobile','schema','5-2',0,''),(45480,14360,'119910','printshop-mobile','border-top-color','#e0e0e0',0,''),(45481,14360,'119910','printshop-mobile','border-top-width','1',0,''),(45482,14361,'119911','printshop-mobile','padding-top','3',0,''),(45483,14362,'119912','printshop-mobile','float','right',0,''),(45484,14362,'119912','printshop-mobile','height','31',0,''),(45485,14365,'119915','printshop-mobile','col_in_row','4',0,''),(45486,14365,'119915','printshop-mobile','products_align','left',0,''),(45487,14365,'119915','printshop-mobile','font-weight','400',0,''),(45488,14365,'119915','printshop-mobile','listing_type','productListing',0,''),(45489,14365,'119915','printshop-mobile','listing_type_rows','Rows',0,''),(45490,14365,'119915','printshop-mobile','show_buy_button_b2b','on',0,''),(45491,14365,'119915','printshop-mobile','show_wishlist_button_b2b','1',0,''),(45492,14365,'119915','printshop-mobile','show_compare_b2b','1',0,''),(45493,14365,'119915','printshop-mobile','listing_type_b2b','b2b',0,''),(45494,14365,'119915','printshop-mobile','show_image','0',0,''),(45495,14365,'119915','printshop-mobile','show_stock','0',0,''),(45496,14365,'119915','printshop-mobile','show_description','0',0,''),(45497,14365,'119915','printshop-mobile','show_model','0',0,''),(45498,14365,'119915','printshop-mobile','show_properties','0',0,''),(45499,14365,'119915','printshop-mobile','show_rating','0',0,''),(45500,14365,'119915','printshop-mobile','show_rating_counts','0',0,''),(45501,14365,'119915','printshop-mobile','show_price','0',0,''),(45502,14365,'119915','printshop-mobile','show_buy_button','0',0,''),(45503,14365,'119915','printshop-mobile','show_view_button','0',0,''),(45504,14365,'119915','printshop-mobile','show_wishlist_button','0',0,''),(45505,14365,'119915','printshop-mobile','show_compare','0',0,''),(45506,14365,'119915','printshop-mobile','show_name_rows','0',0,''),(45507,14365,'119915','printshop-mobile','show_image_rows','0',0,''),(45508,14365,'119915','printshop-mobile','show_stock_rows','0',0,''),(45509,14365,'119915','printshop-mobile','show_description_rows','0',0,''),(45510,14365,'119915','printshop-mobile','show_model_rows','0',0,''),(45511,14365,'119915','printshop-mobile','show_properties_rows','0',0,''),(45512,14365,'119915','printshop-mobile','show_rating_rows','0',0,''),(45513,14365,'119915','printshop-mobile','show_rating_counts_rows','0',0,''),(45514,14365,'119915','printshop-mobile','show_price_rows','0',0,''),(45515,14365,'119915','printshop-mobile','show_buy_button_rows','0',0,''),(45516,14365,'119915','printshop-mobile','show_qty_input_rows','0',0,''),(45517,14365,'119915','printshop-mobile','show_view_button_rows','0',0,''),(45518,14365,'119915','printshop-mobile','show_wishlist_button_rows','0',0,''),(45519,14365,'119915','printshop-mobile','show_compare_rows','0',0,''),(45520,14365,'119915','printshop-mobile','show_name_b2b','0',0,''),(45521,14365,'119915','printshop-mobile','show_image_b2b','0',0,''),(45522,14365,'119915','printshop-mobile','show_stock_b2b','0',0,''),(45523,14365,'119915','printshop-mobile','show_description_b2b','0',0,''),(45524,14365,'119915','printshop-mobile','show_model_b2b','0',0,''),(45525,14365,'119915','printshop-mobile','show_properties_b2b','0',0,''),(45526,14365,'119915','printshop-mobile','show_rating_b2b','0',0,''),(45527,14365,'119915','printshop-mobile','show_rating_counts_b2b','0',0,''),(45528,14365,'119915','printshop-mobile','show_price_b2b','0',0,''),(45529,14365,'119915','printshop-mobile','show_qty_input_b2b','0',0,''),(45530,14365,'119915','printshop-mobile','show_view_button_b2b','0',0,''),(45531,14365,'119915','printshop-mobile','show_attributes_b2b','0',0,''),(45532,14365,'119915','printshop-mobile','items_on_page','12',0,''),(45535,14365,'119915','printshop-mobile','product_names_teg','h2',0,''),(45536,14366,'119916','printshop-mobile','block_type','1',0,''),(45537,14367,'119917','printshop-mobile','block_type','6',0,''),(45538,14367,'119917','printshop-mobile','schema','6-3',0,''),(45539,14367,'119917','printshop-mobile','schema','6-3',0,'702'),(45540,14368,'119918','printshop-mobile','aria_name','account-menu',0,''),(45541,14369,'119919','printshop-mobile','link','Order History Info',0,''),(45542,14369,'119919','printshop-mobile','text','TEXT_VIEW',0,''),(45543,14369,'119919','printshop-mobile','show_pagenation','1',0,''),(45544,14369,'119919','printshop-mobile','link_pay','Order pay',0,''),(45545,14369,'119919','printshop-mobile','margin-bottom','20',0,''),(45546,14370,'119920','printshop-mobile','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(45547,14371,'119921','printshop-mobile','block_type','1',0,''),(45548,14372,'119922','printshop-mobile','block_type','6',0,''),(45549,14372,'119922','printshop-mobile','schema','6-3',0,'702'),(45550,14373,'119923','printshop-mobile','aria_name','account-menu',0,''),(45551,14374,'119924','printshop-mobile','float','left',0,''),(45552,14375,'119925','printshop-mobile','block_type','3',0,''),(45553,14375,'119925','printshop-mobile','clear','both',0,''),(45554,14375,'119925','printshop-mobile','padding-top','20',0,''),(45555,14375,'119925','printshop-mobile','schema','3-4',0,'702'),(45556,14376,'119926','printshop-mobile','block_type','1',0,''),(45557,14376,'119926','printshop-mobile','padding-right','20',0,''),(45558,14376,'119926','printshop-mobile','margin-bottom','20',0,''),(45559,14377,'119927','printshop-mobile','link','Tracking numbers',0,''),(45560,14377,'119927','printshop-mobile','text','MORE_TRACKING_NUMBER',0,''),(45561,14377,'119927','printshop-mobile','popup','1',0,''),(45562,14377,'119927','printshop-mobile','order_id','1',0,''),(45563,14377,'119927','printshop-mobile','popup_class','tracking-numbers-popup',0,''),(45564,14377,'119927','printshop-mobile','font-weight','700',0,''),(45565,14377,'119927','printshop-mobile','font-size','18',0,''),(45566,14378,'119928','printshop-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(45567,14379,'119929','printshop-mobile','short_view','1',0,''),(45568,14379,'119929','printshop-mobile','hide_parents','2',0,''),(45569,14380,'119930','printshop-mobile','block_type','1',0,''),(45570,14380,'119930','printshop-mobile','margin-bottom','20',0,''),(45571,14380,'119930','printshop-mobile','padding-right','20',0,''),(45572,14381,'119931','printshop-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(45573,14382,'119932','printshop-mobile','padding-left','30',0,''),(45574,14382,'119932','printshop-mobile','orders_data','telephone',0,''),(45575,14382,'119932','printshop-mobile','hide_parents','2',0,''),(45576,14383,'119933','printshop-mobile','block_type','1',0,''),(45577,14383,'119933','printshop-mobile','padding-right','20',0,''),(45578,14383,'119933','printshop-mobile','padding-bottom','20',0,''),(45579,14384,'119934','printshop-mobile','orders_data','name',0,''),(45580,14384,'119934','printshop-mobile','padding-left','30',0,''),(45581,14385,'119935','printshop-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(45582,14386,'119936','printshop-mobile','block_type','1',0,''),(45583,14386,'119936','printshop-mobile','padding-right','20',0,''),(45584,14386,'119936','printshop-mobile','padding-bottom','20',0,''),(45585,14387,'119937','printshop-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(45586,14388,'119938','printshop-mobile','orders_data','delivery_address',0,''),(45587,14388,'119938','printshop-mobile','padding-left','30',0,''),(45588,14389,'119939','printshop-mobile','block_type','1',0,''),(45589,14389,'119939','printshop-mobile','padding-right','20',0,''),(45590,14390,'119940','printshop-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(45591,14391,'119941','printshop-mobile','orders_data','shipping_method',0,''),(45592,14391,'119941','printshop-mobile','padding-left','30',0,''),(45593,14392,'119942','printshop-mobile','block_type','1',0,''),(45594,14392,'119942','printshop-mobile','padding-bottom','20',0,''),(45595,14393,'119943','printshop-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(45596,14394,'119944','printshop-mobile','orders_data','billing_address',0,''),(45597,14394,'119944','printshop-mobile','padding-left','30',0,''),(45598,14395,'119945','printshop-mobile','block_type','1',0,''),(45599,14396,'119946','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(45600,14397,'119947','printshop-mobile','orders_data','payment_method',0,''),(45601,14397,'119947','printshop-mobile','padding-left','30',0,''),(45602,14398,'119948','printshop-mobile','float','right',0,''),(45603,14400,'119950','printshop-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(45604,14403,'119953','printshop-mobile','float','right',0,''),(45605,14403,'119953','printshop-mobile','clear','none',0,''),(45606,14403,'119953','printshop-mobile','margin-left','20',0,''),(45607,14404,'119954','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(45608,14406,'119956','printshop-mobile','float','right',0,''),(45609,14406,'119956','printshop-mobile','clear','none',0,''),(45610,14406,'119956','printshop-mobile','like_button','2',0,''),(45611,14406,'119956','printshop-mobile','link','Order pay',0,''),(45612,14407,'119957','printshop-mobile','float','right',0,''),(45613,14407,'119957','printshop-mobile','clear','none',0,''),(45614,14407,'119957','printshop-mobile','margin-left','20',0,''),(45615,14408,'119958','printshop-mobile','block_type','2',0,''),(45616,14408,'119958','printshop-mobile','padding-top','20',0,''),(45617,14408,'119958','printshop-mobile','margin-bottom','20',0,''),(45618,14409,'119959','printshop-mobile','like_button','1',0,''),(45619,14409,'119959','printshop-mobile','text','IMAGE_BUTTON_BACK',0,''),(45620,14409,'119959','printshop-mobile','link','Order History',0,''),(45621,14410,'119960','printshop-mobile','text-align','right',0,''),(45622,14411,'119961','printshop-mobile','block_type','1',0,''),(45623,14412,'119962','printshop-mobile','block_type','6',0,''),(45624,14412,'119962','printshop-mobile','schema','6-3',0,''),(45625,14412,'119962','printshop-mobile','schema','6-3',0,'702'),(45626,14413,'119963','printshop-mobile','aria_name','account-menu',0,''),(45627,14416,'119966','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(45628,14417,'119967','printshop-mobile','margin-bottom','20',0,''),(45629,14418,'119968','printshop-mobile','block_type','3',0,''),(45630,14418,'119968','printshop-mobile','schema','3-4',0,'702'),(45631,14419,'119969','printshop-mobile','block_type','1',0,''),(45632,14420,'119970','printshop-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(45633,14421,'119971','printshop-mobile','padding-left','30',0,''),(45634,14422,'119972','printshop-mobile','block_type','1',0,''),(45635,14422,'119972','printshop-mobile','padding-right','20',0,''),(45636,14422,'119972','printshop-mobile','padding-bottom','20',0,''),(45637,14423,'119973','printshop-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(45638,14424,'119974','printshop-mobile','orders_data','name',0,''),(45639,14424,'119974','printshop-mobile','padding-left','30',0,''),(45640,14425,'119975','printshop-mobile','block_type','1',0,''),(45641,14425,'119975','printshop-mobile','padding-right','20',0,''),(45642,14426,'119976','printshop-mobile','orders_data','shipping_method',0,''),(45643,14426,'119976','printshop-mobile','padding-left','30',0,''),(45644,14427,'119977','printshop-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(45645,14428,'119978','printshop-mobile','block_type','1',0,''),(45646,14428,'119978','printshop-mobile','padding-right','20',0,''),(45647,14428,'119978','printshop-mobile','padding-bottom','20',0,''),(45648,14429,'119979','printshop-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(45649,14430,'119980','printshop-mobile','orders_data','delivery_address',0,''),(45650,14430,'119980','printshop-mobile','padding-left','30',0,''),(45651,14431,'119981','printshop-mobile','block_type','1',0,''),(45652,14432,'119982','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(45653,14433,'119983','printshop-mobile','orders_data','payment_method',0,''),(45654,14433,'119983','printshop-mobile','padding-left','30',0,''),(45655,14434,'119984','printshop-mobile','block_type','1',0,''),(45656,14434,'119984','printshop-mobile','padding-bottom','20',0,''),(45657,14435,'119985','printshop-mobile','orders_data','billing_address',0,''),(45658,14435,'119985','printshop-mobile','padding-left','30',0,''),(45659,14436,'119986','printshop-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(45660,14438,'119988','printshop-mobile','width','680',0,''),(45661,14438,'119988','printshop-mobile','font-weight','400',0,''),(45662,14438,'119988','printshop-mobile','font-size','12',0,''),(45663,14438,'119988','printshop-mobile','padding-top','20',0,''),(45664,14438,'119988','printshop-mobile','padding-bottom','20',0,''),(45665,14439,'119989','printshop-mobile','font-weight','normal',0,''),(45666,14439,'119989','printshop-mobile','padding-top','20',0,''),(45667,14439,'119989','printshop-mobile','font-size','12',0,''),(45668,14440,'119990','printshop-mobile','block_type','4',0,''),(45669,14440,'119990','printshop-mobile','font-weight','400',0,''),(45670,14440,'119990','printshop-mobile','border-top-width','1',0,''),(45671,14440,'119990','printshop-mobile','border-top-color','#e0e0e0',0,''),(45672,14440,'119990','printshop-mobile','border-left-width','1',0,''),(45673,14440,'119990','printshop-mobile','border-left-color','#e0e0e0',0,''),(45674,14440,'119990','printshop-mobile','border-right-width','1',0,''),(45675,14440,'119990','printshop-mobile','border-right-color','#e0e0e0',0,''),(45676,14440,'119990','printshop-mobile','border-bottom-width','1',0,''),(45677,14440,'119990','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(45678,14441,'119991','printshop-mobile','block_type','2',0,''),(45679,14441,'119991','printshop-mobile','font-weight','normal',0,''),(45680,14441,'119991','printshop-mobile','border-right-width','1',0,''),(45681,14441,'119991','printshop-mobile','border-right-color','#e0e0e0',0,''),(45682,14442,'119992','printshop-mobile','block_type','1',0,''),(45683,14442,'119992','printshop-mobile','font-weight','normal',0,''),(45684,14442,'119992','printshop-mobile','border-right-width','1',0,''),(45685,14442,'119992','printshop-mobile','border-right-color','#e0e0e0',0,''),(45686,14442,'119992','printshop-mobile','background-color','#e0e0e0',0,''),(45687,14442,'119992','printshop-mobile','padding-top','10',0,''),(45688,14442,'119992','printshop-mobile','padding-left','10',0,''),(45689,14442,'119992','printshop-mobile','padding-right','10',0,''),(45690,14442,'119992','printshop-mobile','padding-bottom','10',0,''),(45691,14443,'119993','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(45692,14443,'119993','printshop-mobile','font-size','16',0,''),(45693,14443,'119993','printshop-mobile','font-weight','bold',0,''),(45694,14443,'119993','printshop-mobile','padding-bottom','10',0,''),(45695,14444,'119994','printshop-mobile','font-size','16',0,''),(45696,14444,'119994','printshop-mobile','font-weight','normal',0,''),(45697,14445,'119995','printshop-mobile','block_type','1',0,''),(45698,14445,'119995','printshop-mobile','font-weight','normal',0,''),(45699,14445,'119995','printshop-mobile','padding-top','10',0,''),(45700,14445,'119995','printshop-mobile','padding-left','10',0,''),(45701,14445,'119995','printshop-mobile','padding-right','10',0,''),(45702,14445,'119995','printshop-mobile','padding-bottom','10',0,''),(45703,14449,'119999','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(45704,14449,'119999','printshop-mobile','font-size','14',0,''),(45705,14449,'119999','printshop-mobile','font-weight','bold',0,''),(45706,14449,'119999','printshop-mobile','padding-top','10',0,''),(45707,14450,'120000','printshop-mobile','text','<p>CUSTOMER:</p>',1,''),(45708,14450,'120000','printshop-mobile','font-size','14',0,''),(45709,14450,'120000','printshop-mobile','font-weight','bold',0,''),(45710,14451,'120001','printshop-mobile','text','<p>PHONE NUMBER:</p>',1,''),(45711,14451,'120001','printshop-mobile','font-size','14',0,''),(45712,14451,'120001','printshop-mobile','font-weight','bold',0,''),(45713,14451,'120001','printshop-mobile','padding-top','10',0,''),(45714,14452,'120002','printshop-mobile','block_type','2',0,''),(45715,14452,'120002','printshop-mobile','font-weight','normal',0,''),(45716,14452,'120002','printshop-mobile','border-right-width','1',0,''),(45717,14452,'120002','printshop-mobile','border-right-color','#e0e0e0',0,''),(45718,14452,'120002','printshop-mobile','border-top-width','1',0,''),(45719,14452,'120002','printshop-mobile','border-top-color','#e0e0e0',0,''),(45720,14453,'120003','printshop-mobile','block_type','1',0,''),(45721,14453,'120003','printshop-mobile','font-weight','normal',0,''),(45722,14453,'120003','printshop-mobile','padding-top','10',0,''),(45723,14453,'120003','printshop-mobile','padding-left','10',0,''),(45724,14453,'120003','printshop-mobile','padding-right','10',0,''),(45725,14453,'120003','printshop-mobile','padding-bottom','10',0,''),(45726,14453,'120003','printshop-mobile','border-right-width','1',0,''),(45727,14453,'120003','printshop-mobile','border-right-color','#e0e0e0',0,''),(45728,14455,'120005','printshop-mobile','text','<p>Shipping via</p>',1,''),(45729,14455,'120005','printshop-mobile','font-weight','bold',0,''),(45730,14456,'120006','printshop-mobile','block_type','1',0,''),(45731,14456,'120006','printshop-mobile','font-weight','normal',0,''),(45732,14456,'120006','printshop-mobile','padding-top','10',0,''),(45733,14456,'120006','printshop-mobile','padding-left','10',0,''),(45734,14456,'120006','printshop-mobile','padding-right','10',0,''),(45735,14456,'120006','printshop-mobile','padding-bottom','10',0,''),(45736,14457,'120007','printshop-mobile','text','<p>Shipping service</p>',1,''),(45737,14457,'120007','printshop-mobile','font-weight','bold',0,''),(45738,14459,'120009','printshop-mobile','font-weight','normal',0,''),(45739,14459,'120009','printshop-mobile','text-align','center',0,''),(45740,14459,'120009','printshop-mobile','padding-top','40',0,''),(45741,14460,'120010','printshop-mobile','block_type','1',0,''),(45742,14460,'120010','printshop-mobile','font-weight','normal',0,''),(45743,14460,'120010','printshop-mobile','padding-top','10',0,''),(45744,14460,'120010','printshop-mobile','padding-bottom','10',0,''),(45745,14461,'120011','printshop-mobile','text','<p>If undelivered please return to:</p>',1,''),(45746,14461,'120011','printshop-mobile','font-weight','bold',0,''),(45747,14463,'120013','printshop-mobile','block_type','2',0,''),(45748,14463,'120013','printshop-mobile','font-weight','normal',0,''),(45749,14463,'120013','printshop-mobile','padding-bottom','20',0,''),(45750,14464,'120014','printshop-mobile','font-weight','400',0,''),(45751,14464,'120014','printshop-mobile','text-align','center',0,''),(45752,14464,'120014','printshop-mobile','padding-top','10',0,''),(45754,14465,'120015','printshop-mobile','block_type','1',0,''),(45755,14466,'120016','printshop-mobile','font-weight','400',0,''),(45756,14466,'120016','printshop-mobile','text-align','right',0,''),(45757,14466,'120016','printshop-mobile','padding-bottom','10',0,''),(45758,14466,'120016','printshop-mobile','address_spacer',',',0,''),(45759,14467,'120017','printshop-mobile','block_type','11',0,''),(45760,14467,'120017','printshop-mobile','font-weight','normal',0,''),(45761,14468,'120018','printshop-mobile','text','<p>Phone:</p>',1,''),(45762,14468,'120018','printshop-mobile','font-weight','normal',0,''),(45763,14468,'120018','printshop-mobile','text-align','right',0,''),(45764,14469,'120019','printshop-mobile','font-weight','normal',0,''),(45765,14469,'120019','printshop-mobile','text-align','right',0,''),(45766,14470,'120020','printshop-mobile','block_type','11',0,''),(45767,14470,'120020','printshop-mobile','font-weight','400',0,''),(45768,14471,'120021','printshop-mobile','text','<p>Web:</p>',1,''),(45769,14471,'120021','printshop-mobile','font-weight','400',0,''),(45770,14471,'120021','printshop-mobile','text-align','right',0,''),(45771,14472,'120022','printshop-mobile','font-weight','normal',0,''),(45772,14472,'120022','printshop-mobile','text-align','right',0,''),(45773,14473,'120023','printshop-mobile','block_type','11',0,''),(45774,14473,'120023','printshop-mobile','font-weight','normal',0,''),(45775,14474,'120024','printshop-mobile','text','<p>Email:</p>',1,''),(45776,14474,'120024','printshop-mobile','font-weight','normal',0,''),(45777,14474,'120024','printshop-mobile','text-align','right',0,''),(45778,14475,'120025','printshop-mobile','font-weight','normal',0,''),(45779,14475,'120025','printshop-mobile','text-align','right',0,''),(45780,14476,'120026','printshop-mobile','block_type','1',0,''),(45781,14477,'120027','printshop-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(45782,14478,'120028','printshop-mobile','block_type','8',0,''),(45783,14479,'120029','printshop-mobile','margin-bottom','20',0,''),(45784,14480,'120030','printshop-mobile','text','##TEXT_MAIN##',0,''),(45785,14480,'120030','printshop-mobile','margin-bottom','20',0,''),(45786,14480,'120030','printshop-mobile','text-align','center',0,''),(45787,14482,'120032','printshop-mobile','block_type','2',0,''),(45788,14483,'120033','printshop-mobile','block_type','1',0,''),(45789,14483,'120033','printshop-mobile','style_class','product',0,''),(45790,14483,'120033','printshop-mobile','padding-right','10',0,''),(45791,14483,'120033','printshop-mobile','padding-bottom','20',0,''),(45792,14484,'120034','printshop-mobile','block_type','2',0,''),(45793,14485,'120035','printshop-mobile','product_element','image',0,''),(45794,14485,'120035','printshop-mobile','padding-right','10',0,''),(45795,14486,'120036','printshop-mobile','product_element','products_price_old',0,''),(45796,14486,'120036','printshop-mobile','font-family','Varela Round',0,''),(45797,14486,'120036','printshop-mobile','font-size','14',0,''),(45798,14486,'120036','printshop-mobile','text-decoration','line-through',0,''),(45799,14487,'120037','printshop-mobile','product_element','products_price',0,''),(45800,14487,'120037','printshop-mobile','font-family','Varela Round',0,''),(45801,14487,'120037','printshop-mobile','font-size','20',0,''),(45802,14487,'120037','printshop-mobile','padding-top','20',0,''),(45803,14488,'120038','printshop-mobile','block_type','1',0,''),(45804,14489,'120039','printshop-mobile','product_element','products_name',0,''),(45805,14489,'120039','printshop-mobile','font-family','Varela Round',0,''),(45806,14489,'120039','printshop-mobile','padding-bottom','10',0,''),(45807,14489,'120039','printshop-mobile','font-size','16',0,''),(45808,14490,'120040','printshop-mobile','block_type','1',0,''),(45809,14490,'120040','printshop-mobile','style_class','product',0,''),(45810,14490,'120040','printshop-mobile','padding-left','10',0,''),(45811,14490,'120040','printshop-mobile','padding-bottom','20',0,''),(45812,14491,'120041','printshop-mobile','block_type','1',0,''),(45813,14492,'120042','printshop-mobile','product_element','products_name',0,''),(45814,14492,'120042','printshop-mobile','font-family','Varela Round',0,''),(45815,14492,'120042','printshop-mobile','font-size','16',0,''),(45816,14492,'120042','printshop-mobile','padding-bottom','10',0,''),(45817,14493,'120043','printshop-mobile','block_type','2',0,''),(45818,14494,'120044','printshop-mobile','product_element','image',0,''),(45819,14494,'120044','printshop-mobile','padding-right','10',0,''),(45820,14495,'120045','printshop-mobile','font-size','14',0,''),(45821,14495,'120045','printshop-mobile','font-family','Varela Round',0,''),(45822,14495,'120045','printshop-mobile','text-decoration','line-through',0,''),(45823,14495,'120045','printshop-mobile','product_element','products_price_old',0,''),(45824,14496,'120046','printshop-mobile','product_element','products_price',0,''),(45825,14496,'120046','printshop-mobile','font-family','Varela Round',0,''),(45826,14496,'120046','printshop-mobile','font-size','20',0,''),(45827,14496,'120046','printshop-mobile','padding-top','20',0,''),(45828,14497,'120047','printshop-mobile','font-size','30',0,''),(45829,14497,'120047','printshop-mobile','font-family','Varela Round',0,''),(45830,14497,'120047','printshop-mobile','text-align','center',0,''),(45831,14497,'120047','printshop-mobile','padding-bottom','50',0,''),(45832,14498,'120048','printshop-mobile','padding-bottom','20',0,''),(45833,14498,'120048','printshop-mobile','text-align','center',0,''),(45834,14499,'120049','printshop-mobile','width','680',0,''),(45835,14500,'120050','printshop-mobile','padding-top','200',0,''),(45836,14500,'120050','printshop-mobile','padding-left','200',0,''),(45838,14501,'120051','printshop-mobile','text','osCommerce 4',1,''),(45839,14501,'120051','printshop-mobile','font-family','Varela Round',0,''),(45840,14501,'120051','printshop-mobile','font-size','40',0,''),(45841,14501,'120051','printshop-mobile','padding-top','50',0,''),(45842,14501,'120051','printshop-mobile','text-align','center',0,''),(45843,14502,'120052','printshop-mobile','block_type','2',0,''),(45844,14502,'120052','printshop-mobile','border-top-width','1',0,''),(45845,14502,'120052','printshop-mobile','border-top-color','#eeeeee',0,''),(45846,14503,'120053','printshop-mobile','text-align','right',0,''),(45847,14503,'120053','printshop-mobile','padding-top','15',0,''),(45848,14503,'120053','printshop-mobile','padding-bottom','15',0,''),(45849,14503,'120053','printshop-mobile','font-size','14',0,''),(45850,14504,'120054','printshop-mobile','font-family','Varela Round',0,''),(45851,14504,'120054','printshop-mobile','text-align','center',0,''),(45852,14504,'120054','printshop-mobile','font-size','20',0,''),(45853,14504,'120054','printshop-mobile','color','#183d78',0,''),(45854,14504,'120054','printshop-mobile','border-bottom-width','1',0,''),(45855,14504,'120054','printshop-mobile','border-bottom-color','#dedede',0,''),(45856,14504,'120054','printshop-mobile','padding-top','10',0,''),(45857,14504,'120054','printshop-mobile','padding-bottom','10',0,''),(45858,14505,'120055','printshop-mobile','block_type','1',0,''),(45859,14506,'120056','printshop-mobile','block_type','6',0,''),(45860,14506,'120056','printshop-mobile','schema','6-3',0,''),(45861,14506,'120056','printshop-mobile','schema','6-3',0,'702'),(45862,14507,'120057','printshop-mobile','aria_name','account-menu',0,''),(45863,14508,'120058','printshop-mobile','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(45864,14509,'120059','printshop-mobile','max_items','10',0,''),(45865,14510,'120060','printshop-mobile','block_type','1',0,''),(45866,14510,'120060','printshop-mobile','padding-top','20',0,''),(45867,14510,'120060','printshop-mobile','padding-left','20',0,''),(45868,14510,'120060','printshop-mobile','padding-right','20',0,''),(45869,14510,'120060','printshop-mobile','padding-bottom','20',0,''),(45870,14511,'120061','printshop-mobile','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(45871,14513,'120063','printshop-mobile','block_type','1',0,''),(45872,14514,'120064','printshop-mobile','margin_left_measure','auto',0,''),(45873,14514,'120064','printshop-mobile','margin_right_measure','auto',0,''),(45874,14514,'120064','printshop-mobile','max-width','560',0,''),(45875,14515,'120065','printshop-mobile','margin-bottom','30',0,''),(45876,14516,'120066','printshop-mobile','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(45877,14517,'120067','printshop-mobile','block_type','1',0,''),(45878,14518,'120068','printshop-mobile','block_type','2',0,''),(45879,14518,'120068','printshop-mobile','border-top-width','1',0,''),(45880,14518,'120068','printshop-mobile','border-top-color','#e0e0e0',0,''),(45881,14518,'120068','printshop-mobile','padding-top','15',0,''),(45882,14518,'120068','printshop-mobile','padding-bottom','15',0,''),(45883,14520,'120070','printshop-mobile','font-size','30',0,''),(45884,14520,'120070','printshop-mobile','font-weight','400',0,''),(45885,14520,'120070','printshop-mobile','line-height','35',0,''),(45886,14520,'120070','printshop-mobile','font-family','Varela Round',0,''),(45887,14520,'120070','printshop-mobile','line_height_measure','px',0,''),(45888,14521,'120071','printshop-mobile','font-weight','400',0,''),(45889,14522,'120072','printshop-mobile','font-weight','normal',0,''),(45890,14522,'120072','printshop-mobile','padding-bottom','20',0,''),(45891,14523,'120073','printshop-mobile','padding-right','0',0,''),(45892,14523,'120073','printshop-mobile','align_position','horizontal',0,''),(45893,14525,'120075','printshop-mobile','text-align','right',0,''),(45894,14525,'120075','printshop-mobile','width','100',0,'693'),(45895,14525,'120075','printshop-mobile','width_measure','%',0,'693'),(45896,14525,'120075','printshop-mobile','float','none',0,'693'),(45897,14525,'120075','printshop-mobile','margin-bottom','20',0,''),(45898,14526,'120076','printshop-mobile','font-weight','400',0,''),(45899,14526,'120076','printshop-mobile','box_align','4',0,''),(45900,14526,'120076','printshop-mobile','align_position','horizontal',0,''),(45901,14526,'120076','printshop-mobile','margin-bottom','30',0,''),(45902,14527,'120077','printshop-mobile','font-weight','400',0,''),(45903,14528,'120078','printshop-mobile','block_type','1',0,''),(45904,14528,'120078','printshop-mobile','style_class','personal-buttons',0,''),(45905,14528,'120078','printshop-mobile','margin-bottom','20',0,''),(45906,14528,'120078','printshop-mobile','border-bottom-width','1',0,''),(45907,14528,'120078','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(45908,14528,'120078','printshop-mobile','padding-left','30',0,''),(45909,14533,'120083','printshop-mobile','font-weight','normal',0,''),(45910,14533,'120083','printshop-mobile','padding-bottom','20',0,''),(45911,14533,'120083','printshop-mobile','show_qty_input','1',0,''),(45912,14533,'120083','printshop-mobile','show_compare','1',0,''),(45913,14533,'120083','printshop-mobile','col_in_row','1',0,''),(45914,14533,'120083','printshop-mobile','view_as','carousel',0,''),(45915,14533,'120083','printshop-mobile','listing_type','productListing',0,''),(45916,14534,'120084','printshop-mobile','font-weight','400',0,''),(45917,14534,'120084','printshop-mobile','padding-bottom','20',0,''),(45918,14534,'120084','printshop-mobile','show_qty_input','1',0,''),(45919,14534,'120084','printshop-mobile','show_compare','1',0,''),(45920,14534,'120084','printshop-mobile','listing_type','type-1',0,''),(45921,14534,'120084','printshop-mobile','view_as','carousel',0,''),(45922,14534,'120084','printshop-mobile','show_name','0',0,''),(45923,14534,'120084','printshop-mobile','show_image','0',0,''),(45924,14534,'120084','printshop-mobile','show_stock','0',0,''),(45925,14534,'120084','printshop-mobile','show_description','0',0,''),(45926,14534,'120084','printshop-mobile','show_model','0',0,''),(45927,14534,'120084','printshop-mobile','show_properties','0',0,''),(45928,14534,'120084','printshop-mobile','show_rating','0',0,''),(45929,14534,'120084','printshop-mobile','show_rating_counts','0',0,''),(45930,14534,'120084','printshop-mobile','show_price','0',0,''),(45931,14534,'120084','printshop-mobile','show_buy_button','0',0,''),(45932,14534,'120084','printshop-mobile','show_view_button','0',0,''),(45933,14534,'120084','printshop-mobile','show_wishlist_button','0',0,''),(45934,14534,'120084','printshop-mobile','display','none',0,'694'),(45935,14534,'120084','printshop-mobile','product_names_teg','h2',0,''),(45936,14535,'120085','printshop-mobile','font-weight','normal',0,''),(45937,14535,'120085','printshop-mobile','padding-bottom','20',0,''),(45938,14536,'120086','printshop-mobile','tab_1','Description',1,''),(45939,14536,'120086','printshop-mobile','tab_2','Reviews',1,''),(45940,14536,'120086','printshop-mobile','font-weight','400',0,''),(45941,14536,'120086','printshop-mobile','margin-top','20',0,''),(45942,14539,'120089','printshop-mobile','padding-bottom','10',0,''),(45943,14539,'120089','printshop-mobile','padding-top','5',0,''),(45944,14540,'120090','printshop-mobile','font-weight','normal',0,''),(45945,14540,'120090','printshop-mobile','padding-top','20',0,''),(45946,14540,'120090','printshop-mobile','padding-bottom','20',0,''),(45947,14540,'120090','printshop-mobile','border-top-width','1',0,''),(45948,14540,'120090','printshop-mobile','border-top-color','#cccccc',0,''),(45949,14542,'120092','printshop-mobile','font-weight','400',0,''),(45950,14542,'120092','printshop-mobile','padding-bottom','20',0,''),(45951,14542,'120092','printshop-mobile','show_qty_input','1',0,''),(45952,14542,'120092','printshop-mobile','show_compare','1',0,''),(45953,14542,'120092','printshop-mobile','show_name','0',0,''),(45954,14542,'120092','printshop-mobile','show_image','0',0,''),(45955,14542,'120092','printshop-mobile','show_stock','0',0,''),(45956,14542,'120092','printshop-mobile','show_description','0',0,''),(45957,14542,'120092','printshop-mobile','show_model','0',0,''),(45958,14542,'120092','printshop-mobile','show_properties','0',0,''),(45959,14542,'120092','printshop-mobile','show_rating','0',0,''),(45960,14542,'120092','printshop-mobile','show_rating_counts','0',0,''),(45961,14542,'120092','printshop-mobile','show_price','0',0,''),(45962,14542,'120092','printshop-mobile','show_buy_button','0',0,''),(45963,14542,'120092','printshop-mobile','show_view_button','0',0,''),(45964,14542,'120092','printshop-mobile','show_wishlist_button','0',0,''),(45965,14542,'120092','printshop-mobile','listing_type','productListing',0,''),(45966,14542,'120092','printshop-mobile','col_in_row','1',0,''),(45967,14542,'120092','printshop-mobile','view_as','carousel',0,''),(45968,14553,'120103','printshop-mobile','block_type','1',0,''),(45969,14553,'120103','printshop-mobile','style_class','item-holder',0,''),(45970,14553,'120103','printshop-mobile','padding-top','25',0,''),(45971,14553,'120103','printshop-mobile','padding-left','25',0,''),(45972,14553,'120103','printshop-mobile','padding-right','25',0,''),(45973,14553,'120103','printshop-mobile','padding-bottom','25',0,''),(45974,14553,'120103','printshop-mobile','text-align','left',0,''),(45975,14556,'120106','printshop-mobile','description_characters','90',0,''),(45976,14557,'120107','printshop-mobile','text-align','right',0,''),(45977,14557,'120107','printshop-mobile','margin-bottom','10',0,''),(45978,14558,'120108','printshop-mobile','text-align','right',0,''),(45979,14558,'120108','printshop-mobile','clear','none',0,''),(45980,14558,'120108','printshop-mobile','float','left',0,''),(45981,14560,'120110','printshop-mobile','block_type','2',0,''),(45982,14561,'120111','printshop-mobile','margin-bottom','7',0,''),(45983,14562,'120112','printshop-mobile','margin-bottom','10',0,''),(45984,14562,'120112','printshop-mobile','text-align','right',0,''),(45985,14562,'120112','printshop-mobile','float','right',0,''),(45986,14563,'120113','printshop-mobile','clear','both',0,''),(45987,14564,'120114','printshop-mobile','float','left',0,''),(45988,14564,'120114','printshop-mobile','margin-right','20',0,''),(45989,14564,'120114','printshop-mobile','margin-bottom','5',0,''),(45990,14565,'120115','printshop-mobile','block_type','1',0,''),(45991,14566,'120116','printshop-mobile','font-weight','400',0,''),(45992,14566,'120116','printshop-mobile','padding-right','40',0,''),(45993,14566,'120116','printshop-mobile','padding-right','0',0,'718'),(45994,14566,'120116','printshop-mobile','padding-right','0',0,'720'),(45995,14566,'120116','printshop-mobile','margin-bottom','20',0,''),(45996,14567,'120117','printshop-mobile','text-align','center',0,''),(45997,14567,'120117','printshop-mobile','margin-bottom','20',0,''),(45998,14569,'120119','printshop-mobile','margin-bottom','20',0,''),(45999,14569,'120119','printshop-mobile','text-align','center',0,''),(46000,14570,'120120','printshop-mobile','block_type','2',0,''),(46001,14570,'120120','printshop-mobile','margin-bottom','20',0,''),(46002,14571,'120121','printshop-mobile','sort_pos_3','1',0,''),(46003,14571,'120121','printshop-mobile','sort_pos_4','2',0,''),(46004,14571,'120121','printshop-mobile','sort_pos_10','5',0,''),(46005,14571,'120121','printshop-mobile','sort_pos_9','6',0,''),(46006,14571,'120121','printshop-mobile','sort_pos_11','7',0,''),(46007,14571,'120121','printshop-mobile','sort_pos_12','8',0,''),(46008,14571,'120121','printshop-mobile','sort_pos_14','9',0,''),(46009,14571,'120121','printshop-mobile','sort_pos_13','10',0,''),(46010,14571,'120121','printshop-mobile','sort_pos_8','11',0,''),(46011,14571,'120121','printshop-mobile','sort_pos_7','12',0,''),(46012,14571,'120121','printshop-mobile','sort_pos_2','13',0,''),(46013,14571,'120121','printshop-mobile','sort_pos_1','14',0,''),(46014,14571,'120121','printshop-mobile','sort_pos_6','15',0,''),(46015,14571,'120121','printshop-mobile','sort_pos_5','16',0,''),(46016,14571,'120121','printshop-mobile','sort_pos_0','17',0,''),(46017,14571,'120121','printshop-mobile','sort_hide_10','1',0,''),(46018,14571,'120121','printshop-mobile','sort_hide_9','1',0,''),(46019,14571,'120121','printshop-mobile','sort_pos_15','4',0,''),(46020,14571,'120121','printshop-mobile','sort_pos_16','3',0,''),(46021,14571,'120121','printshop-mobile','sort_hide_3','0',0,''),(46022,14571,'120121','printshop-mobile','sort_hide_4','0',0,''),(46023,14571,'120121','printshop-mobile','sort_hide_16','1',0,''),(46024,14571,'120121','printshop-mobile','sort_hide_15','1',0,''),(46025,14571,'120121','printshop-mobile','sort_hide_11','0',0,''),(46026,14571,'120121','printshop-mobile','sort_hide_12','0',0,''),(46027,14571,'120121','printshop-mobile','sort_hide_14','0',0,''),(46028,14571,'120121','printshop-mobile','sort_hide_13','0',0,''),(46029,14571,'120121','printshop-mobile','sort_hide_8','0',0,''),(46030,14571,'120121','printshop-mobile','sort_hide_7','0',0,''),(46031,14571,'120121','printshop-mobile','sort_hide_2','0',0,''),(46032,14571,'120121','printshop-mobile','sort_hide_1','0',0,''),(46033,14571,'120121','printshop-mobile','sort_hide_6','0',0,''),(46034,14571,'120121','printshop-mobile','sort_hide_5','0',0,''),(46035,14571,'120121','printshop-mobile','sort_hide_0','0',0,''),(46036,14572,'120122','printshop-mobile','text-align','right',0,''),(46037,14572,'120122','printshop-mobile','padding-top','10',0,''),(46038,14573,'120123','printshop-mobile','col_in_row','2',0,''),(46039,14573,'120123','printshop-mobile','products_align','left',0,''),(46040,14573,'120123','printshop-mobile','font-weight','400',0,''),(46041,14573,'120123','printshop-mobile','show_qty_input','1',0,''),(46042,14573,'120123','printshop-mobile','listing_type','productListing',0,''),(46043,14573,'120123','printshop-mobile','listing_type_rows','type-1_2',0,''),(46044,14573,'120123','printshop-mobile','show_buy_button_b2b','on',0,''),(46045,14573,'120123','printshop-mobile','show_wishlist_button_b2b','1',0,''),(46046,14573,'120123','printshop-mobile','show_compare_b2b','1',0,''),(46047,14573,'120123','printshop-mobile','listing_type_b2b','type-1_3',0,''),(46048,14573,'120123','printshop-mobile','show_name','0',0,''),(46049,14573,'120123','printshop-mobile','show_image','0',0,''),(46050,14573,'120123','printshop-mobile','show_stock','0',0,''),(46051,14573,'120123','printshop-mobile','show_description','1',0,''),(46052,14573,'120123','printshop-mobile','show_model','1',0,''),(46053,14573,'120123','printshop-mobile','show_properties','1',0,''),(46054,14573,'120123','printshop-mobile','show_rating_counts','1',0,''),(46055,14573,'120123','printshop-mobile','show_price','0',0,''),(46056,14573,'120123','printshop-mobile','show_buy_button','1',0,''),(46057,14573,'120123','printshop-mobile','show_view_button','1',0,''),(46058,14573,'120123','printshop-mobile','show_wishlist_button','1',0,''),(46059,14573,'120123','printshop-mobile','show_compare','1',0,''),(46060,14573,'120123','printshop-mobile','show_name_rows','0',0,''),(46061,14573,'120123','printshop-mobile','show_image_rows','0',0,''),(46062,14573,'120123','printshop-mobile','show_stock_rows','0',0,''),(46063,14573,'120123','printshop-mobile','show_description_rows','0',0,''),(46064,14573,'120123','printshop-mobile','show_model_rows','0',0,''),(46065,14573,'120123','printshop-mobile','show_properties_rows','0',0,''),(46066,14573,'120123','printshop-mobile','show_rating_rows','0',0,''),(46067,14573,'120123','printshop-mobile','show_rating_counts_rows','0',0,''),(46068,14573,'120123','printshop-mobile','show_price_rows','0',0,''),(46069,14573,'120123','printshop-mobile','show_buy_button_rows','0',0,''),(46070,14573,'120123','printshop-mobile','show_qty_input_rows','0',0,''),(46071,14573,'120123','printshop-mobile','show_view_button_rows','0',0,''),(46072,14573,'120123','printshop-mobile','show_wishlist_button_rows','0',0,''),(46073,14573,'120123','printshop-mobile','show_compare_rows','0',0,''),(46074,14573,'120123','printshop-mobile','show_name_b2b','0',0,''),(46075,14573,'120123','printshop-mobile','show_image_b2b','0',0,''),(46076,14573,'120123','printshop-mobile','show_stock_b2b','0',0,''),(46077,14573,'120123','printshop-mobile','show_description_b2b','0',0,''),(46078,14573,'120123','printshop-mobile','show_model_b2b','0',0,''),(46079,14573,'120123','printshop-mobile','show_properties_b2b','0',0,''),(46080,14573,'120123','printshop-mobile','show_rating_b2b','0',0,''),(46081,14573,'120123','printshop-mobile','show_rating_counts_b2b','0',0,''),(46082,14573,'120123','printshop-mobile','show_price_b2b','0',0,''),(46083,14573,'120123','printshop-mobile','show_qty_input_b2b','0',0,''),(46084,14573,'120123','printshop-mobile','show_view_button_b2b','0',0,''),(46085,14573,'120123','printshop-mobile','show_attributes_b2b','0',0,''),(46086,14573,'120123','printshop-mobile','items_on_page','10',0,''),(46087,14573,'120123','printshop-mobile','product_names_teg','h2',0,''),(46088,14575,'120125','printshop-mobile','block_type','1',0,''),(46089,14577,'120127','printshop-mobile','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(46090,14578,'120128','printshop-mobile','width','680',0,''),(46091,14578,'120128','printshop-mobile','font-weight','normal',0,''),(46092,14578,'120128','printshop-mobile','font-size','12',0,''),(46093,14578,'120128','printshop-mobile','padding-top','20',0,''),(46094,14578,'120128','printshop-mobile','padding-bottom','20',0,''),(46095,14578,'120128','printshop-mobile','color','#424242',0,''),(46096,14579,'120129','printshop-mobile','block_type','5',0,''),(46097,14579,'120129','printshop-mobile','font-weight','normal',0,''),(46098,14579,'120129','printshop-mobile','border-bottom-width','1',0,''),(46099,14579,'120129','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(46100,14579,'120129','printshop-mobile','border-top-width','1',0,''),(46101,14579,'120129','printshop-mobile','border-top-color','#e0e0e0',0,''),(46102,14579,'120129','printshop-mobile','border-left-color','#e0e0e0',0,''),(46103,14579,'120129','printshop-mobile','border-left-width','1',0,''),(46104,14580,'120130','printshop-mobile','block_type','1',0,''),(46105,14580,'120130','printshop-mobile','font-weight','normal',0,''),(46106,14580,'120130','printshop-mobile','padding-top','10',0,''),(46107,14580,'120130','printshop-mobile','padding-left','10',0,''),(46108,14580,'120130','printshop-mobile','padding-right','10',0,''),(46109,14581,'120131','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(46110,14581,'120131','printshop-mobile','font-size','14',0,''),(46111,14581,'120131','printshop-mobile','font-weight','bold',0,''),(46112,14581,'120131','printshop-mobile','padding-bottom','10',0,''),(46113,14582,'120132','printshop-mobile','font-weight','400',0,''),(46114,14582,'120132','printshop-mobile','line-height','120',0,''),(46115,14582,'120132','printshop-mobile','line_height_measure','%',0,''),(46116,14582,'120132','printshop-mobile','font-size','12',0,''),(46117,14583,'120133','printshop-mobile','block_type','4',0,''),(46118,14583,'120133','printshop-mobile','font-weight','normal',0,''),(46119,14583,'120133','printshop-mobile','border-top-width','1',0,''),(46120,14583,'120133','printshop-mobile','border-top-color','#e0e0e0',0,''),(46121,14583,'120133','printshop-mobile','border-left-width','1',0,''),(46122,14583,'120133','printshop-mobile','border-left-color','#e0e0e0',0,''),(46123,14583,'120133','printshop-mobile','border-right-width','1',0,''),(46124,14583,'120133','printshop-mobile','border-right-color','#e0e0e0',0,''),(46125,14583,'120133','printshop-mobile','border-bottom-width','1',0,''),(46126,14583,'120133','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(46127,14584,'120134','printshop-mobile','block_type','2',0,''),(46128,14584,'120134','printshop-mobile','font-weight','normal',0,''),(46129,14584,'120134','printshop-mobile','border-right-width','1',0,''),(46130,14584,'120134','printshop-mobile','border-right-color','#e0e0e0',0,''),(46131,14585,'120135','printshop-mobile','block_type','1',0,''),(46132,14585,'120135','printshop-mobile','font-weight','400',0,''),(46133,14585,'120135','printshop-mobile','background-color','#eeeeee',0,''),(46134,14585,'120135','printshop-mobile','padding-top','10',0,''),(46135,14585,'120135','printshop-mobile','padding-left','10',0,''),(46136,14585,'120135','printshop-mobile','padding-right','10',0,''),(46137,14585,'120135','printshop-mobile','padding-bottom','30',0,''),(46138,14586,'120136','printshop-mobile','text','<p>ADDRESS:</p>\n',1,''),(46139,14586,'120136','printshop-mobile','font-size','14',0,''),(46140,14586,'120136','printshop-mobile','font-weight','bold',0,''),(46141,14587,'120137','printshop-mobile','font-size','12',0,''),(46142,14588,'120138','printshop-mobile','block_type','1',0,''),(46143,14588,'120138','printshop-mobile','font-weight','normal',0,''),(46144,14588,'120138','printshop-mobile','padding-top','10',0,''),(46145,14588,'120138','printshop-mobile','padding-left','10',0,''),(46146,14588,'120138','printshop-mobile','padding-right','10',0,''),(46147,14588,'120138','printshop-mobile','padding-bottom','10',0,''),(46148,14589,'120139','printshop-mobile','text','<p>CUSTOMER:</p>',1,''),(46149,14589,'120139','printshop-mobile','font-size','13',0,''),(46150,14589,'120139','printshop-mobile','font-weight','bold',0,''),(46151,14590,'120140','printshop-mobile','text','<p>PHONE NUMBER:</p>',1,''),(46152,14590,'120140','printshop-mobile','font-size','14',0,''),(46153,14590,'120140','printshop-mobile','font-weight','bold',0,''),(46154,14590,'120140','printshop-mobile','padding-top','10',0,''),(46155,14591,'120141','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(46156,14591,'120141','printshop-mobile','font-weight','bold',0,''),(46157,14591,'120141','printshop-mobile','font-size','14',0,''),(46158,14591,'120141','printshop-mobile','padding-top','10',0,''),(46159,14592,'120142','printshop-mobile','font-weight','normal',0,''),(46160,14593,'120143','printshop-mobile','font-weight','normal',0,''),(46161,14595,'120145','printshop-mobile','text','<p>Order date:</p>\n',1,''),(46162,14595,'120145','printshop-mobile','font-weight','bold',0,''),(46163,14595,'120145','printshop-mobile','text-align','center',0,''),(46164,14595,'120145','printshop-mobile','font-size','12',0,''),(46165,14596,'120146','printshop-mobile','font-weight','normal',0,''),(46166,14596,'120146','printshop-mobile','text-align','center',0,''),(46167,14596,'120146','printshop-mobile','padding-bottom','10',0,''),(46168,14597,'120147','printshop-mobile','font-size','14',0,''),(46169,14597,'120147','printshop-mobile','font-weight','bold',0,''),(46170,14597,'120147','printshop-mobile','text-align','center',0,''),(46171,14597,'120147','printshop-mobile','padding-bottom','10',0,''),(46172,14597,'120147','printshop-mobile','padding-top','10',0,''),(46173,14598,'120148','printshop-mobile','block_type','2',0,''),(46174,14598,'120148','printshop-mobile','font-weight','normal',0,''),(46175,14598,'120148','printshop-mobile','padding-bottom','20',0,''),(46176,14599,'120149','printshop-mobile','font-weight','400',0,''),(46177,14599,'120149','printshop-mobile','padding-top','20',0,''),(46179,14600,'120150','printshop-mobile','block_type','1',0,''),(46180,14601,'120151','printshop-mobile','font-weight','normal',0,''),(46181,14601,'120151','printshop-mobile','text-align','right',0,''),(46182,14601,'120151','printshop-mobile','padding-bottom','10',0,''),(46183,14601,'120151','printshop-mobile','address_spacer',',',0,''),(46184,14601,'120151','printshop-mobile','font-size','12',0,''),(46185,14602,'120152','printshop-mobile','block_type','11',0,''),(46186,14602,'120152','printshop-mobile','font-weight','normal',0,''),(46187,14603,'120153','printshop-mobile','text','<p>Email:</p>',1,''),(46188,14603,'120153','printshop-mobile','font-weight','normal',0,''),(46189,14603,'120153','printshop-mobile','text-align','right',0,''),(46190,14604,'120154','printshop-mobile','font-weight','normal',0,''),(46191,14604,'120154','printshop-mobile','text-align','right',0,''),(46192,14605,'120155','printshop-mobile','block_type','11',0,''),(46193,14605,'120155','printshop-mobile','font-weight','normal',0,''),(46194,14606,'120156','printshop-mobile','text','<p>Web:</p>',1,''),(46195,14606,'120156','printshop-mobile','font-weight','normal',0,''),(46196,14606,'120156','printshop-mobile','text-align','right',0,''),(46197,14607,'120157','printshop-mobile','font-weight','normal',0,''),(46198,14607,'120157','printshop-mobile','text-align','right',0,''),(46199,14608,'120158','printshop-mobile','block_type','11',0,''),(46200,14608,'120158','printshop-mobile','font-weight','normal',0,''),(46201,14609,'120159','printshop-mobile','text','<p>Phone:</p>',1,''),(46202,14609,'120159','printshop-mobile','font-weight','normal',0,''),(46203,14609,'120159','printshop-mobile','text-align','right',0,''),(46204,14610,'120160','printshop-mobile','font-weight','normal',0,''),(46205,14610,'120160','printshop-mobile','text-align','right',0,''),(46206,14611,'120161','printshop-mobile','block_type','3',0,''),(46207,14611,'120161','printshop-mobile','font-weight','normal',0,''),(46208,14611,'120161','printshop-mobile','padding-top','20',0,''),(46209,14612,'120162','printshop-mobile','font-size','12',0,''),(46210,14613,'120163','printshop-mobile','text','<p>If undelivered please return to:</p>',1,''),(46211,14613,'120163','printshop-mobile','font-size','12',0,''),(46212,14613,'120163','printshop-mobile','font-weight','bold',0,''),(46213,14614,'120164','printshop-mobile','text','<p>Thank you for your order</p>',1,''),(46214,14614,'120164','printshop-mobile','color','#1da1f2',0,''),(46215,14614,'120164','printshop-mobile','font-size','13',0,''),(46216,14614,'120164','printshop-mobile','font-weight','bold',0,''),(46217,14614,'120164','printshop-mobile','padding-top','5',0,''),(46218,14614,'120164','printshop-mobile','text-align','center',0,''),(46219,14615,'120165','printshop-mobile','font-weight','400',0,''),(46220,14615,'120165','printshop-mobile','text-align','center',0,''),(46221,14615,'120165','printshop-mobile','padding-top','0',0,''),(46223,14615,'120165','printshop-mobile','padding-left','20',0,''),(46224,14615,'120165','printshop-mobile','padding-right','20',0,''),(46225,14616,'120166','printshop-mobile','block_type','6',0,''),(46226,14616,'120166','printshop-mobile','font-weight','normal',0,''),(46227,14616,'120166','printshop-mobile','font-size','16',0,''),(46228,14617,'120167','printshop-mobile','text','<p>Phone:</p>',1,''),(46229,14617,'120167','printshop-mobile','font-weight','normal',0,''),(46230,14617,'120167','printshop-mobile','text-align','right',0,''),(46231,14617,'120167','printshop-mobile','font-size','12',0,''),(46232,14618,'120168','printshop-mobile','font-weight','normal',0,''),(46233,14618,'120168','printshop-mobile','text-align','right',0,''),(46234,14618,'120168','printshop-mobile','font-size','12',0,''),(46235,14619,'120169','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(46236,14619,'120169','printshop-mobile','font-size','12',0,''),(46237,14619,'120169','printshop-mobile','font-weight','bold',0,''),(46238,14619,'120169','printshop-mobile','text-align','right',0,''),(46239,14620,'120170','printshop-mobile','block_type','6',0,''),(46240,14620,'120170','printshop-mobile','font-weight','normal',0,''),(46241,14620,'120170','printshop-mobile','font-size','16',0,''),(46242,14621,'120171','printshop-mobile','text','<p>Email:</p>',1,''),(46243,14621,'120171','printshop-mobile','font-weight','normal',0,''),(46244,14621,'120171','printshop-mobile','text-align','right',0,''),(46245,14621,'120171','printshop-mobile','font-size','12',0,''),(46246,14622,'120172','printshop-mobile','font-weight','normal',0,''),(46247,14622,'120172','printshop-mobile','text-align','right',0,''),(46248,14622,'120172','printshop-mobile','font-size','12',0,''),(46249,14623,'120173','printshop-mobile','font-weight','400',0,''),(46250,14623,'120173','printshop-mobile','padding-top','20',0,''),(46251,14623,'120173','printshop-mobile','padding-bottom','0',0,''),(46252,14623,'120173','printshop-mobile','font-size','12',0,''),(46253,14624,'120174','printshop-mobile','block_type','1',0,''),(46254,14625,'120175','printshop-mobile','block_type','6',0,''),(46255,14625,'120175','printshop-mobile','schema','6-3',0,'702'),(46256,14626,'120176','printshop-mobile','aria_name','account-menu',0,''),(46257,14627,'120177','printshop-mobile','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(46258,14628,'120178','printshop-mobile','link','Quotation Info',0,''),(46259,14628,'120178','printshop-mobile','margin-bottom','20',0,''),(46260,14629,'120179','printshop-mobile','block_type','1',0,''),(46261,14630,'120180','printshop-mobile','block_type','6',0,''),(46262,14630,'120180','printshop-mobile','schema','6-3',0,''),(46263,14630,'120180','printshop-mobile','schema','6-3',0,'702'),(46264,14631,'120181','printshop-mobile','aria_name','account-menu',0,''),(46265,14634,'120184','printshop-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(46266,14635,'120185','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(46267,14637,'120187','printshop-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(46268,14638,'120188','printshop-mobile','block_type','2',0,''),(46269,14638,'120188','printshop-mobile','padding-top','20',0,''),(46270,14638,'120188','printshop-mobile','margin-bottom','20',0,''),(46271,14639,'120189','printshop-mobile','like_button','1',0,''),(46272,14639,'120189','printshop-mobile','text','IMAGE_BUTTON_BACK',0,''),(46273,14639,'120189','printshop-mobile','link','Quotations',0,''),(46274,14640,'120190','printshop-mobile','block_type','3',0,''),(46275,14640,'120190','printshop-mobile','schema','3-4',0,'702'),(46276,14641,'120191','printshop-mobile','block_type','1',0,''),(46277,14641,'120191','printshop-mobile','padding-right','20',0,''),(46278,14641,'120191','printshop-mobile','padding-bottom','20',0,''),(46279,14642,'120192','printshop-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(46280,14643,'120193','printshop-mobile','orders_data','telephone',0,''),(46281,14644,'120194','printshop-mobile','block_type','1',0,''),(46282,14644,'120194','printshop-mobile','padding-right','20',0,''),(46283,14644,'120194','printshop-mobile','padding-bottom','20',0,''),(46284,14645,'120195','printshop-mobile','orders_data','name',0,''),(46285,14646,'120196','printshop-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(46286,14647,'120197','printshop-mobile','block_type','1',0,''),(46287,14647,'120197','printshop-mobile','padding-right','20',0,''),(46288,14648,'120198','printshop-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(46289,14649,'120199','printshop-mobile','orders_data','shipping_method',0,''),(46290,14650,'120200','printshop-mobile','block_type','1',0,''),(46291,14650,'120200','printshop-mobile','padding-right','20',0,''),(46292,14650,'120200','printshop-mobile','padding-bottom','20',0,''),(46293,14651,'120201','printshop-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(46294,14652,'120202','printshop-mobile','orders_data','delivery_address',0,''),(46295,14653,'120203','printshop-mobile','block_type','1',0,''),(46296,14653,'120203','printshop-mobile','padding-bottom','20',0,''),(46297,14654,'120204','printshop-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(46298,14655,'120205','printshop-mobile','orders_data','billing_address',0,''),(46299,14656,'120206','printshop-mobile','block_type','1',0,''),(46300,14657,'120207','printshop-mobile','orders_data','payment_method',0,''),(46301,14658,'120208','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(46302,14661,'120211','printshop-mobile','text','<h1>Quotations</h1>',1,''),(46303,14662,'120212','printshop-mobile','block_type','1',0,''),(46304,14663,'120213','printshop-mobile','block_type','6',0,''),(46305,14663,'120213','printshop-mobile','schema','6-3',0,''),(46306,14663,'120213','printshop-mobile','schema','6-3',0,'702'),(46307,14664,'120214','printshop-mobile','aria_name','account-menu',0,''),(46308,14665,'120215','printshop-mobile','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(46309,14666,'120216','printshop-mobile','margin-bottom','20',0,''),(46310,14667,'120217','printshop-mobile','block_type','1',0,''),(46311,14668,'120218','printshop-mobile','pagination','bottom',0,''),(46312,14670,'120220','printshop-mobile','width','800',0,''),(46313,14671,'120221','printshop-mobile','block_type','1',0,''),(46314,14671,'120221','printshop-mobile','border-top-width','1',0,''),(46315,14671,'120221','printshop-mobile','border-left-width','1',0,''),(46316,14671,'120221','printshop-mobile','border-right-width','1',0,''),(46317,14671,'120221','printshop-mobile','border-bottom-width','1',0,''),(46318,14671,'120221','printshop-mobile','border-top-color','#000000',0,''),(46319,14671,'120221','printshop-mobile','border-left-color','#000000',0,''),(46320,14671,'120221','printshop-mobile','border-right-color','#000000',0,''),(46321,14671,'120221','printshop-mobile','border-bottom-color','#000000',0,''),(46322,14672,'120222','printshop-mobile','block_type','11',0,''),(46323,14673,'120223','printshop-mobile','block_type','1',0,''),(46324,14673,'120223','printshop-mobile','padding-top','10',0,''),(46325,14673,'120223','printshop-mobile','padding-right','10',0,''),(46326,14673,'120223','printshop-mobile','padding-bottom','10',0,''),(46327,14673,'120223','printshop-mobile','border-right-width','1',0,''),(46328,14673,'120223','printshop-mobile','border-right-color','#000000',0,''),(46329,14674,'120224','printshop-mobile','block_type','1',0,''),(46330,14674,'120224','printshop-mobile','padding-left','10',0,''),(46331,14674,'120224','printshop-mobile','padding-right','10',0,''),(46332,14674,'120224','printshop-mobile','padding-bottom','10',0,''),(46333,14675,'120225','printshop-mobile','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(46334,14675,'120225','printshop-mobile','font-size','11',0,''),(46335,14675,'120225','printshop-mobile','font-style','italic',0,''),(46336,14676,'120226','printshop-mobile','block_type','9',0,''),(46337,14677,'120227','printshop-mobile','text','2.',0,''),(46338,14677,'120227','printshop-mobile','font-size','12',0,''),(46339,14677,'120227','printshop-mobile','text-align','right',0,''),(46340,14677,'120227','printshop-mobile','padding-right','5',0,''),(46341,14678,'120228','printshop-mobile','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(46342,14678,'120228','printshop-mobile','font-size','12',0,''),(46343,14678,'120228','printshop-mobile','padding-bottom','10',0,''),(46344,14679,'120229','printshop-mobile','block_type','1',0,''),(46345,14680,'120230','printshop-mobile','text','Shipping Instructions:',0,''),(46346,14680,'120230','printshop-mobile','font-weight','bold',0,''),(46347,14680,'120230','printshop-mobile','font-size','14',0,''),(46348,14680,'120230','printshop-mobile','padding-bottom','5',0,''),(46349,14680,'120230','printshop-mobile','padding-left','10',0,''),(46350,14681,'120231','printshop-mobile','block_type','9',0,''),(46351,14682,'120232','printshop-mobile','text','1.',0,''),(46352,14682,'120232','printshop-mobile','font-size','12',0,''),(46353,14682,'120232','printshop-mobile','text-align','right',0,''),(46354,14682,'120232','printshop-mobile','padding-right','5',0,''),(46355,14683,'120233','printshop-mobile','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(46356,14683,'120233','printshop-mobile','font-size','12',0,''),(46357,14683,'120233','printshop-mobile','padding-bottom','10',0,''),(46358,14684,'120234','printshop-mobile','block_type','9',0,''),(46359,14685,'120235','printshop-mobile','text','3.',0,''),(46360,14685,'120235','printshop-mobile','font-size','12',0,''),(46361,14685,'120235','printshop-mobile','text-align','right',0,''),(46362,14685,'120235','printshop-mobile','padding-right','5',0,''),(46363,14686,'120236','printshop-mobile','text','Ship only the items that are authorized.',0,''),(46364,14686,'120236','printshop-mobile','font-size','12',0,''),(46365,14686,'120236','printshop-mobile','padding-bottom','10',0,''),(46366,14687,'120237','printshop-mobile','block_type','9',0,''),(46367,14688,'120238','printshop-mobile','text','4.',0,''),(46368,14688,'120238','printshop-mobile','font-size','12',0,''),(46369,14688,'120238','printshop-mobile','text-align','right',0,''),(46370,14688,'120238','printshop-mobile','padding-right','5',0,''),(46371,14689,'120239','printshop-mobile','text','Ship returned items to:',0,''),(46372,14689,'120239','printshop-mobile','font-size','12',0,''),(46373,14689,'120239','printshop-mobile','padding-bottom','5',0,''),(46374,14690,'120240','printshop-mobile','font-size','11',0,''),(46375,14690,'120240','printshop-mobile','font-style','italic',0,''),(46376,14690,'120240','printshop-mobile','padding-bottom','5',0,''),(46377,14691,'120241','printshop-mobile','block_type','3',0,''),(46378,14691,'120241','printshop-mobile','padding-right','10',0,''),(46379,14692,'120242','printshop-mobile','text','Customer Signature:',0,''),(46380,14692,'120242','printshop-mobile','font-weight','bold',0,''),(46381,14692,'120242','printshop-mobile','font-size','11',0,''),(46382,14692,'120242','printshop-mobile','padding-top','5',0,''),(46383,14692,'120242','printshop-mobile','padding-left','10',0,''),(46384,14693,'120243','printshop-mobile','text','&nbsp;',0,''),(46385,14693,'120243','printshop-mobile','border-bottom-width','1',0,''),(46386,14693,'120243','printshop-mobile','border-bottom-color','#000000',0,''),(46387,14694,'120244','printshop-mobile','block_type','5',0,''),(46388,14695,'120245','printshop-mobile','text','Date:',0,''),(46389,14695,'120245','printshop-mobile','padding-top','5',0,''),(46390,14695,'120245','printshop-mobile','font-size','11',0,''),(46391,14695,'120245','printshop-mobile','font-weight','bold',0,''),(46392,14695,'120245','printshop-mobile','padding-left','5',0,''),(46393,14696,'120246','printshop-mobile','text','&nbsp;',0,''),(46394,14696,'120246','printshop-mobile','border-bottom-width','1',0,''),(46395,14696,'120246','printshop-mobile','border-bottom-color','#000000',0,''),(46396,14697,'120247','printshop-mobile','block_type','3',0,''),(46397,14697,'120247','printshop-mobile','padding-top','10',0,''),(46398,14697,'120247','printshop-mobile','padding-bottom','10',0,''),(46399,14697,'120247','printshop-mobile','padding-right','10',0,''),(46400,14698,'120248','printshop-mobile','font-size','11',0,''),(46401,14698,'120248','printshop-mobile','font-weight','bold',0,''),(46402,14698,'120248','printshop-mobile','text','Return Approval:',0,''),(46403,14698,'120248','printshop-mobile','padding-top','5',0,''),(46404,14698,'120248','printshop-mobile','padding-left','10',0,''),(46405,14699,'120249','printshop-mobile','border-bottom-width','1',0,''),(46406,14699,'120249','printshop-mobile','border-bottom-color','#000000',0,''),(46407,14699,'120249','printshop-mobile','text','&nbsp;',0,''),(46408,14700,'120250','printshop-mobile','block_type','5',0,''),(46409,14701,'120251','printshop-mobile','text','Date:',0,''),(46410,14701,'120251','printshop-mobile','padding-top','5',0,''),(46411,14701,'120251','printshop-mobile','font-size','11',0,''),(46412,14701,'120251','printshop-mobile','font-weight','bold',0,''),(46413,14701,'120251','printshop-mobile','padding-left','5',0,''),(46414,14702,'120252','printshop-mobile','text','&nbsp;',0,''),(46415,14702,'120252','printshop-mobile','border-bottom-width','1',0,''),(46416,14702,'120252','printshop-mobile','border-bottom-color','#000000',0,''),(46417,14703,'120253','printshop-mobile','block_type','1',0,''),(46418,14703,'120253','printshop-mobile','padding-left','10',0,''),(46419,14703,'120253','printshop-mobile','padding-right','10',0,''),(46420,14703,'120253','printshop-mobile','padding-bottom','10',0,''),(46421,14704,'120254','printshop-mobile','text','Use this space for additional Comments:',0,''),(46422,14704,'120254','printshop-mobile','font-size','11',0,''),(46423,14704,'120254','printshop-mobile','font-style','italic',0,''),(46424,14705,'120255','printshop-mobile','text','&nbsp;',0,''),(46425,14705,'120255','printshop-mobile','border-bottom-width','1',0,''),(46426,14705,'120255','printshop-mobile','border-bottom-color','#000000',0,''),(46427,14706,'120256','printshop-mobile','text','&nbsp;',0,''),(46428,14706,'120256','printshop-mobile','border-bottom-width','1',0,''),(46429,14706,'120256','printshop-mobile','border-bottom-color','#000000',0,''),(46430,14706,'120256','printshop-mobile','padding-top','5',0,''),(46431,14707,'120257','printshop-mobile','text','&nbsp;',0,''),(46432,14707,'120257','printshop-mobile','border-bottom-width','1',0,''),(46433,14707,'120257','printshop-mobile','border-bottom-color','#000000',0,''),(46434,14707,'120257','printshop-mobile','padding-top','5',0,''),(46435,14708,'120258','printshop-mobile','text','&nbsp;',0,''),(46436,14708,'120258','printshop-mobile','border-bottom-width','1',0,''),(46437,14708,'120258','printshop-mobile','border-bottom-color','#000000',0,''),(46438,14708,'120258','printshop-mobile','padding-top','5',0,''),(46439,14709,'120259','printshop-mobile','block_type','1',0,''),(46440,14709,'120259','printshop-mobile','padding-top','10',0,''),(46441,14709,'120259','printshop-mobile','padding-left','40',0,''),(46442,14709,'120259','printshop-mobile','padding-right','40',0,''),(46443,14709,'120259','printshop-mobile','padding-bottom','10',0,''),(46444,14710,'120260','printshop-mobile','block_type','1',0,''),(46445,14710,'120260','printshop-mobile','padding-top','10',0,''),(46446,14710,'120260','printshop-mobile','padding-left','10',0,''),(46447,14710,'120260','printshop-mobile','padding-right','10',0,''),(46448,14710,'120260','printshop-mobile','padding-bottom','10',0,''),(46449,14710,'120260','printshop-mobile','border-top-width','1',0,''),(46450,14710,'120260','printshop-mobile','border-left-width','1',0,''),(46451,14710,'120260','printshop-mobile','border-right-width','1',0,''),(46452,14710,'120260','printshop-mobile','border-bottom-width','1',0,''),(46453,14710,'120260','printshop-mobile','border-top-color','#000000',0,''),(46454,14710,'120260','printshop-mobile','border-left-color','#000000',0,''),(46455,14710,'120260','printshop-mobile','border-right-color','#000000',0,''),(46456,14710,'120260','printshop-mobile','border-bottom-color','#000000',0,''),(46457,14711,'120261','printshop-mobile','block_type','3',0,''),(46458,14712,'120262','printshop-mobile','data','rrDelivery_name',0,''),(46459,14712,'120262','printshop-mobile','font-size','9',0,''),(46460,14713,'120263','printshop-mobile','block_type','2',0,''),(46461,14714,'120264','printshop-mobile','text','RMA#:',0,''),(46462,14714,'120264','printshop-mobile','font-size','10',0,''),(46463,14715,'120265','printshop-mobile','data','rrNumber',0,''),(46464,14715,'120265','printshop-mobile','font-size','9',0,''),(46465,14716,'120266','printshop-mobile','block_type','5',0,''),(46466,14717,'120267','printshop-mobile','font-size','9',0,''),(46467,14718,'120268','printshop-mobile','block_type','1',0,''),(46468,14720,'120270','printshop-mobile','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(46469,14720,'120270','printshop-mobile','font-size','12',0,''),(46470,14720,'120270','printshop-mobile','font-style','italic',0,''),(46471,14720,'120270','printshop-mobile','padding-bottom','20',0,''),(46472,14721,'120271','printshop-mobile','block_type','11',0,''),(46473,14721,'120271','printshop-mobile','border-top-width','1',0,''),(46474,14721,'120271','printshop-mobile','border-left-width','1',0,''),(46475,14721,'120271','printshop-mobile','border-right-width','1',0,''),(46476,14721,'120271','printshop-mobile','border-bottom-width','1',0,''),(46477,14721,'120271','printshop-mobile','border-top-color','#000000',0,''),(46478,14721,'120271','printshop-mobile','border-left-color','#000000',0,''),(46479,14721,'120271','printshop-mobile','border-right-color','#000000',0,''),(46480,14721,'120271','printshop-mobile','border-bottom-color','#000000',0,''),(46481,14722,'120272','printshop-mobile','block_type','1',0,''),(46482,14722,'120272','printshop-mobile','border-right-width','1',0,''),(46483,14722,'120272','printshop-mobile','border-right-color','#000000',0,''),(46484,14722,'120272','printshop-mobile','padding-top','10',0,''),(46485,14722,'120272','printshop-mobile','padding-right','10',0,''),(46486,14722,'120272','printshop-mobile','padding-bottom','10',0,''),(46487,14723,'120273','printshop-mobile','block_type','1',0,''),(46488,14723,'120273','printshop-mobile','padding-left','15',0,''),(46489,14724,'120274','printshop-mobile','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(46490,14724,'120274','printshop-mobile','font-size','11',0,''),(46491,14724,'120274','printshop-mobile','font-style','italic',0,''),(46492,14724,'120274','printshop-mobile','padding-bottom','5',0,''),(46493,14725,'120275','printshop-mobile','text','Replacement Policy:',0,''),(46494,14725,'120275','printshop-mobile','font-size','14',0,''),(46495,14725,'120275','printshop-mobile','padding-bottom','5',0,''),(46496,14725,'120275','printshop-mobile','font-weight','bold',0,''),(46497,14726,'120276','printshop-mobile','block_type','9',0,''),(46498,14727,'120277','printshop-mobile','text','2.',0,''),(46499,14727,'120277','printshop-mobile','font-size','12',0,''),(46500,14727,'120277','printshop-mobile','text-align','right',0,''),(46501,14727,'120277','printshop-mobile','margin-right','5',0,''),(46502,14728,'120278','printshop-mobile','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(46503,14728,'120278','printshop-mobile','font-size','12',0,''),(46504,14728,'120278','printshop-mobile','padding-bottom','5',0,''),(46505,14729,'120279','printshop-mobile','block_type','9',0,''),(46506,14730,'120280','printshop-mobile','text','1.',0,''),(46507,14730,'120280','printshop-mobile','font-size','12',0,''),(46508,14730,'120280','printshop-mobile','text-align','right',0,''),(46509,14730,'120280','printshop-mobile','padding-right','5',0,''),(46510,14731,'120281','printshop-mobile','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(46511,14731,'120281','printshop-mobile','font-size','12',0,''),(46512,14731,'120281','printshop-mobile','padding-bottom','5',0,''),(46513,14732,'120282','printshop-mobile','block_type','9',0,''),(46514,14733,'120283','printshop-mobile','text','3.',0,''),(46515,14733,'120283','printshop-mobile','font-size','12',0,''),(46516,14733,'120283','printshop-mobile','text-align','right',0,''),(46517,14733,'120283','printshop-mobile','margin-right','5',0,''),(46518,14734,'120284','printshop-mobile','text','Return the authorized item(s) per shipping instructions.',0,''),(46519,14734,'120284','printshop-mobile','font-size','12',0,''),(46520,14734,'120284','printshop-mobile','padding-bottom','5',0,''),(46521,14735,'120285','printshop-mobile','block_type','9',0,''),(46522,14736,'120286','printshop-mobile','text','4.',0,''),(46523,14736,'120286','printshop-mobile','font-size','12',0,''),(46524,14736,'120286','printshop-mobile','text-align','right',0,''),(46525,14736,'120286','printshop-mobile','margin-right','5',0,''),(46526,14737,'120287','printshop-mobile','text','Our Replacement Department will process your request.',0,''),(46527,14737,'120287','printshop-mobile','font-size','12',0,''),(46528,14737,'120287','printshop-mobile','padding-bottom','5',0,''),(46529,14738,'120288','printshop-mobile','block_type','2',0,''),(46530,14738,'120288','printshop-mobile','padding-left','10',0,''),(46531,14738,'120288','printshop-mobile','padding-top','20',0,''),(46532,14738,'120288','printshop-mobile','padding-right','10',0,''),(46533,14739,'120289','printshop-mobile','block_type','5',0,''),(46534,14740,'120290','printshop-mobile','text','RMA No:',0,''),(46535,14740,'120290','printshop-mobile','font-size','12',0,''),(46536,14740,'120290','printshop-mobile','font-weight','bold',0,''),(46537,14741,'120291','printshop-mobile','data','rrNumber',0,''),(46538,14741,'120291','printshop-mobile','font-size','12',0,''),(46539,14741,'120291','printshop-mobile','font-weight','bold',0,''),(46540,14742,'120292','printshop-mobile','block_type','2',0,''),(46541,14743,'120293','printshop-mobile','text','Date Issued:',0,''),(46542,14743,'120293','printshop-mobile','font-size','12',0,''),(46543,14743,'120293','printshop-mobile','font-weight','bold',0,''),(46544,14744,'120294','printshop-mobile','data','rrDateCreate',0,''),(46545,14744,'120294','printshop-mobile','font-size','12',0,''),(46546,14744,'120294','printshop-mobile','font-weight','bold',0,''),(46547,14745,'120295','printshop-mobile','block_type','1',0,''),(46548,14745,'120295','printshop-mobile','padding-top','10',0,''),(46549,14745,'120295','printshop-mobile','padding-left','10',0,''),(46550,14745,'120295','printshop-mobile','padding-right','10',0,''),(46551,14745,'120295','printshop-mobile','padding-bottom','10',0,''),(46552,14746,'120296','printshop-mobile','block_type','2',0,''),(46553,14747,'120297','printshop-mobile','block_type','11',0,''),(46554,14748,'120298','printshop-mobile','text','Company:',0,''),(46555,14748,'120298','printshop-mobile','font-size','12',0,''),(46556,14749,'120299','printshop-mobile','data','rrDelivery_company',0,''),(46557,14749,'120299','printshop-mobile','font-size','12',0,''),(46558,14750,'120300','printshop-mobile','block_type','2',0,''),(46559,14751,'120301','printshop-mobile','text','Contact Name:',0,''),(46560,14751,'120301','printshop-mobile','font-size','12',0,''),(46561,14752,'120302','printshop-mobile','data','rrDelivery_name',0,''),(46562,14752,'120302','printshop-mobile','font-size','12',0,''),(46563,14753,'120303','printshop-mobile','block_type','9',0,''),(46564,14753,'120303','printshop-mobile','padding-top','5',0,''),(46565,14754,'120304','printshop-mobile','text','Address:',0,''),(46566,14754,'120304','printshop-mobile','font-size','12',0,''),(46567,14755,'120305','printshop-mobile','data','rrDelivery_street_address',0,''),(46568,14755,'120305','printshop-mobile','font-size','12',0,''),(46569,14756,'120306','printshop-mobile','block_type','2',0,''),(46570,14756,'120306','printshop-mobile','padding-top','5',0,''),(46571,14757,'120307','printshop-mobile','block_type','11',0,''),(46572,14758,'120308','printshop-mobile','text','City:',0,''),(46573,14758,'120308','printshop-mobile','font-size','12',0,''),(46574,14759,'120309','printshop-mobile','data','rrDelivery_city',0,''),(46575,14759,'120309','printshop-mobile','font-size','12',0,''),(46576,14760,'120310','printshop-mobile','block_type','11',0,''),(46577,14761,'120311','printshop-mobile','text','State:',0,''),(46578,14761,'120311','printshop-mobile','font-size','12',0,''),(46579,14762,'120312','printshop-mobile','data','rrDelivery_state',0,''),(46580,14762,'120312','printshop-mobile','font-size','12',0,''),(46581,14763,'120313','printshop-mobile','block_type','2',0,''),(46582,14763,'120313','printshop-mobile','padding-top','5',0,''),(46583,14764,'120314','printshop-mobile','block_type','11',0,''),(46584,14765,'120315','printshop-mobile','text','Country:',0,''),(46585,14765,'120315','printshop-mobile','font-size','12',0,''),(46586,14766,'120316','printshop-mobile','data','rrDelivery_country',0,''),(46587,14766,'120316','printshop-mobile','font-size','12',0,''),(46588,14767,'120317','printshop-mobile','block_type','11',0,''),(46589,14768,'120318','printshop-mobile','text','Postcode:',0,''),(46590,14768,'120318','printshop-mobile','font-size','12',0,''),(46591,14769,'120319','printshop-mobile','data','rrDelivery_postcode',0,''),(46592,14769,'120319','printshop-mobile','font-size','12',0,''),(46593,14770,'120320','printshop-mobile','block_type','2',0,''),(46594,14770,'120320','printshop-mobile','padding-top','5',0,''),(46595,14771,'120321','printshop-mobile','block_type','11',0,''),(46596,14772,'120322','printshop-mobile','text','Email:',0,''),(46597,14772,'120322','printshop-mobile','font-size','12',0,''),(46598,14773,'120323','printshop-mobile','data','rrDelivery_email_address',0,''),(46599,14773,'120323','printshop-mobile','font-size','12',0,''),(46600,14774,'120324','printshop-mobile','block_type','11',0,''),(46601,14775,'120325','printshop-mobile','text','Phone:',0,''),(46602,14775,'120325','printshop-mobile','font-size','12',0,''),(46603,14776,'120326','printshop-mobile','data','rrDelivery_telephone',0,''),(46604,14776,'120326','printshop-mobile','font-size','12',0,''),(46605,14777,'120327','printshop-mobile','block_type','1',0,''),(46606,14777,'120327','printshop-mobile','border-bottom-width','1',0,''),(46607,14777,'120327','printshop-mobile','border-bottom-color','#000000',0,''),(46608,14778,'120328','printshop-mobile','text-align','center',0,''),(46609,14778,'120328','printshop-mobile','logo','themes/printshop-mobile/img/Furntech-1.jpg',1,''),(46610,14778,'120328','printshop-mobile','padding-top','10',0,''),(46611,14778,'120328','printshop-mobile','padding-bottom','10',0,''),(46612,14779,'120329','printshop-mobile','text','Return Material Authorization (RMA) Form',0,''),(46613,14779,'120329','printshop-mobile','text-align','center',0,''),(46614,14779,'120329','printshop-mobile','font-size','12',0,''),(46615,14779,'120329','printshop-mobile','font-weight','bold',0,''),(46616,14779,'120329','printshop-mobile','font-family','Arial',0,''),(46617,14780,'120330','printshop-mobile','block_type','1',0,''),(46618,14780,'120330','printshop-mobile','style_class','item-holder',0,''),(46619,14780,'120330','printshop-mobile','padding-top','25',0,''),(46620,14780,'120330','printshop-mobile','padding-bottom','25',0,''),(46621,14780,'120330','printshop-mobile','text-align','left',0,''),(46622,14780,'120330','printshop-mobile','border-top-width','1',0,''),(46623,14780,'120330','printshop-mobile','border-top-color','#e0e0e0',0,''),(46624,14781,'120331','printshop-mobile','block_type','7',0,''),(46625,14781,'120331','printshop-mobile','schema','7-2',0,''),(46626,14782,'120332','printshop-mobile','block_type','5',0,''),(46627,14782,'120332','printshop-mobile','schema','5-2',0,''),(46628,14783,'120333','printshop-mobile','block_type','1',0,''),(46629,14784,'120334','printshop-mobile','text-align','right',0,''),(46630,14784,'120334','printshop-mobile','margin-top','4',0,''),(46631,14784,'120334','printshop-mobile','margin-bottom','7',0,''),(46632,14784,'120334','printshop-mobile','float','left',0,''),(46633,14785,'120335','printshop-mobile','padding-top','6',0,''),(46634,14785,'120335','printshop-mobile','padding-left','5',0,''),(46635,14785,'120335','printshop-mobile','float','left',0,''),(46636,14785,'120335','printshop-mobile','clear','none',0,''),(46637,14786,'120336','printshop-mobile','clear','none',0,''),(46638,14786,'120336','printshop-mobile','padding-right','20',0,''),(46639,14787,'120337','printshop-mobile','padding-right','20',0,''),(46640,14787,'120337','printshop-mobile','max-width','300',0,''),(46641,14787,'120337','printshop-mobile','margin_left_measure','auto',0,''),(46642,14787,'120337','printshop-mobile','margin_right_measure','auto',0,''),(46643,14788,'120338','printshop-mobile','clear','none',0,''),(46644,14789,'120339','printshop-mobile','padding-right','20',0,''),(46645,14790,'120340','printshop-mobile','description_characters','200',0,''),(46646,14790,'120340','printshop-mobile','clear','none',0,''),(46647,14790,'120340','printshop-mobile','padding-right','20',0,''),(46648,14791,'120341','printshop-mobile','margin-bottom','20',0,''),(46649,14792,'120342','printshop-mobile','block_type','1',0,''),(46650,14792,'120342','printshop-mobile','padding-left','40',0,''),(46651,14792,'120342','printshop-mobile','style_class','right-aria',0,''),(46653,14793,'120343','printshop-mobile','text-align','right',0,''),(46654,14793,'120343','printshop-mobile','margin-bottom','10',0,''),(46655,14794,'120344','printshop-mobile','margin-bottom','10',0,''),(46656,14794,'120344','printshop-mobile','text-align','right',0,''),(46657,14796,'120346','printshop-mobile','margin-bottom','15',0,''),(46658,14796,'120346','printshop-mobile','text-align','right',0,''),(46659,14797,'120347','printshop-mobile','margin-bottom','10',0,''),(46660,14798,'120348','printshop-mobile','text-align','right',0,''),(46661,14798,'120348','printshop-mobile','margin-bottom','15',0,''),(46662,14799,'120349','printshop-mobile','block_type','1',0,''),(46663,14800,'120350','printshop-mobile','padding-bottom','20',0,''),(46664,14801,'120351','printshop-mobile','text-align','right',0,''),(46665,14801,'120351','printshop-mobile','margin-bottom','40',0,''),(46666,14802,'120352','printshop-mobile','text','<h1>Samples</h1>',1,''),(46667,14803,'120353','printshop-mobile','block_type','1',0,''),(46668,14804,'120354','printshop-mobile','block_type','6',0,''),(46669,14804,'120354','printshop-mobile','schema','6-3',0,''),(46670,14804,'120354','printshop-mobile','schema','6-3',0,'702'),(46671,14805,'120355','printshop-mobile','aria_name','account-menu',0,''),(46672,14806,'120356','printshop-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(46673,14807,'120357','printshop-mobile','show_pagenation','1',0,''),(46674,14807,'120357','printshop-mobile','link','Sample Info',0,''),(46675,14807,'120357','printshop-mobile','margin-bottom','20',0,''),(46676,14808,'120358','printshop-mobile','block_type','1',0,''),(46677,14809,'120359','printshop-mobile','block_type','6',0,''),(46678,14810,'120360','printshop-mobile','aria_name','account-menu',0,''),(46679,14811,'120361','printshop-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(46680,14812,'120362','printshop-mobile','block_type','3',0,''),(46681,14813,'120363','printshop-mobile','block_type','1',0,''),(46682,14813,'120363','printshop-mobile','padding-right','20',0,''),(46683,14813,'120363','printshop-mobile','padding-bottom','20',0,''),(46684,14814,'120364','printshop-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(46685,14815,'120365','printshop-mobile','orders_data','telephone',0,''),(46686,14816,'120366','printshop-mobile','block_type','1',0,''),(46687,14816,'120366','printshop-mobile','padding-right','20',0,''),(46688,14816,'120366','printshop-mobile','padding-bottom','20',0,''),(46689,14817,'120367','printshop-mobile','orders_data','name',0,''),(46690,14818,'120368','printshop-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(46691,14819,'120369','printshop-mobile','block_type','1',0,''),(46692,14819,'120369','printshop-mobile','padding-right','20',0,''),(46693,14819,'120369','printshop-mobile','padding-bottom','20',0,''),(46694,14820,'120370','printshop-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(46695,14821,'120371','printshop-mobile','orders_data','delivery_address',0,''),(46696,14822,'120372','printshop-mobile','block_type','1',0,''),(46697,14822,'120372','printshop-mobile','padding-right','20',0,''),(46698,14823,'120373','printshop-mobile','orders_data','shipping_method',0,''),(46699,14824,'120374','printshop-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(46700,14825,'120375','printshop-mobile','block_type','1',0,''),(46701,14825,'120375','printshop-mobile','padding-bottom','20',0,''),(46702,14826,'120376','printshop-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(46703,14827,'120377','printshop-mobile','orders_data','billing_address',0,''),(46704,14828,'120378','printshop-mobile','block_type','1',0,''),(46705,14829,'120379','printshop-mobile','orders_data','payment_method',0,''),(46706,14830,'120380','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(46707,14831,'120381','printshop-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(46708,14834,'120384','printshop-mobile','block_type','2',0,''),(46709,14834,'120384','printshop-mobile','padding-top','20',0,''),(46710,14834,'120384','printshop-mobile','margin-bottom','20',0,''),(46711,14835,'120385','printshop-mobile','like_button','1',0,''),(46712,14835,'120385','printshop-mobile','text','IMAGE_BUTTON_BACK',0,''),(46713,14835,'120385','printshop-mobile','link','Samples',0,''),(46714,14837,'120387','printshop-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(46715,14838,'120388','printshop-mobile','block_type','1',0,''),(46716,14839,'120389','printshop-mobile','block_type','6',0,''),(46717,14839,'120389','printshop-mobile','schema','6-3',0,''),(46718,14839,'120389','printshop-mobile','schema','6-3',0,'702'),(46719,14840,'120390','printshop-mobile','aria_name','account-menu',0,''),(46720,14841,'120391','printshop-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(46721,14842,'120392','printshop-mobile','link','Order History Info',0,''),(46722,14842,'120392','printshop-mobile','text','TEXT_VIEW',0,''),(46723,14842,'120392','printshop-mobile','max_orders','3',0,''),(46724,14842,'120392','printshop-mobile','link_pay','Order pay',0,''),(46725,14842,'120392','printshop-mobile','margin-bottom','30',0,''),(46726,14842,'120392','printshop-mobile','text_pay','ORDER_PAY',0,''),(46727,14843,'120393','printshop-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(46728,14844,'120394','printshop-mobile','block_type','15',0,''),(46729,14844,'120394','printshop-mobile','margin-bottom','30',0,''),(46730,14844,'120394','printshop-mobile','padding-top','20',0,''),(46731,14844,'120394','printshop-mobile','padding-left','20',0,''),(46732,14844,'120394','printshop-mobile','padding-right','20',0,''),(46733,14844,'120394','printshop-mobile','padding-bottom','20',0,''),(46734,14844,'120394','printshop-mobile','border-top-width','1',0,''),(46735,14844,'120394','printshop-mobile','border-top-color','#e0e0e0',0,''),(46736,14844,'120394','printshop-mobile','border-left-width','1',0,''),(46737,14844,'120394','printshop-mobile','border-right-width','1',0,''),(46738,14844,'120394','printshop-mobile','border-bottom-width','1',0,''),(46739,14844,'120394','printshop-mobile','border-left-color','#e0e0e0',0,''),(46740,14844,'120394','printshop-mobile','border-right-color','#e0e0e0',0,''),(46741,14844,'120394','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(46742,14844,'120394','printshop-mobile','schema','15-2',0,'702'),(46743,14845,'120395','printshop-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(46744,14845,'120395','printshop-mobile','font-family','trueloaded',0,'3'),(46745,14845,'120395','printshop-mobile','content','\\e920',0,'3'),(46746,14845,'120395','printshop-mobile','color','#ee4225',0,'3'),(46747,14845,'120395','printshop-mobile','font-size','30',0,'3'),(46748,14845,'120395','printshop-mobile','text-align','center',0,'3'),(46749,14845,'120395','printshop-mobile','margin-bottom','10',0,'3'),(46750,14845,'120395','printshop-mobile','text-align','center',0,''),(46751,14845,'120395','printshop-mobile','font-size','16',0,''),(46752,14845,'120395','printshop-mobile','text-transform','uppercase',0,''),(46753,14845,'120395','printshop-mobile','line-height','1',0,'3'),(46755,14846,'120396','printshop-mobile','font-family','Varela Round',0,''),(46756,14846,'120396','printshop-mobile','color','#ee4225',0,''),(46757,14846,'120396','printshop-mobile','font-size','14',0,''),(46758,14846,'120396','printshop-mobile','text-align','center',0,''),(46759,14847,'120397','printshop-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(46760,14847,'120397','printshop-mobile','font-family','trueloaded',0,'3'),(46761,14847,'120397','printshop-mobile','content','\\e928',0,'3'),(46762,14847,'120397','printshop-mobile','color','#ee4225',0,'3'),(46763,14847,'120397','printshop-mobile','font-size','30',0,'3'),(46764,14847,'120397','printshop-mobile','text-align','center',0,'3'),(46765,14847,'120397','printshop-mobile','text-align','center',0,''),(46766,14847,'120397','printshop-mobile','font-size','16',0,''),(46767,14847,'120397','printshop-mobile','text-transform','uppercase',0,''),(46768,14847,'120397','printshop-mobile','line-height','1',0,'3'),(46770,14848,'120398','printshop-mobile','link','download_orders',0,''),(46771,14848,'120398','printshop-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(46772,14848,'120398','printshop-mobile','hide_link','orders',0,''),(46773,14848,'120398','printshop-mobile','text-align','center',0,''),(46774,14848,'120398','printshop-mobile','popup','2',0,''),(46775,14848,'120398','printshop-mobile','font-size','14',0,''),(46776,14849,'120399','printshop-mobile','font-family','Varela Round',0,''),(46777,14849,'120399','printshop-mobile','color','#ee4225',0,''),(46778,14849,'120399','printshop-mobile','font-size','14',0,''),(46779,14849,'120399','printshop-mobile','text-align','center',0,''),(46780,14850,'120400','printshop-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(46781,14850,'120400','printshop-mobile','font-family','trueloaded',0,'3'),(46782,14850,'120400','printshop-mobile','content','\\e922',0,'3'),(46783,14850,'120400','printshop-mobile','color','#ee4225',0,'3'),(46784,14850,'120400','printshop-mobile','font-size','30',0,'3'),(46785,14850,'120400','printshop-mobile','line-height','1',0,'3'),(46786,14850,'120400','printshop-mobile','font-size','16',0,''),(46787,14850,'120400','printshop-mobile','text-align','center',0,''),(46788,14850,'120400','printshop-mobile','text-transform','uppercase',0,''),(46790,14851,'120401','printshop-mobile','font-family','Varela Round',0,''),(46791,14851,'120401','printshop-mobile','color','#ee4225',0,''),(46792,14851,'120401','printshop-mobile','line-height','1',0,''),(46793,14851,'120401','printshop-mobile','text-align','center',0,''),(46794,14851,'120401','printshop-mobile','font-size','14',0,''),(46795,14852,'120402','printshop-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(46796,14852,'120402','printshop-mobile','content','\\e994',0,'3'),(46797,14852,'120402','printshop-mobile','font-family','trueloaded',0,'3'),(46798,14852,'120402','printshop-mobile','color','#ee4225',0,'3'),(46799,14852,'120402','printshop-mobile','font-size','30',0,'3'),(46800,14852,'120402','printshop-mobile','line-height','1',0,'3'),(46801,14852,'120402','printshop-mobile','font-size','16',0,''),(46802,14852,'120402','printshop-mobile','text-align','center',0,''),(46803,14852,'120402','printshop-mobile','text-transform','uppercase',0,''),(46805,14853,'120403','printshop-mobile','link','Gift Certificate',0,''),(46806,14853,'120403','printshop-mobile','text','GIFT_CERTIFICATE',0,''),(46807,14853,'120403','printshop-mobile','popup','1',0,''),(46808,14853,'120403','printshop-mobile','text-align','center',0,''),(46809,14853,'120403','printshop-mobile','font-size','14',0,''),(46810,14854,'120404','printshop-mobile','font-family','Varela Round',0,''),(46811,14854,'120404','printshop-mobile','color','#ee4225',0,''),(46812,14854,'120404','printshop-mobile','font-size','14',0,''),(46813,14854,'120404','printshop-mobile','text-align','center',0,''),(46814,14855,'120405','printshop-mobile','text','TEXT_VIEW_HISTORY',0,''),(46815,14855,'120405','printshop-mobile','popup','1',0,''),(46816,14855,'120405','printshop-mobile','text-align','center',0,''),(46817,14855,'120405','printshop-mobile','link','Points Earnt History',0,''),(46818,14855,'120405','printshop-mobile','font-size','14',0,''),(46819,14856,'120406','printshop-mobile','font-family','Varela Round',0,''),(46820,14856,'120406','printshop-mobile','color','#ee4225',0,''),(46821,14856,'120406','printshop-mobile','font-size','14',0,''),(46822,14856,'120406','printshop-mobile','text-align','center',0,''),(46823,14857,'120407','printshop-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(46824,14857,'120407','printshop-mobile','content','\\e990',0,'3'),(46825,14857,'120407','printshop-mobile','font-family','trueloaded',0,'3'),(46826,14857,'120407','printshop-mobile','font-size','30',0,'3'),(46827,14857,'120407','printshop-mobile','text-align','center',0,'3'),(46828,14857,'120407','printshop-mobile','line-height','1',0,'3'),(46829,14857,'120407','printshop-mobile','color','#ee4225',0,'3'),(46830,14857,'120407','printshop-mobile','font-size','16',0,''),(46831,14857,'120407','printshop-mobile','text-align','center',0,''),(46832,14857,'120407','printshop-mobile','text-transform','uppercase',0,''),(46834,14858,'120408','printshop-mobile','block_type','1',0,''),(46835,14859,'120409','printshop-mobile','hide_parents','2',0,''),(46836,14860,'120410','printshop-mobile','text','<div class=\"heading-3\">##TEXT_GIFT_CARDS##</div>',0,''),(46837,14862,'120412','printshop-mobile','block_type','1',0,''),(46838,14863,'120413','printshop-mobile','block_type','6',0,''),(46839,14864,'120414','printshop-mobile','class','menu-simple',0,''),(46840,14866,'120416','printshop-mobile','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(46841,14868,'120418','printshop-mobile','text','<div class=\"heading-4\">Categories</div>',0,''),(46842,14869,'120419','printshop-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(46843,14870,'120420','printshop-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(46844,14872,'120422','printshop-mobile','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(46845,14873,'120423','printshop-mobile','block_type','1',0,''),(46846,14874,'120424','printshop-mobile','style_class','middle-form',0,''),(46847,14874,'120424','printshop-mobile','margin-bottom','30',0,''),(46848,14875,'120425','printshop-mobile','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(46849,14876,'120426','printshop-mobile','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(46850,14876,'120426','printshop-mobile','style_class','middle-form',0,''),(46851,14877,'120427','printshop-mobile','style_class','middle-form',0,''),(46852,14878,'120428','printshop-mobile','block_type','1',0,''),(46853,14879,'120429','printshop-mobile','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(46854,14879,'120429','printshop-mobile','padding-top','100',0,''),(46855,14879,'120429','printshop-mobile','margin-bottom','100',0,''),(46856,14879,'120429','printshop-mobile','text-align','center',0,''),(46857,14879,'120429','printshop-mobile','font-size','20',0,''),(46858,14880,'120430','printshop-mobile','block_type','1',0,''),(46859,14881,'120431','printshop-mobile','block_type','6',0,''),(46860,14881,'120431','printshop-mobile','schema','6-3',0,''),(46861,14881,'120431','printshop-mobile','schema','6-3',0,'702'),(46862,14882,'120432','printshop-mobile','aria_name','account-menu',0,''),(46863,14883,'120433','printshop-mobile','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(46864,14884,'120434','printshop-mobile','text','##SUBSCRIPTION_TEXT##',0,''),(46865,14886,'120436','printshop-mobile','block_type','1',0,''),(46866,14887,'120437','printshop-mobile','block_type','1',0,''),(46867,14887,'120437','printshop-mobile','font-weight','normal',0,''),(46868,14888,'120438','printshop-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',1,''),(46869,14888,'120438','printshop-mobile','font-weight','400',0,''),(46870,14889,'120439','printshop-mobile','block_type','3',0,''),(46871,14889,'120439','printshop-mobile','font-weight','400',0,''),(46872,14889,'120439','printshop-mobile','schema','3-4',0,'694'),(46873,14890,'120440','printshop-mobile','text','&nbsp;',0,''),(46874,14890,'120440','printshop-mobile','font-weight','normal',0,''),(46875,14891,'120441','printshop-mobile','font-weight','normal',0,''),(46876,14891,'120441','printshop-mobile','box_align','2',0,''),(46877,14891,'120441','printshop-mobile','padding-top','40',0,''),(46878,14892,'120442','printshop-mobile','font-weight','400',0,''),(46879,14892,'120442','printshop-mobile','text-align','right',0,''),(46880,14892,'120442','printshop-mobile','padding-top','40',0,''),(46881,14892,'120442','printshop-mobile','padding-bottom','100',0,''),(46882,14892,'120442','printshop-mobile','text-align','center',0,'694'),(46883,14892,'120442','printshop-mobile','float','none',0,'694'),(46884,14893,'120443','printshop-mobile','block_type','1',0,''),(46885,14894,'120444','printshop-mobile','block_type','1',0,''),(46886,14894,'120444','printshop-mobile','font-weight','normal',0,''),(46887,14895,'120445','printshop-mobile','block_type','1',0,''),(46888,14895,'120445','printshop-mobile','text-align','center',0,''),(46889,14895,'120445','printshop-mobile','padding-top','30',0,''),(46890,14895,'120445','printshop-mobile','margin-bottom','200',0,''),(46891,14896,'120446','printshop-mobile','display','inline-block',0,''),(46892,14897,'120447','printshop-mobile','display','inline-block',0,''),(46893,14897,'120447','printshop-mobile','clear','none',0,''),(46894,14897,'120447','printshop-mobile','margin-left','20',0,''),(46895,14898,'120448','printshop-mobile','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(46897,14902,'120452','printshop-mobile','width','680',0,''),(46898,14902,'120452','printshop-mobile','font-weight','normal',0,''),(46899,14902,'120452','printshop-mobile','font-size','12',0,''),(46900,14902,'120452','printshop-mobile','padding-top','20',0,''),(46901,14902,'120452','printshop-mobile','padding-bottom','20',0,''),(46902,14902,'120452','printshop-mobile','color','#424242',0,''),(46903,14903,'120453','printshop-mobile','block_type','2',0,''),(46904,14903,'120453','printshop-mobile','font-weight','normal',0,''),(46905,14903,'120453','printshop-mobile','padding-bottom','20',0,''),(46906,14904,'120454','printshop-mobile','block_type','1',0,''),(46907,14905,'120455','printshop-mobile','font-weight','normal',0,''),(46908,14905,'120455','printshop-mobile','text-align','right',0,''),(46909,14905,'120455','printshop-mobile','padding-bottom','10',0,''),(46910,14905,'120455','printshop-mobile','address_spacer',',',0,''),(46911,14905,'120455','printshop-mobile','font-size','12',0,''),(46912,14906,'120456','printshop-mobile','block_type','11',0,''),(46913,14906,'120456','printshop-mobile','font-weight','normal',0,''),(46914,14907,'120457','printshop-mobile','text','<p>Phone:</p>',1,''),(46915,14907,'120457','printshop-mobile','font-weight','normal',0,''),(46916,14907,'120457','printshop-mobile','text-align','right',0,''),(46917,14908,'120458','printshop-mobile','font-weight','normal',0,''),(46918,14908,'120458','printshop-mobile','text-align','right',0,''),(46919,14909,'120459','printshop-mobile','block_type','11',0,''),(46920,14909,'120459','printshop-mobile','font-weight','normal',0,''),(46921,14910,'120460','printshop-mobile','text','<p>Web:</p>',1,''),(46922,14910,'120460','printshop-mobile','font-weight','normal',0,''),(46923,14910,'120460','printshop-mobile','text-align','right',0,''),(46924,14911,'120461','printshop-mobile','font-weight','normal',0,''),(46925,14911,'120461','printshop-mobile','text-align','right',0,''),(46926,14912,'120462','printshop-mobile','block_type','11',0,''),(46927,14912,'120462','printshop-mobile','font-weight','normal',0,''),(46928,14913,'120463','printshop-mobile','text','<p>Email:</p>',1,''),(46929,14913,'120463','printshop-mobile','font-weight','normal',0,''),(46930,14913,'120463','printshop-mobile','text-align','right',0,''),(46931,14914,'120464','printshop-mobile','font-weight','normal',0,''),(46932,14914,'120464','printshop-mobile','text-align','right',0,''),(46933,14915,'120465','printshop-mobile','block_type','4',0,''),(46934,14915,'120465','printshop-mobile','font-weight','normal',0,''),(46935,14915,'120465','printshop-mobile','border-top-width','1',0,''),(46936,14915,'120465','printshop-mobile','border-top-color','#e0e0e0',0,''),(46937,14915,'120465','printshop-mobile','border-left-width','1',0,''),(46938,14915,'120465','printshop-mobile','border-left-color','#e0e0e0',0,''),(46939,14915,'120465','printshop-mobile','border-right-width','1',0,''),(46940,14915,'120465','printshop-mobile','border-right-color','#e0e0e0',0,''),(46941,14915,'120465','printshop-mobile','border-bottom-width','1',0,''),(46942,14915,'120465','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(46943,14916,'120466','printshop-mobile','block_type','2',0,''),(46944,14916,'120466','printshop-mobile','font-weight','normal',0,''),(46945,14916,'120466','printshop-mobile','border-right-width','1',0,''),(46946,14916,'120466','printshop-mobile','border-right-color','#e0e0e0',0,''),(46947,14917,'120467','printshop-mobile','block_type','1',0,''),(46948,14917,'120467','printshop-mobile','font-weight','400',0,''),(46949,14917,'120467','printshop-mobile','background-color','#eeeeee',0,''),(46950,14917,'120467','printshop-mobile','padding-top','10',0,''),(46951,14917,'120467','printshop-mobile','padding-left','10',0,''),(46952,14917,'120467','printshop-mobile','padding-right','10',0,''),(46953,14917,'120467','printshop-mobile','padding-bottom','30',0,''),(46954,14918,'120468','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(46955,14918,'120468','printshop-mobile','font-size','14',0,''),(46956,14918,'120468','printshop-mobile','font-weight','bold',0,''),(46957,14919,'120469','printshop-mobile','font-size','12',0,''),(46958,14920,'120470','printshop-mobile','block_type','1',0,''),(46959,14920,'120470','printshop-mobile','font-weight','normal',0,''),(46960,14920,'120470','printshop-mobile','padding-top','10',0,''),(46961,14920,'120470','printshop-mobile','padding-left','10',0,''),(46962,14920,'120470','printshop-mobile','padding-right','10',0,''),(46963,14920,'120470','printshop-mobile','padding-bottom','10',0,''),(46964,14921,'120471','printshop-mobile','text','<p>PHONE NUMBER:</p>',1,''),(46965,14921,'120471','printshop-mobile','font-size','14',0,''),(46966,14921,'120471','printshop-mobile','font-weight','bold',0,''),(46967,14921,'120471','printshop-mobile','padding-top','10',0,''),(46968,14922,'120472','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(46969,14922,'120472','printshop-mobile','font-weight','bold',0,''),(46970,14922,'120472','printshop-mobile','font-size','14',0,''),(46971,14922,'120472','printshop-mobile','padding-top','10',0,''),(46972,14923,'120473','printshop-mobile','text','<p>CUSTOMER:</p>',1,''),(46973,14923,'120473','printshop-mobile','font-size','13',0,''),(46974,14923,'120473','printshop-mobile','font-weight','bold',0,''),(46975,14924,'120474','printshop-mobile','font-weight','normal',0,''),(46976,14925,'120475','printshop-mobile','font-weight','normal',0,''),(46977,14927,'120477','printshop-mobile','block_type','2',0,''),(46978,14927,'120477','printshop-mobile','font-weight','normal',0,''),(46979,14927,'120477','printshop-mobile','border-top-width','1',0,''),(46980,14927,'120477','printshop-mobile','border-top-color','#e0e0e0',0,''),(46981,14927,'120477','printshop-mobile','border-right-width','1',0,''),(46982,14927,'120477','printshop-mobile','border-right-color','#e0e0e0',0,''),(46983,14928,'120478','printshop-mobile','block_type','1',0,''),(46984,14928,'120478','printshop-mobile','font-weight','normal',0,''),(46985,14928,'120478','printshop-mobile','padding-top','10',0,''),(46986,14928,'120478','printshop-mobile','padding-left','10',0,''),(46987,14928,'120478','printshop-mobile','padding-right','10',0,''),(46988,14928,'120478','printshop-mobile','padding-bottom','10',0,''),(46989,14928,'120478','printshop-mobile','border-right-width','1',0,''),(46990,14928,'120478','printshop-mobile','border-right-color','#e0e0e0',0,''),(46991,14929,'120479','printshop-mobile','text','<p>Shipping via</p>',1,''),(46992,14929,'120479','printshop-mobile','font-weight','bold',0,''),(46993,14929,'120479','printshop-mobile','font-size','14',0,''),(46994,14931,'120481','printshop-mobile','block_type','1',0,''),(46995,14931,'120481','printshop-mobile','font-weight','normal',0,''),(46996,14931,'120481','printshop-mobile','padding-top','10',0,''),(46997,14931,'120481','printshop-mobile','padding-left','10',0,''),(46998,14931,'120481','printshop-mobile','padding-right','10',0,''),(46999,14931,'120481','printshop-mobile','padding-bottom','10',0,''),(47000,14933,'120483','printshop-mobile','text','<p>Shipping service</p>',1,''),(47001,14933,'120483','printshop-mobile','font-weight','bold',0,''),(47002,14933,'120483','printshop-mobile','font-size','14',0,''),(47003,14934,'120484','printshop-mobile','text','<p>Payment date:</p>',1,''),(47004,14934,'120484','printshop-mobile','font-weight','bold',0,''),(47005,14934,'120484','printshop-mobile','text-align','center',0,''),(47006,14934,'120484','printshop-mobile','font-size','12',0,''),(47007,14935,'120485','printshop-mobile','font-weight','normal',0,''),(47008,14935,'120485','printshop-mobile','text-align','center',0,''),(47009,14936,'120486','printshop-mobile','text','<p>Payment Method:</p>',1,''),(47010,14936,'120486','printshop-mobile','font-weight','bold',0,''),(47011,14936,'120486','printshop-mobile','text-align','center',0,''),(47012,14937,'120487','printshop-mobile','font-size','14',0,''),(47013,14937,'120487','printshop-mobile','font-weight','bold',0,''),(47014,14937,'120487','printshop-mobile','text-align','center',0,''),(47015,14937,'120487','printshop-mobile','padding-bottom','10',0,''),(47016,14937,'120487','printshop-mobile','padding-top','10',0,''),(47017,14938,'120488','printshop-mobile','font-weight','normal',0,''),(47018,14938,'120488','printshop-mobile','text-align','center',0,''),(47019,14938,'120488','printshop-mobile','padding-bottom','10',0,''),(47020,14939,'120489','printshop-mobile','font-weight','normal',0,''),(47021,14939,'120489','printshop-mobile','text-align','center',0,''),(47022,14939,'120489','printshop-mobile','padding-bottom','20',0,''),(47023,14940,'120490','printshop-mobile','block_type','3',0,''),(47024,14940,'120490','printshop-mobile','font-weight','normal',0,''),(47025,14940,'120490','printshop-mobile','padding-top','20',0,''),(47026,14941,'120491','printshop-mobile','text','<p>If undelivered please return to:</p>',1,''),(47027,14941,'120491','printshop-mobile','font-size','12',0,''),(47028,14941,'120491','printshop-mobile','font-weight','bold',0,''),(47029,14942,'120492','printshop-mobile','font-size','12',0,''),(47030,14943,'120493','printshop-mobile','font-weight','400',0,''),(47031,14943,'120493','printshop-mobile','text-align','center',0,''),(47032,14943,'120493','printshop-mobile','padding-top','0',0,''),(47034,14943,'120493','printshop-mobile','padding-left','20',0,''),(47035,14943,'120493','printshop-mobile','padding-right','20',0,''),(47036,14944,'120494','printshop-mobile','text','<p>Thank you for your order</p>',1,''),(47037,14944,'120494','printshop-mobile','color','#1da1f2',0,''),(47038,14944,'120494','printshop-mobile','font-size','13',0,''),(47039,14944,'120494','printshop-mobile','font-weight','bold',0,''),(47040,14944,'120494','printshop-mobile','padding-top','5',0,''),(47041,14944,'120494','printshop-mobile','text-align','center',0,''),(47042,14945,'120495','printshop-mobile','block_type','6',0,''),(47043,14945,'120495','printshop-mobile','font-weight','normal',0,''),(47044,14945,'120495','printshop-mobile','font-size','16',0,''),(47045,14946,'120496','printshop-mobile','text','<p>Phone:</p>',1,''),(47046,14946,'120496','printshop-mobile','font-weight','normal',0,''),(47047,14946,'120496','printshop-mobile','text-align','right',0,''),(47048,14946,'120496','printshop-mobile','font-size','12',0,''),(47049,14947,'120497','printshop-mobile','font-weight','normal',0,''),(47050,14947,'120497','printshop-mobile','text-align','right',0,''),(47051,14947,'120497','printshop-mobile','font-size','12',0,''),(47052,14948,'120498','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(47053,14948,'120498','printshop-mobile','font-size','12',0,''),(47054,14948,'120498','printshop-mobile','font-weight','bold',0,''),(47055,14948,'120498','printshop-mobile','text-align','right',0,''),(47056,14949,'120499','printshop-mobile','block_type','6',0,''),(47057,14949,'120499','printshop-mobile','font-weight','normal',0,''),(47058,14949,'120499','printshop-mobile','font-size','16',0,''),(47059,14950,'120500','printshop-mobile','text','<p>Email:</p>',1,''),(47060,14950,'120500','printshop-mobile','font-weight','normal',0,''),(47061,14950,'120500','printshop-mobile','text-align','right',0,''),(47062,14950,'120500','printshop-mobile','font-size','12',0,''),(47063,14951,'120501','printshop-mobile','font-weight','normal',0,''),(47064,14951,'120501','printshop-mobile','text-align','right',0,''),(47065,14951,'120501','printshop-mobile','font-size','12',0,''),(47066,14952,'120502','printshop-mobile','font-weight','400',0,''),(47067,14952,'120502','printshop-mobile','padding-top','20',0,''),(47068,14952,'120502','printshop-mobile','padding-bottom','0',0,''),(47069,14952,'120502','printshop-mobile','font-size','12',0,''),(47070,14953,'120503','printshop-mobile','block_type','5',0,''),(47071,14953,'120503','printshop-mobile','font-weight','normal',0,''),(47072,14953,'120503','printshop-mobile','border-bottom-width','1',0,''),(47073,14953,'120503','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(47074,14953,'120503','printshop-mobile','border-top-width','1',0,''),(47075,14953,'120503','printshop-mobile','border-top-color','#e0e0e0',0,''),(47076,14953,'120503','printshop-mobile','border-left-color','#e0e0e0',0,''),(47077,14953,'120503','printshop-mobile','border-left-width','1',0,''),(47078,14954,'120504','printshop-mobile','block_type','1',0,''),(47079,14954,'120504','printshop-mobile','font-weight','normal',0,''),(47080,14954,'120504','printshop-mobile','padding-top','10',0,''),(47081,14954,'120504','printshop-mobile','padding-left','10',0,''),(47082,14954,'120504','printshop-mobile','padding-right','10',0,''),(47083,14955,'120505','printshop-mobile','font-weight','400',0,''),(47084,14955,'120505','printshop-mobile','line-height','120',0,''),(47085,14955,'120505','printshop-mobile','line_height_measure','%',0,''),(47086,14955,'120505','printshop-mobile','font-size','12',0,''),(47087,14956,'120506','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(47088,14956,'120506','printshop-mobile','font-size','14',0,''),(47089,14956,'120506','printshop-mobile','font-weight','bold',0,''),(47090,14956,'120506','printshop-mobile','padding-bottom','10',0,''),(47091,14957,'120507','printshop-mobile','block_type','1',0,''),(47092,14957,'120507','printshop-mobile','background-color','#eeeeee',0,''),(47093,14957,'120507','printshop-mobile','padding-top','20',0,''),(47094,14957,'120507','printshop-mobile','padding-left','10',0,''),(47095,14957,'120507','printshop-mobile','padding-right','10',0,''),(47096,14957,'120507','printshop-mobile','padding-bottom','20',0,''),(47097,14957,'120507','printshop-mobile','font-size','14',0,''),(47098,14958,'120508','printshop-mobile','font-weight','normal',0,''),(47099,14958,'120508','printshop-mobile','text-align','right',0,''),(47100,14958,'120508','printshop-mobile','font-size','14',0,''),(47101,14958,'120508','printshop-mobile','box_align','3',0,''),(47102,14959,'120509','printshop-mobile','block_type','1',0,''),(47103,14959,'120509','printshop-mobile','padding-top','35',0,''),(47104,14959,'120509','printshop-mobile','padding-bottom','35',0,''),(47105,14960,'120510','printshop-mobile','block_type','7',0,''),(47106,14960,'120510','printshop-mobile','schema','7-2',0,''),(47107,14961,'120511','printshop-mobile','block_type','1',0,''),(47108,14961,'120511','printshop-mobile','style_class','blog_list_content',0,''),(47109,14963,'120513','printshop-mobile','text-align','center',0,''),(47110,14964,'120514','printshop-mobile','aria_name','blogsidebar',0,''),(47111,14964,'120514','printshop-mobile','style_class','blogsidebar',0,''),(47112,14965,'120515','printshop-mobile','block_type','1',0,''),(47113,14965,'120515','printshop-mobile','padding-top','35',0,''),(47114,14965,'120515','printshop-mobile','padding-bottom','35',0,''),(47115,14966,'120516','printshop-mobile','block_type','7',0,''),(47116,14966,'120516','printshop-mobile','schema','7-1',0,''),(47118,14967,'120517','printshop-mobile','block_type','1',0,''),(47119,14967,'120517','printshop-mobile','style_class','blog_list_content',0,''),(47120,14968,'120518','printshop-mobile','items_on_page','12',0,''),(47121,14968,'120518','printshop-mobile','items_cut_off','200',0,''),(47122,14969,'120519','printshop-mobile','text-align','center',0,''),(47123,14969,'120519','printshop-mobile','hide_parents','1',0,''),(47124,14970,'120520','printshop-mobile','aria_name','blogsidebar',0,''),(47125,14970,'120520','printshop-mobile','padding-left','35',0,''),(47126,14970,'120520','printshop-mobile','style_class','blogsidebar',0,''),(47128,14971,'120521','printshop-mobile','banners_group','blog',0,''),(47129,14971,'120521','printshop-mobile','margin-bottom','40',0,''),(47130,14972,'120522','printshop-mobile','block_type','1',0,''),(47131,14972,'120522','printshop-mobile','padding-top','35',0,''),(47132,14972,'120522','printshop-mobile','padding-bottom','35',0,''),(47133,14973,'120523','printshop-mobile','block_type','7',0,''),(47134,14973,'120523','printshop-mobile','schema','7-2',0,''),(47135,14975,'120525','printshop-mobile','block_type','1',0,''),(47136,14976,'120526','printshop-mobile','text','<div class=\"heading-3\">##TEXT_BLOG_RELATED_PRODUCTS##</div>',0,''),(47137,14977,'120527','printshop-mobile','count_products','8',0,''),(47138,14977,'120527','printshop-mobile','col_in_row','4',0,''),(47139,14977,'120527','printshop-mobile','view_as','carousel',0,''),(47140,14977,'120527','printshop-mobile','show_stock','1',0,''),(47141,14977,'120527','printshop-mobile','show_description','1',0,''),(47142,14977,'120527','printshop-mobile','show_properties','1',0,''),(47143,14977,'120527','printshop-mobile','show_rating','1',0,''),(47144,14977,'120527','printshop-mobile','show_rating_counts','1',0,''),(47145,14977,'120527','printshop-mobile','show_qty_input','1',0,''),(47146,14977,'120527','printshop-mobile','show_wishlist_button','1',0,''),(47147,14977,'120527','printshop-mobile','show_compare','1',0,''),(47151,14977,'120527','printshop-mobile','listing_type','productListing',0,''),(47152,14977,'120527','printshop-mobile','hide_parents','2',0,''),(47153,14978,'120528','printshop-mobile','block_type','1',0,''),(47154,14978,'120528','printshop-mobile','style_class','blog-white-bg',0,''),(47155,14978,'120528','printshop-mobile','padding-bottom','20',0,''),(47156,14982,'120532','printshop-mobile','block_type','1',0,''),(47157,14982,'120532','printshop-mobile','padding-top','20',0,''),(47158,14982,'120532','printshop-mobile','margin-top','20',0,''),(47159,14982,'120532','printshop-mobile','border-top-width','1',0,''),(47160,14982,'120532','printshop-mobile','border-top-color','#EDE5D5',0,''),(47161,14982,'120532','printshop-mobile','clear','both',0,''),(47162,14983,'120533','printshop-mobile','box_align','4',0,''),(47163,14983,'120533','printshop-mobile','text-align','center',0,''),(47164,14984,'120534','printshop-mobile','text-align','center',0,''),(47165,14985,'120535','printshop-mobile','aria_name','blogsidebar',0,''),(47166,14985,'120535','printshop-mobile','style_class','blogsidebar',0,''),(47167,14986,'120536','printshop-mobile','block_type','1',0,''),(47168,14986,'120536','printshop-mobile','padding-top','35',0,''),(47169,14986,'120536','printshop-mobile','padding-bottom','35',0,''),(47170,14987,'120537','printshop-mobile','block_type','7',0,''),(47171,14987,'120537','printshop-mobile','schema','7-2',0,''),(47172,14988,'120538','printshop-mobile','block_type','1',0,''),(47173,14988,'120538','printshop-mobile','style_class','blog_list_content',0,''),(47174,14990,'120540','printshop-mobile','text-align','center',0,''),(47175,14990,'120540','printshop-mobile','hide_parents','1',0,''),(47176,14991,'120541','printshop-mobile','aria_name','blogsidebar',0,''),(47177,14991,'120541','printshop-mobile','style_class','blogsidebar',0,''),(47178,14992,'120542','printshop-mobile','block_type','1',0,''),(47179,14994,'120544','printshop-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(47180,14995,'120545','printshop-mobile','block_type','1',0,''),(47181,14996,'120546','printshop-mobile','block_type','2',0,''),(47182,14996,'120546','printshop-mobile','margin-bottom','20',0,''),(47183,14997,'120547','printshop-mobile','block_type','1',0,''),(47184,14997,'120547','printshop-mobile','padding-right','20',0,''),(47185,14998,'120548','printshop-mobile','field','50',0,''),(47186,14999,'120549','printshop-mobile','field','49',0,''),(47187,15000,'120550','printshop-mobile','block_type','2',0,''),(47188,15002,'120552','printshop-mobile','float','right',0,''),(47189,15002,'120552','printshop-mobile','clear','none',0,''),(47190,15003,'120553','printshop-mobile','float','right',0,''),(47191,15003,'120553','printshop-mobile','margin-left','20',0,''),(47192,15004,'120554','printshop-mobile','block_type','2',0,''),(47193,15004,'120554','printshop-mobile','margin-bottom','20',0,''),(47194,15005,'120555','printshop-mobile','block_type','1',0,''),(47195,15005,'120555','printshop-mobile','padding-right','20',0,''),(47196,15006,'120556','printshop-mobile','field','66',0,''),(47197,15007,'120557','printshop-mobile','block_type','1',0,''),(47198,15007,'120557','printshop-mobile','padding-left','20',0,''),(47199,15008,'120558','printshop-mobile','field','67',0,''),(47200,15009,'120559','printshop-mobile','text','<div class=\"heading-2\">##TRADE_REFERENCES##</div>',0,''),(47201,15009,'120559','printshop-mobile','text-align','center',0,''),(47202,15010,'120560','printshop-mobile','text','<div class=\"heading-2\">##BANK_ACCOUNT_DETAILS##</div>',0,''),(47203,15010,'120560','printshop-mobile','text-align','center',0,''),(47204,15011,'120561','printshop-mobile','text','<div class=\"heading-2\">##TEXT_DECLARATION##</div>',0,''),(47205,15011,'120561','printshop-mobile','text-align','center',0,''),(47206,15012,'120562','printshop-mobile','block_type','2',0,''),(47207,15012,'120562','printshop-mobile','margin-bottom','20',0,''),(47208,15013,'120563','printshop-mobile','block_type','1',0,''),(47209,15013,'120563','printshop-mobile','padding-right','20',0,''),(47210,15014,'120564','printshop-mobile','field','62',0,''),(47211,15015,'120565','printshop-mobile','field','60',0,''),(47212,15016,'120566','printshop-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 1</div>',0,''),(47213,15017,'120567','printshop-mobile','field','61',0,''),(47214,15018,'120568','printshop-mobile','block_type','1',0,''),(47215,15018,'120568','printshop-mobile','padding-left','20',0,''),(47216,15019,'120569','printshop-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 2</div>',0,''),(47217,15020,'120570','printshop-mobile','field','64',0,''),(47218,15021,'120571','printshop-mobile','field','63',0,''),(47219,15022,'120572','printshop-mobile','field','65',0,''),(47220,15023,'120573','printshop-mobile','block_type','2',0,''),(47221,15023,'120573','printshop-mobile','margin-bottom','20',0,''),(47222,15024,'120574','printshop-mobile','block_type','1',0,''),(47223,15024,'120574','printshop-mobile','padding-right','20',0,''),(47224,15025,'120575','printshop-mobile','field','52',0,''),(47225,15026,'120576','printshop-mobile','field','51',0,''),(47226,15027,'120577','printshop-mobile','block_type','2',0,''),(47227,15028,'120578','printshop-mobile','block_type','1',0,''),(47228,15028,'120578','printshop-mobile','padding-right','20',0,''),(47229,15029,'120579','printshop-mobile','group','15',0,''),(47230,15030,'120580','printshop-mobile','text','<div class=\"heading-3\">##CATEGORY_COMPANY##</div>',0,''),(47231,15032,'120582','printshop-mobile','block_type','2',0,''),(47232,15033,'120583','printshop-mobile','field','68',0,''),(47233,15033,'120583','printshop-mobile','padding-right','10',0,''),(47234,15034,'120584','printshop-mobile','block_type','2',0,''),(47235,15034,'120584','printshop-mobile','border-bottom-width','1',0,''),(47236,15034,'120584','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(47237,15034,'120584','printshop-mobile','padding-bottom','10',0,''),(47238,15034,'120584','printshop-mobile','margin-bottom','20',0,''),(47239,15035,'120585','printshop-mobile','block_type','1',0,''),(47240,15035,'120585','printshop-mobile','padding-right','10',0,''),(47241,15036,'120586','printshop-mobile','field','69',0,''),(47242,15037,'120587','printshop-mobile','field','75',0,''),(47243,15038,'120588','printshop-mobile','field','71',0,''),(47244,15039,'120589','printshop-mobile','field','73',0,''),(47245,15040,'120590','printshop-mobile','block_type','1',0,''),(47246,15040,'120590','printshop-mobile','padding-left','10',0,''),(47247,15041,'120591','printshop-mobile','field','76',0,''),(47248,15042,'120592','printshop-mobile','field','74',0,''),(47249,15043,'120593','printshop-mobile','field','72',0,''),(47250,15044,'120594','printshop-mobile','field','70',0,''),(47251,15045,'120595','printshop-mobile','block_type','1',0,''),(47252,15045,'120595','printshop-mobile','padding-left','20',0,''),(47253,15046,'120596','printshop-mobile','group','16',0,''),(47254,15047,'120597','printshop-mobile','block_type','2',0,''),(47255,15048,'120598','printshop-mobile','block_type','1',0,''),(47256,15048,'120598','printshop-mobile','padding-right','10',0,''),(47257,15049,'120599','printshop-mobile','field','77',0,''),(47258,15050,'120600','printshop-mobile','field','79',0,''),(47259,15051,'120601','printshop-mobile','block_type','1',0,''),(47260,15051,'120601','printshop-mobile','padding-left','10',0,''),(47261,15052,'120602','printshop-mobile','field','78',0,''),(47262,15053,'120603','printshop-mobile','block_type','2',0,''),(47263,15054,'120604','printshop-mobile','block_type','1',0,''),(47264,15054,'120604','printshop-mobile','padding-right','10',0,''),(47265,15055,'120605','printshop-mobile','field','82',0,''),(47266,15056,'120606','printshop-mobile','field','80',0,''),(47267,15057,'120607','printshop-mobile','field','84',0,''),(47268,15058,'120608','printshop-mobile','block_type','1',0,''),(47269,15058,'120608','printshop-mobile','padding-left','10',0,''),(47270,15059,'120609','printshop-mobile','field','83',0,''),(47271,15060,'120610','printshop-mobile','field','81',0,''),(47272,15061,'120611','printshop-mobile','field','85',0,''),(47273,15062,'120612','printshop-mobile','text','<div class=\"heading-3\">##OWNERS_DETAILS##</div>',0,''),(47274,15063,'120613','printshop-mobile','block_type','2',0,''),(47275,15063,'120613','printshop-mobile','margin-bottom','20',0,''),(47276,15064,'120614','printshop-mobile','block_type','1',0,''),(47277,15064,'120614','printshop-mobile','padding-right','20',0,''),(47278,15065,'120615','printshop-mobile','field','53',0,''),(47279,15066,'120616','printshop-mobile','field','54',0,''),(47280,15067,'120617','printshop-mobile','block_type','1',0,''),(47281,15067,'120617','printshop-mobile','padding-left','20',0,''),(47282,15068,'120618','printshop-mobile','field','55',0,''),(47283,15069,'120619','printshop-mobile','text','<div class=\"heading-2\">##TEXT_CUSTOMER_DETAILS##</div>',0,''),(47284,15069,'120619','printshop-mobile','text-align','center',0,''),(47285,15070,'120620','printshop-mobile','block_type','2',0,''),(47286,15070,'120620','printshop-mobile','margin-bottom','20',0,''),(47287,15071,'120621','printshop-mobile','block_type','1',0,''),(47288,15071,'120621','printshop-mobile','padding-right','20',0,''),(47289,15072,'120622','printshop-mobile','field','56',0,''),(47290,15073,'120623','printshop-mobile','field','57',0,''),(47291,15074,'120624','printshop-mobile','block_type','1',0,''),(47292,15074,'120624','printshop-mobile','padding-left','20',0,''),(47293,15075,'120625','printshop-mobile','field','58',0,''),(47294,15076,'120626','printshop-mobile','field','59',0,''),(47295,15077,'120627','printshop-mobile','text','<h1>##TRADE_FORM##</h1>',0,''),(47296,15078,'120628','printshop-mobile','text','<div class=\"heading-2\">##DISCOUNT##</div>',0,''),(47297,15078,'120628','printshop-mobile','text-align','center',0,''),(47298,15079,'120629','printshop-mobile','block_type','1',0,''),(47299,15080,'120630','printshop-mobile','block_type','6',0,''),(47300,15081,'120631','printshop-mobile','text','Telephone No.',0,''),(47301,15081,'120631','printshop-mobile','text-align','right',0,''),(47302,15082,'120632','printshop-mobile','field','79',0,''),(47303,15082,'120632','printshop-mobile','border-bottom-width','1',0,''),(47304,15082,'120632','printshop-mobile','border-bottom-color','#000000',0,''),(47305,15082,'120632','printshop-mobile','padding-left','10',0,''),(47306,15083,'120633','printshop-mobile','block_type','6',0,''),(47307,15084,'120634','printshop-mobile','text','Address',0,''),(47308,15084,'120634','printshop-mobile','text-align','right',0,''),(47309,15085,'120635','printshop-mobile','fields','company_street_address, company_suburb, company_city',0,''),(47310,15085,'120635','printshop-mobile','padding-left','10',0,''),(47311,15085,'120635','printshop-mobile','border-bottom-width','1',0,''),(47312,15085,'120635','printshop-mobile','border-bottom-color','#000000',0,''),(47313,15086,'120636','printshop-mobile','block_type','6',0,''),(47314,15087,'120637','printshop-mobile','text','Postcode',0,''),(47315,15087,'120637','printshop-mobile','text-align','right',0,''),(47316,15088,'120638','printshop-mobile','field','80',0,''),(47317,15088,'120638','printshop-mobile','border-bottom-width','1',0,''),(47318,15088,'120638','printshop-mobile','border-bottom-color','#000000',0,''),(47319,15088,'120638','printshop-mobile','padding-left','10',0,''),(47320,15089,'120639','printshop-mobile','block_type','6',0,''),(47321,15090,'120640','printshop-mobile','text','Address',0,''),(47322,15090,'120640','printshop-mobile','text-align','right',0,''),(47323,15091,'120641','printshop-mobile','fields','oner_street_address, owner_suburb, owner_city',0,''),(47324,15091,'120641','printshop-mobile','padding-left','10',0,''),(47325,15091,'120641','printshop-mobile','border-bottom-width','1',0,''),(47326,15091,'120641','printshop-mobile','border-bottom-color','#000000',0,''),(47327,15092,'120642','printshop-mobile','block_type','6',0,''),(47328,15092,'120642','printshop-mobile','margin-top','20',0,''),(47329,15093,'120643','printshop-mobile','text','Owner’s Name',0,''),(47330,15093,'120643','printshop-mobile','text-align','right',0,''),(47331,15094,'120644','printshop-mobile','fields','owner_firstname owner_lastname',0,''),(47332,15094,'120644','printshop-mobile','padding-left','10',0,''),(47333,15094,'120644','printshop-mobile','border-bottom-width','1',0,''),(47334,15094,'120644','printshop-mobile','border-bottom-color','#000000',0,''),(47335,15095,'120645','printshop-mobile','block_type','6',0,''),(47336,15096,'120646','printshop-mobile','text','Email',0,''),(47337,15096,'120646','printshop-mobile','text-align','right',0,''),(47338,15097,'120647','printshop-mobile','field','70',0,''),(47339,15097,'120647','printshop-mobile','border-bottom-width','1',0,''),(47340,15097,'120647','printshop-mobile','border-bottom-color','#000000',0,''),(47341,15097,'120647','printshop-mobile','padding-left','10',0,''),(47342,15098,'120648','printshop-mobile','block_type','6',0,''),(47343,15098,'120648','printshop-mobile','padding-bottom','20',0,''),(47344,15099,'120649','printshop-mobile','text','Telephone No.',0,''),(47345,15099,'120649','printshop-mobile','text-align','right',0,''),(47346,15100,'120650','printshop-mobile','block_type','11',0,''),(47347,15101,'120651','printshop-mobile','field','69',0,''),(47348,15101,'120651','printshop-mobile','border-bottom-width','1',0,''),(47349,15101,'120651','printshop-mobile','border-bottom-color','#000000',0,''),(47350,15101,'120651','printshop-mobile','padding-left','10',0,''),(47351,15102,'120652','printshop-mobile','block_type','5',0,''),(47352,15103,'120653','printshop-mobile','text','Fax No.',0,''),(47353,15103,'120653','printshop-mobile','text-align','right',0,''),(47354,15104,'120654','printshop-mobile','field','51',0,''),(47355,15104,'120654','printshop-mobile','padding-left','10',0,''),(47356,15104,'120654','printshop-mobile','border-bottom-width','1',0,''),(47357,15104,'120654','printshop-mobile','border-bottom-color','#000000',0,''),(47358,15105,'120655','printshop-mobile','block_type','1',0,''),(47359,15106,'120656','printshop-mobile','background-color','#000000',0,''),(47360,15106,'120656','printshop-mobile','color','#ffffff',0,''),(47361,15106,'120656','printshop-mobile','font-size','20',0,''),(47362,15106,'120656','printshop-mobile','text','Customer Details',0,''),(47363,15106,'120656','printshop-mobile','padding-left','10',0,''),(47364,15106,'120656','printshop-mobile','padding-right','10',0,''),(47365,15107,'120657','printshop-mobile','block_type','2',0,''),(47366,15107,'120657','printshop-mobile','color','#ffffff',0,''),(47367,15107,'120657','printshop-mobile','background-color','#000000',0,''),(47368,15108,'120658','printshop-mobile','view_item','name',0,''),(47369,15108,'120658','printshop-mobile','color','#ffffff',0,''),(47370,15108,'120658','printshop-mobile','font-size','40',0,''),(47371,15109,'120659','printshop-mobile','text','New Account Form',0,''),(47372,15109,'120659','printshop-mobile','font-size','20',0,''),(47373,15109,'120659','printshop-mobile','color','#ffffff',0,''),(47374,15109,'120659','printshop-mobile','padding-top','20',0,''),(47375,15110,'120660','printshop-mobile','block_type','2',0,''),(47376,15111,'120661','printshop-mobile','block_type','2',0,''),(47377,15111,'120661','printshop-mobile','padding-top','5',0,''),(47378,15112,'120662','printshop-mobile','block_type','10',0,''),(47379,15113,'120663','printshop-mobile','text','Limited Company',0,''),(47380,15113,'120663','printshop-mobile','font-size','16',0,''),(47381,15114,'120664','printshop-mobile','field','49',0,''),(47382,15114,'120664','printshop-mobile','padding-left','5',0,''),(47383,15115,'120665','printshop-mobile','block_type','10',0,''),(47384,15116,'120666','printshop-mobile','text','Sole Trader',0,''),(47385,15116,'120666','printshop-mobile','text-align','center',0,''),(47386,15117,'120667','printshop-mobile','field','50',0,''),(47387,15117,'120667','printshop-mobile','padding-left','5',0,''),(47388,15118,'120668','printshop-mobile','block_type','5',0,''),(47389,15119,'120669','printshop-mobile','view_item','data_format',0,''),(47390,15119,'120669','printshop-mobile','data_format_content','##STREET_ADDRESS##, ##SUBURB##,\n##CITY##, ##POSTCODE##\nTel: ##TELEPHONE##\nEmail: ##EMAIL_ADDRESS##\n',0,''),(47391,15119,'120669','printshop-mobile','font-size','14',0,''),(47392,15120,'120670','printshop-mobile','block_type','6',0,''),(47393,15121,'120671','printshop-mobile','text','Postcode',0,''),(47394,15121,'120671','printshop-mobile','text-align','right',0,''),(47395,15122,'120672','printshop-mobile','field','71',0,''),(47396,15122,'120672','printshop-mobile','border-bottom-width','1',0,''),(47397,15122,'120672','printshop-mobile','border-bottom-color','#000000',0,''),(47398,15122,'120672','printshop-mobile','padding-left','10',0,''),(47399,15123,'120673','printshop-mobile','block_type','6',0,''),(47400,15124,'120674','printshop-mobile','text','Business Name',0,''),(47401,15124,'120674','printshop-mobile','text-align','right',0,''),(47402,15125,'120675','printshop-mobile','field','68',0,''),(47403,15125,'120675','printshop-mobile','border-bottom-width','1',0,''),(47404,15125,'120675','printshop-mobile','border-bottom-color','#000000',0,''),(47405,15125,'120675','printshop-mobile','padding-left','10',0,''),(47406,15126,'120676','printshop-mobile','block_type','6',0,''),(47407,15126,'120676','printshop-mobile','padding-bottom','20',0,''),(47408,15127,'120677','printshop-mobile','text','Nature of Business',0,''),(47409,15127,'120677','printshop-mobile','text-align','right',0,''),(47410,15128,'120678','printshop-mobile','field','52',0,''),(47411,15128,'120678','printshop-mobile','border-bottom-width','1',0,''),(47412,15128,'120678','printshop-mobile','border-bottom-color','#000000',0,''),(47413,15128,'120678','printshop-mobile','padding-left','10',0,''),(47414,15129,'120679','printshop-mobile','block_type','6',0,''),(47415,15130,'120680','printshop-mobile','text','Bank Name',0,''),(47416,15130,'120680','printshop-mobile','text-align','right',0,''),(47417,15130,'120680','printshop-mobile','font-size','16',0,''),(47418,15131,'120681','printshop-mobile','field','53',0,''),(47419,15131,'120681','printshop-mobile','border-bottom-width','1',0,''),(47420,15131,'120681','printshop-mobile','border-bottom-color','#000000',0,''),(47421,15131,'120681','printshop-mobile','padding-left','10',0,''),(47422,15132,'120682','printshop-mobile','block_type','1',0,''),(47423,15132,'120682','printshop-mobile','padding-top','20',0,''),(47424,15132,'120682','printshop-mobile','padding-bottom','10',0,''),(47425,15133,'120683','printshop-mobile','background-color','#000000',0,''),(47426,15133,'120683','printshop-mobile','color','#ffffff',0,''),(47427,15133,'120683','printshop-mobile','font-size','20',0,''),(47428,15133,'120683','printshop-mobile','text','Discount (%)',0,''),(47429,15133,'120683','printshop-mobile','padding-left','10',0,''),(47430,15133,'120683','printshop-mobile','padding-right','10',0,''),(47431,15134,'120684','printshop-mobile','block_type','1',0,''),(47432,15134,'120684','printshop-mobile','padding-bottom','10',0,''),(47433,15135,'120685','printshop-mobile','background-color','#000000',0,''),(47434,15135,'120685','printshop-mobile','color','#ffffff',0,''),(47435,15135,'120685','printshop-mobile','font-size','20',0,''),(47436,15135,'120685','printshop-mobile','text','Bank Account Details',0,''),(47437,15135,'120685','printshop-mobile','padding-left','10',0,''),(47438,15135,'120685','printshop-mobile','padding-right','10',0,''),(47439,15136,'120686','printshop-mobile','block_type','6',0,''),(47440,15136,'120686','printshop-mobile','padding-bottom','20',0,''),(47441,15137,'120687','printshop-mobile','text','Account No',0,''),(47442,15137,'120687','printshop-mobile','text-align','right',0,''),(47443,15138,'120688','printshop-mobile','field','54',0,''),(47444,15138,'120688','printshop-mobile','border-bottom-width','1',0,''),(47445,15138,'120688','printshop-mobile','border-bottom-color','#000000',0,''),(47446,15138,'120688','printshop-mobile','padding-left','10',0,''),(47447,15139,'120689','printshop-mobile','block_type','6',0,''),(47448,15140,'120690','printshop-mobile','text','Address',0,''),(47449,15140,'120690','printshop-mobile','text-align','right',0,''),(47450,15141,'120691','printshop-mobile','field','55',0,''),(47451,15141,'120691','printshop-mobile','border-bottom-width','1',0,''),(47452,15141,'120691','printshop-mobile','border-bottom-color','#000000',0,''),(47453,15141,'120691','printshop-mobile','padding-left','10',0,''),(47454,15142,'120692','printshop-mobile','block_type','14',0,''),(47455,15142,'120692','printshop-mobile','padding-bottom','20',0,''),(47456,15143,'120693','printshop-mobile','text','33.33% Sale or Return',0,''),(47457,15143,'120693','printshop-mobile','text-align','right',0,''),(47458,15143,'120693','printshop-mobile','font-size','16',0,''),(47459,15144,'120694','printshop-mobile','block_type','13',0,''),(47460,15145,'120695','printshop-mobile','field','56',0,''),(47461,15145,'120695','printshop-mobile','padding-left','10',0,''),(47462,15146,'120696','printshop-mobile','text','35% Firm',0,''),(47463,15146,'120696','printshop-mobile','text-align','right',0,''),(47464,15147,'120697','printshop-mobile','field','58',0,''),(47465,15147,'120697','printshop-mobile','padding-left','10',0,''),(47466,15148,'120698','printshop-mobile','block_type','10',0,''),(47467,15149,'120699','printshop-mobile','block_type','6',0,''),(47468,15150,'120700','printshop-mobile','text','Address',0,''),(47469,15150,'120700','printshop-mobile','text-align','right',0,''),(47470,15151,'120701','printshop-mobile','field','61',0,''),(47471,15151,'120701','printshop-mobile','border-bottom-width','1',0,''),(47472,15151,'120701','printshop-mobile','border-bottom-color','#000000',0,''),(47473,15151,'120701','printshop-mobile','padding-left','10',0,''),(47474,15152,'120702','printshop-mobile','block_type','1',0,''),(47475,15152,'120702','printshop-mobile','padding-bottom','10',0,''),(47476,15153,'120703','printshop-mobile','background-color','#000000',0,''),(47477,15153,'120703','printshop-mobile','color','#ffffff',0,''),(47478,15153,'120703','printshop-mobile','font-size','20',0,''),(47479,15153,'120703','printshop-mobile','text','Trade References',0,''),(47480,15153,'120703','printshop-mobile','padding-left','10',0,''),(47481,15153,'120703','printshop-mobile','padding-right','10',0,''),(47482,15154,'120704','printshop-mobile','block_type','1',0,''),(47483,15155,'120705','printshop-mobile','text','I would like to open a trade account with Vladislav B. Malyshev and agree to abide by their General Terms & Conditions –\na signed copy of which is returned to them with this form in the supplied SAE. I have retained a copy for my reference. I\nam authorised to sign on behalf of the company I represent.',0,''),(47484,15155,'120705','printshop-mobile','font-size','15',0,''),(47485,15155,'120705','printshop-mobile','padding-left','10',0,''),(47486,15155,'120705','printshop-mobile','padding-right','10',0,''),(47487,15156,'120706','printshop-mobile','block_type','6',0,''),(47488,15156,'120706','printshop-mobile','padding-bottom','20',0,''),(47489,15157,'120707','printshop-mobile','text','Telephone No.',0,''),(47490,15157,'120707','printshop-mobile','text-align','right',0,''),(47491,15158,'120708','printshop-mobile','field','62',0,''),(47492,15158,'120708','printshop-mobile','border-bottom-width','1',0,''),(47493,15158,'120708','printshop-mobile','border-bottom-color','#000000',0,''),(47494,15158,'120708','printshop-mobile','padding-left','10',0,''),(47495,15159,'120709','printshop-mobile','block_type','1',0,''),(47496,15159,'120709','printshop-mobile','padding-bottom','10',0,''),(47497,15160,'120710','printshop-mobile','background-color','#000000',0,''),(47498,15160,'120710','printshop-mobile','color','#ffffff',0,''),(47499,15160,'120710','printshop-mobile','font-size','20',0,''),(47500,15160,'120710','printshop-mobile','text','Customer Details',0,''),(47501,15160,'120710','printshop-mobile','padding-left','10',0,''),(47502,15160,'120710','printshop-mobile','padding-right','10',0,''),(47503,15161,'120711','printshop-mobile','block_type','6',0,''),(47504,15162,'120712','printshop-mobile','text','Name',0,''),(47505,15162,'120712','printshop-mobile','text-align','right',0,''),(47506,15162,'120712','printshop-mobile','font-size','16',0,''),(47507,15163,'120713','printshop-mobile','field','60',0,''),(47508,15163,'120713','printshop-mobile','border-bottom-width','1',0,''),(47509,15163,'120713','printshop-mobile','border-bottom-color','#000000',0,''),(47510,15163,'120713','printshop-mobile','padding-left','10',0,''),(47511,15164,'120714','printshop-mobile','block_type','14',0,''),(47512,15165,'120715','printshop-mobile','text','Signed',0,''),(47513,15165,'120715','printshop-mobile','text-align','right',0,''),(47514,15166,'120716','printshop-mobile','text','&nbsp;',0,''),(47515,15166,'120716','printshop-mobile','border-bottom-width','1',0,''),(47516,15166,'120716','printshop-mobile','border-bottom-color','#000000',0,''),(47517,15167,'120717','printshop-mobile','text','Date',0,''),(47518,15167,'120717','printshop-mobile','text-align','right',0,''),(47519,15168,'120718','printshop-mobile','text','&nbsp;',0,''),(47520,15168,'120718','printshop-mobile','border-bottom-width','1',0,''),(47521,15168,'120718','printshop-mobile','border-bottom-color','#000000',0,''),(47522,15169,'120719','printshop-mobile','block_type','14',0,''),(47523,15170,'120720','printshop-mobile','text','Name in Full',0,''),(47524,15170,'120720','printshop-mobile','text-align','right',0,''),(47525,15171,'120721','printshop-mobile','field','66',0,''),(47526,15171,'120721','printshop-mobile','padding-left','10',0,''),(47527,15171,'120721','printshop-mobile','border-bottom-width','1',0,''),(47528,15171,'120721','printshop-mobile','border-bottom-color','#000000',0,''),(47529,15172,'120722','printshop-mobile','text','Position',0,''),(47530,15172,'120722','printshop-mobile','text-align','right',0,''),(47531,15173,'120723','printshop-mobile','field','67',0,''),(47532,15173,'120723','printshop-mobile','border-bottom-width','1',0,''),(47533,15173,'120723','printshop-mobile','border-bottom-color','#000000',0,''),(47534,15173,'120723','printshop-mobile','padding-left','10',0,''),(47535,15174,'120724','printshop-mobile','block_type','1',0,''),(47536,15175,'120725','printshop-mobile','text','Scottish books of exceptional value',0,''),(47537,15175,'120725','printshop-mobile','font-size','20',0,''),(47538,15175,'120725','printshop-mobile','text-align','center',0,''),(47539,15175,'120725','printshop-mobile','padding-top','20',0,''),(47540,15176,'120726','printshop-mobile','block_type','1',0,''),(47541,15177,'120727','printshop-mobile','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(47542,15177,'120727','printshop-mobile','padding-top','100',0,''),(47543,15177,'120727','printshop-mobile','margin-bottom','100',0,''),(47544,15177,'120727','printshop-mobile','text-align','center',0,''),(47545,15177,'120727','printshop-mobile','font-size','20',0,''),(47546,15178,'120728','printshop-mobile','block_type','1',0,''),(47547,15178,'120728','printshop-mobile','background-color','#eeeeee',0,''),(47548,15178,'120728','printshop-mobile','padding-bottom','30',0,''),(47549,15179,'120729','printshop-mobile','block_type','4',0,''),(47550,15179,'120729','printshop-mobile','schema','4-2',0,''),(47551,15180,'120730','printshop-mobile','block_type','1',0,''),(47552,15180,'120730','printshop-mobile','padding-right','40',0,''),(47554,15181,'120731','printshop-mobile','block_type','2',0,''),(47555,15181,'120731','printshop-mobile','margin-bottom','20',0,''),(47556,15181,'120731','printshop-mobile','schema','2-2',0,''),(47557,15181,'120731','printshop-mobile','background-color','#ffffff',0,''),(47558,15182,'120732','printshop-mobile','block_type','1',0,''),(47559,15182,'120732','printshop-mobile','border-right-width','20',0,''),(47560,15182,'120732','printshop-mobile','border-right-color','#e0e0e0',0,''),(47561,15182,'120732','printshop-mobile','margin-right','-10',0,''),(47562,15182,'120732','printshop-mobile','padding-right','30',0,''),(47563,15182,'120732','printshop-mobile','padding-top','20',0,''),(47564,15182,'120732','printshop-mobile','padding-left','30',0,''),(47565,15182,'120732','printshop-mobile','padding-bottom','20',0,''),(47568,15182,'120732','printshop-mobile','margin-bottom','20',0,''),(47571,15183,'120733','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(47572,15183,'120733','printshop-mobile','clear','none',0,''),(47573,15184,'120734','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(47574,15184,'120734','printshop-mobile','clear','none',0,''),(47575,15185,'120735','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(47576,15187,'120737','printshop-mobile','margin-bottom','20',0,''),(47577,15191,'120741','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(47578,15191,'120741','printshop-mobile','padding-top','20',0,''),(47579,15192,'120742','printshop-mobile','block_type','1',0,''),(47580,15192,'120742','printshop-mobile','padding-left','30',0,''),(47581,15192,'120742','printshop-mobile','border-left-width','20',0,''),(47582,15192,'120742','printshop-mobile','border-left-color','#e0e0e0',0,''),(47583,15192,'120742','printshop-mobile','margin-left','-10',0,''),(47584,15192,'120742','printshop-mobile','padding-right','30',0,''),(47585,15192,'120742','printshop-mobile','padding-top','20',0,''),(47586,15192,'120742','printshop-mobile','padding-bottom','20',0,''),(47588,15193,'120743','printshop-mobile','margin-bottom','20',0,''),(47589,15195,'120745','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(47590,15196,'120746','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(47591,15196,'120746','printshop-mobile','clear','none',0,''),(47592,15197,'120747','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(47593,15197,'120747','printshop-mobile','clear','none',0,''),(47594,15198,'120748','printshop-mobile','block_type','1',0,''),(47595,15198,'120748','printshop-mobile','padding-right','30',0,''),(47596,15198,'120748','printshop-mobile','background-color','#ffffff',0,''),(47597,15198,'120748','printshop-mobile','padding-top','20',0,''),(47598,15198,'120748','printshop-mobile','padding-left','30',0,''),(47599,15198,'120748','printshop-mobile','padding-bottom','20',0,''),(47602,15200,'120750','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(47603,15201,'120751','printshop-mobile','block_type','1',0,''),(47604,15201,'120751','printshop-mobile','padding-top','20',0,''),(47605,15201,'120751','printshop-mobile','padding-left','20',0,''),(47606,15201,'120751','printshop-mobile','padding-right','20',0,''),(47607,15201,'120751','printshop-mobile','padding-bottom','20',0,''),(47608,15201,'120751','printshop-mobile','background-color','#ffffff',0,''),(47609,15201,'120751','printshop-mobile','style_class','order-summary',0,''),(47610,15202,'120752','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(47611,15206,'120756','printshop-mobile','block_type','1',0,''),(47612,15206,'120756','printshop-mobile','background-color','#eeeeee',0,''),(47613,15206,'120756','printshop-mobile','padding-bottom','30',0,''),(47614,15207,'120757','printshop-mobile','block_type','4',0,''),(47615,15207,'120757','printshop-mobile','schema','4-2',0,''),(47616,15208,'120758','printshop-mobile','block_type','1',0,''),(47617,15208,'120758','printshop-mobile','padding-right','40',0,''),(47619,15209,'120759','printshop-mobile','block_type','1',0,''),(47620,15209,'120759','printshop-mobile','padding-right','30',0,''),(47621,15209,'120759','printshop-mobile','background-color','#ffffff',0,''),(47622,15209,'120759','printshop-mobile','padding-top','20',0,''),(47623,15209,'120759','printshop-mobile','padding-left','30',0,''),(47624,15209,'120759','printshop-mobile','padding-bottom','20',0,''),(47627,15210,'120760','printshop-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(47628,15212,'120762','printshop-mobile','block_type','2',0,''),(47629,15212,'120762','printshop-mobile','margin-bottom','20',0,''),(47630,15212,'120762','printshop-mobile','schema','2-2',0,''),(47631,15212,'120762','printshop-mobile','background-color','#ffffff',0,''),(47632,15213,'120763','printshop-mobile','block_type','1',0,''),(47633,15213,'120763','printshop-mobile','border-right-width','20',0,''),(47634,15213,'120763','printshop-mobile','border-right-color','#e0e0e0',0,''),(47635,15213,'120763','printshop-mobile','margin-right','-10',0,''),(47636,15213,'120763','printshop-mobile','padding-right','30',0,''),(47637,15213,'120763','printshop-mobile','padding-top','20',0,''),(47638,15213,'120763','printshop-mobile','padding-left','30',0,''),(47639,15213,'120763','printshop-mobile','padding-bottom','20',0,''),(47642,15213,'120763','printshop-mobile','margin-bottom','20',0,''),(47645,15216,'120766','printshop-mobile','margin-bottom','20',0,''),(47646,15217,'120767','printshop-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(47647,15217,'120767','printshop-mobile','padding-top','20',0,''),(47648,15219,'120769','printshop-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(47649,15219,'120769','printshop-mobile','clear','none',0,''),(47650,15221,'120771','printshop-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(47651,15221,'120771','printshop-mobile','clear','none',0,''),(47652,15222,'120772','printshop-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(47653,15223,'120773','printshop-mobile','block_type','1',0,''),(47654,15223,'120773','printshop-mobile','padding-left','30',0,''),(47655,15223,'120773','printshop-mobile','border-left-width','20',0,''),(47656,15223,'120773','printshop-mobile','border-left-color','#e0e0e0',0,''),(47657,15223,'120773','printshop-mobile','margin-left','-10',0,''),(47658,15223,'120773','printshop-mobile','padding-right','30',0,''),(47659,15223,'120773','printshop-mobile','padding-top','20',0,''),(47660,15223,'120773','printshop-mobile','padding-bottom','20',0,''),(47662,15224,'120774','printshop-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(47663,15224,'120774','printshop-mobile','clear','none',0,''),(47664,15225,'120775','printshop-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(47665,15226,'120776','printshop-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(47666,15226,'120776','printshop-mobile','clear','none',0,''),(47667,15227,'120777','printshop-mobile','margin-bottom','20',0,''),(47668,15229,'120779','printshop-mobile','block_type','1',0,''),(47669,15229,'120779','printshop-mobile','padding-top','20',0,''),(47670,15229,'120779','printshop-mobile','padding-left','20',0,''),(47671,15229,'120779','printshop-mobile','padding-right','20',0,''),(47672,15229,'120779','printshop-mobile','padding-bottom','20',0,''),(47673,15229,'120779','printshop-mobile','background-color','#ffffff',0,''),(47674,15229,'120779','printshop-mobile','style_class','order-summary',0,''),(47675,15231,'120781','printshop-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(47676,15234,'120784','printshop-mobile','block_type','1',0,''),(47677,15234,'120784','printshop-mobile','background_image','themes/printshop-mobile/img/wedding-registry-page-1-1.jpg',0,''),(47678,15234,'120784','printshop-mobile','background-position','top center',0,''),(47679,15234,'120784','printshop-mobile','background-repeat','no-repeat',0,''),(47680,15234,'120784','printshop-mobile','background-size','cover',0,''),(47681,15234,'120784','printshop-mobile','padding-top','50',0,''),(47682,15234,'120784','printshop-mobile','padding-bottom','50',0,''),(47683,15234,'120784','printshop-mobile','margin-bottom','30',0,''),(47684,15235,'120785','printshop-mobile','background-color','#ffffff',0,''),(47685,15235,'120785','printshop-mobile','block_type','1',0,''),(47686,15235,'120785','printshop-mobile','max-width','700',0,''),(47687,15235,'120785','printshop-mobile','margin_left_measure','auto',0,''),(47688,15235,'120785','printshop-mobile','margin_right_measure','auto',0,''),(47689,15236,'120786','printshop-mobile','text-align','center',0,''),(47690,15236,'120786','printshop-mobile','margin-bottom','30',0,''),(47691,15237,'120787','printshop-mobile','padding-bottom','30',0,''),(47692,15237,'120787','printshop-mobile','text-align','center',0,''),(47693,15238,'120788','printshop-mobile','heading_type','h1',0,''),(47694,15239,'120789','printshop-mobile','block_type','13',0,''),(47695,15239,'120789','printshop-mobile','margin-bottom','20',0,''),(47696,15239,'120789','printshop-mobile','schema','13-2',0,''),(47697,15240,'120790','printshop-mobile','position','relative',0,''),(47698,15240,'120790','printshop-mobile','margin-top','-100',0,''),(47700,15241,'120791','printshop-mobile','font-family','Varela Round',0,''),(47701,15241,'120791','printshop-mobile','font-size','30',0,''),(47702,15241,'120791','printshop-mobile','text-transform','uppercase',0,''),(47703,15241,'120791','printshop-mobile','text-align','center',0,''),(47705,15242,'120792','printshop-mobile','block_type','1',0,''),(47706,15242,'120792','printshop-mobile','float','left',0,''),(47708,15243,'120793','printshop-mobile','display','inline-block',0,''),(47709,15243,'120793','printshop-mobile','font-weight','700',0,''),(47710,15244,'120794','printshop-mobile','clear','none',0,''),(47711,15244,'120794','printshop-mobile','padding-left','20',0,''),(47712,15244,'120794','printshop-mobile','font-weight','700',0,''),(47713,15244,'120794','printshop-mobile','display','inline-block',0,''),(47714,15245,'120795','printshop-mobile','font-weight','700',0,''),(47715,15245,'120795','printshop-mobile','clear','none',0,''),(47716,15245,'120795','printshop-mobile','padding-left','20',0,''),(47717,15245,'120795','printshop-mobile','display','inline-block',0,''),(47718,15246,'120796','printshop-mobile','font-family','Varela Round',0,''),(47719,15246,'120796','printshop-mobile','font-size','18',0,''),(47720,15246,'120796','printshop-mobile','margin-bottom','10',0,''),(47721,15246,'120796','printshop-mobile','text-align','center',0,''),(47722,15247,'120797','printshop-mobile','font-weight','700',0,''),(47723,15247,'120797','printshop-mobile','text-align','right',0,''),(47724,15247,'120797','printshop-mobile','max-width','110',0,''),(47725,15247,'120797','printshop-mobile','float','right',0,''),(47726,15248,'120798','printshop-mobile','margin-bottom','10',0,''),(47727,15249,'120799','printshop-mobile','like_button','1',0,''),(47728,15249,'120799','printshop-mobile','text-align','center',0,''),(47729,15249,'120799','printshop-mobile','margin-bottom','20',0,''),(47730,15249,'120799','printshop-mobile','margin-top','20',0,''),(47731,15249,'120799','printshop-mobile','padding-top','30',0,''),(47732,15249,'120799','printshop-mobile','border-top-width','1',0,''),(47733,15249,'120799','printshop-mobile','border-top-color','#e0e0e0',0,''),(47741,15254,'120804','printshop-mobile','block_type','1',0,''),(47742,15254,'120804','printshop-mobile','padding-top','20',0,''),(47743,15254,'120804','printshop-mobile','padding-bottom','20',0,''),(47744,15256,'120806','printshop-mobile','padding-top','10',0,''),(47745,15256,'120806','printshop-mobile','padding-bottom','10',0,''),(47746,15256,'120806','printshop-mobile','border-top-width','1',0,''),(47747,15256,'120806','printshop-mobile','border-top-color','#e0e0e0',0,''),(47748,15256,'120806','printshop-mobile','text-align','right',0,''),(47749,15257,'120807','printshop-mobile','block_type','1',0,''),(47750,15257,'120807','printshop-mobile','border-top-width','1',0,''),(47751,15257,'120807','printshop-mobile','border-left-width','1',0,''),(47752,15257,'120807','printshop-mobile','border-right-width','1',0,''),(47753,15257,'120807','printshop-mobile','border-bottom-width','1',0,''),(47754,15257,'120807','printshop-mobile','border-top-color','#e0e0e0',0,''),(47755,15257,'120807','printshop-mobile','border-left-color','#e0e0e0',0,''),(47756,15257,'120807','printshop-mobile','border-right-color','#e0e0e0',0,''),(47757,15257,'120807','printshop-mobile','border-bottom-color','#e0e0e0',0,''),(47758,15257,'120807','printshop-mobile','padding-top','15',0,''),(47759,15257,'120807','printshop-mobile','padding-left','15',0,''),(47760,15257,'120807','printshop-mobile','padding-right','15',0,''),(47761,15257,'120807','printshop-mobile','padding-bottom','15',0,''),(47762,15257,'120807','printshop-mobile','margin-bottom','50',0,''),(47763,15258,'120808','printshop-mobile','block_type','1',0,''),(47764,15258,'120808','printshop-mobile','padding-top','20',0,''),(47765,15258,'120808','printshop-mobile','padding-left','20',0,''),(47766,15258,'120808','printshop-mobile','padding-right','20',0,''),(47767,15258,'120808','printshop-mobile','background-color','#ffffff',0,''),(47768,15260,'120810','printshop-mobile','text','<h1>##FIND_REGISTRY##</h1>',0,''),(47769,15261,'120811','printshop-mobile','block_type','1',0,''),(47770,15262,'120812','printshop-mobile','block_type','8',0,''),(47771,15262,'120812','printshop-mobile','schema','8-6',0,''),(47772,15263,'120813','printshop-mobile','text','<div class=\"heading-3\">##INVITE_GUESTS##</div>',0,''),(47773,15264,'120814','printshop-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_PERSONALIZED_URL##</div>',0,''),(47774,15265,'120815','printshop-mobile','margin-bottom','30',0,''),(47775,15268,'120818','printshop-mobile','margin-top','-100',0,''),(47776,15269,'120819','printshop-mobile','text','<h1>##SHARE_YOUR_WEDDING_REGISTRY##</h1>',0,''),(47777,15269,'120819','printshop-mobile','margin-top','-80',0,''),(47779,15270,'120820','printshop-mobile','text','<h1>##CREATE_WR_SUCCESS_MESSAGE##</h1>',0,''),(47780,15272,'120822','printshop-mobile','block_type','2',0,''),(47781,15272,'120822','printshop-mobile','schema','2-2',0,''),(47782,15273,'120823','printshop-mobile','block_type','1',0,''),(47783,15273,'120823','printshop-mobile','padding-right','15',0,''),(47785,15274,'120824','printshop-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_REGISTRY##</div>',0,''),(47786,15275,'120825','printshop-mobile','text','<div class=\"heading-3\">##TEXT_WEDDING_DETAILS##</div>',0,''),(47787,15276,'120826','printshop-mobile','margin-bottom','20',0,''),(47788,15277,'120827','printshop-mobile','margin-bottom','20',0,''),(47789,15278,'120828','printshop-mobile','text','<div class=\"heading-3\">##TEXT_NAMES##</div>',0,''),(47790,15279,'120829','printshop-mobile','padding-bottom','20',0,''),(47791,15280,'120830','printshop-mobile','block_type','1',0,''),(47792,15280,'120830','printshop-mobile','padding-left','15',0,''),(47794,15281,'120831','printshop-mobile','margin-bottom','20',0,''),(47795,15282,'120832','printshop-mobile','text','<div class=\"heading-3\">##TEXT_SHIPPING_DETAILS##</div>',0,''),(47796,15283,'120833','printshop-mobile','text','<div class=\"heading-3\">##UPLOAD_PHOTO##</div>',0,''),(47797,15284,'120834','printshop-mobile','margin-bottom','20',0,''),(47798,15284,'120834','printshop-mobile','padding-left','1',0,''),(47799,15285,'120835','printshop-mobile','text','<div class=\"heading-3\">##TEXT_ADDITIONAL_INFORMATION##</div>',0,''),(47800,15286,'120836','printshop-mobile','margin-bottom','20',0,''),(47801,15287,'120837','printshop-mobile','text','<h1>##WEDDING_REGISTRY_FORM_HEADING##</h1>',0,''),(47802,15288,'120838','printshop-mobile','block_type','2',0,''),(47803,15288,'120838','printshop-mobile','margin-bottom','20',0,''),(47804,15290,'120840','printshop-mobile','text-align','right',0,''),(47805,15292,'120842','printshop-mobile','block_type','13',0,''),(47806,15292,'120842','printshop-mobile','margin-bottom','20',0,''),(47807,15293,'120843','printshop-mobile','position','relative',0,''),(47808,15293,'120843','printshop-mobile','margin-top','-100',0,''),(47809,15294,'120844','printshop-mobile','font-family','Varela Round',0,''),(47810,15294,'120844','printshop-mobile','font-size','18',0,''),(47811,15294,'120844','printshop-mobile','margin-bottom','10',0,''),(47812,15295,'120845','printshop-mobile','font-family','Varela Round',0,''),(47813,15295,'120845','printshop-mobile','font-size','30',0,''),(47814,15295,'120845','printshop-mobile','text-transform','uppercase',0,''),(47815,15296,'120846','printshop-mobile','font-weight','700',0,''),(47816,15296,'120846','printshop-mobile','text-align','right',0,''),(47817,15298,'120848','printshop-mobile','block_type','1',0,''),(47818,15299,'120849','printshop-mobile','block_type','6',0,''),(47819,15299,'120849','printshop-mobile','schema','6-3',0,''),(47820,15300,'120850','printshop-mobile','aria_name','account-menu',0,''),(47821,15301,'120851','printshop-mobile','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(47822,15302,'120852','printshop-mobile','margin-bottom','20',0,''),(47823,15303,'120853','printshop-mobile','block_type','1',0,''),(47824,15303,'120853','printshop-mobile','padding-top','20',0,''),(47825,15303,'120853','printshop-mobile','padding-bottom','20',0,''),(47826,15305,'120855','printshop-mobile','padding-top','20',0,''),(47827,15305,'120855','printshop-mobile','padding-bottom','20',0,''),(55610,17790,'118459','deals-mobile','text','##TEXT_PAGE_NOT_FOUND##',0,''),(55611,17790,'118459','deals-mobile','text-align','center',0,''),(55612,17790,'118459','deals-mobile','padding-top','100',0,''),(55613,17790,'118459','deals-mobile','padding-bottom','100',0,''),(55614,17791,'118460','deals-mobile','block_type','1',0,''),(55733,17807,'118476','deals-mobile','block_type','1',0,''),(55852,17823,'118492','deals-mobile','block_type','1',0,''),(55971,17839,'118508','deals-mobile','block_type','1',0,''),(56090,17855,'118524','deals-mobile','block_type','1',0,''),(56209,17871,'118540','deals-mobile','block_type','1',0,''),(56328,17887,'118556','deals-mobile','block_type','1',0,''),(56329,17888,'118557','deals-mobile','block_type','6',0,''),(56330,17888,'118557','deals-mobile','schema','6-3',0,''),(56331,17888,'118557','deals-mobile','schema','6-3',0,'872'),(56332,17889,'118558','deals-mobile','aria_name','account-menu',0,''),(56333,17890,'118559','deals-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(56334,17891,'118560','deals-mobile','link','Order History Info',0,''),(56335,17891,'118560','deals-mobile','text','TEXT_VIEW',0,''),(56336,17891,'118560','deals-mobile','max_orders','3',0,''),(56337,17891,'118560','deals-mobile','link_pay','Order pay',0,''),(56338,17891,'118560','deals-mobile','margin-bottom','30',0,''),(56339,17891,'118560','deals-mobile','text_pay','ORDER_PAY',0,''),(56340,17892,'118561','deals-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(56341,17893,'118562','deals-mobile','block_type','15',0,''),(56342,17893,'118562','deals-mobile','margin-bottom','30',0,''),(56343,17893,'118562','deals-mobile','padding-top','20',0,''),(56344,17893,'118562','deals-mobile','padding-left','20',0,''),(56345,17893,'118562','deals-mobile','padding-right','20',0,''),(56346,17893,'118562','deals-mobile','padding-bottom','20',0,''),(56347,17893,'118562','deals-mobile','border-top-width','1',0,''),(56348,17893,'118562','deals-mobile','border-top-color','#e0e0e0',0,''),(56349,17893,'118562','deals-mobile','border-left-width','1',0,''),(56350,17893,'118562','deals-mobile','border-right-width','1',0,''),(56351,17893,'118562','deals-mobile','border-bottom-width','1',0,''),(56352,17893,'118562','deals-mobile','border-left-color','#e0e0e0',0,''),(56353,17893,'118562','deals-mobile','border-right-color','#e0e0e0',0,''),(56354,17893,'118562','deals-mobile','border-bottom-color','#e0e0e0',0,''),(56355,17893,'118562','deals-mobile','schema','15-2',0,'872'),(56356,17894,'118563','deals-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(56357,17894,'118563','deals-mobile','font-family','trueloaded',0,'3'),(56358,17894,'118563','deals-mobile','content','\\e920',0,'3'),(56359,17894,'118563','deals-mobile','color','#ee4225',0,'3'),(56360,17894,'118563','deals-mobile','font-size','30',0,'3'),(56361,17894,'118563','deals-mobile','text-align','center',0,'3'),(56362,17894,'118563','deals-mobile','margin-bottom','10',0,'3'),(56363,17894,'118563','deals-mobile','text-align','center',0,''),(56364,17894,'118563','deals-mobile','font-size','16',0,''),(56365,17894,'118563','deals-mobile','text-transform','uppercase',0,''),(56366,17894,'118563','deals-mobile','line-height','1',0,'3'),(56368,17895,'118564','deals-mobile','font-family','Varela Round',0,''),(56369,17895,'118564','deals-mobile','color','#ee4225',0,''),(56370,17895,'118564','deals-mobile','font-size','14',0,''),(56371,17895,'118564','deals-mobile','text-align','center',0,''),(56372,17896,'118565','deals-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(56373,17896,'118565','deals-mobile','font-family','trueloaded',0,'3'),(56374,17896,'118565','deals-mobile','content','\\e928',0,'3'),(56375,17896,'118565','deals-mobile','color','#ee4225',0,'3'),(56376,17896,'118565','deals-mobile','font-size','30',0,'3'),(56377,17896,'118565','deals-mobile','text-align','center',0,'3'),(56378,17896,'118565','deals-mobile','text-align','center',0,''),(56379,17896,'118565','deals-mobile','font-size','16',0,''),(56380,17896,'118565','deals-mobile','text-transform','uppercase',0,''),(56381,17896,'118565','deals-mobile','line-height','1',0,'3'),(56383,17897,'118566','deals-mobile','link','download_orders',0,''),(56384,17897,'118566','deals-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(56385,17897,'118566','deals-mobile','hide_link','orders',0,''),(56386,17897,'118566','deals-mobile','text-align','center',0,''),(56387,17897,'118566','deals-mobile','popup','2',0,''),(56388,17897,'118566','deals-mobile','font-size','14',0,''),(56389,17898,'118567','deals-mobile','font-family','Varela Round',0,''),(56390,17898,'118567','deals-mobile','color','#ee4225',0,''),(56391,17898,'118567','deals-mobile','font-size','14',0,''),(56392,17898,'118567','deals-mobile','text-align','center',0,''),(56393,17899,'118568','deals-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(56394,17899,'118568','deals-mobile','font-family','trueloaded',0,'3'),(56395,17899,'118568','deals-mobile','content','\\e922',0,'3'),(56396,17899,'118568','deals-mobile','color','#ee4225',0,'3'),(56397,17899,'118568','deals-mobile','font-size','30',0,'3'),(56398,17899,'118568','deals-mobile','line-height','1',0,'3'),(56399,17899,'118568','deals-mobile','font-size','16',0,''),(56400,17899,'118568','deals-mobile','text-align','center',0,''),(56401,17899,'118568','deals-mobile','text-transform','uppercase',0,''),(56403,17900,'118569','deals-mobile','font-family','Varela Round',0,''),(56404,17900,'118569','deals-mobile','color','#ee4225',0,''),(56405,17900,'118569','deals-mobile','line-height','1',0,''),(56406,17900,'118569','deals-mobile','text-align','center',0,''),(56407,17900,'118569','deals-mobile','font-size','14',0,''),(56408,17901,'118570','deals-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(56409,17901,'118570','deals-mobile','content','\\e994',0,'3'),(56410,17901,'118570','deals-mobile','font-family','trueloaded',0,'3'),(56411,17901,'118570','deals-mobile','color','#ee4225',0,'3'),(56412,17901,'118570','deals-mobile','font-size','30',0,'3'),(56413,17901,'118570','deals-mobile','line-height','1',0,'3'),(56414,17901,'118570','deals-mobile','font-size','16',0,''),(56415,17901,'118570','deals-mobile','text-align','center',0,''),(56416,17901,'118570','deals-mobile','text-transform','uppercase',0,''),(56418,17902,'118571','deals-mobile','link','Gift Certificate',0,''),(56419,17902,'118571','deals-mobile','text','GIFT_CERTIFICATE',0,''),(56420,17902,'118571','deals-mobile','popup','1',0,''),(56421,17902,'118571','deals-mobile','text-align','center',0,''),(56422,17902,'118571','deals-mobile','font-size','14',0,''),(56423,17903,'118572','deals-mobile','font-family','Varela Round',0,''),(56424,17903,'118572','deals-mobile','color','#ee4225',0,''),(56425,17903,'118572','deals-mobile','font-size','14',0,''),(56426,17903,'118572','deals-mobile','text-align','center',0,''),(56427,17904,'118573','deals-mobile','text','TEXT_VIEW_HISTORY',0,''),(56428,17904,'118573','deals-mobile','popup','1',0,''),(56429,17904,'118573','deals-mobile','text-align','center',0,''),(56430,17904,'118573','deals-mobile','link','Points Earnt History',0,''),(56431,17904,'118573','deals-mobile','font-size','14',0,''),(56432,17905,'118574','deals-mobile','font-family','Varela Round',0,''),(56433,17905,'118574','deals-mobile','color','#ee4225',0,''),(56434,17905,'118574','deals-mobile','font-size','14',0,''),(56435,17905,'118574','deals-mobile','text-align','center',0,''),(56436,17906,'118575','deals-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(56437,17906,'118575','deals-mobile','content','\\e990',0,'3'),(56438,17906,'118575','deals-mobile','font-family','trueloaded',0,'3'),(56439,17906,'118575','deals-mobile','font-size','30',0,'3'),(56440,17906,'118575','deals-mobile','text-align','center',0,'3'),(56441,17906,'118575','deals-mobile','line-height','1',0,'3'),(56442,17906,'118575','deals-mobile','color','#ee4225',0,'3'),(56443,17906,'118575','deals-mobile','font-size','16',0,''),(56444,17906,'118575','deals-mobile','text-align','center',0,''),(56445,17906,'118575','deals-mobile','text-transform','uppercase',0,''),(56447,17907,'118576','deals-mobile','block_type','1',0,''),(56448,17908,'118577','deals-mobile','hide_parents','2',0,''),(56449,17909,'118578','deals-mobile','text','<div class=\"heading-3\">##TEXT_GIFT_CARDS##</div>',0,''),(56450,17911,'118580','deals-mobile','block_type','1',0,''),(56451,17911,'118580','deals-mobile','padding-top','70',0,''),(56452,17911,'118580','deals-mobile','padding-right','30',0,''),(56453,17911,'118580','deals-mobile','padding-bottom','30',0,''),(56455,17911,'118580','deals-mobile','padding-left','0',0,''),(56458,17912,'118581','deals-mobile','block_type','1',0,''),(56459,17912,'118581','deals-mobile','padding-right','20',0,''),(56460,17912,'118581','deals-mobile','style_class','account-menu',0,''),(56461,17912,'118581','deals-mobile','padding-top','20',0,''),(56462,17912,'118581','deals-mobile','margin-bottom','20',0,''),(56463,17912,'118581','deals-mobile','background-color','#eeeeee',0,''),(56464,17912,'118581','deals-mobile','padding-left','20',0,''),(56465,17912,'118581','deals-mobile','padding-bottom','20',0,''),(56466,17913,'118582','deals-mobile','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(56467,17913,'118582','deals-mobile','style_class','heading-settings',0,''),(56468,17914,'118583','deals-mobile','link','delete',0,''),(56469,17914,'118583','deals-mobile','text','DELETE_ACCOUNT',0,''),(56470,17915,'118584','deals-mobile','text','TEXT_DASHBOARD',0,''),(56471,17915,'118584','deals-mobile','font-family','Varela Round',0,''),(56472,17915,'118584','deals-mobile','font-size','18',0,''),(56473,17915,'118584','deals-mobile','text-transform','uppercase',0,''),(56474,17916,'118585','deals-mobile','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(56475,17916,'118585','deals-mobile','style_class','heading-saved-lists',0,''),(56476,17917,'118586','deals-mobile','link','logoff',0,''),(56477,17918,'118587','deals-mobile','link','Personal Catalog',0,''),(56478,17918,'118587','deals-mobile','text','TEXT_PERSONAL_CATALOG',0,''),(56479,17918,'118587','deals-mobile','hide_link','personal_catalog',0,''),(56480,17919,'118588','deals-mobile','link','Address Book',0,''),(56481,17919,'118588','deals-mobile','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(56482,17920,'118589','deals-mobile','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(56483,17920,'118589','deals-mobile','style_class','heading-ordered-items',0,''),(56484,17921,'118590','deals-mobile','link','Samples',0,''),(56485,17921,'118590','deals-mobile','text','TEXT_HEADING_SAMPLE_CART',0,''),(56486,17921,'118590','deals-mobile','hide_link','samples',0,''),(56487,17922,'118591','deals-mobile','link','Order History',0,''),(56488,17922,'118591','deals-mobile','text','HEADING_ORDER_HISTORY',0,''),(56489,17922,'118591','deals-mobile','active_link','Order History Info,Order pay',0,''),(56490,17923,'118592','deals-mobile','link','My password',0,''),(56491,17923,'118592','deals-mobile','text','TEXT_MY_PASSWORD',0,''),(56492,17924,'118593','deals-mobile','link','Review',0,''),(56493,17924,'118593','deals-mobile','text','REVIEWS',0,''),(56494,17925,'118594','deals-mobile','link','Account edit',0,''),(56495,17925,'118594','deals-mobile','text','ACCOUNT_EDIT',0,''),(56496,17926,'118595','deals-mobile','link','Quotations',0,''),(56497,17926,'118595','deals-mobile','hide_link','quotations',0,''),(56498,17926,'118595','deals-mobile','text','TEXT_HEADING_QUOTE_CART',0,''),(56499,17927,'118596','deals-mobile','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(56500,17927,'118596','deals-mobile','style_class','heading-settings',0,''),(56501,17928,'118597','deals-mobile','link','trade_form',0,''),(56502,17928,'118597','deals-mobile','text','TRADE_FORM',0,''),(56503,17929,'118598','deals-mobile','block_type','1',0,''),(56504,17930,'118599','deals-mobile','block_type','6',0,''),(56505,17930,'118599','deals-mobile','schema','6-3',0,''),(56506,17930,'118599','deals-mobile','schema','6-3',0,'872'),(56507,17931,'118600','deals-mobile','aria_name','account-menu',0,''),(56508,17933,'118602','deals-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(56509,17934,'118603','deals-mobile','text','CANCEL',0,''),(56510,17934,'118603','deals-mobile','like_button','1',0,''),(56511,17934,'118603','deals-mobile','padding-bottom','20',0,''),(56512,17935,'118604','deals-mobile','block_type','1',0,''),(56513,17936,'118605','deals-mobile','block_type','6',0,''),(56514,17936,'118605','deals-mobile','schema','6-3',0,''),(56515,17936,'118605','deals-mobile','schema','6-3',0,'872'),(56516,17937,'118606','deals-mobile','aria_name','account-menu',0,''),(56517,17938,'118607','deals-mobile','padding-top','15',0,''),(56518,17938,'118607','deals-mobile','padding-bottom','15',0,''),(56519,17938,'118607','deals-mobile','link','Address Book Process',0,''),(56520,17938,'118607','deals-mobile','text','EDIT',0,''),(56521,17938,'118607','deals-mobile','link_add','Address Book Process',0,''),(56522,17938,'118607','deals-mobile','like_button_add','2',0,''),(56523,17938,'118607','deals-mobile','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(56524,17939,'118608','deals-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1><div class=\"info-popup bottom-left\">\n<div><ul><li>##PRIMARY_ADDRESS##<br>##PRIMARY_ADDRESS_DESCRIPTION##<br></li><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(56525,17939,'118608','deals-mobile','text-align','center',0,''),(56526,17940,'118609','deals-mobile','block_type','1',0,''),(56527,17941,'118610','deals-mobile','block_type','6',0,''),(56528,17941,'118610','deals-mobile','schema','6-3',0,''),(56529,17941,'118610','deals-mobile','schema','6-3',0,'872'),(56530,17942,'118611','deals-mobile','aria_name','account-menu',0,''),(56531,17944,'118613','deals-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(56532,17945,'118614','deals-mobile','text','CANCEL',0,''),(56533,17945,'118614','deals-mobile','like_button','1',0,''),(56534,17945,'118614','deals-mobile','padding-bottom','20',0,''),(56535,17945,'118614','deals-mobile','link','Address Book',0,''),(56536,17946,'118615','deals-mobile','block_type','1',0,''),(56537,17946,'118615','deals-mobile','style_class','item-holder',0,''),(56538,17946,'118615','deals-mobile','padding-top','25',0,''),(56539,17946,'118615','deals-mobile','padding-bottom','25',0,''),(56540,17946,'118615','deals-mobile','text-align','left',0,''),(56541,17946,'118615','deals-mobile','border-top-color','#e0e0e0',0,''),(56542,17946,'118615','deals-mobile','border-top-width','1',0,''),(56543,17947,'118616','deals-mobile','block_type','6',0,''),(56544,17948,'118617','deals-mobile','padding-right','20',0,''),(56545,17949,'118618','deals-mobile','clear','none',0,''),(56546,17951,'118620','deals-mobile','block_type','4',0,''),(56547,17952,'118621','deals-mobile','block_type','2',0,''),(56548,17953,'118622','deals-mobile','margin-bottom','7',0,''),(56549,17954,'118623','deals-mobile','clear','none',0,''),(56550,17955,'118624','deals-mobile','margin-bottom','20',0,''),(56551,17955,'118624','deals-mobile','text-align','right',0,''),(56552,17956,'118625','deals-mobile','description_characters','200',0,''),(56553,17956,'118625','deals-mobile','clear','none',0,''),(56554,17956,'118625','deals-mobile','padding-right','20',0,''),(56555,17957,'118626','deals-mobile','block_type','2',0,''),(56556,17958,'118627','deals-mobile','clear','none',0,''),(56557,17960,'118629','deals-mobile','padding-right','20',0,''),(56558,17961,'118630','deals-mobile','block_type','1',0,''),(56559,17961,'118630','deals-mobile','style_class','item-holder',0,''),(56560,17961,'118630','deals-mobile','padding-top','25',0,''),(56561,17961,'118630','deals-mobile','padding-left','25',0,''),(56562,17961,'118630','deals-mobile','padding-right','25',0,''),(56563,17961,'118630','deals-mobile','padding-bottom','25',0,''),(56564,17961,'118630','deals-mobile','text-align','left',0,''),(56565,17963,'118632','deals-mobile','margin-bottom','7',0,''),(56566,17964,'118633','deals-mobile','clear','both',0,''),(56567,17967,'118636','deals-mobile','block_type','1',0,''),(56568,17967,'118636','deals-mobile','style_class','item-holder',0,''),(56569,17967,'118636','deals-mobile','padding-top','25',0,''),(56570,17967,'118636','deals-mobile','padding-left','25',0,''),(56571,17967,'118636','deals-mobile','padding-right','25',0,''),(56572,17967,'118636','deals-mobile','padding-bottom','25',0,''),(56573,17967,'118636','deals-mobile','text-align','left',0,''),(56574,17968,'118637','deals-mobile','block_type','5',0,''),(56575,17971,'118640','deals-mobile','margin-bottom','7',0,''),(56576,17972,'118641','deals-mobile','clear','both',0,''),(56577,17973,'118642','deals-mobile','block_type','1',0,''),(56578,17974,'118643','deals-mobile','block_type','6',0,''),(56579,17974,'118643','deals-mobile','font-weight','400',0,''),(56580,17974,'118643','deals-mobile','schema','6-2',0,''),(56582,17975,'118644','deals-mobile','font-weight','400',0,''),(56583,17975,'118644','deals-mobile','padding-right','40',0,''),(56586,17976,'118645','deals-mobile','block_type','5',0,''),(56587,17976,'118645','deals-mobile','padding-top','10',0,''),(56588,17976,'118645','deals-mobile','padding-bottom','10',0,''),(56589,17976,'118645','deals-mobile','schema','5-2',0,''),(56590,17976,'118645','deals-mobile','border-top-color','#e0e0e0',0,''),(56591,17976,'118645','deals-mobile','border-top-width','1',0,''),(56592,17978,'118647','deals-mobile','float','right',0,''),(56593,17980,'118649','deals-mobile','col_in_row','3',0,''),(56594,17980,'118649','deals-mobile','products_align','left',0,''),(56595,17980,'118649','deals-mobile','font-weight','400',0,''),(56596,17980,'118649','deals-mobile','show_qty_input','0',0,''),(56597,17980,'118649','deals-mobile','listing_type','productListing',0,''),(56598,17980,'118649','deals-mobile','listing_type_rows','no',0,''),(56599,17980,'118649','deals-mobile','show_buy_button_b2b','on',0,''),(56600,17980,'118649','deals-mobile','show_wishlist_button_b2b','1',0,''),(56601,17980,'118649','deals-mobile','show_compare_b2b','1',0,''),(56602,17980,'118649','deals-mobile','show_stock','0',0,''),(56603,17980,'118649','deals-mobile','show_description','0',0,''),(56604,17980,'118649','deals-mobile','show_model','0',0,''),(56605,17980,'118649','deals-mobile','show_properties','0',0,''),(56606,17980,'118649','deals-mobile','show_rating','0',0,''),(56607,17980,'118649','deals-mobile','show_rating_counts','0',0,''),(56608,17980,'118649','deals-mobile','show_price','0',0,''),(56609,17980,'118649','deals-mobile','show_buy_button','0',0,''),(56610,17980,'118649','deals-mobile','show_view_button','0',0,''),(56611,17980,'118649','deals-mobile','show_wishlist_button','0',0,''),(56612,17980,'118649','deals-mobile','show_compare','0',0,''),(56613,17980,'118649','deals-mobile','show_name_rows','0',0,''),(56614,17980,'118649','deals-mobile','show_image_rows','0',0,''),(56615,17980,'118649','deals-mobile','show_stock_rows','0',0,''),(56616,17980,'118649','deals-mobile','show_description_rows','0',0,''),(56617,17980,'118649','deals-mobile','show_model_rows','0',0,''),(56618,17980,'118649','deals-mobile','show_properties_rows','0',0,''),(56619,17980,'118649','deals-mobile','show_rating_rows','0',0,''),(56620,17980,'118649','deals-mobile','show_rating_counts_rows','0',0,''),(56621,17980,'118649','deals-mobile','show_price_rows','0',0,''),(56622,17980,'118649','deals-mobile','show_buy_button_rows','0',0,''),(56623,17980,'118649','deals-mobile','show_qty_input_rows','0',0,''),(56624,17980,'118649','deals-mobile','show_view_button_rows','0',0,''),(56625,17980,'118649','deals-mobile','show_wishlist_button_rows','0',0,''),(56626,17980,'118649','deals-mobile','show_compare_rows','0',0,''),(56627,17980,'118649','deals-mobile','show_name_b2b','0',0,''),(56628,17980,'118649','deals-mobile','show_image_b2b','0',0,''),(56629,17980,'118649','deals-mobile','show_stock_b2b','0',0,''),(56630,17980,'118649','deals-mobile','show_description_b2b','0',0,''),(56631,17980,'118649','deals-mobile','show_model_b2b','0',0,''),(56632,17980,'118649','deals-mobile','show_properties_b2b','0',0,''),(56633,17980,'118649','deals-mobile','show_rating_b2b','0',0,''),(56634,17980,'118649','deals-mobile','show_rating_counts_b2b','0',0,''),(56635,17980,'118649','deals-mobile','show_price_b2b','0',0,''),(56636,17980,'118649','deals-mobile','show_qty_input_b2b','0',0,''),(56637,17980,'118649','deals-mobile','show_view_button_b2b','0',0,''),(56638,17980,'118649','deals-mobile','show_attributes_b2b','0',0,''),(56639,17980,'118649','deals-mobile','items_on_page','9',0,''),(56642,17980,'118649','deals-mobile','product_names_teg','h2',0,''),(56643,17981,'118650','deals-mobile','listing_type','productListing',0,''),(56644,17982,'118651','deals-mobile','block_type','1',0,''),(56645,17982,'118651','deals-mobile','padding-top','10',0,''),(56646,17982,'118651','deals-mobile','padding-bottom','10',0,''),(56647,17982,'118651','deals-mobile','border-bottom-width','1',0,''),(56648,17982,'118651','deals-mobile','border-bottom-color','#e0e0e0',0,''),(56649,17982,'118651','deals-mobile','margin-left','0',0,''),(56650,17982,'118651','deals-mobile','margin-right','0',0,''),(56651,17983,'118652','deals-mobile','float','right',0,''),(56652,17983,'118652','deals-mobile','display','none',0,''),(56653,17984,'118653','deals-mobile','margin-right','20',0,''),(56654,17984,'118653','deals-mobile','float','right',0,''),(56655,17984,'118653','deals-mobile','clear','none',0,''),(56656,17984,'118653','deals-mobile','display','none',0,''),(56657,17985,'118654','deals-mobile','float','left',0,''),(56658,17985,'118654','deals-mobile','clear','none',0,''),(56659,17985,'118654','deals-mobile','margin-left','20',0,''),(56660,17985,'118654','deals-mobile','display','none',0,''),(56661,17986,'118655','deals-mobile','float','left',0,''),(56662,17986,'118655','deals-mobile','clear','none',0,''),(56663,17986,'118655','deals-mobile','sort_pos_3','1',0,''),(56664,17986,'118655','deals-mobile','sort_pos_4','2',0,''),(56665,17986,'118655','deals-mobile','sort_pos_10','3',0,''),(56666,17986,'118655','deals-mobile','sort_pos_9','4',0,''),(56667,17986,'118655','deals-mobile','sort_pos_11','5',0,''),(56668,17986,'118655','deals-mobile','sort_pos_12','6',0,''),(56669,17986,'118655','deals-mobile','sort_pos_14','7',0,''),(56670,17986,'118655','deals-mobile','sort_pos_13','8',0,''),(56671,17986,'118655','deals-mobile','sort_pos_8','9',0,''),(56672,17986,'118655','deals-mobile','sort_pos_7','10',0,''),(56673,17986,'118655','deals-mobile','sort_pos_2','11',0,''),(56674,17986,'118655','deals-mobile','sort_pos_1','12',0,''),(56675,17986,'118655','deals-mobile','sort_pos_6','13',0,''),(56676,17986,'118655','deals-mobile','sort_pos_5','14',0,''),(56677,17986,'118655','deals-mobile','sort_pos_0','15',0,''),(56678,17986,'118655','deals-mobile','sort_hide_10','1',0,''),(56679,17986,'118655','deals-mobile','sort_hide_9','1',0,''),(56680,17986,'118655','deals-mobile','hide_icons','1',0,''),(56681,17986,'118655','deals-mobile','sort_hide_16','1',0,''),(56682,17986,'118655','deals-mobile','sort_hide_15','1',0,''),(56683,17986,'118655','deals-mobile','sort_hide_3','0',0,''),(56684,17986,'118655','deals-mobile','sort_hide_4','0',0,''),(56685,17986,'118655','deals-mobile','sort_hide_11','1',0,''),(56686,17986,'118655','deals-mobile','sort_hide_12','1',0,''),(56687,17986,'118655','deals-mobile','sort_hide_14','1',0,''),(56688,17986,'118655','deals-mobile','sort_hide_13','1',0,''),(56689,17986,'118655','deals-mobile','sort_hide_8','0',0,''),(56690,17986,'118655','deals-mobile','sort_hide_7','0',0,''),(56691,17986,'118655','deals-mobile','sort_hide_2','1',0,''),(56692,17986,'118655','deals-mobile','sort_hide_1','1',0,''),(56693,17986,'118655','deals-mobile','sort_hide_6','1',0,''),(56694,17986,'118655','deals-mobile','sort_hide_5','1',0,''),(56695,17986,'118655','deals-mobile','sort_hide_0','1',0,''),(56696,17989,'118658','deals-mobile','block_type','1',0,''),(56697,17990,'118659','deals-mobile','block_type','7',0,''),(56698,17990,'118659','deals-mobile','schema','7-2',0,'890'),(56699,17991,'118660','deals-mobile','padding-top','20',0,''),(56700,17991,'118660','deals-mobile','padding-right','20',0,''),(56701,17992,'118661','deals-mobile','blog_sidebar','1',0,''),(56702,17992,'118661','deals-mobile','padding-top','20',0,''),(56703,17992,'118661','deals-mobile','padding-left','20',0,''),(56704,17993,'118662','deals-mobile','block_type','1',0,''),(56705,17994,'118663','deals-mobile','item_tag','h2',0,''),(56706,17994,'118663','deals-mobile','hTagsInline','inline',0,''),(56707,17998,'118667','deals-mobile','block_type','1',0,''),(56708,17998,'118667','deals-mobile','schema','4-1',0,''),(56710,17998,'118667','deals-mobile','schema','4-1',0,'872'),(56711,17999,'118668','deals-mobile','block_type','1',0,''),(56712,17999,'118668','deals-mobile','background-color','#ffffff',0,''),(56713,17999,'118668','deals-mobile','padding-top','20',0,''),(56714,17999,'118668','deals-mobile','padding-bottom','20',0,''),(56715,17999,'118668','deals-mobile','margin-bottom','30',0,''),(56716,18000,'118669','deals-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(56717,18000,'118669','deals-mobile','style_class','bell-ico',0,''),(56718,18001,'118670','deals-mobile','col_in_row','3',0,''),(56719,18001,'118670','deals-mobile','show_description','1',0,''),(56720,18001,'118670','deals-mobile','show_model','1',0,''),(56721,18001,'118670','deals-mobile','show_properties','1',0,''),(56722,18001,'118670','deals-mobile','show_rating','1',0,''),(56723,18001,'118670','deals-mobile','show_rating_counts','1',0,''),(56724,18001,'118670','deals-mobile','show_qty_input','1',0,''),(56725,18001,'118670','deals-mobile','show_view_button','1',0,''),(56726,18001,'118670','deals-mobile','show_wishlist_button','1',0,''),(56727,18001,'118670','deals-mobile','show_compare','1',0,''),(56728,18001,'118670','deals-mobile','view_as','carousel',0,''),(56729,18001,'118670','deals-mobile','hide_parents','2',0,''),(56730,18002,'118671','deals-mobile','block_type','1',0,''),(56731,18002,'118671','deals-mobile','background-color','#ffffff',0,''),(56732,18002,'118671','deals-mobile','margin-bottom','30',0,''),(56733,18003,'118672','deals-mobile','padding-top','20',0,''),(56734,18003,'118672','deals-mobile','padding-bottom','20',0,''),(56735,18004,'118673','deals-mobile','block_type','2',0,''),(56736,18004,'118673','deals-mobile','padding-bottom','20',0,''),(56737,18004,'118673','deals-mobile','padding-top','20',0,''),(56738,18004,'118673','deals-mobile','border-bottom-color','#e0e0e0',0,''),(56739,18004,'118673','deals-mobile','border-bottom-width','1',0,''),(56740,18004,'118673','deals-mobile','schema','2-2',0,''),(56741,18005,'118674','deals-mobile','padding-top','22',0,''),(56742,18006,'118675','deals-mobile','float','right',0,''),(56743,18006,'118675','deals-mobile','padding-top','26',0,''),(56744,18007,'118676','deals-mobile','float','left',0,''),(56745,18008,'118677','deals-mobile','block_type','1',0,''),(56746,18008,'118677','deals-mobile','padding-top','20',0,''),(56747,18008,'118677','deals-mobile','padding-bottom','20',0,''),(56748,18008,'118677','deals-mobile','background-color','#ffffff',0,''),(56749,18008,'118677','deals-mobile','margin-bottom','30',0,''),(56750,18009,'118678','deals-mobile','hide_parents','2',0,''),(56751,18010,'118679','deals-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(56752,18011,'118680','deals-mobile','block_type','1',0,''),(56753,18011,'118680','deals-mobile','background-color','#ffffff',0,''),(56754,18011,'118680','deals-mobile','padding-top','20',0,''),(56755,18011,'118680','deals-mobile','padding-bottom','20',0,''),(56756,18011,'118680','deals-mobile','margin-bottom','30',0,''),(56757,18011,'118680','deals-mobile','style_class','closeable-box',0,''),(56758,18012,'118681','deals-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(56759,18012,'118681','deals-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(56760,18013,'118682','deals-mobile','block_type','1',0,''),(56761,18013,'118682','deals-mobile','font-weight','400',0,''),(56762,18013,'118682','deals-mobile','schema','2-2',0,''),(56763,18013,'118682','deals-mobile','style_class','closeable-content',0,''),(56764,18013,'118682','deals-mobile','padding-top','10',0,''),(56765,18014,'118683','deals-mobile','font-weight','400',0,''),(56766,18014,'118683','deals-mobile','padding-top','12',0,''),(56767,18014,'118683','deals-mobile','padding-left','0',0,''),(56768,18017,'118686','deals-mobile','block_type','1',0,''),(56769,18017,'118686','deals-mobile','background-color','#ffffff',0,''),(56770,18017,'118686','deals-mobile','padding-top','20',0,''),(56771,18017,'118686','deals-mobile','padding-left','25',0,''),(56772,18017,'118686','deals-mobile','padding-right','25',0,''),(56773,18017,'118686','deals-mobile','padding-bottom','20',0,''),(56774,18017,'118686','deals-mobile','margin-bottom','30',0,''),(56775,18017,'118686','deals-mobile','style_class','closeable-box',0,''),(56776,18017,'118686','deals-mobile','display','none',0,''),(56778,18018,'118687','deals-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(56779,18018,'118687','deals-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(56780,18019,'118688','deals-mobile','font-weight','normal',0,''),(56781,18019,'118688','deals-mobile','style_class','closeable-content',0,''),(56782,18019,'118688','deals-mobile','padding-top','10',0,''),(56783,18019,'118688','deals-mobile','hide_parents','2',0,''),(56784,18020,'118689','deals-mobile','style_class','order-summary',0,''),(56785,18020,'118689','deals-mobile','block_type','1',0,''),(56786,18020,'118689','deals-mobile','margin-left','30',0,''),(56788,18020,'118689','deals-mobile','margin-bottom','30',0,''),(56789,18021,'118690','deals-mobile','block_type','1',0,''),(56790,18021,'118690','deals-mobile','padding-bottom','20',0,''),(56791,18022,'118691','deals-mobile','font-weight','400',0,''),(56792,18022,'118691','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',1,''),(56793,18022,'118691','deals-mobile','padding-top','20',0,''),(56794,18022,'118691','deals-mobile','padding-bottom','10',0,''),(56795,18023,'118692','deals-mobile','font-weight','400',0,''),(56796,18023,'118692','deals-mobile','box_align','4',0,''),(56797,18023,'118692','deals-mobile','text-align','center',0,''),(56798,18023,'118692','deals-mobile','float','none',0,''),(56799,18023,'118692','deals-mobile','width','100',0,''),(56800,18023,'118692','deals-mobile','width_measure','%',0,''),(56801,18025,'118694','deals-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(56802,18026,'118695','deals-mobile','block_type','1',0,''),(56803,18026,'118695','deals-mobile','font-weight','normal',0,''),(56804,18026,'118695','deals-mobile','padding-top','20',0,''),(56805,18026,'118695','deals-mobile','background-color','#eeeeee',0,''),(56806,18028,'118697','deals-mobile','block_type','4',0,''),(56807,18028,'118697','deals-mobile','schema','4-1',0,''),(56809,18029,'118698','deals-mobile','block_type','1',0,''),(56810,18029,'118698','deals-mobile','background-color','#ffffff',0,''),(56811,18029,'118698','deals-mobile','padding-top','20',0,''),(56812,18029,'118698','deals-mobile','padding-bottom','20',0,''),(56813,18029,'118698','deals-mobile','padding-left','25',0,''),(56814,18029,'118698','deals-mobile','padding-right','25',0,''),(56815,18029,'118698','deals-mobile','margin-bottom','30',0,''),(56816,18030,'118699','deals-mobile','col_in_row','3',0,''),(56817,18030,'118699','deals-mobile','show_description','1',0,''),(56818,18030,'118699','deals-mobile','show_model','1',0,''),(56819,18030,'118699','deals-mobile','show_properties','1',0,''),(56820,18030,'118699','deals-mobile','show_rating','1',0,''),(56821,18030,'118699','deals-mobile','show_rating_counts','1',0,''),(56822,18030,'118699','deals-mobile','show_qty_input','1',0,''),(56823,18030,'118699','deals-mobile','show_view_button','1',0,''),(56824,18030,'118699','deals-mobile','show_wishlist_button','1',0,''),(56825,18030,'118699','deals-mobile','show_compare','1',0,''),(56826,18030,'118699','deals-mobile','view_as','carousel',0,''),(56827,18030,'118699','deals-mobile','hide_parents','2',0,''),(56828,18031,'118700','deals-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(56829,18031,'118700','deals-mobile','style_class','bell-ico',0,''),(56830,18032,'118701','deals-mobile','block_type','1',0,''),(56831,18032,'118701','deals-mobile','background-color','#ffffff',0,''),(56832,18032,'118701','deals-mobile','margin-bottom','30',0,''),(56833,18033,'118702','deals-mobile','padding-top','20',0,''),(56834,18033,'118702','deals-mobile','padding-left','25',0,''),(56835,18033,'118702','deals-mobile','padding-right','25',0,''),(56836,18033,'118702','deals-mobile','padding-bottom','20',0,''),(56837,18034,'118703','deals-mobile','block_type','2',0,''),(56838,18034,'118703','deals-mobile','padding-bottom','20',0,''),(56839,18034,'118703','deals-mobile','padding-top','20',0,''),(56840,18034,'118703','deals-mobile','padding-left','25',0,''),(56841,18034,'118703','deals-mobile','padding-right','25',0,''),(56842,18034,'118703','deals-mobile','border-bottom-color','#e0e0e0',0,''),(56843,18034,'118703','deals-mobile','border-bottom-width','1',0,''),(56844,18034,'118703','deals-mobile','schema','2-2',0,''),(56845,18035,'118704','deals-mobile','float','left',0,''),(56846,18036,'118705','deals-mobile','text-align','right',0,''),(56847,18036,'118705','deals-mobile','clear','none',0,''),(56848,18036,'118705','deals-mobile','float','right',0,''),(56849,18036,'118705','deals-mobile','padding-top','22',0,''),(56850,18037,'118706','deals-mobile','float','right',0,''),(56851,18037,'118706','deals-mobile','padding-top','26',0,''),(56852,18038,'118707','deals-mobile','block_type','1',0,''),(56853,18038,'118707','deals-mobile','padding-top','20',0,''),(56854,18038,'118707','deals-mobile','padding-bottom','20',0,''),(56855,18038,'118707','deals-mobile','padding-left','25',0,''),(56856,18038,'118707','deals-mobile','padding-right','25',0,''),(56857,18038,'118707','deals-mobile','background-color','#ffffff',0,''),(56858,18038,'118707','deals-mobile','margin-bottom','30',0,''),(56859,18039,'118708','deals-mobile','hide_parents','2',0,''),(56860,18040,'118709','deals-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(56861,18041,'118710','deals-mobile','block_type','1',0,''),(56862,18041,'118710','deals-mobile','background-color','#ffffff',0,''),(56863,18041,'118710','deals-mobile','padding-top','20',0,''),(56864,18041,'118710','deals-mobile','padding-bottom','20',0,''),(56865,18041,'118710','deals-mobile','padding-left','25',0,''),(56866,18041,'118710','deals-mobile','padding-right','25',0,''),(56867,18041,'118710','deals-mobile','margin-bottom','30',0,''),(56868,18041,'118710','deals-mobile','style_class','closeable-box',0,''),(56869,18042,'118711','deals-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(56870,18042,'118711','deals-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(56871,18043,'118712','deals-mobile','block_type','3',0,''),(56872,18043,'118712','deals-mobile','font-weight','400',0,''),(56873,18043,'118712','deals-mobile','schema','2-2',0,''),(56874,18043,'118712','deals-mobile','style_class','closeable-content',0,''),(56875,18043,'118712','deals-mobile','padding-top','10',0,''),(56876,18044,'118713','deals-mobile','font-weight','400',0,''),(56877,18044,'118713','deals-mobile','padding-top','12',0,''),(56878,18044,'118713','deals-mobile','padding-left','0',0,''),(56879,18047,'118716','deals-mobile','block_type','1',0,''),(56880,18047,'118716','deals-mobile','background-color','#ffffff',0,''),(56881,18047,'118716','deals-mobile','padding-top','20',0,''),(56882,18047,'118716','deals-mobile','padding-left','25',0,''),(56883,18047,'118716','deals-mobile','padding-right','25',0,''),(56884,18047,'118716','deals-mobile','padding-bottom','20',0,''),(56885,18047,'118716','deals-mobile','margin-bottom','30',0,''),(56886,18047,'118716','deals-mobile','style_class','closeable-box',0,''),(56887,18047,'118716','deals-mobile','display','none',0,''),(56889,18048,'118717','deals-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(56890,18048,'118717','deals-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(56891,18049,'118718','deals-mobile','font-weight','normal',0,''),(56892,18049,'118718','deals-mobile','style_class','closeable-content',0,''),(56893,18049,'118718','deals-mobile','padding-top','10',0,''),(56894,18049,'118718','deals-mobile','hide_parents','2',0,''),(56895,18050,'118719','deals-mobile','style_class','order-summary',0,''),(56896,18050,'118719','deals-mobile','block_type','1',0,''),(56897,18050,'118719','deals-mobile','margin-left','30',0,''),(56899,18050,'118719','deals-mobile','margin-bottom','30',0,''),(56900,18051,'118720','deals-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(56901,18052,'118721','deals-mobile','block_type','1',0,''),(56902,18052,'118721','deals-mobile','padding-left','20',0,''),(56903,18052,'118721','deals-mobile','padding-right','20',0,''),(56904,18052,'118721','deals-mobile','padding-bottom','20',0,''),(56905,18053,'118722','deals-mobile','font-weight','400',0,''),(56906,18053,'118722','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',1,''),(56907,18053,'118722','deals-mobile','padding-top','20',0,''),(56908,18053,'118722','deals-mobile','padding-bottom','10',0,''),(56909,18054,'118723','deals-mobile','font-weight','400',0,''),(56910,18054,'118723','deals-mobile','box_align','4',0,''),(56911,18054,'118723','deals-mobile','text-align','center',0,''),(56912,18054,'118723','deals-mobile','float','none',0,''),(56913,18054,'118723','deals-mobile','width','100',0,''),(56914,18054,'118723','deals-mobile','width_measure','%',0,''),(56915,18056,'118725','deals-mobile','block_type','1',0,''),(56916,18059,'118728','deals-mobile','block_type','1',0,''),(56917,18060,'118729','deals-mobile','col_in_row','2',0,''),(56918,18060,'118729','deals-mobile','products_align','left',0,''),(56919,18060,'118729','deals-mobile','font-weight','400',0,''),(56920,18060,'118729','deals-mobile','show_qty_input','1',0,''),(56921,18060,'118729','deals-mobile','listing_type','productListing',0,''),(56922,18060,'118729','deals-mobile','listing_type_rows','type-1_2',0,''),(56923,18060,'118729','deals-mobile','show_buy_button_b2b','on',0,''),(56924,18060,'118729','deals-mobile','show_wishlist_button_b2b','1',0,''),(56925,18060,'118729','deals-mobile','show_compare_b2b','1',0,''),(56926,18060,'118729','deals-mobile','listing_type_b2b','type-1_3',0,''),(56927,18060,'118729','deals-mobile','show_name','0',0,''),(56928,18060,'118729','deals-mobile','show_image','0',0,''),(56929,18060,'118729','deals-mobile','show_stock','0',0,''),(56930,18060,'118729','deals-mobile','show_description','1',0,''),(56931,18060,'118729','deals-mobile','show_model','1',0,''),(56932,18060,'118729','deals-mobile','show_properties','1',0,''),(56933,18060,'118729','deals-mobile','show_rating_counts','1',0,''),(56934,18060,'118729','deals-mobile','show_price','0',0,''),(56935,18060,'118729','deals-mobile','show_buy_button','1',0,''),(56936,18060,'118729','deals-mobile','show_view_button','1',0,''),(56937,18060,'118729','deals-mobile','show_wishlist_button','1',0,''),(56938,18060,'118729','deals-mobile','show_compare','1',0,''),(56939,18060,'118729','deals-mobile','show_name_rows','0',0,''),(56940,18060,'118729','deals-mobile','show_image_rows','0',0,''),(56941,18060,'118729','deals-mobile','show_stock_rows','0',0,''),(56942,18060,'118729','deals-mobile','show_description_rows','0',0,''),(56943,18060,'118729','deals-mobile','show_model_rows','0',0,''),(56944,18060,'118729','deals-mobile','show_properties_rows','0',0,''),(56945,18060,'118729','deals-mobile','show_rating_rows','0',0,''),(56946,18060,'118729','deals-mobile','show_rating_counts_rows','0',0,''),(56947,18060,'118729','deals-mobile','show_price_rows','0',0,''),(56948,18060,'118729','deals-mobile','show_buy_button_rows','0',0,''),(56949,18060,'118729','deals-mobile','show_qty_input_rows','0',0,''),(56950,18060,'118729','deals-mobile','show_view_button_rows','0',0,''),(56951,18060,'118729','deals-mobile','show_wishlist_button_rows','0',0,''),(56952,18060,'118729','deals-mobile','show_compare_rows','0',0,''),(56953,18060,'118729','deals-mobile','show_name_b2b','0',0,''),(56954,18060,'118729','deals-mobile','show_image_b2b','0',0,''),(56955,18060,'118729','deals-mobile','show_stock_b2b','0',0,''),(56956,18060,'118729','deals-mobile','show_description_b2b','0',0,''),(56957,18060,'118729','deals-mobile','show_model_b2b','0',0,''),(56958,18060,'118729','deals-mobile','show_properties_b2b','0',0,''),(56959,18060,'118729','deals-mobile','show_rating_b2b','0',0,''),(56960,18060,'118729','deals-mobile','show_rating_counts_b2b','0',0,''),(56961,18060,'118729','deals-mobile','show_price_b2b','0',0,''),(56962,18060,'118729','deals-mobile','show_qty_input_b2b','0',0,''),(56963,18060,'118729','deals-mobile','show_view_button_b2b','0',0,''),(56964,18060,'118729','deals-mobile','show_attributes_b2b','0',0,''),(56965,18060,'118729','deals-mobile','items_on_page','10',0,''),(56966,18060,'118729','deals-mobile','product_names_teg','h2',0,''),(56967,18061,'118730','deals-mobile','block_type','2',0,''),(56968,18061,'118730','deals-mobile','margin-bottom','20',0,''),(56969,18062,'118731','deals-mobile','sort_pos_3','1',0,''),(56970,18062,'118731','deals-mobile','sort_pos_4','2',0,''),(56971,18062,'118731','deals-mobile','sort_pos_10','5',0,''),(56972,18062,'118731','deals-mobile','sort_pos_9','6',0,''),(56973,18062,'118731','deals-mobile','sort_pos_11','7',0,''),(56974,18062,'118731','deals-mobile','sort_pos_12','8',0,''),(56975,18062,'118731','deals-mobile','sort_pos_14','9',0,''),(56976,18062,'118731','deals-mobile','sort_pos_13','10',0,''),(56977,18062,'118731','deals-mobile','sort_pos_8','11',0,''),(56978,18062,'118731','deals-mobile','sort_pos_7','12',0,''),(56979,18062,'118731','deals-mobile','sort_pos_2','13',0,''),(56980,18062,'118731','deals-mobile','sort_pos_1','14',0,''),(56981,18062,'118731','deals-mobile','sort_pos_6','15',0,''),(56982,18062,'118731','deals-mobile','sort_pos_5','16',0,''),(56983,18062,'118731','deals-mobile','sort_pos_0','17',0,''),(56984,18062,'118731','deals-mobile','sort_hide_10','1',0,''),(56985,18062,'118731','deals-mobile','sort_hide_9','1',0,''),(56986,18062,'118731','deals-mobile','sort_pos_15','4',0,''),(56987,18062,'118731','deals-mobile','sort_pos_16','3',0,''),(56988,18062,'118731','deals-mobile','sort_hide_3','0',0,''),(56989,18062,'118731','deals-mobile','sort_hide_4','0',0,''),(56990,18062,'118731','deals-mobile','sort_hide_16','1',0,''),(56991,18062,'118731','deals-mobile','sort_hide_15','1',0,''),(56992,18062,'118731','deals-mobile','sort_hide_11','0',0,''),(56993,18062,'118731','deals-mobile','sort_hide_12','0',0,''),(56994,18062,'118731','deals-mobile','sort_hide_14','0',0,''),(56995,18062,'118731','deals-mobile','sort_hide_13','0',0,''),(56996,18062,'118731','deals-mobile','sort_hide_8','0',0,''),(56997,18062,'118731','deals-mobile','sort_hide_7','0',0,''),(56998,18062,'118731','deals-mobile','sort_hide_2','0',0,''),(56999,18062,'118731','deals-mobile','sort_hide_1','0',0,''),(57000,18062,'118731','deals-mobile','sort_hide_6','0',0,''),(57001,18062,'118731','deals-mobile','sort_hide_5','0',0,''),(57002,18062,'118731','deals-mobile','sort_hide_0','0',0,''),(57003,18063,'118732','deals-mobile','text-align','right',0,''),(57004,18063,'118732','deals-mobile','padding-top','10',0,''),(57005,18064,'118733','deals-mobile','text-align','center',0,''),(57006,18064,'118733','deals-mobile','margin-bottom','20',0,''),(57007,18070,'118739','deals-mobile','block_type','1',0,''),(57008,18072,'118741','deals-mobile','block_type','6',0,''),(57009,18072,'118741','deals-mobile','font-weight','400',0,''),(57010,18072,'118741','deals-mobile','schema','6-2',0,''),(57012,18073,'118742','deals-mobile','font-weight','400',0,''),(57013,18073,'118742','deals-mobile','padding-right','40',0,''),(57016,18075,'118744','deals-mobile','col_in_row','3',0,''),(57017,18075,'118744','deals-mobile','products_align','left',0,''),(57018,18075,'118744','deals-mobile','font-weight','400',0,''),(57019,18075,'118744','deals-mobile','show_qty_input','0',0,''),(57020,18075,'118744','deals-mobile','listing_type','productListing',0,''),(57021,18075,'118744','deals-mobile','listing_type_rows','no',0,''),(57022,18075,'118744','deals-mobile','show_buy_button_b2b','on',0,''),(57023,18075,'118744','deals-mobile','show_wishlist_button_b2b','1',0,''),(57024,18075,'118744','deals-mobile','show_compare_b2b','1',0,''),(57025,18075,'118744','deals-mobile','show_stock','0',0,''),(57026,18075,'118744','deals-mobile','show_description','0',0,''),(57027,18075,'118744','deals-mobile','show_model','0',0,''),(57028,18075,'118744','deals-mobile','show_properties','0',0,''),(57029,18075,'118744','deals-mobile','show_rating','0',0,''),(57030,18075,'118744','deals-mobile','show_rating_counts','0',0,''),(57031,18075,'118744','deals-mobile','show_price','0',0,''),(57032,18075,'118744','deals-mobile','show_buy_button','0',0,''),(57033,18075,'118744','deals-mobile','show_view_button','0',0,''),(57034,18075,'118744','deals-mobile','show_wishlist_button','0',0,''),(57035,18075,'118744','deals-mobile','show_compare','0',0,''),(57036,18075,'118744','deals-mobile','show_name_rows','0',0,''),(57037,18075,'118744','deals-mobile','show_image_rows','0',0,''),(57038,18075,'118744','deals-mobile','show_stock_rows','0',0,''),(57039,18075,'118744','deals-mobile','show_description_rows','0',0,''),(57040,18075,'118744','deals-mobile','show_model_rows','0',0,''),(57041,18075,'118744','deals-mobile','show_properties_rows','0',0,''),(57042,18075,'118744','deals-mobile','show_rating_rows','0',0,''),(57043,18075,'118744','deals-mobile','show_rating_counts_rows','0',0,''),(57044,18075,'118744','deals-mobile','show_price_rows','0',0,''),(57045,18075,'118744','deals-mobile','show_buy_button_rows','0',0,''),(57046,18075,'118744','deals-mobile','show_qty_input_rows','0',0,''),(57047,18075,'118744','deals-mobile','show_view_button_rows','0',0,''),(57048,18075,'118744','deals-mobile','show_wishlist_button_rows','0',0,''),(57049,18075,'118744','deals-mobile','show_compare_rows','0',0,''),(57050,18075,'118744','deals-mobile','show_name_b2b','0',0,''),(57051,18075,'118744','deals-mobile','show_image_b2b','0',0,''),(57052,18075,'118744','deals-mobile','show_stock_b2b','0',0,''),(57053,18075,'118744','deals-mobile','show_description_b2b','0',0,''),(57054,18075,'118744','deals-mobile','show_model_b2b','0',0,''),(57055,18075,'118744','deals-mobile','show_properties_b2b','0',0,''),(57056,18075,'118744','deals-mobile','show_rating_b2b','0',0,''),(57057,18075,'118744','deals-mobile','show_rating_counts_b2b','0',0,''),(57058,18075,'118744','deals-mobile','show_price_b2b','0',0,''),(57059,18075,'118744','deals-mobile','show_qty_input_b2b','0',0,''),(57060,18075,'118744','deals-mobile','show_view_button_b2b','0',0,''),(57061,18075,'118744','deals-mobile','show_attributes_b2b','0',0,''),(57062,18075,'118744','deals-mobile','items_on_page','9',0,''),(57065,18075,'118744','deals-mobile','product_names_teg','h2',0,''),(57066,18076,'118745','deals-mobile','block_type','1',0,''),(57067,18076,'118745','deals-mobile','padding-top','10',0,''),(57068,18076,'118745','deals-mobile','padding-bottom','10',0,''),(57069,18076,'118745','deals-mobile','border-bottom-width','1',0,''),(57070,18076,'118745','deals-mobile','border-bottom-color','#e0e0e0',0,''),(57071,18076,'118745','deals-mobile','margin-left','0',0,''),(57072,18076,'118745','deals-mobile','margin-right','0',0,''),(57073,18077,'118746','deals-mobile','float','left',0,''),(57074,18077,'118746','deals-mobile','clear','none',0,''),(57075,18077,'118746','deals-mobile','sort_pos_3','1',0,''),(57076,18077,'118746','deals-mobile','sort_pos_4','2',0,''),(57077,18077,'118746','deals-mobile','sort_pos_10','3',0,''),(57078,18077,'118746','deals-mobile','sort_pos_9','4',0,''),(57079,18077,'118746','deals-mobile','sort_pos_11','5',0,''),(57080,18077,'118746','deals-mobile','sort_pos_12','6',0,''),(57081,18077,'118746','deals-mobile','sort_pos_14','7',0,''),(57082,18077,'118746','deals-mobile','sort_pos_13','8',0,''),(57083,18077,'118746','deals-mobile','sort_pos_8','9',0,''),(57084,18077,'118746','deals-mobile','sort_pos_7','10',0,''),(57085,18077,'118746','deals-mobile','sort_pos_2','11',0,''),(57086,18077,'118746','deals-mobile','sort_pos_1','12',0,''),(57087,18077,'118746','deals-mobile','sort_pos_6','13',0,''),(57088,18077,'118746','deals-mobile','sort_pos_5','14',0,''),(57089,18077,'118746','deals-mobile','sort_pos_0','15',0,''),(57090,18077,'118746','deals-mobile','sort_hide_10','1',0,''),(57091,18077,'118746','deals-mobile','sort_hide_9','1',0,''),(57092,18077,'118746','deals-mobile','hide_icons','1',0,''),(57093,18077,'118746','deals-mobile','sort_hide_16','1',0,''),(57094,18077,'118746','deals-mobile','sort_hide_15','1',0,''),(57095,18077,'118746','deals-mobile','sort_hide_3','0',0,''),(57096,18077,'118746','deals-mobile','sort_hide_4','0',0,''),(57097,18077,'118746','deals-mobile','sort_hide_11','1',0,''),(57098,18077,'118746','deals-mobile','sort_hide_12','1',0,''),(57099,18077,'118746','deals-mobile','sort_hide_14','1',0,''),(57100,18077,'118746','deals-mobile','sort_hide_13','1',0,''),(57101,18077,'118746','deals-mobile','sort_hide_8','0',0,''),(57102,18077,'118746','deals-mobile','sort_hide_7','0',0,''),(57103,18077,'118746','deals-mobile','sort_hide_2','1',0,''),(57104,18077,'118746','deals-mobile','sort_hide_1','1',0,''),(57105,18077,'118746','deals-mobile','sort_hide_6','1',0,''),(57106,18077,'118746','deals-mobile','sort_hide_5','1',0,''),(57107,18077,'118746','deals-mobile','sort_hide_0','1',0,''),(57108,18078,'118747','deals-mobile','float','left',0,''),(57109,18078,'118747','deals-mobile','clear','none',0,''),(57110,18078,'118747','deals-mobile','margin-left','20',0,''),(57111,18078,'118747','deals-mobile','display','none',0,''),(57112,18079,'118748','deals-mobile','margin-right','20',0,''),(57113,18079,'118748','deals-mobile','float','right',0,''),(57114,18079,'118748','deals-mobile','clear','none',0,''),(57115,18079,'118748','deals-mobile','display','none',0,''),(57116,18080,'118749','deals-mobile','float','right',0,''),(57117,18080,'118749','deals-mobile','display','none',0,''),(57118,18081,'118750','deals-mobile','listing_type','productListing',0,''),(57119,18083,'118752','deals-mobile','block_type','5',0,''),(57120,18083,'118752','deals-mobile','padding-top','10',0,''),(57121,18083,'118752','deals-mobile','padding-bottom','10',0,''),(57122,18083,'118752','deals-mobile','schema','5-2',0,''),(57123,18083,'118752','deals-mobile','border-top-color','#e0e0e0',0,''),(57124,18083,'118752','deals-mobile','border-top-width','1',0,''),(57125,18085,'118754','deals-mobile','float','right',0,''),(57126,18086,'118755','deals-mobile','block_type','1',0,''),(57127,18088,'118757','deals-mobile','block_type','5',0,''),(57128,18088,'118757','deals-mobile','padding-top','10',0,''),(57129,18088,'118757','deals-mobile','padding-bottom','10',0,''),(57130,18088,'118757','deals-mobile','schema','5-2',0,''),(57131,18088,'118757','deals-mobile','border-top-color','#e0e0e0',0,''),(57132,18088,'118757','deals-mobile','border-top-width','1',0,''),(57133,18090,'118759','deals-mobile','float','right',0,''),(57134,18091,'118760','deals-mobile','col_in_row','4',0,''),(57135,18091,'118760','deals-mobile','products_align','left',0,''),(57136,18091,'118760','deals-mobile','font-weight','400',0,''),(57137,18091,'118760','deals-mobile','show_qty_input','0',0,''),(57138,18091,'118760','deals-mobile','listing_type','productListing',0,''),(57139,18091,'118760','deals-mobile','listing_type_rows','Rows',0,''),(57140,18091,'118760','deals-mobile','show_buy_button_b2b','on',0,''),(57141,18091,'118760','deals-mobile','show_wishlist_button_b2b','1',0,''),(57142,18091,'118760','deals-mobile','show_compare_b2b','1',0,''),(57143,18091,'118760','deals-mobile','listing_type_b2b','b2b',0,''),(57144,18091,'118760','deals-mobile','show_image','0',0,''),(57145,18091,'118760','deals-mobile','show_stock','0',0,''),(57146,18091,'118760','deals-mobile','show_description','0',0,''),(57147,18091,'118760','deals-mobile','show_model','0',0,''),(57148,18091,'118760','deals-mobile','show_properties','0',0,''),(57149,18091,'118760','deals-mobile','show_rating','0',0,''),(57150,18091,'118760','deals-mobile','show_rating_counts','0',0,''),(57151,18091,'118760','deals-mobile','show_price','0',0,''),(57152,18091,'118760','deals-mobile','show_buy_button','0',0,''),(57153,18091,'118760','deals-mobile','show_view_button','0',0,''),(57154,18091,'118760','deals-mobile','show_wishlist_button','0',0,''),(57155,18091,'118760','deals-mobile','show_compare','0',0,''),(57156,18091,'118760','deals-mobile','show_name_rows','0',0,''),(57157,18091,'118760','deals-mobile','show_image_rows','0',0,''),(57158,18091,'118760','deals-mobile','show_stock_rows','0',0,''),(57159,18091,'118760','deals-mobile','show_description_rows','0',0,''),(57160,18091,'118760','deals-mobile','show_model_rows','0',0,''),(57161,18091,'118760','deals-mobile','show_properties_rows','0',0,''),(57162,18091,'118760','deals-mobile','show_rating_rows','0',0,''),(57163,18091,'118760','deals-mobile','show_rating_counts_rows','0',0,''),(57164,18091,'118760','deals-mobile','show_price_rows','0',0,''),(57165,18091,'118760','deals-mobile','show_buy_button_rows','0',0,''),(57166,18091,'118760','deals-mobile','show_qty_input_rows','0',0,''),(57167,18091,'118760','deals-mobile','show_view_button_rows','0',0,''),(57168,18091,'118760','deals-mobile','show_wishlist_button_rows','0',0,''),(57169,18091,'118760','deals-mobile','show_compare_rows','0',0,''),(57170,18091,'118760','deals-mobile','show_name_b2b','0',0,''),(57171,18091,'118760','deals-mobile','show_image_b2b','0',0,''),(57172,18091,'118760','deals-mobile','show_stock_b2b','0',0,''),(57173,18091,'118760','deals-mobile','show_description_b2b','0',0,''),(57174,18091,'118760','deals-mobile','show_model_b2b','0',0,''),(57175,18091,'118760','deals-mobile','show_properties_b2b','0',0,''),(57176,18091,'118760','deals-mobile','show_rating_b2b','0',0,''),(57177,18091,'118760','deals-mobile','show_rating_counts_b2b','0',0,''),(57178,18091,'118760','deals-mobile','show_price_b2b','0',0,''),(57179,18091,'118760','deals-mobile','show_qty_input_b2b','0',0,''),(57180,18091,'118760','deals-mobile','show_view_button_b2b','0',0,''),(57181,18091,'118760','deals-mobile','show_attributes_b2b','0',0,''),(57182,18091,'118760','deals-mobile','items_on_page','12',0,''),(57185,18091,'118760','deals-mobile','product_names_teg','h2',0,''),(57187,18093,'118762','deals-mobile','block_type','1',0,''),(57188,18093,'118762','deals-mobile','padding-top','10',0,''),(57189,18093,'118762','deals-mobile','padding-bottom','10',0,''),(57190,18093,'118762','deals-mobile','border-bottom-width','1',0,''),(57191,18093,'118762','deals-mobile','border-bottom-color','#e0e0e0',0,''),(57192,18093,'118762','deals-mobile','margin-left','0',0,''),(57193,18093,'118762','deals-mobile','margin-right','0',0,''),(57194,18094,'118763','deals-mobile','float','right',0,''),(57195,18094,'118763','deals-mobile','display','none',0,''),(57196,18095,'118764','deals-mobile','margin-right','20',0,''),(57197,18095,'118764','deals-mobile','float','right',0,''),(57198,18095,'118764','deals-mobile','clear','none',0,''),(57199,18095,'118764','deals-mobile','display','none',0,''),(57200,18096,'118765','deals-mobile','clear','none',0,''),(57201,18096,'118765','deals-mobile','float','left',0,''),(57202,18096,'118765','deals-mobile','padding-top','3',0,''),(57203,18096,'118765','deals-mobile','padding-left','20',0,''),(57204,18097,'118766','deals-mobile','float','left',0,''),(57205,18097,'118766','deals-mobile','clear','none',0,''),(57206,18097,'118766','deals-mobile','margin-left','20',0,''),(57207,18097,'118766','deals-mobile','display','none',0,''),(57208,18098,'118767','deals-mobile','float','left',0,''),(57209,18098,'118767','deals-mobile','clear','none',0,''),(57210,18098,'118767','deals-mobile','sort_pos_3','1',0,''),(57211,18098,'118767','deals-mobile','sort_pos_4','2',0,''),(57212,18098,'118767','deals-mobile','sort_pos_10','3',0,''),(57213,18098,'118767','deals-mobile','sort_pos_9','4',0,''),(57214,18098,'118767','deals-mobile','sort_pos_11','5',0,''),(57215,18098,'118767','deals-mobile','sort_pos_12','6',0,''),(57216,18098,'118767','deals-mobile','sort_pos_14','7',0,''),(57217,18098,'118767','deals-mobile','sort_pos_13','8',0,''),(57218,18098,'118767','deals-mobile','sort_pos_8','9',0,''),(57219,18098,'118767','deals-mobile','sort_pos_7','10',0,''),(57220,18098,'118767','deals-mobile','sort_pos_2','11',0,''),(57221,18098,'118767','deals-mobile','sort_pos_1','12',0,''),(57222,18098,'118767','deals-mobile','sort_pos_6','13',0,''),(57223,18098,'118767','deals-mobile','sort_pos_5','14',0,''),(57224,18098,'118767','deals-mobile','sort_pos_0','15',0,''),(57225,18098,'118767','deals-mobile','sort_hide_10','1',0,''),(57226,18098,'118767','deals-mobile','sort_hide_9','1',0,''),(57227,18098,'118767','deals-mobile','hide_icons','1',0,''),(57228,18098,'118767','deals-mobile','sort_hide_16','1',0,''),(57229,18098,'118767','deals-mobile','sort_hide_15','1',0,''),(57230,18098,'118767','deals-mobile','sort_hide_3','0',0,''),(57231,18098,'118767','deals-mobile','sort_hide_4','0',0,''),(57232,18098,'118767','deals-mobile','sort_hide_11','1',0,''),(57233,18098,'118767','deals-mobile','sort_hide_12','1',0,''),(57234,18098,'118767','deals-mobile','sort_hide_14','1',0,''),(57235,18098,'118767','deals-mobile','sort_hide_13','1',0,''),(57236,18098,'118767','deals-mobile','sort_hide_8','0',0,''),(57237,18098,'118767','deals-mobile','sort_hide_7','0',0,''),(57238,18098,'118767','deals-mobile','sort_hide_2','1',0,''),(57239,18098,'118767','deals-mobile','sort_hide_1','1',0,''),(57240,18098,'118767','deals-mobile','sort_hide_6','1',0,''),(57241,18098,'118767','deals-mobile','sort_hide_5','1',0,''),(57242,18098,'118767','deals-mobile','sort_hide_0','1',0,''),(57243,18101,'118770','deals-mobile','block_type','1',0,''),(57244,18101,'118770','deals-mobile','background-color','#eeeeee',0,''),(57245,18101,'118770','deals-mobile','padding-top','30',0,''),(57246,18101,'118770','deals-mobile','padding-bottom','30',0,''),(57247,18102,'118771','deals-mobile','block_type','1',0,''),(57248,18102,'118771','deals-mobile','schema','4-2',0,''),(57249,18102,'118771','deals-mobile','schema','4-1',0,'872'),(57250,18103,'118772','deals-mobile','block_type','1',0,''),(57251,18103,'118772','deals-mobile','padding-right','40',0,''),(57253,18104,'118773','deals-mobile','block_type','1',0,''),(57254,18104,'118773','deals-mobile','padding-top','30',0,''),(57255,18104,'118773','deals-mobile','padding-left','30',0,''),(57256,18104,'118773','deals-mobile','padding-right','30',0,''),(57257,18104,'118773','deals-mobile','padding-bottom','23',0,''),(57258,18104,'118773','deals-mobile','margin-bottom','20',0,''),(57259,18104,'118773','deals-mobile','background-color','#ffffff',0,''),(57260,18104,'118773','deals-mobile','style_class','hiding-box',0,''),(57261,18105,'118774','deals-mobile','block_type','2',0,''),(57262,18105,'118774','deals-mobile','schema','2-2',0,''),(57263,18105,'118774','deals-mobile','schema','2-2',0,'872'),(57264,18106,'118775','deals-mobile','padding-right','20',0,''),(57266,18106,'118775','deals-mobile','padding-bottom','20',0,''),(57267,18106,'118775','deals-mobile','address_in','popup',0,''),(57268,18107,'118776','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57269,18108,'118777','deals-mobile','block_type','1',0,''),(57270,18108,'118777','deals-mobile','padding-left','20',0,''),(57272,18109,'118778','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57273,18111,'118780','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(57274,18112,'118781','deals-mobile','block_type','1',0,''),(57275,18112,'118781','deals-mobile','background-color','#ffffff',0,''),(57276,18112,'118781','deals-mobile','padding-top','30',0,''),(57277,18112,'118781','deals-mobile','padding-left','30',0,''),(57278,18112,'118781','deals-mobile','padding-right','30',0,''),(57279,18112,'118781','deals-mobile','padding-bottom','30',0,''),(57280,18112,'118781','deals-mobile','margin-bottom','20',0,''),(57281,18112,'118781','deals-mobile','style_class','hiding-box',0,''),(57282,18113,'118782','deals-mobile','padding-top','10',0,''),(57283,18113,'118782','deals-mobile','padding-left','20',0,''),(57284,18113,'118782','deals-mobile','padding-right','20',0,''),(57285,18113,'118782','deals-mobile','margin-top','20',0,''),(57286,18113,'118782','deals-mobile','background-color','#eeeeee',0,''),(57287,18113,'118782','deals-mobile','padding-bottom','8',0,''),(57288,18114,'118783','deals-mobile','margin-bottom','20',0,''),(57289,18115,'118784','deals-mobile','background-color','#ffffff',0,''),(57290,18115,'118784','deals-mobile','block_type','1',0,''),(57291,18115,'118784','deals-mobile','padding-top','30',0,''),(57292,18115,'118784','deals-mobile','padding-left','30',0,''),(57293,18115,'118784','deals-mobile','padding-right','30',0,''),(57294,18115,'118784','deals-mobile','padding-bottom','30',0,''),(57295,18115,'118784','deals-mobile','margin-bottom','20',0,''),(57296,18115,'118784','deals-mobile','style_class','hiding-box',0,''),(57297,18116,'118785','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(57298,18117,'118786','deals-mobile','block_type','1',0,''),(57299,18117,'118786','deals-mobile','schema','2-2',0,''),(57300,18117,'118786','deals-mobile','schema','2-1',0,'872'),(57301,18118,'118787','deals-mobile','block_type','1',0,''),(57302,18118,'118787','deals-mobile','padding-left','0',0,''),(57303,18118,'118787','deals-mobile','margin-bottom','20',0,''),(57304,18121,'118790','deals-mobile','address_in','popup',0,''),(57305,18122,'118791','deals-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(57306,18123,'118792','deals-mobile','block_type','1',0,''),(57307,18123,'118792','deals-mobile','padding-left','20',0,''),(57309,18124,'118793','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(57310,18125,'118794','deals-mobile','border-top-width','1',0,''),(57311,18125,'118794','deals-mobile','border-top-color','#e0e0e0',0,''),(57312,18125,'118794','deals-mobile','padding-top','13',0,''),(57313,18125,'118794','deals-mobile','padding-bottom','10',0,''),(57314,18127,'118796','deals-mobile','background-color','#eeeeee',0,''),(57315,18127,'118796','deals-mobile','padding-top','10',0,''),(57316,18127,'118796','deals-mobile','padding-left','10',0,''),(57317,18127,'118796','deals-mobile','padding-right','10',0,''),(57318,18127,'118796','deals-mobile','padding-bottom','10',0,''),(57319,18127,'118796','deals-mobile','margin-top','10',0,''),(57320,18128,'118797','deals-mobile','block_type','1',0,''),(57321,18128,'118797','deals-mobile','content','\\_',0,'3'),(57322,18128,'118797','deals-mobile','border-top-width','1',0,'3'),(57323,18128,'118797','deals-mobile','border-top-color','#e0e0e0',0,'3'),(57324,18128,'118797','deals-mobile','display','block',0,'3'),(57325,18128,'118797','deals-mobile','position','absolute',0,'3'),(57326,18128,'118797','deals-mobile','top','19',0,'3'),(57327,18128,'118797','deals-mobile','left','0',0,'3'),(57328,18128,'118797','deals-mobile','right','0',0,'3'),(57329,18128,'118797','deals-mobile','margin-top','-2',0,'3'),(57330,18128,'118797','deals-mobile','position','relative',0,''),(57331,18129,'118798','deals-mobile','box_align','2',0,''),(57332,18129,'118798','deals-mobile','margin-bottom','10',0,''),(57333,18129,'118798','deals-mobile','background-color','#ffffff',0,''),(57334,18129,'118798','deals-mobile','position','relative',0,''),(57335,18130,'118799','deals-mobile','block_type','1',0,''),(57336,18130,'118799','deals-mobile','padding-top','30',0,''),(57337,18130,'118799','deals-mobile','padding-left','30',0,''),(57338,18130,'118799','deals-mobile','padding-right','30',0,''),(57339,18130,'118799','deals-mobile','padding-bottom','14',0,''),(57340,18130,'118799','deals-mobile','margin-bottom','20',0,''),(57341,18130,'118799','deals-mobile','background-color','#ffffff',0,''),(57342,18130,'118799','deals-mobile','style_class','hiding-box closeable-box',0,''),(57343,18131,'118800','deals-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(57344,18131,'118800','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57345,18132,'118801','deals-mobile','block_type','2',0,''),(57346,18132,'118801','deals-mobile','style_class','closeable-content',0,''),(57347,18132,'118801','deals-mobile','schema','2-2',0,''),(57348,18132,'118801','deals-mobile','schema','2-2',0,'872'),(57349,18133,'118802','deals-mobile','padding-right','20',0,''),(57350,18133,'118802','deals-mobile','padding-bottom','20',0,''),(57352,18134,'118803','deals-mobile','padding-left','20',0,''),(57353,18134,'118803','deals-mobile','padding-bottom','20',0,''),(57355,18135,'118804','deals-mobile','padding-left','20',0,''),(57356,18135,'118804','deals-mobile','padding-bottom','20',0,''),(57358,18136,'118805','deals-mobile','block_type','1',0,''),(57359,18136,'118805','deals-mobile','background-color','#ffffff',0,''),(57360,18136,'118805','deals-mobile','padding-top','30',0,''),(57361,18136,'118805','deals-mobile','padding-left','30',0,''),(57362,18136,'118805','deals-mobile','padding-right','30',0,''),(57363,18136,'118805','deals-mobile','padding-bottom','14',0,''),(57364,18136,'118805','deals-mobile','margin-bottom','20',0,''),(57365,18136,'118805','deals-mobile','style_class','hiding-box closeable-box',0,''),(57366,18137,'118806','deals-mobile','style_class','closeable-content',0,''),(57367,18137,'118806','deals-mobile','padding-bottom','20',0,''),(57368,18138,'118807','deals-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(57369,18138,'118807','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57370,18139,'118808','deals-mobile','block_type','1',0,''),(57371,18139,'118808','deals-mobile','padding-top','20',0,''),(57372,18139,'118808','deals-mobile','padding-left','20',0,''),(57373,18139,'118808','deals-mobile','padding-right','20',0,''),(57374,18139,'118808','deals-mobile','padding-bottom','20',0,''),(57375,18139,'118808','deals-mobile','background-color','#ffffff',0,''),(57376,18139,'118808','deals-mobile','style_class','order-summary',0,''),(57377,18140,'118809','deals-mobile','margin-bottom','10',0,''),(57378,18142,'118811','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(57379,18143,'118812','deals-mobile','hide_page','1',0,''),(57380,18143,'118812','deals-mobile','hide_continue_button','1',0,''),(57381,18144,'118813','deals-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(57382,18144,'118813','deals-mobile','text-align','center',0,''),(57383,18144,'118813','deals-mobile','font-size','14',0,''),(57384,18144,'118813','deals-mobile','color','#757575',0,''),(57385,18144,'118813','deals-mobile','padding-top','10',0,''),(57386,18145,'118814','deals-mobile','block_type','1',0,''),(57387,18146,'118815','deals-mobile','margin-bottom','20',0,''),(57388,18146,'118815','deals-mobile','text-align','right',0,''),(57389,18148,'118817','deals-mobile','block_type','2',0,''),(57390,18148,'118817','deals-mobile','margin-bottom','20',0,''),(57391,18148,'118817','deals-mobile','schema','2-2',0,''),(57392,18149,'118818','deals-mobile','block_type','1',0,''),(57393,18149,'118818','deals-mobile','padding-right','20',0,''),(57395,18150,'118819','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(57396,18150,'118819','deals-mobile','clear','none',0,''),(57397,18152,'118821','deals-mobile','block_type','1',0,''),(57398,18152,'118821','deals-mobile','padding-left','20',0,''),(57400,18153,'118822','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57401,18153,'118822','deals-mobile','clear','none',0,''),(57402,18155,'118824','deals-mobile','text-align','right',0,''),(57403,18155,'118824','deals-mobile','margin-bottom','20',0,''),(57404,18156,'118825','deals-mobile','block_type','2',0,''),(57405,18156,'118825','deals-mobile','margin-bottom','20',0,''),(57406,18156,'118825','deals-mobile','schema','2-2',0,''),(57407,18157,'118826','deals-mobile','block_type','1',0,''),(57408,18157,'118826','deals-mobile','padding-right','20',0,''),(57410,18158,'118827','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(57411,18158,'118827','deals-mobile','clear','none',0,''),(57412,18160,'118829','deals-mobile','padding-left','20',0,''),(57413,18160,'118829','deals-mobile','block_type','1',0,''),(57415,18162,'118831','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57416,18162,'118831','deals-mobile','clear','none',0,''),(57417,18163,'118832','deals-mobile','link','products',0,''),(57418,18163,'118832','deals-mobile','margin-top','-33',0,''),(57419,18163,'118832','deals-mobile','float','right',0,''),(57420,18165,'118834','deals-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(57421,18166,'118835','deals-mobile','block_type','1',0,''),(57422,18167,'118836','deals-mobile','margin-bottom','20',0,''),(57423,18168,'118837','deals-mobile','text-align','right',0,''),(57424,18168,'118837','deals-mobile','margin-bottom','20',0,''),(57425,18169,'118838','deals-mobile','block_type','2',0,''),(57426,18169,'118838','deals-mobile','margin-bottom','20',0,''),(57427,18169,'118838','deals-mobile','schema','2-2',0,''),(57428,18170,'118839','deals-mobile','block_type','1',0,''),(57429,18170,'118839','deals-mobile','padding-right','20',0,''),(57431,18171,'118840','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57432,18171,'118840','deals-mobile','clear','none',0,''),(57433,18173,'118842','deals-mobile','block_type','1',0,''),(57434,18173,'118842','deals-mobile','padding-left','20',0,''),(57436,18174,'118843','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57437,18174,'118843','deals-mobile','clear','none',0,''),(57438,18176,'118845','deals-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(57439,18177,'118846','deals-mobile','margin-bottom','20',0,''),(57440,18178,'118847','deals-mobile','margin-bottom','20',0,''),(57441,18178,'118847','deals-mobile','text-align','right',0,''),(57442,18179,'118848','deals-mobile','block_type','1',0,''),(57443,18180,'118849','deals-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(57444,18181,'118850','deals-mobile','margin-bottom','20',0,''),(57445,18181,'118850','deals-mobile','text-align','right',0,''),(57446,18184,'118853','deals-mobile','text-align','right',0,''),(57447,18184,'118853','deals-mobile','margin-bottom','20',0,''),(57448,18185,'118854','deals-mobile','block_type','2',0,''),(57449,18185,'118854','deals-mobile','margin-bottom','20',0,''),(57450,18185,'118854','deals-mobile','schema','2-2',0,''),(57451,18186,'118855','deals-mobile','block_type','1',0,''),(57452,18186,'118855','deals-mobile','padding-right','20',0,''),(57454,18188,'118857','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57455,18188,'118857','deals-mobile','clear','none',0,''),(57456,18189,'118858','deals-mobile','block_type','1',0,''),(57457,18189,'118858','deals-mobile','padding-left','20',0,''),(57459,18190,'118859','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57460,18190,'118859','deals-mobile','clear','none',0,''),(57461,18192,'118861','deals-mobile','block_type','1',0,''),(57462,18193,'118862','deals-mobile','block_type','2',0,''),(57463,18193,'118862','deals-mobile','margin-bottom','20',0,''),(57464,18193,'118862','deals-mobile','schema','2-2',0,''),(57465,18194,'118863','deals-mobile','block_type','1',0,''),(57466,18194,'118863','deals-mobile','padding-right','20',0,''),(57468,18196,'118865','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(57469,18196,'118865','deals-mobile','clear','none',0,''),(57470,18197,'118866','deals-mobile','padding-left','20',0,''),(57471,18197,'118866','deals-mobile','block_type','1',0,''),(57473,18198,'118867','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57474,18198,'118867','deals-mobile','clear','none',0,''),(57475,18200,'118869','deals-mobile','text-align','right',0,''),(57476,18200,'118869','deals-mobile','margin-bottom','20',0,''),(57477,18201,'118870','deals-mobile','margin-bottom','20',0,''),(57478,18201,'118870','deals-mobile','text-align','right',0,''),(57479,18202,'118871','deals-mobile','link','products',0,''),(57480,18202,'118871','deals-mobile','margin-top','-33',0,''),(57481,18202,'118871','deals-mobile','float','right',0,''),(57482,18203,'118872','deals-mobile','margin-bottom','20',0,''),(57483,18204,'118873','deals-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(57484,18205,'118874','deals-mobile','margin-bottom','20',0,''),(57485,18206,'118875','deals-mobile','block_type','2',0,''),(57486,18206,'118875','deals-mobile','margin-bottom','20',0,''),(57487,18206,'118875','deals-mobile','schema','2-2',0,''),(57488,18207,'118876','deals-mobile','block_type','1',0,''),(57489,18207,'118876','deals-mobile','padding-right','20',0,''),(57491,18209,'118878','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(57492,18209,'118878','deals-mobile','clear','none',0,''),(57493,18210,'118879','deals-mobile','block_type','1',0,''),(57494,18210,'118879','deals-mobile','padding-left','20',0,''),(57496,18211,'118880','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57497,18211,'118880','deals-mobile','clear','none',0,''),(57498,18213,'118882','deals-mobile','text','##TEXT_CONFIRMATION##',0,''),(57499,18214,'118883','deals-mobile','text','##TEXT_CONFIRMATION##',0,''),(57500,18215,'118884','deals-mobile','text','##TEXT_CONFIRMATION##',0,''),(57501,18216,'118885','deals-mobile','text','##TEXT_CONFIRMATION##',0,''),(57502,18217,'118886','deals-mobile','text','##TEXT_CONFIRMATION##',0,''),(57503,18218,'118887','deals-mobile','text','##TEXT_CONFIRMATION##',0,''),(57504,18219,'118888','deals-mobile','block_type','2',0,''),(57505,18220,'118889','deals-mobile','block_type','1',0,''),(57506,18220,'118889','deals-mobile','padding-right','20',0,''),(57508,18222,'118891','deals-mobile','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(57509,18223,'118892','deals-mobile','block_type','1',0,''),(57510,18223,'118892','deals-mobile','padding-right','0',0,''),(57511,18223,'118892','deals-mobile','padding-left','20',0,''),(57512,18225,'118894','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(57513,18228,'118897','deals-mobile','block_type','2',0,''),(57514,18229,'118898','deals-mobile','block_type','1',0,''),(57515,18229,'118898','deals-mobile','padding-right','20',0,''),(57516,18230,'118899','deals-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(57517,18232,'118901','deals-mobile','block_type','1',0,''),(57518,18232,'118901','deals-mobile','padding-left','20',0,''),(57520,18233,'118902','deals-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(57521,18235,'118904','deals-mobile','block_type','4',0,''),(57522,18235,'118904','deals-mobile','schema','4-2',0,''),(57523,18236,'118905','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57524,18236,'118905','deals-mobile','text-align','right',0,''),(57525,18236,'118905','deals-mobile','padding-top','10',0,''),(57526,18236,'118905','deals-mobile','font_size_measure','em',0,''),(57527,18236,'118905','deals-mobile','font-size','1.2',0,''),(57528,18237,'118906','deals-mobile','text-align','right',0,''),(57529,18238,'118907','deals-mobile','block_type','2',0,''),(57530,18239,'118908','deals-mobile','block_type','1',0,''),(57531,18239,'118908','deals-mobile','padding-right','20',0,''),(57533,18241,'118910','deals-mobile','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(57534,18242,'118911','deals-mobile','block_type','1',0,''),(57535,18242,'118911','deals-mobile','padding-right','0',0,''),(57536,18242,'118911','deals-mobile','padding-left','20',0,''),(57537,18243,'118912','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(57538,18247,'118916','deals-mobile','block_type','4',0,''),(57539,18247,'118916','deals-mobile','schema','4-2',0,''),(57540,18248,'118917','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57541,18248,'118917','deals-mobile','text-align','right',0,''),(57542,18248,'118917','deals-mobile','padding-top','10',0,''),(57543,18248,'118917','deals-mobile','font_size_measure','em',0,''),(57544,18248,'118917','deals-mobile','font-size','1.2',0,''),(57545,18249,'118918','deals-mobile','text-align','right',0,''),(57546,18250,'118919','deals-mobile','block_type','2',0,''),(57547,18251,'118920','deals-mobile','block_type','1',0,''),(57548,18251,'118920','deals-mobile','padding-right','20',0,''),(57549,18253,'118922','deals-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(57550,18254,'118923','deals-mobile','block_type','1',0,''),(57551,18254,'118923','deals-mobile','padding-left','20',0,''),(57553,18256,'118925','deals-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(57554,18257,'118926','deals-mobile','block_type','4',0,''),(57555,18257,'118926','deals-mobile','schema','4-2',0,''),(57556,18258,'118927','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57557,18258,'118927','deals-mobile','text-align','right',0,''),(57558,18258,'118927','deals-mobile','padding-top','10',0,''),(57559,18258,'118927','deals-mobile','font_size_measure','em',0,''),(57560,18258,'118927','deals-mobile','font-size','1.2',0,''),(57561,18259,'118928','deals-mobile','text-align','right',0,''),(57562,18260,'118929','deals-mobile','block_type','2',0,''),(57563,18261,'118930','deals-mobile','block_type','1',0,''),(57564,18261,'118930','deals-mobile','padding-right','20',0,''),(57565,18263,'118932','deals-mobile','block_type','1',0,''),(57566,18263,'118932','deals-mobile','padding-left','20',0,''),(57568,18265,'118934','deals-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(57569,18266,'118935','deals-mobile','block_type','2',0,''),(57570,18267,'118936','deals-mobile','block_type','1',0,''),(57571,18267,'118936','deals-mobile','padding-right','20',0,''),(57572,18269,'118938','deals-mobile','block_type','1',0,''),(57573,18269,'118938','deals-mobile','padding-left','20',0,''),(57575,18270,'118939','deals-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(57576,18272,'118941','deals-mobile','block_type','4',0,''),(57577,18272,'118941','deals-mobile','schema','4-2',0,''),(57578,18273,'118942','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57579,18273,'118942','deals-mobile','text-align','right',0,''),(57580,18273,'118942','deals-mobile','padding-top','10',0,''),(57581,18273,'118942','deals-mobile','font_size_measure','em',0,''),(57582,18273,'118942','deals-mobile','font-size','1.2',0,''),(57583,18274,'118943','deals-mobile','text-align','right',0,''),(57584,18275,'118944','deals-mobile','text','##DELIVERY_DETAILS##',0,''),(57585,18276,'118945','deals-mobile','text','##DELIVERY_DETAILS##',0,''),(57586,18277,'118946','deals-mobile','text','##CONTACT_INFORMATION##',0,''),(57587,18278,'118947','deals-mobile','text','##CONTACT_INFORMATION##',0,''),(57588,18279,'118948','deals-mobile','text','##DELIVERY_DETAILS##',0,''),(57589,18280,'118949','deals-mobile','text','##DELIVERY_DETAILS##',0,''),(57590,18281,'118950','deals-mobile','block_type','1',0,''),(57591,18281,'118950','deals-mobile','background-color','#eeeeee',0,''),(57592,18281,'118950','deals-mobile','padding-top','30',0,''),(57593,18281,'118950','deals-mobile','padding-bottom','30',0,''),(57594,18282,'118951','deals-mobile','block_type','4',0,''),(57595,18282,'118951','deals-mobile','schema','4-2',0,''),(57596,18283,'118952','deals-mobile','block_type','1',0,''),(57597,18283,'118952','deals-mobile','padding-right','40',0,''),(57599,18284,'118953','deals-mobile','background-color','#ffffff',0,''),(57600,18284,'118953','deals-mobile','block_type','1',0,''),(57601,18284,'118953','deals-mobile','padding-top','30',0,''),(57602,18284,'118953','deals-mobile','padding-left','30',0,''),(57603,18284,'118953','deals-mobile','padding-right','30',0,''),(57604,18284,'118953','deals-mobile','padding-bottom','30',0,''),(57605,18284,'118953','deals-mobile','margin-bottom','20',0,''),(57606,18284,'118953','deals-mobile','style_class','hiding-box',0,''),(57607,18285,'118954','deals-mobile','background-color','#eeeeee',0,''),(57608,18285,'118954','deals-mobile','padding-top','10',0,''),(57609,18285,'118954','deals-mobile','padding-left','10',0,''),(57610,18285,'118954','deals-mobile','padding-right','10',0,''),(57611,18285,'118954','deals-mobile','padding-bottom','10',0,''),(57612,18285,'118954','deals-mobile','margin-top','10',0,''),(57613,18286,'118955','deals-mobile','block_type','2',0,''),(57614,18286,'118955','deals-mobile','schema','2-2',0,''),(57615,18287,'118956','deals-mobile','block_type','1',0,''),(57616,18287,'118956','deals-mobile','padding-right','20',0,''),(57617,18287,'118956','deals-mobile','padding-left','0',0,''),(57618,18287,'118956','deals-mobile','margin-bottom','20',0,''),(57619,18289,'118958','deals-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(57620,18291,'118960','deals-mobile','block_type','1',0,''),(57621,18291,'118960','deals-mobile','padding-left','20',0,''),(57623,18292,'118961','deals-mobile','border-top-width','1',0,''),(57624,18292,'118961','deals-mobile','border-top-color','#e0e0e0',0,''),(57625,18292,'118961','deals-mobile','padding-top','13',0,''),(57626,18292,'118961','deals-mobile','padding-bottom','10',0,''),(57627,18293,'118962','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(57628,18294,'118963','deals-mobile','block_type','1',0,''),(57629,18294,'118963','deals-mobile','content','\\_',0,'3'),(57630,18294,'118963','deals-mobile','border-top-width','1',0,'3'),(57631,18294,'118963','deals-mobile','border-top-color','#e0e0e0',0,'3'),(57632,18294,'118963','deals-mobile','display','block',0,'3'),(57633,18294,'118963','deals-mobile','position','absolute',0,'3'),(57634,18294,'118963','deals-mobile','top','19',0,'3'),(57635,18294,'118963','deals-mobile','left','0',0,'3'),(57636,18294,'118963','deals-mobile','right','0',0,'3'),(57637,18294,'118963','deals-mobile','margin-top','-2',0,'3'),(57638,18294,'118963','deals-mobile','position','relative',0,''),(57639,18295,'118964','deals-mobile','box_align','2',0,''),(57640,18295,'118964','deals-mobile','margin-bottom','10',0,''),(57641,18295,'118964','deals-mobile','background-color','#ffffff',0,''),(57642,18295,'118964','deals-mobile','position','relative',0,''),(57643,18296,'118965','deals-mobile','block_type','1',0,''),(57644,18296,'118965','deals-mobile','background-color','#ffffff',0,''),(57645,18296,'118965','deals-mobile','padding-top','30',0,''),(57646,18296,'118965','deals-mobile','padding-left','30',0,''),(57647,18296,'118965','deals-mobile','padding-right','30',0,''),(57648,18296,'118965','deals-mobile','padding-bottom','14',0,''),(57649,18296,'118965','deals-mobile','margin-bottom','20',0,''),(57650,18296,'118965','deals-mobile','style_class','hiding-box closeable-box',0,''),(57651,18297,'118966','deals-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(57652,18297,'118966','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57653,18298,'118967','deals-mobile','style_class','closeable-content',0,''),(57654,18298,'118967','deals-mobile','padding-bottom','20',0,''),(57655,18299,'118968','deals-mobile','background-color','#ffffff',0,''),(57656,18299,'118968','deals-mobile','padding-top','30',0,''),(57657,18299,'118968','deals-mobile','padding-left','30',0,''),(57658,18299,'118968','deals-mobile','padding-right','30',0,''),(57659,18299,'118968','deals-mobile','padding-bottom','30',0,''),(57660,18299,'118968','deals-mobile','margin-bottom','20',0,''),(57661,18300,'118969','deals-mobile','block_type','1',0,''),(57662,18300,'118969','deals-mobile','background-color','#ffffff',0,''),(57663,18300,'118969','deals-mobile','padding-top','30',0,''),(57664,18300,'118969','deals-mobile','padding-left','30',0,''),(57665,18300,'118969','deals-mobile','padding-right','30',0,''),(57666,18300,'118969','deals-mobile','padding-bottom','30',0,''),(57667,18300,'118969','deals-mobile','margin-bottom','20',0,''),(57668,18300,'118969','deals-mobile','style_class','hiding-box',0,''),(57669,18301,'118970','deals-mobile','padding-top','10',0,''),(57670,18301,'118970','deals-mobile','padding-left','20',0,''),(57671,18301,'118970','deals-mobile','padding-right','20',0,''),(57672,18301,'118970','deals-mobile','margin-top','20',0,''),(57673,18301,'118970','deals-mobile','background-color','#eeeeee',0,''),(57674,18301,'118970','deals-mobile','padding-bottom','8',0,''),(57675,18302,'118971','deals-mobile','margin-bottom','20',0,''),(57676,18303,'118972','deals-mobile','block_type','1',0,''),(57677,18303,'118972','deals-mobile','padding-top','20',0,''),(57678,18303,'118972','deals-mobile','padding-left','20',0,''),(57679,18303,'118972','deals-mobile','padding-right','20',0,''),(57680,18303,'118972','deals-mobile','padding-bottom','20',0,''),(57681,18303,'118972','deals-mobile','background-color','#ffffff',0,''),(57682,18303,'118972','deals-mobile','style_class','order-summary',0,''),(57683,18305,'118974','deals-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(57684,18305,'118974','deals-mobile','text-align','center',0,''),(57685,18305,'118974','deals-mobile','font-size','14',0,''),(57686,18305,'118974','deals-mobile','color','#757575',0,''),(57687,18305,'118974','deals-mobile','padding-top','10',0,''),(57688,18306,'118975','deals-mobile','block_type','1',0,''),(57689,18306,'118975','deals-mobile','background-color','#eeeeee',0,''),(57690,18306,'118975','deals-mobile','padding-top','30',0,''),(57691,18306,'118975','deals-mobile','padding-bottom','30',0,''),(57692,18307,'118976','deals-mobile','block_type','4',0,''),(57693,18308,'118977','deals-mobile','block_type','1',0,''),(57694,18308,'118977','deals-mobile','padding-right','40',0,''),(57695,18309,'118978','deals-mobile','block_type','1',0,''),(57696,18309,'118978','deals-mobile','background-color','#ffffff',0,''),(57697,18309,'118978','deals-mobile','padding-top','30',0,''),(57698,18309,'118978','deals-mobile','padding-left','30',0,''),(57699,18309,'118978','deals-mobile','padding-right','30',0,''),(57700,18309,'118978','deals-mobile','padding-bottom','14',0,''),(57701,18309,'118978','deals-mobile','margin-bottom','20',0,''),(57702,18309,'118978','deals-mobile','style_class','hiding-box closeable-box',0,''),(57703,18310,'118979','deals-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(57704,18310,'118979','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57705,18311,'118980','deals-mobile','style_class','closeable-content',0,''),(57706,18311,'118980','deals-mobile','padding-bottom','20',0,''),(57707,18312,'118981','deals-mobile','block_type','1',0,''),(57708,18312,'118981','deals-mobile','padding-top','30',0,''),(57709,18312,'118981','deals-mobile','padding-left','30',0,''),(57710,18312,'118981','deals-mobile','padding-right','30',0,''),(57711,18312,'118981','deals-mobile','padding-bottom','14',0,''),(57712,18312,'118981','deals-mobile','margin-bottom','20',0,''),(57713,18312,'118981','deals-mobile','background-color','#ffffff',0,''),(57714,18312,'118981','deals-mobile','style_class','hiding-box closeable-box',0,''),(57715,18313,'118982','deals-mobile','block_type','2',0,''),(57716,18313,'118982','deals-mobile','style_class','closeable-content',0,''),(57717,18314,'118983','deals-mobile','padding-right','20',0,''),(57718,18314,'118983','deals-mobile','padding-bottom','20',0,''),(57719,18315,'118984','deals-mobile','padding-left','20',0,''),(57720,18315,'118984','deals-mobile','padding-bottom','20',0,''),(57721,18316,'118985','deals-mobile','padding-left','20',0,''),(57722,18316,'118985','deals-mobile','padding-bottom','20',0,''),(57723,18317,'118986','deals-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(57724,18317,'118986','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57725,18318,'118987','deals-mobile','block_type','1',0,''),(57726,18318,'118987','deals-mobile','padding-top','30',0,''),(57727,18318,'118987','deals-mobile','padding-left','30',0,''),(57728,18318,'118987','deals-mobile','padding-right','30',0,''),(57729,18318,'118987','deals-mobile','padding-bottom','23',0,''),(57730,18318,'118987','deals-mobile','margin-bottom','20',0,''),(57731,18318,'118987','deals-mobile','background-color','#ffffff',0,''),(57732,18318,'118987','deals-mobile','style_class','hiding-box',0,''),(57733,18319,'118988','deals-mobile','block_type','2',0,''),(57734,18320,'118989','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57735,18321,'118990','deals-mobile','padding-right','20',0,''),(57736,18322,'118991','deals-mobile','block_type','1',0,''),(57737,18322,'118991','deals-mobile','padding-left','20',0,''),(57738,18323,'118992','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57739,18325,'118994','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(57740,18326,'118995','deals-mobile','block_type','1',0,''),(57741,18326,'118995','deals-mobile','background-color','#ffffff',0,''),(57742,18326,'118995','deals-mobile','padding-top','30',0,''),(57743,18326,'118995','deals-mobile','padding-left','30',0,''),(57744,18326,'118995','deals-mobile','padding-right','30',0,''),(57745,18326,'118995','deals-mobile','padding-bottom','30',0,''),(57746,18326,'118995','deals-mobile','margin-bottom','20',0,''),(57747,18326,'118995','deals-mobile','style_class','hiding-box',0,''),(57748,18327,'118996','deals-mobile','margin-bottom','20',0,''),(57749,18328,'118997','deals-mobile','padding-top','10',0,''),(57750,18328,'118997','deals-mobile','padding-left','20',0,''),(57751,18328,'118997','deals-mobile','padding-right','20',0,''),(57752,18328,'118997','deals-mobile','margin-top','20',0,''),(57753,18328,'118997','deals-mobile','background-color','#eeeeee',0,''),(57754,18328,'118997','deals-mobile','padding-bottom','8',0,''),(57755,18329,'118998','deals-mobile','block_type','1',0,''),(57756,18329,'118998','deals-mobile','padding-top','20',0,''),(57757,18329,'118998','deals-mobile','padding-left','20',0,''),(57758,18329,'118998','deals-mobile','padding-right','20',0,''),(57759,18329,'118998','deals-mobile','padding-bottom','20',0,''),(57760,18329,'118998','deals-mobile','background-color','#ffffff',0,''),(57761,18329,'118998','deals-mobile','style_class','order-summary hiding-box',0,''),(57762,18330,'118999','deals-mobile','hide_page','1',0,''),(57763,18330,'118999','deals-mobile','hide_continue_button','1',0,''),(57764,18332,'119001','deals-mobile','margin-bottom','10',0,''),(57765,18333,'119002','deals-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(57766,18333,'119002','deals-mobile','text-align','center',0,''),(57767,18333,'119002','deals-mobile','font-size','14',0,''),(57768,18333,'119002','deals-mobile','color','#757575',0,''),(57769,18333,'119002','deals-mobile','padding-top','10',0,''),(57770,18334,'119003','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(57771,18335,'119004','deals-mobile','block_type','1',0,''),(57772,18336,'119005','deals-mobile','margin-bottom','20',0,''),(57773,18337,'119006','deals-mobile','block_type','2',0,''),(57774,18337,'119006','deals-mobile','schema','2-2',0,''),(57775,18338,'119007','deals-mobile','block_type','1',0,''),(57776,18338,'119007','deals-mobile','padding-right','20',0,''),(57778,18340,'119009','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57779,18341,'119010','deals-mobile','block_type','1',0,''),(57780,18341,'119010','deals-mobile','padding-left','20',0,''),(57782,18343,'119012','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57783,18347,'119016','deals-mobile','block_type','2',0,''),(57784,18347,'119016','deals-mobile','schema','2-2',0,''),(57785,18348,'119017','deals-mobile','block_type','1',0,''),(57786,18348,'119017','deals-mobile','padding-right','20',0,''),(57788,18349,'119018','deals-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(57789,18351,'119020','deals-mobile','block_type','1',0,''),(57790,18351,'119020','deals-mobile','padding-left','20',0,''),(57792,18352,'119021','deals-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(57793,18354,'119023','deals-mobile','block_type','4',0,''),(57794,18354,'119023','deals-mobile','schema','4-2',0,''),(57795,18355,'119024','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57796,18355,'119024','deals-mobile','text-align','right',0,''),(57797,18355,'119024','deals-mobile','padding-top','10',0,''),(57798,18355,'119024','deals-mobile','font_size_measure','em',0,''),(57799,18355,'119024','deals-mobile','font-size','1.2',0,''),(57800,18356,'119025','deals-mobile','text-align','right',0,''),(57801,18358,'119027','deals-mobile','block_type','1',0,''),(57802,18358,'119027','deals-mobile','background-color','#eeeeee',0,''),(57803,18358,'119027','deals-mobile','padding-top','30',0,''),(57804,18358,'119027','deals-mobile','padding-bottom','30',0,''),(57805,18359,'119028','deals-mobile','block_type','4',0,''),(57806,18359,'119028','deals-mobile','schema','4-2',0,''),(57807,18360,'119029','deals-mobile','block_type','1',0,''),(57808,18360,'119029','deals-mobile','padding-right','40',0,''),(57810,18361,'119030','deals-mobile','block_type','1',0,''),(57811,18361,'119030','deals-mobile','padding-top','30',0,''),(57812,18361,'119030','deals-mobile','padding-left','30',0,''),(57813,18361,'119030','deals-mobile','padding-right','30',0,''),(57814,18361,'119030','deals-mobile','padding-bottom','23',0,''),(57815,18361,'119030','deals-mobile','margin-bottom','20',0,''),(57816,18361,'119030','deals-mobile','background-color','#ffffff',0,''),(57817,18361,'119030','deals-mobile','style_class','hiding-box',0,''),(57818,18362,'119031','deals-mobile','block_type','2',0,''),(57819,18362,'119031','deals-mobile','schema','2-2',0,''),(57820,18363,'119032','deals-mobile','padding-right','20',0,''),(57822,18363,'119032','deals-mobile','padding-bottom','20',0,''),(57823,18364,'119033','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57824,18365,'119034','deals-mobile','block_type','1',0,''),(57825,18365,'119034','deals-mobile','padding-left','20',0,''),(57827,18366,'119035','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57828,18368,'119037','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(57829,18369,'119038','deals-mobile','block_type','1',0,''),(57830,18369,'119038','deals-mobile','background-color','#ffffff',0,''),(57831,18369,'119038','deals-mobile','padding-top','30',0,''),(57832,18369,'119038','deals-mobile','padding-left','30',0,''),(57833,18369,'119038','deals-mobile','padding-right','30',0,''),(57834,18369,'119038','deals-mobile','padding-bottom','30',0,''),(57835,18369,'119038','deals-mobile','margin-bottom','20',0,''),(57836,18369,'119038','deals-mobile','style_class','hiding-box',0,''),(57837,18370,'119039','deals-mobile','padding-top','10',0,''),(57838,18370,'119039','deals-mobile','padding-left','20',0,''),(57839,18370,'119039','deals-mobile','padding-right','20',0,''),(57840,18370,'119039','deals-mobile','margin-top','20',0,''),(57841,18370,'119039','deals-mobile','background-color','#eeeeee',0,''),(57842,18370,'119039','deals-mobile','padding-bottom','8',0,''),(57843,18371,'119040','deals-mobile','margin-bottom','20',0,''),(57844,18372,'119041','deals-mobile','block_type','1',0,''),(57845,18372,'119041','deals-mobile','background-color','#ffffff',0,''),(57846,18372,'119041','deals-mobile','padding-top','30',0,''),(57847,18372,'119041','deals-mobile','padding-left','30',0,''),(57848,18372,'119041','deals-mobile','padding-right','30',0,''),(57849,18372,'119041','deals-mobile','padding-bottom','14',0,''),(57850,18372,'119041','deals-mobile','margin-bottom','20',0,''),(57851,18372,'119041','deals-mobile','style_class','hiding-box closeable-box',0,''),(57852,18373,'119042','deals-mobile','style_class','closeable-content',0,''),(57853,18373,'119042','deals-mobile','padding-bottom','20',0,''),(57854,18374,'119043','deals-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(57855,18374,'119043','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57856,18375,'119044','deals-mobile','background-color','#ffffff',0,''),(57857,18375,'119044','deals-mobile','padding-top','30',0,''),(57858,18375,'119044','deals-mobile','padding-left','30',0,''),(57859,18375,'119044','deals-mobile','padding-right','30',0,''),(57860,18375,'119044','deals-mobile','padding-bottom','30',0,''),(57861,18375,'119044','deals-mobile','margin-bottom','20',0,''),(57862,18376,'119045','deals-mobile','block_type','1',0,''),(57863,18376,'119045','deals-mobile','padding-top','20',0,''),(57864,18376,'119045','deals-mobile','padding-left','20',0,''),(57865,18376,'119045','deals-mobile','padding-right','20',0,''),(57866,18376,'119045','deals-mobile','padding-bottom','20',0,''),(57867,18376,'119045','deals-mobile','background-color','#ffffff',0,''),(57868,18376,'119045','deals-mobile','style_class','order-summary',0,''),(57869,18377,'119046','deals-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(57870,18377,'119046','deals-mobile','text-align','center',0,''),(57871,18377,'119046','deals-mobile','font-size','14',0,''),(57872,18377,'119046','deals-mobile','color','#757575',0,''),(57873,18377,'119046','deals-mobile','padding-top','10',0,''),(57874,18378,'119047','deals-mobile','margin-bottom','10',0,''),(57875,18380,'119049','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(57876,18381,'119050','deals-mobile','block_type','4',0,''),(57877,18381,'119050','deals-mobile','schema','4-2',0,''),(57878,18382,'119051','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57879,18382,'119051','deals-mobile','text-align','right',0,''),(57880,18382,'119051','deals-mobile','padding-top','10',0,''),(57881,18382,'119051','deals-mobile','font_size_measure','em',0,''),(57882,18382,'119051','deals-mobile','font-size','1.2',0,''),(57883,18383,'119052','deals-mobile','text-align','right',0,''),(57884,18384,'119053','deals-mobile','block_type','2',0,''),(57885,18385,'119054','deals-mobile','block_type','1',0,''),(57886,18385,'119054','deals-mobile','padding-left','0',0,''),(57887,18385,'119054','deals-mobile','padding-right','20',0,''),(57888,18387,'119056','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57889,18388,'119057','deals-mobile','block_type','1',0,''),(57890,18388,'119057','deals-mobile','padding-left','20',0,''),(57892,18390,'119059','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57893,18394,'119063','deals-mobile','block_type','2',0,''),(57894,18395,'119064','deals-mobile','block_type','1',0,''),(57895,18395,'119064','deals-mobile','padding-left','0',0,''),(57896,18395,'119064','deals-mobile','padding-right','20',0,''),(57897,18396,'119065','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57898,18398,'119067','deals-mobile','block_type','1',0,''),(57899,18398,'119067','deals-mobile','padding-left','20',0,''),(57901,18400,'119069','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57902,18404,'119073','deals-mobile','block_type','4',0,''),(57903,18404,'119073','deals-mobile','schema','4-2',0,''),(57904,18405,'119074','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57905,18405,'119074','deals-mobile','text-align','right',0,''),(57906,18405,'119074','deals-mobile','padding-top','10',0,''),(57907,18405,'119074','deals-mobile','font_size_measure','em',0,''),(57908,18405,'119074','deals-mobile','font-size','1.2',0,''),(57909,18406,'119075','deals-mobile','text-align','right',0,''),(57910,18407,'119076','deals-mobile','block_type','2',0,''),(57911,18408,'119077','deals-mobile','block_type','1',0,''),(57912,18408,'119077','deals-mobile','padding-left','0',0,''),(57913,18408,'119077','deals-mobile','padding-right','20',0,''),(57914,18409,'119078','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57915,18411,'119080','deals-mobile','block_type','1',0,''),(57916,18411,'119080','deals-mobile','padding-left','20',0,''),(57918,18412,'119081','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57919,18417,'119086','deals-mobile','block_type','4',0,''),(57920,18417,'119086','deals-mobile','schema','4-2',0,''),(57921,18418,'119087','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57922,18418,'119087','deals-mobile','text-align','right',0,''),(57923,18418,'119087','deals-mobile','padding-top','10',0,''),(57924,18418,'119087','deals-mobile','font_size_measure','em',0,''),(57925,18418,'119087','deals-mobile','font-size','1.2',0,''),(57926,18419,'119088','deals-mobile','text-align','right',0,''),(57927,18420,'119089','deals-mobile','block_type','4',0,''),(57928,18420,'119089','deals-mobile','schema','4-2',0,''),(57929,18421,'119090','deals-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(57930,18421,'119090','deals-mobile','text-align','right',0,''),(57931,18421,'119090','deals-mobile','padding-top','10',0,''),(57932,18421,'119090','deals-mobile','font_size_measure','em',0,''),(57933,18421,'119090','deals-mobile','font-size','1.2',0,''),(57934,18422,'119091','deals-mobile','text-align','right',0,''),(57935,18423,'119092','deals-mobile','block_type','2',0,''),(57936,18424,'119093','deals-mobile','block_type','1',0,''),(57937,18424,'119093','deals-mobile','padding-left','0',0,''),(57938,18424,'119093','deals-mobile','padding-right','20',0,''),(57939,18426,'119095','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57940,18427,'119096','deals-mobile','block_type','1',0,''),(57941,18427,'119096','deals-mobile','padding-left','20',0,''),(57943,18429,'119098','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57944,18433,'119102','deals-mobile','text','##PAYMENT_DETAILS##',0,''),(57945,18434,'119103','deals-mobile','text','##PAYMENT_DETAILS##',0,''),(57946,18435,'119104','deals-mobile','text','##PAYMENT_DETAILS##',0,''),(57947,18436,'119105','deals-mobile','text','##PAYMENT_DETAILS##',0,''),(57948,18437,'119106','deals-mobile','text','##PAYMENT_DETAILS##',0,''),(57949,18438,'119107','deals-mobile','text','##PAYMENT_DETAILS##',0,''),(57950,18439,'119108','deals-mobile','block_type','1',0,''),(57951,18439,'119108','deals-mobile','background-color','#eeeeee',0,''),(57952,18439,'119108','deals-mobile','padding-top','30',0,''),(57953,18439,'119108','deals-mobile','padding-bottom','30',0,''),(57954,18440,'119109','deals-mobile','block_type','4',0,''),(57955,18440,'119109','deals-mobile','schema','4-2',0,''),(57956,18441,'119110','deals-mobile','block_type','1',0,''),(57957,18441,'119110','deals-mobile','padding-right','40',0,''),(57959,18442,'119111','deals-mobile','block_type','1',0,''),(57960,18442,'119111','deals-mobile','padding-top','30',0,''),(57961,18442,'119111','deals-mobile','padding-left','30',0,''),(57962,18442,'119111','deals-mobile','padding-right','30',0,''),(57963,18442,'119111','deals-mobile','padding-bottom','23',0,''),(57964,18442,'119111','deals-mobile','margin-bottom','20',0,''),(57965,18442,'119111','deals-mobile','background-color','#ffffff',0,''),(57966,18442,'119111','deals-mobile','style_class','hiding-box',0,''),(57967,18443,'119112','deals-mobile','block_type','2',0,''),(57968,18443,'119112','deals-mobile','schema','2-2',0,''),(57969,18444,'119113','deals-mobile','padding-right','20',0,''),(57971,18444,'119113','deals-mobile','padding-bottom','20',0,''),(57972,18445,'119114','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(57973,18446,'119115','deals-mobile','block_type','1',0,''),(57974,18446,'119115','deals-mobile','padding-left','20',0,''),(57976,18447,'119116','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(57977,18449,'119118','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(57978,18450,'119119','deals-mobile','block_type','1',0,''),(57979,18450,'119119','deals-mobile','background-color','#ffffff',0,''),(57980,18450,'119119','deals-mobile','padding-top','30',0,''),(57981,18450,'119119','deals-mobile','padding-left','30',0,''),(57982,18450,'119119','deals-mobile','padding-right','30',0,''),(57983,18450,'119119','deals-mobile','padding-bottom','14',0,''),(57984,18450,'119119','deals-mobile','margin-bottom','20',0,''),(57985,18450,'119119','deals-mobile','style_class','hiding-box closeable-box',0,''),(57986,18451,'119120','deals-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(57987,18451,'119120','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(57988,18452,'119121','deals-mobile','style_class','closeable-content',0,''),(57989,18452,'119121','deals-mobile','padding-bottom','20',0,''),(57990,18453,'119122','deals-mobile','background-color','#ffffff',0,''),(57991,18453,'119122','deals-mobile','padding-top','30',0,''),(57992,18453,'119122','deals-mobile','padding-left','30',0,''),(57993,18453,'119122','deals-mobile','padding-right','30',0,''),(57994,18453,'119122','deals-mobile','padding-bottom','30',0,''),(57995,18453,'119122','deals-mobile','margin-bottom','20',0,''),(57996,18454,'119123','deals-mobile','background-color','#ffffff',0,''),(57997,18454,'119123','deals-mobile','block_type','1',0,''),(57998,18454,'119123','deals-mobile','padding-top','30',0,''),(57999,18454,'119123','deals-mobile','padding-left','30',0,''),(58000,18454,'119123','deals-mobile','padding-right','30',0,''),(58001,18454,'119123','deals-mobile','padding-bottom','30',0,''),(58002,18454,'119123','deals-mobile','margin-bottom','20',0,''),(58003,18454,'119123','deals-mobile','style_class','hiding-box',0,''),(58004,18455,'119124','deals-mobile','block_type','2',0,''),(58005,18455,'119124','deals-mobile','schema','2-2',0,''),(58006,18456,'119125','deals-mobile','block_type','1',0,''),(58007,18456,'119125','deals-mobile','padding-right','20',0,''),(58008,18456,'119125','deals-mobile','padding-left','0',0,''),(58009,18456,'119125','deals-mobile','margin-bottom','20',0,''),(58010,18457,'119126','deals-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(58011,18460,'119129','deals-mobile','block_type','1',0,''),(58012,18460,'119129','deals-mobile','padding-left','20',0,''),(58014,18461,'119130','deals-mobile','border-top-width','1',0,''),(58015,18461,'119130','deals-mobile','border-top-color','#e0e0e0',0,''),(58016,18461,'119130','deals-mobile','padding-top','13',0,''),(58017,18461,'119130','deals-mobile','padding-bottom','10',0,''),(58018,18462,'119131','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(58019,18464,'119133','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(58020,18465,'119134','deals-mobile','background-color','#eeeeee',0,''),(58021,18465,'119134','deals-mobile','padding-top','10',0,''),(58022,18465,'119134','deals-mobile','padding-left','10',0,''),(58023,18465,'119134','deals-mobile','padding-right','10',0,''),(58024,18465,'119134','deals-mobile','padding-bottom','10',0,''),(58025,18465,'119134','deals-mobile','margin-top','10',0,''),(58026,18466,'119135','deals-mobile','block_type','1',0,''),(58027,18466,'119135','deals-mobile','content','\\_',0,'3'),(58028,18466,'119135','deals-mobile','border-top-width','1',0,'3'),(58029,18466,'119135','deals-mobile','border-top-color','#e0e0e0',0,'3'),(58030,18466,'119135','deals-mobile','display','block',0,'3'),(58031,18466,'119135','deals-mobile','position','absolute',0,'3'),(58032,18466,'119135','deals-mobile','top','19',0,'3'),(58033,18466,'119135','deals-mobile','left','0',0,'3'),(58034,18466,'119135','deals-mobile','right','0',0,'3'),(58035,18466,'119135','deals-mobile','margin-top','-2',0,'3'),(58036,18466,'119135','deals-mobile','position','relative',0,''),(58037,18467,'119136','deals-mobile','box_align','2',0,''),(58038,18467,'119136','deals-mobile','margin-bottom','10',0,''),(58039,18467,'119136','deals-mobile','background-color','#ffffff',0,''),(58040,18467,'119136','deals-mobile','position','relative',0,''),(58041,18468,'119137','deals-mobile','block_type','1',0,''),(58042,18468,'119137','deals-mobile','background-color','#ffffff',0,''),(58043,18468,'119137','deals-mobile','padding-top','30',0,''),(58044,18468,'119137','deals-mobile','padding-left','30',0,''),(58045,18468,'119137','deals-mobile','padding-right','30',0,''),(58046,18468,'119137','deals-mobile','padding-bottom','30',0,''),(58047,18468,'119137','deals-mobile','margin-bottom','20',0,''),(58048,18468,'119137','deals-mobile','style_class','hiding-box',0,''),(58049,18469,'119138','deals-mobile','margin-bottom','20',0,''),(58050,18470,'119139','deals-mobile','padding-top','10',0,''),(58051,18470,'119139','deals-mobile','padding-left','20',0,''),(58052,18470,'119139','deals-mobile','padding-right','20',0,''),(58053,18470,'119139','deals-mobile','margin-top','20',0,''),(58054,18470,'119139','deals-mobile','background-color','#eeeeee',0,''),(58055,18470,'119139','deals-mobile','padding-bottom','8',0,''),(58056,18471,'119140','deals-mobile','block_type','1',0,''),(58057,18471,'119140','deals-mobile','padding-top','20',0,''),(58058,18471,'119140','deals-mobile','padding-left','20',0,''),(58059,18471,'119140','deals-mobile','padding-right','20',0,''),(58060,18471,'119140','deals-mobile','padding-bottom','20',0,''),(58061,18471,'119140','deals-mobile','background-color','#ffffff',0,''),(58062,18471,'119140','deals-mobile','style_class','order-summary',0,''),(58063,18473,'119142','deals-mobile','margin-bottom','10',0,''),(58064,18474,'119143','deals-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(58065,18474,'119143','deals-mobile','text-align','center',0,''),(58066,18474,'119143','deals-mobile','font-size','14',0,''),(58067,18474,'119143','deals-mobile','color','#757575',0,''),(58068,18474,'119143','deals-mobile','padding-top','10',0,''),(58069,18475,'119144','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58070,18476,'119145','deals-mobile','block_type','1',0,''),(58071,18476,'119145','deals-mobile','padding-top','30',0,''),(58072,18476,'119145','deals-mobile','padding-bottom','30',0,''),(58073,18476,'119145','deals-mobile','background-color','#eeeeeh',0,''),(58074,18477,'119146','deals-mobile','block_type','4',0,''),(58075,18477,'119146','deals-mobile','schema','4-2',0,''),(58076,18478,'119147','deals-mobile','block_type','1',0,''),(58077,18478,'119147','deals-mobile','padding-right','40',0,''),(58079,18479,'119148','deals-mobile','block_type','1',0,''),(58080,18479,'119148','deals-mobile','padding-top','30',0,''),(58081,18479,'119148','deals-mobile','padding-left','30',0,''),(58082,18479,'119148','deals-mobile','padding-right','30',0,''),(58083,18479,'119148','deals-mobile','padding-bottom','14',0,''),(58084,18479,'119148','deals-mobile','margin-bottom','20',0,''),(58085,18479,'119148','deals-mobile','background-color','#ffffff',0,''),(58086,18479,'119148','deals-mobile','style_class','hiding-box closeable-box',0,''),(58087,18480,'119149','deals-mobile','block_type','2',0,''),(58088,18480,'119149','deals-mobile','style_class','closeable-content',0,''),(58089,18480,'119149','deals-mobile','schema','2-2',0,''),(58090,18481,'119150','deals-mobile','padding-right','20',0,''),(58091,18481,'119150','deals-mobile','padding-bottom','20',0,''),(58093,18482,'119151','deals-mobile','padding-left','20',0,''),(58094,18482,'119151','deals-mobile','padding-bottom','20',0,''),(58096,18483,'119152','deals-mobile','padding-left','20',0,''),(58097,18483,'119152','deals-mobile','padding-bottom','20',0,''),(58099,18484,'119153','deals-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(58100,18484,'119153','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(58101,18485,'119154','deals-mobile','block_type','1',0,''),(58102,18485,'119154','deals-mobile','padding-top','30',0,''),(58103,18485,'119154','deals-mobile','padding-left','30',0,''),(58104,18485,'119154','deals-mobile','padding-right','30',0,''),(58105,18485,'119154','deals-mobile','padding-bottom','23',0,''),(58106,18485,'119154','deals-mobile','margin-bottom','20',0,''),(58107,18485,'119154','deals-mobile','background-color','#ffffff',0,''),(58108,18485,'119154','deals-mobile','style_class','hiding-box',0,''),(58109,18486,'119155','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(58110,18487,'119156','deals-mobile','block_type','2',0,''),(58111,18487,'119156','deals-mobile','schema','2-2',0,''),(58112,18488,'119157','deals-mobile','padding-right','20',0,''),(58114,18488,'119157','deals-mobile','padding-bottom','20',0,''),(58115,18489,'119158','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(58116,18490,'119159','deals-mobile','block_type','1',0,''),(58117,18490,'119159','deals-mobile','padding-left','20',0,''),(58119,18492,'119161','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(58120,18493,'119162','deals-mobile','block_type','1',0,''),(58121,18493,'119162','deals-mobile','background-color','#ffffff',0,''),(58122,18493,'119162','deals-mobile','padding-top','30',0,''),(58123,18493,'119162','deals-mobile','padding-left','30',0,''),(58124,18493,'119162','deals-mobile','padding-right','30',0,''),(58125,18493,'119162','deals-mobile','padding-bottom','14',0,''),(58126,18493,'119162','deals-mobile','margin-bottom','20',0,''),(58127,18493,'119162','deals-mobile','style_class','hiding-box closeable-box',0,''),(58128,18494,'119163','deals-mobile','style_class','closeable-content',0,''),(58129,18494,'119163','deals-mobile','padding-bottom','20',0,''),(58130,18495,'119164','deals-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(58131,18495,'119164','deals-mobile','style_class','closeable-heading closeable-event closed',0,''),(58132,18496,'119165','deals-mobile','background-color','#ffffff',0,''),(58133,18496,'119165','deals-mobile','block_type','1',0,''),(58134,18496,'119165','deals-mobile','padding-top','30',0,''),(58135,18496,'119165','deals-mobile','padding-left','30',0,''),(58136,18496,'119165','deals-mobile','padding-right','30',0,''),(58137,18496,'119165','deals-mobile','padding-bottom','30',0,''),(58138,18496,'119165','deals-mobile','margin-bottom','20',0,''),(58139,18496,'119165','deals-mobile','style_class','hiding-box',0,''),(58140,18497,'119166','deals-mobile','block_type','1',0,''),(58141,18497,'119166','deals-mobile','content','\\_',0,'3'),(58142,18497,'119166','deals-mobile','border-top-width','1',0,'3'),(58143,18497,'119166','deals-mobile','border-top-color','#e0e0e0',0,'3'),(58144,18497,'119166','deals-mobile','display','block',0,'3'),(58145,18497,'119166','deals-mobile','position','absolute',0,'3'),(58146,18497,'119166','deals-mobile','top','19',0,'3'),(58147,18497,'119166','deals-mobile','left','0',0,'3'),(58148,18497,'119166','deals-mobile','right','0',0,'3'),(58149,18497,'119166','deals-mobile','margin-top','-2',0,'3'),(58150,18497,'119166','deals-mobile','position','relative',0,''),(58151,18498,'119167','deals-mobile','box_align','2',0,''),(58152,18498,'119167','deals-mobile','margin-bottom','10',0,''),(58153,18498,'119167','deals-mobile','background-color','#ffffff',0,''),(58154,18498,'119167','deals-mobile','position','relative',0,''),(58155,18499,'119168','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(58156,18500,'119169','deals-mobile','block_type','2',0,''),(58157,18500,'119169','deals-mobile','schema','2-2',0,''),(58158,18501,'119170','deals-mobile','block_type','1',0,''),(58159,18501,'119170','deals-mobile','padding-right','20',0,''),(58160,18501,'119170','deals-mobile','padding-left','0',0,''),(58161,18501,'119170','deals-mobile','margin-bottom','20',0,''),(58162,18503,'119172','deals-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(58163,18505,'119174','deals-mobile','block_type','1',0,''),(58164,18505,'119174','deals-mobile','padding-left','20',0,''),(58166,18506,'119175','deals-mobile','border-top-width','1',0,''),(58167,18506,'119175','deals-mobile','border-top-color','#e0e0e0',0,''),(58168,18506,'119175','deals-mobile','padding-top','13',0,''),(58169,18506,'119175','deals-mobile','padding-bottom','10',0,''),(58170,18507,'119176','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(58171,18509,'119178','deals-mobile','background-color','#eeeeee',0,''),(58172,18509,'119178','deals-mobile','padding-top','10',0,''),(58173,18509,'119178','deals-mobile','padding-left','10',0,''),(58174,18509,'119178','deals-mobile','padding-right','10',0,''),(58175,18509,'119178','deals-mobile','padding-bottom','10',0,''),(58176,18509,'119178','deals-mobile','margin-top','10',0,''),(58177,18510,'119179','deals-mobile','block_type','1',0,''),(58178,18510,'119179','deals-mobile','background-color','#ffffff',0,''),(58179,18510,'119179','deals-mobile','padding-top','30',0,''),(58180,18510,'119179','deals-mobile','padding-left','30',0,''),(58181,18510,'119179','deals-mobile','padding-right','30',0,''),(58182,18510,'119179','deals-mobile','padding-bottom','30',0,''),(58183,18510,'119179','deals-mobile','margin-bottom','20',0,''),(58184,18510,'119179','deals-mobile','style_class','hiding-box',0,''),(58185,18511,'119180','deals-mobile','padding-top','10',0,''),(58186,18511,'119180','deals-mobile','padding-left','20',0,''),(58187,18511,'119180','deals-mobile','padding-right','20',0,''),(58188,18511,'119180','deals-mobile','margin-top','20',0,''),(58189,18511,'119180','deals-mobile','background-color','#eeeeee',0,''),(58190,18511,'119180','deals-mobile','padding-bottom','8',0,''),(58191,18512,'119181','deals-mobile','margin-bottom','20',0,''),(58192,18513,'119182','deals-mobile','background-color','#ffffff',0,''),(58193,18513,'119182','deals-mobile','padding-top','30',0,''),(58194,18513,'119182','deals-mobile','padding-left','30',0,''),(58195,18513,'119182','deals-mobile','padding-right','30',0,''),(58196,18513,'119182','deals-mobile','padding-bottom','30',0,''),(58197,18513,'119182','deals-mobile','margin-bottom','20',0,''),(58198,18514,'119183','deals-mobile','block_type','1',0,''),(58199,18514,'119183','deals-mobile','padding-top','20',0,''),(58200,18514,'119183','deals-mobile','padding-left','20',0,''),(58201,18514,'119183','deals-mobile','padding-right','20',0,''),(58202,18514,'119183','deals-mobile','padding-bottom','20',0,''),(58203,18514,'119183','deals-mobile','background-color','#ffffff',0,''),(58204,18514,'119183','deals-mobile','style_class','order-summary',0,''),(58205,18515,'119184','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58206,18517,'119186','deals-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(58207,18517,'119186','deals-mobile','text-align','center',0,''),(58208,18517,'119186','deals-mobile','font-size','14',0,''),(58209,18517,'119186','deals-mobile','color','#757575',0,''),(58210,18517,'119186','deals-mobile','padding-top','10',0,''),(58211,18518,'119187','deals-mobile','margin-bottom','10',0,''),(58212,18521,'119190','deals-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(58213,18524,'119193','deals-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(58214,18525,'119194','deals-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(58215,18528,'119197','deals-mobile','style_class','order-summary',0,''),(58216,18528,'119197','deals-mobile','box_align','3',0,''),(58217,18528,'119197','deals-mobile','width','400',0,''),(58218,18529,'119198','deals-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(58219,18531,'119200','deals-mobile','block_type','1',0,''),(58220,18532,'119201','deals-mobile','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(58221,18533,'119202','deals-mobile','margin-bottom','30',0,''),(58222,18534,'119203','deals-mobile','float','right',0,''),(58223,18534,'119203','deals-mobile','position','relative',0,''),(58224,18534,'119203','deals-mobile','z-index','1',0,''),(58225,18534,'119203','deals-mobile','top','30',0,''),(58226,18534,'119203','deals-mobile','margin-bottom','-20',0,''),(58227,18535,'119204','deals-mobile','block_type','1',0,''),(58228,18536,'119205','deals-mobile','listing_type','Compare Products',0,''),(58229,18537,'119206','deals-mobile','block_type','1',0,''),(58230,18537,'119206','deals-mobile','style_class','item-holder',0,''),(58231,18537,'119206','deals-mobile','padding-top','10',0,''),(58232,18537,'119206','deals-mobile','padding-left','20',0,''),(58233,18537,'119206','deals-mobile','padding-right','20',0,''),(58234,18537,'119206','deals-mobile','padding-bottom','10',0,''),(58235,18537,'119206','deals-mobile','text-align','left',0,''),(58236,18540,'119209','deals-mobile','margin-bottom','10',0,''),(58237,18541,'119210','deals-mobile','block_type','5',0,''),(58238,18543,'119212','deals-mobile','clear','both',0,''),(58239,18544,'119213','deals-mobile','block_type','2',0,''),(58240,18545,'119214','deals-mobile','margin-bottom','7',0,''),(58241,18546,'119215','deals-mobile','text-align','right',0,''),(58242,18546,'119215','deals-mobile','margin-bottom','10',0,''),(58243,18546,'119215','deals-mobile','float','right',0,''),(58244,18547,'119216','deals-mobile','block_type','1',0,''),(58245,18547,'119216','deals-mobile','background-color','#eeeeee',0,''),(58246,18547,'119216','deals-mobile','padding-bottom','30',0,''),(58247,18548,'119217','deals-mobile','block_type','1',0,''),(58248,18548,'119217','deals-mobile','schema','4-2',0,''),(58249,18548,'119217','deals-mobile','schema','4-2',0,'872'),(58250,18550,'119219','deals-mobile','block_type','1',0,''),(58251,18550,'119219','deals-mobile','padding-right','40',0,''),(58253,18551,'119220','deals-mobile','block_type','1',0,''),(58254,18551,'119220','deals-mobile','margin-bottom','20',0,''),(58255,18551,'119220','deals-mobile','schema','2-2',0,''),(58256,18551,'119220','deals-mobile','background-color','#ffffff',0,''),(58257,18552,'119221','deals-mobile','block_type','1',0,''),(58258,18552,'119221','deals-mobile','border-right-width','20',0,''),(58259,18552,'119221','deals-mobile','border-right-color','#e0e0e0',0,''),(58260,18552,'119221','deals-mobile','margin-right','-10',0,''),(58261,18552,'119221','deals-mobile','padding-right','30',0,''),(58262,18552,'119221','deals-mobile','padding-top','20',0,''),(58263,18552,'119221','deals-mobile','padding-left','30',0,''),(58264,18552,'119221','deals-mobile','padding-bottom','20',0,''),(58267,18552,'119221','deals-mobile','margin-bottom','20',0,''),(58270,18553,'119222','deals-mobile','margin-bottom','20',0,''),(58271,18554,'119223','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(58272,18555,'119224','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(58273,18555,'119224','deals-mobile','clear','none',0,''),(58274,18557,'119226','deals-mobile','link','shipping_address',0,''),(58275,18557,'119226','deals-mobile','float','right',0,''),(58276,18557,'119226','deals-mobile','margin-top','-31',0,''),(58277,18558,'119227','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(58278,18558,'119227','deals-mobile','clear','none',0,''),(58279,18560,'119229','deals-mobile','link','contact_information',0,''),(58280,18560,'119229','deals-mobile','margin-top','-31',0,''),(58281,18560,'119229','deals-mobile','float','right',0,''),(58282,18561,'119230','deals-mobile','link','shipping_method',0,''),(58283,18561,'119230','deals-mobile','float','right',0,''),(58284,18561,'119230','deals-mobile','margin-top','-31',0,''),(58285,18562,'119231','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(58286,18562,'119231','deals-mobile','padding-top','20',0,''),(58287,18564,'119233','deals-mobile','block_type','1',0,''),(58288,18564,'119233','deals-mobile','padding-left','30',0,''),(58289,18564,'119233','deals-mobile','border-left-width','20',0,''),(58290,18564,'119233','deals-mobile','border-left-color','#e0e0e0',0,''),(58291,18564,'119233','deals-mobile','margin-left','-10',0,''),(58292,18564,'119233','deals-mobile','padding-right','30',0,''),(58293,18564,'119233','deals-mobile','padding-top','20',0,''),(58294,18564,'119233','deals-mobile','padding-bottom','20',0,''),(58296,18565,'119234','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(58297,18565,'119234','deals-mobile','clear','none',0,''),(58298,18566,'119235','deals-mobile','margin-bottom','20',0,''),(58299,18567,'119236','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(58300,18567,'119236','deals-mobile','clear','none',0,''),(58301,18569,'119238','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(58302,18570,'119239','deals-mobile','link','billing_address',0,''),(58303,18570,'119239','deals-mobile','float','right',0,''),(58304,18570,'119239','deals-mobile','margin-top','-31',0,''),(58305,18571,'119240','deals-mobile','link','payment_method',0,''),(58306,18571,'119240','deals-mobile','float','right',0,''),(58307,18571,'119240','deals-mobile','margin-top','-31',0,''),(58308,18572,'119241','deals-mobile','block_type','1',0,''),(58309,18572,'119241','deals-mobile','padding-right','30',0,''),(58310,18572,'119241','deals-mobile','background-color','#ffffff',0,''),(58311,18572,'119241','deals-mobile','padding-top','20',0,''),(58312,18572,'119241','deals-mobile','padding-left','30',0,''),(58313,18572,'119241','deals-mobile','padding-bottom','20',0,''),(58316,18573,'119242','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(58317,18574,'119243','deals-mobile','link','products',0,''),(58318,18574,'119243','deals-mobile','float','right',0,''),(58319,18574,'119243','deals-mobile','margin-top','-37',0,''),(58320,18576,'119245','deals-mobile','block_type','1',0,''),(58321,18576,'119245','deals-mobile','background-color','#ffffff',0,'');
INSERT INTO `design_boxes_settings_tmp` VALUES (58322,18576,'119245','deals-mobile','padding-top','20',0,''),(58323,18576,'119245','deals-mobile','padding-bottom','20',0,''),(58324,18576,'119245','deals-mobile','padding-left','30',0,''),(58325,18576,'119245','deals-mobile','padding-right','30',0,''),(58326,18576,'119245','deals-mobile','margin-bottom','20',0,''),(58327,18577,'119246','deals-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(58328,18578,'119247','deals-mobile','hide_parents','2',0,''),(58329,18579,'119248','deals-mobile','float','right',0,''),(58330,18579,'119248','deals-mobile','margin-top','-37',0,''),(58331,18579,'119248','deals-mobile','link','comments',0,''),(58332,18580,'119249','deals-mobile','block_type','1',0,''),(58333,18580,'119249','deals-mobile','padding-top','20',0,''),(58334,18580,'119249','deals-mobile','padding-left','20',0,''),(58335,18580,'119249','deals-mobile','padding-right','20',0,''),(58336,18580,'119249','deals-mobile','padding-bottom','20',0,''),(58337,18580,'119249','deals-mobile','background-color','#ffffff',0,''),(58338,18580,'119249','deals-mobile','style_class','order-summary2 hiding-box',0,''),(58339,18582,'119251','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58340,18583,'119252','deals-mobile','margin-bottom','20',0,''),(58341,18583,'119252','deals-mobile','text-align','right',0,''),(58342,18584,'119253','deals-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(58343,18585,'119254','deals-mobile','block_type','1',0,''),(58344,18585,'119254','deals-mobile','background-color','#eeeeee',0,''),(58345,18585,'119254','deals-mobile','padding-bottom','30',0,''),(58346,18586,'119255','deals-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(58347,18587,'119256','deals-mobile','block_type','4',0,''),(58348,18587,'119256','deals-mobile','schema','4-2',0,''),(58349,18588,'119257','deals-mobile','block_type','1',0,''),(58350,18588,'119257','deals-mobile','padding-right','40',0,''),(58352,18589,'119258','deals-mobile','block_type','2',0,''),(58353,18589,'119258','deals-mobile','margin-bottom','20',0,''),(58354,18589,'119258','deals-mobile','schema','2-2',0,''),(58355,18589,'119258','deals-mobile','background-color','#ffffff',0,''),(58356,18590,'119259','deals-mobile','block_type','1',0,''),(58357,18590,'119259','deals-mobile','border-right-width','20',0,''),(58358,18590,'119259','deals-mobile','border-right-color','#e0e0e0',0,''),(58359,18590,'119259','deals-mobile','margin-right','-10',0,''),(58360,18590,'119259','deals-mobile','padding-right','30',0,''),(58361,18590,'119259','deals-mobile','padding-top','20',0,''),(58362,18590,'119259','deals-mobile','padding-left','30',0,''),(58363,18590,'119259','deals-mobile','padding-bottom','20',0,''),(58366,18590,'119259','deals-mobile','margin-bottom','20',0,''),(58369,18591,'119260','deals-mobile','link','shipping_method',0,''),(58370,18591,'119260','deals-mobile','float','right',0,''),(58371,18591,'119260','deals-mobile','margin-top','-31',0,''),(58372,18592,'119261','deals-mobile','margin-bottom','20',0,''),(58373,18593,'119262','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(58374,18593,'119262','deals-mobile','clear','none',0,''),(58375,18595,'119264','deals-mobile','link','shipping_address',0,''),(58376,18595,'119264','deals-mobile','float','right',0,''),(58377,18595,'119264','deals-mobile','margin-top','-31',0,''),(58378,18596,'119265','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(58379,18596,'119265','deals-mobile','clear','none',0,''),(58380,18597,'119266','deals-mobile','block_type','1',0,''),(58381,18597,'119266','deals-mobile','padding-left','30',0,''),(58382,18597,'119266','deals-mobile','border-left-width','20',0,''),(58383,18597,'119266','deals-mobile','border-left-color','#e0e0e0',0,''),(58384,18597,'119266','deals-mobile','margin-left','-10',0,''),(58385,18597,'119266','deals-mobile','padding-right','30',0,''),(58386,18597,'119266','deals-mobile','padding-top','20',0,''),(58387,18597,'119266','deals-mobile','padding-bottom','20',0,''),(58389,18598,'119267','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(58390,18599,'119268','deals-mobile','link','contact_information',0,''),(58391,18599,'119268','deals-mobile','margin-top','-31',0,''),(58392,18599,'119268','deals-mobile','float','right',0,''),(58393,18602,'119271','deals-mobile','block_type','1',0,''),(58394,18602,'119271','deals-mobile','background-color','#ffffff',0,''),(58395,18602,'119271','deals-mobile','padding-top','20',0,''),(58396,18602,'119271','deals-mobile','padding-bottom','20',0,''),(58397,18602,'119271','deals-mobile','padding-left','30',0,''),(58398,18602,'119271','deals-mobile','padding-right','30',0,''),(58399,18602,'119271','deals-mobile','margin-bottom','20',0,''),(58400,18603,'119272','deals-mobile','hide_parents','2',0,''),(58401,18604,'119273','deals-mobile','float','right',0,''),(58402,18604,'119273','deals-mobile','margin-top','-37',0,''),(58403,18604,'119273','deals-mobile','link','comments',0,''),(58404,18605,'119274','deals-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(58405,18606,'119275','deals-mobile','block_type','1',0,''),(58406,18606,'119275','deals-mobile','padding-right','30',0,''),(58407,18606,'119275','deals-mobile','background-color','#ffffff',0,''),(58408,18606,'119275','deals-mobile','padding-top','20',0,''),(58409,18606,'119275','deals-mobile','padding-left','30',0,''),(58410,18606,'119275','deals-mobile','padding-bottom','20',0,''),(58413,18608,'119277','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(58414,18609,'119278','deals-mobile','link','products',0,''),(58415,18609,'119278','deals-mobile','float','right',0,''),(58416,18609,'119278','deals-mobile','margin-top','-37',0,''),(58417,18610,'119279','deals-mobile','block_type','1',0,''),(58418,18610,'119279','deals-mobile','padding-top','20',0,''),(58419,18610,'119279','deals-mobile','padding-left','20',0,''),(58420,18610,'119279','deals-mobile','padding-right','20',0,''),(58421,18610,'119279','deals-mobile','padding-bottom','20',0,''),(58422,18610,'119279','deals-mobile','background-color','#ffffff',0,''),(58423,18610,'119279','deals-mobile','style_class','order-summary',0,''),(58424,18611,'119280','deals-mobile','margin-bottom','20',0,''),(58425,18611,'119280','deals-mobile','text-align','right',0,''),(58426,18612,'119281','deals-mobile','block_type','1',0,''),(58427,18612,'119281','deals-mobile','background-color','#eeeeee',0,''),(58428,18612,'119281','deals-mobile','padding-bottom','30',0,''),(58429,18613,'119282','deals-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(58430,18614,'119283','deals-mobile','block_type','4',0,''),(58431,18615,'119284','deals-mobile','block_type','1',0,''),(58432,18615,'119284','deals-mobile','padding-right','40',0,''),(58433,18616,'119285','deals-mobile','block_type','1',0,''),(58434,18616,'119285','deals-mobile','padding-right','30',0,''),(58436,18616,'119285','deals-mobile','background-color','#ffffff',0,''),(58437,18616,'119285','deals-mobile','padding-top','20',0,''),(58438,18616,'119285','deals-mobile','padding-left','30',0,''),(58439,18616,'119285','deals-mobile','padding-bottom','20',0,''),(58440,18617,'119286','deals-mobile','link','products',0,''),(58441,18617,'119286','deals-mobile','float','right',0,''),(58442,18617,'119286','deals-mobile','margin-top','-37',0,''),(58443,18618,'119287','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(58444,18620,'119289','deals-mobile','block_type','1',0,''),(58445,18620,'119289','deals-mobile','background-color','#ffffff',0,''),(58446,18620,'119289','deals-mobile','padding-top','20',0,''),(58447,18620,'119289','deals-mobile','padding-bottom','20',0,''),(58448,18620,'119289','deals-mobile','padding-left','30',0,''),(58449,18620,'119289','deals-mobile','padding-right','30',0,''),(58450,18620,'119289','deals-mobile','margin-bottom','20',0,''),(58451,18621,'119290','deals-mobile','float','right',0,''),(58452,18621,'119290','deals-mobile','margin-top','-37',0,''),(58453,18621,'119290','deals-mobile','link','comments',0,''),(58454,18622,'119291','deals-mobile','hide_parents','2',0,''),(58455,18623,'119292','deals-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(58456,18624,'119293','deals-mobile','block_type','2',0,''),(58457,18624,'119293','deals-mobile','margin-bottom','20',0,''),(58458,18624,'119293','deals-mobile','schema','2-2',0,''),(58459,18624,'119293','deals-mobile','background-color','#ffffff',0,''),(58460,18625,'119294','deals-mobile','block_type','1',0,''),(58461,18625,'119294','deals-mobile','padding-right','0',0,''),(58462,18625,'119294','deals-mobile','border-right-width','20',0,''),(58463,18625,'119294','deals-mobile','border-right-color','#e0e0e0',0,''),(58464,18625,'119294','deals-mobile','margin-right','-10',0,''),(58466,18625,'119294','deals-mobile','padding-top','20',0,''),(58467,18625,'119294','deals-mobile','padding-left','30',0,''),(58468,18625,'119294','deals-mobile','padding-bottom','20',0,''),(58469,18626,'119295','deals-mobile','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(58470,18626,'119295','deals-mobile','padding-top','20',0,''),(58471,18628,'119297','deals-mobile','link','contact_information',0,''),(58472,18628,'119297','deals-mobile','margin-top','-37',0,''),(58473,18628,'119297','deals-mobile','float','right',0,''),(58474,18629,'119298','deals-mobile','block_type','1',0,''),(58475,18629,'119298','deals-mobile','padding-left','30',0,''),(58477,18629,'119298','deals-mobile','border-left-width','20',0,''),(58478,18629,'119298','deals-mobile','border-left-color','#e0e0e0',0,''),(58479,18629,'119298','deals-mobile','margin-left','-10',0,''),(58480,18629,'119298','deals-mobile','padding-right','30',0,''),(58481,18629,'119298','deals-mobile','padding-top','20',0,''),(58482,18629,'119298','deals-mobile','padding-bottom','20',0,''),(58483,18630,'119299','deals-mobile','link','billing_address',0,''),(58484,18630,'119299','deals-mobile','float','right',0,''),(58485,18630,'119299','deals-mobile','margin-top','-31',0,''),(58486,18631,'119300','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(58487,18631,'119300','deals-mobile','clear','none',0,''),(58488,18632,'119301','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(58489,18633,'119302','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(58490,18633,'119302','deals-mobile','clear','none',0,''),(58491,18634,'119303','deals-mobile','margin-bottom','20',0,''),(58492,18636,'119305','deals-mobile','link','payment_method',0,''),(58493,18636,'119305','deals-mobile','float','right',0,''),(58494,18636,'119305','deals-mobile','margin-top','-31',0,''),(58495,18637,'119306','deals-mobile','block_type','1',0,''),(58496,18637,'119306','deals-mobile','padding-top','20',0,''),(58497,18637,'119306','deals-mobile','padding-left','20',0,''),(58498,18637,'119306','deals-mobile','padding-right','20',0,''),(58499,18637,'119306','deals-mobile','padding-bottom','20',0,''),(58500,18637,'119306','deals-mobile','background-color','#ffffff',0,''),(58501,18637,'119306','deals-mobile','style_class','order-summary2 hiding-box',0,''),(58502,18638,'119307','deals-mobile','margin-bottom','20',0,''),(58503,18638,'119307','deals-mobile','text-align','right',0,''),(58504,18640,'119309','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58505,18641,'119310','deals-mobile','block_type','1',0,''),(58506,18641,'119310','deals-mobile','background-color','#eeeeee',0,''),(58507,18641,'119310','deals-mobile','padding-bottom','30',0,''),(58508,18642,'119311','deals-mobile','block_type','4',0,''),(58509,18642,'119311','deals-mobile','schema','4-2',0,''),(58510,18643,'119312','deals-mobile','block_type','1',0,''),(58511,18643,'119312','deals-mobile','padding-right','40',0,''),(58513,18644,'119313','deals-mobile','block_type','1',0,''),(58514,18644,'119313','deals-mobile','padding-right','30',0,''),(58515,18644,'119313','deals-mobile','background-color','#ffffff',0,''),(58516,18644,'119313','deals-mobile','padding-top','20',0,''),(58517,18644,'119313','deals-mobile','padding-left','30',0,''),(58518,18644,'119313','deals-mobile','padding-bottom','20',0,''),(58521,18645,'119314','deals-mobile','margin-bottom','20',0,''),(58522,18646,'119315','deals-mobile','link','products',0,''),(58523,18646,'119315','deals-mobile','float','right',0,''),(58524,18646,'119315','deals-mobile','margin-top','-37',0,''),(58525,18647,'119316','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(58526,18648,'119317','deals-mobile','block_type','2',0,''),(58527,18648,'119317','deals-mobile','margin-bottom','20',0,''),(58528,18648,'119317','deals-mobile','schema','2-2',0,''),(58529,18648,'119317','deals-mobile','background-color','#ffffff',0,''),(58530,18649,'119318','deals-mobile','block_type','1',0,''),(58531,18649,'119318','deals-mobile','border-right-width','20',0,''),(58532,18649,'119318','deals-mobile','border-right-color','#e0e0e0',0,''),(58533,18649,'119318','deals-mobile','margin-right','-10',0,''),(58534,18649,'119318','deals-mobile','padding-right','30',0,''),(58535,18649,'119318','deals-mobile','padding-top','20',0,''),(58536,18649,'119318','deals-mobile','padding-left','30',0,''),(58537,18649,'119318','deals-mobile','padding-bottom','20',0,''),(58540,18649,'119318','deals-mobile','margin-bottom','20',0,''),(58543,18650,'119319','deals-mobile','link','payment_method',0,''),(58544,18650,'119319','deals-mobile','float','right',0,''),(58545,18650,'119319','deals-mobile','margin-top','-31',0,''),(58546,18651,'119320','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(58547,18651,'119320','deals-mobile','clear','none',0,''),(58548,18652,'119321','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(58549,18652,'119321','deals-mobile','padding-top','20',0,''),(58550,18654,'119323','deals-mobile','link','contact_information',0,''),(58551,18654,'119323','deals-mobile','margin-top','-31',0,''),(58552,18654,'119323','deals-mobile','float','right',0,''),(58553,18656,'119325','deals-mobile','block_type','1',0,''),(58554,18656,'119325','deals-mobile','padding-left','30',0,''),(58555,18656,'119325','deals-mobile','border-left-width','20',0,''),(58556,18656,'119325','deals-mobile','border-left-color','#e0e0e0',0,''),(58557,18656,'119325','deals-mobile','margin-left','-10',0,''),(58558,18656,'119325','deals-mobile','padding-right','30',0,''),(58559,18656,'119325','deals-mobile','padding-top','20',0,''),(58560,18656,'119325','deals-mobile','padding-bottom','20',0,''),(58562,18657,'119326','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(58563,18657,'119326','deals-mobile','clear','none',0,''),(58564,18658,'119327','deals-mobile','link','billing_address',0,''),(58565,18658,'119327','deals-mobile','float','right',0,''),(58566,18658,'119327','deals-mobile','margin-top','-31',0,''),(58567,18659,'119328','deals-mobile','margin-bottom','20',0,''),(58568,18660,'119329','deals-mobile','block_type','1',0,''),(58569,18660,'119329','deals-mobile','background-color','#ffffff',0,''),(58570,18660,'119329','deals-mobile','padding-top','20',0,''),(58571,18660,'119329','deals-mobile','padding-bottom','20',0,''),(58572,18660,'119329','deals-mobile','padding-left','30',0,''),(58573,18660,'119329','deals-mobile','padding-right','30',0,''),(58574,18660,'119329','deals-mobile','margin-bottom','20',0,''),(58575,18661,'119330','deals-mobile','hide_parents','2',0,''),(58576,18662,'119331','deals-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(58577,18663,'119332','deals-mobile','float','right',0,''),(58578,18663,'119332','deals-mobile','margin-top','-37',0,''),(58579,18663,'119332','deals-mobile','link','comments',0,''),(58580,18664,'119333','deals-mobile','block_type','1',0,''),(58581,18664,'119333','deals-mobile','padding-top','20',0,''),(58582,18664,'119333','deals-mobile','padding-left','20',0,''),(58583,18664,'119333','deals-mobile','padding-right','20',0,''),(58584,18664,'119333','deals-mobile','padding-bottom','20',0,''),(58585,18664,'119333','deals-mobile','background-color','#ffffff',0,''),(58586,18664,'119333','deals-mobile','style_class','order-summary',0,''),(58587,18665,'119334','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58588,18667,'119336','deals-mobile','margin-bottom','20',0,''),(58589,18667,'119336','deals-mobile','text-align','right',0,''),(58590,18668,'119337','deals-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(58591,18669,'119338','deals-mobile','block_type','1',0,''),(58592,18669,'119338','deals-mobile','background-color','#eeeeee',0,''),(58593,18669,'119338','deals-mobile','padding-bottom','30',0,''),(58594,18670,'119339','deals-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(58595,18671,'119340','deals-mobile','block_type','4',0,''),(58596,18671,'119340','deals-mobile','schema','4-2',0,''),(58597,18672,'119341','deals-mobile','block_type','1',0,''),(58598,18672,'119341','deals-mobile','padding-right','40',0,''),(58600,18673,'119342','deals-mobile','block_type','1',0,''),(58601,18673,'119342','deals-mobile','padding-right','30',0,''),(58602,18673,'119342','deals-mobile','background-color','#ffffff',0,''),(58603,18673,'119342','deals-mobile','padding-top','20',0,''),(58604,18673,'119342','deals-mobile','padding-left','30',0,''),(58605,18673,'119342','deals-mobile','padding-bottom','20',0,''),(58608,18674,'119343','deals-mobile','link','products',0,''),(58609,18674,'119343','deals-mobile','float','right',0,''),(58610,18674,'119343','deals-mobile','margin-top','-37',0,''),(58611,18675,'119344','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(58612,18677,'119346','deals-mobile','block_type','1',0,''),(58613,18677,'119346','deals-mobile','background-color','#ffffff',0,''),(58614,18677,'119346','deals-mobile','padding-top','20',0,''),(58615,18677,'119346','deals-mobile','padding-bottom','20',0,''),(58616,18677,'119346','deals-mobile','padding-left','30',0,''),(58617,18677,'119346','deals-mobile','padding-right','30',0,''),(58618,18677,'119346','deals-mobile','margin-bottom','20',0,''),(58619,18678,'119347','deals-mobile','float','right',0,''),(58620,18678,'119347','deals-mobile','margin-top','-37',0,''),(58621,18678,'119347','deals-mobile','link','comments',0,''),(58622,18679,'119348','deals-mobile','hide_parents','2',0,''),(58623,18680,'119349','deals-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(58624,18681,'119350','deals-mobile','block_type','2',0,''),(58625,18681,'119350','deals-mobile','margin-bottom','20',0,''),(58626,18681,'119350','deals-mobile','schema','2-2',0,''),(58627,18681,'119350','deals-mobile','background-color','#ffffff',0,''),(58628,18682,'119351','deals-mobile','block_type','1',0,''),(58629,18682,'119351','deals-mobile','border-right-width','20',0,''),(58630,18682,'119351','deals-mobile','border-right-color','#e0e0e0',0,''),(58631,18682,'119351','deals-mobile','margin-right','-10',0,''),(58632,18682,'119351','deals-mobile','padding-right','30',0,''),(58633,18682,'119351','deals-mobile','padding-top','20',0,''),(58634,18682,'119351','deals-mobile','padding-left','30',0,''),(58635,18682,'119351','deals-mobile','padding-bottom','20',0,''),(58638,18682,'119351','deals-mobile','margin-bottom','20',0,''),(58641,18683,'119352','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(58642,18683,'119352','deals-mobile','clear','none',0,''),(58643,18684,'119353','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(58644,18684,'119353','deals-mobile','padding-top','20',0,''),(58645,18685,'119354','deals-mobile','link','shipping_method',0,''),(58646,18685,'119354','deals-mobile','float','right',0,''),(58647,18685,'119354','deals-mobile','margin-top','-31',0,''),(58648,18687,'119356','deals-mobile','link','shipping_address',0,''),(58649,18687,'119356','deals-mobile','float','right',0,''),(58650,18687,'119356','deals-mobile','margin-top','-31',0,''),(58651,18689,'119358','deals-mobile','margin-bottom','20',0,''),(58652,18691,'119360','deals-mobile','link','contact_information',0,''),(58653,18691,'119360','deals-mobile','margin-top','-31',0,''),(58654,18691,'119360','deals-mobile','float','right',0,''),(58655,18692,'119361','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(58656,18692,'119361','deals-mobile','clear','none',0,''),(58657,18693,'119362','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(58658,18694,'119363','deals-mobile','block_type','1',0,''),(58659,18694,'119363','deals-mobile','padding-left','30',0,''),(58660,18694,'119363','deals-mobile','border-left-width','20',0,''),(58661,18694,'119363','deals-mobile','border-left-color','#e0e0e0',0,''),(58662,18694,'119363','deals-mobile','margin-left','-10',0,''),(58663,18694,'119363','deals-mobile','padding-right','30',0,''),(58664,18694,'119363','deals-mobile','padding-top','20',0,''),(58665,18694,'119363','deals-mobile','padding-bottom','20',0,''),(58667,18695,'119364','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(58668,18696,'119365','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(58669,18696,'119365','deals-mobile','clear','none',0,''),(58670,18698,'119367','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(58671,18698,'119367','deals-mobile','clear','none',0,''),(58672,18699,'119368','deals-mobile','margin-bottom','20',0,''),(58673,18700,'119369','deals-mobile','link','payment_method',0,''),(58674,18700,'119369','deals-mobile','float','right',0,''),(58675,18700,'119369','deals-mobile','margin-top','-31',0,''),(58676,18701,'119370','deals-mobile','link','billing_address',0,''),(58677,18701,'119370','deals-mobile','float','right',0,''),(58678,18701,'119370','deals-mobile','margin-top','-31',0,''),(58679,18702,'119371','deals-mobile','block_type','1',0,''),(58680,18702,'119371','deals-mobile','padding-top','20',0,''),(58681,18702,'119371','deals-mobile','padding-left','20',0,''),(58682,18702,'119371','deals-mobile','padding-right','20',0,''),(58683,18702,'119371','deals-mobile','padding-bottom','20',0,''),(58684,18702,'119371','deals-mobile','background-color','#ffffff',0,''),(58685,18702,'119371','deals-mobile','style_class','order-summary',0,''),(58686,18703,'119372','deals-mobile','margin-bottom','20',0,''),(58687,18703,'119372','deals-mobile','text-align','right',0,''),(58688,18704,'119373','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58689,18706,'119375','deals-mobile','block_type','1',0,''),(58690,18706,'119375','deals-mobile','background-color','#eeeeee',0,''),(58691,18706,'119375','deals-mobile','padding-bottom','30',0,''),(58692,18707,'119376','deals-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(58693,18708,'119377','deals-mobile','block_type','4',0,''),(58694,18708,'119377','deals-mobile','schema','4-2',0,''),(58695,18709,'119378','deals-mobile','block_type','1',0,''),(58696,18709,'119378','deals-mobile','padding-right','40',0,''),(58698,18710,'119379','deals-mobile','block_type','1',0,''),(58699,18710,'119379','deals-mobile','background-color','#ffffff',0,''),(58700,18710,'119379','deals-mobile','padding-top','20',0,''),(58701,18710,'119379','deals-mobile','padding-bottom','20',0,''),(58702,18710,'119379','deals-mobile','padding-left','30',0,''),(58703,18710,'119379','deals-mobile','padding-right','30',0,''),(58704,18710,'119379','deals-mobile','margin-bottom','20',0,''),(58705,18711,'119380','deals-mobile','hide_parents','2',0,''),(58706,18712,'119381','deals-mobile','float','right',0,''),(58707,18712,'119381','deals-mobile','margin-top','-37',0,''),(58708,18712,'119381','deals-mobile','link','comments',0,''),(58709,18713,'119382','deals-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(58710,18714,'119383','deals-mobile','block_type','1',0,''),(58711,18714,'119383','deals-mobile','padding-right','30',0,''),(58712,18714,'119383','deals-mobile','background-color','#ffffff',0,''),(58713,18714,'119383','deals-mobile','padding-top','20',0,''),(58714,18714,'119383','deals-mobile','padding-left','30',0,''),(58715,18714,'119383','deals-mobile','padding-bottom','20',0,''),(58718,18716,'119385','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(58719,18717,'119386','deals-mobile','link','products',0,''),(58720,18717,'119386','deals-mobile','float','right',0,''),(58721,18717,'119386','deals-mobile','margin-top','-37',0,''),(58722,18718,'119387','deals-mobile','block_type','2',0,''),(58723,18718,'119387','deals-mobile','margin-bottom','20',0,''),(58724,18718,'119387','deals-mobile','schema','2-2',0,''),(58725,18718,'119387','deals-mobile','background-color','#ffffff',0,''),(58726,18719,'119388','deals-mobile','block_type','1',0,''),(58727,18719,'119388','deals-mobile','border-right-width','20',0,''),(58728,18719,'119388','deals-mobile','border-right-color','#e0e0e0',0,''),(58729,18719,'119388','deals-mobile','margin-right','-10',0,''),(58730,18719,'119388','deals-mobile','padding-right','30',0,''),(58731,18719,'119388','deals-mobile','padding-top','20',0,''),(58732,18719,'119388','deals-mobile','padding-left','30',0,''),(58733,18719,'119388','deals-mobile','padding-bottom','20',0,''),(58736,18719,'119388','deals-mobile','margin-bottom','20',0,''),(58739,18720,'119389','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(58740,18720,'119389','deals-mobile','padding-top','20',0,''),(58741,18722,'119391','deals-mobile','link','shipping_method',0,''),(58742,18722,'119391','deals-mobile','float','right',0,''),(58743,18722,'119391','deals-mobile','margin-top','-31',0,''),(58744,18723,'119392','deals-mobile','link','contact_information',0,''),(58745,18723,'119392','deals-mobile','margin-top','-31',0,''),(58746,18723,'119392','deals-mobile','float','right',0,''),(58747,18724,'119393','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(58748,18726,'119395','deals-mobile','link','shipping_address',0,''),(58749,18726,'119395','deals-mobile','float','right',0,''),(58750,18726,'119395','deals-mobile','margin-top','-31',0,''),(58751,18727,'119396','deals-mobile','margin-bottom','20',0,''),(58752,18728,'119397','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(58753,18728,'119397','deals-mobile','clear','none',0,''),(58754,18729,'119398','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(58755,18729,'119398','deals-mobile','clear','none',0,''),(58756,18731,'119400','deals-mobile','block_type','1',0,''),(58757,18731,'119400','deals-mobile','padding-left','30',0,''),(58758,18731,'119400','deals-mobile','border-left-width','20',0,''),(58759,18731,'119400','deals-mobile','border-left-color','#e0e0e0',0,''),(58760,18731,'119400','deals-mobile','margin-left','-10',0,''),(58761,18731,'119400','deals-mobile','padding-right','30',0,''),(58762,18731,'119400','deals-mobile','padding-top','20',0,''),(58763,18731,'119400','deals-mobile','padding-bottom','20',0,''),(58765,18732,'119401','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(58766,18732,'119401','deals-mobile','clear','none',0,''),(58767,18733,'119402','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(58768,18734,'119403','deals-mobile','link','payment_method',0,''),(58769,18734,'119403','deals-mobile','float','right',0,''),(58770,18734,'119403','deals-mobile','margin-top','-31',0,''),(58771,18735,'119404','deals-mobile','margin-bottom','20',0,''),(58772,18736,'119405','deals-mobile','link','billing_address',0,''),(58773,18736,'119405','deals-mobile','float','right',0,''),(58774,18736,'119405','deals-mobile','margin-top','-31',0,''),(58775,18737,'119406','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(58776,18737,'119406','deals-mobile','clear','none',0,''),(58777,18739,'119408','deals-mobile','block_type','1',0,''),(58778,18739,'119408','deals-mobile','padding-top','20',0,''),(58779,18739,'119408','deals-mobile','padding-left','20',0,''),(58780,18739,'119408','deals-mobile','padding-right','20',0,''),(58781,18739,'119408','deals-mobile','padding-bottom','20',0,''),(58782,18739,'119408','deals-mobile','background-color','#ffffff',0,''),(58783,18739,'119408','deals-mobile','style_class','order-summary',0,''),(58784,18741,'119410','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(58785,18742,'119411','deals-mobile','margin-bottom','20',0,''),(58786,18742,'119411','deals-mobile','text-align','right',0,''),(58787,18743,'119412','deals-mobile','block_type','1',0,''),(58788,18744,'119413','deals-mobile','block_type','2',0,''),(58789,18744,'119413','deals-mobile','font-weight','400',0,''),(58790,18744,'119413','deals-mobile','padding-bottom','20',0,''),(58791,18744,'119413','deals-mobile','schema','2-2',0,''),(58792,18744,'119413','deals-mobile','schema','2-2',0,'864'),(58793,18746,'119415','deals-mobile','street_heading','90',0,''),(58794,18747,'119416','deals-mobile','block_type','2',0,''),(58795,18747,'119416','deals-mobile','font-weight','400',0,''),(58796,18747,'119416','deals-mobile','padding-bottom','20',0,''),(58797,18747,'119416','deals-mobile','schema','2-2',0,'864'),(58798,18748,'119417','deals-mobile','show_captcha','on',0,''),(58799,18749,'119418','deals-mobile','font-weight','400',0,''),(58800,18749,'119418','deals-mobile','padding-left','40',0,''),(58801,18749,'119418','deals-mobile','time_format','24',0,''),(58802,18749,'119418','deals-mobile','show_icons','on',0,''),(58803,18749,'119418','deals-mobile','padding-left','0',0,'864'),(58804,18751,'119420','deals-mobile','block_type','1',0,''),(58805,18752,'119421','deals-mobile','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(58806,18752,'119421','deals-mobile','margin-bottom','40',0,''),(58807,18753,'119422','deals-mobile','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(58808,18754,'119423','deals-mobile','width','680',0,''),(58809,18754,'119423','deals-mobile','font-weight','normal',0,''),(58810,18754,'119423','deals-mobile','font-size','12',0,''),(58811,18754,'119423','deals-mobile','padding-top','20',0,''),(58812,18754,'119423','deals-mobile','padding-bottom','20',0,''),(58813,18754,'119423','deals-mobile','color','#424242',0,''),(58814,18755,'119424','deals-mobile','block_type','4',0,''),(58815,18755,'119424','deals-mobile','font-weight','normal',0,''),(58816,18755,'119424','deals-mobile','border-top-width','1',0,''),(58817,18755,'119424','deals-mobile','border-top-color','#e0e0e0',0,''),(58818,18755,'119424','deals-mobile','border-left-width','1',0,''),(58819,18755,'119424','deals-mobile','border-left-color','#e0e0e0',0,''),(58820,18755,'119424','deals-mobile','border-right-width','1',0,''),(58821,18755,'119424','deals-mobile','border-right-color','#e0e0e0',0,''),(58822,18755,'119424','deals-mobile','border-bottom-width','1',0,''),(58823,18755,'119424','deals-mobile','border-bottom-color','#e0e0e0',0,''),(58824,18756,'119425','deals-mobile','block_type','2',0,''),(58825,18756,'119425','deals-mobile','font-weight','normal',0,''),(58826,18756,'119425','deals-mobile','border-top-width','1',0,''),(58827,18756,'119425','deals-mobile','border-top-color','#e0e0e0',0,''),(58828,18756,'119425','deals-mobile','border-right-width','1',0,''),(58829,18756,'119425','deals-mobile','border-right-color','#e0e0e0',0,''),(58830,18757,'119426','deals-mobile','block_type','1',0,''),(58831,18757,'119426','deals-mobile','font-weight','normal',0,''),(58832,18757,'119426','deals-mobile','padding-top','10',0,''),(58833,18757,'119426','deals-mobile','padding-left','10',0,''),(58834,18757,'119426','deals-mobile','padding-right','10',0,''),(58835,18757,'119426','deals-mobile','padding-bottom','10',0,''),(58836,18757,'119426','deals-mobile','border-right-width','1',0,''),(58837,18757,'119426','deals-mobile','border-right-color','#e0e0e0',0,''),(58838,18758,'119427','deals-mobile','text','<p>Shipping via</p>',1,''),(58839,18758,'119427','deals-mobile','font-weight','bold',0,''),(58840,18758,'119427','deals-mobile','font-size','14',0,''),(58841,18760,'119429','deals-mobile','block_type','1',0,''),(58842,18760,'119429','deals-mobile','font-weight','normal',0,''),(58843,18760,'119429','deals-mobile','padding-top','10',0,''),(58844,18760,'119429','deals-mobile','padding-left','10',0,''),(58845,18760,'119429','deals-mobile','padding-right','10',0,''),(58846,18760,'119429','deals-mobile','padding-bottom','10',0,''),(58847,18762,'119431','deals-mobile','text','<p>Shipping service</p>',1,''),(58848,18762,'119431','deals-mobile','font-weight','bold',0,''),(58849,18762,'119431','deals-mobile','font-size','14',0,''),(58850,18763,'119432','deals-mobile','block_type','2',0,''),(58851,18763,'119432','deals-mobile','font-weight','normal',0,''),(58852,18763,'119432','deals-mobile','border-right-width','1',0,''),(58853,18763,'119432','deals-mobile','border-right-color','#e0e0e0',0,''),(58854,18764,'119433','deals-mobile','block_type','1',0,''),(58855,18764,'119433','deals-mobile','font-weight','400',0,''),(58856,18764,'119433','deals-mobile','background-color','#eeeeee',0,''),(58857,18764,'119433','deals-mobile','padding-top','10',0,''),(58858,18764,'119433','deals-mobile','padding-left','10',0,''),(58859,18764,'119433','deals-mobile','padding-right','10',0,''),(58860,18764,'119433','deals-mobile','padding-bottom','30',0,''),(58861,18765,'119434','deals-mobile','font-size','12',0,''),(58862,18766,'119435','deals-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(58863,18766,'119435','deals-mobile','font-size','14',0,''),(58864,18766,'119435','deals-mobile','font-weight','bold',0,''),(58865,18767,'119436','deals-mobile','block_type','1',0,''),(58866,18767,'119436','deals-mobile','font-weight','normal',0,''),(58867,18767,'119436','deals-mobile','padding-top','10',0,''),(58868,18767,'119436','deals-mobile','padding-left','10',0,''),(58869,18767,'119436','deals-mobile','padding-right','10',0,''),(58870,18767,'119436','deals-mobile','padding-bottom','10',0,''),(58871,18768,'119437','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(58872,18768,'119437','deals-mobile','font-weight','bold',0,''),(58873,18768,'119437','deals-mobile','font-size','14',0,''),(58874,18768,'119437','deals-mobile','padding-top','10',0,''),(58875,18769,'119438','deals-mobile','font-weight','normal',0,''),(58876,18771,'119440','deals-mobile','text','<p>PHONE NUMBER:</p>',1,''),(58877,18771,'119440','deals-mobile','font-size','14',0,''),(58878,18771,'119440','deals-mobile','font-weight','bold',0,''),(58879,18771,'119440','deals-mobile','padding-top','10',0,''),(58880,18772,'119441','deals-mobile','text','<p>CUSTOMER:</p>',1,''),(58881,18772,'119441','deals-mobile','font-size','13',0,''),(58882,18772,'119441','deals-mobile','font-weight','bold',0,''),(58883,18773,'119442','deals-mobile','font-weight','normal',0,''),(58884,18774,'119443','deals-mobile','font-weight','normal',0,''),(58885,18774,'119443','deals-mobile','text-align','center',0,''),(58886,18774,'119443','deals-mobile','padding-bottom','10',0,''),(58887,18775,'119444','deals-mobile','text','<p>Payment date:</p>',1,''),(58888,18775,'119444','deals-mobile','font-weight','bold',0,''),(58889,18775,'119444','deals-mobile','text-align','center',0,''),(58890,18775,'119444','deals-mobile','font-size','12',0,''),(58891,18776,'119445','deals-mobile','font-size','14',0,''),(58892,18776,'119445','deals-mobile','font-weight','bold',0,''),(58893,18776,'119445','deals-mobile','text-align','center',0,''),(58894,18776,'119445','deals-mobile','padding-bottom','10',0,''),(58895,18776,'119445','deals-mobile','padding-top','10',0,''),(58896,18777,'119446','deals-mobile','block_type','5',0,''),(58897,18777,'119446','deals-mobile','font-weight','normal',0,''),(58898,18777,'119446','deals-mobile','border-bottom-width','1',0,''),(58899,18777,'119446','deals-mobile','border-bottom-color','#e0e0e0',0,''),(58900,18777,'119446','deals-mobile','border-top-width','1',0,''),(58901,18777,'119446','deals-mobile','border-top-color','#e0e0e0',0,''),(58902,18777,'119446','deals-mobile','border-left-color','#e0e0e0',0,''),(58903,18777,'119446','deals-mobile','border-left-width','1',0,''),(58904,18778,'119447','deals-mobile','block_type','1',0,''),(58905,18778,'119447','deals-mobile','font-weight','normal',0,''),(58906,18778,'119447','deals-mobile','padding-top','10',0,''),(58907,18778,'119447','deals-mobile','padding-left','10',0,''),(58908,18778,'119447','deals-mobile','padding-right','10',0,''),(58909,18779,'119448','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(58910,18779,'119448','deals-mobile','font-size','14',0,''),(58911,18779,'119448','deals-mobile','font-weight','bold',0,''),(58912,18779,'119448','deals-mobile','padding-bottom','10',0,''),(58913,18780,'119449','deals-mobile','font-weight','400',0,''),(58914,18780,'119449','deals-mobile','line-height','120',0,''),(58915,18780,'119449','deals-mobile','line_height_measure','%',0,''),(58916,18780,'119449','deals-mobile','font-size','12',0,''),(58917,18781,'119450','deals-mobile','block_type','1',0,''),(58918,18781,'119450','deals-mobile','background-color','#eeeeee',0,''),(58919,18781,'119450','deals-mobile','padding-top','20',0,''),(58920,18781,'119450','deals-mobile','padding-left','10',0,''),(58921,18781,'119450','deals-mobile','padding-right','10',0,''),(58922,18781,'119450','deals-mobile','padding-bottom','20',0,''),(58923,18781,'119450','deals-mobile','font-size','14',0,''),(58924,18782,'119451','deals-mobile','block_type','2',0,''),(58925,18782,'119451','deals-mobile','font-weight','normal',0,''),(58926,18782,'119451','deals-mobile','padding-bottom','20',0,''),(58927,18783,'119452','deals-mobile','font-weight','400',0,''),(58928,18783,'119452','deals-mobile','padding-top','20',0,''),(58930,18784,'119453','deals-mobile','block_type','1',0,''),(58931,18785,'119454','deals-mobile','font-weight','normal',0,''),(58932,18785,'119454','deals-mobile','text-align','right',0,''),(58933,18785,'119454','deals-mobile','padding-bottom','10',0,''),(58934,18785,'119454','deals-mobile','address_spacer',',',0,''),(58935,18785,'119454','deals-mobile','font-size','12',0,''),(58936,18786,'119455','deals-mobile','block_type','11',0,''),(58937,18786,'119455','deals-mobile','font-weight','normal',0,''),(58938,18787,'119456','deals-mobile','text','<p>Email:</p>',1,''),(58939,18787,'119456','deals-mobile','font-weight','normal',0,''),(58940,18787,'119456','deals-mobile','text-align','right',0,''),(58941,18788,'119457','deals-mobile','font-weight','normal',0,''),(58942,18788,'119457','deals-mobile','text-align','right',0,''),(58943,18789,'119458','deals-mobile','block_type','11',0,''),(58944,18789,'119458','deals-mobile','font-weight','normal',0,''),(58945,18790,'119459','deals-mobile','text','<p>Phone:</p>',1,''),(58946,18790,'119459','deals-mobile','font-weight','normal',0,''),(58947,18790,'119459','deals-mobile','text-align','right',0,''),(58948,18791,'119460','deals-mobile','font-weight','normal',0,''),(58949,18791,'119460','deals-mobile','text-align','right',0,''),(58950,18792,'119461','deals-mobile','block_type','11',0,''),(58951,18792,'119461','deals-mobile','font-weight','normal',0,''),(58952,18793,'119462','deals-mobile','text','<p>Web:</p>',1,''),(58953,18793,'119462','deals-mobile','font-weight','normal',0,''),(58954,18793,'119462','deals-mobile','text-align','right',0,''),(58955,18794,'119463','deals-mobile','font-weight','normal',0,''),(58956,18794,'119463','deals-mobile','text-align','right',0,''),(58957,18795,'119464','deals-mobile','font-weight','400',0,''),(58958,18795,'119464','deals-mobile','padding-top','20',0,''),(58959,18795,'119464','deals-mobile','padding-bottom','0',0,''),(58960,18795,'119464','deals-mobile','font-size','12',0,''),(58961,18796,'119465','deals-mobile','block_type','3',0,''),(58962,18796,'119465','deals-mobile','font-weight','normal',0,''),(58963,18796,'119465','deals-mobile','padding-top','20',0,''),(58964,18797,'119466','deals-mobile','font-size','12',0,''),(58965,18798,'119467','deals-mobile','text','<p>If undelivered please return to:</p>',1,''),(58966,18798,'119467','deals-mobile','font-size','12',0,''),(58967,18798,'119467','deals-mobile','font-weight','bold',0,''),(58968,18799,'119468','deals-mobile','text','<p>Thank you for your order</p>',1,''),(58969,18799,'119468','deals-mobile','color','#1da1f2',0,''),(58970,18799,'119468','deals-mobile','font-size','13',0,''),(58971,18799,'119468','deals-mobile','font-weight','bold',0,''),(58972,18799,'119468','deals-mobile','padding-top','5',0,''),(58973,18799,'119468','deals-mobile','text-align','center',0,''),(58974,18800,'119469','deals-mobile','font-weight','400',0,''),(58975,18800,'119469','deals-mobile','text-align','center',0,''),(58976,18800,'119469','deals-mobile','padding-top','0',0,''),(58978,18800,'119469','deals-mobile','padding-left','20',0,''),(58979,18800,'119469','deals-mobile','padding-right','20',0,''),(58980,18801,'119470','deals-mobile','block_type','6',0,''),(58981,18801,'119470','deals-mobile','font-weight','normal',0,''),(58982,18801,'119470','deals-mobile','font-size','16',0,''),(58983,18802,'119471','deals-mobile','text','<p>Phone:</p>',1,''),(58984,18802,'119471','deals-mobile','font-weight','normal',0,''),(58985,18802,'119471','deals-mobile','text-align','right',0,''),(58986,18802,'119471','deals-mobile','font-size','12',0,''),(58987,18803,'119472','deals-mobile','font-weight','normal',0,''),(58988,18803,'119472','deals-mobile','text-align','right',0,''),(58989,18803,'119472','deals-mobile','font-size','12',0,''),(58990,18804,'119473','deals-mobile','block_type','6',0,''),(58991,18804,'119473','deals-mobile','font-weight','normal',0,''),(58992,18804,'119473','deals-mobile','font-size','16',0,''),(58993,18805,'119474','deals-mobile','text','<p>Email:</p>',1,''),(58994,18805,'119474','deals-mobile','font-weight','normal',0,''),(58995,18805,'119474','deals-mobile','text-align','right',0,''),(58996,18805,'119474','deals-mobile','font-size','12',0,''),(58997,18806,'119475','deals-mobile','font-weight','normal',0,''),(58998,18806,'119475','deals-mobile','text-align','right',0,''),(58999,18806,'119475','deals-mobile','font-size','12',0,''),(59000,18807,'119476','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(59001,18807,'119476','deals-mobile','font-size','12',0,''),(59002,18807,'119476','deals-mobile','font-weight','bold',0,''),(59003,18807,'119476','deals-mobile','text-align','right',0,''),(59004,18810,'119479','deals-mobile','text-align','center',0,''),(59005,18810,'119479','deals-mobile','padding-top','10',0,''),(59006,18816,'119485','deals-mobile','heading_type','h1',0,''),(59007,18819,'119488','deals-mobile','text-align','center',0,''),(59008,18819,'119488','deals-mobile','padding-top','10',0,''),(59009,18824,'119493','deals-mobile','font-weight','normal',0,''),(59010,18824,'119493','deals-mobile','padding-top','20',0,''),(59011,18824,'119493','deals-mobile','padding-left','10',0,''),(59012,18824,'119493','deals-mobile','padding-right','10',0,''),(59013,18824,'119493','deals-mobile','padding-bottom','20',0,''),(59014,18824,'119493','deals-mobile','color','#444444',0,''),(59015,18824,'119493','deals-mobile','font-size','14',0,''),(59016,18825,'119494','deals-mobile','block_type','2',0,''),(59017,18825,'119494','deals-mobile','font-weight','normal',0,''),(59018,18826,'119495','deals-mobile','font-weight','normal',0,''),(59019,18826,'119495','deals-mobile','padding-bottom','20',0,''),(59020,18827,'119496','deals-mobile','color','#444444',0,''),(59021,18827,'119496','deals-mobile','font-size','14',0,''),(59022,18827,'119496','deals-mobile','padding-top','20',0,''),(59023,18827,'119496','deals-mobile','padding-bottom','20',0,''),(59024,18827,'119496','deals-mobile','border-top-width','1',0,''),(59025,18827,'119496','deals-mobile','border-top-color','#cccccc',0,''),(59026,18828,'119497','deals-mobile','block_type','1',0,''),(59027,18829,'119498','deals-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',1,''),(59028,18829,'119498','deals-mobile','font-weight','normal',0,''),(59029,18829,'119498','deals-mobile','color','#444444',0,''),(59030,18829,'119498','deals-mobile','font-size','14',0,''),(59031,18830,'119499','deals-mobile','block_type','2',0,''),(59032,18830,'119499','deals-mobile','font-weight','normal',0,''),(59033,18830,'119499','deals-mobile','background-color','#092964',0,''),(59034,18830,'119499','deals-mobile','padding-top','5',0,''),(59035,18830,'119499','deals-mobile','padding-left','10',0,''),(59036,18830,'119499','deals-mobile','padding-right','10',0,''),(59037,18830,'119499','deals-mobile','padding-bottom','5',0,''),(59038,18831,'119500','deals-mobile','color','#ffffff',0,''),(59039,18831,'119500','deals-mobile','font-size','14',0,''),(59040,18831,'119500','deals-mobile','font-weight','normal',0,''),(59041,18832,'119501','deals-mobile','font-weight','normal',0,''),(59042,18832,'119501','deals-mobile','text-align','right',0,''),(59043,18832,'119501','deals-mobile','color','#ffffff',0,''),(59044,18832,'119501','deals-mobile','font-size','12',0,''),(59045,18833,'119502','deals-mobile','block_type','1',0,''),(59046,18834,'119503','deals-mobile','block_type','1',0,''),(59047,18834,'119503','deals-mobile','max-width','800',0,''),(59048,18834,'119503','deals-mobile','margin','0 auto',0,''),(59049,18834,'119503','deals-mobile','background-color','#ffffff',0,''),(59050,18835,'119504','deals-mobile','font-weight','normal',0,''),(59051,18835,'119504','deals-mobile','padding-top','20',0,''),(59052,18835,'119504','deals-mobile','padding-left','10',0,''),(59053,18835,'119504','deals-mobile','padding-right','10',0,''),(59054,18835,'119504','deals-mobile','padding-bottom','20',0,''),(59055,18835,'119504','deals-mobile','color','#424242',0,''),(59056,18835,'119504','deals-mobile','font-size','14',0,''),(59057,18836,'119505','deals-mobile','block_type','7',0,''),(59058,18836,'119505','deals-mobile','font-weight','normal',0,''),(59059,18836,'119505','deals-mobile','background-color','#183d78',0,''),(59060,18836,'119505','deals-mobile','padding-top','5',0,''),(59061,18836,'119505','deals-mobile','padding-left','10',0,''),(59062,18836,'119505','deals-mobile','padding-right','10',0,''),(59063,18836,'119505','deals-mobile','padding-bottom','5',0,''),(59064,18837,'119506','deals-mobile','color','#ffffff',0,''),(59065,18837,'119506','deals-mobile','font-size','15',0,''),(59066,18837,'119506','deals-mobile','font-weight','700',0,''),(59067,18838,'119507','deals-mobile','font-weight','normal',0,''),(59068,18838,'119507','deals-mobile','text-align','right',0,''),(59069,18838,'119507','deals-mobile','color','#757575',0,''),(59070,18838,'119507','deals-mobile','font-size','12',0,''),(59071,18839,'119508','deals-mobile','color','#424242',0,''),(59072,18839,'119508','deals-mobile','font-size','12',0,''),(59073,18839,'119508','deals-mobile','padding-top','20',0,''),(59074,18839,'119508','deals-mobile','padding-bottom','20',0,''),(59075,18839,'119508','deals-mobile','border-top-width','1',0,''),(59076,18839,'119508','deals-mobile','border-top-color','#e0e0e0',0,''),(59077,18840,'119509','deals-mobile','font-weight','normal',0,''),(59078,18840,'119509','deals-mobile','padding-bottom','10',0,''),(59079,18840,'119509','deals-mobile','background-color','#183d78',0,''),(59080,18840,'119509','deals-mobile','logo','themes/deals-mobile/img/logo-white-1.png',1,''),(59081,18840,'119509','deals-mobile','padding-left','20',0,''),(59082,18840,'119509','deals-mobile','padding-top','10',0,''),(59083,18841,'119510','deals-mobile','block_type','1',0,''),(59084,18841,'119510','deals-mobile','background-color','#eeeeee',0,''),(59085,18842,'119511','deals-mobile','block_type','1',0,''),(59086,18842,'119511','deals-mobile','max-width','800',0,''),(59087,18842,'119511','deals-mobile','margin','0 auto',0,''),(59088,18843,'119512','deals-mobile','font-weight','normal',0,''),(59089,18843,'119512','deals-mobile','padding-bottom','10',0,''),(59090,18843,'119512','deals-mobile','padding-top','10',0,''),(59091,18843,'119512','deals-mobile','text-align','center',0,''),(59092,18843,'119512','deals-mobile','logo_from','theme',0,''),(59093,18844,'119513','deals-mobile','color','#757575',0,''),(59094,18844,'119513','deals-mobile','font-size','12',0,''),(59095,18844,'119513','deals-mobile','padding-top','20',0,''),(59096,18844,'119513','deals-mobile','padding-bottom','20',0,''),(59097,18844,'119513','deals-mobile','text-align','center',0,''),(59098,18845,'119514','deals-mobile','block_type','1',0,''),(59099,18845,'119514','deals-mobile','background-color','#ffffff',0,''),(59100,18845,'119514','deals-mobile','padding-top','20',0,''),(59101,18845,'119514','deals-mobile','padding-left','20',0,''),(59102,18845,'119514','deals-mobile','padding-right','20',0,''),(59103,18845,'119514','deals-mobile','padding-bottom','20',0,''),(59104,18846,'119515','deals-mobile','block_type','7',0,''),(59105,18846,'119515','deals-mobile','font-weight','normal',0,''),(59106,18846,'119515','deals-mobile','padding-left','10',0,''),(59107,18846,'119515','deals-mobile','padding-right','10',0,''),(59108,18846,'119515','deals-mobile','padding-bottom','15',0,''),(59109,18846,'119515','deals-mobile','border-bottom-width','1',0,''),(59110,18846,'119515','deals-mobile','border-bottom-color','#e0e0e0',0,''),(59111,18847,'119516','deals-mobile','color','#424242',0,''),(59112,18847,'119516','deals-mobile','font-size','14',0,''),(59113,18847,'119516','deals-mobile','font-weight','700',0,''),(59114,18848,'119517','deals-mobile','font-weight','normal',0,''),(59115,18848,'119517','deals-mobile','text-align','right',0,''),(59116,18848,'119517','deals-mobile','color','#757575',0,''),(59117,18848,'119517','deals-mobile','font-size','11',0,''),(59118,18848,'119517','deals-mobile','text-transform','uppercase',0,''),(59119,18849,'119518','deals-mobile','font-weight','normal',0,''),(59120,18849,'119518','deals-mobile','padding-top','20',0,''),(59121,18849,'119518','deals-mobile','padding-bottom','20',0,''),(59122,18849,'119518','deals-mobile','color','#424242',0,''),(59123,18849,'119518','deals-mobile','font-size','14',0,''),(59124,18850,'119519','deals-mobile','block_type','1',0,''),(59125,18850,'119519','deals-mobile','background-color','#eeeeee',0,''),(59126,18850,'119519','deals-mobile','padding-top','20',0,''),(59127,18850,'119519','deals-mobile','padding-bottom','20',0,''),(59128,18851,'119520','deals-mobile','block_type','1',0,''),(59129,18851,'119520','deals-mobile','max-width','800',0,''),(59130,18851,'119520','deals-mobile','margin','0 auto',0,''),(59131,18852,'119521','deals-mobile','block_type','1',0,''),(59132,18852,'119521','deals-mobile','background-color','#ffffff',0,''),(59133,18852,'119521','deals-mobile','padding-top','20',0,''),(59134,18852,'119521','deals-mobile','padding-left','20',0,''),(59135,18852,'119521','deals-mobile','padding-right','20',0,''),(59136,18852,'119521','deals-mobile','padding-bottom','20',0,''),(59137,18852,'119521','deals-mobile','border-top-width','1',0,''),(59138,18852,'119521','deals-mobile','border-left-width','1',0,''),(59139,18852,'119521','deals-mobile','border-right-width','1',0,''),(59140,18852,'119521','deals-mobile','border-bottom-width','1',0,''),(59141,18852,'119521','deals-mobile','border-top-color','#e0e0e0',0,''),(59142,18852,'119521','deals-mobile','border-left-color','#e0e0e0',0,''),(59143,18852,'119521','deals-mobile','border-bottom-color','#e0e0e0',0,''),(59144,18852,'119521','deals-mobile','border-right-color','#e0e0e0',0,''),(59145,18853,'119522','deals-mobile','font-weight','normal',0,''),(59146,18853,'119522','deals-mobile','padding-top','20',0,''),(59147,18853,'119522','deals-mobile','padding-bottom','20',0,''),(59148,18853,'119522','deals-mobile','color','#424242',0,''),(59149,18853,'119522','deals-mobile','font-size','14',0,''),(59150,18854,'119523','deals-mobile','block_type','2',0,''),(59151,18855,'119524','deals-mobile','font-weight','normal',0,''),(59152,18855,'119524','deals-mobile','padding-bottom','10',0,''),(59153,18855,'119524','deals-mobile','padding-top','10',0,''),(59154,18855,'119524','deals-mobile','logo_from','theme',0,''),(59155,18856,'119525','deals-mobile','color','#424242',0,''),(59156,18856,'119525','deals-mobile','font-size','14',0,''),(59157,18856,'119525','deals-mobile','font-weight','700',0,''),(59158,18856,'119525','deals-mobile','text-align','right',0,''),(59159,18857,'119526','deals-mobile','font-weight','normal',0,''),(59160,18857,'119526','deals-mobile','text-align','right',0,''),(59161,18857,'119526','deals-mobile','color','#757575',0,''),(59162,18857,'119526','deals-mobile','font-size','11',0,''),(59163,18857,'119526','deals-mobile','text-transform','uppercase',0,''),(59164,18858,'119527','deals-mobile','color','#757575',0,''),(59165,18858,'119527','deals-mobile','font-size','12',0,''),(59166,18858,'119527','deals-mobile','padding-top','20',0,''),(59167,18858,'119527','deals-mobile','padding-bottom','20',0,''),(59168,18858,'119527','deals-mobile','text-align','left',0,''),(59169,18859,'119528','deals-mobile','block_type','1',0,''),(59170,18859,'119528','deals-mobile','font-weight','normal',0,''),(59171,18859,'119528','deals-mobile','margin-top','40',0,''),(59172,18860,'119529','deals-mobile','block_type','1',0,''),(59173,18861,'119530','deals-mobile','text','Account',1,''),(59174,18861,'119530','deals-mobile','style_class','footerTitle',0,''),(59175,18861,'119530','deals-mobile','font-family','Varela Round',0,''),(59176,18861,'119530','deals-mobile','font-size','18',0,''),(59177,18861,'119530','deals-mobile','text-transform','uppercase',0,''),(59178,18862,'119531','deals-mobile','class','menu-style-2',0,''),(59179,18862,'119531','deals-mobile','padding-top','10',0,''),(59180,18862,'119531','deals-mobile','padding-bottom','20',0,''),(59181,18863,'119532','deals-mobile','border-top-width','1',0,''),(59182,18863,'119532','deals-mobile','border-top-color','#e0e0e0',0,''),(59183,18863,'119532','deals-mobile','padding-top','20',0,''),(59184,18864,'119533','deals-mobile','block_type','1',0,''),(59185,18865,'119534','deals-mobile','class','menu-style-2',0,''),(59186,18865,'119534','deals-mobile','padding-top','10',0,''),(59187,18865,'119534','deals-mobile','padding-bottom','20',0,''),(59188,18866,'119535','deals-mobile','text','Account',1,''),(59189,18866,'119535','deals-mobile','style_class','footerTitle',0,''),(59192,18866,'119535','deals-mobile','font-family','Varela Round',0,''),(59193,18866,'119535','deals-mobile','font-size','18',0,''),(59194,18866,'119535','deals-mobile','text-transform','uppercase',0,''),(59195,18867,'119536','deals-mobile','block_type','1',0,''),(59196,18868,'119537','deals-mobile','text','Account',1,''),(59197,18868,'119537','deals-mobile','style_class','footerTitle',0,''),(59200,18868,'119537','deals-mobile','font-family','Varela Round',0,''),(59201,18868,'119537','deals-mobile','text-transform','uppercase',0,''),(59202,18868,'119537','deals-mobile','font-size','18',0,''),(59203,18869,'119538','deals-mobile','class','menu-style-2',0,''),(59204,18869,'119538','deals-mobile','padding-top','10',0,''),(59205,18869,'119538','deals-mobile','padding-bottom','20',0,''),(59206,18870,'119539','deals-mobile','block_type','1',0,''),(59207,18871,'119540','deals-mobile','view_item','address',0,''),(59208,18871,'119540','deals-mobile','address_spacer',',<span> </span>',0,''),(59209,18871,'119540','deals-mobile','padding-top','10',0,''),(59210,18871,'119540','deals-mobile','padding-bottom','20',0,''),(59211,18872,'119541','deals-mobile','text','Account',1,''),(59212,18872,'119541','deals-mobile','style_class','footerTitle',0,''),(59215,18872,'119541','deals-mobile','font-family','Varela Round',0,''),(59216,18872,'119541','deals-mobile','font-size','18',0,''),(59217,18872,'119541','deals-mobile','text-transform','uppercase',0,''),(59218,18873,'119542','deals-mobile','block_type','5',0,''),(59219,18874,'119543','deals-mobile','text','##TEXT_LANGUAGE##',0,''),(59220,18876,'119545','deals-mobile','block_type','5',0,''),(59221,18877,'119546','deals-mobile','text','##TEXT_CURRENCY##',0,''),(59222,18879,'119548','deals-mobile','block_type','1',0,''),(59223,18879,'119548','deals-mobile','font-weight','normal',0,''),(59224,18880,'119549','deals-mobile','block_type','2',0,''),(59225,18880,'119549','deals-mobile','font-weight','normal',0,''),(59226,18880,'119549','deals-mobile','padding-bottom','20',0,''),(59227,18881,'119550','deals-mobile','block_type','1',0,''),(59228,18881,'119550','deals-mobile','margin-right','20',0,''),(59229,18882,'119551','deals-mobile','block_type','1',0,''),(59230,18882,'119551','deals-mobile','font-weight','normal',0,''),(59231,18882,'119551','deals-mobile','style_class','gift-card-view',0,''),(59232,18882,'119551','deals-mobile','text-align','center',0,''),(59233,18882,'119551','deals-mobile','padding-bottom','20',0,''),(59234,18882,'119551','deals-mobile','background-color','#4546e2',0,''),(59235,18882,'119551','deals-mobile','padding-left','20',0,''),(59236,18882,'119551','deals-mobile','padding-right','20',0,''),(59237,18882,'119551','deals-mobile','color','#f4f2f2',0,''),(59238,18883,'119552','deals-mobile','block_type','1',0,''),(59239,18883,'119552','deals-mobile','font-weight','normal',0,''),(59240,18883,'119552','deals-mobile','padding-top','10',0,''),(59241,18884,'119553','deals-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(59242,18884,'119553','deals-mobile','font-weight','normal',0,''),(59243,18884,'119553','deals-mobile','text-align','center',0,''),(59244,18884,'119553','deals-mobile','font-size','12',0,''),(59245,18884,'119553','deals-mobile','padding-top','10',0,''),(59246,18884,'119553','deals-mobile','padding-bottom','5',0,''),(59247,18884,'119553','deals-mobile','border-top-width','1',0,''),(59248,18884,'119553','deals-mobile','border-top-color','#dfa82a',0,''),(59249,18885,'119554','deals-mobile','font-size','12',0,''),(59250,18885,'119554','deals-mobile','font-weight','bold',0,''),(59251,18885,'119554','deals-mobile','text-align','center',0,''),(59252,18885,'119554','deals-mobile','style_class','email',0,''),(59253,18886,'119555','deals-mobile','font-size','12',0,''),(59254,18886,'119555','deals-mobile','font-weight','bold',0,''),(59255,18886,'119555','deals-mobile','text-align','center',0,''),(59256,18886,'119555','deals-mobile','style_class','phone',0,''),(59257,18886,'119555','deals-mobile','padding-bottom','5',0,''),(59258,18887,'119556','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(59259,18887,'119556','deals-mobile','font-weight','normal',0,''),(59260,18887,'119556','deals-mobile','text-align','center',0,''),(59261,18887,'119556','deals-mobile','padding-top','20',0,''),(59262,18887,'119556','deals-mobile','padding-bottom','10',0,''),(59263,18887,'119556','deals-mobile','style_class','question-ico',0,''),(59264,18887,'119556','deals-mobile','border-top-width','1',0,''),(59265,18887,'119556','deals-mobile','border-top-color','#dfa82a',0,''),(59266,18887,'119556','deals-mobile','font-size','18',0,''),(59267,18888,'119557','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59268,18888,'119557','deals-mobile','font-size','18',0,''),(59269,18888,'119557','deals-mobile','font-weight','normal',0,''),(59270,18888,'119557','deals-mobile','text-align','center',0,''),(59271,18888,'119557','deals-mobile','padding-top','20',0,''),(59272,18888,'119557','deals-mobile','padding-bottom','10',0,''),(59273,18888,'119557','deals-mobile','border-top-width','1',0,''),(59274,18888,'119557','deals-mobile','border-top-color','#dfa82a',0,''),(59275,18889,'119558','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(59276,18889,'119558','deals-mobile','font-weight','normal',0,''),(59277,18889,'119558','deals-mobile','text-align','center',0,''),(59278,18889,'119558','deals-mobile','padding-bottom','10',0,''),(59279,18889,'119558','deals-mobile','font-size','14',0,''),(59280,18890,'119559','deals-mobile','text','<p>GIFT CARD</p>',1,''),(59281,18890,'119559','deals-mobile','font-size','30',0,''),(59282,18890,'119559','deals-mobile','font-weight','normal',0,''),(59283,18890,'119559','deals-mobile','border-top-width','1',0,''),(59284,18890,'119559','deals-mobile','border-top-color','#dfa82a',0,''),(59285,18890,'119559','deals-mobile','style_class','gift-ico',0,''),(59286,18890,'119559','deals-mobile','text-align','center',0,''),(59287,18890,'119559','deals-mobile','padding-top','15',0,''),(59288,18891,'119560','deals-mobile','block_type','4',0,''),(59289,18891,'119560','deals-mobile','color','#ffffff',0,''),(59290,18891,'119560','deals-mobile','font-size','30',0,''),(59291,18891,'119560','deals-mobile','font-weight','normal',0,''),(59292,18891,'119560','deals-mobile','background-color','#ee4225',0,''),(59293,18891,'119560','deals-mobile','padding-top','5',0,''),(59294,18891,'119560','deals-mobile','padding-left','10',0,''),(59295,18891,'119560','deals-mobile','padding-right','10',0,''),(59296,18891,'119560','deals-mobile','padding-bottom','5',0,''),(59297,18892,'119561','deals-mobile','text','<p>Your code is:</p>',1,''),(59298,18892,'119561','deals-mobile','font-weight','normal',0,''),(59299,18894,'119563','deals-mobile','font-weight','normal',0,''),(59300,18894,'119563','deals-mobile','text-align','center',0,''),(59301,18894,'119563','deals-mobile','padding-bottom','20',0,''),(59302,18895,'119564','deals-mobile','font-size','60',0,''),(59303,18895,'119564','deals-mobile','font-weight','bold',0,''),(59304,18895,'119564','deals-mobile','text-align','center',0,''),(59305,18895,'119564','deals-mobile','line-height','100',0,''),(59306,18895,'119564','deals-mobile','padding-bottom','20',0,''),(59307,18895,'119564','deals-mobile','line_height_measure','px',0,''),(59308,18896,'119565','deals-mobile','text','<p>HOLBI</p>',1,''),(59309,18896,'119565','deals-mobile','font-family','Varela Round',0,''),(59310,18896,'119565','deals-mobile','font-size','24',0,''),(59311,18896,'119565','deals-mobile','font-weight','normal',0,''),(59312,18896,'119565','deals-mobile','text-align','center',0,''),(59313,18896,'119565','deals-mobile','padding-top','10',0,''),(59314,18896,'119565','deals-mobile','padding-bottom','20',0,''),(59315,18898,'119567','deals-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(59316,18898,'119567','deals-mobile','font-weight','normal',0,''),(59317,18898,'119567','deals-mobile','padding-bottom','20',0,''),(59318,18900,'119569','deals-mobile','block_type','1',0,''),(59319,18900,'119569','deals-mobile','font-weight','normal',0,''),(59320,18900,'119569','deals-mobile','style_class','gift-card-view',0,''),(59321,18900,'119569','deals-mobile','text-align','center',0,''),(59322,18900,'119569','deals-mobile','padding-bottom','20',0,''),(59323,18900,'119569','deals-mobile','background-color','#183d78',0,''),(59324,18900,'119569','deals-mobile','padding-left','20',0,''),(59325,18900,'119569','deals-mobile','padding-right','20',0,''),(59326,18900,'119569','deals-mobile','color','#cccccc',0,''),(59327,18901,'119570','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(59328,18901,'119570','deals-mobile','font-weight','normal',0,''),(59329,18901,'119570','deals-mobile','text-align','center',0,''),(59330,18901,'119570','deals-mobile','padding-bottom','10',0,''),(59331,18901,'119570','deals-mobile','font-size','14',0,''),(59332,18902,'119571','deals-mobile','text','<p>GIFT CARD</p>',1,''),(59333,18902,'119571','deals-mobile','font-size','30',0,''),(59334,18902,'119571','deals-mobile','font-weight','normal',0,''),(59335,18902,'119571','deals-mobile','border-top-width','1',0,''),(59336,18902,'119571','deals-mobile','border-top-color','#dfa82a',0,''),(59337,18902,'119571','deals-mobile','style_class','gift-ico',0,''),(59338,18902,'119571','deals-mobile','text-align','center',0,''),(59339,18902,'119571','deals-mobile','padding-top','15',0,''),(59340,18903,'119572','deals-mobile','logo','themes/deals-mobile/img/logo-1.png',1,''),(59341,18904,'119573','deals-mobile','logo','themes/deals-mobile/img/bestseller-1.png',1,''),(59342,18905,'119574','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59343,18905,'119574','deals-mobile','font-size','18',0,''),(59344,18905,'119574','deals-mobile','font-weight','normal',0,''),(59345,18905,'119574','deals-mobile','text-align','center',0,''),(59346,18905,'119574','deals-mobile','padding-top','20',0,''),(59347,18905,'119574','deals-mobile','padding-bottom','10',0,''),(59348,18905,'119574','deals-mobile','border-top-width','1',0,''),(59349,18905,'119574','deals-mobile','border-top-color','#dfa82a',0,''),(59350,18906,'119575','deals-mobile','font-size','60',0,''),(59351,18906,'119575','deals-mobile','font-weight','bold',0,''),(59352,18906,'119575','deals-mobile','text-align','center',0,''),(59353,18906,'119575','deals-mobile','line-height','100',0,''),(59354,18906,'119575','deals-mobile','padding-bottom','20',0,''),(59355,18906,'119575','deals-mobile','line_height_measure','px',0,''),(59356,18907,'119576','deals-mobile','font-weight','normal',0,''),(59357,18907,'119576','deals-mobile','text-align','center',0,''),(59358,18907,'119576','deals-mobile','padding-bottom','20',0,''),(59359,18908,'119577','deals-mobile','block_type','4',0,''),(59360,18908,'119577','deals-mobile','color','#ffffff',0,''),(59361,18908,'119577','deals-mobile','font-size','30',0,''),(59362,18908,'119577','deals-mobile','font-weight','normal',0,''),(59363,18908,'119577','deals-mobile','background-color','#ee4225',0,''),(59364,18908,'119577','deals-mobile','padding-top','5',0,''),(59365,18908,'119577','deals-mobile','padding-left','10',0,''),(59366,18908,'119577','deals-mobile','padding-right','10',0,''),(59367,18908,'119577','deals-mobile','padding-bottom','5',0,''),(59368,18909,'119578','deals-mobile','text','<p>Your code is:</p>',1,''),(59369,18909,'119578','deals-mobile','font-weight','normal',0,''),(59370,18911,'119580','deals-mobile','text','<p>HOLBI</p>',1,''),(59371,18911,'119580','deals-mobile','font-family','Varela Round',0,''),(59372,18911,'119580','deals-mobile','font-size','24',0,''),(59373,18911,'119580','deals-mobile','font-weight','normal',0,''),(59374,18911,'119580','deals-mobile','text-align','center',0,''),(59375,18911,'119580','deals-mobile','padding-top','10',0,''),(59376,18911,'119580','deals-mobile','padding-bottom','20',0,''),(59377,18912,'119581','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(59378,18912,'119581','deals-mobile','font-weight','normal',0,''),(59379,18912,'119581','deals-mobile','text-align','center',0,''),(59380,18912,'119581','deals-mobile','padding-top','20',0,''),(59381,18912,'119581','deals-mobile','padding-bottom','10',0,''),(59382,18912,'119581','deals-mobile','style_class','question-ico',0,''),(59383,18912,'119581','deals-mobile','border-top-width','1',0,''),(59384,18912,'119581','deals-mobile','border-top-color','#dfa82a',0,''),(59385,18912,'119581','deals-mobile','font-size','18',0,''),(59386,18913,'119582','deals-mobile','block_type','1',0,''),(59387,18913,'119582','deals-mobile','font-weight','normal',0,''),(59388,18913,'119582','deals-mobile','padding-top','10',0,''),(59389,18914,'119583','deals-mobile','font-size','12',0,''),(59390,18914,'119583','deals-mobile','font-weight','bold',0,''),(59391,18914,'119583','deals-mobile','text-align','center',0,''),(59392,18914,'119583','deals-mobile','style_class','phone',0,''),(59393,18914,'119583','deals-mobile','padding-bottom','5',0,''),(59394,18915,'119584','deals-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(59395,18915,'119584','deals-mobile','font-weight','normal',0,''),(59396,18915,'119584','deals-mobile','text-align','center',0,''),(59397,18915,'119584','deals-mobile','font-size','12',0,''),(59398,18915,'119584','deals-mobile','padding-top','10',0,''),(59399,18915,'119584','deals-mobile','padding-bottom','5',0,''),(59400,18915,'119584','deals-mobile','border-top-width','1',0,''),(59401,18915,'119584','deals-mobile','border-top-color','#dfa82a',0,''),(59402,18916,'119585','deals-mobile','font-size','12',0,''),(59403,18916,'119585','deals-mobile','font-weight','bold',0,''),(59404,18916,'119585','deals-mobile','text-align','center',0,''),(59405,18916,'119585','deals-mobile','style_class','email',0,''),(59406,18917,'119586','deals-mobile','block_type','1',0,''),(59407,18917,'119586','deals-mobile','font-weight','normal',0,''),(59408,18917,'119586','deals-mobile','style_class','gift-card-view',0,''),(59409,18917,'119586','deals-mobile','text-align','center',0,''),(59410,18917,'119586','deals-mobile','padding-bottom','20',0,''),(59411,18917,'119586','deals-mobile','background-color','#5289a4',0,''),(59412,18917,'119586','deals-mobile','padding-left','20',0,''),(59413,18917,'119586','deals-mobile','padding-right','20',0,''),(59414,18917,'119586','deals-mobile','color','#cccccc',0,''),(59415,18918,'119587','deals-mobile','text','<p>HOLBI</p>',1,''),(59416,18918,'119587','deals-mobile','font-family','Varela Round',0,''),(59417,18918,'119587','deals-mobile','font-size','24',0,''),(59418,18918,'119587','deals-mobile','font-weight','normal',0,''),(59419,18918,'119587','deals-mobile','text-align','center',0,''),(59420,18918,'119587','deals-mobile','padding-top','10',0,''),(59421,18918,'119587','deals-mobile','padding-bottom','20',0,''),(59422,18919,'119588','deals-mobile','text','<p>GIFT CARD</p>',1,''),(59423,18919,'119588','deals-mobile','font-size','30',0,''),(59424,18919,'119588','deals-mobile','font-weight','normal',0,''),(59425,18919,'119588','deals-mobile','border-top-width','1',0,''),(59426,18919,'119588','deals-mobile','border-top-color','#dfa82a',0,''),(59427,18919,'119588','deals-mobile','style_class','gift-ico',0,''),(59428,18919,'119588','deals-mobile','text-align','center',0,''),(59429,18919,'119588','deals-mobile','padding-top','15',0,''),(59430,18920,'119589','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(59431,18920,'119589','deals-mobile','font-weight','normal',0,''),(59432,18920,'119589','deals-mobile','text-align','center',0,''),(59433,18920,'119589','deals-mobile','padding-top','20',0,''),(59434,18920,'119589','deals-mobile','padding-bottom','10',0,''),(59435,18920,'119589','deals-mobile','style_class','question-ico',0,''),(59436,18920,'119589','deals-mobile','border-top-width','1',0,''),(59437,18920,'119589','deals-mobile','border-top-color','#dfa82a',0,''),(59438,18920,'119589','deals-mobile','font-size','18',0,''),(59439,18921,'119590','deals-mobile','font-weight','normal',0,''),(59440,18921,'119590','deals-mobile','text-align','center',0,''),(59441,18921,'119590','deals-mobile','padding-bottom','20',0,''),(59442,18922,'119591','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(59443,18922,'119591','deals-mobile','font-weight','normal',0,''),(59444,18922,'119591','deals-mobile','text-align','center',0,''),(59445,18922,'119591','deals-mobile','padding-bottom','10',0,''),(59446,18922,'119591','deals-mobile','font-size','14',0,''),(59447,18923,'119592','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59448,18923,'119592','deals-mobile','font-size','18',0,''),(59449,18923,'119592','deals-mobile','font-weight','normal',0,''),(59450,18923,'119592','deals-mobile','text-align','center',0,''),(59451,18923,'119592','deals-mobile','padding-top','20',0,''),(59452,18923,'119592','deals-mobile','padding-bottom','10',0,''),(59453,18923,'119592','deals-mobile','border-top-width','1',0,''),(59454,18923,'119592','deals-mobile','border-top-color','#dfa82a',0,''),(59455,18924,'119593','deals-mobile','block_type','1',0,''),(59456,18924,'119593','deals-mobile','font-weight','normal',0,''),(59457,18924,'119593','deals-mobile','padding-top','10',0,''),(59458,18925,'119594','deals-mobile','font-size','12',0,''),(59459,18925,'119594','deals-mobile','font-weight','bold',0,''),(59460,18925,'119594','deals-mobile','text-align','center',0,''),(59461,18925,'119594','deals-mobile','style_class','phone',0,''),(59462,18925,'119594','deals-mobile','padding-bottom','5',0,''),(59463,18926,'119595','deals-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(59464,18926,'119595','deals-mobile','font-weight','normal',0,''),(59465,18926,'119595','deals-mobile','text-align','center',0,''),(59466,18926,'119595','deals-mobile','font-size','12',0,''),(59467,18926,'119595','deals-mobile','padding-top','10',0,''),(59468,18926,'119595','deals-mobile','padding-bottom','5',0,''),(59469,18926,'119595','deals-mobile','border-top-width','1',0,''),(59470,18926,'119595','deals-mobile','border-top-color','#dfa82a',0,''),(59471,18927,'119596','deals-mobile','font-size','12',0,''),(59472,18927,'119596','deals-mobile','font-weight','bold',0,''),(59473,18927,'119596','deals-mobile','text-align','center',0,''),(59474,18927,'119596','deals-mobile','style_class','email',0,''),(59475,18928,'119597','deals-mobile','block_type','4',0,''),(59476,18928,'119597','deals-mobile','color','#ffffff',0,''),(59477,18928,'119597','deals-mobile','font-size','30',0,''),(59478,18928,'119597','deals-mobile','font-weight','normal',0,''),(59479,18928,'119597','deals-mobile','background-color','#ee4225',0,''),(59480,18928,'119597','deals-mobile','padding-top','5',0,''),(59481,18928,'119597','deals-mobile','padding-left','10',0,''),(59482,18928,'119597','deals-mobile','padding-right','10',0,''),(59483,18928,'119597','deals-mobile','padding-bottom','5',0,''),(59484,18929,'119598','deals-mobile','text','<p>Your code is:</p>',1,''),(59485,18929,'119598','deals-mobile','font-weight','normal',0,''),(59486,18931,'119600','deals-mobile','font-size','60',0,''),(59487,18931,'119600','deals-mobile','font-weight','bold',0,''),(59488,18931,'119600','deals-mobile','text-align','center',0,''),(59489,18931,'119600','deals-mobile','line-height','100',0,''),(59490,18931,'119600','deals-mobile','padding-bottom','20',0,''),(59491,18931,'119600','deals-mobile','line_height_measure','px',0,''),(59492,18932,'119601','deals-mobile','block_type','1',0,''),(59493,18932,'119601','deals-mobile','font-weight','normal',0,''),(59494,18932,'119601','deals-mobile','style_class','gift-card-view',0,''),(59495,18932,'119601','deals-mobile','text-align','center',0,''),(59496,18932,'119601','deals-mobile','padding-bottom','20',0,''),(59497,18932,'119601','deals-mobile','background-color','#5289a4',0,''),(59498,18932,'119601','deals-mobile','padding-left','20',0,''),(59499,18932,'119601','deals-mobile','padding-right','20',0,''),(59500,18932,'119601','deals-mobile','color','#cccccc',0,''),(59501,18933,'119602','deals-mobile','block_type','1',0,''),(59502,18933,'119602','deals-mobile','font-weight','normal',0,''),(59503,18933,'119602','deals-mobile','padding-top','10',0,''),(59504,18934,'119603','deals-mobile','font-size','12',0,''),(59505,18934,'119603','deals-mobile','font-weight','bold',0,''),(59506,18934,'119603','deals-mobile','text-align','center',0,''),(59507,18934,'119603','deals-mobile','style_class','email',0,''),(59508,18934,'119603','deals-mobile','color','#ffffff',0,''),(59509,18935,'119604','deals-mobile','font-size','12',0,''),(59510,18935,'119604','deals-mobile','font-weight','bold',0,''),(59511,18935,'119604','deals-mobile','text-align','center',0,''),(59512,18935,'119604','deals-mobile','style_class','phone',0,''),(59513,18935,'119604','deals-mobile','padding-bottom','5',0,''),(59514,18935,'119604','deals-mobile','color','#ffffff',0,''),(59515,18936,'119605','deals-mobile','text','If you require further assistance please contact us',0,''),(59516,18936,'119605','deals-mobile','font-size','12',0,''),(59517,18936,'119605','deals-mobile','color','#ffffff',0,''),(59518,18936,'119605','deals-mobile','text-align','center',0,''),(59519,18936,'119605','deals-mobile','padding-top','10',0,''),(59520,18937,'119606','deals-mobile','block_type','4',0,''),(59521,18937,'119606','deals-mobile','color','#ffffff',0,''),(59522,18937,'119606','deals-mobile','font-size','30',0,''),(59523,18937,'119606','deals-mobile','font-weight','normal',0,''),(59524,18937,'119606','deals-mobile','background-color','#ee4225',0,''),(59525,18937,'119606','deals-mobile','padding-top','5',0,''),(59526,18937,'119606','deals-mobile','padding-left','10',0,''),(59527,18937,'119606','deals-mobile','padding-right','10',0,''),(59528,18937,'119606','deals-mobile','padding-bottom','5',0,''),(59529,18938,'119607','deals-mobile','text','Your code is:',0,''),(59530,18938,'119607','deals-mobile','font-size','30',0,''),(59531,18938,'119607','deals-mobile','color','#ffffff',0,''),(59532,18939,'119608','deals-mobile','color','#ffffff',0,''),(59533,18939,'119608','deals-mobile','font-size','30',0,''),(59534,18940,'119609','deals-mobile','block_type','1',0,''),(59535,18941,'119610','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59536,18941,'119610','deals-mobile','font-size','18',0,''),(59537,18941,'119610','deals-mobile','font-weight','normal',0,''),(59538,18941,'119610','deals-mobile','text-align','center',0,''),(59539,18941,'119610','deals-mobile','padding-top','20',0,''),(59540,18941,'119610','deals-mobile','padding-bottom','10',0,''),(59541,18941,'119610','deals-mobile','border-top-width','1',0,''),(59542,18941,'119610','deals-mobile','border-top-color','#dfa82a',0,''),(59543,18942,'119611','deals-mobile','text','HOLBI',0,''),(59544,18942,'119611','deals-mobile','color','#ffffff',0,''),(59545,18942,'119611','deals-mobile','font-size','24',0,''),(59546,18942,'119611','deals-mobile','padding-top','20',0,''),(59547,18942,'119611','deals-mobile','text-align','center',0,''),(59548,18942,'119611','deals-mobile','padding-bottom','20',0,''),(59549,18943,'119612','deals-mobile','border-top-color','#dfa82a',0,''),(59550,18943,'119612','deals-mobile','border-top-width','1',0,''),(59551,18943,'119612','deals-mobile','padding-top','20',0,''),(59552,18943,'119612','deals-mobile','font-size','30',0,''),(59553,18943,'119612','deals-mobile','text-align','center',0,''),(59554,18943,'119612','deals-mobile','color','#ffffff',0,''),(59555,18943,'119612','deals-mobile','text','GIFT CARD',0,''),(59556,18944,'119613','deals-mobile','text-align','center',0,''),(59557,18944,'119613','deals-mobile','font-weight','bold',0,''),(59558,18944,'119613','deals-mobile','font-size','60',0,''),(59559,18944,'119613','deals-mobile','color','#ffffff',0,''),(59560,18945,'119614','deals-mobile','font-size','20',0,''),(59561,18945,'119614','deals-mobile','text-align','center',0,''),(59562,18945,'119614','deals-mobile','color','#ffffff',0,''),(59563,18945,'119614','deals-mobile','padding-top','20',0,''),(59564,18945,'119614','deals-mobile','padding-bottom','20',0,''),(59565,18946,'119615','deals-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(59566,18946,'119615','deals-mobile','text-align','center',0,''),(59567,18946,'119615','deals-mobile','color','#ffffff',0,''),(59568,18946,'119615','deals-mobile','font-size','14',0,''),(59569,18946,'119615','deals-mobile','padding-bottom','20',0,''),(59570,18947,'119616','deals-mobile','text','WHAT TO DO NEXT:',0,''),(59571,18947,'119616','deals-mobile','font-size','18',0,''),(59572,18947,'119616','deals-mobile','text-align','center',0,''),(59573,18947,'119616','deals-mobile','color','#ffffff',0,''),(59574,18947,'119616','deals-mobile','padding-top','20',0,''),(59575,18947,'119616','deals-mobile','padding-bottom','10',0,''),(59576,18947,'119616','deals-mobile','border-top-width','1',0,''),(59577,18947,'119616','deals-mobile','border-top-color','#dfa82a',0,''),(59578,18949,'119618','deals-mobile','block_type','1',0,''),(59579,18949,'119618','deals-mobile','font-weight','normal',0,''),(59580,18949,'119618','deals-mobile','style_class','gift-card-view',0,''),(59581,18949,'119618','deals-mobile','text-align','center',0,''),(59582,18949,'119618','deals-mobile','padding-bottom','20',0,''),(59583,18949,'119618','deals-mobile','background-color','#183d78',0,''),(59584,18949,'119618','deals-mobile','padding-left','20',0,''),(59585,18949,'119618','deals-mobile','padding-right','20',0,''),(59586,18949,'119618','deals-mobile','color','#cccccc',0,''),(59587,18950,'119619','deals-mobile','block_type','1',0,''),(59588,18950,'119619','deals-mobile','font-weight','normal',0,''),(59589,18950,'119619','deals-mobile','padding-top','10',0,''),(59590,18951,'119620','deals-mobile','font-size','12',0,''),(59591,18951,'119620','deals-mobile','font-weight','bold',0,''),(59592,18951,'119620','deals-mobile','text-align','center',0,''),(59593,18951,'119620','deals-mobile','style_class','email',0,''),(59594,18951,'119620','deals-mobile','color','#ffffff',0,''),(59595,18952,'119621','deals-mobile','font-size','12',0,''),(59596,18952,'119621','deals-mobile','font-weight','bold',0,''),(59597,18952,'119621','deals-mobile','text-align','center',0,''),(59598,18952,'119621','deals-mobile','style_class','phone',0,''),(59599,18952,'119621','deals-mobile','padding-bottom','5',0,''),(59600,18952,'119621','deals-mobile','color','#ffffff',0,''),(59601,18953,'119622','deals-mobile','text','If you require further assistance please contact us',0,''),(59602,18953,'119622','deals-mobile','font-size','12',0,''),(59603,18953,'119622','deals-mobile','color','#ffffff',0,''),(59604,18953,'119622','deals-mobile','text-align','center',0,''),(59605,18953,'119622','deals-mobile','padding-top','10',0,''),(59606,18954,'119623','deals-mobile','block_type','4',0,''),(59607,18954,'119623','deals-mobile','color','#ffffff',0,''),(59608,18954,'119623','deals-mobile','font-size','30',0,''),(59609,18954,'119623','deals-mobile','font-weight','normal',0,''),(59610,18954,'119623','deals-mobile','background-color','#ee4225',0,''),(59611,18954,'119623','deals-mobile','padding-top','5',0,''),(59612,18954,'119623','deals-mobile','padding-left','10',0,''),(59613,18954,'119623','deals-mobile','padding-right','10',0,''),(59614,18954,'119623','deals-mobile','padding-bottom','5',0,''),(59615,18955,'119624','deals-mobile','text','Your code is:',0,''),(59616,18955,'119624','deals-mobile','font-size','30',0,''),(59617,18955,'119624','deals-mobile','color','#ffffff',0,''),(59618,18956,'119625','deals-mobile','color','#ffffff',0,''),(59619,18956,'119625','deals-mobile','font-size','30',0,''),(59620,18957,'119626','deals-mobile','block_type','1',0,''),(59621,18958,'119627','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59622,18958,'119627','deals-mobile','font-size','18',0,''),(59623,18958,'119627','deals-mobile','font-weight','normal',0,''),(59624,18958,'119627','deals-mobile','text-align','center',0,''),(59625,18958,'119627','deals-mobile','padding-top','20',0,''),(59626,18958,'119627','deals-mobile','padding-bottom','10',0,''),(59627,18958,'119627','deals-mobile','border-top-width','1',0,''),(59628,18958,'119627','deals-mobile','border-top-color','#dfa82a',0,''),(59629,18959,'119628','deals-mobile','text','HOLBI',0,''),(59630,18959,'119628','deals-mobile','color','#ffffff',0,''),(59631,18959,'119628','deals-mobile','font-size','24',0,''),(59632,18959,'119628','deals-mobile','padding-top','20',0,''),(59633,18959,'119628','deals-mobile','text-align','center',0,''),(59634,18959,'119628','deals-mobile','padding-bottom','20',0,''),(59635,18960,'119629','deals-mobile','border-top-color','#dfa82a',0,''),(59636,18960,'119629','deals-mobile','border-top-width','1',0,''),(59637,18960,'119629','deals-mobile','padding-top','20',0,''),(59638,18960,'119629','deals-mobile','font-size','30',0,''),(59639,18960,'119629','deals-mobile','text-align','center',0,''),(59640,18960,'119629','deals-mobile','color','#ffffff',0,''),(59641,18960,'119629','deals-mobile','text','GIFT CARD',0,''),(59642,18961,'119630','deals-mobile','text-align','center',0,''),(59643,18961,'119630','deals-mobile','font-weight','bold',0,''),(59644,18961,'119630','deals-mobile','font-size','60',0,''),(59645,18961,'119630','deals-mobile','color','#ffffff',0,''),(59646,18962,'119631','deals-mobile','font-size','20',0,''),(59647,18962,'119631','deals-mobile','text-align','center',0,''),(59648,18962,'119631','deals-mobile','color','#ffffff',0,''),(59649,18962,'119631','deals-mobile','padding-top','20',0,''),(59650,18962,'119631','deals-mobile','padding-bottom','20',0,''),(59651,18963,'119632','deals-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(59652,18963,'119632','deals-mobile','text-align','center',0,''),(59653,18963,'119632','deals-mobile','color','#ffffff',0,''),(59654,18963,'119632','deals-mobile','font-size','14',0,''),(59655,18963,'119632','deals-mobile','padding-bottom','20',0,''),(59656,18964,'119633','deals-mobile','text','WHAT TO DO NEXT:',0,''),(59657,18964,'119633','deals-mobile','font-size','18',0,''),(59658,18964,'119633','deals-mobile','text-align','center',0,''),(59659,18964,'119633','deals-mobile','color','#ffffff',0,''),(59660,18964,'119633','deals-mobile','padding-top','20',0,''),(59661,18964,'119633','deals-mobile','padding-bottom','10',0,''),(59662,18964,'119633','deals-mobile','border-top-width','1',0,''),(59663,18964,'119633','deals-mobile','border-top-color','#dfa82a',0,''),(59664,18966,'119635','deals-mobile','block_type','1',0,''),(59665,18968,'119637','deals-mobile','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(59666,18968,'119637','deals-mobile','text-align','center',0,''),(59667,18969,'119638','deals-mobile','block_type','1',0,''),(59668,18969,'119638','deals-mobile','font-weight','normal',0,''),(59669,18969,'119638','deals-mobile','style_class','gift-card-view',0,''),(59670,18969,'119638','deals-mobile','text-align','center',0,''),(59671,18969,'119638','deals-mobile','padding-bottom','20',0,''),(59672,18969,'119638','deals-mobile','background-color','#47a793',0,''),(59673,18969,'119638','deals-mobile','padding-left','20',0,''),(59674,18969,'119638','deals-mobile','padding-right','20',0,''),(59675,18969,'119638','deals-mobile','color','#cccccc',0,''),(59676,18970,'119639','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',1,''),(59677,18970,'119639','deals-mobile','font-weight','normal',0,''),(59678,18970,'119639','deals-mobile','text-align','center',0,''),(59679,18970,'119639','deals-mobile','padding-bottom','10',0,''),(59680,18970,'119639','deals-mobile','font-size','14',0,''),(59681,18971,'119640','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59682,18971,'119640','deals-mobile','font-size','18',0,''),(59683,18971,'119640','deals-mobile','font-weight','normal',0,''),(59684,18971,'119640','deals-mobile','text-align','center',0,''),(59685,18971,'119640','deals-mobile','padding-top','20',0,''),(59686,18971,'119640','deals-mobile','padding-bottom','10',0,''),(59687,18971,'119640','deals-mobile','border-top-width','1',0,''),(59688,18971,'119640','deals-mobile','border-top-color','#dfa82a',0,''),(59689,18972,'119641','deals-mobile','font-size','60',0,''),(59690,18972,'119641','deals-mobile','font-weight','bold',0,''),(59691,18972,'119641','deals-mobile','text-align','center',0,''),(59692,18972,'119641','deals-mobile','line-height','100',0,''),(59693,18972,'119641','deals-mobile','padding-bottom','20',0,''),(59694,18972,'119641','deals-mobile','line_height_measure','px',0,''),(59695,18973,'119642','deals-mobile','text','<p>GIFT CARD</p>',1,''),(59696,18973,'119642','deals-mobile','font-size','30',0,''),(59697,18973,'119642','deals-mobile','font-weight','normal',0,''),(59698,18973,'119642','deals-mobile','border-top-width','1',0,''),(59699,18973,'119642','deals-mobile','border-top-color','#dfa82a',0,''),(59700,18973,'119642','deals-mobile','style_class','gift-ico',0,''),(59701,18973,'119642','deals-mobile','text-align','center',0,''),(59702,18973,'119642','deals-mobile','padding-top','15',0,''),(59703,18974,'119643','deals-mobile','font-weight','normal',0,''),(59704,18974,'119643','deals-mobile','text-align','center',0,''),(59705,18974,'119643','deals-mobile','padding-bottom','20',0,''),(59706,18975,'119644','deals-mobile','text','<p>HOLBI</p>',1,''),(59707,18975,'119644','deals-mobile','font-family','Varela Round',0,''),(59708,18975,'119644','deals-mobile','font-size','24',0,''),(59709,18975,'119644','deals-mobile','font-weight','normal',0,''),(59710,18975,'119644','deals-mobile','text-align','center',0,''),(59711,18975,'119644','deals-mobile','padding-top','10',0,''),(59712,18975,'119644','deals-mobile','padding-bottom','20',0,''),(59713,18976,'119645','deals-mobile','block_type','1',0,''),(59714,18976,'119645','deals-mobile','font-weight','normal',0,''),(59715,18976,'119645','deals-mobile','padding-top','10',0,''),(59716,18977,'119646','deals-mobile','font-size','12',0,''),(59717,18977,'119646','deals-mobile','font-weight','bold',0,''),(59718,18977,'119646','deals-mobile','text-align','center',0,''),(59719,18977,'119646','deals-mobile','style_class','email',0,''),(59720,18978,'119647','deals-mobile','font-size','12',0,''),(59721,18978,'119647','deals-mobile','font-weight','bold',0,''),(59722,18978,'119647','deals-mobile','text-align','center',0,''),(59723,18978,'119647','deals-mobile','style_class','phone',0,''),(59724,18978,'119647','deals-mobile','padding-bottom','5',0,''),(59725,18979,'119648','deals-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(59726,18979,'119648','deals-mobile','font-weight','normal',0,''),(59727,18979,'119648','deals-mobile','text-align','center',0,''),(59728,18979,'119648','deals-mobile','font-size','12',0,''),(59729,18979,'119648','deals-mobile','padding-top','10',0,''),(59730,18979,'119648','deals-mobile','padding-bottom','5',0,''),(59731,18979,'119648','deals-mobile','border-top-width','1',0,''),(59732,18979,'119648','deals-mobile','border-top-color','#dfa82a',0,''),(59733,18980,'119649','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(59734,18980,'119649','deals-mobile','font-weight','normal',0,''),(59735,18980,'119649','deals-mobile','text-align','center',0,''),(59736,18980,'119649','deals-mobile','padding-top','20',0,''),(59737,18980,'119649','deals-mobile','padding-bottom','10',0,''),(59738,18980,'119649','deals-mobile','style_class','question-ico',0,''),(59739,18980,'119649','deals-mobile','border-top-width','1',0,''),(59740,18980,'119649','deals-mobile','border-top-color','#dfa82a',0,''),(59741,18980,'119649','deals-mobile','font-size','18',0,''),(59742,18981,'119650','deals-mobile','block_type','4',0,''),(59743,18981,'119650','deals-mobile','color','#ffffff',0,''),(59744,18981,'119650','deals-mobile','font-size','30',0,''),(59745,18981,'119650','deals-mobile','font-weight','normal',0,''),(59746,18981,'119650','deals-mobile','background-color','#ee4225',0,''),(59747,18981,'119650','deals-mobile','padding-top','5',0,''),(59748,18981,'119650','deals-mobile','padding-left','10',0,''),(59749,18981,'119650','deals-mobile','padding-right','10',0,''),(59750,18981,'119650','deals-mobile','padding-bottom','5',0,''),(59751,18982,'119651','deals-mobile','text','<p>Your code is:</p>',1,''),(59752,18982,'119651','deals-mobile','font-weight','normal',0,''),(59753,18984,'119653','deals-mobile','block_type','1',0,''),(59754,18984,'119653','deals-mobile','font-weight','normal',0,''),(59755,18984,'119653','deals-mobile','style_class','gift-card-view',0,''),(59756,18984,'119653','deals-mobile','text-align','center',0,''),(59757,18984,'119653','deals-mobile','padding-bottom','20',0,''),(59758,18984,'119653','deals-mobile','background-color','#47a793',0,''),(59759,18984,'119653','deals-mobile','padding-left','20',0,''),(59760,18984,'119653','deals-mobile','padding-right','20',0,''),(59761,18984,'119653','deals-mobile','color','#cccccc',0,''),(59762,18985,'119654','deals-mobile','block_type','1',0,''),(59763,18985,'119654','deals-mobile','font-weight','normal',0,''),(59764,18985,'119654','deals-mobile','padding-top','10',0,''),(59765,18986,'119655','deals-mobile','font-size','12',0,''),(59766,18986,'119655','deals-mobile','font-weight','bold',0,''),(59767,18986,'119655','deals-mobile','text-align','center',0,''),(59768,18986,'119655','deals-mobile','style_class','email',0,''),(59769,18986,'119655','deals-mobile','color','#ffffff',0,''),(59770,18987,'119656','deals-mobile','font-size','12',0,''),(59771,18987,'119656','deals-mobile','font-weight','bold',0,''),(59772,18987,'119656','deals-mobile','text-align','center',0,''),(59773,18987,'119656','deals-mobile','style_class','phone',0,''),(59774,18987,'119656','deals-mobile','padding-bottom','5',0,''),(59775,18987,'119656','deals-mobile','color','#ffffff',0,''),(59776,18988,'119657','deals-mobile','text','If you require further assistance please contact us',0,''),(59777,18988,'119657','deals-mobile','font-size','12',0,''),(59778,18988,'119657','deals-mobile','color','#ffffff',0,''),(59779,18988,'119657','deals-mobile','text-align','center',0,''),(59780,18988,'119657','deals-mobile','padding-top','10',0,''),(59781,18989,'119658','deals-mobile','block_type','4',0,''),(59782,18989,'119658','deals-mobile','color','#ffffff',0,''),(59783,18989,'119658','deals-mobile','font-size','30',0,''),(59784,18989,'119658','deals-mobile','font-weight','normal',0,''),(59785,18989,'119658','deals-mobile','background-color','#ee4225',0,''),(59786,18989,'119658','deals-mobile','padding-top','5',0,''),(59787,18989,'119658','deals-mobile','padding-left','10',0,''),(59788,18989,'119658','deals-mobile','padding-right','10',0,''),(59789,18989,'119658','deals-mobile','padding-bottom','5',0,''),(59790,18990,'119659','deals-mobile','text','Your code is:',0,''),(59791,18990,'119659','deals-mobile','font-size','30',0,''),(59792,18990,'119659','deals-mobile','color','#ffffff',0,''),(59793,18991,'119660','deals-mobile','color','#ffffff',0,''),(59794,18991,'119660','deals-mobile','font-size','30',0,''),(59795,18992,'119661','deals-mobile','block_type','1',0,''),(59796,18993,'119662','deals-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(59797,18993,'119662','deals-mobile','font-size','18',0,''),(59798,18993,'119662','deals-mobile','font-weight','normal',0,''),(59799,18993,'119662','deals-mobile','text-align','center',0,''),(59800,18993,'119662','deals-mobile','padding-top','20',0,''),(59801,18993,'119662','deals-mobile','padding-bottom','10',0,''),(59802,18993,'119662','deals-mobile','border-top-width','1',0,''),(59803,18993,'119662','deals-mobile','border-top-color','#dfa82a',0,''),(59804,18994,'119663','deals-mobile','text','HOLBI',0,''),(59805,18994,'119663','deals-mobile','color','#ffffff',0,''),(59806,18994,'119663','deals-mobile','font-size','24',0,''),(59807,18994,'119663','deals-mobile','padding-top','20',0,''),(59808,18994,'119663','deals-mobile','text-align','center',0,''),(59809,18994,'119663','deals-mobile','padding-bottom','20',0,''),(59810,18995,'119664','deals-mobile','border-top-color','#dfa82a',0,''),(59811,18995,'119664','deals-mobile','border-top-width','1',0,''),(59812,18995,'119664','deals-mobile','padding-top','20',0,''),(59813,18995,'119664','deals-mobile','font-size','30',0,''),(59814,18995,'119664','deals-mobile','text-align','center',0,''),(59815,18995,'119664','deals-mobile','color','#ffffff',0,''),(59816,18995,'119664','deals-mobile','text','GIFT CARD',0,''),(59817,18996,'119665','deals-mobile','text-align','center',0,''),(59818,18996,'119665','deals-mobile','font-weight','bold',0,''),(59819,18996,'119665','deals-mobile','font-size','60',0,''),(59820,18996,'119665','deals-mobile','color','#ffffff',0,''),(59821,18997,'119666','deals-mobile','font-size','20',0,''),(59822,18997,'119666','deals-mobile','text-align','center',0,''),(59823,18997,'119666','deals-mobile','color','#ffffff',0,''),(59824,18997,'119666','deals-mobile','padding-top','20',0,''),(59825,18997,'119666','deals-mobile','padding-bottom','20',0,''),(59826,18998,'119667','deals-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(59827,18998,'119667','deals-mobile','text-align','center',0,''),(59828,18998,'119667','deals-mobile','color','#ffffff',0,''),(59829,18998,'119667','deals-mobile','font-size','14',0,''),(59830,18998,'119667','deals-mobile','padding-bottom','20',0,''),(59831,18999,'119668','deals-mobile','text','WHAT TO DO NEXT:',0,''),(59832,18999,'119668','deals-mobile','font-size','18',0,''),(59833,18999,'119668','deals-mobile','text-align','center',0,''),(59834,18999,'119668','deals-mobile','color','#ffffff',0,''),(59835,18999,'119668','deals-mobile','padding-top','20',0,''),(59836,18999,'119668','deals-mobile','padding-bottom','10',0,''),(59837,18999,'119668','deals-mobile','border-top-width','1',0,''),(59838,18999,'119668','deals-mobile','border-top-color','#dfa82a',0,''),(59839,19000,'119669','deals-mobile','logo','themes/deals-mobile/img/oscommerce_logo.png',1,''),(59840,19000,'119669','deals-mobile','text-align','center',0,''),(59841,19000,'119669','deals-mobile','padding-top','10',0,''),(59842,19000,'119669','deals-mobile','padding-left','60',0,''),(59843,19000,'119669','deals-mobile','padding-right','60',0,''),(59844,19000,'119669','deals-mobile','padding-bottom','10',0,''),(59845,19001,'119670','deals-mobile','text-align','center',0,''),(59846,19001,'119670','deals-mobile','margin-bottom','20',0,''),(59847,19002,'119671','deals-mobile','block_type','1',0,''),(59848,19002,'119671','deals-mobile','background-color','#eeeeee',0,''),(59849,19002,'119671','deals-mobile','border-bottom-width','1',0,''),(59850,19002,'119671','deals-mobile','border-bottom-color','#dedede',0,''),(59851,19002,'119671','deals-mobile','display_none','on',0,'864'),(59852,19003,'119672','deals-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',1,''),(59853,19003,'119672','deals-mobile','float','right',0,''),(59854,19003,'119672','deals-mobile','max-width','450',0,''),(59855,19003,'119672','deals-mobile','font-size','13',0,''),(59856,19003,'119672','deals-mobile','padding-top','5',0,''),(59857,19003,'119672','deals-mobile','padding-bottom','5',0,''),(59858,19003,'119672','deals-mobile','width','350',0,'871'),(59859,19004,'119673','deals-mobile','block_type','4',0,''),(59860,19004,'119673','deals-mobile','display','inline-block',0,''),(59861,19004,'119673','deals-mobile','width','650',0,''),(59862,19004,'119673','deals-mobile','vertical-align','middle',0,''),(59863,19004,'119673','deals-mobile','float','left',0,''),(59864,19004,'119673','deals-mobile','clear','none',0,''),(59865,19004,'119673','deals-mobile','text-align','left',0,''),(59866,19004,'119673','deals-mobile','padding-top','10',0,''),(59867,19004,'119673','deals-mobile','padding-bottom','10',0,''),(59868,19004,'119673','deals-mobile','schema','4-2',0,'871'),(59869,19004,'119673','deals-mobile','width','350',0,'871'),(59870,19004,'119673','deals-mobile','padding-top','0',0,'871'),(59871,19005,'119674','deals-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',1,''),(59872,19005,'119674','deals-mobile','font-family','Hind',0,''),(59873,19005,'119674','deals-mobile','font-size','22',0,''),(59874,19005,'119674','deals-mobile','color','#00a858',0,''),(59875,19005,'119674','deals-mobile','padding-top','7',0,''),(59876,19005,'119674','deals-mobile','display','inline-block',0,''),(59877,19005,'119674','deals-mobile','float','left',0,''),(59878,19005,'119674','deals-mobile','clear','none',0,''),(59879,19005,'119674','deals-mobile','font-size','20',0,'871'),(59880,19006,'119675','deals-mobile','logo','themes/deals-mobile/img/check-2.png',1,''),(59881,19006,'119675','deals-mobile','display','inline-block',0,''),(59882,19006,'119675','deals-mobile','vertical-align','top',0,''),(59883,19006,'119675','deals-mobile','padding-top','10',0,''),(59884,19006,'119675','deals-mobile','padding-right','10',0,''),(59885,19006,'119675','deals-mobile','float','left',0,''),(59886,19006,'119675','deals-mobile','clear','none',0,''),(59887,19007,'119676','deals-mobile','block_type','2',0,''),(59888,19008,'119677','deals-mobile','text','<a class=\"secure-1_\" href=\"//www.securitymetrics.com/site_certificate?id=1442870&tk=4964ae06eb42dd2462f57cde979b3228\" target=\"_blank\"><img src=\"images/security.jpg\" alt=\"SecurityMetrics Credit Card Safe\" /></a>',0,''),(59889,19008,'119677','deals-mobile','text-align','center',0,''),(59890,19009,'119678','deals-mobile','text','<a href=\"//www.securitymetrics.com/site_certificate?id=1442870&tk=4964ae06eb42dd2462f57cde979b3228\" target=\"_blank\"><img src=\"images/security2.jpg\" alt=\"SecurityMetrics Credit Card Safe\" /></a>',0,''),(59891,19009,'119678','deals-mobile','text-align','center',0,''),(59892,19010,'119679','deals-mobile','block_type','14',0,''),(59893,19010,'119679','deals-mobile','font-weight','400',0,''),(59894,19010,'119679','deals-mobile','background-color','#183d78',0,''),(59895,19011,'119680','deals-mobile','class','menu-style-1',0,''),(59896,19011,'119680','deals-mobile','box_align','4',0,''),(59897,19011,'119680','deals-mobile','font-weight','400',0,''),(59898,19011,'119680','deals-mobile','hide_menu','on',0,''),(59899,19011,'119680','deals-mobile','color','#ffffff',0,''),(59900,19011,'119680','deals-mobile','hide_menu','1',0,'865'),(59901,19015,'119684','deals-mobile','block_type','1',0,''),(59902,19018,'119687','deals-mobile','width','680',0,''),(59903,19018,'119687','deals-mobile','font-weight','normal',0,''),(59904,19018,'119687','deals-mobile','font-size','12',0,''),(59905,19018,'119687','deals-mobile','padding-top','20',0,''),(59906,19018,'119687','deals-mobile','padding-bottom','20',0,''),(59907,19018,'119687','deals-mobile','color','#000000',0,''),(59908,19019,'119688','deals-mobile','block_type','5',0,''),(59909,19019,'119688','deals-mobile','font-weight','normal',0,''),(59910,19019,'119688','deals-mobile','border-bottom-width','1',0,''),(59911,19019,'119688','deals-mobile','border-bottom-color','#e0e0e0',0,''),(59912,19019,'119688','deals-mobile','border-top-width','1',0,''),(59913,19019,'119688','deals-mobile','border-top-color','#e0e0e0',0,''),(59914,19019,'119688','deals-mobile','border-left-color','#e0e0e0',0,''),(59915,19019,'119688','deals-mobile','border-left-width','1',0,''),(59916,19020,'119689','deals-mobile','block_type','1',0,''),(59917,19020,'119689','deals-mobile','font-weight','normal',0,''),(59918,19020,'119689','deals-mobile','padding-top','10',0,''),(59919,19020,'119689','deals-mobile','padding-left','10',0,''),(59920,19020,'119689','deals-mobile','padding-right','10',0,''),(59921,19021,'119690','deals-mobile','font-weight','400',0,''),(59922,19021,'119690','deals-mobile','line-height','120',0,''),(59923,19021,'119690','deals-mobile','line_height_measure','%',0,''),(59924,19022,'119691','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(59925,19022,'119691','deals-mobile','font-size','14',0,''),(59926,19022,'119691','deals-mobile','font-weight','bold',0,''),(59927,19022,'119691','deals-mobile','padding-bottom','10',0,''),(59928,19023,'119692','deals-mobile','block_type','1',0,''),(59929,19023,'119692','deals-mobile','background-color','#e0e0e0',0,''),(59930,19023,'119692','deals-mobile','padding-top','40',0,''),(59931,19023,'119692','deals-mobile','padding-left','10',0,''),(59932,19023,'119692','deals-mobile','padding-right','10',0,''),(59933,19023,'119692','deals-mobile','padding-bottom','40',0,''),(59934,19024,'119693','deals-mobile','font-weight','normal',0,''),(59935,19024,'119693','deals-mobile','line-height','200',0,''),(59936,19024,'119693','deals-mobile','text-align','right',0,''),(59937,19024,'119693','deals-mobile','font-size','14',0,''),(59938,19024,'119693','deals-mobile','box_align','3',0,''),(59939,19025,'119694','deals-mobile','font-weight','400',0,''),(59940,19025,'119694','deals-mobile','padding-top','20',0,''),(59941,19025,'119694','deals-mobile','padding-bottom','20',0,''),(59942,19025,'119694','deals-mobile','font-size','12',0,''),(59943,19026,'119695','deals-mobile','block_type','2',0,''),(59944,19026,'119695','deals-mobile','font-weight','normal',0,''),(59945,19026,'119695','deals-mobile','padding-bottom','20',0,''),(59946,19027,'119696','deals-mobile','font-weight','400',0,''),(59947,19027,'119696','deals-mobile','padding-top','20',0,''),(59949,19028,'119697','deals-mobile','block_type','11',0,''),(59950,19028,'119697','deals-mobile','font-weight','normal',0,''),(59951,19029,'119698','deals-mobile','text','<p>Phone:</p>',1,''),(59952,19029,'119698','deals-mobile','font-weight','normal',0,''),(59953,19029,'119698','deals-mobile','text-align','right',0,''),(59954,19030,'119699','deals-mobile','font-weight','normal',0,''),(59955,19030,'119699','deals-mobile','text-align','right',0,''),(59956,19031,'119700','deals-mobile','block_type','1',0,''),(59957,19032,'119701','deals-mobile','font-weight','normal',0,''),(59958,19032,'119701','deals-mobile','text-align','right',0,''),(59959,19032,'119701','deals-mobile','padding-bottom','10',0,''),(59960,19032,'119701','deals-mobile','address_spacer',',',0,''),(59961,19033,'119702','deals-mobile','block_type','11',0,''),(59962,19033,'119702','deals-mobile','font-weight','normal',0,''),(59963,19034,'119703','deals-mobile','text','<p>Web:</p>',1,''),(59964,19034,'119703','deals-mobile','font-weight','normal',0,''),(59965,19034,'119703','deals-mobile','text-align','right',0,''),(59966,19035,'119704','deals-mobile','font-weight','normal',0,''),(59967,19035,'119704','deals-mobile','text-align','right',0,''),(59968,19036,'119705','deals-mobile','block_type','11',0,''),(59969,19036,'119705','deals-mobile','font-weight','normal',0,''),(59970,19037,'119706','deals-mobile','text','<p>Email:</p>',1,''),(59971,19037,'119706','deals-mobile','font-weight','normal',0,''),(59972,19037,'119706','deals-mobile','text-align','right',0,''),(59973,19038,'119707','deals-mobile','font-weight','normal',0,''),(59974,19038,'119707','deals-mobile','text-align','right',0,''),(59975,19039,'119708','deals-mobile','block_type','3',0,''),(59976,19039,'119708','deals-mobile','font-weight','normal',0,''),(59977,19039,'119708','deals-mobile','padding-top','20',0,''),(59978,19040,'119709','deals-mobile','text','<p>If undelivered please return to:</p>',1,''),(59979,19040,'119709','deals-mobile','font-size','15',0,''),(59980,19040,'119709','deals-mobile','font-weight','bold',0,''),(59981,19041,'119710','deals-mobile','font-size','14',0,''),(59982,19042,'119711','deals-mobile','text','<p>Thank you for your order</p>',1,''),(59983,19042,'119711','deals-mobile','color','#008fe9',0,''),(59984,19042,'119711','deals-mobile','font-size','16',0,''),(59985,19042,'119711','deals-mobile','font-weight','bold',0,''),(59986,19042,'119711','deals-mobile','padding-top','5',0,''),(59987,19042,'119711','deals-mobile','text-align','center',0,''),(59988,19043,'119712','deals-mobile','font-weight','400',0,''),(59989,19043,'119712','deals-mobile','text-align','center',0,''),(59990,19043,'119712','deals-mobile','padding-top','0',0,''),(59992,19043,'119712','deals-mobile','padding-left','20',0,''),(59993,19043,'119712','deals-mobile','padding-right','20',0,''),(59994,19044,'119713','deals-mobile','block_type','6',0,''),(59995,19044,'119713','deals-mobile','font-weight','normal',0,''),(59996,19044,'119713','deals-mobile','font-size','16',0,''),(59997,19045,'119714','deals-mobile','text','<p>Email:</p>',1,''),(59998,19045,'119714','deals-mobile','font-weight','normal',0,''),(59999,19045,'119714','deals-mobile','text-align','right',0,''),(60000,19045,'119714','deals-mobile','font-size','14',0,''),(60001,19046,'119715','deals-mobile','font-weight','normal',0,''),(60002,19046,'119715','deals-mobile','text-align','right',0,''),(60003,19046,'119715','deals-mobile','font-size','14',0,''),(60004,19047,'119716','deals-mobile','block_type','6',0,''),(60005,19047,'119716','deals-mobile','font-weight','normal',0,''),(60006,19047,'119716','deals-mobile','font-size','16',0,''),(60007,19048,'119717','deals-mobile','text','<p>Phone:</p>',1,''),(60008,19048,'119717','deals-mobile','font-weight','normal',0,''),(60009,19048,'119717','deals-mobile','text-align','right',0,''),(60010,19048,'119717','deals-mobile','font-size','14',0,''),(60011,19049,'119718','deals-mobile','font-weight','normal',0,''),(60012,19049,'119718','deals-mobile','text-align','right',0,''),(60013,19049,'119718','deals-mobile','font-size','14',0,''),(60014,19050,'119719','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(60015,19050,'119719','deals-mobile','font-size','14',0,''),(60016,19050,'119719','deals-mobile','font-weight','bold',0,''),(60017,19050,'119719','deals-mobile','text-align','right',0,''),(60018,19051,'119720','deals-mobile','block_type','4',0,''),(60019,19051,'119720','deals-mobile','font-weight','normal',0,''),(60020,19051,'119720','deals-mobile','border-top-width','1',0,''),(60021,19051,'119720','deals-mobile','border-top-color','#e0e0e0',0,''),(60022,19051,'119720','deals-mobile','border-left-width','1',0,''),(60023,19051,'119720','deals-mobile','border-left-color','#e0e0e0',0,''),(60024,19051,'119720','deals-mobile','border-right-width','1',0,''),(60025,19051,'119720','deals-mobile','border-right-color','#e0e0e0',0,''),(60026,19051,'119720','deals-mobile','border-bottom-width','1',0,''),(60027,19051,'119720','deals-mobile','border-bottom-color','#e0e0e0',0,''),(60028,19052,'119721','deals-mobile','block_type','2',0,''),(60029,19052,'119721','deals-mobile','font-weight','normal',0,''),(60030,19052,'119721','deals-mobile','border-top-width','1',0,''),(60031,19052,'119721','deals-mobile','border-top-color','#e0e0e0',0,''),(60032,19052,'119721','deals-mobile','border-right-width','1',0,''),(60033,19052,'119721','deals-mobile','border-right-color','#e0e0e0',0,''),(60034,19053,'119722','deals-mobile','block_type','1',0,''),(60035,19053,'119722','deals-mobile','font-weight','normal',0,''),(60036,19053,'119722','deals-mobile','padding-top','10',0,''),(60037,19053,'119722','deals-mobile','padding-left','10',0,''),(60038,19053,'119722','deals-mobile','padding-right','10',0,''),(60039,19053,'119722','deals-mobile','padding-bottom','10',0,''),(60040,19053,'119722','deals-mobile','border-right-width','1',0,''),(60041,19053,'119722','deals-mobile','border-right-color','#e0e0e0',0,''),(60042,19054,'119723','deals-mobile','text','<p>Shipping via</p>',1,''),(60043,19054,'119723','deals-mobile','font-weight','bold',0,''),(60044,19056,'119725','deals-mobile','block_type','1',0,''),(60045,19056,'119725','deals-mobile','font-weight','normal',0,''),(60046,19056,'119725','deals-mobile','padding-top','10',0,''),(60047,19056,'119725','deals-mobile','padding-left','10',0,''),(60048,19056,'119725','deals-mobile','padding-right','10',0,''),(60049,19056,'119725','deals-mobile','padding-bottom','10',0,''),(60050,19058,'119727','deals-mobile','text','<p>Shipping service</p>',1,''),(60051,19058,'119727','deals-mobile','font-weight','bold',0,''),(60052,19059,'119728','deals-mobile','block_type','2',0,''),(60053,19059,'119728','deals-mobile','font-weight','normal',0,''),(60054,19059,'119728','deals-mobile','border-right-width','1',0,''),(60055,19059,'119728','deals-mobile','border-right-color','#e0e0e0',0,''),(60056,19060,'119729','deals-mobile','block_type','1',0,''),(60057,19060,'119729','deals-mobile','font-weight','400',0,''),(60058,19060,'119729','deals-mobile','background-color','#e0e0e0',0,''),(60059,19060,'119729','deals-mobile','padding-top','10',0,''),(60060,19060,'119729','deals-mobile','padding-left','10',0,''),(60061,19060,'119729','deals-mobile','padding-right','10',0,''),(60062,19060,'119729','deals-mobile','padding-bottom','50',0,''),(60063,19061,'119730','deals-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(60064,19061,'119730','deals-mobile','font-size','16',0,''),(60065,19061,'119730','deals-mobile','font-weight','bold',0,''),(60066,19063,'119732','deals-mobile','block_type','1',0,''),(60067,19063,'119732','deals-mobile','font-weight','normal',0,''),(60068,19063,'119732','deals-mobile','padding-top','10',0,''),(60069,19063,'119732','deals-mobile','padding-left','10',0,''),(60070,19063,'119732','deals-mobile','padding-right','10',0,''),(60071,19063,'119732','deals-mobile','padding-bottom','10',0,''),(60072,19064,'119733','deals-mobile','font-weight','normal',0,''),(60073,19065,'119734','deals-mobile','text','<p>CUSTOMER:</p>',1,''),(60074,19065,'119734','deals-mobile','font-size','14',0,''),(60075,19065,'119734','deals-mobile','font-weight','bold',0,''),(60076,19066,'119735','deals-mobile','font-weight','normal',0,''),(60077,19067,'119736','deals-mobile','text','<p>PHONE NUMBER:</p>',1,''),(60078,19067,'119736','deals-mobile','font-size','14',0,''),(60079,19067,'119736','deals-mobile','font-weight','bold',0,''),(60080,19067,'119736','deals-mobile','padding-top','10',0,''),(60081,19068,'119737','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(60082,19068,'119737','deals-mobile','font-weight','bold',0,''),(60083,19068,'119737','deals-mobile','font-size','14',0,''),(60084,19068,'119737','deals-mobile','padding-top','10',0,''),(60085,19070,'119739','deals-mobile','font-weight','normal',0,''),(60086,19070,'119739','deals-mobile','text-align','center',0,''),(60087,19070,'119739','deals-mobile','padding-bottom','20',0,''),(60088,19071,'119740','deals-mobile','font-weight','normal',0,''),(60089,19071,'119740','deals-mobile','text-align','center',0,''),(60090,19071,'119740','deals-mobile','padding-bottom','10',0,''),(60091,19072,'119741','deals-mobile','font-size','16',0,''),(60092,19072,'119741','deals-mobile','font-weight','bold',0,''),(60093,19072,'119741','deals-mobile','text-align','center',0,''),(60094,19072,'119741','deals-mobile','padding-bottom','10',0,''),(60095,19072,'119741','deals-mobile','padding-top','10',0,''),(60096,19073,'119742','deals-mobile','font-weight','normal',0,''),(60097,19073,'119742','deals-mobile','text-align','center',0,''),(60098,19074,'119743','deals-mobile','text','<p>Payment date:</p>',1,''),(60099,19074,'119743','deals-mobile','font-weight','bold',0,''),(60100,19074,'119743','deals-mobile','text-align','center',0,''),(60101,19075,'119744','deals-mobile','text','<p>Payment Method:</p>',1,''),(60102,19075,'119744','deals-mobile','font-weight','bold',0,''),(60103,19075,'119744','deals-mobile','text-align','center',0,''),(60104,19076,'119745','deals-mobile','block_type','1',0,''),(60105,19076,'119745','deals-mobile','padding-top','20',0,''),(60106,19077,'119746','deals-mobile','tab_1','RETURNING CUSTOMER',1,''),(60107,19077,'119746','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(60108,19080,'119749','deals-mobile','block_type','1',0,''),(60109,19081,'119750','deals-mobile','text','##TEXT_OR##',0,''),(60110,19081,'119750','deals-mobile','font-size','18',0,''),(60111,19081,'119750','deals-mobile','font-weight','700',0,''),(60112,19081,'119750','deals-mobile','padding-top','15',0,''),(60113,19081,'119750','deals-mobile','text-align','center',0,''),(60114,19081,'119750','deals-mobile','content','\\_',0,'3'),(60115,19081,'119750','deals-mobile','height','5',0,'3'),(60116,19081,'119750','deals-mobile','width','70',0,'3'),(60117,19081,'119750','deals-mobile','display','inline-block',0,'3'),(60118,19081,'119750','deals-mobile','border-top-width','1',0,'3'),(60119,19081,'119750','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60120,19081,'119750','deals-mobile','margin-left','10',0,'3'),(60121,19081,'119750','deals-mobile','margin-right','10',0,'3'),(60122,19081,'119750','deals-mobile','content','\\_',0,'4'),(60123,19081,'119750','deals-mobile','display','inline-block',0,'4'),(60124,19081,'119750','deals-mobile','width','70',0,'4'),(60125,19081,'119750','deals-mobile','height','5',0,'4'),(60126,19081,'119750','deals-mobile','border-top-width','1',0,'4'),(60127,19081,'119750','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60128,19081,'119750','deals-mobile','margin-left','10',0,'4'),(60129,19081,'119750','deals-mobile','margin-right','10',0,'4'),(60130,19081,'119750','deals-mobile','position','relative',0,''),(60131,19081,'119750','deals-mobile','top','-10',0,''),(60132,19082,'119751','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60133,19082,'119751','deals-mobile','font-size','26',0,''),(60134,19082,'119751','deals-mobile','font-family','Varela Round',0,''),(60135,19082,'119751','deals-mobile','padding-top','15',0,''),(60136,19082,'119751','deals-mobile','padding-bottom','15',0,''),(60137,19082,'119751','deals-mobile','text-align','center',0,''),(60138,19083,'119752','deals-mobile','text-align','center',0,''),(60139,19083,'119752','deals-mobile','hide_parents','2',0,''),(60140,19084,'119753','deals-mobile','block_type','1',0,''),(60141,19084,'119753','deals-mobile','padding-top','40',0,''),(60142,19084,'119753','deals-mobile','background-color','#eeeeee',0,''),(60143,19084,'119753','deals-mobile','padding-bottom','40',0,''),(60144,19085,'119754','deals-mobile','block_type','1',0,''),(60145,19085,'119754','deals-mobile','background-color','#ffffff',0,''),(60146,19085,'119754','deals-mobile','max-width','830',0,''),(60147,19085,'119754','deals-mobile','margin_left_measure','auto',0,''),(60148,19085,'119754','deals-mobile','margin_right_measure','auto',0,''),(60149,19085,'119754','deals-mobile','padding-top','40',0,''),(60150,19085,'119754','deals-mobile','padding-bottom','40',0,''),(60151,19085,'119754','deals-mobile','schema','2-3',0,''),(60152,19086,'119755','deals-mobile','text','##NEW_CUSTOMER##',0,''),(60153,19086,'119755','deals-mobile','font-size','18',0,''),(60154,19086,'119755','deals-mobile','font-family','Varela Round',0,''),(60155,19086,'119755','deals-mobile','text-align','center',0,''),(60156,19086,'119755','deals-mobile','text-transform','uppercase',0,''),(60157,19086,'119755','deals-mobile','margin-bottom','10',0,''),(60158,19087,'119756','deals-mobile','text-align','center',0,''),(60159,19087,'119756','deals-mobile','margin-bottom','40',0,''),(60160,19088,'119757','deals-mobile','text-align','center',0,''),(60161,19089,'119758','deals-mobile','text','##TEXT_OR##',0,''),(60162,19089,'119758','deals-mobile','font-size','18',0,''),(60163,19089,'119758','deals-mobile','font-weight','700',0,''),(60164,19089,'119758','deals-mobile','text-align','center',0,''),(60165,19089,'119758','deals-mobile','content','\\_',0,'3'),(60166,19089,'119758','deals-mobile','height','5',0,'3'),(60167,19089,'119758','deals-mobile','width','70',0,'3'),(60168,19089,'119758','deals-mobile','display','inline-block',0,'3'),(60169,19089,'119758','deals-mobile','border-top-width','1',0,'3'),(60170,19089,'119758','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60171,19089,'119758','deals-mobile','margin-left','10',0,'3'),(60172,19089,'119758','deals-mobile','margin-right','10',0,'3'),(60173,19089,'119758','deals-mobile','content','\\_',0,'4'),(60174,19089,'119758','deals-mobile','display','inline-block',0,'4'),(60175,19089,'119758','deals-mobile','width','70',0,'4'),(60176,19089,'119758','deals-mobile','height','5',0,'4'),(60177,19089,'119758','deals-mobile','border-top-width','1',0,'4'),(60178,19089,'119758','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60179,19089,'119758','deals-mobile','margin-left','10',0,'4'),(60180,19089,'119758','deals-mobile','margin-right','10',0,'4'),(60181,19089,'119758','deals-mobile','position','relative',0,''),(60182,19089,'119758','deals-mobile','padding-top','10',0,''),(60183,19089,'119758','deals-mobile','padding-bottom','10',0,''),(60184,19090,'119759','deals-mobile','block_type','1',0,''),(60185,19091,'119760','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60186,19091,'119760','deals-mobile','font-size','18',0,''),(60187,19091,'119760','deals-mobile','font-family','Varela Round',0,''),(60188,19091,'119760','deals-mobile','padding-top','15',0,''),(60189,19091,'119760','deals-mobile','padding-bottom','15',0,''),(60190,19091,'119760','deals-mobile','text-align','center',0,''),(60191,19091,'119760','deals-mobile','text-transform','uppercase',0,''),(60192,19092,'119761','deals-mobile','text-align','center',0,''),(60193,19092,'119761','deals-mobile','hide_parents','2',0,''),(60194,19093,'119762','deals-mobile','max-width','230',0,''),(60195,19093,'119762','deals-mobile','margin_left_measure','auto',0,''),(60196,19093,'119762','deals-mobile','margin_right_measure','auto',0,''),(60197,19094,'119763','deals-mobile','text','##RETURNING_CUSTOMER##',0,''),(60198,19094,'119763','deals-mobile','font-size','18',0,''),(60199,19094,'119763','deals-mobile','font-family','Varela Round',0,''),(60200,19094,'119763','deals-mobile','text-transform','uppercase',0,''),(60201,19094,'119763','deals-mobile','text-align','center',0,''),(60202,19095,'119764','deals-mobile','block_type','1',0,''),(60203,19095,'119764','deals-mobile','padding-top','20',0,''),(60204,19096,'119765','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60205,19096,'119765','deals-mobile','font-size','26',0,''),(60206,19096,'119765','deals-mobile','font-family','Varela Round',0,''),(60207,19096,'119765','deals-mobile','padding-top','15',0,''),(60208,19096,'119765','deals-mobile','padding-bottom','15',0,''),(60209,19096,'119765','deals-mobile','text-align','center',0,''),(60210,19097,'119766','deals-mobile','text','##TEXT_OR##',0,''),(60211,19097,'119766','deals-mobile','font-size','18',0,''),(60212,19097,'119766','deals-mobile','font-weight','700',0,''),(60213,19097,'119766','deals-mobile','padding-top','15',0,''),(60214,19097,'119766','deals-mobile','text-align','center',0,''),(60215,19097,'119766','deals-mobile','content','\\_',0,'3'),(60216,19097,'119766','deals-mobile','height','5',0,'3'),(60217,19097,'119766','deals-mobile','width','70',0,'3'),(60218,19097,'119766','deals-mobile','display','inline-block',0,'3'),(60219,19097,'119766','deals-mobile','border-top-width','1',0,'3'),(60220,19097,'119766','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60221,19097,'119766','deals-mobile','margin-left','10',0,'3'),(60222,19097,'119766','deals-mobile','margin-right','10',0,'3'),(60223,19097,'119766','deals-mobile','content','\\_',0,'4'),(60224,19097,'119766','deals-mobile','display','inline-block',0,'4'),(60225,19097,'119766','deals-mobile','width','70',0,'4'),(60226,19097,'119766','deals-mobile','height','5',0,'4'),(60227,19097,'119766','deals-mobile','border-top-width','1',0,'4'),(60228,19097,'119766','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60229,19097,'119766','deals-mobile','margin-left','10',0,'4'),(60230,19097,'119766','deals-mobile','margin-right','10',0,'4'),(60231,19097,'119766','deals-mobile','position','relative',0,''),(60232,19097,'119766','deals-mobile','top','-10',0,''),(60233,19098,'119767','deals-mobile','text-align','center',0,''),(60234,19099,'119768','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(60235,19099,'119768','deals-mobile','tab_2','RETURNING CUSTOMER',1,''),(60236,19099,'119768','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(60237,19100,'119769','deals-mobile','block_type','8',0,''),(60238,19101,'119770','deals-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(60239,19102,'119771','deals-mobile','block_type','1',0,''),(60240,19102,'119771','deals-mobile','padding-left','20',0,''),(60241,19102,'119771','deals-mobile','padding-right','20',0,''),(60242,19103,'119772','deals-mobile','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(60243,19103,'119772','deals-mobile','border-top-width','1',0,''),(60244,19103,'119772','deals-mobile','border-top-color','#e0e0e0',0,''),(60245,19106,'119775','deals-mobile','block_type','8',0,''),(60246,19107,'119776','deals-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(60247,19108,'119777','deals-mobile','block_type','1',0,''),(60248,19108,'119777','deals-mobile','padding-left','20',0,''),(60249,19108,'119777','deals-mobile','padding-right','20',0,''),(60250,19110,'119779','deals-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(60251,19111,'119780','deals-mobile','block_type','1',0,''),(60252,19111,'119780','deals-mobile','padding-top','20',0,''),(60253,19112,'119781','deals-mobile','text-align','center',0,''),(60254,19113,'119782','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60255,19113,'119782','deals-mobile','font-size','26',0,''),(60256,19113,'119782','deals-mobile','font-family','Varela Round',0,''),(60257,19113,'119782','deals-mobile','padding-top','15',0,''),(60258,19113,'119782','deals-mobile','padding-bottom','15',0,''),(60259,19113,'119782','deals-mobile','text-align','center',0,''),(60260,19114,'119783','deals-mobile','text','##TEXT_OR##',0,''),(60261,19114,'119783','deals-mobile','font-size','18',0,''),(60262,19114,'119783','deals-mobile','font-weight','700',0,''),(60263,19114,'119783','deals-mobile','padding-top','15',0,''),(60264,19114,'119783','deals-mobile','text-align','center',0,''),(60265,19114,'119783','deals-mobile','content','\\_',0,'3'),(60266,19114,'119783','deals-mobile','height','5',0,'3'),(60267,19114,'119783','deals-mobile','width','70',0,'3'),(60268,19114,'119783','deals-mobile','display','inline-block',0,'3'),(60269,19114,'119783','deals-mobile','border-top-width','1',0,'3'),(60270,19114,'119783','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60271,19114,'119783','deals-mobile','margin-left','10',0,'3'),(60272,19114,'119783','deals-mobile','margin-right','10',0,'3'),(60273,19114,'119783','deals-mobile','content','\\_',0,'4'),(60274,19114,'119783','deals-mobile','display','inline-block',0,'4'),(60275,19114,'119783','deals-mobile','width','70',0,'4'),(60276,19114,'119783','deals-mobile','height','5',0,'4'),(60277,19114,'119783','deals-mobile','border-top-width','1',0,'4'),(60278,19114,'119783','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60279,19114,'119783','deals-mobile','margin-left','10',0,'4'),(60280,19114,'119783','deals-mobile','margin-right','10',0,'4'),(60281,19114,'119783','deals-mobile','position','relative',0,''),(60282,19114,'119783','deals-mobile','top','-10',0,''),(60283,19115,'119784','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(60284,19115,'119784','deals-mobile','tab_2','RETURNING CUSTOMER',1,''),(60285,19115,'119784','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(60286,19116,'119785','deals-mobile','block_type','8',0,''),(60287,19117,'119786','deals-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(60288,19120,'119789','deals-mobile','block_type','8',0,''),(60289,19121,'119790','deals-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(60290,19123,'119792','deals-mobile','block_type','1',0,''),(60291,19123,'119792','deals-mobile','padding-left','20',0,''),(60292,19123,'119792','deals-mobile','padding-right','20',0,''),(60293,19124,'119793','deals-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(60294,19126,'119795','deals-mobile','block_type','1',0,''),(60295,19126,'119795','deals-mobile','padding-top','20',0,''),(60296,19127,'119796','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60297,19127,'119796','deals-mobile','font-size','26',0,''),(60298,19127,'119796','deals-mobile','font-family','Varela Round',0,''),(60299,19127,'119796','deals-mobile','padding-top','15',0,''),(60300,19127,'119796','deals-mobile','padding-bottom','15',0,''),(60301,19127,'119796','deals-mobile','text-align','center',0,''),(60302,19128,'119797','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(60303,19128,'119797','deals-mobile','tab_2','RETURNING CUSTOMER',1,''),(60304,19128,'119797','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(60305,19129,'119798','deals-mobile','block_type','8',0,''),(60306,19130,'119799','deals-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(60307,19133,'119802','deals-mobile','block_type','8',0,''),(60308,19134,'119803','deals-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(60309,19135,'119804','deals-mobile','block_type','1',0,''),(60310,19135,'119804','deals-mobile','padding-left','20',0,''),(60311,19135,'119804','deals-mobile','padding-right','20',0,''),(60312,19136,'119805','deals-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(60313,19138,'119807','deals-mobile','text-align','center',0,''),(60314,19139,'119808','deals-mobile','text','##TEXT_OR##',0,''),(60315,19139,'119808','deals-mobile','font-size','18',0,''),(60316,19139,'119808','deals-mobile','font-weight','700',0,''),(60317,19139,'119808','deals-mobile','padding-top','15',0,''),(60318,19139,'119808','deals-mobile','text-align','center',0,''),(60319,19139,'119808','deals-mobile','content','\\_',0,'3'),(60320,19139,'119808','deals-mobile','height','5',0,'3'),(60321,19139,'119808','deals-mobile','width','70',0,'3'),(60322,19139,'119808','deals-mobile','display','inline-block',0,'3'),(60323,19139,'119808','deals-mobile','border-top-width','1',0,'3'),(60324,19139,'119808','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60325,19139,'119808','deals-mobile','margin-left','10',0,'3'),(60326,19139,'119808','deals-mobile','margin-right','10',0,'3'),(60327,19139,'119808','deals-mobile','content','\\_',0,'4'),(60328,19139,'119808','deals-mobile','display','inline-block',0,'4'),(60329,19139,'119808','deals-mobile','width','70',0,'4'),(60330,19139,'119808','deals-mobile','height','5',0,'4'),(60331,19139,'119808','deals-mobile','border-top-width','1',0,'4'),(60332,19139,'119808','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60333,19139,'119808','deals-mobile','margin-left','10',0,'4'),(60334,19139,'119808','deals-mobile','margin-right','10',0,'4'),(60335,19139,'119808','deals-mobile','position','relative',0,''),(60336,19139,'119808','deals-mobile','top','-10',0,''),(60337,19140,'119809','deals-mobile','block_type','1',0,''),(60338,19140,'119809','deals-mobile','padding-top','40',0,''),(60339,19140,'119809','deals-mobile','background-color','#eeeeee',0,''),(60340,19140,'119809','deals-mobile','padding-bottom','40',0,''),(60341,19141,'119810','deals-mobile','block_type','2',0,''),(60342,19141,'119810','deals-mobile','background-color','#ffffff',0,''),(60343,19141,'119810','deals-mobile','max-width','830',0,''),(60344,19141,'119810','deals-mobile','margin_left_measure','auto',0,''),(60345,19141,'119810','deals-mobile','margin_right_measure','auto',0,''),(60346,19141,'119810','deals-mobile','padding-top','40',0,''),(60347,19141,'119810','deals-mobile','padding-bottom','40',0,''),(60348,19142,'119811','deals-mobile','text-align','center',0,''),(60349,19142,'119811','deals-mobile','margin-bottom','40',0,''),(60350,19143,'119812','deals-mobile','text-align','center',0,''),(60351,19144,'119813','deals-mobile','text','##NEW_CUSTOMER##',0,''),(60352,19144,'119813','deals-mobile','font-size','18',0,''),(60353,19144,'119813','deals-mobile','font-family','Varela Round',0,''),(60354,19144,'119813','deals-mobile','text-align','center',0,''),(60355,19144,'119813','deals-mobile','text-transform','uppercase',0,''),(60356,19144,'119813','deals-mobile','margin-bottom','10',0,''),(60357,19145,'119814','deals-mobile','text','##TEXT_OR##',0,''),(60358,19145,'119814','deals-mobile','font-size','18',0,''),(60359,19145,'119814','deals-mobile','font-weight','700',0,''),(60360,19145,'119814','deals-mobile','text-align','center',0,''),(60361,19145,'119814','deals-mobile','content','\\_',0,'3'),(60362,19145,'119814','deals-mobile','height','5',0,'3'),(60363,19145,'119814','deals-mobile','width','70',0,'3'),(60364,19145,'119814','deals-mobile','display','inline-block',0,'3'),(60365,19145,'119814','deals-mobile','border-top-width','1',0,'3'),(60366,19145,'119814','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60367,19145,'119814','deals-mobile','margin-left','10',0,'3'),(60368,19145,'119814','deals-mobile','margin-right','10',0,'3'),(60369,19145,'119814','deals-mobile','content','\\_',0,'4'),(60370,19145,'119814','deals-mobile','display','inline-block',0,'4'),(60371,19145,'119814','deals-mobile','width','70',0,'4'),(60372,19145,'119814','deals-mobile','height','5',0,'4'),(60373,19145,'119814','deals-mobile','border-top-width','1',0,'4'),(60374,19145,'119814','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60375,19145,'119814','deals-mobile','margin-left','10',0,'4'),(60376,19145,'119814','deals-mobile','margin-right','10',0,'4'),(60377,19145,'119814','deals-mobile','position','relative',0,''),(60378,19145,'119814','deals-mobile','padding-top','10',0,''),(60379,19145,'119814','deals-mobile','padding-bottom','10',0,''),(60380,19146,'119815','deals-mobile','block_type','1',0,''),(60381,19147,'119816','deals-mobile','text-align','center',0,''),(60382,19147,'119816','deals-mobile','hide_parents','2',0,''),(60383,19148,'119817','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60384,19148,'119817','deals-mobile','font-size','18',0,''),(60385,19148,'119817','deals-mobile','font-family','Varela Round',0,''),(60386,19148,'119817','deals-mobile','padding-top','15',0,''),(60387,19148,'119817','deals-mobile','padding-bottom','15',0,''),(60388,19148,'119817','deals-mobile','text-align','center',0,''),(60389,19148,'119817','deals-mobile','text-transform','uppercase',0,''),(60390,19149,'119818','deals-mobile','max-width','230',0,''),(60391,19149,'119818','deals-mobile','margin_left_measure','auto',0,''),(60392,19149,'119818','deals-mobile','margin_right_measure','auto',0,''),(60393,19150,'119819','deals-mobile','text','##RETURNING_CUSTOMER##',0,''),(60394,19150,'119819','deals-mobile','font-size','18',0,''),(60395,19150,'119819','deals-mobile','font-family','Varela Round',0,''),(60396,19150,'119819','deals-mobile','text-transform','uppercase',0,''),(60397,19150,'119819','deals-mobile','text-align','center',0,''),(60398,19151,'119820','deals-mobile','block_type','1',0,''),(60399,19151,'119820','deals-mobile','padding-top','40',0,''),(60400,19151,'119820','deals-mobile','background-color','#eeeeee',0,''),(60401,19151,'119820','deals-mobile','padding-bottom','40',0,''),(60402,19152,'119821','deals-mobile','block_type','2',0,''),(60403,19152,'119821','deals-mobile','background-color','#ffffff',0,''),(60404,19152,'119821','deals-mobile','max-width','830',0,''),(60405,19152,'119821','deals-mobile','margin_left_measure','auto',0,''),(60406,19152,'119821','deals-mobile','margin_right_measure','auto',0,''),(60407,19152,'119821','deals-mobile','padding-top','40',0,''),(60408,19152,'119821','deals-mobile','padding-bottom','40',0,''),(60409,19153,'119822','deals-mobile','block_type','1',0,''),(60410,19154,'119823','deals-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(60411,19154,'119823','deals-mobile','font-size','18',0,''),(60412,19154,'119823','deals-mobile','font-family','Varela Round',0,''),(60413,19154,'119823','deals-mobile','padding-top','15',0,''),(60414,19154,'119823','deals-mobile','padding-bottom','15',0,''),(60415,19154,'119823','deals-mobile','text-align','center',0,''),(60416,19154,'119823','deals-mobile','text-transform','uppercase',0,''),(60417,19155,'119824','deals-mobile','text-align','center',0,''),(60418,19155,'119824','deals-mobile','hide_parents','2',0,''),(60419,19156,'119825','deals-mobile','text','##TEXT_OR##',0,''),(60420,19156,'119825','deals-mobile','font-size','18',0,''),(60421,19156,'119825','deals-mobile','font-weight','700',0,''),(60422,19156,'119825','deals-mobile','text-align','center',0,''),(60423,19156,'119825','deals-mobile','content','\\_',0,'3'),(60424,19156,'119825','deals-mobile','height','5',0,'3'),(60425,19156,'119825','deals-mobile','width','70',0,'3'),(60426,19156,'119825','deals-mobile','display','inline-block',0,'3'),(60427,19156,'119825','deals-mobile','border-top-width','1',0,'3'),(60428,19156,'119825','deals-mobile','border-top-color','#e0e0e0',0,'3'),(60429,19156,'119825','deals-mobile','margin-left','10',0,'3'),(60430,19156,'119825','deals-mobile','margin-right','10',0,'3'),(60431,19156,'119825','deals-mobile','content','\\_',0,'4'),(60432,19156,'119825','deals-mobile','display','inline-block',0,'4'),(60433,19156,'119825','deals-mobile','width','70',0,'4'),(60434,19156,'119825','deals-mobile','height','5',0,'4'),(60435,19156,'119825','deals-mobile','border-top-width','1',0,'4'),(60436,19156,'119825','deals-mobile','border-top-color','#e0e0e0',0,'4'),(60437,19156,'119825','deals-mobile','margin-left','10',0,'4'),(60438,19156,'119825','deals-mobile','margin-right','10',0,'4'),(60439,19156,'119825','deals-mobile','position','relative',0,''),(60440,19156,'119825','deals-mobile','padding-top','10',0,''),(60441,19156,'119825','deals-mobile','padding-bottom','10',0,''),(60442,19157,'119826','deals-mobile','text-align','center',0,''),(60443,19157,'119826','deals-mobile','margin-bottom','40',0,''),(60444,19158,'119827','deals-mobile','text','##NEW_CUSTOMER##',0,''),(60445,19158,'119827','deals-mobile','font-size','18',0,''),(60446,19158,'119827','deals-mobile','font-family','Varela Round',0,''),(60447,19158,'119827','deals-mobile','text-align','center',0,''),(60448,19158,'119827','deals-mobile','text-transform','uppercase',0,''),(60449,19158,'119827','deals-mobile','margin-bottom','10',0,''),(60450,19159,'119828','deals-mobile','text-align','center',0,''),(60451,19160,'119829','deals-mobile','text','##RETURNING_CUSTOMER##',0,''),(60452,19160,'119829','deals-mobile','font-size','18',0,''),(60453,19160,'119829','deals-mobile','font-family','Varela Round',0,''),(60454,19160,'119829','deals-mobile','text-transform','uppercase',0,''),(60455,19160,'119829','deals-mobile','text-align','center',0,''),(60456,19161,'119830','deals-mobile','max-width','230',0,''),(60457,19161,'119830','deals-mobile','margin_left_measure','auto',0,''),(60458,19161,'119830','deals-mobile','margin_right_measure','auto',0,''),(60459,19162,'119831','deals-mobile','block_type','1',0,''),(60460,19163,'119832','deals-mobile','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(60461,19163,'119832','deals-mobile','margin-bottom','30',0,''),(60462,19164,'119833','deals-mobile','block_type','1',0,''),(60463,19165,'119834','deals-mobile','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(60464,19165,'119834','deals-mobile','margin-bottom','30',0,''),(60465,19166,'119835','deals-mobile','block_type','1',0,''),(60466,19166,'119835','deals-mobile','font-weight','normal',0,''),(60467,19168,'119837','deals-mobile','box_align','4',0,''),(60468,19168,'119837','deals-mobile','margin-bottom','30',0,''),(60469,19169,'119838','deals-mobile','tab_1','New products',1,''),(60470,19169,'119838','deals-mobile','tab_2','Specials products',1,''),(60471,19169,'119838','deals-mobile','font-weight','normal',0,''),(60472,19169,'119838','deals-mobile','tab_3','Featured',1,''),(60473,19169,'119838','deals-mobile','accordion','1',0,'863'),(60474,19170,'119839','deals-mobile','font-weight','400',0,''),(60475,19170,'119839','deals-mobile','listing_type','productListing',0,''),(60476,19170,'119839','deals-mobile','show_compare','1',0,''),(60477,19170,'119839','deals-mobile','show_model','1',0,''),(60478,19170,'119839','deals-mobile','show_properties','1',0,''),(60479,19170,'119839','deals-mobile','col_in_row','2',0,''),(60480,19170,'119839','deals-mobile','show_name','0',0,''),(60481,19170,'119839','deals-mobile','show_image','0',0,''),(60482,19170,'119839','deals-mobile','show_stock','0',0,''),(60483,19170,'119839','deals-mobile','show_description','0',0,''),(60484,19170,'119839','deals-mobile','show_rating','0',0,''),(60485,19170,'119839','deals-mobile','show_rating_counts','0',0,''),(60486,19170,'119839','deals-mobile','show_price','0',0,''),(60487,19170,'119839','deals-mobile','show_buy_button','0',0,''),(60488,19170,'119839','deals-mobile','show_qty_input','0',0,''),(60489,19170,'119839','deals-mobile','show_view_button','0',0,''),(60490,19170,'119839','deals-mobile','show_wishlist_button','0',0,''),(60491,19170,'119839','deals-mobile','col_in_row','2',0,'864'),(60492,19170,'119839','deals-mobile','col_in_row','1',0,'888'),(60493,19170,'119839','deals-mobile','view_as','carousel',0,''),(60494,19170,'119839','deals-mobile','col_in_row','3',0,'872'),(60495,19171,'119840','deals-mobile','font-weight','400',0,''),(60496,19171,'119840','deals-mobile','show_compare','1',0,''),(60497,19171,'119840','deals-mobile','listing_type','productListing',0,''),(60498,19171,'119840','deals-mobile','show_model','1',0,''),(60499,19171,'119840','deals-mobile','show_properties','1',0,''),(60500,19171,'119840','deals-mobile','col_in_row','2',0,''),(60501,19171,'119840','deals-mobile','show_name','0',0,''),(60502,19171,'119840','deals-mobile','show_image','0',0,''),(60503,19171,'119840','deals-mobile','show_stock','0',0,''),(60504,19171,'119840','deals-mobile','show_description','0',0,''),(60505,19171,'119840','deals-mobile','show_rating','0',0,''),(60506,19171,'119840','deals-mobile','show_rating_counts','0',0,''),(60507,19171,'119840','deals-mobile','show_price','0',0,''),(60508,19171,'119840','deals-mobile','show_buy_button','0',0,''),(60509,19171,'119840','deals-mobile','show_qty_input','0',0,''),(60510,19171,'119840','deals-mobile','show_view_button','0',0,''),(60511,19171,'119840','deals-mobile','show_wishlist_button','0',0,''),(60512,19171,'119840','deals-mobile','col_in_row','2',0,'864'),(60513,19171,'119840','deals-mobile','col_in_row','1',0,'888'),(60514,19171,'119840','deals-mobile','view_as','carousel',0,''),(60515,19171,'119840','deals-mobile','col_in_row','3',0,'872'),(60516,19171,'119840','deals-mobile','product_names_teg','h2',0,''),(60517,19172,'119841','deals-mobile','font-weight','400',0,''),(60518,19172,'119841','deals-mobile','show_compare','1',0,''),(60519,19172,'119841','deals-mobile','listing_type','productListing',0,''),(60520,19172,'119841','deals-mobile','show_model','1',0,''),(60521,19172,'119841','deals-mobile','show_properties','1',0,''),(60522,19172,'119841','deals-mobile','col_in_row','2',0,''),(60523,19172,'119841','deals-mobile','show_name','0',0,''),(60524,19172,'119841','deals-mobile','show_image','0',0,''),(60525,19172,'119841','deals-mobile','show_stock','0',0,''),(60526,19172,'119841','deals-mobile','show_description','0',0,''),(60527,19172,'119841','deals-mobile','show_rating','0',0,''),(60528,19172,'119841','deals-mobile','show_rating_counts','0',0,''),(60529,19172,'119841','deals-mobile','show_price','0',0,''),(60530,19172,'119841','deals-mobile','show_buy_button','0',0,''),(60531,19172,'119841','deals-mobile','show_qty_input','0',0,''),(60532,19172,'119841','deals-mobile','show_view_button','0',0,''),(60533,19172,'119841','deals-mobile','show_wishlist_button','0',0,''),(60534,19172,'119841','deals-mobile','col_in_row','2',0,'864'),(60535,19172,'119841','deals-mobile','col_in_row','1',0,'888'),(60536,19172,'119841','deals-mobile','view_as','carousel',0,''),(60537,19172,'119841','deals-mobile','col_in_row','3',0,'872'),(60538,19173,'119842','deals-mobile','heading_type','h1',0,''),(60539,19174,'119843','deals-mobile','block_type','1',0,''),(60540,19174,'119843','deals-mobile','background-color','#eeeeee',0,''),(60541,19174,'119843','deals-mobile','padding-top','20',0,''),(60542,19174,'119843','deals-mobile','padding-bottom','20',0,''),(60543,19174,'119843','deals-mobile','font-weight','400',0,''),(60544,19174,'119843','deals-mobile','visibility_product','1',0,''),(60545,19174,'119843','deals-mobile','visibility_catalog','1',0,''),(60546,19174,'119843','deals-mobile','visibility_info','1',0,''),(60547,19174,'119843','deals-mobile','visibility_cart','1',0,''),(60548,19174,'119843','deals-mobile','visibility_checkout','1',0,''),(60549,19174,'119843','deals-mobile','visibility_success','1',0,''),(60550,19174,'119843','deals-mobile','visibility_account','1',0,''),(60551,19174,'119843','deals-mobile','visibility_login','1',0,''),(60552,19174,'119843','deals-mobile','visibility_other','1',0,''),(60553,19174,'119843','deals-mobile','margin-bottom','20',0,''),(60554,19174,'119843','deals-mobile','display_none','on',0,'864'),(60555,19175,'119844','deals-mobile','block_type','2',0,''),(60556,19175,'119844','deals-mobile','font-weight','normal',0,''),(60557,19176,'119845','deals-mobile','font-weight','400',0,''),(60558,19176,'119845','deals-mobile','visibility_product','1',0,''),(60559,19176,'119845','deals-mobile','show_name','0',0,''),(60560,19176,'119845','deals-mobile','show_image','1',0,''),(60561,19176,'119845','deals-mobile','show_stock','1',0,''),(60562,19176,'119845','deals-mobile','show_description','1',0,''),(60563,19176,'119845','deals-mobile','show_model','1',0,''),(60564,19176,'119845','deals-mobile','show_rating','1',0,''),(60565,19176,'119845','deals-mobile','show_rating_counts','1',0,''),(60566,19176,'119845','deals-mobile','show_price','1',0,''),(60567,19176,'119845','deals-mobile','show_buy_button','1',0,''),(60568,19176,'119845','deals-mobile','show_qty_input','1',0,''),(60569,19176,'119845','deals-mobile','show_view_button','1',0,''),(60570,19176,'119845','deals-mobile','show_wishlist_button','1',0,''),(60571,19176,'119845','deals-mobile','show_compare','1',0,''),(60572,19176,'119845','deals-mobile','listing_type','type-1',0,''),(60573,19176,'119845','deals-mobile','show_properties','1',0,''),(60574,19177,'119846','deals-mobile','font-weight','normal',0,''),(60575,19177,'119846','deals-mobile','visibility_product','1',0,''),(60576,19178,'119847','deals-mobile','block_type','1',0,''),(60577,19179,'119848','deals-mobile','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(60578,19181,'119850','deals-mobile','block_type','1',0,''),(60579,19181,'119850','deals-mobile','padding-top','40',0,''),(60580,19181,'119850','deals-mobile','padding-bottom','80',0,''),(60581,19182,'119851','deals-mobile','block_type','6',0,''),(60582,19183,'119852','deals-mobile','block_type','1',0,''),(60583,19183,'119852','deals-mobile','padding-top','20',0,''),(60584,19183,'119852','deals-mobile','padding-left','20',0,''),(60585,19183,'119852','deals-mobile','padding-right','20',0,''),(60586,19183,'119852','deals-mobile','padding-bottom','20',0,''),(60587,19183,'119852','deals-mobile','border-top-width','1',0,''),(60588,19183,'119852','deals-mobile','border-left-width','1',0,''),(60589,19183,'119852','deals-mobile','border-right-width','1',0,''),(60590,19183,'119852','deals-mobile','border-bottom-width','1',0,''),(60591,19183,'119852','deals-mobile','border-top-color','#e0e0e0',0,''),(60592,19183,'119852','deals-mobile','border-left-color','#e0e0e0',0,''),(60593,19183,'119852','deals-mobile','border-right-color','#e0e0e0',0,''),(60594,19183,'119852','deals-mobile','border-bottom-color','#e0e0e0',0,''),(60595,19183,'119852','deals-mobile','margin-right','20',0,''),(60596,19186,'119855','deals-mobile','block_type','1',0,''),(60597,19186,'119855','deals-mobile','padding-top','20',0,''),(60598,19187,'119856','deals-mobile','block_type','6',0,''),(60599,19188,'119857','deals-mobile','padding-right','20',0,''),(60600,19190,'119859','deals-mobile','block_type','1',0,''),(60601,19190,'119859','deals-mobile','padding-top','20',0,''),(60602,19191,'119860','deals-mobile','block_type','6',0,''),(60603,19192,'119861','deals-mobile','padding-right','20',0,''),(60604,19194,'119863','deals-mobile','block_type','1',0,''),(60605,19195,'119864','deals-mobile','block_type','6',0,''),(60606,19195,'119864','deals-mobile','schema','6-3',0,''),(60607,19195,'119864','deals-mobile','schema','6-3',0,'872'),(60608,19196,'119865','deals-mobile','aria_name','account-menu',0,''),(60609,19198,'119867','deals-mobile','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(60610,19199,'119868','deals-mobile','text','CANCEL',0,''),(60611,19199,'119868','deals-mobile','like_button','1',0,''),(60612,19199,'119868','deals-mobile','padding-bottom','20',0,''),(60613,19200,'119869','deals-mobile','block_type','1',0,''),(60614,19200,'119869','deals-mobile','padding-top','20',0,''),(60615,19201,'119870','deals-mobile','block_type','1',0,''),(60616,19202,'119871','deals-mobile','tab_1','RETURNING CUSTOMER',1,''),(60617,19202,'119871','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(60618,19204,'119873','deals-mobile','block_type','8',0,''),(60619,19205,'119874','deals-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(60620,19206,'119875','deals-mobile','block_type','1',0,''),(60621,19206,'119875','deals-mobile','padding-left','20',0,''),(60622,19206,'119875','deals-mobile','padding-right','20',0,''),(60623,19208,'119877','deals-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(60624,19209,'119878','deals-mobile','block_type','1',0,''),(60625,19210,'119879','deals-mobile','margin-bottom','30',0,''),(60626,19211,'119880','deals-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(60627,19212,'119881','deals-mobile','margin_left_measure','auto',0,''),(60628,19212,'119881','deals-mobile','margin_right_measure','auto',0,''),(60629,19212,'119881','deals-mobile','max-width','560',0,''),(60630,19213,'119882','deals-mobile','block_type','1',0,''),(60631,19215,'119884','deals-mobile','block_type','6',0,''),(60632,19215,'119884','deals-mobile','font-weight','400',0,''),(60633,19215,'119884','deals-mobile','schema','6-2',0,''),(60635,19216,'119885','deals-mobile','font-weight','400',0,''),(60636,19216,'119885','deals-mobile','padding-right','40',0,''),(60639,19217,'119886','deals-mobile','col_in_row','3',0,''),(60640,19217,'119886','deals-mobile','products_align','left',0,''),(60641,19217,'119886','deals-mobile','font-weight','400',0,''),(60642,19217,'119886','deals-mobile','show_qty_input','0',0,''),(60643,19217,'119886','deals-mobile','listing_type','productListing',0,''),(60644,19217,'119886','deals-mobile','listing_type_rows','no',0,''),(60645,19217,'119886','deals-mobile','show_buy_button_b2b','on',0,''),(60646,19217,'119886','deals-mobile','show_wishlist_button_b2b','1',0,''),(60647,19217,'119886','deals-mobile','show_compare_b2b','1',0,''),(60648,19217,'119886','deals-mobile','show_stock','0',0,''),(60649,19217,'119886','deals-mobile','show_description','0',0,''),(60650,19217,'119886','deals-mobile','show_model','0',0,''),(60651,19217,'119886','deals-mobile','show_properties','0',0,''),(60652,19217,'119886','deals-mobile','show_rating','0',0,''),(60653,19217,'119886','deals-mobile','show_rating_counts','0',0,''),(60654,19217,'119886','deals-mobile','show_price','0',0,''),(60655,19217,'119886','deals-mobile','show_buy_button','0',0,''),(60656,19217,'119886','deals-mobile','show_view_button','0',0,''),(60657,19217,'119886','deals-mobile','show_wishlist_button','0',0,''),(60658,19217,'119886','deals-mobile','show_compare','0',0,''),(60659,19217,'119886','deals-mobile','show_name_rows','0',0,''),(60660,19217,'119886','deals-mobile','show_image_rows','0',0,''),(60661,19217,'119886','deals-mobile','show_stock_rows','0',0,''),(60662,19217,'119886','deals-mobile','show_description_rows','0',0,''),(60663,19217,'119886','deals-mobile','show_model_rows','0',0,''),(60664,19217,'119886','deals-mobile','show_properties_rows','0',0,''),(60665,19217,'119886','deals-mobile','show_rating_rows','0',0,''),(60666,19217,'119886','deals-mobile','show_rating_counts_rows','0',0,''),(60667,19217,'119886','deals-mobile','show_price_rows','0',0,''),(60668,19217,'119886','deals-mobile','show_buy_button_rows','0',0,''),(60669,19217,'119886','deals-mobile','show_qty_input_rows','0',0,''),(60670,19217,'119886','deals-mobile','show_view_button_rows','0',0,''),(60671,19217,'119886','deals-mobile','show_wishlist_button_rows','0',0,''),(60672,19217,'119886','deals-mobile','show_compare_rows','0',0,''),(60673,19217,'119886','deals-mobile','show_name_b2b','0',0,''),(60674,19217,'119886','deals-mobile','show_image_b2b','0',0,''),(60675,19217,'119886','deals-mobile','show_stock_b2b','0',0,''),(60676,19217,'119886','deals-mobile','show_description_b2b','0',0,''),(60677,19217,'119886','deals-mobile','show_model_b2b','0',0,''),(60678,19217,'119886','deals-mobile','show_properties_b2b','0',0,''),(60679,19217,'119886','deals-mobile','show_rating_b2b','0',0,''),(60680,19217,'119886','deals-mobile','show_rating_counts_b2b','0',0,''),(60681,19217,'119886','deals-mobile','show_price_b2b','0',0,''),(60682,19217,'119886','deals-mobile','show_qty_input_b2b','0',0,''),(60683,19217,'119886','deals-mobile','show_view_button_b2b','0',0,''),(60684,19217,'119886','deals-mobile','show_attributes_b2b','0',0,''),(60685,19217,'119886','deals-mobile','items_on_page','9',0,''),(60688,19217,'119886','deals-mobile','product_names_teg','h2',0,''),(60689,19219,'119888','deals-mobile','block_type','5',0,''),(60690,19219,'119888','deals-mobile','padding-top','10',0,''),(60691,19219,'119888','deals-mobile','padding-bottom','10',0,''),(60692,19219,'119888','deals-mobile','schema','5-2',0,''),(60693,19219,'119888','deals-mobile','border-top-color','#e0e0e0',0,''),(60694,19219,'119888','deals-mobile','border-top-width','1',0,''),(60695,19221,'119890','deals-mobile','float','right',0,''),(60696,19222,'119891','deals-mobile','listing_type','productListing',0,''),(60697,19224,'119893','deals-mobile','block_type','1',0,''),(60698,19224,'119893','deals-mobile','padding-top','10',0,''),(60699,19224,'119893','deals-mobile','padding-bottom','10',0,''),(60700,19224,'119893','deals-mobile','border-bottom-width','1',0,''),(60701,19224,'119893','deals-mobile','border-bottom-color','#e0e0e0',0,''),(60702,19224,'119893','deals-mobile','margin-left','0',0,''),(60703,19224,'119893','deals-mobile','margin-right','0',0,''),(60704,19225,'119894','deals-mobile','float','right',0,''),(60705,19225,'119894','deals-mobile','display','none',0,''),(60706,19226,'119895','deals-mobile','float','left',0,''),(60707,19226,'119895','deals-mobile','clear','none',0,''),(60708,19226,'119895','deals-mobile','margin-left','20',0,''),(60709,19226,'119895','deals-mobile','display','none',0,''),(60710,19227,'119896','deals-mobile','margin-right','20',0,''),(60711,19227,'119896','deals-mobile','float','right',0,''),(60712,19227,'119896','deals-mobile','clear','none',0,''),(60713,19227,'119896','deals-mobile','display','none',0,''),(60714,19228,'119897','deals-mobile','float','left',0,''),(60715,19228,'119897','deals-mobile','clear','none',0,''),(60716,19228,'119897','deals-mobile','sort_pos_3','1',0,''),(60717,19228,'119897','deals-mobile','sort_pos_4','2',0,''),(60718,19228,'119897','deals-mobile','sort_pos_10','3',0,''),(60719,19228,'119897','deals-mobile','sort_pos_9','4',0,''),(60720,19228,'119897','deals-mobile','sort_pos_11','5',0,''),(60721,19228,'119897','deals-mobile','sort_pos_12','6',0,''),(60722,19228,'119897','deals-mobile','sort_pos_14','7',0,''),(60723,19228,'119897','deals-mobile','sort_pos_13','8',0,''),(60724,19228,'119897','deals-mobile','sort_pos_8','9',0,''),(60725,19228,'119897','deals-mobile','sort_pos_7','10',0,''),(60726,19228,'119897','deals-mobile','sort_pos_2','11',0,''),(60727,19228,'119897','deals-mobile','sort_pos_1','12',0,''),(60728,19228,'119897','deals-mobile','sort_pos_6','13',0,''),(60729,19228,'119897','deals-mobile','sort_pos_5','14',0,''),(60730,19228,'119897','deals-mobile','sort_pos_0','15',0,''),(60731,19228,'119897','deals-mobile','sort_hide_10','1',0,''),(60732,19228,'119897','deals-mobile','sort_hide_9','1',0,''),(60733,19228,'119897','deals-mobile','hide_icons','1',0,''),(60734,19228,'119897','deals-mobile','sort_hide_16','1',0,''),(60735,19228,'119897','deals-mobile','sort_hide_15','1',0,''),(60736,19228,'119897','deals-mobile','sort_hide_3','0',0,''),(60737,19228,'119897','deals-mobile','sort_hide_4','0',0,''),(60738,19228,'119897','deals-mobile','sort_hide_11','1',0,''),(60739,19228,'119897','deals-mobile','sort_hide_12','1',0,''),(60740,19228,'119897','deals-mobile','sort_hide_14','1',0,''),(60741,19228,'119897','deals-mobile','sort_hide_13','1',0,''),(60742,19228,'119897','deals-mobile','sort_hide_8','0',0,''),(60743,19228,'119897','deals-mobile','sort_hide_7','0',0,''),(60744,19228,'119897','deals-mobile','sort_hide_2','1',0,''),(60745,19228,'119897','deals-mobile','sort_hide_1','1',0,''),(60746,19228,'119897','deals-mobile','sort_hide_6','1',0,''),(60747,19228,'119897','deals-mobile','sort_hide_5','1',0,''),(60748,19228,'119897','deals-mobile','sort_hide_0','1',0,''),(60749,19229,'119898','deals-mobile','block_type','1',0,''),(60750,19230,'119899','deals-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(60751,19231,'119900','deals-mobile','margin-bottom','30',0,''),(60752,19232,'119901','deals-mobile','block_type','1',0,''),(60753,19233,'119902','deals-mobile','block_type','1',0,''),(60754,19234,'119903','deals-mobile','margin-bottom','20',0,''),(60755,19235,'119904','deals-mobile','block_type','1',0,''),(60756,19235,'119904','deals-mobile','padding-top','10',0,''),(60757,19235,'119904','deals-mobile','padding-bottom','10',0,''),(60758,19235,'119904','deals-mobile','border-bottom-width','1',0,''),(60759,19235,'119904','deals-mobile','border-bottom-color','#e0e0e0',0,''),(60760,19235,'119904','deals-mobile','margin-left','0',0,''),(60761,19235,'119904','deals-mobile','margin-right','0',0,''),(60762,19236,'119905','deals-mobile','float','left',0,''),(60763,19236,'119905','deals-mobile','clear','none',0,''),(60764,19236,'119905','deals-mobile','sort_pos_3','2',0,''),(60765,19236,'119905','deals-mobile','sort_pos_4','1',0,''),(60766,19236,'119905','deals-mobile','sort_pos_10','5',0,''),(60767,19236,'119905','deals-mobile','sort_pos_9','6',0,''),(60768,19236,'119905','deals-mobile','sort_pos_11','7',0,''),(60769,19236,'119905','deals-mobile','sort_pos_12','8',0,''),(60770,19236,'119905','deals-mobile','sort_pos_14','9',0,''),(60771,19236,'119905','deals-mobile','sort_pos_13','10',0,''),(60772,19236,'119905','deals-mobile','sort_pos_8','11',0,''),(60773,19236,'119905','deals-mobile','sort_pos_7','12',0,''),(60774,19236,'119905','deals-mobile','sort_pos_2','13',0,''),(60775,19236,'119905','deals-mobile','sort_pos_1','14',0,''),(60776,19236,'119905','deals-mobile','sort_pos_6','15',0,''),(60777,19236,'119905','deals-mobile','sort_pos_5','16',0,''),(60778,19236,'119905','deals-mobile','sort_pos_0','17',0,''),(60779,19236,'119905','deals-mobile','sort_hide_10','1',0,''),(60780,19236,'119905','deals-mobile','sort_hide_9','1',0,''),(60781,19236,'119905','deals-mobile','sort_pos_15','4',0,''),(60782,19236,'119905','deals-mobile','sort_pos_16','3',0,''),(60783,19236,'119905','deals-mobile','sort_hide_4','0',0,''),(60784,19236,'119905','deals-mobile','sort_hide_3','0',0,''),(60785,19236,'119905','deals-mobile','sort_hide_16','1',0,''),(60786,19236,'119905','deals-mobile','sort_hide_15','1',0,''),(60787,19236,'119905','deals-mobile','sort_hide_11','1',0,''),(60788,19236,'119905','deals-mobile','sort_hide_12','1',0,''),(60789,19236,'119905','deals-mobile','sort_hide_14','1',0,''),(60790,19236,'119905','deals-mobile','sort_hide_13','1',0,''),(60791,19236,'119905','deals-mobile','sort_hide_8','0',0,''),(60792,19236,'119905','deals-mobile','sort_hide_7','0',0,''),(60793,19236,'119905','deals-mobile','sort_hide_2','1',0,''),(60794,19236,'119905','deals-mobile','sort_hide_1','1',0,''),(60795,19236,'119905','deals-mobile','sort_hide_6','1',0,''),(60796,19236,'119905','deals-mobile','sort_hide_5','1',0,''),(60797,19236,'119905','deals-mobile','sort_hide_0','1',0,''),(60798,19236,'119905','deals-mobile','hide_icons','1',0,''),(60799,19237,'119906','deals-mobile','float','left',0,''),(60800,19237,'119906','deals-mobile','clear','none',0,''),(60801,19237,'119906','deals-mobile','margin-left','20',0,''),(60802,19237,'119906','deals-mobile','display','none',0,''),(60803,19238,'119907','deals-mobile','clear','none',0,''),(60804,19238,'119907','deals-mobile','float','left',0,''),(60805,19238,'119907','deals-mobile','padding-top','3',0,''),(60806,19238,'119907','deals-mobile','margin-left','20',0,''),(60807,19239,'119908','deals-mobile','margin-right','20',0,''),(60808,19239,'119908','deals-mobile','float','right',0,''),(60809,19239,'119908','deals-mobile','clear','none',0,''),(60810,19239,'119908','deals-mobile','display','none',0,''),(60811,19240,'119909','deals-mobile','float','right',0,''),(60812,19240,'119909','deals-mobile','display','none',0,''),(60813,19241,'119910','deals-mobile','block_type','5',0,''),(60814,19241,'119910','deals-mobile','padding-top','10',0,''),(60815,19241,'119910','deals-mobile','padding-bottom','10',0,''),(60816,19241,'119910','deals-mobile','schema','5-2',0,''),(60817,19241,'119910','deals-mobile','border-top-color','#e0e0e0',0,''),(60818,19241,'119910','deals-mobile','border-top-width','1',0,''),(60819,19242,'119911','deals-mobile','padding-top','3',0,''),(60820,19243,'119912','deals-mobile','float','right',0,''),(60821,19243,'119912','deals-mobile','height','31',0,''),(60822,19246,'119915','deals-mobile','col_in_row','4',0,''),(60823,19246,'119915','deals-mobile','products_align','left',0,''),(60824,19246,'119915','deals-mobile','font-weight','400',0,''),(60825,19246,'119915','deals-mobile','listing_type','productListing',0,''),(60826,19246,'119915','deals-mobile','listing_type_rows','Rows',0,''),(60827,19246,'119915','deals-mobile','show_buy_button_b2b','on',0,''),(60828,19246,'119915','deals-mobile','show_wishlist_button_b2b','1',0,''),(60829,19246,'119915','deals-mobile','show_compare_b2b','1',0,''),(60830,19246,'119915','deals-mobile','listing_type_b2b','b2b',0,''),(60831,19246,'119915','deals-mobile','show_image','0',0,''),(60832,19246,'119915','deals-mobile','show_stock','0',0,''),(60833,19246,'119915','deals-mobile','show_description','0',0,''),(60834,19246,'119915','deals-mobile','show_model','0',0,''),(60835,19246,'119915','deals-mobile','show_properties','0',0,''),(60836,19246,'119915','deals-mobile','show_rating','0',0,''),(60837,19246,'119915','deals-mobile','show_rating_counts','0',0,''),(60838,19246,'119915','deals-mobile','show_price','0',0,''),(60839,19246,'119915','deals-mobile','show_buy_button','0',0,''),(60840,19246,'119915','deals-mobile','show_view_button','0',0,''),(60841,19246,'119915','deals-mobile','show_wishlist_button','0',0,''),(60842,19246,'119915','deals-mobile','show_compare','0',0,''),(60843,19246,'119915','deals-mobile','show_name_rows','0',0,''),(60844,19246,'119915','deals-mobile','show_image_rows','0',0,''),(60845,19246,'119915','deals-mobile','show_stock_rows','0',0,''),(60846,19246,'119915','deals-mobile','show_description_rows','0',0,''),(60847,19246,'119915','deals-mobile','show_model_rows','0',0,''),(60848,19246,'119915','deals-mobile','show_properties_rows','0',0,''),(60849,19246,'119915','deals-mobile','show_rating_rows','0',0,''),(60850,19246,'119915','deals-mobile','show_rating_counts_rows','0',0,''),(60851,19246,'119915','deals-mobile','show_price_rows','0',0,''),(60852,19246,'119915','deals-mobile','show_buy_button_rows','0',0,''),(60853,19246,'119915','deals-mobile','show_qty_input_rows','0',0,''),(60854,19246,'119915','deals-mobile','show_view_button_rows','0',0,''),(60855,19246,'119915','deals-mobile','show_wishlist_button_rows','0',0,''),(60856,19246,'119915','deals-mobile','show_compare_rows','0',0,''),(60857,19246,'119915','deals-mobile','show_name_b2b','0',0,''),(60858,19246,'119915','deals-mobile','show_image_b2b','0',0,''),(60859,19246,'119915','deals-mobile','show_stock_b2b','0',0,''),(60860,19246,'119915','deals-mobile','show_description_b2b','0',0,''),(60861,19246,'119915','deals-mobile','show_model_b2b','0',0,''),(60862,19246,'119915','deals-mobile','show_properties_b2b','0',0,''),(60863,19246,'119915','deals-mobile','show_rating_b2b','0',0,''),(60864,19246,'119915','deals-mobile','show_rating_counts_b2b','0',0,''),(60865,19246,'119915','deals-mobile','show_price_b2b','0',0,''),(60866,19246,'119915','deals-mobile','show_qty_input_b2b','0',0,''),(60867,19246,'119915','deals-mobile','show_view_button_b2b','0',0,''),(60868,19246,'119915','deals-mobile','show_attributes_b2b','0',0,''),(60869,19246,'119915','deals-mobile','items_on_page','12',0,''),(60872,19246,'119915','deals-mobile','product_names_teg','h2',0,''),(60873,19247,'119916','deals-mobile','block_type','1',0,''),(60874,19248,'119917','deals-mobile','block_type','6',0,''),(60875,19248,'119917','deals-mobile','schema','6-3',0,''),(60876,19248,'119917','deals-mobile','schema','6-3',0,'872'),(60877,19249,'119918','deals-mobile','aria_name','account-menu',0,''),(60878,19250,'119919','deals-mobile','link','Order History Info',0,''),(60879,19250,'119919','deals-mobile','text','TEXT_VIEW',0,''),(60880,19250,'119919','deals-mobile','show_pagenation','1',0,''),(60881,19250,'119919','deals-mobile','link_pay','Order pay',0,''),(60882,19250,'119919','deals-mobile','margin-bottom','20',0,''),(60883,19251,'119920','deals-mobile','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(60884,19252,'119921','deals-mobile','block_type','1',0,''),(60885,19253,'119922','deals-mobile','block_type','6',0,''),(60886,19253,'119922','deals-mobile','schema','6-3',0,'872'),(60887,19254,'119923','deals-mobile','aria_name','account-menu',0,''),(60888,19255,'119924','deals-mobile','float','left',0,''),(60889,19256,'119925','deals-mobile','block_type','3',0,''),(60890,19256,'119925','deals-mobile','clear','both',0,''),(60891,19256,'119925','deals-mobile','padding-top','20',0,''),(60892,19256,'119925','deals-mobile','schema','3-4',0,'872'),(60893,19257,'119926','deals-mobile','block_type','1',0,''),(60894,19257,'119926','deals-mobile','padding-right','20',0,''),(60895,19257,'119926','deals-mobile','margin-bottom','20',0,''),(60896,19258,'119927','deals-mobile','link','Tracking numbers',0,''),(60897,19258,'119927','deals-mobile','text','MORE_TRACKING_NUMBER',0,''),(60898,19258,'119927','deals-mobile','popup','1',0,''),(60899,19258,'119927','deals-mobile','order_id','1',0,''),(60900,19258,'119927','deals-mobile','popup_class','tracking-numbers-popup',0,''),(60901,19258,'119927','deals-mobile','font-weight','700',0,''),(60902,19258,'119927','deals-mobile','font-size','18',0,''),(60903,19259,'119928','deals-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(60904,19260,'119929','deals-mobile','short_view','1',0,''),(60905,19260,'119929','deals-mobile','hide_parents','2',0,''),(60906,19261,'119930','deals-mobile','block_type','1',0,''),(60907,19261,'119930','deals-mobile','margin-bottom','20',0,''),(60908,19261,'119930','deals-mobile','padding-right','20',0,''),(60909,19262,'119931','deals-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(60910,19263,'119932','deals-mobile','padding-left','30',0,''),(60911,19263,'119932','deals-mobile','orders_data','telephone',0,''),(60912,19263,'119932','deals-mobile','hide_parents','2',0,''),(60913,19264,'119933','deals-mobile','block_type','1',0,''),(60914,19264,'119933','deals-mobile','padding-right','20',0,''),(60915,19264,'119933','deals-mobile','padding-bottom','20',0,''),(60916,19265,'119934','deals-mobile','orders_data','name',0,''),(60917,19265,'119934','deals-mobile','padding-left','30',0,''),(60918,19266,'119935','deals-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(60919,19267,'119936','deals-mobile','block_type','1',0,''),(60920,19267,'119936','deals-mobile','padding-right','20',0,''),(60921,19267,'119936','deals-mobile','padding-bottom','20',0,''),(60922,19268,'119937','deals-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(60923,19269,'119938','deals-mobile','orders_data','delivery_address',0,''),(60924,19269,'119938','deals-mobile','padding-left','30',0,''),(60925,19270,'119939','deals-mobile','block_type','1',0,''),(60926,19270,'119939','deals-mobile','padding-right','20',0,''),(60927,19271,'119940','deals-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(60928,19272,'119941','deals-mobile','orders_data','shipping_method',0,''),(60929,19272,'119941','deals-mobile','padding-left','30',0,''),(60930,19273,'119942','deals-mobile','block_type','1',0,''),(60931,19273,'119942','deals-mobile','padding-bottom','20',0,''),(60932,19274,'119943','deals-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(60933,19275,'119944','deals-mobile','orders_data','billing_address',0,''),(60934,19275,'119944','deals-mobile','padding-left','30',0,''),(60935,19276,'119945','deals-mobile','block_type','1',0,''),(60936,19277,'119946','deals-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(60937,19278,'119947','deals-mobile','orders_data','payment_method',0,''),(60938,19278,'119947','deals-mobile','padding-left','30',0,''),(60939,19279,'119948','deals-mobile','float','right',0,''),(60940,19281,'119950','deals-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(60941,19284,'119953','deals-mobile','float','right',0,''),(60942,19284,'119953','deals-mobile','clear','none',0,''),(60943,19284,'119953','deals-mobile','margin-left','20',0,''),(60944,19285,'119954','deals-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(60945,19287,'119956','deals-mobile','float','right',0,''),(60946,19287,'119956','deals-mobile','clear','none',0,''),(60947,19287,'119956','deals-mobile','like_button','2',0,''),(60948,19287,'119956','deals-mobile','link','Order pay',0,''),(60949,19288,'119957','deals-mobile','float','right',0,''),(60950,19288,'119957','deals-mobile','clear','none',0,''),(60951,19288,'119957','deals-mobile','margin-left','20',0,''),(60952,19289,'119958','deals-mobile','block_type','2',0,''),(60953,19289,'119958','deals-mobile','padding-top','20',0,''),(60954,19289,'119958','deals-mobile','margin-bottom','20',0,''),(60955,19290,'119959','deals-mobile','like_button','1',0,''),(60956,19290,'119959','deals-mobile','text','IMAGE_BUTTON_BACK',0,''),(60957,19290,'119959','deals-mobile','link','Order History',0,''),(60958,19291,'119960','deals-mobile','text-align','right',0,''),(60959,19292,'119961','deals-mobile','block_type','1',0,''),(60960,19293,'119962','deals-mobile','block_type','6',0,''),(60961,19293,'119962','deals-mobile','schema','6-3',0,''),(60962,19293,'119962','deals-mobile','schema','6-3',0,'872'),(60963,19294,'119963','deals-mobile','aria_name','account-menu',0,''),(60964,19297,'119966','deals-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(60965,19298,'119967','deals-mobile','margin-bottom','20',0,''),(60966,19299,'119968','deals-mobile','block_type','3',0,''),(60967,19299,'119968','deals-mobile','schema','3-4',0,'872'),(60968,19300,'119969','deals-mobile','block_type','1',0,''),(60969,19301,'119970','deals-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(60970,19302,'119971','deals-mobile','padding-left','30',0,''),(60971,19303,'119972','deals-mobile','block_type','1',0,''),(60972,19303,'119972','deals-mobile','padding-right','20',0,''),(60973,19303,'119972','deals-mobile','padding-bottom','20',0,''),(60974,19304,'119973','deals-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(60975,19305,'119974','deals-mobile','orders_data','name',0,''),(60976,19305,'119974','deals-mobile','padding-left','30',0,''),(60977,19306,'119975','deals-mobile','block_type','1',0,''),(60978,19306,'119975','deals-mobile','padding-right','20',0,''),(60979,19307,'119976','deals-mobile','orders_data','shipping_method',0,''),(60980,19307,'119976','deals-mobile','padding-left','30',0,''),(60981,19308,'119977','deals-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(60982,19309,'119978','deals-mobile','block_type','1',0,''),(60983,19309,'119978','deals-mobile','padding-right','20',0,''),(60984,19309,'119978','deals-mobile','padding-bottom','20',0,''),(60985,19310,'119979','deals-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(60986,19311,'119980','deals-mobile','orders_data','delivery_address',0,''),(60987,19311,'119980','deals-mobile','padding-left','30',0,''),(60988,19312,'119981','deals-mobile','block_type','1',0,''),(60989,19313,'119982','deals-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(60990,19314,'119983','deals-mobile','orders_data','payment_method',0,''),(60991,19314,'119983','deals-mobile','padding-left','30',0,''),(60992,19315,'119984','deals-mobile','block_type','1',0,''),(60993,19315,'119984','deals-mobile','padding-bottom','20',0,''),(60994,19316,'119985','deals-mobile','orders_data','billing_address',0,''),(60995,19316,'119985','deals-mobile','padding-left','30',0,''),(60996,19317,'119986','deals-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(60997,19319,'119988','deals-mobile','width','680',0,''),(60998,19319,'119988','deals-mobile','font-weight','400',0,''),(60999,19319,'119988','deals-mobile','font-size','12',0,''),(61000,19319,'119988','deals-mobile','padding-top','20',0,''),(61001,19319,'119988','deals-mobile','padding-bottom','20',0,''),(61002,19320,'119989','deals-mobile','font-weight','normal',0,''),(61003,19320,'119989','deals-mobile','padding-top','20',0,''),(61004,19320,'119989','deals-mobile','font-size','12',0,''),(61005,19321,'119990','deals-mobile','block_type','4',0,''),(61006,19321,'119990','deals-mobile','font-weight','400',0,''),(61007,19321,'119990','deals-mobile','border-top-width','1',0,''),(61008,19321,'119990','deals-mobile','border-top-color','#e0e0e0',0,''),(61009,19321,'119990','deals-mobile','border-left-width','1',0,''),(61010,19321,'119990','deals-mobile','border-left-color','#e0e0e0',0,''),(61011,19321,'119990','deals-mobile','border-right-width','1',0,''),(61012,19321,'119990','deals-mobile','border-right-color','#e0e0e0',0,''),(61013,19321,'119990','deals-mobile','border-bottom-width','1',0,''),(61014,19321,'119990','deals-mobile','border-bottom-color','#e0e0e0',0,''),(61015,19322,'119991','deals-mobile','block_type','2',0,''),(61016,19322,'119991','deals-mobile','font-weight','normal',0,''),(61017,19322,'119991','deals-mobile','border-right-width','1',0,''),(61018,19322,'119991','deals-mobile','border-right-color','#e0e0e0',0,''),(61019,19323,'119992','deals-mobile','block_type','1',0,''),(61020,19323,'119992','deals-mobile','font-weight','normal',0,''),(61021,19323,'119992','deals-mobile','border-right-width','1',0,''),(61022,19323,'119992','deals-mobile','border-right-color','#e0e0e0',0,''),(61023,19323,'119992','deals-mobile','background-color','#e0e0e0',0,''),(61024,19323,'119992','deals-mobile','padding-top','10',0,''),(61025,19323,'119992','deals-mobile','padding-left','10',0,''),(61026,19323,'119992','deals-mobile','padding-right','10',0,''),(61027,19323,'119992','deals-mobile','padding-bottom','10',0,''),(61028,19324,'119993','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(61029,19324,'119993','deals-mobile','font-size','16',0,''),(61030,19324,'119993','deals-mobile','font-weight','bold',0,''),(61031,19324,'119993','deals-mobile','padding-bottom','10',0,''),(61032,19325,'119994','deals-mobile','font-size','16',0,''),(61033,19325,'119994','deals-mobile','font-weight','normal',0,''),(61034,19326,'119995','deals-mobile','block_type','1',0,''),(61035,19326,'119995','deals-mobile','font-weight','normal',0,''),(61036,19326,'119995','deals-mobile','padding-top','10',0,''),(61037,19326,'119995','deals-mobile','padding-left','10',0,''),(61038,19326,'119995','deals-mobile','padding-right','10',0,''),(61039,19326,'119995','deals-mobile','padding-bottom','10',0,''),(61040,19330,'119999','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(61041,19330,'119999','deals-mobile','font-size','14',0,''),(61042,19330,'119999','deals-mobile','font-weight','bold',0,''),(61043,19330,'119999','deals-mobile','padding-top','10',0,''),(61044,19331,'120000','deals-mobile','text','<p>CUSTOMER:</p>',1,''),(61045,19331,'120000','deals-mobile','font-size','14',0,''),(61046,19331,'120000','deals-mobile','font-weight','bold',0,''),(61047,19332,'120001','deals-mobile','text','<p>PHONE NUMBER:</p>',1,''),(61048,19332,'120001','deals-mobile','font-size','14',0,''),(61049,19332,'120001','deals-mobile','font-weight','bold',0,''),(61050,19332,'120001','deals-mobile','padding-top','10',0,''),(61051,19333,'120002','deals-mobile','block_type','2',0,''),(61052,19333,'120002','deals-mobile','font-weight','normal',0,''),(61053,19333,'120002','deals-mobile','border-right-width','1',0,''),(61054,19333,'120002','deals-mobile','border-right-color','#e0e0e0',0,''),(61055,19333,'120002','deals-mobile','border-top-width','1',0,''),(61056,19333,'120002','deals-mobile','border-top-color','#e0e0e0',0,''),(61057,19334,'120003','deals-mobile','block_type','1',0,''),(61058,19334,'120003','deals-mobile','font-weight','normal',0,''),(61059,19334,'120003','deals-mobile','padding-top','10',0,''),(61060,19334,'120003','deals-mobile','padding-left','10',0,''),(61061,19334,'120003','deals-mobile','padding-right','10',0,''),(61062,19334,'120003','deals-mobile','padding-bottom','10',0,''),(61063,19334,'120003','deals-mobile','border-right-width','1',0,''),(61064,19334,'120003','deals-mobile','border-right-color','#e0e0e0',0,''),(61065,19336,'120005','deals-mobile','text','<p>Shipping via</p>',1,''),(61066,19336,'120005','deals-mobile','font-weight','bold',0,''),(61067,19337,'120006','deals-mobile','block_type','1',0,''),(61068,19337,'120006','deals-mobile','font-weight','normal',0,''),(61069,19337,'120006','deals-mobile','padding-top','10',0,''),(61070,19337,'120006','deals-mobile','padding-left','10',0,''),(61071,19337,'120006','deals-mobile','padding-right','10',0,''),(61072,19337,'120006','deals-mobile','padding-bottom','10',0,''),(61073,19338,'120007','deals-mobile','text','<p>Shipping service</p>',1,''),(61074,19338,'120007','deals-mobile','font-weight','bold',0,''),(61075,19340,'120009','deals-mobile','font-weight','normal',0,''),(61076,19340,'120009','deals-mobile','text-align','center',0,''),(61077,19340,'120009','deals-mobile','padding-top','40',0,''),(61078,19341,'120010','deals-mobile','block_type','1',0,''),(61079,19341,'120010','deals-mobile','font-weight','normal',0,''),(61080,19341,'120010','deals-mobile','padding-top','10',0,''),(61081,19341,'120010','deals-mobile','padding-bottom','10',0,''),(61082,19342,'120011','deals-mobile','text','<p>If undelivered please return to:</p>',1,''),(61083,19342,'120011','deals-mobile','font-weight','bold',0,''),(61084,19344,'120013','deals-mobile','block_type','2',0,''),(61085,19344,'120013','deals-mobile','font-weight','normal',0,''),(61086,19344,'120013','deals-mobile','padding-bottom','20',0,''),(61087,19345,'120014','deals-mobile','font-weight','400',0,''),(61088,19345,'120014','deals-mobile','text-align','center',0,''),(61089,19345,'120014','deals-mobile','padding-top','10',0,''),(61091,19346,'120015','deals-mobile','block_type','1',0,''),(61092,19347,'120016','deals-mobile','font-weight','400',0,''),(61093,19347,'120016','deals-mobile','text-align','right',0,''),(61094,19347,'120016','deals-mobile','padding-bottom','10',0,''),(61095,19347,'120016','deals-mobile','address_spacer',',',0,''),(61096,19348,'120017','deals-mobile','block_type','11',0,''),(61097,19348,'120017','deals-mobile','font-weight','normal',0,''),(61098,19349,'120018','deals-mobile','text','<p>Phone:</p>',1,''),(61099,19349,'120018','deals-mobile','font-weight','normal',0,''),(61100,19349,'120018','deals-mobile','text-align','right',0,''),(61101,19350,'120019','deals-mobile','font-weight','normal',0,''),(61102,19350,'120019','deals-mobile','text-align','right',0,''),(61103,19351,'120020','deals-mobile','block_type','11',0,''),(61104,19351,'120020','deals-mobile','font-weight','400',0,''),(61105,19352,'120021','deals-mobile','text','<p>Web:</p>',1,''),(61106,19352,'120021','deals-mobile','font-weight','400',0,''),(61107,19352,'120021','deals-mobile','text-align','right',0,''),(61108,19353,'120022','deals-mobile','font-weight','normal',0,''),(61109,19353,'120022','deals-mobile','text-align','right',0,''),(61110,19354,'120023','deals-mobile','block_type','11',0,''),(61111,19354,'120023','deals-mobile','font-weight','normal',0,''),(61112,19355,'120024','deals-mobile','text','<p>Email:</p>',1,''),(61113,19355,'120024','deals-mobile','font-weight','normal',0,''),(61114,19355,'120024','deals-mobile','text-align','right',0,''),(61115,19356,'120025','deals-mobile','font-weight','normal',0,''),(61116,19356,'120025','deals-mobile','text-align','right',0,''),(61117,19357,'120026','deals-mobile','block_type','1',0,''),(61118,19358,'120027','deals-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(61119,19359,'120028','deals-mobile','block_type','8',0,''),(61120,19360,'120029','deals-mobile','margin-bottom','20',0,''),(61121,19361,'120030','deals-mobile','text','##TEXT_MAIN##',0,''),(61122,19361,'120030','deals-mobile','margin-bottom','20',0,''),(61123,19361,'120030','deals-mobile','text-align','center',0,''),(61124,19363,'120032','deals-mobile','block_type','2',0,''),(61125,19364,'120033','deals-mobile','block_type','1',0,''),(61126,19364,'120033','deals-mobile','style_class','product',0,''),(61127,19364,'120033','deals-mobile','padding-right','10',0,''),(61128,19364,'120033','deals-mobile','padding-bottom','20',0,''),(61129,19365,'120034','deals-mobile','block_type','2',0,''),(61130,19366,'120035','deals-mobile','product_element','image',0,''),(61131,19366,'120035','deals-mobile','padding-right','10',0,''),(61132,19367,'120036','deals-mobile','product_element','products_price_old',0,''),(61133,19367,'120036','deals-mobile','font-family','Varela Round',0,''),(61134,19367,'120036','deals-mobile','font-size','14',0,''),(61135,19367,'120036','deals-mobile','text-decoration','line-through',0,''),(61136,19368,'120037','deals-mobile','product_element','products_price',0,''),(61137,19368,'120037','deals-mobile','font-family','Varela Round',0,''),(61138,19368,'120037','deals-mobile','font-size','20',0,''),(61139,19368,'120037','deals-mobile','padding-top','20',0,''),(61140,19369,'120038','deals-mobile','block_type','1',0,''),(61141,19370,'120039','deals-mobile','product_element','products_name',0,''),(61142,19370,'120039','deals-mobile','font-family','Varela Round',0,''),(61143,19370,'120039','deals-mobile','padding-bottom','10',0,''),(61144,19370,'120039','deals-mobile','font-size','16',0,''),(61145,19371,'120040','deals-mobile','block_type','1',0,''),(61146,19371,'120040','deals-mobile','style_class','product',0,''),(61147,19371,'120040','deals-mobile','padding-left','10',0,''),(61148,19371,'120040','deals-mobile','padding-bottom','20',0,''),(61149,19372,'120041','deals-mobile','block_type','1',0,''),(61150,19373,'120042','deals-mobile','product_element','products_name',0,''),(61151,19373,'120042','deals-mobile','font-family','Varela Round',0,''),(61152,19373,'120042','deals-mobile','font-size','16',0,''),(61153,19373,'120042','deals-mobile','padding-bottom','10',0,''),(61154,19374,'120043','deals-mobile','block_type','2',0,''),(61155,19375,'120044','deals-mobile','product_element','image',0,''),(61156,19375,'120044','deals-mobile','padding-right','10',0,''),(61157,19376,'120045','deals-mobile','font-size','14',0,''),(61158,19376,'120045','deals-mobile','font-family','Varela Round',0,''),(61159,19376,'120045','deals-mobile','text-decoration','line-through',0,''),(61160,19376,'120045','deals-mobile','product_element','products_price_old',0,''),(61161,19377,'120046','deals-mobile','product_element','products_price',0,''),(61162,19377,'120046','deals-mobile','font-family','Varela Round',0,''),(61163,19377,'120046','deals-mobile','font-size','20',0,''),(61164,19377,'120046','deals-mobile','padding-top','20',0,''),(61165,19378,'120047','deals-mobile','font-size','30',0,''),(61166,19378,'120047','deals-mobile','font-family','Varela Round',0,''),(61167,19378,'120047','deals-mobile','text-align','center',0,''),(61168,19378,'120047','deals-mobile','padding-bottom','50',0,''),(61169,19379,'120048','deals-mobile','padding-bottom','20',0,''),(61170,19379,'120048','deals-mobile','text-align','center',0,''),(61171,19380,'120049','deals-mobile','width','680',0,''),(61172,19381,'120050','deals-mobile','padding-top','200',0,''),(61173,19381,'120050','deals-mobile','padding-left','200',0,''),(61175,19382,'120051','deals-mobile','text','osCommerce 4',1,''),(61176,19382,'120051','deals-mobile','font-family','Varela Round',0,''),(61177,19382,'120051','deals-mobile','font-size','40',0,''),(61178,19382,'120051','deals-mobile','padding-top','50',0,''),(61179,19382,'120051','deals-mobile','text-align','center',0,''),(61180,19383,'120052','deals-mobile','block_type','2',0,''),(61181,19383,'120052','deals-mobile','border-top-width','1',0,''),(61182,19383,'120052','deals-mobile','border-top-color','#eeeeee',0,''),(61183,19384,'120053','deals-mobile','text-align','right',0,''),(61184,19384,'120053','deals-mobile','padding-top','15',0,''),(61185,19384,'120053','deals-mobile','padding-bottom','15',0,''),(61186,19384,'120053','deals-mobile','font-size','14',0,''),(61187,19385,'120054','deals-mobile','font-family','Varela Round',0,''),(61188,19385,'120054','deals-mobile','text-align','center',0,''),(61189,19385,'120054','deals-mobile','font-size','20',0,''),(61190,19385,'120054','deals-mobile','color','#183d78',0,''),(61191,19385,'120054','deals-mobile','border-bottom-width','1',0,''),(61192,19385,'120054','deals-mobile','border-bottom-color','#dedede',0,''),(61193,19385,'120054','deals-mobile','padding-top','10',0,''),(61194,19385,'120054','deals-mobile','padding-bottom','10',0,''),(61195,19386,'120055','deals-mobile','block_type','1',0,''),(61196,19387,'120056','deals-mobile','block_type','6',0,''),(61197,19387,'120056','deals-mobile','schema','6-3',0,''),(61198,19387,'120056','deals-mobile','schema','6-3',0,'872'),(61199,19388,'120057','deals-mobile','aria_name','account-menu',0,''),(61200,19389,'120058','deals-mobile','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(61201,19390,'120059','deals-mobile','max_items','10',0,''),(61202,19391,'120060','deals-mobile','block_type','1',0,''),(61203,19391,'120060','deals-mobile','padding-top','20',0,''),(61204,19391,'120060','deals-mobile','padding-left','20',0,''),(61205,19391,'120060','deals-mobile','padding-right','20',0,''),(61206,19391,'120060','deals-mobile','padding-bottom','20',0,''),(61207,19392,'120061','deals-mobile','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(61208,19394,'120063','deals-mobile','block_type','1',0,''),(61209,19395,'120064','deals-mobile','margin_left_measure','auto',0,''),(61210,19395,'120064','deals-mobile','margin_right_measure','auto',0,''),(61211,19395,'120064','deals-mobile','max-width','560',0,''),(61212,19396,'120065','deals-mobile','margin-bottom','30',0,''),(61213,19397,'120066','deals-mobile','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(61214,19398,'120067','deals-mobile','block_type','1',0,''),(61215,19399,'120068','deals-mobile','block_type','2',0,''),(61216,19399,'120068','deals-mobile','border-top-width','1',0,''),(61217,19399,'120068','deals-mobile','border-top-color','#e0e0e0',0,''),(61218,19399,'120068','deals-mobile','padding-top','15',0,''),(61219,19399,'120068','deals-mobile','padding-bottom','15',0,''),(61220,19401,'120070','deals-mobile','font-size','30',0,''),(61221,19401,'120070','deals-mobile','font-weight','400',0,''),(61222,19401,'120070','deals-mobile','line-height','35',0,''),(61223,19401,'120070','deals-mobile','font-family','Varela Round',0,''),(61224,19401,'120070','deals-mobile','line_height_measure','px',0,''),(61225,19402,'120071','deals-mobile','font-weight','400',0,''),(61226,19403,'120072','deals-mobile','font-weight','normal',0,''),(61227,19403,'120072','deals-mobile','padding-bottom','20',0,''),(61228,19404,'120073','deals-mobile','padding-right','0',0,''),(61229,19404,'120073','deals-mobile','align_position','horizontal',0,''),(61230,19406,'120075','deals-mobile','text-align','right',0,''),(61231,19406,'120075','deals-mobile','width','100',0,'863'),(61232,19406,'120075','deals-mobile','width_measure','%',0,'863'),(61233,19406,'120075','deals-mobile','float','none',0,'863'),(61234,19406,'120075','deals-mobile','margin-bottom','20',0,''),(61235,19407,'120076','deals-mobile','font-weight','400',0,''),(61236,19407,'120076','deals-mobile','box_align','4',0,''),(61237,19407,'120076','deals-mobile','align_position','horizontal',0,''),(61238,19407,'120076','deals-mobile','margin-bottom','30',0,''),(61239,19408,'120077','deals-mobile','font-weight','400',0,''),(61240,19409,'120078','deals-mobile','block_type','1',0,''),(61241,19409,'120078','deals-mobile','style_class','personal-buttons',0,''),(61242,19409,'120078','deals-mobile','margin-bottom','20',0,''),(61243,19409,'120078','deals-mobile','border-bottom-width','1',0,''),(61244,19409,'120078','deals-mobile','border-bottom-color','#e0e0e0',0,''),(61245,19409,'120078','deals-mobile','padding-left','30',0,''),(61246,19414,'120083','deals-mobile','font-weight','normal',0,''),(61247,19414,'120083','deals-mobile','padding-bottom','20',0,''),(61248,19414,'120083','deals-mobile','show_qty_input','1',0,''),(61249,19414,'120083','deals-mobile','show_compare','1',0,''),(61250,19414,'120083','deals-mobile','col_in_row','1',0,''),(61251,19414,'120083','deals-mobile','view_as','carousel',0,''),(61252,19414,'120083','deals-mobile','listing_type','productListing',0,''),(61253,19415,'120084','deals-mobile','font-weight','400',0,''),(61254,19415,'120084','deals-mobile','padding-bottom','20',0,''),(61255,19415,'120084','deals-mobile','show_qty_input','1',0,''),(61256,19415,'120084','deals-mobile','show_compare','1',0,''),(61257,19415,'120084','deals-mobile','listing_type','type-1',0,''),(61258,19415,'120084','deals-mobile','view_as','carousel',0,''),(61259,19415,'120084','deals-mobile','show_name','0',0,''),(61260,19415,'120084','deals-mobile','show_image','0',0,''),(61261,19415,'120084','deals-mobile','show_stock','0',0,''),(61262,19415,'120084','deals-mobile','show_description','0',0,''),(61263,19415,'120084','deals-mobile','show_model','0',0,''),(61264,19415,'120084','deals-mobile','show_properties','0',0,''),(61265,19415,'120084','deals-mobile','show_rating','0',0,''),(61266,19415,'120084','deals-mobile','show_rating_counts','0',0,''),(61267,19415,'120084','deals-mobile','show_price','0',0,''),(61268,19415,'120084','deals-mobile','show_buy_button','0',0,''),(61269,19415,'120084','deals-mobile','show_view_button','0',0,''),(61270,19415,'120084','deals-mobile','show_wishlist_button','0',0,''),(61271,19415,'120084','deals-mobile','display','none',0,'864'),(61272,19415,'120084','deals-mobile','product_names_teg','h2',0,''),(61273,19416,'120085','deals-mobile','font-weight','normal',0,''),(61274,19416,'120085','deals-mobile','padding-bottom','20',0,''),(61275,19417,'120086','deals-mobile','tab_1','Description',1,''),(61276,19417,'120086','deals-mobile','tab_2','Reviews',1,''),(61277,19417,'120086','deals-mobile','font-weight','400',0,''),(61278,19417,'120086','deals-mobile','margin-top','20',0,''),(61279,19420,'120089','deals-mobile','padding-bottom','10',0,''),(61280,19420,'120089','deals-mobile','padding-top','5',0,''),(61281,19421,'120090','deals-mobile','font-weight','normal',0,''),(61282,19421,'120090','deals-mobile','padding-top','20',0,''),(61283,19421,'120090','deals-mobile','padding-bottom','20',0,''),(61284,19421,'120090','deals-mobile','border-top-width','1',0,''),(61285,19421,'120090','deals-mobile','border-top-color','#cccccc',0,''),(61286,19423,'120092','deals-mobile','font-weight','400',0,''),(61287,19423,'120092','deals-mobile','padding-bottom','20',0,''),(61288,19423,'120092','deals-mobile','show_qty_input','1',0,''),(61289,19423,'120092','deals-mobile','show_compare','1',0,''),(61290,19423,'120092','deals-mobile','show_name','0',0,''),(61291,19423,'120092','deals-mobile','show_image','0',0,''),(61292,19423,'120092','deals-mobile','show_stock','0',0,''),(61293,19423,'120092','deals-mobile','show_description','0',0,''),(61294,19423,'120092','deals-mobile','show_model','0',0,''),(61295,19423,'120092','deals-mobile','show_properties','0',0,''),(61296,19423,'120092','deals-mobile','show_rating','0',0,''),(61297,19423,'120092','deals-mobile','show_rating_counts','0',0,''),(61298,19423,'120092','deals-mobile','show_price','0',0,''),(61299,19423,'120092','deals-mobile','show_buy_button','0',0,''),(61300,19423,'120092','deals-mobile','show_view_button','0',0,''),(61301,19423,'120092','deals-mobile','show_wishlist_button','0',0,''),(61302,19423,'120092','deals-mobile','listing_type','productListing',0,''),(61303,19423,'120092','deals-mobile','col_in_row','1',0,''),(61304,19423,'120092','deals-mobile','view_as','carousel',0,''),(61305,19434,'120103','deals-mobile','block_type','1',0,''),(61306,19434,'120103','deals-mobile','style_class','item-holder',0,''),(61307,19434,'120103','deals-mobile','padding-top','25',0,''),(61308,19434,'120103','deals-mobile','padding-left','25',0,''),(61309,19434,'120103','deals-mobile','padding-right','25',0,''),(61310,19434,'120103','deals-mobile','padding-bottom','25',0,''),(61311,19434,'120103','deals-mobile','text-align','left',0,''),(61312,19437,'120106','deals-mobile','description_characters','90',0,''),(61313,19438,'120107','deals-mobile','text-align','right',0,''),(61314,19438,'120107','deals-mobile','margin-bottom','10',0,''),(61315,19439,'120108','deals-mobile','text-align','right',0,''),(61316,19439,'120108','deals-mobile','clear','none',0,''),(61317,19439,'120108','deals-mobile','float','left',0,''),(61318,19441,'120110','deals-mobile','block_type','2',0,''),(61319,19442,'120111','deals-mobile','margin-bottom','7',0,''),(61320,19443,'120112','deals-mobile','margin-bottom','10',0,''),(61321,19443,'120112','deals-mobile','text-align','right',0,''),(61322,19443,'120112','deals-mobile','float','right',0,''),(61323,19444,'120113','deals-mobile','clear','both',0,''),(61324,19445,'120114','deals-mobile','float','left',0,''),(61325,19445,'120114','deals-mobile','margin-right','20',0,''),(61326,19445,'120114','deals-mobile','margin-bottom','5',0,''),(61327,19446,'120115','deals-mobile','block_type','1',0,''),(61328,19447,'120116','deals-mobile','font-weight','400',0,''),(61329,19447,'120116','deals-mobile','padding-right','40',0,''),(61330,19447,'120116','deals-mobile','padding-right','0',0,'888'),(61331,19447,'120116','deals-mobile','padding-right','0',0,'890'),(61332,19447,'120116','deals-mobile','margin-bottom','20',0,''),(61333,19448,'120117','deals-mobile','text-align','center',0,''),(61334,19448,'120117','deals-mobile','margin-bottom','20',0,''),(61335,19450,'120119','deals-mobile','margin-bottom','20',0,''),(61336,19450,'120119','deals-mobile','text-align','center',0,''),(61337,19451,'120120','deals-mobile','block_type','2',0,''),(61338,19451,'120120','deals-mobile','margin-bottom','20',0,''),(61339,19452,'120121','deals-mobile','sort_pos_3','1',0,''),(61340,19452,'120121','deals-mobile','sort_pos_4','2',0,''),(61341,19452,'120121','deals-mobile','sort_pos_10','5',0,''),(61342,19452,'120121','deals-mobile','sort_pos_9','6',0,''),(61343,19452,'120121','deals-mobile','sort_pos_11','7',0,''),(61344,19452,'120121','deals-mobile','sort_pos_12','8',0,''),(61345,19452,'120121','deals-mobile','sort_pos_14','9',0,''),(61346,19452,'120121','deals-mobile','sort_pos_13','10',0,''),(61347,19452,'120121','deals-mobile','sort_pos_8','11',0,''),(61348,19452,'120121','deals-mobile','sort_pos_7','12',0,''),(61349,19452,'120121','deals-mobile','sort_pos_2','13',0,''),(61350,19452,'120121','deals-mobile','sort_pos_1','14',0,''),(61351,19452,'120121','deals-mobile','sort_pos_6','15',0,''),(61352,19452,'120121','deals-mobile','sort_pos_5','16',0,''),(61353,19452,'120121','deals-mobile','sort_pos_0','17',0,''),(61354,19452,'120121','deals-mobile','sort_hide_10','1',0,''),(61355,19452,'120121','deals-mobile','sort_hide_9','1',0,''),(61356,19452,'120121','deals-mobile','sort_pos_15','4',0,''),(61357,19452,'120121','deals-mobile','sort_pos_16','3',0,''),(61358,19452,'120121','deals-mobile','sort_hide_3','0',0,''),(61359,19452,'120121','deals-mobile','sort_hide_4','0',0,''),(61360,19452,'120121','deals-mobile','sort_hide_16','1',0,''),(61361,19452,'120121','deals-mobile','sort_hide_15','1',0,''),(61362,19452,'120121','deals-mobile','sort_hide_11','0',0,''),(61363,19452,'120121','deals-mobile','sort_hide_12','0',0,''),(61364,19452,'120121','deals-mobile','sort_hide_14','0',0,''),(61365,19452,'120121','deals-mobile','sort_hide_13','0',0,''),(61366,19452,'120121','deals-mobile','sort_hide_8','0',0,''),(61367,19452,'120121','deals-mobile','sort_hide_7','0',0,''),(61368,19452,'120121','deals-mobile','sort_hide_2','0',0,''),(61369,19452,'120121','deals-mobile','sort_hide_1','0',0,''),(61370,19452,'120121','deals-mobile','sort_hide_6','0',0,''),(61371,19452,'120121','deals-mobile','sort_hide_5','0',0,''),(61372,19452,'120121','deals-mobile','sort_hide_0','0',0,''),(61373,19453,'120122','deals-mobile','text-align','right',0,''),(61374,19453,'120122','deals-mobile','padding-top','10',0,''),(61375,19454,'120123','deals-mobile','col_in_row','2',0,''),(61376,19454,'120123','deals-mobile','products_align','left',0,''),(61377,19454,'120123','deals-mobile','font-weight','400',0,''),(61378,19454,'120123','deals-mobile','show_qty_input','1',0,''),(61379,19454,'120123','deals-mobile','listing_type','productListing',0,''),(61380,19454,'120123','deals-mobile','listing_type_rows','type-1_2',0,''),(61381,19454,'120123','deals-mobile','show_buy_button_b2b','on',0,''),(61382,19454,'120123','deals-mobile','show_wishlist_button_b2b','1',0,''),(61383,19454,'120123','deals-mobile','show_compare_b2b','1',0,''),(61384,19454,'120123','deals-mobile','listing_type_b2b','type-1_3',0,''),(61385,19454,'120123','deals-mobile','show_name','0',0,''),(61386,19454,'120123','deals-mobile','show_image','0',0,''),(61387,19454,'120123','deals-mobile','show_stock','0',0,''),(61388,19454,'120123','deals-mobile','show_description','1',0,''),(61389,19454,'120123','deals-mobile','show_model','1',0,''),(61390,19454,'120123','deals-mobile','show_properties','1',0,''),(61391,19454,'120123','deals-mobile','show_rating_counts','1',0,''),(61392,19454,'120123','deals-mobile','show_price','0',0,''),(61393,19454,'120123','deals-mobile','show_buy_button','1',0,''),(61394,19454,'120123','deals-mobile','show_view_button','1',0,''),(61395,19454,'120123','deals-mobile','show_wishlist_button','1',0,''),(61396,19454,'120123','deals-mobile','show_compare','1',0,''),(61397,19454,'120123','deals-mobile','show_name_rows','0',0,''),(61398,19454,'120123','deals-mobile','show_image_rows','0',0,''),(61399,19454,'120123','deals-mobile','show_stock_rows','0',0,''),(61400,19454,'120123','deals-mobile','show_description_rows','0',0,''),(61401,19454,'120123','deals-mobile','show_model_rows','0',0,''),(61402,19454,'120123','deals-mobile','show_properties_rows','0',0,''),(61403,19454,'120123','deals-mobile','show_rating_rows','0',0,''),(61404,19454,'120123','deals-mobile','show_rating_counts_rows','0',0,''),(61405,19454,'120123','deals-mobile','show_price_rows','0',0,''),(61406,19454,'120123','deals-mobile','show_buy_button_rows','0',0,''),(61407,19454,'120123','deals-mobile','show_qty_input_rows','0',0,''),(61408,19454,'120123','deals-mobile','show_view_button_rows','0',0,''),(61409,19454,'120123','deals-mobile','show_wishlist_button_rows','0',0,''),(61410,19454,'120123','deals-mobile','show_compare_rows','0',0,''),(61411,19454,'120123','deals-mobile','show_name_b2b','0',0,''),(61412,19454,'120123','deals-mobile','show_image_b2b','0',0,''),(61413,19454,'120123','deals-mobile','show_stock_b2b','0',0,''),(61414,19454,'120123','deals-mobile','show_description_b2b','0',0,''),(61415,19454,'120123','deals-mobile','show_model_b2b','0',0,''),(61416,19454,'120123','deals-mobile','show_properties_b2b','0',0,''),(61417,19454,'120123','deals-mobile','show_rating_b2b','0',0,''),(61418,19454,'120123','deals-mobile','show_rating_counts_b2b','0',0,''),(61419,19454,'120123','deals-mobile','show_price_b2b','0',0,''),(61420,19454,'120123','deals-mobile','show_qty_input_b2b','0',0,''),(61421,19454,'120123','deals-mobile','show_view_button_b2b','0',0,''),(61422,19454,'120123','deals-mobile','show_attributes_b2b','0',0,''),(61423,19454,'120123','deals-mobile','items_on_page','10',0,''),(61424,19454,'120123','deals-mobile','product_names_teg','h2',0,''),(61425,19456,'120125','deals-mobile','block_type','1',0,''),(61426,19458,'120127','deals-mobile','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(61427,19459,'120128','deals-mobile','width','680',0,''),(61428,19459,'120128','deals-mobile','font-weight','normal',0,''),(61429,19459,'120128','deals-mobile','font-size','12',0,''),(61430,19459,'120128','deals-mobile','padding-top','20',0,''),(61431,19459,'120128','deals-mobile','padding-bottom','20',0,''),(61432,19459,'120128','deals-mobile','color','#424242',0,''),(61433,19460,'120129','deals-mobile','block_type','5',0,''),(61434,19460,'120129','deals-mobile','font-weight','normal',0,''),(61435,19460,'120129','deals-mobile','border-bottom-width','1',0,''),(61436,19460,'120129','deals-mobile','border-bottom-color','#e0e0e0',0,''),(61437,19460,'120129','deals-mobile','border-top-width','1',0,''),(61438,19460,'120129','deals-mobile','border-top-color','#e0e0e0',0,''),(61439,19460,'120129','deals-mobile','border-left-color','#e0e0e0',0,''),(61440,19460,'120129','deals-mobile','border-left-width','1',0,''),(61441,19461,'120130','deals-mobile','block_type','1',0,''),(61442,19461,'120130','deals-mobile','font-weight','normal',0,''),(61443,19461,'120130','deals-mobile','padding-top','10',0,''),(61444,19461,'120130','deals-mobile','padding-left','10',0,''),(61445,19461,'120130','deals-mobile','padding-right','10',0,''),(61446,19462,'120131','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(61447,19462,'120131','deals-mobile','font-size','14',0,''),(61448,19462,'120131','deals-mobile','font-weight','bold',0,''),(61449,19462,'120131','deals-mobile','padding-bottom','10',0,''),(61450,19463,'120132','deals-mobile','font-weight','400',0,''),(61451,19463,'120132','deals-mobile','line-height','120',0,''),(61452,19463,'120132','deals-mobile','line_height_measure','%',0,''),(61453,19463,'120132','deals-mobile','font-size','12',0,''),(61454,19464,'120133','deals-mobile','block_type','4',0,''),(61455,19464,'120133','deals-mobile','font-weight','normal',0,''),(61456,19464,'120133','deals-mobile','border-top-width','1',0,''),(61457,19464,'120133','deals-mobile','border-top-color','#e0e0e0',0,''),(61458,19464,'120133','deals-mobile','border-left-width','1',0,''),(61459,19464,'120133','deals-mobile','border-left-color','#e0e0e0',0,''),(61460,19464,'120133','deals-mobile','border-right-width','1',0,''),(61461,19464,'120133','deals-mobile','border-right-color','#e0e0e0',0,''),(61462,19464,'120133','deals-mobile','border-bottom-width','1',0,''),(61463,19464,'120133','deals-mobile','border-bottom-color','#e0e0e0',0,''),(61464,19465,'120134','deals-mobile','block_type','2',0,''),(61465,19465,'120134','deals-mobile','font-weight','normal',0,''),(61466,19465,'120134','deals-mobile','border-right-width','1',0,''),(61467,19465,'120134','deals-mobile','border-right-color','#e0e0e0',0,''),(61468,19466,'120135','deals-mobile','block_type','1',0,''),(61469,19466,'120135','deals-mobile','font-weight','400',0,''),(61470,19466,'120135','deals-mobile','background-color','#eeeeee',0,''),(61471,19466,'120135','deals-mobile','padding-top','10',0,''),(61472,19466,'120135','deals-mobile','padding-left','10',0,''),(61473,19466,'120135','deals-mobile','padding-right','10',0,''),(61474,19466,'120135','deals-mobile','padding-bottom','30',0,''),(61475,19467,'120136','deals-mobile','text','<p>ADDRESS:</p>\n',1,''),(61476,19467,'120136','deals-mobile','font-size','14',0,''),(61477,19467,'120136','deals-mobile','font-weight','bold',0,''),(61478,19468,'120137','deals-mobile','font-size','12',0,''),(61479,19469,'120138','deals-mobile','block_type','1',0,''),(61480,19469,'120138','deals-mobile','font-weight','normal',0,''),(61481,19469,'120138','deals-mobile','padding-top','10',0,''),(61482,19469,'120138','deals-mobile','padding-left','10',0,''),(61483,19469,'120138','deals-mobile','padding-right','10',0,''),(61484,19469,'120138','deals-mobile','padding-bottom','10',0,''),(61485,19470,'120139','deals-mobile','text','<p>CUSTOMER:</p>',1,''),(61486,19470,'120139','deals-mobile','font-size','13',0,''),(61487,19470,'120139','deals-mobile','font-weight','bold',0,''),(61488,19471,'120140','deals-mobile','text','<p>PHONE NUMBER:</p>',1,''),(61489,19471,'120140','deals-mobile','font-size','14',0,''),(61490,19471,'120140','deals-mobile','font-weight','bold',0,''),(61491,19471,'120140','deals-mobile','padding-top','10',0,''),(61492,19472,'120141','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(61493,19472,'120141','deals-mobile','font-weight','bold',0,''),(61494,19472,'120141','deals-mobile','font-size','14',0,''),(61495,19472,'120141','deals-mobile','padding-top','10',0,''),(61496,19473,'120142','deals-mobile','font-weight','normal',0,''),(61497,19474,'120143','deals-mobile','font-weight','normal',0,''),(61498,19476,'120145','deals-mobile','text','<p>Order date:</p>\n',1,''),(61499,19476,'120145','deals-mobile','font-weight','bold',0,''),(61500,19476,'120145','deals-mobile','text-align','center',0,''),(61501,19476,'120145','deals-mobile','font-size','12',0,''),(61502,19477,'120146','deals-mobile','font-weight','normal',0,''),(61503,19477,'120146','deals-mobile','text-align','center',0,''),(61504,19477,'120146','deals-mobile','padding-bottom','10',0,''),(61505,19478,'120147','deals-mobile','font-size','14',0,''),(61506,19478,'120147','deals-mobile','font-weight','bold',0,''),(61507,19478,'120147','deals-mobile','text-align','center',0,''),(61508,19478,'120147','deals-mobile','padding-bottom','10',0,''),(61509,19478,'120147','deals-mobile','padding-top','10',0,''),(61510,19479,'120148','deals-mobile','block_type','2',0,''),(61511,19479,'120148','deals-mobile','font-weight','normal',0,''),(61512,19479,'120148','deals-mobile','padding-bottom','20',0,''),(61513,19480,'120149','deals-mobile','font-weight','400',0,''),(61514,19480,'120149','deals-mobile','padding-top','20',0,''),(61516,19481,'120150','deals-mobile','block_type','1',0,''),(61517,19482,'120151','deals-mobile','font-weight','normal',0,''),(61518,19482,'120151','deals-mobile','text-align','right',0,''),(61519,19482,'120151','deals-mobile','padding-bottom','10',0,''),(61520,19482,'120151','deals-mobile','address_spacer',',',0,''),(61521,19482,'120151','deals-mobile','font-size','12',0,''),(61522,19483,'120152','deals-mobile','block_type','11',0,''),(61523,19483,'120152','deals-mobile','font-weight','normal',0,''),(61524,19484,'120153','deals-mobile','text','<p>Email:</p>',1,''),(61525,19484,'120153','deals-mobile','font-weight','normal',0,''),(61526,19484,'120153','deals-mobile','text-align','right',0,''),(61527,19485,'120154','deals-mobile','font-weight','normal',0,''),(61528,19485,'120154','deals-mobile','text-align','right',0,''),(61529,19486,'120155','deals-mobile','block_type','11',0,''),(61530,19486,'120155','deals-mobile','font-weight','normal',0,''),(61531,19487,'120156','deals-mobile','text','<p>Web:</p>',1,''),(61532,19487,'120156','deals-mobile','font-weight','normal',0,''),(61533,19487,'120156','deals-mobile','text-align','right',0,''),(61534,19488,'120157','deals-mobile','font-weight','normal',0,''),(61535,19488,'120157','deals-mobile','text-align','right',0,''),(61536,19489,'120158','deals-mobile','block_type','11',0,''),(61537,19489,'120158','deals-mobile','font-weight','normal',0,''),(61538,19490,'120159','deals-mobile','text','<p>Phone:</p>',1,''),(61539,19490,'120159','deals-mobile','font-weight','normal',0,''),(61540,19490,'120159','deals-mobile','text-align','right',0,''),(61541,19491,'120160','deals-mobile','font-weight','normal',0,''),(61542,19491,'120160','deals-mobile','text-align','right',0,''),(61543,19492,'120161','deals-mobile','block_type','3',0,''),(61544,19492,'120161','deals-mobile','font-weight','normal',0,''),(61545,19492,'120161','deals-mobile','padding-top','20',0,''),(61546,19493,'120162','deals-mobile','font-size','12',0,''),(61547,19494,'120163','deals-mobile','text','<p>If undelivered please return to:</p>',1,''),(61548,19494,'120163','deals-mobile','font-size','12',0,''),(61549,19494,'120163','deals-mobile','font-weight','bold',0,''),(61550,19495,'120164','deals-mobile','text','<p>Thank you for your order</p>',1,''),(61551,19495,'120164','deals-mobile','color','#1da1f2',0,''),(61552,19495,'120164','deals-mobile','font-size','13',0,''),(61553,19495,'120164','deals-mobile','font-weight','bold',0,''),(61554,19495,'120164','deals-mobile','padding-top','5',0,''),(61555,19495,'120164','deals-mobile','text-align','center',0,''),(61556,19496,'120165','deals-mobile','font-weight','400',0,''),(61557,19496,'120165','deals-mobile','text-align','center',0,''),(61558,19496,'120165','deals-mobile','padding-top','0',0,''),(61560,19496,'120165','deals-mobile','padding-left','20',0,''),(61561,19496,'120165','deals-mobile','padding-right','20',0,''),(61562,19497,'120166','deals-mobile','block_type','6',0,''),(61563,19497,'120166','deals-mobile','font-weight','normal',0,''),(61564,19497,'120166','deals-mobile','font-size','16',0,''),(61565,19498,'120167','deals-mobile','text','<p>Phone:</p>',1,''),(61566,19498,'120167','deals-mobile','font-weight','normal',0,''),(61567,19498,'120167','deals-mobile','text-align','right',0,''),(61568,19498,'120167','deals-mobile','font-size','12',0,''),(61569,19499,'120168','deals-mobile','font-weight','normal',0,''),(61570,19499,'120168','deals-mobile','text-align','right',0,''),(61571,19499,'120168','deals-mobile','font-size','12',0,''),(61572,19500,'120169','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(61573,19500,'120169','deals-mobile','font-size','12',0,''),(61574,19500,'120169','deals-mobile','font-weight','bold',0,''),(61575,19500,'120169','deals-mobile','text-align','right',0,''),(61576,19501,'120170','deals-mobile','block_type','6',0,''),(61577,19501,'120170','deals-mobile','font-weight','normal',0,''),(61578,19501,'120170','deals-mobile','font-size','16',0,''),(61579,19502,'120171','deals-mobile','text','<p>Email:</p>',1,''),(61580,19502,'120171','deals-mobile','font-weight','normal',0,''),(61581,19502,'120171','deals-mobile','text-align','right',0,''),(61582,19502,'120171','deals-mobile','font-size','12',0,''),(61583,19503,'120172','deals-mobile','font-weight','normal',0,''),(61584,19503,'120172','deals-mobile','text-align','right',0,''),(61585,19503,'120172','deals-mobile','font-size','12',0,''),(61586,19504,'120173','deals-mobile','font-weight','400',0,''),(61587,19504,'120173','deals-mobile','padding-top','20',0,''),(61588,19504,'120173','deals-mobile','padding-bottom','0',0,''),(61589,19504,'120173','deals-mobile','font-size','12',0,''),(61590,19505,'120174','deals-mobile','block_type','1',0,''),(61591,19506,'120175','deals-mobile','block_type','6',0,''),(61592,19506,'120175','deals-mobile','schema','6-3',0,'872'),(61593,19507,'120176','deals-mobile','aria_name','account-menu',0,''),(61594,19508,'120177','deals-mobile','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(61595,19509,'120178','deals-mobile','link','Quotation Info',0,''),(61596,19509,'120178','deals-mobile','margin-bottom','20',0,''),(61597,19510,'120179','deals-mobile','block_type','1',0,''),(61598,19511,'120180','deals-mobile','block_type','6',0,''),(61599,19511,'120180','deals-mobile','schema','6-3',0,''),(61600,19511,'120180','deals-mobile','schema','6-3',0,'872'),(61601,19512,'120181','deals-mobile','aria_name','account-menu',0,''),(61602,19515,'120184','deals-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(61603,19516,'120185','deals-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(61604,19518,'120187','deals-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(61605,19519,'120188','deals-mobile','block_type','2',0,''),(61606,19519,'120188','deals-mobile','padding-top','20',0,''),(61607,19519,'120188','deals-mobile','margin-bottom','20',0,''),(61608,19520,'120189','deals-mobile','like_button','1',0,''),(61609,19520,'120189','deals-mobile','text','IMAGE_BUTTON_BACK',0,''),(61610,19520,'120189','deals-mobile','link','Quotations',0,''),(61611,19521,'120190','deals-mobile','block_type','3',0,''),(61612,19521,'120190','deals-mobile','schema','3-4',0,'872'),(61613,19522,'120191','deals-mobile','block_type','1',0,''),(61614,19522,'120191','deals-mobile','padding-right','20',0,''),(61615,19522,'120191','deals-mobile','padding-bottom','20',0,''),(61616,19523,'120192','deals-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(61617,19524,'120193','deals-mobile','orders_data','telephone',0,''),(61618,19525,'120194','deals-mobile','block_type','1',0,''),(61619,19525,'120194','deals-mobile','padding-right','20',0,''),(61620,19525,'120194','deals-mobile','padding-bottom','20',0,''),(61621,19526,'120195','deals-mobile','orders_data','name',0,''),(61622,19527,'120196','deals-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(61623,19528,'120197','deals-mobile','block_type','1',0,''),(61624,19528,'120197','deals-mobile','padding-right','20',0,''),(61625,19529,'120198','deals-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(61626,19530,'120199','deals-mobile','orders_data','shipping_method',0,''),(61627,19531,'120200','deals-mobile','block_type','1',0,''),(61628,19531,'120200','deals-mobile','padding-right','20',0,''),(61629,19531,'120200','deals-mobile','padding-bottom','20',0,''),(61630,19532,'120201','deals-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(61631,19533,'120202','deals-mobile','orders_data','delivery_address',0,''),(61632,19534,'120203','deals-mobile','block_type','1',0,''),(61633,19534,'120203','deals-mobile','padding-bottom','20',0,''),(61634,19535,'120204','deals-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(61635,19536,'120205','deals-mobile','orders_data','billing_address',0,''),(61636,19537,'120206','deals-mobile','block_type','1',0,''),(61637,19538,'120207','deals-mobile','orders_data','payment_method',0,''),(61638,19539,'120208','deals-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(61639,19542,'120211','deals-mobile','text','<h1>Quotations</h1>',1,''),(61640,19543,'120212','deals-mobile','block_type','1',0,''),(61641,19544,'120213','deals-mobile','block_type','6',0,''),(61642,19544,'120213','deals-mobile','schema','6-3',0,''),(61643,19544,'120213','deals-mobile','schema','6-3',0,'872'),(61644,19545,'120214','deals-mobile','aria_name','account-menu',0,''),(61645,19546,'120215','deals-mobile','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(61646,19547,'120216','deals-mobile','margin-bottom','20',0,''),(61647,19548,'120217','deals-mobile','block_type','1',0,''),(61648,19549,'120218','deals-mobile','pagination','bottom',0,''),(61649,19551,'120220','deals-mobile','width','800',0,''),(61650,19552,'120221','deals-mobile','block_type','1',0,''),(61651,19552,'120221','deals-mobile','border-top-width','1',0,''),(61652,19552,'120221','deals-mobile','border-left-width','1',0,''),(61653,19552,'120221','deals-mobile','border-right-width','1',0,''),(61654,19552,'120221','deals-mobile','border-bottom-width','1',0,''),(61655,19552,'120221','deals-mobile','border-top-color','#000000',0,''),(61656,19552,'120221','deals-mobile','border-left-color','#000000',0,''),(61657,19552,'120221','deals-mobile','border-right-color','#000000',0,''),(61658,19552,'120221','deals-mobile','border-bottom-color','#000000',0,''),(61659,19553,'120222','deals-mobile','block_type','11',0,''),(61660,19554,'120223','deals-mobile','block_type','1',0,''),(61661,19554,'120223','deals-mobile','padding-top','10',0,''),(61662,19554,'120223','deals-mobile','padding-right','10',0,''),(61663,19554,'120223','deals-mobile','padding-bottom','10',0,''),(61664,19554,'120223','deals-mobile','border-right-width','1',0,''),(61665,19554,'120223','deals-mobile','border-right-color','#000000',0,''),(61666,19555,'120224','deals-mobile','block_type','1',0,''),(61667,19555,'120224','deals-mobile','padding-left','10',0,''),(61668,19555,'120224','deals-mobile','padding-right','10',0,''),(61669,19555,'120224','deals-mobile','padding-bottom','10',0,''),(61670,19556,'120225','deals-mobile','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(61671,19556,'120225','deals-mobile','font-size','11',0,''),(61672,19556,'120225','deals-mobile','font-style','italic',0,''),(61673,19557,'120226','deals-mobile','block_type','9',0,''),(61674,19558,'120227','deals-mobile','text','2.',0,''),(61675,19558,'120227','deals-mobile','font-size','12',0,''),(61676,19558,'120227','deals-mobile','text-align','right',0,''),(61677,19558,'120227','deals-mobile','padding-right','5',0,''),(61678,19559,'120228','deals-mobile','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(61679,19559,'120228','deals-mobile','font-size','12',0,''),(61680,19559,'120228','deals-mobile','padding-bottom','10',0,''),(61681,19560,'120229','deals-mobile','block_type','1',0,''),(61682,19561,'120230','deals-mobile','text','Shipping Instructions:',0,''),(61683,19561,'120230','deals-mobile','font-weight','bold',0,''),(61684,19561,'120230','deals-mobile','font-size','14',0,''),(61685,19561,'120230','deals-mobile','padding-bottom','5',0,''),(61686,19561,'120230','deals-mobile','padding-left','10',0,''),(61687,19562,'120231','deals-mobile','block_type','9',0,''),(61688,19563,'120232','deals-mobile','text','1.',0,''),(61689,19563,'120232','deals-mobile','font-size','12',0,''),(61690,19563,'120232','deals-mobile','text-align','right',0,''),(61691,19563,'120232','deals-mobile','padding-right','5',0,''),(61692,19564,'120233','deals-mobile','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(61693,19564,'120233','deals-mobile','font-size','12',0,''),(61694,19564,'120233','deals-mobile','padding-bottom','10',0,''),(61695,19565,'120234','deals-mobile','block_type','9',0,''),(61696,19566,'120235','deals-mobile','text','3.',0,''),(61697,19566,'120235','deals-mobile','font-size','12',0,''),(61698,19566,'120235','deals-mobile','text-align','right',0,''),(61699,19566,'120235','deals-mobile','padding-right','5',0,''),(61700,19567,'120236','deals-mobile','text','Ship only the items that are authorized.',0,''),(61701,19567,'120236','deals-mobile','font-size','12',0,''),(61702,19567,'120236','deals-mobile','padding-bottom','10',0,''),(61703,19568,'120237','deals-mobile','block_type','9',0,''),(61704,19569,'120238','deals-mobile','text','4.',0,''),(61705,19569,'120238','deals-mobile','font-size','12',0,''),(61706,19569,'120238','deals-mobile','text-align','right',0,''),(61707,19569,'120238','deals-mobile','padding-right','5',0,''),(61708,19570,'120239','deals-mobile','text','Ship returned items to:',0,''),(61709,19570,'120239','deals-mobile','font-size','12',0,''),(61710,19570,'120239','deals-mobile','padding-bottom','5',0,''),(61711,19571,'120240','deals-mobile','font-size','11',0,''),(61712,19571,'120240','deals-mobile','font-style','italic',0,''),(61713,19571,'120240','deals-mobile','padding-bottom','5',0,''),(61714,19572,'120241','deals-mobile','block_type','3',0,''),(61715,19572,'120241','deals-mobile','padding-right','10',0,''),(61716,19573,'120242','deals-mobile','text','Customer Signature:',0,''),(61717,19573,'120242','deals-mobile','font-weight','bold',0,''),(61718,19573,'120242','deals-mobile','font-size','11',0,''),(61719,19573,'120242','deals-mobile','padding-top','5',0,''),(61720,19573,'120242','deals-mobile','padding-left','10',0,''),(61721,19574,'120243','deals-mobile','text','&nbsp;',0,''),(61722,19574,'120243','deals-mobile','border-bottom-width','1',0,''),(61723,19574,'120243','deals-mobile','border-bottom-color','#000000',0,''),(61724,19575,'120244','deals-mobile','block_type','5',0,''),(61725,19576,'120245','deals-mobile','text','Date:',0,''),(61726,19576,'120245','deals-mobile','padding-top','5',0,''),(61727,19576,'120245','deals-mobile','font-size','11',0,''),(61728,19576,'120245','deals-mobile','font-weight','bold',0,''),(61729,19576,'120245','deals-mobile','padding-left','5',0,''),(61730,19577,'120246','deals-mobile','text','&nbsp;',0,''),(61731,19577,'120246','deals-mobile','border-bottom-width','1',0,''),(61732,19577,'120246','deals-mobile','border-bottom-color','#000000',0,''),(61733,19578,'120247','deals-mobile','block_type','3',0,''),(61734,19578,'120247','deals-mobile','padding-top','10',0,''),(61735,19578,'120247','deals-mobile','padding-bottom','10',0,''),(61736,19578,'120247','deals-mobile','padding-right','10',0,''),(61737,19579,'120248','deals-mobile','font-size','11',0,''),(61738,19579,'120248','deals-mobile','font-weight','bold',0,''),(61739,19579,'120248','deals-mobile','text','Return Approval:',0,''),(61740,19579,'120248','deals-mobile','padding-top','5',0,''),(61741,19579,'120248','deals-mobile','padding-left','10',0,''),(61742,19580,'120249','deals-mobile','border-bottom-width','1',0,''),(61743,19580,'120249','deals-mobile','border-bottom-color','#000000',0,''),(61744,19580,'120249','deals-mobile','text','&nbsp;',0,''),(61745,19581,'120250','deals-mobile','block_type','5',0,''),(61746,19582,'120251','deals-mobile','text','Date:',0,''),(61747,19582,'120251','deals-mobile','padding-top','5',0,''),(61748,19582,'120251','deals-mobile','font-size','11',0,''),(61749,19582,'120251','deals-mobile','font-weight','bold',0,''),(61750,19582,'120251','deals-mobile','padding-left','5',0,''),(61751,19583,'120252','deals-mobile','text','&nbsp;',0,''),(61752,19583,'120252','deals-mobile','border-bottom-width','1',0,''),(61753,19583,'120252','deals-mobile','border-bottom-color','#000000',0,''),(61754,19584,'120253','deals-mobile','block_type','1',0,''),(61755,19584,'120253','deals-mobile','padding-left','10',0,''),(61756,19584,'120253','deals-mobile','padding-right','10',0,''),(61757,19584,'120253','deals-mobile','padding-bottom','10',0,''),(61758,19585,'120254','deals-mobile','text','Use this space for additional Comments:',0,''),(61759,19585,'120254','deals-mobile','font-size','11',0,''),(61760,19585,'120254','deals-mobile','font-style','italic',0,''),(61761,19586,'120255','deals-mobile','text','&nbsp;',0,''),(61762,19586,'120255','deals-mobile','border-bottom-width','1',0,''),(61763,19586,'120255','deals-mobile','border-bottom-color','#000000',0,''),(61764,19587,'120256','deals-mobile','text','&nbsp;',0,''),(61765,19587,'120256','deals-mobile','border-bottom-width','1',0,''),(61766,19587,'120256','deals-mobile','border-bottom-color','#000000',0,''),(61767,19587,'120256','deals-mobile','padding-top','5',0,''),(61768,19588,'120257','deals-mobile','text','&nbsp;',0,''),(61769,19588,'120257','deals-mobile','border-bottom-width','1',0,''),(61770,19588,'120257','deals-mobile','border-bottom-color','#000000',0,''),(61771,19588,'120257','deals-mobile','padding-top','5',0,''),(61772,19589,'120258','deals-mobile','text','&nbsp;',0,''),(61773,19589,'120258','deals-mobile','border-bottom-width','1',0,''),(61774,19589,'120258','deals-mobile','border-bottom-color','#000000',0,''),(61775,19589,'120258','deals-mobile','padding-top','5',0,''),(61776,19590,'120259','deals-mobile','block_type','1',0,''),(61777,19590,'120259','deals-mobile','padding-top','10',0,''),(61778,19590,'120259','deals-mobile','padding-left','40',0,''),(61779,19590,'120259','deals-mobile','padding-right','40',0,''),(61780,19590,'120259','deals-mobile','padding-bottom','10',0,''),(61781,19591,'120260','deals-mobile','block_type','1',0,''),(61782,19591,'120260','deals-mobile','padding-top','10',0,''),(61783,19591,'120260','deals-mobile','padding-left','10',0,''),(61784,19591,'120260','deals-mobile','padding-right','10',0,''),(61785,19591,'120260','deals-mobile','padding-bottom','10',0,''),(61786,19591,'120260','deals-mobile','border-top-width','1',0,''),(61787,19591,'120260','deals-mobile','border-left-width','1',0,''),(61788,19591,'120260','deals-mobile','border-right-width','1',0,''),(61789,19591,'120260','deals-mobile','border-bottom-width','1',0,''),(61790,19591,'120260','deals-mobile','border-top-color','#000000',0,''),(61791,19591,'120260','deals-mobile','border-left-color','#000000',0,''),(61792,19591,'120260','deals-mobile','border-right-color','#000000',0,''),(61793,19591,'120260','deals-mobile','border-bottom-color','#000000',0,''),(61794,19592,'120261','deals-mobile','block_type','3',0,''),(61795,19593,'120262','deals-mobile','data','rrDelivery_name',0,''),(61796,19593,'120262','deals-mobile','font-size','9',0,''),(61797,19594,'120263','deals-mobile','block_type','2',0,''),(61798,19595,'120264','deals-mobile','text','RMA#:',0,''),(61799,19595,'120264','deals-mobile','font-size','10',0,''),(61800,19596,'120265','deals-mobile','data','rrNumber',0,''),(61801,19596,'120265','deals-mobile','font-size','9',0,''),(61802,19597,'120266','deals-mobile','block_type','5',0,''),(61803,19598,'120267','deals-mobile','font-size','9',0,''),(61804,19599,'120268','deals-mobile','block_type','1',0,''),(61805,19601,'120270','deals-mobile','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(61806,19601,'120270','deals-mobile','font-size','12',0,''),(61807,19601,'120270','deals-mobile','font-style','italic',0,''),(61808,19601,'120270','deals-mobile','padding-bottom','20',0,''),(61809,19602,'120271','deals-mobile','block_type','11',0,''),(61810,19602,'120271','deals-mobile','border-top-width','1',0,''),(61811,19602,'120271','deals-mobile','border-left-width','1',0,''),(61812,19602,'120271','deals-mobile','border-right-width','1',0,''),(61813,19602,'120271','deals-mobile','border-bottom-width','1',0,''),(61814,19602,'120271','deals-mobile','border-top-color','#000000',0,''),(61815,19602,'120271','deals-mobile','border-left-color','#000000',0,''),(61816,19602,'120271','deals-mobile','border-right-color','#000000',0,''),(61817,19602,'120271','deals-mobile','border-bottom-color','#000000',0,''),(61818,19603,'120272','deals-mobile','block_type','1',0,''),(61819,19603,'120272','deals-mobile','border-right-width','1',0,''),(61820,19603,'120272','deals-mobile','border-right-color','#000000',0,''),(61821,19603,'120272','deals-mobile','padding-top','10',0,''),(61822,19603,'120272','deals-mobile','padding-right','10',0,''),(61823,19603,'120272','deals-mobile','padding-bottom','10',0,''),(61824,19604,'120273','deals-mobile','block_type','1',0,''),(61825,19604,'120273','deals-mobile','padding-left','15',0,''),(61826,19605,'120274','deals-mobile','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(61827,19605,'120274','deals-mobile','font-size','11',0,''),(61828,19605,'120274','deals-mobile','font-style','italic',0,''),(61829,19605,'120274','deals-mobile','padding-bottom','5',0,''),(61830,19606,'120275','deals-mobile','text','Replacement Policy:',0,''),(61831,19606,'120275','deals-mobile','font-size','14',0,''),(61832,19606,'120275','deals-mobile','padding-bottom','5',0,''),(61833,19606,'120275','deals-mobile','font-weight','bold',0,''),(61834,19607,'120276','deals-mobile','block_type','9',0,''),(61835,19608,'120277','deals-mobile','text','2.',0,''),(61836,19608,'120277','deals-mobile','font-size','12',0,''),(61837,19608,'120277','deals-mobile','text-align','right',0,''),(61838,19608,'120277','deals-mobile','margin-right','5',0,''),(61839,19609,'120278','deals-mobile','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(61840,19609,'120278','deals-mobile','font-size','12',0,''),(61841,19609,'120278','deals-mobile','padding-bottom','5',0,''),(61842,19610,'120279','deals-mobile','block_type','9',0,''),(61843,19611,'120280','deals-mobile','text','1.',0,''),(61844,19611,'120280','deals-mobile','font-size','12',0,''),(61845,19611,'120280','deals-mobile','text-align','right',0,''),(61846,19611,'120280','deals-mobile','padding-right','5',0,''),(61847,19612,'120281','deals-mobile','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(61848,19612,'120281','deals-mobile','font-size','12',0,''),(61849,19612,'120281','deals-mobile','padding-bottom','5',0,''),(61850,19613,'120282','deals-mobile','block_type','9',0,''),(61851,19614,'120283','deals-mobile','text','3.',0,''),(61852,19614,'120283','deals-mobile','font-size','12',0,''),(61853,19614,'120283','deals-mobile','text-align','right',0,''),(61854,19614,'120283','deals-mobile','margin-right','5',0,''),(61855,19615,'120284','deals-mobile','text','Return the authorized item(s) per shipping instructions.',0,''),(61856,19615,'120284','deals-mobile','font-size','12',0,''),(61857,19615,'120284','deals-mobile','padding-bottom','5',0,''),(61858,19616,'120285','deals-mobile','block_type','9',0,''),(61859,19617,'120286','deals-mobile','text','4.',0,''),(61860,19617,'120286','deals-mobile','font-size','12',0,''),(61861,19617,'120286','deals-mobile','text-align','right',0,''),(61862,19617,'120286','deals-mobile','margin-right','5',0,''),(61863,19618,'120287','deals-mobile','text','Our Replacement Department will process your request.',0,''),(61864,19618,'120287','deals-mobile','font-size','12',0,''),(61865,19618,'120287','deals-mobile','padding-bottom','5',0,''),(61866,19619,'120288','deals-mobile','block_type','2',0,''),(61867,19619,'120288','deals-mobile','padding-left','10',0,''),(61868,19619,'120288','deals-mobile','padding-top','20',0,''),(61869,19619,'120288','deals-mobile','padding-right','10',0,''),(61870,19620,'120289','deals-mobile','block_type','5',0,''),(61871,19621,'120290','deals-mobile','text','RMA No:',0,''),(61872,19621,'120290','deals-mobile','font-size','12',0,''),(61873,19621,'120290','deals-mobile','font-weight','bold',0,''),(61874,19622,'120291','deals-mobile','data','rrNumber',0,''),(61875,19622,'120291','deals-mobile','font-size','12',0,''),(61876,19622,'120291','deals-mobile','font-weight','bold',0,''),(61877,19623,'120292','deals-mobile','block_type','2',0,''),(61878,19624,'120293','deals-mobile','text','Date Issued:',0,''),(61879,19624,'120293','deals-mobile','font-size','12',0,''),(61880,19624,'120293','deals-mobile','font-weight','bold',0,''),(61881,19625,'120294','deals-mobile','data','rrDateCreate',0,''),(61882,19625,'120294','deals-mobile','font-size','12',0,''),(61883,19625,'120294','deals-mobile','font-weight','bold',0,''),(61884,19626,'120295','deals-mobile','block_type','1',0,''),(61885,19626,'120295','deals-mobile','padding-top','10',0,''),(61886,19626,'120295','deals-mobile','padding-left','10',0,''),(61887,19626,'120295','deals-mobile','padding-right','10',0,''),(61888,19626,'120295','deals-mobile','padding-bottom','10',0,''),(61889,19627,'120296','deals-mobile','block_type','2',0,''),(61890,19628,'120297','deals-mobile','block_type','11',0,''),(61891,19629,'120298','deals-mobile','text','Company:',0,''),(61892,19629,'120298','deals-mobile','font-size','12',0,''),(61893,19630,'120299','deals-mobile','data','rrDelivery_company',0,''),(61894,19630,'120299','deals-mobile','font-size','12',0,''),(61895,19631,'120300','deals-mobile','block_type','2',0,''),(61896,19632,'120301','deals-mobile','text','Contact Name:',0,''),(61897,19632,'120301','deals-mobile','font-size','12',0,''),(61898,19633,'120302','deals-mobile','data','rrDelivery_name',0,''),(61899,19633,'120302','deals-mobile','font-size','12',0,''),(61900,19634,'120303','deals-mobile','block_type','9',0,''),(61901,19634,'120303','deals-mobile','padding-top','5',0,''),(61902,19635,'120304','deals-mobile','text','Address:',0,''),(61903,19635,'120304','deals-mobile','font-size','12',0,''),(61904,19636,'120305','deals-mobile','data','rrDelivery_street_address',0,''),(61905,19636,'120305','deals-mobile','font-size','12',0,''),(61906,19637,'120306','deals-mobile','block_type','2',0,''),(61907,19637,'120306','deals-mobile','padding-top','5',0,''),(61908,19638,'120307','deals-mobile','block_type','11',0,''),(61909,19639,'120308','deals-mobile','text','City:',0,''),(61910,19639,'120308','deals-mobile','font-size','12',0,''),(61911,19640,'120309','deals-mobile','data','rrDelivery_city',0,''),(61912,19640,'120309','deals-mobile','font-size','12',0,''),(61913,19641,'120310','deals-mobile','block_type','11',0,''),(61914,19642,'120311','deals-mobile','text','State:',0,''),(61915,19642,'120311','deals-mobile','font-size','12',0,''),(61916,19643,'120312','deals-mobile','data','rrDelivery_state',0,''),(61917,19643,'120312','deals-mobile','font-size','12',0,''),(61918,19644,'120313','deals-mobile','block_type','2',0,''),(61919,19644,'120313','deals-mobile','padding-top','5',0,''),(61920,19645,'120314','deals-mobile','block_type','11',0,''),(61921,19646,'120315','deals-mobile','text','Country:',0,''),(61922,19646,'120315','deals-mobile','font-size','12',0,''),(61923,19647,'120316','deals-mobile','data','rrDelivery_country',0,''),(61924,19647,'120316','deals-mobile','font-size','12',0,''),(61925,19648,'120317','deals-mobile','block_type','11',0,''),(61926,19649,'120318','deals-mobile','text','Postcode:',0,''),(61927,19649,'120318','deals-mobile','font-size','12',0,''),(61928,19650,'120319','deals-mobile','data','rrDelivery_postcode',0,''),(61929,19650,'120319','deals-mobile','font-size','12',0,''),(61930,19651,'120320','deals-mobile','block_type','2',0,''),(61931,19651,'120320','deals-mobile','padding-top','5',0,''),(61932,19652,'120321','deals-mobile','block_type','11',0,''),(61933,19653,'120322','deals-mobile','text','Email:',0,''),(61934,19653,'120322','deals-mobile','font-size','12',0,''),(61935,19654,'120323','deals-mobile','data','rrDelivery_email_address',0,''),(61936,19654,'120323','deals-mobile','font-size','12',0,''),(61937,19655,'120324','deals-mobile','block_type','11',0,''),(61938,19656,'120325','deals-mobile','text','Phone:',0,''),(61939,19656,'120325','deals-mobile','font-size','12',0,''),(61940,19657,'120326','deals-mobile','data','rrDelivery_telephone',0,''),(61941,19657,'120326','deals-mobile','font-size','12',0,''),(61942,19658,'120327','deals-mobile','block_type','1',0,''),(61943,19658,'120327','deals-mobile','border-bottom-width','1',0,''),(61944,19658,'120327','deals-mobile','border-bottom-color','#000000',0,''),(61945,19659,'120328','deals-mobile','text-align','center',0,''),(61946,19659,'120328','deals-mobile','logo','themes/deals-mobile/img/Furntech-1.jpg',1,''),(61947,19659,'120328','deals-mobile','padding-top','10',0,''),(61948,19659,'120328','deals-mobile','padding-bottom','10',0,''),(61949,19660,'120329','deals-mobile','text','Return Material Authorization (RMA) Form',0,''),(61950,19660,'120329','deals-mobile','text-align','center',0,''),(61951,19660,'120329','deals-mobile','font-size','12',0,''),(61952,19660,'120329','deals-mobile','font-weight','bold',0,''),(61953,19660,'120329','deals-mobile','font-family','Arial',0,''),(61954,19661,'120330','deals-mobile','block_type','1',0,''),(61955,19661,'120330','deals-mobile','style_class','item-holder',0,''),(61956,19661,'120330','deals-mobile','padding-top','25',0,''),(61957,19661,'120330','deals-mobile','padding-bottom','25',0,''),(61958,19661,'120330','deals-mobile','text-align','left',0,''),(61959,19661,'120330','deals-mobile','border-top-width','1',0,''),(61960,19661,'120330','deals-mobile','border-top-color','#e0e0e0',0,''),(61961,19662,'120331','deals-mobile','block_type','7',0,''),(61962,19662,'120331','deals-mobile','schema','7-2',0,''),(61963,19663,'120332','deals-mobile','block_type','5',0,''),(61964,19663,'120332','deals-mobile','schema','5-2',0,''),(61965,19664,'120333','deals-mobile','block_type','1',0,''),(61966,19665,'120334','deals-mobile','text-align','right',0,''),(61967,19665,'120334','deals-mobile','margin-top','4',0,''),(61968,19665,'120334','deals-mobile','margin-bottom','7',0,''),(61969,19665,'120334','deals-mobile','float','left',0,''),(61970,19666,'120335','deals-mobile','padding-top','6',0,''),(61971,19666,'120335','deals-mobile','padding-left','5',0,''),(61972,19666,'120335','deals-mobile','float','left',0,''),(61973,19666,'120335','deals-mobile','clear','none',0,''),(61974,19667,'120336','deals-mobile','clear','none',0,''),(61975,19667,'120336','deals-mobile','padding-right','20',0,''),(61976,19668,'120337','deals-mobile','padding-right','20',0,''),(61977,19668,'120337','deals-mobile','max-width','300',0,''),(61978,19668,'120337','deals-mobile','margin_left_measure','auto',0,''),(61979,19668,'120337','deals-mobile','margin_right_measure','auto',0,''),(61980,19669,'120338','deals-mobile','clear','none',0,''),(61981,19670,'120339','deals-mobile','padding-right','20',0,''),(61982,19671,'120340','deals-mobile','description_characters','200',0,''),(61983,19671,'120340','deals-mobile','clear','none',0,''),(61984,19671,'120340','deals-mobile','padding-right','20',0,''),(61985,19672,'120341','deals-mobile','margin-bottom','20',0,''),(61986,19673,'120342','deals-mobile','block_type','1',0,''),(61987,19673,'120342','deals-mobile','padding-left','40',0,''),(61988,19673,'120342','deals-mobile','style_class','right-aria',0,''),(61990,19674,'120343','deals-mobile','text-align','right',0,''),(61991,19674,'120343','deals-mobile','margin-bottom','10',0,''),(61992,19675,'120344','deals-mobile','margin-bottom','10',0,''),(61993,19675,'120344','deals-mobile','text-align','right',0,''),(61994,19677,'120346','deals-mobile','margin-bottom','15',0,''),(61995,19677,'120346','deals-mobile','text-align','right',0,''),(61996,19678,'120347','deals-mobile','margin-bottom','10',0,''),(61997,19679,'120348','deals-mobile','text-align','right',0,''),(61998,19679,'120348','deals-mobile','margin-bottom','15',0,''),(61999,19680,'120349','deals-mobile','block_type','1',0,''),(62000,19681,'120350','deals-mobile','padding-bottom','20',0,''),(62001,19682,'120351','deals-mobile','text-align','right',0,''),(62002,19682,'120351','deals-mobile','margin-bottom','40',0,''),(62003,19683,'120352','deals-mobile','text','<h1>Samples</h1>',1,''),(62004,19684,'120353','deals-mobile','block_type','1',0,''),(62005,19685,'120354','deals-mobile','block_type','6',0,''),(62006,19685,'120354','deals-mobile','schema','6-3',0,''),(62007,19685,'120354','deals-mobile','schema','6-3',0,'872'),(62008,19686,'120355','deals-mobile','aria_name','account-menu',0,''),(62009,19687,'120356','deals-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(62010,19688,'120357','deals-mobile','show_pagenation','1',0,''),(62011,19688,'120357','deals-mobile','link','Sample Info',0,''),(62012,19688,'120357','deals-mobile','margin-bottom','20',0,''),(62013,19689,'120358','deals-mobile','block_type','1',0,''),(62014,19690,'120359','deals-mobile','block_type','6',0,''),(62015,19691,'120360','deals-mobile','aria_name','account-menu',0,''),(62016,19692,'120361','deals-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(62017,19693,'120362','deals-mobile','block_type','3',0,''),(62018,19694,'120363','deals-mobile','block_type','1',0,''),(62019,19694,'120363','deals-mobile','padding-right','20',0,''),(62020,19694,'120363','deals-mobile','padding-bottom','20',0,''),(62021,19695,'120364','deals-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(62022,19696,'120365','deals-mobile','orders_data','telephone',0,''),(62023,19697,'120366','deals-mobile','block_type','1',0,''),(62024,19697,'120366','deals-mobile','padding-right','20',0,''),(62025,19697,'120366','deals-mobile','padding-bottom','20',0,''),(62026,19698,'120367','deals-mobile','orders_data','name',0,''),(62027,19699,'120368','deals-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(62028,19700,'120369','deals-mobile','block_type','1',0,''),(62029,19700,'120369','deals-mobile','padding-right','20',0,''),(62030,19700,'120369','deals-mobile','padding-bottom','20',0,''),(62031,19701,'120370','deals-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(62032,19702,'120371','deals-mobile','orders_data','delivery_address',0,''),(62033,19703,'120372','deals-mobile','block_type','1',0,''),(62034,19703,'120372','deals-mobile','padding-right','20',0,''),(62035,19704,'120373','deals-mobile','orders_data','shipping_method',0,''),(62036,19705,'120374','deals-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(62037,19706,'120375','deals-mobile','block_type','1',0,''),(62038,19706,'120375','deals-mobile','padding-bottom','20',0,''),(62039,19707,'120376','deals-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(62040,19708,'120377','deals-mobile','orders_data','billing_address',0,''),(62041,19709,'120378','deals-mobile','block_type','1',0,''),(62042,19710,'120379','deals-mobile','orders_data','payment_method',0,''),(62043,19711,'120380','deals-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(62044,19712,'120381','deals-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(62045,19715,'120384','deals-mobile','block_type','2',0,''),(62046,19715,'120384','deals-mobile','padding-top','20',0,''),(62047,19715,'120384','deals-mobile','margin-bottom','20',0,''),(62048,19716,'120385','deals-mobile','like_button','1',0,''),(62049,19716,'120385','deals-mobile','text','IMAGE_BUTTON_BACK',0,''),(62050,19716,'120385','deals-mobile','link','Samples',0,''),(62051,19718,'120387','deals-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(62052,19719,'120388','deals-mobile','block_type','1',0,''),(62053,19720,'120389','deals-mobile','block_type','6',0,''),(62054,19720,'120389','deals-mobile','schema','6-3',0,''),(62055,19720,'120389','deals-mobile','schema','6-3',0,'872'),(62056,19721,'120390','deals-mobile','aria_name','account-menu',0,''),(62057,19722,'120391','deals-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(62058,19723,'120392','deals-mobile','link','Order History Info',0,''),(62059,19723,'120392','deals-mobile','text','TEXT_VIEW',0,''),(62060,19723,'120392','deals-mobile','max_orders','3',0,''),(62061,19723,'120392','deals-mobile','link_pay','Order pay',0,''),(62062,19723,'120392','deals-mobile','margin-bottom','30',0,''),(62063,19723,'120392','deals-mobile','text_pay','ORDER_PAY',0,''),(62064,19724,'120393','deals-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(62065,19725,'120394','deals-mobile','block_type','15',0,''),(62066,19725,'120394','deals-mobile','margin-bottom','30',0,''),(62067,19725,'120394','deals-mobile','padding-top','20',0,''),(62068,19725,'120394','deals-mobile','padding-left','20',0,''),(62069,19725,'120394','deals-mobile','padding-right','20',0,''),(62070,19725,'120394','deals-mobile','padding-bottom','20',0,''),(62071,19725,'120394','deals-mobile','border-top-width','1',0,''),(62072,19725,'120394','deals-mobile','border-top-color','#e0e0e0',0,''),(62073,19725,'120394','deals-mobile','border-left-width','1',0,''),(62074,19725,'120394','deals-mobile','border-right-width','1',0,''),(62075,19725,'120394','deals-mobile','border-bottom-width','1',0,''),(62076,19725,'120394','deals-mobile','border-left-color','#e0e0e0',0,''),(62077,19725,'120394','deals-mobile','border-right-color','#e0e0e0',0,''),(62078,19725,'120394','deals-mobile','border-bottom-color','#e0e0e0',0,''),(62079,19725,'120394','deals-mobile','schema','15-2',0,'872'),(62080,19726,'120395','deals-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(62081,19726,'120395','deals-mobile','font-family','trueloaded',0,'3'),(62082,19726,'120395','deals-mobile','content','\\e920',0,'3'),(62083,19726,'120395','deals-mobile','color','#ee4225',0,'3'),(62084,19726,'120395','deals-mobile','font-size','30',0,'3'),(62085,19726,'120395','deals-mobile','text-align','center',0,'3'),(62086,19726,'120395','deals-mobile','margin-bottom','10',0,'3'),(62087,19726,'120395','deals-mobile','text-align','center',0,''),(62088,19726,'120395','deals-mobile','font-size','16',0,''),(62089,19726,'120395','deals-mobile','text-transform','uppercase',0,''),(62090,19726,'120395','deals-mobile','line-height','1',0,'3'),(62092,19727,'120396','deals-mobile','font-family','Varela Round',0,''),(62093,19727,'120396','deals-mobile','color','#ee4225',0,''),(62094,19727,'120396','deals-mobile','font-size','14',0,''),(62095,19727,'120396','deals-mobile','text-align','center',0,''),(62096,19728,'120397','deals-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(62097,19728,'120397','deals-mobile','font-family','trueloaded',0,'3'),(62098,19728,'120397','deals-mobile','content','\\e928',0,'3'),(62099,19728,'120397','deals-mobile','color','#ee4225',0,'3'),(62100,19728,'120397','deals-mobile','font-size','30',0,'3'),(62101,19728,'120397','deals-mobile','text-align','center',0,'3'),(62102,19728,'120397','deals-mobile','text-align','center',0,''),(62103,19728,'120397','deals-mobile','font-size','16',0,''),(62104,19728,'120397','deals-mobile','text-transform','uppercase',0,''),(62105,19728,'120397','deals-mobile','line-height','1',0,'3'),(62107,19729,'120398','deals-mobile','link','download_orders',0,''),(62108,19729,'120398','deals-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(62109,19729,'120398','deals-mobile','hide_link','orders',0,''),(62110,19729,'120398','deals-mobile','text-align','center',0,''),(62111,19729,'120398','deals-mobile','popup','2',0,''),(62112,19729,'120398','deals-mobile','font-size','14',0,''),(62113,19730,'120399','deals-mobile','font-family','Varela Round',0,''),(62114,19730,'120399','deals-mobile','color','#ee4225',0,''),(62115,19730,'120399','deals-mobile','font-size','14',0,''),(62116,19730,'120399','deals-mobile','text-align','center',0,''),(62117,19731,'120400','deals-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(62118,19731,'120400','deals-mobile','font-family','trueloaded',0,'3'),(62119,19731,'120400','deals-mobile','content','\\e922',0,'3'),(62120,19731,'120400','deals-mobile','color','#ee4225',0,'3'),(62121,19731,'120400','deals-mobile','font-size','30',0,'3'),(62122,19731,'120400','deals-mobile','line-height','1',0,'3'),(62123,19731,'120400','deals-mobile','font-size','16',0,''),(62124,19731,'120400','deals-mobile','text-align','center',0,''),(62125,19731,'120400','deals-mobile','text-transform','uppercase',0,''),(62127,19732,'120401','deals-mobile','font-family','Varela Round',0,''),(62128,19732,'120401','deals-mobile','color','#ee4225',0,''),(62129,19732,'120401','deals-mobile','line-height','1',0,''),(62130,19732,'120401','deals-mobile','text-align','center',0,''),(62131,19732,'120401','deals-mobile','font-size','14',0,''),(62132,19733,'120402','deals-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(62133,19733,'120402','deals-mobile','content','\\e994',0,'3'),(62134,19733,'120402','deals-mobile','font-family','trueloaded',0,'3'),(62135,19733,'120402','deals-mobile','color','#ee4225',0,'3'),(62136,19733,'120402','deals-mobile','font-size','30',0,'3'),(62137,19733,'120402','deals-mobile','line-height','1',0,'3'),(62138,19733,'120402','deals-mobile','font-size','16',0,''),(62139,19733,'120402','deals-mobile','text-align','center',0,''),(62140,19733,'120402','deals-mobile','text-transform','uppercase',0,''),(62142,19734,'120403','deals-mobile','link','Gift Certificate',0,''),(62143,19734,'120403','deals-mobile','text','GIFT_CERTIFICATE',0,''),(62144,19734,'120403','deals-mobile','popup','1',0,''),(62145,19734,'120403','deals-mobile','text-align','center',0,''),(62146,19734,'120403','deals-mobile','font-size','14',0,''),(62147,19735,'120404','deals-mobile','font-family','Varela Round',0,''),(62148,19735,'120404','deals-mobile','color','#ee4225',0,''),(62149,19735,'120404','deals-mobile','font-size','14',0,''),(62150,19735,'120404','deals-mobile','text-align','center',0,''),(62151,19736,'120405','deals-mobile','text','TEXT_VIEW_HISTORY',0,''),(62152,19736,'120405','deals-mobile','popup','1',0,''),(62153,19736,'120405','deals-mobile','text-align','center',0,''),(62154,19736,'120405','deals-mobile','link','Points Earnt History',0,''),(62155,19736,'120405','deals-mobile','font-size','14',0,''),(62156,19737,'120406','deals-mobile','font-family','Varela Round',0,''),(62157,19737,'120406','deals-mobile','color','#ee4225',0,''),(62158,19737,'120406','deals-mobile','font-size','14',0,''),(62159,19737,'120406','deals-mobile','text-align','center',0,''),(62160,19738,'120407','deals-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(62161,19738,'120407','deals-mobile','content','\\e990',0,'3'),(62162,19738,'120407','deals-mobile','font-family','trueloaded',0,'3'),(62163,19738,'120407','deals-mobile','font-size','30',0,'3'),(62164,19738,'120407','deals-mobile','text-align','center',0,'3'),(62165,19738,'120407','deals-mobile','line-height','1',0,'3'),(62166,19738,'120407','deals-mobile','color','#ee4225',0,'3'),(62167,19738,'120407','deals-mobile','font-size','16',0,''),(62168,19738,'120407','deals-mobile','text-align','center',0,''),(62169,19738,'120407','deals-mobile','text-transform','uppercase',0,''),(62171,19739,'120408','deals-mobile','block_type','1',0,''),(62172,19740,'120409','deals-mobile','hide_parents','2',0,''),(62173,19741,'120410','deals-mobile','text','<div class=\"heading-3\">##TEXT_GIFT_CARDS##</div>',0,''),(62174,19743,'120412','deals-mobile','block_type','1',0,''),(62175,19744,'120413','deals-mobile','block_type','6',0,''),(62176,19745,'120414','deals-mobile','class','menu-simple',0,''),(62177,19747,'120416','deals-mobile','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(62178,19749,'120418','deals-mobile','text','<div class=\"heading-4\">Categories</div>',0,''),(62179,19750,'120419','deals-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(62180,19751,'120420','deals-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(62181,19753,'120422','deals-mobile','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(62182,19754,'120423','deals-mobile','block_type','1',0,''),(62183,19755,'120424','deals-mobile','style_class','middle-form',0,''),(62184,19755,'120424','deals-mobile','margin-bottom','30',0,''),(62185,19756,'120425','deals-mobile','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(62186,19757,'120426','deals-mobile','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(62187,19757,'120426','deals-mobile','style_class','middle-form',0,''),(62188,19758,'120427','deals-mobile','style_class','middle-form',0,''),(62189,19759,'120428','deals-mobile','block_type','1',0,''),(62190,19760,'120429','deals-mobile','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(62191,19760,'120429','deals-mobile','padding-top','100',0,''),(62192,19760,'120429','deals-mobile','margin-bottom','100',0,''),(62193,19760,'120429','deals-mobile','text-align','center',0,''),(62194,19760,'120429','deals-mobile','font-size','20',0,''),(62195,19761,'120430','deals-mobile','block_type','1',0,''),(62196,19762,'120431','deals-mobile','block_type','6',0,''),(62197,19762,'120431','deals-mobile','schema','6-3',0,''),(62198,19762,'120431','deals-mobile','schema','6-3',0,'872'),(62199,19763,'120432','deals-mobile','aria_name','account-menu',0,''),(62200,19764,'120433','deals-mobile','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(62201,19765,'120434','deals-mobile','text','##SUBSCRIPTION_TEXT##',0,''),(62202,19767,'120436','deals-mobile','block_type','1',0,''),(62203,19768,'120437','deals-mobile','block_type','1',0,''),(62204,19768,'120437','deals-mobile','font-weight','normal',0,''),(62205,19769,'120438','deals-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',1,''),(62206,19769,'120438','deals-mobile','font-weight','400',0,''),(62207,19770,'120439','deals-mobile','block_type','3',0,''),(62208,19770,'120439','deals-mobile','font-weight','400',0,''),(62209,19770,'120439','deals-mobile','schema','3-4',0,'864'),(62210,19771,'120440','deals-mobile','text','&nbsp;',0,''),(62211,19771,'120440','deals-mobile','font-weight','normal',0,''),(62212,19772,'120441','deals-mobile','font-weight','normal',0,''),(62213,19772,'120441','deals-mobile','box_align','2',0,''),(62214,19772,'120441','deals-mobile','padding-top','40',0,''),(62215,19773,'120442','deals-mobile','font-weight','400',0,''),(62216,19773,'120442','deals-mobile','text-align','right',0,''),(62217,19773,'120442','deals-mobile','padding-top','40',0,''),(62218,19773,'120442','deals-mobile','padding-bottom','100',0,''),(62219,19773,'120442','deals-mobile','text-align','center',0,'864'),(62220,19773,'120442','deals-mobile','float','none',0,'864'),(62221,19774,'120443','deals-mobile','block_type','1',0,''),(62222,19775,'120444','deals-mobile','block_type','1',0,''),(62223,19775,'120444','deals-mobile','font-weight','normal',0,''),(62224,19776,'120445','deals-mobile','block_type','1',0,''),(62225,19776,'120445','deals-mobile','text-align','center',0,''),(62226,19776,'120445','deals-mobile','padding-top','30',0,''),(62227,19776,'120445','deals-mobile','margin-bottom','200',0,''),(62228,19777,'120446','deals-mobile','display','inline-block',0,''),(62229,19778,'120447','deals-mobile','display','inline-block',0,''),(62230,19778,'120447','deals-mobile','clear','none',0,''),(62231,19778,'120447','deals-mobile','margin-left','20',0,''),(62232,19779,'120448','deals-mobile','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(62234,19783,'120452','deals-mobile','width','680',0,''),(62235,19783,'120452','deals-mobile','font-weight','normal',0,''),(62236,19783,'120452','deals-mobile','font-size','12',0,''),(62237,19783,'120452','deals-mobile','padding-top','20',0,''),(62238,19783,'120452','deals-mobile','padding-bottom','20',0,''),(62239,19783,'120452','deals-mobile','color','#424242',0,''),(62240,19784,'120453','deals-mobile','block_type','2',0,''),(62241,19784,'120453','deals-mobile','font-weight','normal',0,''),(62242,19784,'120453','deals-mobile','padding-bottom','20',0,''),(62243,19785,'120454','deals-mobile','block_type','1',0,''),(62244,19786,'120455','deals-mobile','font-weight','normal',0,''),(62245,19786,'120455','deals-mobile','text-align','right',0,''),(62246,19786,'120455','deals-mobile','padding-bottom','10',0,''),(62247,19786,'120455','deals-mobile','address_spacer',',',0,''),(62248,19786,'120455','deals-mobile','font-size','12',0,''),(62249,19787,'120456','deals-mobile','block_type','11',0,''),(62250,19787,'120456','deals-mobile','font-weight','normal',0,''),(62251,19788,'120457','deals-mobile','text','<p>Phone:</p>',1,''),(62252,19788,'120457','deals-mobile','font-weight','normal',0,''),(62253,19788,'120457','deals-mobile','text-align','right',0,''),(62254,19789,'120458','deals-mobile','font-weight','normal',0,''),(62255,19789,'120458','deals-mobile','text-align','right',0,''),(62256,19790,'120459','deals-mobile','block_type','11',0,''),(62257,19790,'120459','deals-mobile','font-weight','normal',0,''),(62258,19791,'120460','deals-mobile','text','<p>Web:</p>',1,''),(62259,19791,'120460','deals-mobile','font-weight','normal',0,''),(62260,19791,'120460','deals-mobile','text-align','right',0,''),(62261,19792,'120461','deals-mobile','font-weight','normal',0,''),(62262,19792,'120461','deals-mobile','text-align','right',0,''),(62263,19793,'120462','deals-mobile','block_type','11',0,''),(62264,19793,'120462','deals-mobile','font-weight','normal',0,''),(62265,19794,'120463','deals-mobile','text','<p>Email:</p>',1,''),(62266,19794,'120463','deals-mobile','font-weight','normal',0,''),(62267,19794,'120463','deals-mobile','text-align','right',0,''),(62268,19795,'120464','deals-mobile','font-weight','normal',0,''),(62269,19795,'120464','deals-mobile','text-align','right',0,''),(62270,19796,'120465','deals-mobile','block_type','4',0,''),(62271,19796,'120465','deals-mobile','font-weight','normal',0,''),(62272,19796,'120465','deals-mobile','border-top-width','1',0,''),(62273,19796,'120465','deals-mobile','border-top-color','#e0e0e0',0,''),(62274,19796,'120465','deals-mobile','border-left-width','1',0,''),(62275,19796,'120465','deals-mobile','border-left-color','#e0e0e0',0,''),(62276,19796,'120465','deals-mobile','border-right-width','1',0,''),(62277,19796,'120465','deals-mobile','border-right-color','#e0e0e0',0,''),(62278,19796,'120465','deals-mobile','border-bottom-width','1',0,''),(62279,19796,'120465','deals-mobile','border-bottom-color','#e0e0e0',0,''),(62280,19797,'120466','deals-mobile','block_type','2',0,''),(62281,19797,'120466','deals-mobile','font-weight','normal',0,''),(62282,19797,'120466','deals-mobile','border-right-width','1',0,''),(62283,19797,'120466','deals-mobile','border-right-color','#e0e0e0',0,''),(62284,19798,'120467','deals-mobile','block_type','1',0,''),(62285,19798,'120467','deals-mobile','font-weight','400',0,''),(62286,19798,'120467','deals-mobile','background-color','#eeeeee',0,''),(62287,19798,'120467','deals-mobile','padding-top','10',0,''),(62288,19798,'120467','deals-mobile','padding-left','10',0,''),(62289,19798,'120467','deals-mobile','padding-right','10',0,''),(62290,19798,'120467','deals-mobile','padding-bottom','30',0,''),(62291,19799,'120468','deals-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(62292,19799,'120468','deals-mobile','font-size','14',0,''),(62293,19799,'120468','deals-mobile','font-weight','bold',0,''),(62294,19800,'120469','deals-mobile','font-size','12',0,''),(62295,19801,'120470','deals-mobile','block_type','1',0,''),(62296,19801,'120470','deals-mobile','font-weight','normal',0,''),(62297,19801,'120470','deals-mobile','padding-top','10',0,''),(62298,19801,'120470','deals-mobile','padding-left','10',0,''),(62299,19801,'120470','deals-mobile','padding-right','10',0,''),(62300,19801,'120470','deals-mobile','padding-bottom','10',0,''),(62301,19802,'120471','deals-mobile','text','<p>PHONE NUMBER:</p>',1,''),(62302,19802,'120471','deals-mobile','font-size','14',0,''),(62303,19802,'120471','deals-mobile','font-weight','bold',0,''),(62304,19802,'120471','deals-mobile','padding-top','10',0,''),(62305,19803,'120472','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(62306,19803,'120472','deals-mobile','font-weight','bold',0,''),(62307,19803,'120472','deals-mobile','font-size','14',0,''),(62308,19803,'120472','deals-mobile','padding-top','10',0,''),(62309,19804,'120473','deals-mobile','text','<p>CUSTOMER:</p>',1,''),(62310,19804,'120473','deals-mobile','font-size','13',0,''),(62311,19804,'120473','deals-mobile','font-weight','bold',0,''),(62312,19805,'120474','deals-mobile','font-weight','normal',0,''),(62313,19806,'120475','deals-mobile','font-weight','normal',0,''),(62314,19808,'120477','deals-mobile','block_type','2',0,''),(62315,19808,'120477','deals-mobile','font-weight','normal',0,''),(62316,19808,'120477','deals-mobile','border-top-width','1',0,''),(62317,19808,'120477','deals-mobile','border-top-color','#e0e0e0',0,''),(62318,19808,'120477','deals-mobile','border-right-width','1',0,''),(62319,19808,'120477','deals-mobile','border-right-color','#e0e0e0',0,''),(62320,19809,'120478','deals-mobile','block_type','1',0,''),(62321,19809,'120478','deals-mobile','font-weight','normal',0,''),(62322,19809,'120478','deals-mobile','padding-top','10',0,''),(62323,19809,'120478','deals-mobile','padding-left','10',0,''),(62324,19809,'120478','deals-mobile','padding-right','10',0,''),(62325,19809,'120478','deals-mobile','padding-bottom','10',0,''),(62326,19809,'120478','deals-mobile','border-right-width','1',0,''),(62327,19809,'120478','deals-mobile','border-right-color','#e0e0e0',0,''),(62328,19810,'120479','deals-mobile','text','<p>Shipping via</p>',1,''),(62329,19810,'120479','deals-mobile','font-weight','bold',0,''),(62330,19810,'120479','deals-mobile','font-size','14',0,''),(62331,19812,'120481','deals-mobile','block_type','1',0,''),(62332,19812,'120481','deals-mobile','font-weight','normal',0,''),(62333,19812,'120481','deals-mobile','padding-top','10',0,''),(62334,19812,'120481','deals-mobile','padding-left','10',0,''),(62335,19812,'120481','deals-mobile','padding-right','10',0,''),(62336,19812,'120481','deals-mobile','padding-bottom','10',0,''),(62337,19814,'120483','deals-mobile','text','<p>Shipping service</p>',1,''),(62338,19814,'120483','deals-mobile','font-weight','bold',0,''),(62339,19814,'120483','deals-mobile','font-size','14',0,''),(62340,19815,'120484','deals-mobile','text','<p>Payment date:</p>',1,''),(62341,19815,'120484','deals-mobile','font-weight','bold',0,''),(62342,19815,'120484','deals-mobile','text-align','center',0,''),(62343,19815,'120484','deals-mobile','font-size','12',0,''),(62344,19816,'120485','deals-mobile','font-weight','normal',0,''),(62345,19816,'120485','deals-mobile','text-align','center',0,''),(62346,19817,'120486','deals-mobile','text','<p>Payment Method:</p>',1,''),(62347,19817,'120486','deals-mobile','font-weight','bold',0,''),(62348,19817,'120486','deals-mobile','text-align','center',0,''),(62349,19818,'120487','deals-mobile','font-size','14',0,''),(62350,19818,'120487','deals-mobile','font-weight','bold',0,''),(62351,19818,'120487','deals-mobile','text-align','center',0,''),(62352,19818,'120487','deals-mobile','padding-bottom','10',0,''),(62353,19818,'120487','deals-mobile','padding-top','10',0,''),(62354,19819,'120488','deals-mobile','font-weight','normal',0,''),(62355,19819,'120488','deals-mobile','text-align','center',0,''),(62356,19819,'120488','deals-mobile','padding-bottom','10',0,''),(62357,19820,'120489','deals-mobile','font-weight','normal',0,''),(62358,19820,'120489','deals-mobile','text-align','center',0,''),(62359,19820,'120489','deals-mobile','padding-bottom','20',0,''),(62360,19821,'120490','deals-mobile','block_type','3',0,''),(62361,19821,'120490','deals-mobile','font-weight','normal',0,''),(62362,19821,'120490','deals-mobile','padding-top','20',0,''),(62363,19822,'120491','deals-mobile','text','<p>If undelivered please return to:</p>',1,''),(62364,19822,'120491','deals-mobile','font-size','12',0,''),(62365,19822,'120491','deals-mobile','font-weight','bold',0,''),(62366,19823,'120492','deals-mobile','font-size','12',0,''),(62367,19824,'120493','deals-mobile','font-weight','400',0,''),(62368,19824,'120493','deals-mobile','text-align','center',0,''),(62369,19824,'120493','deals-mobile','padding-top','0',0,''),(62371,19824,'120493','deals-mobile','padding-left','20',0,''),(62372,19824,'120493','deals-mobile','padding-right','20',0,''),(62373,19825,'120494','deals-mobile','text','<p>Thank you for your order</p>',1,''),(62374,19825,'120494','deals-mobile','color','#1da1f2',0,''),(62375,19825,'120494','deals-mobile','font-size','13',0,''),(62376,19825,'120494','deals-mobile','font-weight','bold',0,''),(62377,19825,'120494','deals-mobile','padding-top','5',0,''),(62378,19825,'120494','deals-mobile','text-align','center',0,''),(62379,19826,'120495','deals-mobile','block_type','6',0,''),(62380,19826,'120495','deals-mobile','font-weight','normal',0,''),(62381,19826,'120495','deals-mobile','font-size','16',0,''),(62382,19827,'120496','deals-mobile','text','<p>Phone:</p>',1,''),(62383,19827,'120496','deals-mobile','font-weight','normal',0,''),(62384,19827,'120496','deals-mobile','text-align','right',0,''),(62385,19827,'120496','deals-mobile','font-size','12',0,''),(62386,19828,'120497','deals-mobile','font-weight','normal',0,''),(62387,19828,'120497','deals-mobile','text-align','right',0,''),(62388,19828,'120497','deals-mobile','font-size','12',0,''),(62389,19829,'120498','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(62390,19829,'120498','deals-mobile','font-size','12',0,''),(62391,19829,'120498','deals-mobile','font-weight','bold',0,''),(62392,19829,'120498','deals-mobile','text-align','right',0,''),(62393,19830,'120499','deals-mobile','block_type','6',0,''),(62394,19830,'120499','deals-mobile','font-weight','normal',0,''),(62395,19830,'120499','deals-mobile','font-size','16',0,''),(62396,19831,'120500','deals-mobile','text','<p>Email:</p>',1,''),(62397,19831,'120500','deals-mobile','font-weight','normal',0,''),(62398,19831,'120500','deals-mobile','text-align','right',0,''),(62399,19831,'120500','deals-mobile','font-size','12',0,''),(62400,19832,'120501','deals-mobile','font-weight','normal',0,''),(62401,19832,'120501','deals-mobile','text-align','right',0,''),(62402,19832,'120501','deals-mobile','font-size','12',0,''),(62403,19833,'120502','deals-mobile','font-weight','400',0,''),(62404,19833,'120502','deals-mobile','padding-top','20',0,''),(62405,19833,'120502','deals-mobile','padding-bottom','0',0,''),(62406,19833,'120502','deals-mobile','font-size','12',0,''),(62407,19834,'120503','deals-mobile','block_type','5',0,''),(62408,19834,'120503','deals-mobile','font-weight','normal',0,''),(62409,19834,'120503','deals-mobile','border-bottom-width','1',0,''),(62410,19834,'120503','deals-mobile','border-bottom-color','#e0e0e0',0,''),(62411,19834,'120503','deals-mobile','border-top-width','1',0,''),(62412,19834,'120503','deals-mobile','border-top-color','#e0e0e0',0,''),(62413,19834,'120503','deals-mobile','border-left-color','#e0e0e0',0,''),(62414,19834,'120503','deals-mobile','border-left-width','1',0,''),(62415,19835,'120504','deals-mobile','block_type','1',0,''),(62416,19835,'120504','deals-mobile','font-weight','normal',0,''),(62417,19835,'120504','deals-mobile','padding-top','10',0,''),(62418,19835,'120504','deals-mobile','padding-left','10',0,''),(62419,19835,'120504','deals-mobile','padding-right','10',0,''),(62420,19836,'120505','deals-mobile','font-weight','400',0,''),(62421,19836,'120505','deals-mobile','line-height','120',0,''),(62422,19836,'120505','deals-mobile','line_height_measure','%',0,''),(62423,19836,'120505','deals-mobile','font-size','12',0,''),(62424,19837,'120506','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(62425,19837,'120506','deals-mobile','font-size','14',0,''),(62426,19837,'120506','deals-mobile','font-weight','bold',0,''),(62427,19837,'120506','deals-mobile','padding-bottom','10',0,''),(62428,19838,'120507','deals-mobile','block_type','1',0,''),(62429,19838,'120507','deals-mobile','background-color','#eeeeee',0,''),(62430,19838,'120507','deals-mobile','padding-top','20',0,''),(62431,19838,'120507','deals-mobile','padding-left','10',0,''),(62432,19838,'120507','deals-mobile','padding-right','10',0,''),(62433,19838,'120507','deals-mobile','padding-bottom','20',0,''),(62434,19838,'120507','deals-mobile','font-size','14',0,''),(62435,19839,'120508','deals-mobile','font-weight','normal',0,''),(62436,19839,'120508','deals-mobile','text-align','right',0,''),(62437,19839,'120508','deals-mobile','font-size','14',0,''),(62438,19839,'120508','deals-mobile','box_align','3',0,''),(62439,19840,'120509','deals-mobile','block_type','1',0,''),(62440,19840,'120509','deals-mobile','padding-top','35',0,''),(62441,19840,'120509','deals-mobile','padding-bottom','35',0,''),(62442,19841,'120510','deals-mobile','block_type','7',0,''),(62443,19841,'120510','deals-mobile','schema','7-2',0,''),(62444,19842,'120511','deals-mobile','block_type','1',0,''),(62445,19842,'120511','deals-mobile','style_class','blog_list_content',0,''),(62446,19844,'120513','deals-mobile','text-align','center',0,''),(62447,19845,'120514','deals-mobile','aria_name','blogsidebar',0,''),(62448,19845,'120514','deals-mobile','style_class','blogsidebar',0,''),(62449,19846,'120515','deals-mobile','block_type','1',0,''),(62450,19846,'120515','deals-mobile','padding-top','35',0,''),(62451,19846,'120515','deals-mobile','padding-bottom','35',0,''),(62452,19847,'120516','deals-mobile','block_type','7',0,''),(62453,19847,'120516','deals-mobile','schema','7-1',0,''),(62455,19848,'120517','deals-mobile','block_type','1',0,''),(62456,19848,'120517','deals-mobile','style_class','blog_list_content',0,''),(62457,19849,'120518','deals-mobile','items_on_page','12',0,''),(62458,19849,'120518','deals-mobile','items_cut_off','200',0,''),(62459,19850,'120519','deals-mobile','text-align','center',0,''),(62460,19850,'120519','deals-mobile','hide_parents','1',0,''),(62461,19851,'120520','deals-mobile','aria_name','blogsidebar',0,''),(62462,19851,'120520','deals-mobile','padding-left','35',0,''),(62463,19851,'120520','deals-mobile','style_class','blogsidebar',0,''),(62465,19852,'120521','deals-mobile','banners_group','blog',0,''),(62466,19852,'120521','deals-mobile','margin-bottom','40',0,''),(62467,19853,'120522','deals-mobile','block_type','1',0,''),(62468,19853,'120522','deals-mobile','padding-top','35',0,''),(62469,19853,'120522','deals-mobile','padding-bottom','35',0,''),(62470,19854,'120523','deals-mobile','block_type','7',0,''),(62471,19854,'120523','deals-mobile','schema','7-2',0,''),(62472,19856,'120525','deals-mobile','block_type','1',0,''),(62473,19857,'120526','deals-mobile','text','<div class=\"heading-3\">##TEXT_BLOG_RELATED_PRODUCTS##</div>',0,''),(62474,19858,'120527','deals-mobile','count_products','8',0,''),(62475,19858,'120527','deals-mobile','col_in_row','4',0,''),(62476,19858,'120527','deals-mobile','view_as','carousel',0,''),(62477,19858,'120527','deals-mobile','show_stock','1',0,''),(62478,19858,'120527','deals-mobile','show_description','1',0,''),(62479,19858,'120527','deals-mobile','show_properties','1',0,''),(62480,19858,'120527','deals-mobile','show_rating','1',0,''),(62481,19858,'120527','deals-mobile','show_rating_counts','1',0,''),(62482,19858,'120527','deals-mobile','show_qty_input','1',0,''),(62483,19858,'120527','deals-mobile','show_wishlist_button','1',0,''),(62484,19858,'120527','deals-mobile','show_compare','1',0,''),(62488,19858,'120527','deals-mobile','listing_type','productListing',0,''),(62489,19858,'120527','deals-mobile','hide_parents','2',0,''),(62490,19859,'120528','deals-mobile','block_type','1',0,''),(62491,19859,'120528','deals-mobile','style_class','blog-white-bg',0,''),(62492,19859,'120528','deals-mobile','padding-bottom','20',0,''),(62493,19863,'120532','deals-mobile','block_type','1',0,''),(62494,19863,'120532','deals-mobile','padding-top','20',0,''),(62495,19863,'120532','deals-mobile','margin-top','20',0,''),(62496,19863,'120532','deals-mobile','border-top-width','1',0,''),(62497,19863,'120532','deals-mobile','border-top-color','#EDE5D5',0,''),(62498,19863,'120532','deals-mobile','clear','both',0,''),(62499,19864,'120533','deals-mobile','box_align','4',0,''),(62500,19864,'120533','deals-mobile','text-align','center',0,''),(62501,19865,'120534','deals-mobile','text-align','center',0,''),(62502,19866,'120535','deals-mobile','aria_name','blogsidebar',0,''),(62503,19866,'120535','deals-mobile','style_class','blogsidebar',0,''),(62504,19867,'120536','deals-mobile','block_type','1',0,''),(62505,19867,'120536','deals-mobile','padding-top','35',0,''),(62506,19867,'120536','deals-mobile','padding-bottom','35',0,''),(62507,19868,'120537','deals-mobile','block_type','7',0,''),(62508,19868,'120537','deals-mobile','schema','7-2',0,''),(62509,19869,'120538','deals-mobile','block_type','1',0,''),(62510,19869,'120538','deals-mobile','style_class','blog_list_content',0,''),(62511,19871,'120540','deals-mobile','text-align','center',0,''),(62512,19871,'120540','deals-mobile','hide_parents','1',0,''),(62513,19872,'120541','deals-mobile','aria_name','blogsidebar',0,''),(62514,19872,'120541','deals-mobile','style_class','blogsidebar',0,''),(62515,19873,'120542','deals-mobile','block_type','1',0,''),(62516,19875,'120544','deals-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(62517,19876,'120545','deals-mobile','block_type','1',0,''),(62518,19877,'120546','deals-mobile','block_type','2',0,''),(62519,19877,'120546','deals-mobile','margin-bottom','20',0,''),(62520,19878,'120547','deals-mobile','block_type','1',0,''),(62521,19878,'120547','deals-mobile','padding-right','20',0,''),(62522,19879,'120548','deals-mobile','field','50',0,''),(62523,19880,'120549','deals-mobile','field','49',0,''),(62524,19881,'120550','deals-mobile','block_type','2',0,''),(62525,19883,'120552','deals-mobile','float','right',0,''),(62526,19883,'120552','deals-mobile','clear','none',0,''),(62527,19884,'120553','deals-mobile','float','right',0,''),(62528,19884,'120553','deals-mobile','margin-left','20',0,''),(62529,19885,'120554','deals-mobile','block_type','2',0,''),(62530,19885,'120554','deals-mobile','margin-bottom','20',0,''),(62531,19886,'120555','deals-mobile','block_type','1',0,''),(62532,19886,'120555','deals-mobile','padding-right','20',0,''),(62533,19887,'120556','deals-mobile','field','66',0,''),(62534,19888,'120557','deals-mobile','block_type','1',0,''),(62535,19888,'120557','deals-mobile','padding-left','20',0,''),(62536,19889,'120558','deals-mobile','field','67',0,''),(62537,19890,'120559','deals-mobile','text','<div class=\"heading-2\">##TRADE_REFERENCES##</div>',0,''),(62538,19890,'120559','deals-mobile','text-align','center',0,''),(62539,19891,'120560','deals-mobile','text','<div class=\"heading-2\">##BANK_ACCOUNT_DETAILS##</div>',0,''),(62540,19891,'120560','deals-mobile','text-align','center',0,''),(62541,19892,'120561','deals-mobile','text','<div class=\"heading-2\">##TEXT_DECLARATION##</div>',0,''),(62542,19892,'120561','deals-mobile','text-align','center',0,''),(62543,19893,'120562','deals-mobile','block_type','2',0,''),(62544,19893,'120562','deals-mobile','margin-bottom','20',0,''),(62545,19894,'120563','deals-mobile','block_type','1',0,''),(62546,19894,'120563','deals-mobile','padding-right','20',0,''),(62547,19895,'120564','deals-mobile','field','62',0,''),(62548,19896,'120565','deals-mobile','field','60',0,''),(62549,19897,'120566','deals-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 1</div>',0,''),(62550,19898,'120567','deals-mobile','field','61',0,''),(62551,19899,'120568','deals-mobile','block_type','1',0,''),(62552,19899,'120568','deals-mobile','padding-left','20',0,''),(62553,19900,'120569','deals-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 2</div>',0,''),(62554,19901,'120570','deals-mobile','field','64',0,''),(62555,19902,'120571','deals-mobile','field','63',0,''),(62556,19903,'120572','deals-mobile','field','65',0,''),(62557,19904,'120573','deals-mobile','block_type','2',0,''),(62558,19904,'120573','deals-mobile','margin-bottom','20',0,''),(62559,19905,'120574','deals-mobile','block_type','1',0,''),(62560,19905,'120574','deals-mobile','padding-right','20',0,''),(62561,19906,'120575','deals-mobile','field','52',0,''),(62562,19907,'120576','deals-mobile','field','51',0,''),(62563,19908,'120577','deals-mobile','block_type','2',0,''),(62564,19909,'120578','deals-mobile','block_type','1',0,''),(62565,19909,'120578','deals-mobile','padding-right','20',0,''),(62566,19910,'120579','deals-mobile','group','15',0,''),(62567,19911,'120580','deals-mobile','text','<div class=\"heading-3\">##CATEGORY_COMPANY##</div>',0,''),(62568,19913,'120582','deals-mobile','block_type','2',0,''),(62569,19914,'120583','deals-mobile','field','68',0,''),(62570,19914,'120583','deals-mobile','padding-right','10',0,''),(62571,19915,'120584','deals-mobile','block_type','2',0,''),(62572,19915,'120584','deals-mobile','border-bottom-width','1',0,''),(62573,19915,'120584','deals-mobile','border-bottom-color','#e0e0e0',0,''),(62574,19915,'120584','deals-mobile','padding-bottom','10',0,''),(62575,19915,'120584','deals-mobile','margin-bottom','20',0,''),(62576,19916,'120585','deals-mobile','block_type','1',0,''),(62577,19916,'120585','deals-mobile','padding-right','10',0,''),(62578,19917,'120586','deals-mobile','field','69',0,''),(62579,19918,'120587','deals-mobile','field','75',0,''),(62580,19919,'120588','deals-mobile','field','71',0,''),(62581,19920,'120589','deals-mobile','field','73',0,''),(62582,19921,'120590','deals-mobile','block_type','1',0,''),(62583,19921,'120590','deals-mobile','padding-left','10',0,''),(62584,19922,'120591','deals-mobile','field','76',0,''),(62585,19923,'120592','deals-mobile','field','74',0,''),(62586,19924,'120593','deals-mobile','field','72',0,''),(62587,19925,'120594','deals-mobile','field','70',0,''),(62588,19926,'120595','deals-mobile','block_type','1',0,''),(62589,19926,'120595','deals-mobile','padding-left','20',0,''),(62590,19927,'120596','deals-mobile','group','16',0,''),(62591,19928,'120597','deals-mobile','block_type','2',0,''),(62592,19929,'120598','deals-mobile','block_type','1',0,''),(62593,19929,'120598','deals-mobile','padding-right','10',0,''),(62594,19930,'120599','deals-mobile','field','77',0,''),(62595,19931,'120600','deals-mobile','field','79',0,''),(62596,19932,'120601','deals-mobile','block_type','1',0,''),(62597,19932,'120601','deals-mobile','padding-left','10',0,''),(62598,19933,'120602','deals-mobile','field','78',0,''),(62599,19934,'120603','deals-mobile','block_type','2',0,''),(62600,19935,'120604','deals-mobile','block_type','1',0,''),(62601,19935,'120604','deals-mobile','padding-right','10',0,''),(62602,19936,'120605','deals-mobile','field','82',0,''),(62603,19937,'120606','deals-mobile','field','80',0,''),(62604,19938,'120607','deals-mobile','field','84',0,''),(62605,19939,'120608','deals-mobile','block_type','1',0,''),(62606,19939,'120608','deals-mobile','padding-left','10',0,''),(62607,19940,'120609','deals-mobile','field','83',0,''),(62608,19941,'120610','deals-mobile','field','81',0,''),(62609,19942,'120611','deals-mobile','field','85',0,''),(62610,19943,'120612','deals-mobile','text','<div class=\"heading-3\">##OWNERS_DETAILS##</div>',0,''),(62611,19944,'120613','deals-mobile','block_type','2',0,''),(62612,19944,'120613','deals-mobile','margin-bottom','20',0,''),(62613,19945,'120614','deals-mobile','block_type','1',0,''),(62614,19945,'120614','deals-mobile','padding-right','20',0,''),(62615,19946,'120615','deals-mobile','field','53',0,''),(62616,19947,'120616','deals-mobile','field','54',0,''),(62617,19948,'120617','deals-mobile','block_type','1',0,''),(62618,19948,'120617','deals-mobile','padding-left','20',0,''),(62619,19949,'120618','deals-mobile','field','55',0,''),(62620,19950,'120619','deals-mobile','text','<div class=\"heading-2\">##TEXT_CUSTOMER_DETAILS##</div>',0,''),(62621,19950,'120619','deals-mobile','text-align','center',0,''),(62622,19951,'120620','deals-mobile','block_type','2',0,''),(62623,19951,'120620','deals-mobile','margin-bottom','20',0,''),(62624,19952,'120621','deals-mobile','block_type','1',0,''),(62625,19952,'120621','deals-mobile','padding-right','20',0,''),(62626,19953,'120622','deals-mobile','field','56',0,''),(62627,19954,'120623','deals-mobile','field','57',0,''),(62628,19955,'120624','deals-mobile','block_type','1',0,''),(62629,19955,'120624','deals-mobile','padding-left','20',0,''),(62630,19956,'120625','deals-mobile','field','58',0,''),(62631,19957,'120626','deals-mobile','field','59',0,''),(62632,19958,'120627','deals-mobile','text','<h1>##TRADE_FORM##</h1>',0,''),(62633,19959,'120628','deals-mobile','text','<div class=\"heading-2\">##DISCOUNT##</div>',0,''),(62634,19959,'120628','deals-mobile','text-align','center',0,''),(62635,19960,'120629','deals-mobile','block_type','1',0,''),(62636,19961,'120630','deals-mobile','block_type','6',0,''),(62637,19962,'120631','deals-mobile','text','Telephone No.',0,''),(62638,19962,'120631','deals-mobile','text-align','right',0,''),(62639,19963,'120632','deals-mobile','field','79',0,''),(62640,19963,'120632','deals-mobile','border-bottom-width','1',0,''),(62641,19963,'120632','deals-mobile','border-bottom-color','#000000',0,''),(62642,19963,'120632','deals-mobile','padding-left','10',0,''),(62643,19964,'120633','deals-mobile','block_type','6',0,''),(62644,19965,'120634','deals-mobile','text','Address',0,''),(62645,19965,'120634','deals-mobile','text-align','right',0,''),(62646,19966,'120635','deals-mobile','fields','company_street_address, company_suburb, company_city',0,''),(62647,19966,'120635','deals-mobile','padding-left','10',0,''),(62648,19966,'120635','deals-mobile','border-bottom-width','1',0,''),(62649,19966,'120635','deals-mobile','border-bottom-color','#000000',0,''),(62650,19967,'120636','deals-mobile','block_type','6',0,''),(62651,19968,'120637','deals-mobile','text','Postcode',0,''),(62652,19968,'120637','deals-mobile','text-align','right',0,''),(62653,19969,'120638','deals-mobile','field','80',0,''),(62654,19969,'120638','deals-mobile','border-bottom-width','1',0,''),(62655,19969,'120638','deals-mobile','border-bottom-color','#000000',0,''),(62656,19969,'120638','deals-mobile','padding-left','10',0,''),(62657,19970,'120639','deals-mobile','block_type','6',0,''),(62658,19971,'120640','deals-mobile','text','Address',0,''),(62659,19971,'120640','deals-mobile','text-align','right',0,''),(62660,19972,'120641','deals-mobile','fields','oner_street_address, owner_suburb, owner_city',0,''),(62661,19972,'120641','deals-mobile','padding-left','10',0,''),(62662,19972,'120641','deals-mobile','border-bottom-width','1',0,''),(62663,19972,'120641','deals-mobile','border-bottom-color','#000000',0,''),(62664,19973,'120642','deals-mobile','block_type','6',0,''),(62665,19973,'120642','deals-mobile','margin-top','20',0,''),(62666,19974,'120643','deals-mobile','text','Owner’s Name',0,''),(62667,19974,'120643','deals-mobile','text-align','right',0,''),(62668,19975,'120644','deals-mobile','fields','owner_firstname owner_lastname',0,''),(62669,19975,'120644','deals-mobile','padding-left','10',0,''),(62670,19975,'120644','deals-mobile','border-bottom-width','1',0,''),(62671,19975,'120644','deals-mobile','border-bottom-color','#000000',0,''),(62672,19976,'120645','deals-mobile','block_type','6',0,''),(62673,19977,'120646','deals-mobile','text','Email',0,''),(62674,19977,'120646','deals-mobile','text-align','right',0,''),(62675,19978,'120647','deals-mobile','field','70',0,''),(62676,19978,'120647','deals-mobile','border-bottom-width','1',0,''),(62677,19978,'120647','deals-mobile','border-bottom-color','#000000',0,''),(62678,19978,'120647','deals-mobile','padding-left','10',0,''),(62679,19979,'120648','deals-mobile','block_type','6',0,''),(62680,19979,'120648','deals-mobile','padding-bottom','20',0,''),(62681,19980,'120649','deals-mobile','text','Telephone No.',0,''),(62682,19980,'120649','deals-mobile','text-align','right',0,''),(62683,19981,'120650','deals-mobile','block_type','11',0,''),(62684,19982,'120651','deals-mobile','field','69',0,''),(62685,19982,'120651','deals-mobile','border-bottom-width','1',0,''),(62686,19982,'120651','deals-mobile','border-bottom-color','#000000',0,''),(62687,19982,'120651','deals-mobile','padding-left','10',0,''),(62688,19983,'120652','deals-mobile','block_type','5',0,''),(62689,19984,'120653','deals-mobile','text','Fax No.',0,''),(62690,19984,'120653','deals-mobile','text-align','right',0,''),(62691,19985,'120654','deals-mobile','field','51',0,''),(62692,19985,'120654','deals-mobile','padding-left','10',0,''),(62693,19985,'120654','deals-mobile','border-bottom-width','1',0,''),(62694,19985,'120654','deals-mobile','border-bottom-color','#000000',0,''),(62695,19986,'120655','deals-mobile','block_type','1',0,''),(62696,19987,'120656','deals-mobile','background-color','#000000',0,''),(62697,19987,'120656','deals-mobile','color','#ffffff',0,''),(62698,19987,'120656','deals-mobile','font-size','20',0,''),(62699,19987,'120656','deals-mobile','text','Customer Details',0,''),(62700,19987,'120656','deals-mobile','padding-left','10',0,''),(62701,19987,'120656','deals-mobile','padding-right','10',0,''),(62702,19988,'120657','deals-mobile','block_type','2',0,''),(62703,19988,'120657','deals-mobile','color','#ffffff',0,''),(62704,19988,'120657','deals-mobile','background-color','#000000',0,''),(62705,19989,'120658','deals-mobile','view_item','name',0,''),(62706,19989,'120658','deals-mobile','color','#ffffff',0,''),(62707,19989,'120658','deals-mobile','font-size','40',0,''),(62708,19990,'120659','deals-mobile','text','New Account Form',0,''),(62709,19990,'120659','deals-mobile','font-size','20',0,''),(62710,19990,'120659','deals-mobile','color','#ffffff',0,''),(62711,19990,'120659','deals-mobile','padding-top','20',0,''),(62712,19991,'120660','deals-mobile','block_type','2',0,''),(62713,19992,'120661','deals-mobile','block_type','2',0,''),(62714,19992,'120661','deals-mobile','padding-top','5',0,''),(62715,19993,'120662','deals-mobile','block_type','10',0,''),(62716,19994,'120663','deals-mobile','text','Limited Company',0,''),(62717,19994,'120663','deals-mobile','font-size','16',0,''),(62718,19995,'120664','deals-mobile','field','49',0,''),(62719,19995,'120664','deals-mobile','padding-left','5',0,''),(62720,19996,'120665','deals-mobile','block_type','10',0,''),(62721,19997,'120666','deals-mobile','text','Sole Trader',0,''),(62722,19997,'120666','deals-mobile','text-align','center',0,''),(62723,19998,'120667','deals-mobile','field','50',0,''),(62724,19998,'120667','deals-mobile','padding-left','5',0,''),(62725,19999,'120668','deals-mobile','block_type','5',0,''),(62726,20000,'120669','deals-mobile','view_item','data_format',0,''),(62727,20000,'120669','deals-mobile','data_format_content','##STREET_ADDRESS##, ##SUBURB##,\n##CITY##, ##POSTCODE##\nTel: ##TELEPHONE##\nEmail: ##EMAIL_ADDRESS##\n',0,''),(62728,20000,'120669','deals-mobile','font-size','14',0,''),(62729,20001,'120670','deals-mobile','block_type','6',0,''),(62730,20002,'120671','deals-mobile','text','Postcode',0,''),(62731,20002,'120671','deals-mobile','text-align','right',0,''),(62732,20003,'120672','deals-mobile','field','71',0,''),(62733,20003,'120672','deals-mobile','border-bottom-width','1',0,''),(62734,20003,'120672','deals-mobile','border-bottom-color','#000000',0,''),(62735,20003,'120672','deals-mobile','padding-left','10',0,''),(62736,20004,'120673','deals-mobile','block_type','6',0,''),(62737,20005,'120674','deals-mobile','text','Business Name',0,''),(62738,20005,'120674','deals-mobile','text-align','right',0,''),(62739,20006,'120675','deals-mobile','field','68',0,''),(62740,20006,'120675','deals-mobile','border-bottom-width','1',0,''),(62741,20006,'120675','deals-mobile','border-bottom-color','#000000',0,''),(62742,20006,'120675','deals-mobile','padding-left','10',0,''),(62743,20007,'120676','deals-mobile','block_type','6',0,''),(62744,20007,'120676','deals-mobile','padding-bottom','20',0,''),(62745,20008,'120677','deals-mobile','text','Nature of Business',0,''),(62746,20008,'120677','deals-mobile','text-align','right',0,''),(62747,20009,'120678','deals-mobile','field','52',0,''),(62748,20009,'120678','deals-mobile','border-bottom-width','1',0,''),(62749,20009,'120678','deals-mobile','border-bottom-color','#000000',0,''),(62750,20009,'120678','deals-mobile','padding-left','10',0,''),(62751,20010,'120679','deals-mobile','block_type','6',0,''),(62752,20011,'120680','deals-mobile','text','Bank Name',0,''),(62753,20011,'120680','deals-mobile','text-align','right',0,''),(62754,20011,'120680','deals-mobile','font-size','16',0,''),(62755,20012,'120681','deals-mobile','field','53',0,''),(62756,20012,'120681','deals-mobile','border-bottom-width','1',0,''),(62757,20012,'120681','deals-mobile','border-bottom-color','#000000',0,''),(62758,20012,'120681','deals-mobile','padding-left','10',0,''),(62759,20013,'120682','deals-mobile','block_type','1',0,''),(62760,20013,'120682','deals-mobile','padding-top','20',0,''),(62761,20013,'120682','deals-mobile','padding-bottom','10',0,''),(62762,20014,'120683','deals-mobile','background-color','#000000',0,''),(62763,20014,'120683','deals-mobile','color','#ffffff',0,''),(62764,20014,'120683','deals-mobile','font-size','20',0,''),(62765,20014,'120683','deals-mobile','text','Discount (%)',0,''),(62766,20014,'120683','deals-mobile','padding-left','10',0,''),(62767,20014,'120683','deals-mobile','padding-right','10',0,''),(62768,20015,'120684','deals-mobile','block_type','1',0,''),(62769,20015,'120684','deals-mobile','padding-bottom','10',0,''),(62770,20016,'120685','deals-mobile','background-color','#000000',0,''),(62771,20016,'120685','deals-mobile','color','#ffffff',0,''),(62772,20016,'120685','deals-mobile','font-size','20',0,''),(62773,20016,'120685','deals-mobile','text','Bank Account Details',0,''),(62774,20016,'120685','deals-mobile','padding-left','10',0,''),(62775,20016,'120685','deals-mobile','padding-right','10',0,''),(62776,20017,'120686','deals-mobile','block_type','6',0,''),(62777,20017,'120686','deals-mobile','padding-bottom','20',0,''),(62778,20018,'120687','deals-mobile','text','Account No',0,''),(62779,20018,'120687','deals-mobile','text-align','right',0,''),(62780,20019,'120688','deals-mobile','field','54',0,''),(62781,20019,'120688','deals-mobile','border-bottom-width','1',0,''),(62782,20019,'120688','deals-mobile','border-bottom-color','#000000',0,''),(62783,20019,'120688','deals-mobile','padding-left','10',0,''),(62784,20020,'120689','deals-mobile','block_type','6',0,''),(62785,20021,'120690','deals-mobile','text','Address',0,''),(62786,20021,'120690','deals-mobile','text-align','right',0,''),(62787,20022,'120691','deals-mobile','field','55',0,''),(62788,20022,'120691','deals-mobile','border-bottom-width','1',0,''),(62789,20022,'120691','deals-mobile','border-bottom-color','#000000',0,''),(62790,20022,'120691','deals-mobile','padding-left','10',0,''),(62791,20023,'120692','deals-mobile','block_type','14',0,''),(62792,20023,'120692','deals-mobile','padding-bottom','20',0,''),(62793,20024,'120693','deals-mobile','text','33.33% Sale or Return',0,''),(62794,20024,'120693','deals-mobile','text-align','right',0,''),(62795,20024,'120693','deals-mobile','font-size','16',0,''),(62796,20025,'120694','deals-mobile','block_type','13',0,''),(62797,20026,'120695','deals-mobile','field','56',0,''),(62798,20026,'120695','deals-mobile','padding-left','10',0,''),(62799,20027,'120696','deals-mobile','text','35% Firm',0,''),(62800,20027,'120696','deals-mobile','text-align','right',0,''),(62801,20028,'120697','deals-mobile','field','58',0,''),(62802,20028,'120697','deals-mobile','padding-left','10',0,''),(62803,20029,'120698','deals-mobile','block_type','10',0,''),(62804,20030,'120699','deals-mobile','block_type','6',0,''),(62805,20031,'120700','deals-mobile','text','Address',0,''),(62806,20031,'120700','deals-mobile','text-align','right',0,''),(62807,20032,'120701','deals-mobile','field','61',0,''),(62808,20032,'120701','deals-mobile','border-bottom-width','1',0,''),(62809,20032,'120701','deals-mobile','border-bottom-color','#000000',0,''),(62810,20032,'120701','deals-mobile','padding-left','10',0,''),(62811,20033,'120702','deals-mobile','block_type','1',0,''),(62812,20033,'120702','deals-mobile','padding-bottom','10',0,''),(62813,20034,'120703','deals-mobile','background-color','#000000',0,''),(62814,20034,'120703','deals-mobile','color','#ffffff',0,''),(62815,20034,'120703','deals-mobile','font-size','20',0,''),(62816,20034,'120703','deals-mobile','text','Trade References',0,''),(62817,20034,'120703','deals-mobile','padding-left','10',0,''),(62818,20034,'120703','deals-mobile','padding-right','10',0,''),(62819,20035,'120704','deals-mobile','block_type','1',0,''),(62820,20036,'120705','deals-mobile','text','I would like to open a trade account with Vladislav B. Malyshev and agree to abide by their General Terms & Conditions –\na signed copy of which is returned to them with this form in the supplied SAE. I have retained a copy for my reference. I\nam authorised to sign on behalf of the company I represent.',0,''),(62821,20036,'120705','deals-mobile','font-size','15',0,''),(62822,20036,'120705','deals-mobile','padding-left','10',0,''),(62823,20036,'120705','deals-mobile','padding-right','10',0,''),(62824,20037,'120706','deals-mobile','block_type','6',0,''),(62825,20037,'120706','deals-mobile','padding-bottom','20',0,''),(62826,20038,'120707','deals-mobile','text','Telephone No.',0,''),(62827,20038,'120707','deals-mobile','text-align','right',0,''),(62828,20039,'120708','deals-mobile','field','62',0,''),(62829,20039,'120708','deals-mobile','border-bottom-width','1',0,''),(62830,20039,'120708','deals-mobile','border-bottom-color','#000000',0,''),(62831,20039,'120708','deals-mobile','padding-left','10',0,''),(62832,20040,'120709','deals-mobile','block_type','1',0,''),(62833,20040,'120709','deals-mobile','padding-bottom','10',0,''),(62834,20041,'120710','deals-mobile','background-color','#000000',0,''),(62835,20041,'120710','deals-mobile','color','#ffffff',0,''),(62836,20041,'120710','deals-mobile','font-size','20',0,''),(62837,20041,'120710','deals-mobile','text','Customer Details',0,''),(62838,20041,'120710','deals-mobile','padding-left','10',0,''),(62839,20041,'120710','deals-mobile','padding-right','10',0,''),(62840,20042,'120711','deals-mobile','block_type','6',0,''),(62841,20043,'120712','deals-mobile','text','Name',0,''),(62842,20043,'120712','deals-mobile','text-align','right',0,''),(62843,20043,'120712','deals-mobile','font-size','16',0,''),(62844,20044,'120713','deals-mobile','field','60',0,''),(62845,20044,'120713','deals-mobile','border-bottom-width','1',0,''),(62846,20044,'120713','deals-mobile','border-bottom-color','#000000',0,''),(62847,20044,'120713','deals-mobile','padding-left','10',0,''),(62848,20045,'120714','deals-mobile','block_type','14',0,''),(62849,20046,'120715','deals-mobile','text','Signed',0,''),(62850,20046,'120715','deals-mobile','text-align','right',0,''),(62851,20047,'120716','deals-mobile','text','&nbsp;',0,''),(62852,20047,'120716','deals-mobile','border-bottom-width','1',0,''),(62853,20047,'120716','deals-mobile','border-bottom-color','#000000',0,''),(62854,20048,'120717','deals-mobile','text','Date',0,''),(62855,20048,'120717','deals-mobile','text-align','right',0,''),(62856,20049,'120718','deals-mobile','text','&nbsp;',0,''),(62857,20049,'120718','deals-mobile','border-bottom-width','1',0,''),(62858,20049,'120718','deals-mobile','border-bottom-color','#000000',0,''),(62859,20050,'120719','deals-mobile','block_type','14',0,''),(62860,20051,'120720','deals-mobile','text','Name in Full',0,''),(62861,20051,'120720','deals-mobile','text-align','right',0,''),(62862,20052,'120721','deals-mobile','field','66',0,''),(62863,20052,'120721','deals-mobile','padding-left','10',0,''),(62864,20052,'120721','deals-mobile','border-bottom-width','1',0,''),(62865,20052,'120721','deals-mobile','border-bottom-color','#000000',0,''),(62866,20053,'120722','deals-mobile','text','Position',0,''),(62867,20053,'120722','deals-mobile','text-align','right',0,''),(62868,20054,'120723','deals-mobile','field','67',0,''),(62869,20054,'120723','deals-mobile','border-bottom-width','1',0,''),(62870,20054,'120723','deals-mobile','border-bottom-color','#000000',0,''),(62871,20054,'120723','deals-mobile','padding-left','10',0,''),(62872,20055,'120724','deals-mobile','block_type','1',0,''),(62873,20056,'120725','deals-mobile','text','Scottish books of exceptional value',0,''),(62874,20056,'120725','deals-mobile','font-size','20',0,''),(62875,20056,'120725','deals-mobile','text-align','center',0,''),(62876,20056,'120725','deals-mobile','padding-top','20',0,''),(62877,20057,'120726','deals-mobile','block_type','1',0,''),(62878,20058,'120727','deals-mobile','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(62879,20058,'120727','deals-mobile','padding-top','100',0,''),(62880,20058,'120727','deals-mobile','margin-bottom','100',0,''),(62881,20058,'120727','deals-mobile','text-align','center',0,''),(62882,20058,'120727','deals-mobile','font-size','20',0,''),(62883,20059,'120728','deals-mobile','block_type','1',0,''),(62884,20059,'120728','deals-mobile','background-color','#eeeeee',0,''),(62885,20059,'120728','deals-mobile','padding-bottom','30',0,''),(62886,20060,'120729','deals-mobile','block_type','4',0,''),(62887,20060,'120729','deals-mobile','schema','4-2',0,''),(62888,20061,'120730','deals-mobile','block_type','1',0,''),(62889,20061,'120730','deals-mobile','padding-right','40',0,''),(62891,20062,'120731','deals-mobile','block_type','2',0,''),(62892,20062,'120731','deals-mobile','margin-bottom','20',0,''),(62893,20062,'120731','deals-mobile','schema','2-2',0,''),(62894,20062,'120731','deals-mobile','background-color','#ffffff',0,''),(62895,20063,'120732','deals-mobile','block_type','1',0,''),(62896,20063,'120732','deals-mobile','border-right-width','20',0,''),(62897,20063,'120732','deals-mobile','border-right-color','#e0e0e0',0,''),(62898,20063,'120732','deals-mobile','margin-right','-10',0,''),(62899,20063,'120732','deals-mobile','padding-right','30',0,''),(62900,20063,'120732','deals-mobile','padding-top','20',0,''),(62901,20063,'120732','deals-mobile','padding-left','30',0,''),(62902,20063,'120732','deals-mobile','padding-bottom','20',0,''),(62905,20063,'120732','deals-mobile','margin-bottom','20',0,''),(62908,20064,'120733','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(62909,20064,'120733','deals-mobile','clear','none',0,''),(62910,20065,'120734','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(62911,20065,'120734','deals-mobile','clear','none',0,''),(62912,20066,'120735','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(62913,20068,'120737','deals-mobile','margin-bottom','20',0,''),(62914,20072,'120741','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(62915,20072,'120741','deals-mobile','padding-top','20',0,''),(62916,20073,'120742','deals-mobile','block_type','1',0,''),(62917,20073,'120742','deals-mobile','padding-left','30',0,''),(62918,20073,'120742','deals-mobile','border-left-width','20',0,''),(62919,20073,'120742','deals-mobile','border-left-color','#e0e0e0',0,''),(62920,20073,'120742','deals-mobile','margin-left','-10',0,''),(62921,20073,'120742','deals-mobile','padding-right','30',0,''),(62922,20073,'120742','deals-mobile','padding-top','20',0,''),(62923,20073,'120742','deals-mobile','padding-bottom','20',0,''),(62925,20074,'120743','deals-mobile','margin-bottom','20',0,''),(62926,20076,'120745','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(62927,20077,'120746','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(62928,20077,'120746','deals-mobile','clear','none',0,''),(62929,20078,'120747','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(62930,20078,'120747','deals-mobile','clear','none',0,''),(62931,20079,'120748','deals-mobile','block_type','1',0,''),(62932,20079,'120748','deals-mobile','padding-right','30',0,''),(62933,20079,'120748','deals-mobile','background-color','#ffffff',0,''),(62934,20079,'120748','deals-mobile','padding-top','20',0,''),(62935,20079,'120748','deals-mobile','padding-left','30',0,''),(62936,20079,'120748','deals-mobile','padding-bottom','20',0,''),(62939,20081,'120750','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(62940,20082,'120751','deals-mobile','block_type','1',0,''),(62941,20082,'120751','deals-mobile','padding-top','20',0,''),(62942,20082,'120751','deals-mobile','padding-left','20',0,''),(62943,20082,'120751','deals-mobile','padding-right','20',0,''),(62944,20082,'120751','deals-mobile','padding-bottom','20',0,''),(62945,20082,'120751','deals-mobile','background-color','#ffffff',0,''),(62946,20082,'120751','deals-mobile','style_class','order-summary',0,''),(62947,20083,'120752','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(62948,20087,'120756','deals-mobile','block_type','1',0,''),(62949,20087,'120756','deals-mobile','background-color','#eeeeee',0,''),(62950,20087,'120756','deals-mobile','padding-bottom','30',0,''),(62951,20088,'120757','deals-mobile','block_type','4',0,''),(62952,20088,'120757','deals-mobile','schema','4-2',0,''),(62953,20089,'120758','deals-mobile','block_type','1',0,''),(62954,20089,'120758','deals-mobile','padding-right','40',0,''),(62956,20090,'120759','deals-mobile','block_type','1',0,''),(62957,20090,'120759','deals-mobile','padding-right','30',0,''),(62958,20090,'120759','deals-mobile','background-color','#ffffff',0,''),(62959,20090,'120759','deals-mobile','padding-top','20',0,''),(62960,20090,'120759','deals-mobile','padding-left','30',0,''),(62961,20090,'120759','deals-mobile','padding-bottom','20',0,''),(62964,20091,'120760','deals-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(62965,20093,'120762','deals-mobile','block_type','2',0,''),(62966,20093,'120762','deals-mobile','margin-bottom','20',0,''),(62967,20093,'120762','deals-mobile','schema','2-2',0,''),(62968,20093,'120762','deals-mobile','background-color','#ffffff',0,''),(62969,20094,'120763','deals-mobile','block_type','1',0,''),(62970,20094,'120763','deals-mobile','border-right-width','20',0,''),(62971,20094,'120763','deals-mobile','border-right-color','#e0e0e0',0,''),(62972,20094,'120763','deals-mobile','margin-right','-10',0,''),(62973,20094,'120763','deals-mobile','padding-right','30',0,''),(62974,20094,'120763','deals-mobile','padding-top','20',0,''),(62975,20094,'120763','deals-mobile','padding-left','30',0,''),(62976,20094,'120763','deals-mobile','padding-bottom','20',0,''),(62979,20094,'120763','deals-mobile','margin-bottom','20',0,''),(62982,20097,'120766','deals-mobile','margin-bottom','20',0,''),(62983,20098,'120767','deals-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(62984,20098,'120767','deals-mobile','padding-top','20',0,''),(62985,20100,'120769','deals-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(62986,20100,'120769','deals-mobile','clear','none',0,''),(62987,20102,'120771','deals-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(62988,20102,'120771','deals-mobile','clear','none',0,''),(62989,20103,'120772','deals-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(62990,20104,'120773','deals-mobile','block_type','1',0,''),(62991,20104,'120773','deals-mobile','padding-left','30',0,''),(62992,20104,'120773','deals-mobile','border-left-width','20',0,''),(62993,20104,'120773','deals-mobile','border-left-color','#e0e0e0',0,''),(62994,20104,'120773','deals-mobile','margin-left','-10',0,''),(62995,20104,'120773','deals-mobile','padding-right','30',0,''),(62996,20104,'120773','deals-mobile','padding-top','20',0,''),(62997,20104,'120773','deals-mobile','padding-bottom','20',0,''),(62999,20105,'120774','deals-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(63000,20105,'120774','deals-mobile','clear','none',0,''),(63001,20106,'120775','deals-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(63002,20107,'120776','deals-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(63003,20107,'120776','deals-mobile','clear','none',0,''),(63004,20108,'120777','deals-mobile','margin-bottom','20',0,''),(63005,20110,'120779','deals-mobile','block_type','1',0,''),(63006,20110,'120779','deals-mobile','padding-top','20',0,''),(63007,20110,'120779','deals-mobile','padding-left','20',0,''),(63008,20110,'120779','deals-mobile','padding-right','20',0,''),(63009,20110,'120779','deals-mobile','padding-bottom','20',0,''),(63010,20110,'120779','deals-mobile','background-color','#ffffff',0,''),(63011,20110,'120779','deals-mobile','style_class','order-summary',0,''),(63012,20112,'120781','deals-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(63013,20115,'120784','deals-mobile','block_type','1',0,''),(63014,20115,'120784','deals-mobile','background_image','themes/deals-mobile/img/wedding-registry-page-1-1.jpg',0,''),(63015,20115,'120784','deals-mobile','background-position','top center',0,''),(63016,20115,'120784','deals-mobile','background-repeat','no-repeat',0,''),(63017,20115,'120784','deals-mobile','background-size','cover',0,''),(63018,20115,'120784','deals-mobile','padding-top','50',0,''),(63019,20115,'120784','deals-mobile','padding-bottom','50',0,''),(63020,20115,'120784','deals-mobile','margin-bottom','30',0,''),(63021,20116,'120785','deals-mobile','background-color','#ffffff',0,''),(63022,20116,'120785','deals-mobile','block_type','1',0,''),(63023,20116,'120785','deals-mobile','max-width','700',0,''),(63024,20116,'120785','deals-mobile','margin_left_measure','auto',0,''),(63025,20116,'120785','deals-mobile','margin_right_measure','auto',0,''),(63026,20117,'120786','deals-mobile','text-align','center',0,''),(63027,20117,'120786','deals-mobile','margin-bottom','30',0,''),(63028,20118,'120787','deals-mobile','padding-bottom','30',0,''),(63029,20118,'120787','deals-mobile','text-align','center',0,''),(63030,20119,'120788','deals-mobile','heading_type','h1',0,''),(63031,20120,'120789','deals-mobile','block_type','13',0,''),(63032,20120,'120789','deals-mobile','margin-bottom','20',0,''),(63033,20120,'120789','deals-mobile','schema','13-2',0,''),(63034,20121,'120790','deals-mobile','position','relative',0,''),(63035,20121,'120790','deals-mobile','margin-top','-100',0,''),(63037,20122,'120791','deals-mobile','font-family','Varela Round',0,''),(63038,20122,'120791','deals-mobile','font-size','30',0,''),(63039,20122,'120791','deals-mobile','text-transform','uppercase',0,''),(63040,20122,'120791','deals-mobile','text-align','center',0,''),(63042,20123,'120792','deals-mobile','block_type','1',0,''),(63043,20123,'120792','deals-mobile','float','left',0,''),(63045,20124,'120793','deals-mobile','display','inline-block',0,''),(63046,20124,'120793','deals-mobile','font-weight','700',0,''),(63047,20125,'120794','deals-mobile','clear','none',0,''),(63048,20125,'120794','deals-mobile','padding-left','20',0,''),(63049,20125,'120794','deals-mobile','font-weight','700',0,''),(63050,20125,'120794','deals-mobile','display','inline-block',0,''),(63051,20126,'120795','deals-mobile','font-weight','700',0,''),(63052,20126,'120795','deals-mobile','clear','none',0,''),(63053,20126,'120795','deals-mobile','padding-left','20',0,''),(63054,20126,'120795','deals-mobile','display','inline-block',0,''),(63055,20127,'120796','deals-mobile','font-family','Varela Round',0,''),(63056,20127,'120796','deals-mobile','font-size','18',0,''),(63057,20127,'120796','deals-mobile','margin-bottom','10',0,''),(63058,20127,'120796','deals-mobile','text-align','center',0,''),(63059,20128,'120797','deals-mobile','font-weight','700',0,''),(63060,20128,'120797','deals-mobile','text-align','right',0,''),(63061,20128,'120797','deals-mobile','max-width','110',0,''),(63062,20128,'120797','deals-mobile','float','right',0,''),(63063,20129,'120798','deals-mobile','margin-bottom','10',0,''),(63064,20130,'120799','deals-mobile','like_button','1',0,''),(63065,20130,'120799','deals-mobile','text-align','center',0,''),(63066,20130,'120799','deals-mobile','margin-bottom','20',0,''),(63067,20130,'120799','deals-mobile','margin-top','20',0,''),(63068,20130,'120799','deals-mobile','padding-top','30',0,''),(63069,20130,'120799','deals-mobile','border-top-width','1',0,''),(63070,20130,'120799','deals-mobile','border-top-color','#e0e0e0',0,''),(63078,20135,'120804','deals-mobile','block_type','1',0,''),(63079,20135,'120804','deals-mobile','padding-top','20',0,''),(63080,20135,'120804','deals-mobile','padding-bottom','20',0,''),(63081,20137,'120806','deals-mobile','padding-top','10',0,''),(63082,20137,'120806','deals-mobile','padding-bottom','10',0,''),(63083,20137,'120806','deals-mobile','border-top-width','1',0,''),(63084,20137,'120806','deals-mobile','border-top-color','#e0e0e0',0,''),(63085,20137,'120806','deals-mobile','text-align','right',0,''),(63086,20138,'120807','deals-mobile','block_type','1',0,''),(63087,20138,'120807','deals-mobile','border-top-width','1',0,''),(63088,20138,'120807','deals-mobile','border-left-width','1',0,''),(63089,20138,'120807','deals-mobile','border-right-width','1',0,''),(63090,20138,'120807','deals-mobile','border-bottom-width','1',0,''),(63091,20138,'120807','deals-mobile','border-top-color','#e0e0e0',0,''),(63092,20138,'120807','deals-mobile','border-left-color','#e0e0e0',0,''),(63093,20138,'120807','deals-mobile','border-right-color','#e0e0e0',0,''),(63094,20138,'120807','deals-mobile','border-bottom-color','#e0e0e0',0,''),(63095,20138,'120807','deals-mobile','padding-top','15',0,''),(63096,20138,'120807','deals-mobile','padding-left','15',0,''),(63097,20138,'120807','deals-mobile','padding-right','15',0,''),(63098,20138,'120807','deals-mobile','padding-bottom','15',0,''),(63099,20138,'120807','deals-mobile','margin-bottom','50',0,''),(63100,20139,'120808','deals-mobile','block_type','1',0,''),(63101,20139,'120808','deals-mobile','padding-top','20',0,''),(63102,20139,'120808','deals-mobile','padding-left','20',0,''),(63103,20139,'120808','deals-mobile','padding-right','20',0,''),(63104,20139,'120808','deals-mobile','background-color','#ffffff',0,''),(63105,20141,'120810','deals-mobile','text','<h1>##FIND_REGISTRY##</h1>',0,''),(63106,20142,'120811','deals-mobile','block_type','1',0,''),(63107,20143,'120812','deals-mobile','block_type','8',0,''),(63108,20143,'120812','deals-mobile','schema','8-6',0,''),(63109,20144,'120813','deals-mobile','text','<div class=\"heading-3\">##INVITE_GUESTS##</div>',0,''),(63110,20145,'120814','deals-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_PERSONALIZED_URL##</div>',0,''),(63111,20146,'120815','deals-mobile','margin-bottom','30',0,''),(63112,20149,'120818','deals-mobile','margin-top','-100',0,''),(63113,20150,'120819','deals-mobile','text','<h1>##SHARE_YOUR_WEDDING_REGISTRY##</h1>',0,''),(63114,20150,'120819','deals-mobile','margin-top','-80',0,''),(63116,20151,'120820','deals-mobile','text','<h1>##CREATE_WR_SUCCESS_MESSAGE##</h1>',0,''),(63117,20153,'120822','deals-mobile','block_type','2',0,''),(63118,20153,'120822','deals-mobile','schema','2-2',0,''),(63119,20154,'120823','deals-mobile','block_type','1',0,''),(63120,20154,'120823','deals-mobile','padding-right','15',0,''),(63122,20155,'120824','deals-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_REGISTRY##</div>',0,''),(63123,20156,'120825','deals-mobile','text','<div class=\"heading-3\">##TEXT_WEDDING_DETAILS##</div>',0,''),(63124,20157,'120826','deals-mobile','margin-bottom','20',0,''),(63125,20158,'120827','deals-mobile','margin-bottom','20',0,''),(63126,20159,'120828','deals-mobile','text','<div class=\"heading-3\">##TEXT_NAMES##</div>',0,''),(63127,20160,'120829','deals-mobile','padding-bottom','20',0,''),(63128,20161,'120830','deals-mobile','block_type','1',0,''),(63129,20161,'120830','deals-mobile','padding-left','15',0,''),(63131,20162,'120831','deals-mobile','margin-bottom','20',0,''),(63132,20163,'120832','deals-mobile','text','<div class=\"heading-3\">##TEXT_SHIPPING_DETAILS##</div>',0,''),(63133,20164,'120833','deals-mobile','text','<div class=\"heading-3\">##UPLOAD_PHOTO##</div>',0,''),(63134,20165,'120834','deals-mobile','margin-bottom','20',0,''),(63135,20165,'120834','deals-mobile','padding-left','1',0,''),(63136,20166,'120835','deals-mobile','text','<div class=\"heading-3\">##TEXT_ADDITIONAL_INFORMATION##</div>',0,''),(63137,20167,'120836','deals-mobile','margin-bottom','20',0,''),(63138,20168,'120837','deals-mobile','text','<h1>##WEDDING_REGISTRY_FORM_HEADING##</h1>',0,''),(63139,20169,'120838','deals-mobile','block_type','2',0,''),(63140,20169,'120838','deals-mobile','margin-bottom','20',0,''),(63141,20171,'120840','deals-mobile','text-align','right',0,''),(63142,20173,'120842','deals-mobile','block_type','13',0,''),(63143,20173,'120842','deals-mobile','margin-bottom','20',0,''),(63144,20174,'120843','deals-mobile','position','relative',0,''),(63145,20174,'120843','deals-mobile','margin-top','-100',0,''),(63146,20175,'120844','deals-mobile','font-family','Varela Round',0,''),(63147,20175,'120844','deals-mobile','font-size','18',0,''),(63148,20175,'120844','deals-mobile','margin-bottom','10',0,''),(63149,20176,'120845','deals-mobile','font-family','Varela Round',0,''),(63150,20176,'120845','deals-mobile','font-size','30',0,''),(63151,20176,'120845','deals-mobile','text-transform','uppercase',0,''),(63152,20177,'120846','deals-mobile','font-weight','700',0,''),(63153,20177,'120846','deals-mobile','text-align','right',0,''),(63154,20179,'120848','deals-mobile','block_type','1',0,''),(63155,20180,'120849','deals-mobile','block_type','6',0,''),(63156,20180,'120849','deals-mobile','schema','6-3',0,''),(63157,20181,'120850','deals-mobile','aria_name','account-menu',0,''),(63158,20182,'120851','deals-mobile','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(63159,20183,'120852','deals-mobile','margin-bottom','20',0,''),(63160,20184,'120853','deals-mobile','block_type','1',0,''),(63161,20184,'120853','deals-mobile','padding-top','20',0,''),(63162,20184,'120853','deals-mobile','padding-bottom','20',0,''),(63163,20186,'120855','deals-mobile','padding-top','20',0,''),(63164,20186,'120855','deals-mobile','padding-bottom','20',0,''),(99209,3156,'115990','watch-mobile','margin-left','0',0,'291'),(114043,3023,'94911','watch-mobile','style_class','account-index',0,''),(114044,3071,'94959','watch-mobile','style_class','account-address-book',0,''),(114045,3076,'94964','watch-mobile','style_class','account-address-book-process',0,''),(114046,3065,'94953','watch-mobile','style_class','account-edit-wrap',0,''),(114047,4369,'114698','watch-mobile','style_class','account-order-history',0,''),(114048,4374,'114703','watch-mobile','style_class','account-order-history-info',0,''),(114049,4414,'114743','watch-mobile','style_class','account-order-pay',0,''),(114050,4316,'114645','watch-mobile','style_class','account-password-wrap',0,''),(114051,4806,'115009','watch-mobile','style_class','account-samples',0,''),(114052,4841,'115715','watch-mobile','style_class','account-sample-info',0,''),(114053,4520,'75821','watch-mobile','style_class','catalog-product-wrap',0,''),(114054,3989,'75625','watch-mobile','style_class','checkout-order-confirmation',0,''),(114055,3677,'114155','watch-mobile','style_class','checkout-order-confirmation',0,''),(114059,36640,'1693578529.207944','watch-mobile','background-color','$background-6',0,''),(114060,36640,'1693578529.207944','watch-mobile','padding-top','30',0,''),(114061,36640,'1693578529.207944','watch-mobile','padding-bottom','30',0,''),(114062,36640,'1693578529.207944','watch-mobile','style_class','checkout-index-wrap',0,''),(114063,36641,'1693578529.311699','watch-mobile','block_type','2',0,''),(114064,36641,'1693578529.311699','watch-mobile','schema','4-2',0,'1314'),(114065,36641,'1693578529.311699','watch-mobile','style_class','checkoutDoubleBox',0,''),(114066,36642,'1693578529.313831','watch-mobile','block_type','1',0,''),(114067,36642,'1693578529.313831','watch-mobile','padding-right','40',0,''),(114068,36642,'1693578529.313831','watch-mobile','padding-right','0',0,'1314'),(114069,36643,'1693578529.315461','watch-mobile','block_type','1',0,''),(114070,36643,'1693578529.315461','watch-mobile','background-color','$background-7',0,''),(114071,36643,'1693578529.315461','watch-mobile','padding-top','30',0,''),(114072,36643,'1693578529.315461','watch-mobile','padding-left','30',0,''),(114073,36643,'1693578529.315461','watch-mobile','padding-right','30',0,''),(114074,36643,'1693578529.315461','watch-mobile','padding-bottom','30',0,''),(114075,36643,'1693578529.315461','watch-mobile','margin-bottom','20',0,''),(114076,36643,'1693578529.315461','watch-mobile','style_class','hiding-box closeable-box',0,''),(114077,36644,'1693578529.317368','watch-mobile','style_class','closeable-content',0,''),(114078,36644,'1693578529.317368','watch-mobile','padding-bottom','20',0,''),(114079,36645,'1693578529.319136','watch-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(114080,36645,'1693578529.319136','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(114081,36646,'1693578529.322437','watch-mobile','block_type','1',0,''),(114082,36646,'1693578529.322437','watch-mobile','padding-top','30',0,''),(114083,36646,'1693578529.322437','watch-mobile','padding-left','30',0,''),(114084,36646,'1693578529.322437','watch-mobile','padding-right','30',0,''),(114085,36646,'1693578529.322437','watch-mobile','padding-bottom','30',0,''),(114086,36646,'1693578529.322437','watch-mobile','margin-bottom','20',0,''),(114087,36646,'1693578529.322437','watch-mobile','background-color','$background-7',0,''),(114088,36646,'1693578529.322437','watch-mobile','style_class','hiding-box closeable-box',0,''),(114089,36647,'1693578529.324468','watch-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(114090,36647,'1693578529.324468','watch-mobile','style_class','closeable-heading closeable-event closed',0,''),(114091,36648,'1693578529.325521','watch-mobile','block_type','2',0,''),(114092,36648,'1693578529.325521','watch-mobile','style_class','closeable-content',0,''),(114093,36648,'1693578529.325521','watch-mobile','schema','2-2',0,'1314'),(114094,36649,'1693578529.326795','watch-mobile','padding-right','20',0,''),(114095,36649,'1693578529.326795','watch-mobile','padding-bottom','20',0,''),(114096,36649,'1693578529.326795','watch-mobile','padding-right','0',0,'1314'),(114097,36650,'1693578529.329372','watch-mobile','padding-left','20',0,''),(114098,36650,'1693578529.329372','watch-mobile','padding-bottom','20',0,''),(114099,36650,'1693578529.329372','watch-mobile','padding-left','0',0,'1314'),(114100,36651,'1693578529.331582','watch-mobile','padding-left','20',0,''),(114101,36651,'1693578529.331582','watch-mobile','padding-bottom','20',0,''),(114102,36651,'1693578529.331582','watch-mobile','padding-left','0',0,'1314'),(114103,36652,'1693578529.333680','watch-mobile','background-color','$background-7',0,''),(114104,36652,'1693578529.333680','watch-mobile','block_type','1',0,''),(114105,36652,'1693578529.333680','watch-mobile','padding-top','30',0,''),(114106,36652,'1693578529.333680','watch-mobile','padding-left','30',0,''),(114107,36652,'1693578529.333680','watch-mobile','padding-right','30',0,''),(114108,36652,'1693578529.333680','watch-mobile','padding-bottom','30',0,''),(114109,36652,'1693578529.333680','watch-mobile','margin-bottom','20',0,''),(114110,36652,'1693578529.333680','watch-mobile','style_class','hiding-box',0,''),(114111,36653,'1693578529.335514','watch-mobile','block_type','1',0,''),(114112,36653,'1693578529.335514','watch-mobile','content','\\_',0,'3'),(114113,36653,'1693578529.335514','watch-mobile','border-top-width','1',0,'3'),(114114,36653,'1693578529.335514','watch-mobile','border-top-color','#e0e0e0',0,'3'),(114115,36653,'1693578529.335514','watch-mobile','display','block',0,'3'),(114116,36653,'1693578529.335514','watch-mobile','position','absolute',0,'3'),(114117,36653,'1693578529.335514','watch-mobile','top','19',0,'3'),(114118,36653,'1693578529.335514','watch-mobile','left','0',0,'3'),(114119,36653,'1693578529.335514','watch-mobile','right','0',0,'3'),(114120,36653,'1693578529.335514','watch-mobile','margin-top','-2',0,'3'),(114121,36653,'1693578529.335514','watch-mobile','position','relative',0,''),(114122,36654,'1693578529.337997','watch-mobile','box_align','2',0,''),(114123,36654,'1693578529.337997','watch-mobile','margin-bottom','10',0,''),(114124,36654,'1693578529.337997','watch-mobile','background-color','$background-7',0,''),(114125,36654,'1693578529.337997','watch-mobile','position','relative',0,''),(114126,36655,'1693578529.34334','watch-mobile','background-color','$background-6',0,''),(114127,36655,'1693578529.34334','watch-mobile','padding-top','10',0,''),(114128,36655,'1693578529.34334','watch-mobile','padding-left','10',0,''),(114129,36655,'1693578529.34334','watch-mobile','padding-right','10',0,''),(114130,36655,'1693578529.34334','watch-mobile','padding-bottom','10',0,''),(114131,36655,'1693578529.34334','watch-mobile','margin-top','10',0,''),(114132,36656,'1693578529.345418','watch-mobile','block_type','2',0,''),(114133,36656,'1693578529.345418','watch-mobile','schema','2-2',0,'1314'),(114134,36657,'1693578529.346757','watch-mobile','block_type','1',0,''),(114135,36657,'1693578529.346757','watch-mobile','padding-right','20',0,''),(114136,36657,'1693578529.346757','watch-mobile','padding-left','0',0,'1314'),(114137,36657,'1693578529.346757','watch-mobile','margin-bottom','20',0,'1314'),(114138,36657,'1693578529.346757','watch-mobile','padding-right','0',0,'1314'),(114139,36658,'1693578529.348387','watch-mobile','address_in','popup',0,''),(114140,36659,'1693578529.351498','watch-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(114141,36662,'1693578529.357732','watch-mobile','block_type','1',0,''),(114142,36662,'1693578529.357732','watch-mobile','padding-left','20',0,''),(114143,36662,'1693578529.357732','watch-mobile','padding-left','0',0,'1314'),(114144,36664,'1693578529.360426','watch-mobile','border-top-width','1',0,''),(114145,36664,'1693578529.360426','watch-mobile','border-top-color','#e0e0e0',0,''),(114146,36664,'1693578529.360426','watch-mobile','padding-top','13',0,''),(114147,36664,'1693578529.360426','watch-mobile','padding-bottom','10',0,''),(114148,36665,'1693578529.361979','watch-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(114149,36666,'1693578529.363439','watch-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(114150,36667,'1693578529.364794','watch-mobile','margin-bottom','20',0,''),(114151,36667,'1693578529.364794','watch-mobile','style_class','hiding-box',0,''),(114152,36668,'1693578529.368484','watch-mobile','padding-top','30',0,''),(114153,36668,'1693578529.368484','watch-mobile','padding-left','30',0,''),(114154,36668,'1693578529.368484','watch-mobile','padding-right','30',0,''),(114155,36668,'1693578529.368484','watch-mobile','margin-top','20',0,''),(114156,36668,'1693578529.368484','watch-mobile','background-color','$background-7',0,''),(114157,36668,'1693578529.368484','watch-mobile','padding-bottom','30',0,''),(114158,36668,'1693578529.368484','watch-mobile','margin-bottom','20',0,''),(114159,36669,'1693578529.371247','watch-mobile','block_type','1',0,''),(114160,36669,'1693578529.371247','watch-mobile','padding-top','30',0,''),(114161,36669,'1693578529.371247','watch-mobile','padding-left','30',0,''),(114162,36669,'1693578529.371247','watch-mobile','padding-right','30',0,''),(114163,36669,'1693578529.371247','watch-mobile','padding-bottom','23',0,''),(114164,36669,'1693578529.371247','watch-mobile','margin-bottom','20',0,''),(114165,36669,'1693578529.371247','watch-mobile','background-color','$background-7',0,''),(114166,36669,'1693578529.371247','watch-mobile','style_class','hiding-box',0,''),(114167,36670,'1693578529.373462','watch-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(114168,36671,'1693578529.374453','watch-mobile','block_type','2',0,''),(114169,36671,'1693578529.374453','watch-mobile','schema','2-2',0,'1314'),(114170,36672,'1693578529.375760','watch-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(114171,36673,'1693578529.376655','watch-mobile','padding-right','20',0,''),(114172,36673,'1693578529.376655','watch-mobile','padding-right','0',0,'1314'),(114173,36673,'1693578529.376655','watch-mobile','padding-bottom','20',0,'1314'),(114174,36673,'1693578529.376655','watch-mobile','address_in','popup',0,''),(114175,36674,'1693578529.380694','watch-mobile','block_type','1',0,''),(114176,36674,'1693578529.380694','watch-mobile','padding-left','20',0,''),(114177,36674,'1693578529.380694','watch-mobile','padding-left','0',0,'1314'),(114178,36676,'1693578529.383416','watch-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(114179,36677,'1693578529.384233','watch-mobile','block_type','1',0,''),(114180,36677,'1693578529.384233','watch-mobile','padding-top','30',0,''),(114181,36677,'1693578529.384233','watch-mobile','padding-left','30',0,''),(114182,36677,'1693578529.384233','watch-mobile','padding-right','30',0,''),(114183,36677,'1693578529.384233','watch-mobile','padding-bottom','30',0,''),(114184,36677,'1693578529.384233','watch-mobile','margin-bottom','20',0,''),(114185,36677,'1693578529.384233','watch-mobile','background-color','$background-7',0,''),(114186,36680,'1693578529.387946','watch-mobile','block_type','1',0,''),(114187,36680,'1693578529.387946','watch-mobile','padding-top','20',0,''),(114188,36680,'1693578529.387946','watch-mobile','padding-left','20',0,''),(114189,36680,'1693578529.387946','watch-mobile','padding-right','20',0,''),(114190,36680,'1693578529.387946','watch-mobile','padding-bottom','20',0,''),(114191,36680,'1693578529.387946','watch-mobile','background-color','$background-7',0,''),(114192,36680,'1693578529.387946','watch-mobile','style_class','order-summary',0,''),(114193,36681,'1693578529.434121','watch-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(114194,36681,'1693578529.434121','watch-mobile','text-align','center',0,''),(114195,36681,'1693578529.434121','watch-mobile','font-size','14',0,''),(114196,36681,'1693578529.434121','watch-mobile','color','$color-font-8',0,''),(114197,36681,'1693578529.434121','watch-mobile','padding-top','10',0,''),(114198,36682,'1693578529.436482','watch-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(114199,36683,'1693578529.437493','watch-mobile','hide_page','1',0,''),(114200,36683,'1693578529.437493','watch-mobile','hide_continue_button','1',0,''),(114201,36684,'1693578529.439185','watch-mobile','margin-bottom','10',0,''),(114202,4206,'114547','watch-mobile','style_class','checkout-login-wrap',0,''),(114203,4889,'75873','watch-mobile','style_class','checkout-success-wrap',0,''),(114204,3134,'115968','watch-mobile','style_class','shopping-cart-index',0,''),(168370,53913,'116005','furniture-mobile','text','##TEXT_PAGE_NOT_FOUND##',0,''),(168371,53913,'116005','furniture-mobile','text-align','center',0,''),(168372,53913,'116005','furniture-mobile','padding-top','100',0,''),(168373,53913,'116005','furniture-mobile','padding-bottom','100',0,''),(168374,53914,'116006','furniture-mobile','block_type','1',0,''),(168493,53930,'116022','furniture-mobile','block_type','1',0,''),(168612,53946,'116038','furniture-mobile','block_type','1',0,''),(168731,53962,'116054','furniture-mobile','block_type','1',0,''),(168850,53978,'116070','furniture-mobile','block_type','1',0,''),(168969,53994,'116086','furniture-mobile','block_type','1',0,''),(169088,54010,'116102','furniture-mobile','block_type','1',0,''),(169089,54010,'116102','furniture-mobile','style_class','account-index',0,''),(169090,54011,'116103','furniture-mobile','block_type','6',0,''),(169091,54011,'116103','furniture-mobile','schema','6-3',0,'2885'),(169092,54012,'116104','furniture-mobile','aria_name','account-menu',0,''),(169149,54032,'116105','furniture-mobile','link','Order History Info',0,''),(169150,54032,'116105','furniture-mobile','text','TEXT_VIEW',0,''),(169151,54032,'116105','furniture-mobile','max_orders','3',0,''),(169152,54032,'116105','furniture-mobile','link_pay','Order pay',0,''),(169153,54032,'116105','furniture-mobile','margin-bottom','30',0,''),(169154,54032,'116105','furniture-mobile','text_pay','ORDER_PAY',0,''),(169155,54033,'116106','furniture-mobile','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(169156,54034,'116109','furniture-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(169157,54035,'116112','furniture-mobile','block_type','15',0,''),(169158,54035,'116112','furniture-mobile','margin-bottom','30',0,''),(169159,54035,'116112','furniture-mobile','padding-top','20',0,''),(169160,54035,'116112','furniture-mobile','padding-left','20',0,''),(169161,54035,'116112','furniture-mobile','padding-right','20',0,''),(169162,54035,'116112','furniture-mobile','padding-bottom','20',0,''),(169163,54035,'116112','furniture-mobile','border-top-width','1',0,''),(169164,54035,'116112','furniture-mobile','border-top-color','$border-color-4',0,''),(169165,54035,'116112','furniture-mobile','border-left-width','1',0,''),(169166,54035,'116112','furniture-mobile','border-right-width','1',0,''),(169167,54035,'116112','furniture-mobile','border-bottom-width','1',0,''),(169168,54035,'116112','furniture-mobile','border-left-color','$border-color-4',0,''),(169169,54035,'116112','furniture-mobile','border-right-color','$border-color-4',0,''),(169170,54035,'116112','furniture-mobile','border-bottom-color','$border-color-4',0,''),(169171,54035,'116112','furniture-mobile','schema','15-3',0,'2885'),(169172,54036,'116113','furniture-mobile','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(169173,54036,'116113','furniture-mobile','font-family','trueloaded',0,'3'),(169174,54036,'116113','furniture-mobile','content','\\e920',0,'3'),(169175,54036,'116113','furniture-mobile','color','$attention-color',0,'3'),(169176,54036,'116113','furniture-mobile','font-size','30',0,'3'),(169177,54036,'116113','furniture-mobile','text-align','center',0,'3'),(169178,54036,'116113','furniture-mobile','margin-bottom','10',0,'3'),(169179,54036,'116113','furniture-mobile','text-align','center',0,''),(169180,54036,'116113','furniture-mobile','font-size','16',0,''),(169181,54036,'116113','furniture-mobile','text-transform','uppercase',0,''),(169182,54036,'116113','furniture-mobile','line-height','1',0,'3'),(169183,54036,'116113','furniture-mobile','font-size','14',0,'2876'),(169184,54037,'116114','furniture-mobile','font-family','$font-1',0,''),(169185,54037,'116114','furniture-mobile','color','$attention-color',0,''),(169186,54037,'116114','furniture-mobile','font-size','14',0,''),(169187,54037,'116114','furniture-mobile','text-align','center',0,''),(169188,54038,'116115','furniture-mobile','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(169189,54038,'116115','furniture-mobile','font-family','trueloaded',0,'3'),(169190,54038,'116115','furniture-mobile','content','\\e928',0,'3'),(169191,54038,'116115','furniture-mobile','color','$attention-color',0,'3'),(169192,54038,'116115','furniture-mobile','font-size','30',0,'3'),(169193,54038,'116115','furniture-mobile','text-align','center',0,'3'),(169194,54038,'116115','furniture-mobile','text-align','center',0,''),(169195,54038,'116115','furniture-mobile','font-size','16',0,''),(169196,54038,'116115','furniture-mobile','text-transform','uppercase',0,''),(169197,54038,'116115','furniture-mobile','line-height','1',0,'3'),(169198,54038,'116115','furniture-mobile','font-size','14',0,'2876'),(169199,54039,'116116','furniture-mobile','font-family','$font-1',0,''),(169200,54039,'116116','furniture-mobile','color','$attention-color',0,''),(169201,54039,'116116','furniture-mobile','font-size','14',0,''),(169202,54039,'116116','furniture-mobile','text-align','center',0,''),(169203,54040,'116117','furniture-mobile','link','download_orders',0,''),(169204,54040,'116117','furniture-mobile','text','TEXT_DOWNLOAD_ORDERS',0,''),(169205,54040,'116117','furniture-mobile','hide_link','orders',0,''),(169206,54040,'116117','furniture-mobile','text-align','center',0,''),(169207,54040,'116117','furniture-mobile','popup','2',0,''),(169208,54040,'116117','furniture-mobile','font-size','14',0,''),(169209,54041,'116118','furniture-mobile','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(169210,54041,'116118','furniture-mobile','font-family','trueloaded',0,'3'),(169211,54041,'116118','furniture-mobile','content','\\e922',0,'3'),(169212,54041,'116118','furniture-mobile','color','$attention-color',0,'3'),(169213,54041,'116118','furniture-mobile','font-size','30',0,'3'),(169214,54041,'116118','furniture-mobile','line-height','1',0,'3'),(169215,54041,'116118','furniture-mobile','font-size','16',0,''),(169216,54041,'116118','furniture-mobile','text-align','center',0,''),(169217,54041,'116118','furniture-mobile','text-transform','uppercase',0,''),(169218,54041,'116118','furniture-mobile','font-size','14',0,'2876'),(169219,54042,'116119','furniture-mobile','font-family','$font-1',0,''),(169220,54042,'116119','furniture-mobile','color','$attention-color',0,''),(169221,54042,'116119','furniture-mobile','line-height','1',0,''),(169222,54042,'116119','furniture-mobile','text-align','center',0,''),(169223,54042,'116119','furniture-mobile','font-size','14',0,''),(169224,54043,'116120','furniture-mobile','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(169225,54043,'116120','furniture-mobile','content','\\e994',0,'3'),(169226,54043,'116120','furniture-mobile','font-family','trueloaded',0,'3'),(169227,54043,'116120','furniture-mobile','color','$attention-color',0,'3'),(169228,54043,'116120','furniture-mobile','font-size','30',0,'3'),(169229,54043,'116120','furniture-mobile','line-height','1',0,'3'),(169230,54043,'116120','furniture-mobile','font-size','16',0,''),(169231,54043,'116120','furniture-mobile','text-align','center',0,''),(169232,54043,'116120','furniture-mobile','text-transform','uppercase',0,''),(169233,54043,'116120','furniture-mobile','font-size','14',0,'2876'),(169234,54044,'116121','furniture-mobile','font-family','$font-1',0,''),(169235,54044,'116121','furniture-mobile','color','$attention-color',0,''),(169236,54044,'116121','furniture-mobile','font-size','14',0,''),(169237,54044,'116121','furniture-mobile','text-align','center',0,''),(169238,54045,'116122','furniture-mobile','link','Gift Certificate',0,''),(169239,54045,'116122','furniture-mobile','text','GIFT_CERTIFICATE',0,''),(169240,54045,'116122','furniture-mobile','popup','1',0,''),(169241,54045,'116122','furniture-mobile','text-align','center',0,''),(169242,54045,'116122','furniture-mobile','font-size','14',0,''),(169243,54046,'116123','furniture-mobile','text','TEXT_VIEW_HISTORY',0,''),(169244,54046,'116123','furniture-mobile','popup','1',0,''),(169245,54046,'116123','furniture-mobile','text-align','center',0,''),(169246,54046,'116123','furniture-mobile','link','Points Earnt History',0,''),(169247,54046,'116123','furniture-mobile','font-size','14',0,''),(169248,54047,'116124','furniture-mobile','font-family','$font-1',0,''),(169249,54047,'116124','furniture-mobile','color','$attention-color',0,''),(169250,54047,'116124','furniture-mobile','font-size','14',0,''),(169251,54047,'116124','furniture-mobile','text-align','center',0,''),(169252,54048,'116125','furniture-mobile','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(169253,54048,'116125','furniture-mobile','content','\\e990',0,'3'),(169254,54048,'116125','furniture-mobile','font-family','trueloaded',0,'3'),(169255,54048,'116125','furniture-mobile','font-size','30',0,'3'),(169256,54048,'116125','furniture-mobile','text-align','center',0,'3'),(169257,54048,'116125','furniture-mobile','line-height','1',0,'3'),(169258,54048,'116125','furniture-mobile','color','$attention-color',0,'3'),(169259,54048,'116125','furniture-mobile','font-size','16',0,''),(169260,54048,'116125','furniture-mobile','text-align','center',0,''),(169261,54048,'116125','furniture-mobile','text-transform','uppercase',0,''),(169262,54048,'116125','furniture-mobile','font-size','14',0,'2876'),(169319,54070,'116145','furniture-mobile','block_type','1',0,''),(169320,54070,'116145','furniture-mobile','style_class','account-edit-wrap',0,''),(169321,54071,'116146','furniture-mobile','block_type','6',0,''),(169322,54071,'116146','furniture-mobile','schema','6-3',0,'2885'),(169323,54072,'116147','furniture-mobile','aria_name','account-menu',0,''),(169380,54093,'116149','furniture-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(169381,54094,'116150','furniture-mobile','block_type','1',0,''),(169382,54094,'116150','furniture-mobile','style_class','account-address-book',0,''),(169383,54095,'116151','furniture-mobile','block_type','6',0,''),(169384,54095,'116151','furniture-mobile','schema','6-3',0,'2885'),(169385,54096,'116152','furniture-mobile','aria_name','account-menu',0,''),(169442,54116,'116153','furniture-mobile','padding-top','15',0,''),(169443,54116,'116153','furniture-mobile','padding-bottom','15',0,''),(169444,54116,'116153','furniture-mobile','link','Address Book Process',0,''),(169445,54116,'116153','furniture-mobile','text','EDIT',0,''),(169446,54116,'116153','furniture-mobile','link_add','Address Book Process',0,''),(169447,54116,'116153','furniture-mobile','like_button_add','2',0,''),(169448,54116,'116153','furniture-mobile','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(169449,54117,'116154','furniture-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(169450,54118,'116155','furniture-mobile','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(169451,54119,'116156','furniture-mobile','block_type','1',0,''),(169452,54119,'116156','furniture-mobile','style_class','account-address-book-process',0,''),(169453,54120,'116157','furniture-mobile','block_type','6',0,''),(169454,54120,'116157','furniture-mobile','schema','6-3',0,'2885'),(169455,54121,'116158','furniture-mobile','aria_name','account-menu',0,''),(169512,54141,'116159','furniture-mobile','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(169513,54143,'117906.000001','furniture-mobile','block_type','1',0,''),(169514,54143,'117906.000001','furniture-mobile','style_class','item-holder',0,''),(169515,54143,'117906.000001','furniture-mobile','padding-top','25',0,''),(169516,54143,'117906.000001','furniture-mobile','padding-bottom','25',0,''),(169517,54143,'117906.000001','furniture-mobile','text-align','left',0,''),(169518,54143,'117906.000001','furniture-mobile','border-top-width','1',0,''),(169519,54143,'117906.000001','furniture-mobile','border-top-color','$border-color-3',0,''),(169520,54144,'117907.000001','furniture-mobile','block_type','7',0,''),(169521,54144,'117907.000001','furniture-mobile','schema','7-2',0,'2885'),(169522,54145,'117908.000001','furniture-mobile','block_type','5',0,''),(169523,54145,'117908.000001','furniture-mobile','schema','5-2',0,'2885'),(169524,54146,'117909.000001','furniture-mobile','clear','none',0,''),(169525,54146,'117909.000001','furniture-mobile','padding-right','20',0,''),(169526,54147,'117910.000001','furniture-mobile','padding-right','20',0,''),(169527,54147,'117910.000001','furniture-mobile','max-width','300',0,'2885'),(169528,54147,'117910.000001','furniture-mobile','margin_left_measure','auto',0,'2885'),(169529,54147,'117910.000001','furniture-mobile','margin_right_measure','auto',0,'2885'),(169530,54148,'117914.000001','furniture-mobile','padding-right','20',0,''),(169531,54149,'117915.000001','furniture-mobile','description_characters','200',0,''),(169532,54149,'117915.000001','furniture-mobile','clear','none',0,''),(169533,54149,'117915.000001','furniture-mobile','padding-right','20',0,''),(169534,54150,'117916.000001','furniture-mobile','clear','none',0,''),(169535,54151,'117917.000001','furniture-mobile','margin-bottom','20',0,''),(169536,54153,'117918.000001','furniture-mobile','block_type','1',0,''),(169537,54153,'117918.000001','furniture-mobile','padding-left','40',0,''),(169538,54153,'117918.000001','furniture-mobile','style_class','right-aria',0,''),(169539,54153,'117918.000001','furniture-mobile','padding-left','0',0,'2885'),(169540,54154,'117911.000001','furniture-mobile','block_type','1',0,''),(169541,54154,'117911.000001','furniture-mobile','text-align','center',0,''),(169542,54155,'117912.000001','furniture-mobile','margin-top','4',0,''),(169543,54155,'117912.000001','furniture-mobile','margin-bottom','7',0,''),(169544,54156,'117913.000001','furniture-mobile','padding-top','6',0,''),(169545,54156,'117913.000001','furniture-mobile','padding-left','5',0,''),(169546,54157,'117919.000001','furniture-mobile','margin-bottom','15',0,''),(169547,54157,'117919.000001','furniture-mobile','text-align','right',0,''),(169548,54158,'117920.000001','furniture-mobile','margin-bottom','10',0,''),(169549,54158,'117920.000001','furniture-mobile','text-align','center',0,''),(169550,54159,'117922.000001','furniture-mobile','text-align','right',0,''),(169551,54159,'117922.000001','furniture-mobile','margin-bottom','15',0,''),(169552,54160,'117924.000001','furniture-mobile','text-align','center',0,''),(169553,54160,'117924.000001','furniture-mobile','margin-bottom','10',0,''),(169554,54161,'120924.000001','furniture-mobile','block_type','1',0,''),(169555,54161,'120924.000001','furniture-mobile','style_class','item-nav',0,''),(169556,54165,'116176','furniture-mobile','block_type','1',0,''),(169557,54165,'116176','furniture-mobile','style_class','item-holder',0,''),(169558,54165,'116176','furniture-mobile','padding-top','25',0,''),(169559,54165,'116176','furniture-mobile','padding-left','25',0,''),(169560,54165,'116176','furniture-mobile','padding-right','25',0,''),(169561,54165,'116176','furniture-mobile','padding-bottom','25',0,''),(169562,54165,'116176','furniture-mobile','text-align','left',0,''),(169563,54167,'116178','furniture-mobile','margin-bottom','7',0,''),(169564,54168,'116179','furniture-mobile','clear','both',0,''),(169565,54171,'116182','furniture-mobile','block_type','1',0,''),(169566,54171,'116182','furniture-mobile','style_class','item-holder',0,''),(169567,54171,'116182','furniture-mobile','padding-top','25',0,''),(169568,54171,'116182','furniture-mobile','padding-left','25',0,''),(169569,54171,'116182','furniture-mobile','padding-right','25',0,''),(169570,54171,'116182','furniture-mobile','padding-bottom','25',0,''),(169571,54171,'116182','furniture-mobile','text-align','left',0,''),(169572,54172,'116183','furniture-mobile','block_type','5',0,''),(169573,54175,'116186','furniture-mobile','margin-bottom','7',0,''),(169574,54176,'116187','furniture-mobile','clear','both',0,''),(169575,54177,'116188','furniture-mobile','block_type','1',0,''),(169576,54178,'116189','furniture-mobile','block_type','6',0,''),(169577,54178,'116189','furniture-mobile','font-weight','400',0,''),(169578,54178,'116189','furniture-mobile','schema','6-2',0,'2906'),(169579,54178,'116189','furniture-mobile','schema','6-2',0,'2885'),(169580,54179,'116190','furniture-mobile','font-weight','400',0,''),(169581,54179,'116190','furniture-mobile','padding-right','40',0,''),(169582,54179,'116190','furniture-mobile','padding-right','0',0,'2906'),(169583,54179,'116190','furniture-mobile','padding-right','0',0,'2885'),(169584,54180,'116191','furniture-mobile','block_type','5',0,''),(169585,54180,'116191','furniture-mobile','padding-top','10',0,''),(169586,54180,'116191','furniture-mobile','padding-bottom','10',0,''),(169587,54180,'116191','furniture-mobile','schema','5-2',0,'2906'),(169588,54180,'116191','furniture-mobile','border-top-color','$border-color-4',0,''),(169589,54180,'116191','furniture-mobile','border-top-width','1',0,''),(169590,54182,'116193','furniture-mobile','float','right',0,''),(169591,54184,'116195','furniture-mobile','col_in_row','3',0,''),(169592,54184,'116195','furniture-mobile','products_align','left',0,''),(169593,54184,'116195','furniture-mobile','font-weight','400',0,''),(169594,54184,'116195','furniture-mobile','show_qty_input','0',0,''),(169595,54184,'116195','furniture-mobile','listing_type','productListing',0,''),(169596,54184,'116195','furniture-mobile','listing_type_rows','no',0,''),(169597,54184,'116195','furniture-mobile','show_buy_button_b2b','on',0,''),(169598,54184,'116195','furniture-mobile','show_wishlist_button_b2b','1',0,''),(169599,54184,'116195','furniture-mobile','show_compare_b2b','1',0,''),(169600,54184,'116195','furniture-mobile','show_stock','0',0,''),(169601,54184,'116195','furniture-mobile','show_description','0',0,''),(169602,54184,'116195','furniture-mobile','show_model','0',0,''),(169603,54184,'116195','furniture-mobile','show_properties','0',0,''),(169604,54184,'116195','furniture-mobile','show_rating','0',0,''),(169605,54184,'116195','furniture-mobile','show_rating_counts','0',0,''),(169606,54184,'116195','furniture-mobile','show_price','0',0,''),(169607,54184,'116195','furniture-mobile','show_buy_button','0',0,''),(169608,54184,'116195','furniture-mobile','show_view_button','0',0,''),(169609,54184,'116195','furniture-mobile','show_wishlist_button','0',0,''),(169610,54184,'116195','furniture-mobile','show_compare','0',0,''),(169611,54184,'116195','furniture-mobile','show_name_rows','0',0,''),(169612,54184,'116195','furniture-mobile','show_image_rows','0',0,''),(169613,54184,'116195','furniture-mobile','show_stock_rows','0',0,''),(169614,54184,'116195','furniture-mobile','show_description_rows','0',0,''),(169615,54184,'116195','furniture-mobile','show_model_rows','0',0,''),(169616,54184,'116195','furniture-mobile','show_properties_rows','0',0,''),(169617,54184,'116195','furniture-mobile','show_rating_rows','0',0,''),(169618,54184,'116195','furniture-mobile','show_rating_counts_rows','0',0,''),(169619,54184,'116195','furniture-mobile','show_price_rows','0',0,''),(169620,54184,'116195','furniture-mobile','show_buy_button_rows','0',0,''),(169621,54184,'116195','furniture-mobile','show_qty_input_rows','0',0,''),(169622,54184,'116195','furniture-mobile','show_view_button_rows','0',0,''),(169623,54184,'116195','furniture-mobile','show_wishlist_button_rows','0',0,''),(169624,54184,'116195','furniture-mobile','show_compare_rows','0',0,''),(169625,54184,'116195','furniture-mobile','show_name_b2b','0',0,''),(169626,54184,'116195','furniture-mobile','show_image_b2b','0',0,''),(169627,54184,'116195','furniture-mobile','show_stock_b2b','0',0,''),(169628,54184,'116195','furniture-mobile','show_description_b2b','0',0,''),(169629,54184,'116195','furniture-mobile','show_model_b2b','0',0,''),(169630,54184,'116195','furniture-mobile','show_properties_b2b','0',0,''),(169631,54184,'116195','furniture-mobile','show_rating_b2b','0',0,''),(169632,54184,'116195','furniture-mobile','show_rating_counts_b2b','0',0,''),(169633,54184,'116195','furniture-mobile','show_price_b2b','0',0,''),(169634,54184,'116195','furniture-mobile','show_qty_input_b2b','0',0,''),(169635,54184,'116195','furniture-mobile','show_view_button_b2b','0',0,''),(169636,54184,'116195','furniture-mobile','show_attributes_b2b','0',0,''),(169637,54184,'116195','furniture-mobile','items_on_page','9',0,''),(169638,54184,'116195','furniture-mobile','col_in_row','2',0,'2885'),(169639,54184,'116195','furniture-mobile','col_in_row','1',0,'2906'),(169640,54184,'116195','furniture-mobile','product_names_teg','h2',0,''),(169641,54185,'116196','furniture-mobile','listing_type','productListing',0,''),(169642,54186,'116197','furniture-mobile','block_type','1',0,''),(169643,54186,'116197','furniture-mobile','padding-top','10',0,''),(169644,54186,'116197','furniture-mobile','padding-bottom','10',0,''),(169645,54186,'116197','furniture-mobile','border-bottom-width','1',0,''),(169646,54186,'116197','furniture-mobile','border-bottom-color','$border-color-4',0,''),(169647,54186,'116197','furniture-mobile','margin-left','0',0,''),(169648,54186,'116197','furniture-mobile','margin-right','0',0,''),(169649,54187,'116198','furniture-mobile','float','right',0,''),(169650,54187,'116198','furniture-mobile','display','none',0,'2906'),(169651,54188,'116199','furniture-mobile','margin-right','20',0,''),(169652,54188,'116199','furniture-mobile','float','right',0,''),(169653,54188,'116199','furniture-mobile','clear','none',0,''),(169654,54188,'116199','furniture-mobile','display','none',0,'2885'),(169655,54189,'116200','furniture-mobile','float','left',0,''),(169656,54189,'116200','furniture-mobile','clear','none',0,''),(169657,54189,'116200','furniture-mobile','margin-left','20',0,''),(169658,54189,'116200','furniture-mobile','display','none',0,'2906'),(169659,54190,'116201','furniture-mobile','float','left',0,''),(169660,54190,'116201','furniture-mobile','clear','none',0,''),(169661,54190,'116201','furniture-mobile','sort_pos_3','1',0,''),(169662,54190,'116201','furniture-mobile','sort_pos_4','2',0,''),(169663,54190,'116201','furniture-mobile','sort_pos_10','3',0,''),(169664,54190,'116201','furniture-mobile','sort_pos_9','4',0,''),(169665,54190,'116201','furniture-mobile','sort_pos_11','5',0,''),(169666,54190,'116201','furniture-mobile','sort_pos_12','6',0,''),(169667,54190,'116201','furniture-mobile','sort_pos_14','7',0,''),(169668,54190,'116201','furniture-mobile','sort_pos_13','8',0,''),(169669,54190,'116201','furniture-mobile','sort_pos_8','9',0,''),(169670,54190,'116201','furniture-mobile','sort_pos_7','10',0,''),(169671,54190,'116201','furniture-mobile','sort_pos_2','11',0,''),(169672,54190,'116201','furniture-mobile','sort_pos_1','12',0,''),(169673,54190,'116201','furniture-mobile','sort_pos_6','13',0,''),(169674,54190,'116201','furniture-mobile','sort_pos_5','14',0,''),(169675,54190,'116201','furniture-mobile','sort_pos_0','15',0,''),(169676,54190,'116201','furniture-mobile','sort_hide_10','1',0,''),(169677,54190,'116201','furniture-mobile','sort_hide_9','1',0,''),(169678,54190,'116201','furniture-mobile','hide_icons','1',0,''),(169679,54190,'116201','furniture-mobile','sort_hide_16','1',0,''),(169680,54190,'116201','furniture-mobile','sort_hide_15','1',0,''),(169681,54190,'116201','furniture-mobile','sort_hide_3','0',0,''),(169682,54190,'116201','furniture-mobile','sort_hide_4','0',0,''),(169683,54190,'116201','furniture-mobile','sort_hide_11','1',0,''),(169684,54190,'116201','furniture-mobile','sort_hide_12','1',0,''),(169685,54190,'116201','furniture-mobile','sort_hide_14','1',0,''),(169686,54190,'116201','furniture-mobile','sort_hide_13','1',0,''),(169687,54190,'116201','furniture-mobile','sort_hide_8','0',0,''),(169688,54190,'116201','furniture-mobile','sort_hide_7','0',0,''),(169689,54190,'116201','furniture-mobile','sort_hide_2','1',0,''),(169690,54190,'116201','furniture-mobile','sort_hide_1','1',0,''),(169691,54190,'116201','furniture-mobile','sort_hide_6','1',0,''),(169692,54190,'116201','furniture-mobile','sort_hide_5','1',0,''),(169693,54190,'116201','furniture-mobile','sort_hide_0','1',0,''),(169694,54193,'116204','furniture-mobile','block_type','1',0,''),(169695,54194,'116205','furniture-mobile','block_type','7',0,''),(169696,54194,'116205','furniture-mobile','schema','7-2',0,'2885'),(169697,54195,'116206','furniture-mobile','padding-top','20',0,''),(169698,54195,'116206','furniture-mobile','padding-right','20',0,''),(169699,54196,'116207','furniture-mobile','blog_sidebar','1',0,''),(169700,54196,'116207','furniture-mobile','padding-top','20',0,''),(169701,54196,'116207','furniture-mobile','padding-left','20',0,''),(169703,54201,'1683110860.800967','furniture-mobile','block_type','1',0,''),(169704,54201,'1683110860.800967','furniture-mobile','font-weight','normal',0,''),(169705,54201,'1683110860.800967','furniture-mobile','padding-top','20',0,''),(169706,54201,'1683110860.800967','furniture-mobile','background-color','$background-6',0,''),(169707,54201,'1683110860.800967','furniture-mobile','style_class','shopping-cart-index',0,''),(169708,54202,'1683110860.811285','furniture-mobile','block_type','7',0,''),(169709,54202,'1683110860.811285','furniture-mobile','schema','4-1',0,'2890'),(169710,54202,'1683110860.811285','furniture-mobile','schema','4-2',0,'2885'),(169711,54203,'1683110860.81452','furniture-mobile','block_type','1',0,''),(169712,54203,'1683110860.81452','furniture-mobile','background-color','$background-7',0,''),(169713,54203,'1683110860.81452','furniture-mobile','padding-top','20',0,''),(169714,54203,'1683110860.81452','furniture-mobile','padding-bottom','20',0,''),(169715,54203,'1683110860.81452','furniture-mobile','padding-left','25',0,''),(169716,54203,'1683110860.81452','furniture-mobile','padding-right','25',0,''),(169717,54203,'1683110860.81452','furniture-mobile','margin-bottom','30',0,''),(169718,54204,'1683110860.815931','furniture-mobile','text','<div class=\"heading-3\">##TEXT_ALSO_INTERESTED##</div>',0,''),(169719,54204,'1683110860.815931','furniture-mobile','style_class','shipping-ico',0,''),(169720,54205,'1683110860.818836','furniture-mobile','col_in_row','4',0,''),(169721,54205,'1683110860.818836','furniture-mobile','show_description','1',0,''),(169722,54205,'1683110860.818836','furniture-mobile','show_model','1',0,''),(169723,54205,'1683110860.818836','furniture-mobile','show_properties','1',0,''),(169724,54205,'1683110860.818836','furniture-mobile','show_rating','1',0,''),(169725,54205,'1683110860.818836','furniture-mobile','show_rating_counts','1',0,''),(169726,54205,'1683110860.818836','furniture-mobile','show_qty_input','1',0,''),(169727,54205,'1683110860.818836','furniture-mobile','show_view_button','1',0,''),(169728,54205,'1683110860.818836','furniture-mobile','show_wishlist_button','1',0,''),(169729,54205,'1683110860.818836','furniture-mobile','show_compare','1',0,''),(169730,54205,'1683110860.818836','furniture-mobile','view_as','carousel',0,''),(169731,54205,'1683110860.818836','furniture-mobile','hide_parents','2',0,''),(169732,54205,'1683110860.818836','furniture-mobile','listing_type','productListing',0,''),(169733,54205,'1683110860.818836','furniture-mobile','show_bonus_points','1',0,''),(169734,54206,'1683110860.82112','furniture-mobile','block_type','1',0,''),(169735,54206,'1683110860.82112','furniture-mobile','background-color','$background-7',0,''),(169736,54206,'1683110860.82112','furniture-mobile','margin-bottom','25',0,''),(169737,54206,'1683110860.82112','furniture-mobile','padding-left','25',0,''),(169738,54206,'1683110860.82112','furniture-mobile','padding-right','25',0,''),(169739,54206,'1683110860.82112','furniture-mobile','padding-bottom','25',0,''),(169740,54207,'1683110860.82264','furniture-mobile','padding-top','20',0,''),(169741,54207,'1683110860.82264','furniture-mobile','padding-bottom','20',0,''),(169742,54208,'1683110860.823336','furniture-mobile','block_type','2',0,''),(169743,54208,'1683110860.823336','furniture-mobile','padding-bottom','20',0,''),(169744,54208,'1683110860.823336','furniture-mobile','padding-top','20',0,''),(169745,54208,'1683110860.823336','furniture-mobile','border-bottom-color','$border-color-4',0,''),(169746,54208,'1683110860.823336','furniture-mobile','border-bottom-width','1',0,''),(169747,54208,'1683110860.823336','furniture-mobile','schema','2-2',0,'2885'),(169748,54209,'1683110860.82490','furniture-mobile','float','left',0,''),(169749,54209,'1683110860.82490','furniture-mobile','float','none',0,'2885'),(169750,54210,'1683110860.825674','furniture-mobile','text-align','right',0,''),(169751,54210,'1683110860.825674','furniture-mobile','clear','none',0,''),(169752,54210,'1683110860.825674','furniture-mobile','float','right',0,''),(169753,54210,'1683110860.825674','furniture-mobile','padding-top','22',0,''),(169754,54210,'1683110860.825674','furniture-mobile','float','none',0,'2885'),(169755,54210,'1683110860.825674','furniture-mobile','text-align','left',0,'2885'),(169756,54211,'1683110860.826797','furniture-mobile','float','right',0,''),(169757,54211,'1683110860.826797','furniture-mobile','padding-top','26',0,''),(169758,54211,'1683110860.826797','furniture-mobile','float','none',0,'2885'),(169759,54211,'1683110860.826797','furniture-mobile','text-align','left',0,'2885'),(169760,54212,'1683110860.827896','furniture-mobile','block_type','3',0,''),(169761,54212,'1683110860.827896','furniture-mobile','font-weight','400',0,''),(169762,54212,'1683110860.827896','furniture-mobile','schema','2-2',0,'2876'),(169763,54212,'1683110860.827896','furniture-mobile','style_class','closeable-content',0,''),(169764,54212,'1683110860.827896','furniture-mobile','padding-top','10',0,''),(169765,54213,'1683110860.829995','furniture-mobile','font-weight','400',0,''),(169766,54213,'1683110860.829995','furniture-mobile','padding-right','24',0,''),(169767,54213,'1683110860.829995','furniture-mobile','padding-right','0',0,'2876'),(169768,54213,'1683110860.829995','furniture-mobile','padding-bottom','20',0,'2876'),(169769,54214,'1683110860.830980','furniture-mobile','padding-right','24',0,''),(169770,54214,'1683110860.830980','furniture-mobile','padding-right','0',0,'2876'),(169771,54214,'1683110860.830980','furniture-mobile','padding-bottom','20',0,'2876'),(169772,54216,'1683110860.83215','furniture-mobile','text-align','right',0,''),(169773,54217,'1683110860.833430','furniture-mobile','text','<div><span>##TEXT_YOUR_SHOPPING_CART##</span></div>',0,''),(169774,54217,'1683110860.833430','furniture-mobile','padding-top','20',0,''),(169775,54217,'1683110860.833430','furniture-mobile','margin-bottom','20',0,''),(169776,54217,'1683110860.833430','furniture-mobile','text-align','center',0,''),(169777,54217,'1683110860.833430','furniture-mobile','font-weight','bold',0,''),(169778,54217,'1683110860.833430','furniture-mobile','font-size','36',0,''),(169779,54217,'1683110860.833430','furniture-mobile','style_class','cartTitle',0,''),(169780,54218,'1683110860.835461','furniture-mobile','block_type','1',0,''),(169781,54218,'1683110860.835461','furniture-mobile','padding-top','20',0,''),(169782,54218,'1683110860.835461','furniture-mobile','padding-bottom','20',0,''),(169783,54218,'1683110860.835461','furniture-mobile','padding-left','25',0,''),(169784,54218,'1683110860.835461','furniture-mobile','padding-right','25',0,''),(169785,54218,'1683110860.835461','furniture-mobile','background-color','$background-7',0,''),(169786,54218,'1683110860.835461','furniture-mobile','margin-bottom','30',0,''),(169787,54219,'1683110860.837349','furniture-mobile','hide_parents','2',0,''),(169788,54220,'1683110860.83786','furniture-mobile','text','<div class=\"heading-3\">##TEXT_GA_PRODUCTS##</div>',0,''),(169789,54220,'1683110860.83786','furniture-mobile','style_class','shipping-ico',0,''),(169790,54221,'1683110860.839462','furniture-mobile','block_type','1',0,''),(169791,54221,'1683110860.839462','furniture-mobile','background-color','$background-7',0,''),(169792,54221,'1683110860.839462','furniture-mobile','padding-top','20',0,''),(169793,54221,'1683110860.839462','furniture-mobile','padding-left','25',0,''),(169794,54221,'1683110860.839462','furniture-mobile','padding-right','25',0,''),(169795,54221,'1683110860.839462','furniture-mobile','padding-bottom','20',0,''),(169796,54221,'1683110860.839462','furniture-mobile','margin-bottom','30',0,''),(169797,54221,'1683110860.839462','furniture-mobile','style_class','closeable-box',0,''),(169798,54222,'1683110860.841398','furniture-mobile','text','<div class=\"heading-3\">##TEXT_SHIPPING##</div>',0,''),(169799,54222,'1683110860.841398','furniture-mobile','style_class','shipping-ico',0,''),(169800,54223,'1683110860.84291','furniture-mobile','font-weight','normal',0,''),(169801,54223,'1683110860.84291','furniture-mobile','hide_parents','2',0,''),(169802,54224,'1683110860.843639','furniture-mobile','listing_type','productListing',0,''),(169803,54224,'1683110860.843639','furniture-mobile','col_in_row','4',0,''),(169804,54224,'1683110860.843639','furniture-mobile','show_popup','1',0,''),(169805,54224,'1683110860.843639','furniture-mobile','col_in_row','3',0,'2885'),(169806,54224,'1683110860.843639','furniture-mobile','col_in_row','2',0,'2876'),(169807,54224,'1683110860.843639','furniture-mobile','col_in_row','1',0,'2906'),(169808,54224,'1683110860.843639','furniture-mobile','padding-top','20',0,''),(169809,54224,'1683110860.843639','furniture-mobile','padding-left','25',0,''),(169810,54224,'1683110860.843639','furniture-mobile','padding-right','25',0,''),(169811,54224,'1683110860.843639','furniture-mobile','padding-bottom','20',0,''),(169812,54224,'1683110860.843639','furniture-mobile','background-color','$background-7',0,''),(169813,54224,'1683110860.843639','furniture-mobile','margin-bottom','25',0,''),(169814,54225,'1683110860.846971','furniture-mobile','style_class','order-summary',0,''),(169815,54225,'1683110860.846971','furniture-mobile','block_type','1',0,''),(169816,54225,'1683110860.846971','furniture-mobile','margin-left','25',0,''),(169817,54225,'1683110860.846971','furniture-mobile','margin-left','0',0,'2885'),(169818,54225,'1683110860.846971','furniture-mobile','margin-bottom','30',0,'2885'),(169819,54225,'1683110860.846971','furniture-mobile','padding-left','10',0,''),(169820,54225,'1683110860.846971','furniture-mobile','padding-right','10',0,''),(169821,54225,'1683110860.846971','furniture-mobile','padding-bottom','10',0,''),(169822,54225,'1683110860.846971','furniture-mobile','background-color','$background-7',0,''),(169823,54226,'1683110860.849323','furniture-mobile','block_type','1',0,''),(169824,54227,'1683110860.862447','furniture-mobile','font-weight','400',0,''),(169825,54227,'1683110860.862447','furniture-mobile','box_align','4',0,''),(169826,54227,'1683110860.862447','furniture-mobile','text-align','center',0,'2876'),(169827,54227,'1683110860.862447','furniture-mobile','float','none',0,'2876'),(169828,54227,'1683110860.862447','furniture-mobile','width','100',0,'2876'),(169829,54227,'1683110860.862447','furniture-mobile','width_measure','%',0,'2876'),(169830,54229,'1683110860.864695','furniture-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(169831,54230,'116242','furniture-mobile','block_type','1',0,''),(169832,54230,'116242','furniture-mobile','font-weight','normal',0,''),(169833,54230,'116242','furniture-mobile','padding-top','20',0,''),(169834,54230,'116242','furniture-mobile','background-color','$background-6',0,''),(169835,54232,'116244','furniture-mobile','block_type','4',0,''),(169836,54232,'116244','furniture-mobile','schema','4-1',0,'2890'),(169837,54232,'116244','furniture-mobile','schema','4-2',0,'2885'),(169838,54233,'116245','furniture-mobile','block_type','1',0,''),(169839,54233,'116245','furniture-mobile','background-color','$background-7',0,''),(169840,54233,'116245','furniture-mobile','padding-top','20',0,''),(169841,54233,'116245','furniture-mobile','padding-bottom','20',0,''),(169842,54233,'116245','furniture-mobile','padding-left','25',0,''),(169843,54233,'116245','furniture-mobile','padding-right','25',0,''),(169844,54233,'116245','furniture-mobile','margin-bottom','30',0,''),(169845,54234,'116246','furniture-mobile','col_in_row','3',0,''),(169846,54234,'116246','furniture-mobile','show_description','1',0,''),(169847,54234,'116246','furniture-mobile','show_model','1',0,''),(169848,54234,'116246','furniture-mobile','show_properties','1',0,''),(169849,54234,'116246','furniture-mobile','show_rating','1',0,''),(169850,54234,'116246','furniture-mobile','show_rating_counts','1',0,''),(169851,54234,'116246','furniture-mobile','show_qty_input','1',0,''),(169852,54234,'116246','furniture-mobile','show_view_button','1',0,''),(169853,54234,'116246','furniture-mobile','show_wishlist_button','1',0,''),(169854,54234,'116246','furniture-mobile','show_compare','1',0,''),(169855,54234,'116246','furniture-mobile','view_as','carousel',0,''),(169856,54234,'116246','furniture-mobile','hide_parents','2',0,''),(169857,54235,'116247','furniture-mobile','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(169858,54235,'116247','furniture-mobile','style_class','bell-ico',0,''),(169859,54236,'116248','furniture-mobile','block_type','1',0,''),(169860,54236,'116248','furniture-mobile','background-color','$background-7',0,''),(169861,54236,'116248','furniture-mobile','margin-bottom','30',0,''),(169862,54237,'116249','furniture-mobile','padding-top','20',0,''),(169863,54237,'116249','furniture-mobile','padding-left','25',0,''),(169864,54237,'116249','furniture-mobile','padding-right','25',0,''),(169865,54237,'116249','furniture-mobile','padding-bottom','20',0,''),(169866,54238,'116250','furniture-mobile','block_type','2',0,''),(169867,54238,'116250','furniture-mobile','padding-bottom','20',0,''),(169868,54238,'116250','furniture-mobile','padding-top','20',0,''),(169869,54238,'116250','furniture-mobile','padding-left','25',0,''),(169870,54238,'116250','furniture-mobile','padding-right','25',0,''),(169871,54238,'116250','furniture-mobile','border-bottom-color','$border-color-4',0,''),(169872,54238,'116250','furniture-mobile','border-bottom-width','1',0,''),(169873,54238,'116250','furniture-mobile','schema','2-2',0,'2885'),(169874,54239,'116251','furniture-mobile','float','left',0,''),(169875,54240,'116252','furniture-mobile','text-align','right',0,''),(169876,54240,'116252','furniture-mobile','clear','none',0,''),(169877,54240,'116252','furniture-mobile','float','right',0,''),(169878,54240,'116252','furniture-mobile','padding-top','22',0,''),(169879,54241,'116253','furniture-mobile','float','right',0,''),(169880,54241,'116253','furniture-mobile','padding-top','26',0,''),(169881,54242,'116254','furniture-mobile','block_type','1',0,''),(169882,54242,'116254','furniture-mobile','padding-top','20',0,''),(169883,54242,'116254','furniture-mobile','padding-bottom','20',0,''),(169884,54242,'116254','furniture-mobile','padding-left','25',0,''),(169885,54242,'116254','furniture-mobile','padding-right','25',0,''),(169886,54242,'116254','furniture-mobile','background-color','$background-7',0,''),(169887,54242,'116254','furniture-mobile','margin-bottom','30',0,''),(169888,54243,'116255','furniture-mobile','hide_parents','2',0,''),(169889,54244,'116256','furniture-mobile','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(169890,54245,'116257','furniture-mobile','block_type','1',0,''),(169891,54245,'116257','furniture-mobile','background-color','$background-7',0,''),(169892,54245,'116257','furniture-mobile','padding-top','20',0,''),(169893,54245,'116257','furniture-mobile','padding-bottom','20',0,''),(169894,54245,'116257','furniture-mobile','padding-left','25',0,''),(169895,54245,'116257','furniture-mobile','padding-right','25',0,''),(169896,54245,'116257','furniture-mobile','margin-bottom','30',0,''),(169897,54245,'116257','furniture-mobile','style_class','closeable-box',0,''),(169898,54246,'116258','furniture-mobile','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(169899,54246,'116258','furniture-mobile','style_class','savings-ico closeable-heading closeable-event',0,''),(169900,54247,'116259','furniture-mobile','block_type','3',0,''),(169901,54247,'116259','furniture-mobile','font-weight','400',0,''),(169902,54247,'116259','furniture-mobile','schema','2-2',0,'2876'),(169903,54247,'116259','furniture-mobile','style_class','closeable-content',0,''),(169904,54247,'116259','furniture-mobile','padding-top','10',0,''),(169905,54248,'116260','furniture-mobile','font-weight','400',0,''),(169906,54248,'116260','furniture-mobile','padding-top','12',0,'2876'),(169907,54248,'116260','furniture-mobile','padding-left','0',0,'2876'),(169908,54251,'116263','furniture-mobile','block_type','1',0,''),(169909,54251,'116263','furniture-mobile','background-color','$background-7',0,''),(169910,54251,'116263','furniture-mobile','padding-top','20',0,''),(169911,54251,'116263','furniture-mobile','padding-left','25',0,''),(169912,54251,'116263','furniture-mobile','padding-right','25',0,''),(169913,54251,'116263','furniture-mobile','padding-bottom','20',0,''),(169914,54251,'116263','furniture-mobile','margin-bottom','30',0,''),(169915,54251,'116263','furniture-mobile','style_class','closeable-box',0,''),(169916,54251,'116263','furniture-mobile','display','none',0,'2885'),(169917,54252,'116264','furniture-mobile','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(169918,54252,'116264','furniture-mobile','style_class','shipping-ico closeable-heading closeable-event',0,''),(169919,54253,'116265','furniture-mobile','font-weight','normal',0,''),(169920,54253,'116265','furniture-mobile','style_class','closeable-content',0,''),(169921,54253,'116265','furniture-mobile','padding-top','10',0,''),(169922,54253,'116265','furniture-mobile','hide_parents','2',0,''),(169923,54254,'116266','furniture-mobile','style_class','order-summary',0,''),(169924,54254,'116266','furniture-mobile','block_type','1',0,''),(169925,54254,'116266','furniture-mobile','margin-left','30',0,''),(169926,54254,'116266','furniture-mobile','margin-left','0',0,'2885'),(169927,54254,'116266','furniture-mobile','margin-bottom','30',0,'2885'),(169928,54255,'116267','furniture-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(169929,54256,'116268','furniture-mobile','block_type','1',0,''),(169930,54256,'116268','furniture-mobile','padding-left','20',0,''),(169931,54256,'116268','furniture-mobile','padding-right','20',0,''),(169932,54256,'116268','furniture-mobile','padding-bottom','20',0,''),(169933,54257,'116269','furniture-mobile','font-weight','400',0,''),(169934,54257,'116269','furniture-mobile','logo','themes/furniture-mobile/img/payicons-1.png',1,''),(169935,54257,'116269','furniture-mobile','padding-top','20',0,''),(169936,54257,'116269','furniture-mobile','padding-bottom','10',0,''),(169937,54258,'116270','furniture-mobile','font-weight','400',0,''),(169938,54258,'116270','furniture-mobile','box_align','4',0,''),(169939,54258,'116270','furniture-mobile','text-align','center',0,'2876'),(169940,54258,'116270','furniture-mobile','float','none',0,'2876'),(169941,54258,'116270','furniture-mobile','width','100',0,'2876'),(169942,54258,'116270','furniture-mobile','width_measure','%',0,'2876'),(169947,54270,'116272','furniture-mobile','block_type','1',0,''),(169948,54271,'116273','furniture-mobile','block_type','6',0,''),(169949,54271,'116273','furniture-mobile','font-weight','400',0,''),(169950,54271,'116273','furniture-mobile','schema','6-2',0,'2906'),(169951,54271,'116273','furniture-mobile','schema','6-2',0,'2885'),(169952,54272,'116274','furniture-mobile','font-weight','400',0,''),(169953,54272,'116274','furniture-mobile','padding-right','40',0,''),(169954,54272,'116274','furniture-mobile','padding-right','0',0,'2906'),(169955,54272,'116274','furniture-mobile','padding-right','0',0,'2885'),(169956,54274,'116275','furniture-mobile','col_in_row','3',0,''),(169957,54274,'116275','furniture-mobile','products_align','left',0,''),(169958,54274,'116275','furniture-mobile','font-weight','400',0,''),(169959,54274,'116275','furniture-mobile','show_qty_input','0',0,''),(169960,54274,'116275','furniture-mobile','listing_type','productListing',0,''),(169961,54274,'116275','furniture-mobile','listing_type_rows','Rows',0,''),(169962,54274,'116275','furniture-mobile','show_buy_button_b2b','on',0,''),(169963,54274,'116275','furniture-mobile','show_wishlist_button_b2b','1',0,''),(169964,54274,'116275','furniture-mobile','show_compare_b2b','1',0,''),(169965,54274,'116275','furniture-mobile','listing_type_b2b','b2b',0,''),(169966,54274,'116275','furniture-mobile','show_stock','0',0,''),(169967,54274,'116275','furniture-mobile','show_description','0',0,''),(169968,54274,'116275','furniture-mobile','show_model','0',0,''),(169969,54274,'116275','furniture-mobile','show_properties','0',0,''),(169970,54274,'116275','furniture-mobile','show_rating','0',0,''),(169971,54274,'116275','furniture-mobile','show_rating_counts','0',0,''),(169972,54274,'116275','furniture-mobile','show_price','0',0,''),(169973,54274,'116275','furniture-mobile','show_buy_button','0',0,''),(169974,54274,'116275','furniture-mobile','show_view_button','0',0,''),(169975,54274,'116275','furniture-mobile','show_wishlist_button','0',0,''),(169976,54274,'116275','furniture-mobile','show_compare','0',0,''),(169977,54274,'116275','furniture-mobile','show_name_rows','0',0,''),(169978,54274,'116275','furniture-mobile','show_image_rows','0',0,''),(169979,54274,'116275','furniture-mobile','show_stock_rows','0',0,''),(169980,54274,'116275','furniture-mobile','show_description_rows','0',0,''),(169981,54274,'116275','furniture-mobile','show_model_rows','0',0,''),(169982,54274,'116275','furniture-mobile','show_properties_rows','0',0,''),(169983,54274,'116275','furniture-mobile','show_rating_rows','0',0,''),(169984,54274,'116275','furniture-mobile','show_rating_counts_rows','0',0,''),(169985,54274,'116275','furniture-mobile','show_price_rows','0',0,''),(169986,54274,'116275','furniture-mobile','show_buy_button_rows','0',0,''),(169987,54274,'116275','furniture-mobile','show_qty_input_rows','0',0,''),(169988,54274,'116275','furniture-mobile','show_view_button_rows','0',0,''),(169989,54274,'116275','furniture-mobile','show_wishlist_button_rows','0',0,''),(169990,54274,'116275','furniture-mobile','show_compare_rows','0',0,''),(169991,54274,'116275','furniture-mobile','show_name_b2b','0',0,''),(169992,54274,'116275','furniture-mobile','show_image_b2b','0',0,''),(169993,54274,'116275','furniture-mobile','show_stock_b2b','0',0,''),(169994,54274,'116275','furniture-mobile','show_description_b2b','0',0,''),(169995,54274,'116275','furniture-mobile','show_model_b2b','0',0,''),(169996,54274,'116275','furniture-mobile','show_properties_b2b','0',0,''),(169997,54274,'116275','furniture-mobile','show_rating_b2b','0',0,''),(169998,54274,'116275','furniture-mobile','show_rating_counts_b2b','0',0,''),(169999,54274,'116275','furniture-mobile','show_price_b2b','0',0,''),(170000,54274,'116275','furniture-mobile','show_qty_input_b2b','0',0,''),(170001,54274,'116275','furniture-mobile','show_view_button_b2b','0',0,''),(170002,54274,'116275','furniture-mobile','show_attributes_b2b','0',0,''),(170003,54274,'116275','furniture-mobile','items_on_page','9',0,''),(170004,54274,'116275','furniture-mobile','col_in_row','2',0,'2885'),(170005,54274,'116275','furniture-mobile','col_in_row','1',0,'2906'),(170006,54274,'116275','furniture-mobile','product_names_teg','h2',0,''),(170007,54276,'116277','furniture-mobile','block_type','5',0,''),(170008,54276,'116277','furniture-mobile','padding-top','10',0,''),(170009,54276,'116277','furniture-mobile','padding-bottom','10',0,''),(170010,54276,'116277','furniture-mobile','schema','5-2',0,'2906'),(170011,54276,'116277','furniture-mobile','border-top-color','$border-color-4',0,''),(170012,54276,'116277','furniture-mobile','border-top-width','1',0,''),(170013,54278,'116279','furniture-mobile','float','right',0,''),(170014,54279,'116280','furniture-mobile','listing_type','productListing',0,''),(170015,54281,'116282','furniture-mobile','block_type','1',0,''),(170016,54281,'116282','furniture-mobile','padding-top','10',0,''),(170017,54281,'116282','furniture-mobile','padding-bottom','10',0,''),(170018,54281,'116282','furniture-mobile','border-bottom-width','1',0,''),(170019,54281,'116282','furniture-mobile','border-bottom-color','$border-color-4',0,''),(170020,54281,'116282','furniture-mobile','margin-left','0',0,''),(170021,54281,'116282','furniture-mobile','margin-right','0',0,''),(170022,54282,'116283','furniture-mobile','float','right',0,''),(170023,54282,'116283','furniture-mobile','display','none',0,'2906'),(170024,54283,'116284','furniture-mobile','margin-right','20',0,''),(170025,54283,'116284','furniture-mobile','float','right',0,''),(170026,54283,'116284','furniture-mobile','clear','none',0,''),(170027,54283,'116284','furniture-mobile','display','none',0,'2885'),(170028,54284,'116285','furniture-mobile','float','left',0,''),(170029,54284,'116285','furniture-mobile','clear','none',0,''),(170030,54284,'116285','furniture-mobile','margin-left','20',0,''),(170031,54284,'116285','furniture-mobile','display','none',0,'2906'),(170032,54284,'116285','furniture-mobile','display','none',0,'2890'),(170033,54285,'116286','furniture-mobile','float','left',0,''),(170034,54285,'116286','furniture-mobile','clear','none',0,''),(170035,54285,'116286','furniture-mobile','sort_pos_3','1',0,''),(170036,54285,'116286','furniture-mobile','sort_pos_4','2',0,''),(170037,54285,'116286','furniture-mobile','sort_pos_10','3',0,''),(170038,54285,'116286','furniture-mobile','sort_pos_9','4',0,''),(170039,54285,'116286','furniture-mobile','sort_pos_11','5',0,''),(170040,54285,'116286','furniture-mobile','sort_pos_12','6',0,''),(170041,54285,'116286','furniture-mobile','sort_pos_14','7',0,''),(170042,54285,'116286','furniture-mobile','sort_pos_13','8',0,''),(170043,54285,'116286','furniture-mobile','sort_pos_8','9',0,''),(170044,54285,'116286','furniture-mobile','sort_pos_7','10',0,''),(170045,54285,'116286','furniture-mobile','sort_pos_2','11',0,''),(170046,54285,'116286','furniture-mobile','sort_pos_1','12',0,''),(170047,54285,'116286','furniture-mobile','sort_pos_6','13',0,''),(170048,54285,'116286','furniture-mobile','sort_pos_5','14',0,''),(170049,54285,'116286','furniture-mobile','sort_pos_0','15',0,''),(170050,54285,'116286','furniture-mobile','sort_hide_10','1',0,''),(170051,54285,'116286','furniture-mobile','sort_hide_9','1',0,''),(170052,54285,'116286','furniture-mobile','hide_icons','1',0,''),(170053,54285,'116286','furniture-mobile','sort_hide_16','1',0,''),(170054,54285,'116286','furniture-mobile','sort_hide_15','1',0,''),(170055,54285,'116286','furniture-mobile','sort_hide_3','0',0,''),(170056,54285,'116286','furniture-mobile','sort_hide_4','0',0,''),(170057,54285,'116286','furniture-mobile','sort_hide_11','1',0,''),(170058,54285,'116286','furniture-mobile','sort_hide_12','1',0,''),(170059,54285,'116286','furniture-mobile','sort_hide_14','1',0,''),(170060,54285,'116286','furniture-mobile','sort_hide_13','1',0,''),(170061,54285,'116286','furniture-mobile','sort_hide_8','0',0,''),(170062,54285,'116286','furniture-mobile','sort_hide_7','0',0,''),(170063,54285,'116286','furniture-mobile','sort_hide_2','1',0,''),(170064,54285,'116286','furniture-mobile','sort_hide_1','1',0,''),(170065,54285,'116286','furniture-mobile','sort_hide_6','1',0,''),(170066,54285,'116286','furniture-mobile','sort_hide_5','1',0,''),(170067,54285,'116286','furniture-mobile','sort_hide_0','1',0,''),(170068,54292,'116293','furniture-mobile','block_type','1',0,''),(170069,54294,'116295','furniture-mobile','block_type','6',0,''),(170070,54294,'116295','furniture-mobile','font-weight','400',0,''),(170071,54294,'116295','furniture-mobile','schema','6-2',0,'2906'),(170072,54294,'116295','furniture-mobile','schema','6-2',0,'2885'),(170073,54295,'116296','furniture-mobile','font-weight','400',0,''),(170074,54295,'116296','furniture-mobile','padding-right','40',0,''),(170075,54295,'116296','furniture-mobile','padding-right','0',0,'2906'),(170076,54295,'116296','furniture-mobile','padding-right','0',0,'2885'),(170077,54297,'116298','furniture-mobile','col_in_row','3',0,''),(170078,54297,'116298','furniture-mobile','products_align','left',0,''),(170079,54297,'116298','furniture-mobile','font-weight','400',0,''),(170080,54297,'116298','furniture-mobile','show_qty_input','0',0,''),(170081,54297,'116298','furniture-mobile','listing_type','productListing',0,''),(170082,54297,'116298','furniture-mobile','listing_type_rows','no',0,''),(170083,54297,'116298','furniture-mobile','show_buy_button_b2b','on',0,''),(170084,54297,'116298','furniture-mobile','show_wishlist_button_b2b','1',0,''),(170085,54297,'116298','furniture-mobile','show_compare_b2b','1',0,''),(170086,54297,'116298','furniture-mobile','show_stock','0',0,''),(170087,54297,'116298','furniture-mobile','show_description','0',0,''),(170088,54297,'116298','furniture-mobile','show_model','0',0,''),(170089,54297,'116298','furniture-mobile','show_properties','0',0,''),(170090,54297,'116298','furniture-mobile','show_rating','0',0,''),(170091,54297,'116298','furniture-mobile','show_rating_counts','0',0,''),(170092,54297,'116298','furniture-mobile','show_price','0',0,''),(170093,54297,'116298','furniture-mobile','show_buy_button','0',0,''),(170094,54297,'116298','furniture-mobile','show_view_button','0',0,''),(170095,54297,'116298','furniture-mobile','show_wishlist_button','0',0,''),(170096,54297,'116298','furniture-mobile','show_compare','0',0,''),(170097,54297,'116298','furniture-mobile','show_name_rows','0',0,''),(170098,54297,'116298','furniture-mobile','show_image_rows','0',0,''),(170099,54297,'116298','furniture-mobile','show_stock_rows','0',0,''),(170100,54297,'116298','furniture-mobile','show_description_rows','0',0,''),(170101,54297,'116298','furniture-mobile','show_model_rows','0',0,''),(170102,54297,'116298','furniture-mobile','show_properties_rows','0',0,''),(170103,54297,'116298','furniture-mobile','show_rating_rows','0',0,''),(170104,54297,'116298','furniture-mobile','show_rating_counts_rows','0',0,''),(170105,54297,'116298','furniture-mobile','show_price_rows','0',0,''),(170106,54297,'116298','furniture-mobile','show_buy_button_rows','0',0,''),(170107,54297,'116298','furniture-mobile','show_qty_input_rows','0',0,''),(170108,54297,'116298','furniture-mobile','show_view_button_rows','0',0,''),(170109,54297,'116298','furniture-mobile','show_wishlist_button_rows','0',0,''),(170110,54297,'116298','furniture-mobile','show_compare_rows','0',0,''),(170111,54297,'116298','furniture-mobile','show_name_b2b','0',0,''),(170112,54297,'116298','furniture-mobile','show_image_b2b','0',0,''),(170113,54297,'116298','furniture-mobile','show_stock_b2b','0',0,''),(170114,54297,'116298','furniture-mobile','show_description_b2b','0',0,''),(170115,54297,'116298','furniture-mobile','show_model_b2b','0',0,''),(170116,54297,'116298','furniture-mobile','show_properties_b2b','0',0,''),(170117,54297,'116298','furniture-mobile','show_rating_b2b','0',0,''),(170118,54297,'116298','furniture-mobile','show_rating_counts_b2b','0',0,''),(170119,54297,'116298','furniture-mobile','show_price_b2b','0',0,''),(170120,54297,'116298','furniture-mobile','show_qty_input_b2b','0',0,''),(170121,54297,'116298','furniture-mobile','show_view_button_b2b','0',0,''),(170122,54297,'116298','furniture-mobile','show_attributes_b2b','0',0,''),(170123,54297,'116298','furniture-mobile','items_on_page','9',0,''),(170124,54297,'116298','furniture-mobile','col_in_row','2',0,'2885'),(170125,54297,'116298','furniture-mobile','col_in_row','1',0,'2906'),(170126,54297,'116298','furniture-mobile','product_names_teg','h2',0,''),(170127,54298,'116299','furniture-mobile','block_type','1',0,''),(170128,54298,'116299','furniture-mobile','padding-top','10',0,''),(170129,54298,'116299','furniture-mobile','padding-bottom','10',0,''),(170130,54298,'116299','furniture-mobile','border-bottom-width','1',0,''),(170131,54298,'116299','furniture-mobile','border-bottom-color','$border-color-4',0,''),(170132,54298,'116299','furniture-mobile','margin-left','0',0,''),(170133,54298,'116299','furniture-mobile','margin-right','0',0,''),(170134,54299,'116300','furniture-mobile','float','left',0,''),(170135,54299,'116300','furniture-mobile','clear','none',0,''),(170136,54299,'116300','furniture-mobile','sort_pos_3','1',0,''),(170137,54299,'116300','furniture-mobile','sort_pos_4','2',0,''),(170138,54299,'116300','furniture-mobile','sort_pos_10','3',0,''),(170139,54299,'116300','furniture-mobile','sort_pos_9','4',0,''),(170140,54299,'116300','furniture-mobile','sort_pos_11','5',0,''),(170141,54299,'116300','furniture-mobile','sort_pos_12','6',0,''),(170142,54299,'116300','furniture-mobile','sort_pos_14','7',0,''),(170143,54299,'116300','furniture-mobile','sort_pos_13','8',0,''),(170144,54299,'116300','furniture-mobile','sort_pos_8','9',0,''),(170145,54299,'116300','furniture-mobile','sort_pos_7','10',0,''),(170146,54299,'116300','furniture-mobile','sort_pos_2','11',0,''),(170147,54299,'116300','furniture-mobile','sort_pos_1','12',0,''),(170148,54299,'116300','furniture-mobile','sort_pos_6','13',0,''),(170149,54299,'116300','furniture-mobile','sort_pos_5','14',0,''),(170150,54299,'116300','furniture-mobile','sort_pos_0','15',0,''),(170151,54299,'116300','furniture-mobile','sort_hide_10','1',0,''),(170152,54299,'116300','furniture-mobile','sort_hide_9','1',0,''),(170153,54299,'116300','furniture-mobile','hide_icons','1',0,''),(170154,54299,'116300','furniture-mobile','sort_hide_16','1',0,''),(170155,54299,'116300','furniture-mobile','sort_hide_15','1',0,''),(170156,54299,'116300','furniture-mobile','sort_hide_3','0',0,''),(170157,54299,'116300','furniture-mobile','sort_hide_4','0',0,''),(170158,54299,'116300','furniture-mobile','sort_hide_11','1',0,''),(170159,54299,'116300','furniture-mobile','sort_hide_12','1',0,''),(170160,54299,'116300','furniture-mobile','sort_hide_14','1',0,''),(170161,54299,'116300','furniture-mobile','sort_hide_13','1',0,''),(170162,54299,'116300','furniture-mobile','sort_hide_8','0',0,''),(170163,54299,'116300','furniture-mobile','sort_hide_7','0',0,''),(170164,54299,'116300','furniture-mobile','sort_hide_2','1',0,''),(170165,54299,'116300','furniture-mobile','sort_hide_1','1',0,''),(170166,54299,'116300','furniture-mobile','sort_hide_6','1',0,''),(170167,54299,'116300','furniture-mobile','sort_hide_5','1',0,''),(170168,54299,'116300','furniture-mobile','sort_hide_0','1',0,''),(170169,54300,'116301','furniture-mobile','float','left',0,''),(170170,54300,'116301','furniture-mobile','clear','none',0,''),(170171,54300,'116301','furniture-mobile','margin-left','20',0,''),(170172,54300,'116301','furniture-mobile','display','none',0,'2906'),(170173,54301,'116302','furniture-mobile','margin-right','20',0,''),(170174,54301,'116302','furniture-mobile','float','right',0,''),(170175,54301,'116302','furniture-mobile','clear','none',0,''),(170176,54301,'116302','furniture-mobile','display','none',0,'2885'),(170177,54302,'116303','furniture-mobile','float','right',0,''),(170178,54302,'116303','furniture-mobile','display','none',0,'2906'),(170179,54303,'116304','furniture-mobile','listing_type','productListing',0,''),(170180,54305,'116306','furniture-mobile','block_type','5',0,''),(170181,54305,'116306','furniture-mobile','padding-top','10',0,''),(170182,54305,'116306','furniture-mobile','padding-bottom','10',0,''),(170183,54305,'116306','furniture-mobile','schema','5-2',0,'2906'),(170184,54305,'116306','furniture-mobile','border-top-color','$border-color-4',0,''),(170185,54305,'116306','furniture-mobile','border-top-width','1',0,''),(170186,54307,'116308','furniture-mobile','float','right',0,''),(170187,54308,'116309','furniture-mobile','block_type','1',0,''),(170188,54311,'116312','furniture-mobile','block_type','1',0,''),(170189,54311,'116312','furniture-mobile','padding-top','10',0,''),(170190,54311,'116312','furniture-mobile','padding-bottom','10',0,''),(170191,54311,'116312','furniture-mobile','border-bottom-width','1',0,''),(170192,54311,'116312','furniture-mobile','border-bottom-color','$border-color-4',0,''),(170193,54311,'116312','furniture-mobile','margin-left','0',0,''),(170194,54311,'116312','furniture-mobile','margin-right','0',0,''),(170195,54312,'116313','furniture-mobile','float','left',0,''),(170196,54312,'116313','furniture-mobile','clear','none',0,''),(170197,54312,'116313','furniture-mobile','margin-left','20',0,''),(170198,54312,'116313','furniture-mobile','display','none',0,'2906'),(170199,54313,'116314','furniture-mobile','float','left',0,''),(170200,54313,'116314','furniture-mobile','clear','none',0,''),(170201,54313,'116314','furniture-mobile','sort_pos_3','1',0,''),(170202,54313,'116314','furniture-mobile','sort_pos_4','2',0,''),(170203,54313,'116314','furniture-mobile','sort_pos_10','3',0,''),(170204,54313,'116314','furniture-mobile','sort_pos_9','4',0,''),(170205,54313,'116314','furniture-mobile','sort_pos_11','5',0,''),(170206,54313,'116314','furniture-mobile','sort_pos_12','6',0,''),(170207,54313,'116314','furniture-mobile','sort_pos_14','7',0,''),(170208,54313,'116314','furniture-mobile','sort_pos_13','8',0,''),(170209,54313,'116314','furniture-mobile','sort_pos_8','9',0,''),(170210,54313,'116314','furniture-mobile','sort_pos_7','10',0,''),(170211,54313,'116314','furniture-mobile','sort_pos_2','11',0,''),(170212,54313,'116314','furniture-mobile','sort_pos_1','12',0,''),(170213,54313,'116314','furniture-mobile','sort_pos_6','13',0,''),(170214,54313,'116314','furniture-mobile','sort_pos_5','14',0,''),(170215,54313,'116314','furniture-mobile','sort_pos_0','15',0,''),(170216,54313,'116314','furniture-mobile','sort_hide_10','1',0,''),(170217,54313,'116314','furniture-mobile','sort_hide_9','1',0,''),(170218,54313,'116314','furniture-mobile','hide_icons','1',0,''),(170219,54313,'116314','furniture-mobile','sort_hide_16','1',0,''),(170220,54313,'116314','furniture-mobile','sort_hide_15','1',0,''),(170221,54313,'116314','furniture-mobile','sort_hide_3','0',0,''),(170222,54313,'116314','furniture-mobile','sort_hide_4','0',0,''),(170223,54313,'116314','furniture-mobile','sort_hide_11','1',0,''),(170224,54313,'116314','furniture-mobile','sort_hide_12','1',0,''),(170225,54313,'116314','furniture-mobile','sort_hide_14','1',0,''),(170226,54313,'116314','furniture-mobile','sort_hide_13','1',0,''),(170227,54313,'116314','furniture-mobile','sort_hide_8','0',0,''),(170228,54313,'116314','furniture-mobile','sort_hide_7','0',0,''),(170229,54313,'116314','furniture-mobile','sort_hide_2','1',0,''),(170230,54313,'116314','furniture-mobile','sort_hide_1','1',0,''),(170231,54313,'116314','furniture-mobile','sort_hide_6','1',0,''),(170232,54313,'116314','furniture-mobile','sort_hide_5','1',0,''),(170233,54313,'116314','furniture-mobile','sort_hide_0','1',0,''),(170234,54314,'116315','furniture-mobile','margin-right','20',0,''),(170235,54314,'116315','furniture-mobile','float','right',0,''),(170236,54314,'116315','furniture-mobile','clear','none',0,''),(170237,54314,'116315','furniture-mobile','display','none',0,'2885'),(170238,54315,'116316','furniture-mobile','float','right',0,''),(170239,54315,'116316','furniture-mobile','display','none',0,'2906'),(170240,54316,'116317','furniture-mobile','clear','none',0,''),(170241,54316,'116317','furniture-mobile','float','left',0,''),(170242,54316,'116317','furniture-mobile','padding-top','3',0,''),(170243,54316,'116317','furniture-mobile','padding-left','20',0,''),(170244,54317,'116318','furniture-mobile','block_type','5',0,''),(170245,54317,'116318','furniture-mobile','padding-top','10',0,''),(170246,54317,'116318','furniture-mobile','padding-bottom','10',0,''),(170247,54317,'116318','furniture-mobile','schema','5-2',0,'2906'),(170248,54317,'116318','furniture-mobile','border-top-color','$border-color-4',0,''),(170249,54317,'116318','furniture-mobile','border-top-width','1',0,''),(170250,54319,'116320','furniture-mobile','float','right',0,''),(170251,54320,'116321','furniture-mobile','col_in_row','4',0,''),(170252,54320,'116321','furniture-mobile','products_align','left',0,''),(170253,54320,'116321','furniture-mobile','font-weight','400',0,''),(170254,54320,'116321','furniture-mobile','show_qty_input','0',0,''),(170255,54320,'116321','furniture-mobile','listing_type','productListing',0,''),(170256,54320,'116321','furniture-mobile','listing_type_rows','Rows',0,''),(170257,54320,'116321','furniture-mobile','show_buy_button_b2b','on',0,''),(170258,54320,'116321','furniture-mobile','show_wishlist_button_b2b','1',0,''),(170259,54320,'116321','furniture-mobile','show_compare_b2b','1',0,''),(170260,54320,'116321','furniture-mobile','listing_type_b2b','b2b',0,''),(170261,54320,'116321','furniture-mobile','show_image','0',0,''),(170262,54320,'116321','furniture-mobile','show_stock','0',0,''),(170263,54320,'116321','furniture-mobile','show_description','0',0,''),(170264,54320,'116321','furniture-mobile','show_model','0',0,''),(170265,54320,'116321','furniture-mobile','show_properties','0',0,''),(170266,54320,'116321','furniture-mobile','show_rating','0',0,''),(170267,54320,'116321','furniture-mobile','show_rating_counts','0',0,''),(170268,54320,'116321','furniture-mobile','show_price','0',0,''),(170269,54320,'116321','furniture-mobile','show_buy_button','0',0,''),(170270,54320,'116321','furniture-mobile','show_view_button','0',0,''),(170271,54320,'116321','furniture-mobile','show_wishlist_button','0',0,''),(170272,54320,'116321','furniture-mobile','show_compare','0',0,''),(170273,54320,'116321','furniture-mobile','show_name_rows','0',0,''),(170274,54320,'116321','furniture-mobile','show_image_rows','0',0,''),(170275,54320,'116321','furniture-mobile','show_stock_rows','0',0,''),(170276,54320,'116321','furniture-mobile','show_description_rows','0',0,''),(170277,54320,'116321','furniture-mobile','show_model_rows','0',0,''),(170278,54320,'116321','furniture-mobile','show_properties_rows','0',0,''),(170279,54320,'116321','furniture-mobile','show_rating_rows','0',0,''),(170280,54320,'116321','furniture-mobile','show_rating_counts_rows','0',0,''),(170281,54320,'116321','furniture-mobile','show_price_rows','0',0,''),(170282,54320,'116321','furniture-mobile','show_buy_button_rows','0',0,''),(170283,54320,'116321','furniture-mobile','show_qty_input_rows','0',0,''),(170284,54320,'116321','furniture-mobile','show_view_button_rows','0',0,''),(170285,54320,'116321','furniture-mobile','show_wishlist_button_rows','0',0,''),(170286,54320,'116321','furniture-mobile','show_compare_rows','0',0,''),(170287,54320,'116321','furniture-mobile','show_name_b2b','0',0,''),(170288,54320,'116321','furniture-mobile','show_image_b2b','0',0,''),(170289,54320,'116321','furniture-mobile','show_stock_b2b','0',0,''),(170290,54320,'116321','furniture-mobile','show_description_b2b','0',0,''),(170291,54320,'116321','furniture-mobile','show_model_b2b','0',0,''),(170292,54320,'116321','furniture-mobile','show_properties_b2b','0',0,''),(170293,54320,'116321','furniture-mobile','show_rating_b2b','0',0,''),(170294,54320,'116321','furniture-mobile','show_rating_counts_b2b','0',0,''),(170295,54320,'116321','furniture-mobile','show_price_b2b','0',0,''),(170296,54320,'116321','furniture-mobile','show_qty_input_b2b','0',0,''),(170297,54320,'116321','furniture-mobile','show_view_button_b2b','0',0,''),(170298,54320,'116321','furniture-mobile','show_attributes_b2b','0',0,''),(170299,54320,'116321','furniture-mobile','items_on_page','12',0,''),(170300,54320,'116321','furniture-mobile','col_in_row','2',0,'2885'),(170301,54320,'116321','furniture-mobile','col_in_row','1',0,'2906'),(170302,54320,'116321','furniture-mobile','product_names_teg','h2',0,''),(170303,54323,'1683112094.454335','furniture-mobile','block_type','1',0,''),(170304,54323,'1683112094.454335','furniture-mobile','background-color','$background-6',0,''),(170305,54323,'1683112094.454335','furniture-mobile','padding-top','30',0,''),(170306,54323,'1683112094.454335','furniture-mobile','padding-bottom','30',0,''),(170307,54323,'1683112094.454335','furniture-mobile','style_class','checkout-index-wrap',0,''),(170308,54324,'1683112094.46510','furniture-mobile','block_type','7',0,''),(170309,54324,'1683112094.46510','furniture-mobile','schema','4-2',0,'2885'),(170310,54325,'1683112094.466634','furniture-mobile','block_type','1',0,''),(170311,54325,'1683112094.466634','furniture-mobile','padding-right','0',0,'2885'),(170312,54326,'1683112094.468254','furniture-mobile','block_type','1',0,''),(170313,54326,'1683112094.468254','furniture-mobile','background-color','$background-7',0,''),(170314,54326,'1683112094.468254','furniture-mobile','padding-top','30',0,''),(170315,54326,'1683112094.468254','furniture-mobile','padding-left','30',0,''),(170316,54326,'1683112094.468254','furniture-mobile','padding-right','30',0,''),(170317,54326,'1683112094.468254','furniture-mobile','padding-bottom','14',0,''),(170318,54326,'1683112094.468254','furniture-mobile','margin-bottom','20',0,''),(170319,54326,'1683112094.468254','furniture-mobile','style_class','hiding-box closeable-box',0,''),(170320,54327,'1683112094.470662','furniture-mobile','style_class','closeable-content',0,''),(170321,54327,'1683112094.470662','furniture-mobile','padding-bottom','20',0,''),(170322,54328,'1683112094.473482','furniture-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(170323,54328,'1683112094.473482','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(170324,54329,'1683112094.477128','furniture-mobile','block_type','1',0,''),(170325,54329,'1683112094.477128','furniture-mobile','padding-top','30',0,''),(170326,54329,'1683112094.477128','furniture-mobile','padding-left','30',0,''),(170327,54329,'1683112094.477128','furniture-mobile','padding-right','30',0,''),(170328,54329,'1683112094.477128','furniture-mobile','padding-bottom','14',0,''),(170329,54329,'1683112094.477128','furniture-mobile','margin-bottom','20',0,''),(170330,54329,'1683112094.477128','furniture-mobile','background-color','$background-7',0,''),(170331,54329,'1683112094.477128','furniture-mobile','style_class','hiding-box closeable-box',0,''),(170332,54330,'1683112094.479689','furniture-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(170333,54330,'1683112094.479689','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(170334,54331,'1683112094.481499','furniture-mobile','block_type','2',0,''),(170335,54331,'1683112094.481499','furniture-mobile','style_class','closeable-content',0,''),(170336,54331,'1683112094.481499','furniture-mobile','schema','2-2',0,'2885'),(170337,54332,'1683112094.482824','furniture-mobile','padding-right','20',0,''),(170338,54332,'1683112094.482824','furniture-mobile','padding-bottom','20',0,''),(170339,54332,'1683112094.482824','furniture-mobile','padding-right','0',0,'2885'),(170340,54333,'1683112094.484566','furniture-mobile','padding-left','20',0,''),(170341,54333,'1683112094.484566','furniture-mobile','padding-bottom','20',0,''),(170342,54333,'1683112094.484566','furniture-mobile','padding-left','0',0,'2885'),(170343,54334,'1683112094.486280','furniture-mobile','padding-left','20',0,''),(170344,54334,'1683112094.486280','furniture-mobile','padding-bottom','20',0,''),(170345,54334,'1683112094.486280','furniture-mobile','padding-left','0',0,'2885'),(170346,54335,'1683112094.487748','furniture-mobile','background-color','$background-7',0,''),(170347,54335,'1683112094.487748','furniture-mobile','block_type','1',0,''),(170348,54335,'1683112094.487748','furniture-mobile','padding-top','30',0,''),(170349,54335,'1683112094.487748','furniture-mobile','padding-left','30',0,''),(170350,54335,'1683112094.487748','furniture-mobile','padding-right','30',0,''),(170351,54335,'1683112094.487748','furniture-mobile','padding-bottom','30',0,''),(170352,54335,'1683112094.487748','furniture-mobile','margin-bottom','20',0,''),(170353,54335,'1683112094.487748','furniture-mobile','style_class','hiding-box',0,''),(170354,54336,'1683112094.489595','furniture-mobile','block_type','1',0,''),(170355,54336,'1683112094.489595','furniture-mobile','content','\\_',0,'3'),(170356,54336,'1683112094.489595','furniture-mobile','border-top-width','1',0,'3'),(170357,54336,'1683112094.489595','furniture-mobile','border-top-color','$border-color-4',0,'3'),(170358,54336,'1683112094.489595','furniture-mobile','display','block',0,'3'),(170359,54336,'1683112094.489595','furniture-mobile','position','absolute',0,'3'),(170360,54336,'1683112094.489595','furniture-mobile','top','19',0,'3'),(170361,54336,'1683112094.489595','furniture-mobile','left','0',0,'3'),(170362,54336,'1683112094.489595','furniture-mobile','right','0',0,'3'),(170363,54336,'1683112094.489595','furniture-mobile','margin-top','-2',0,'3'),(170364,54336,'1683112094.489595','furniture-mobile','position','relative',0,''),(170365,54337,'1683112094.491715','furniture-mobile','box_align','2',0,''),(170366,54337,'1683112094.491715','furniture-mobile','margin-bottom','10',0,''),(170367,54337,'1683112094.491715','furniture-mobile','background-color','$background-7',0,''),(170368,54337,'1683112094.491715','furniture-mobile','position','relative',0,''),(170369,54338,'1683112094.49547','furniture-mobile','background-color','$background-6',0,''),(170370,54338,'1683112094.49547','furniture-mobile','padding-top','10',0,''),(170371,54338,'1683112094.49547','furniture-mobile','padding-left','10',0,''),(170372,54338,'1683112094.49547','furniture-mobile','padding-right','10',0,''),(170373,54338,'1683112094.49547','furniture-mobile','padding-bottom','10',0,''),(170374,54338,'1683112094.49547','furniture-mobile','margin-top','10',0,''),(170375,54339,'1683112094.496940','furniture-mobile','block_type','2',0,''),(170376,54339,'1683112094.496940','furniture-mobile','schema','2-2',0,'2885'),(170377,54340,'1683112094.498374','furniture-mobile','block_type','1',0,''),(170378,54340,'1683112094.498374','furniture-mobile','padding-right','20',0,''),(170379,54340,'1683112094.498374','furniture-mobile','padding-left','0',0,'2885'),(170380,54340,'1683112094.498374','furniture-mobile','margin-bottom','20',0,'2885'),(170381,54340,'1683112094.498374','furniture-mobile','padding-right','0',0,'2885'),(170382,54341,'1683112094.499910','furniture-mobile','address_in','popup',0,''),(170383,54342,'1683112094.502626','furniture-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(170384,54345,'1683112094.508236','furniture-mobile','block_type','1',0,''),(170385,54345,'1683112094.508236','furniture-mobile','padding-left','20',0,''),(170386,54345,'1683112094.508236','furniture-mobile','padding-left','0',0,'2885'),(170387,54347,'1683112094.510627','furniture-mobile','border-top-width','1',0,''),(170388,54347,'1683112094.510627','furniture-mobile','border-top-color','$border-color-4',0,''),(170389,54347,'1683112094.510627','furniture-mobile','padding-top','13',0,''),(170390,54347,'1683112094.510627','furniture-mobile','padding-bottom','10',0,''),(170391,54348,'1683112094.511898','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(170392,54349,'1683112094.513380','furniture-mobile','show_day','next_day',0,''),(170393,54351,'1683112094.518294','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(170394,54352,'1683112094.5284','furniture-mobile','block_type','1',0,''),(170395,54352,'1683112094.5284','furniture-mobile','background-color','$background-7',0,''),(170396,54352,'1683112094.5284','furniture-mobile','padding-top','30',0,''),(170397,54352,'1683112094.5284','furniture-mobile','padding-left','30',0,''),(170398,54352,'1683112094.5284','furniture-mobile','padding-right','30',0,''),(170399,54352,'1683112094.5284','furniture-mobile','padding-bottom','30',0,''),(170400,54352,'1683112094.5284','furniture-mobile','margin-bottom','20',0,''),(170401,54352,'1683112094.5284','furniture-mobile','style_class','hiding-box',0,''),(170402,54353,'1683112094.522685','furniture-mobile','margin-bottom','20',0,''),(170403,54354,'1683112094.52788','furniture-mobile','padding-top','10',0,''),(170404,54354,'1683112094.52788','furniture-mobile','padding-left','20',0,''),(170405,54354,'1683112094.52788','furniture-mobile','padding-right','20',0,''),(170406,54354,'1683112094.52788','furniture-mobile','margin-top','20',0,''),(170407,54354,'1683112094.52788','furniture-mobile','background-color','$background-6',0,''),(170408,54354,'1683112094.52788','furniture-mobile','padding-bottom','8',0,''),(170409,54356,'1683112094.532112','furniture-mobile','block_type','1',0,''),(170410,54356,'1683112094.532112','furniture-mobile','padding-top','30',0,''),(170411,54356,'1683112094.532112','furniture-mobile','padding-left','30',0,''),(170412,54356,'1683112094.532112','furniture-mobile','padding-right','30',0,''),(170413,54356,'1683112094.532112','furniture-mobile','padding-bottom','23',0,''),(170414,54356,'1683112094.532112','furniture-mobile','margin-bottom','20',0,''),(170415,54356,'1683112094.532112','furniture-mobile','background-color','$background-7',0,''),(170416,54356,'1683112094.532112','furniture-mobile','style_class','hiding-box',0,''),(170417,54357,'1683112094.53526','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(170418,54358,'1683112094.536687','furniture-mobile','block_type','2',0,''),(170419,54358,'1683112094.536687','furniture-mobile','schema','2-2',0,'2885'),(170420,54359,'1683112094.53846','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170421,54360,'1683112094.539137','furniture-mobile','padding-right','20',0,''),(170422,54360,'1683112094.539137','furniture-mobile','padding-right','0',0,'2885'),(170423,54360,'1683112094.539137','furniture-mobile','padding-bottom','20',0,'2885'),(170424,54360,'1683112094.539137','furniture-mobile','address_in','popup',0,''),(170425,54361,'1683112094.542437','furniture-mobile','block_type','1',0,''),(170426,54361,'1683112094.542437','furniture-mobile','padding-left','20',0,''),(170427,54361,'1683112094.542437','furniture-mobile','padding-left','0',0,'2885'),(170428,54363,'1683112094.544994','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170429,54364,'1683112094.546257','furniture-mobile','block_type','1',0,''),(170430,54364,'1683112094.546257','furniture-mobile','background-color','$background-7',0,''),(170431,54364,'1683112094.546257','furniture-mobile','padding-top','20',0,''),(170432,54364,'1683112094.546257','furniture-mobile','padding-left','30',0,''),(170433,54364,'1683112094.546257','furniture-mobile','padding-right','30',0,''),(170434,54364,'1683112094.546257','furniture-mobile','padding-bottom','20',0,''),(170435,54364,'1683112094.546257','furniture-mobile','margin-bottom','20',0,''),(170436,54366,'1683112094.549336','furniture-mobile','block_type','1',0,''),(170437,54366,'1683112094.549336','furniture-mobile','padding-top','10',0,''),(170438,54366,'1683112094.549336','furniture-mobile','padding-left','10',0,''),(170439,54366,'1683112094.549336','furniture-mobile','padding-right','10',0,''),(170440,54366,'1683112094.549336','furniture-mobile','padding-bottom','10',0,''),(170441,54366,'1683112094.549336','furniture-mobile','background-color','$background-7',0,''),(170442,54366,'1683112094.549336','furniture-mobile','style_class','order-summary',0,''),(170443,54366,'1683112094.549336','furniture-mobile','margin-left','25',0,''),(170444,54366,'1683112094.549336','furniture-mobile','margin-left','0',0,'2885'),(170445,54367,'1683112094.554924','furniture-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(170446,54367,'1683112094.554924','furniture-mobile','text-align','center',0,''),(170447,54367,'1683112094.554924','furniture-mobile','font-size','14',0,''),(170448,54367,'1683112094.554924','furniture-mobile','color','$color-font-9',0,''),(170449,54367,'1683112094.554924','furniture-mobile','padding-top','10',0,''),(170450,54368,'1683112094.556948','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(170451,54369,'1683112094.558436','furniture-mobile','hide_page','1',0,''),(170452,54369,'1683112094.558436','furniture-mobile','hide_continue_button','1',0,''),(170453,54370,'1683112094.560477','furniture-mobile','margin-bottom','10',0,''),(170454,54372,'116368','furniture-mobile','block_type','1',0,''),(170455,54374,'116370','furniture-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(170456,54375,'116371','furniture-mobile','link','products',0,''),(170457,54375,'116371','furniture-mobile','margin-top','-33',0,''),(170458,54375,'116371','furniture-mobile','float','right',0,''),(170459,54376,'116372','furniture-mobile','block_type','2',0,''),(170460,54376,'116372','furniture-mobile','margin-bottom','20',0,''),(170461,54376,'116372','furniture-mobile','schema','2-2',0,'2876'),(170462,54377,'116373','furniture-mobile','block_type','1',0,''),(170463,54377,'116373','furniture-mobile','padding-right','20',0,''),(170464,54377,'116373','furniture-mobile','padding-right','0',0,'2876'),(170465,54378,'116374','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(170466,54378,'116374','furniture-mobile','clear','none',0,''),(170467,54380,'116376','furniture-mobile','padding-left','20',0,''),(170468,54380,'116376','furniture-mobile','block_type','1',0,''),(170469,54380,'116376','furniture-mobile','padding-left','0',0,'2876'),(170470,54382,'116378','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170471,54382,'116378','furniture-mobile','clear','none',0,''),(170472,54383,'116379','furniture-mobile','text-align','center',0,''),(170473,54383,'116379','furniture-mobile','margin-bottom','10',0,''),(170474,54384,'116380','furniture-mobile','block_type','2',0,''),(170475,54384,'116380','furniture-mobile','margin-bottom','20',0,''),(170476,54384,'116380','furniture-mobile','schema','2-2',0,'2876'),(170477,54385,'116381','furniture-mobile','block_type','1',0,''),(170478,54385,'116381','furniture-mobile','padding-right','20',0,''),(170479,54385,'116381','furniture-mobile','padding-right','0',0,'2876'),(170480,54387,'116383','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(170481,54387,'116383','furniture-mobile','clear','none',0,''),(170482,54388,'116384','furniture-mobile','block_type','1',0,''),(170483,54388,'116384','furniture-mobile','padding-left','20',0,''),(170484,54388,'116384','furniture-mobile','padding-left','0',0,'2876'),(170485,54389,'116385','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170486,54389,'116385','furniture-mobile','clear','none',0,''),(170487,54391,'116387','furniture-mobile','margin-bottom','20',0,''),(170488,54391,'116387','furniture-mobile','text-align','center',0,''),(170489,54393,'116402','furniture-mobile','block_type','1',0,''),(170490,54394,'116403','furniture-mobile','text-align','right',0,''),(170491,54394,'116403','furniture-mobile','margin-bottom','20',0,''),(170492,54395,'116404','furniture-mobile','block_type','2',0,''),(170493,54395,'116404','furniture-mobile','margin-bottom','20',0,''),(170494,54395,'116404','furniture-mobile','schema','2-2',0,'2876'),(170495,54396,'116405','furniture-mobile','block_type','1',0,''),(170496,54396,'116405','furniture-mobile','padding-right','20',0,''),(170497,54396,'116405','furniture-mobile','padding-right','0',0,'2876'),(170498,54397,'116406','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170499,54397,'116406','furniture-mobile','clear','none',0,''),(170500,54399,'116408','furniture-mobile','block_type','1',0,''),(170501,54399,'116408','furniture-mobile','padding-left','20',0,''),(170502,54399,'116408','furniture-mobile','padding-left','0',0,'2876'),(170503,54400,'116409','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170504,54400,'116409','furniture-mobile','clear','none',0,''),(170505,54402,'116411','furniture-mobile','margin-bottom','20',0,''),(170506,54402,'116411','furniture-mobile','text-align','right',0,''),(170507,54405,'116414','furniture-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(170508,54406,'116389','furniture-mobile','block_type','1',0,''),(170509,54407,'116390','furniture-mobile','margin-bottom','20',0,''),(170510,54408,'116391','furniture-mobile','margin-bottom','20',0,''),(170511,54408,'116391','furniture-mobile','text-align','right',0,''),(170512,54409,'116392','furniture-mobile','text-align','right',0,''),(170513,54409,'116392','furniture-mobile','margin-bottom','20',0,''),(170514,54410,'116393','furniture-mobile','block_type','2',0,''),(170515,54410,'116393','furniture-mobile','margin-bottom','20',0,''),(170516,54410,'116393','furniture-mobile','schema','2-2',0,'2876'),(170517,54411,'116394','furniture-mobile','block_type','1',0,''),(170518,54411,'116394','furniture-mobile','padding-right','20',0,''),(170519,54411,'116394','furniture-mobile','padding-right','0',0,'2876'),(170520,54413,'116396','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170521,54413,'116396','furniture-mobile','clear','none',0,''),(170522,54414,'116397','furniture-mobile','block_type','1',0,''),(170523,54414,'116397','furniture-mobile','padding-left','20',0,''),(170524,54414,'116397','furniture-mobile','padding-left','0',0,'2876'),(170525,54416,'116399','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170526,54416,'116399','furniture-mobile','clear','none',0,''),(170527,54417,'116400','furniture-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(170528,54418,'116401','furniture-mobile','margin-bottom','20',0,''),(170529,54419,'116415','furniture-mobile','block_type','1',0,''),(170530,54420,'116416','furniture-mobile','block_type','2',0,''),(170531,54420,'116416','furniture-mobile','margin-bottom','20',0,''),(170532,54420,'116416','furniture-mobile','schema','2-2',0,'2876'),(170533,54421,'116417','furniture-mobile','block_type','1',0,''),(170534,54421,'116417','furniture-mobile','padding-right','20',0,''),(170535,54421,'116417','furniture-mobile','padding-right','0',0,'2876'),(170536,54423,'116419','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(170537,54423,'116419','furniture-mobile','clear','none',0,''),(170538,54424,'116420','furniture-mobile','block_type','1',0,''),(170539,54424,'116420','furniture-mobile','padding-left','20',0,''),(170540,54424,'116420','furniture-mobile','padding-left','0',0,'2876'),(170541,54426,'116422','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170542,54426,'116422','furniture-mobile','clear','none',0,''),(170543,54427,'116423','furniture-mobile','margin-bottom','20',0,''),(170544,54428,'116424','furniture-mobile','margin-bottom','20',0,''),(170545,54429,'116425','furniture-mobile','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(170546,54430,'116426','furniture-mobile','link','products',0,''),(170547,54430,'116426','furniture-mobile','margin-top','-33',0,''),(170548,54430,'116426','furniture-mobile','float','right',0,''),(170549,54431,'116427','furniture-mobile','text-align','right',0,''),(170550,54431,'116427','furniture-mobile','margin-bottom','20',0,''),(170551,54432,'116428','furniture-mobile','margin-bottom','20',0,''),(170552,54432,'116428','furniture-mobile','text-align','right',0,''),(170553,54433,'116429','furniture-mobile','block_type','2',0,''),(170554,54433,'116429','furniture-mobile','margin-bottom','20',0,''),(170555,54433,'116429','furniture-mobile','schema','2-2',0,'2876'),(170556,54434,'116430','furniture-mobile','block_type','1',0,''),(170557,54434,'116430','furniture-mobile','padding-right','20',0,''),(170558,54434,'116430','furniture-mobile','padding-right','0',0,'2876'),(170559,54435,'116431','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(170560,54435,'116431','furniture-mobile','clear','none',0,''),(170561,54437,'116433','furniture-mobile','padding-left','20',0,''),(170562,54437,'116433','furniture-mobile','block_type','1',0,''),(170563,54437,'116433','furniture-mobile','padding-left','0',0,'2876'),(170564,54438,'116434','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170565,54438,'116434','furniture-mobile','clear','none',0,''),(170566,54440,'116436','furniture-mobile','text','##TEXT_CONFIRMATION##',0,''),(170567,54441,'116437','furniture-mobile','text','##TEXT_CONFIRMATION##',0,''),(170568,54442,'116439','furniture-mobile','text','##TEXT_CONFIRMATION##',0,''),(170569,54443,'116438','furniture-mobile','text','##TEXT_CONFIRMATION##',0,''),(170570,54444,'116440','furniture-mobile','text','##TEXT_CONFIRMATION##',0,''),(170571,54445,'116441','furniture-mobile','text','##TEXT_CONFIRMATION##',0,''),(170572,54446,'116442','furniture-mobile','block_type','1',0,''),(170573,54447,'116443','furniture-mobile','block_type','1',0,''),(170574,54447,'116443','furniture-mobile','padding-right','20',0,''),(170575,54448,'116444','furniture-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(170576,54450,'116446','furniture-mobile','block_type','1',0,''),(170577,54450,'116446','furniture-mobile','padding-left','20',0,''),(170578,54450,'116446','furniture-mobile','padding-left','0',0,'2885'),(170579,54451,'116447','furniture-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(170580,54453,'116449','furniture-mobile','block_type','4',0,''),(170581,54453,'116449','furniture-mobile','schema','4-2',0,'2906'),(170582,54454,'116450','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170583,54454,'116450','furniture-mobile','text-align','center',0,''),(170584,54454,'116450','furniture-mobile','padding-top','10',0,''),(170585,54454,'116450','furniture-mobile','font_size_measure','em',0,''),(170586,54454,'116450','furniture-mobile','font-size','1.2',0,''),(170587,54455,'116451','furniture-mobile','text-align','center',0,''),(170588,54456,'116452','furniture-mobile','block_type','1',0,''),(170589,54457,'116453','furniture-mobile','block_type','1',0,''),(170590,54457,'116453','furniture-mobile','padding-right','20',0,''),(170591,54457,'116453','furniture-mobile','padding-right','0',0,'2885'),(170593,54460,'116456','furniture-mobile','block_type','1',0,''),(170594,54460,'116456','furniture-mobile','padding-right','0',0,'2885'),(170596,54463,'116459','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(170597,54465,'116461','furniture-mobile','block_type','2',0,''),(170598,54466,'116462','furniture-mobile','block_type','1',0,''),(170599,54466,'116462','furniture-mobile','padding-right','20',0,''),(170600,54468,'116464','furniture-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(170601,54469,'116465','furniture-mobile','block_type','1',0,''),(170602,54469,'116465','furniture-mobile','padding-left','20',0,''),(170603,54469,'116465','furniture-mobile','padding-left','0',0,'2885'),(170604,54470,'116466','furniture-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(170605,54472,'116468','furniture-mobile','block_type','4',0,''),(170606,54472,'116468','furniture-mobile','schema','4-2',0,'2906'),(170607,54473,'116469','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170608,54473,'116469','furniture-mobile','text-align','right',0,''),(170609,54473,'116469','furniture-mobile','padding-top','10',0,''),(170610,54473,'116469','furniture-mobile','font_size_measure','em',0,''),(170611,54473,'116469','furniture-mobile','font-size','1.2',0,''),(170612,54474,'116470','furniture-mobile','text-align','right',0,''),(170613,54475,'116471','furniture-mobile','block_type','2',0,''),(170614,54476,'116472','furniture-mobile','block_type','1',0,''),(170615,54476,'116472','furniture-mobile','padding-right','20',0,''),(170616,54476,'116472','furniture-mobile','padding-right','0',0,'2885'),(170617,54478,'116474','furniture-mobile','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(170618,54479,'116475','furniture-mobile','block_type','1',0,''),(170619,54479,'116475','furniture-mobile','padding-right','0',0,'2885'),(170620,54479,'116475','furniture-mobile','padding-left','20',0,''),(170621,54481,'116477','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(170622,54484,'116480','furniture-mobile','block_type','4',0,''),(170623,54484,'116480','furniture-mobile','schema','4-2',0,'2906'),(170624,54485,'116481','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170625,54485,'116481','furniture-mobile','text-align','right',0,''),(170626,54485,'116481','furniture-mobile','padding-top','10',0,''),(170627,54485,'116481','furniture-mobile','font_size_measure','em',0,''),(170628,54485,'116481','furniture-mobile','font-size','1.2',0,''),(170629,54486,'116482','furniture-mobile','text-align','right',0,''),(170630,54487,'116483','furniture-mobile','block_type','2',0,''),(170631,54488,'116484','furniture-mobile','block_type','1',0,''),(170632,54488,'116484','furniture-mobile','padding-right','20',0,''),(170633,54490,'116486','furniture-mobile','block_type','1',0,''),(170634,54490,'116486','furniture-mobile','padding-left','20',0,''),(170635,54490,'116486','furniture-mobile','padding-left','0',0,'2885'),(170636,54491,'116487','furniture-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(170637,54493,'116489','furniture-mobile','block_type','4',0,''),(170638,54493,'116489','furniture-mobile','schema','4-2',0,'2906'),(170639,54494,'116490','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170640,54494,'116490','furniture-mobile','text-align','right',0,''),(170641,54494,'116490','furniture-mobile','padding-top','10',0,''),(170642,54494,'116490','furniture-mobile','font_size_measure','em',0,''),(170643,54494,'116490','furniture-mobile','font-size','1.2',0,''),(170644,54495,'116491','furniture-mobile','text-align','right',0,''),(170645,54496,'116492','furniture-mobile','block_type','2',0,''),(170646,54497,'116493','furniture-mobile','block_type','1',0,''),(170647,54497,'116493','furniture-mobile','padding-right','20',0,''),(170648,54499,'116495','furniture-mobile','block_type','1',0,''),(170649,54499,'116495','furniture-mobile','padding-left','20',0,''),(170650,54499,'116495','furniture-mobile','padding-left','0',0,'2885'),(170651,54501,'116497','furniture-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(170652,54502,'116498','furniture-mobile','text','##DELIVERY_DETAILS##',0,''),(170653,54503,'116499','furniture-mobile','text','##DELIVERY_DETAILS##',0,''),(170654,54504,'116501','furniture-mobile','text','##CONTACT_INFORMATION##',0,''),(170655,54505,'116500','furniture-mobile','text','##CONTACT_INFORMATION##',0,''),(170656,54506,'116502','furniture-mobile','text','##DELIVERY_DETAILS##',0,''),(170657,54507,'116503','furniture-mobile','text','##DELIVERY_DETAILS##',0,''),(170658,54508,'116504','furniture-mobile','block_type','1',0,''),(170659,54508,'116504','furniture-mobile','background-color','$background-6',0,''),(170660,54508,'116504','furniture-mobile','padding-top','30',0,''),(170661,54508,'116504','furniture-mobile','padding-bottom','30',0,''),(170662,54509,'116505','furniture-mobile','block_type','7',0,''),(170663,54509,'116505','furniture-mobile','schema','4-2',0,'2885'),(170664,54510,'116506','furniture-mobile','block_type','1',0,''),(170665,54510,'116506','furniture-mobile','padding-right','0',0,'2885'),(170666,54511,'116508','furniture-mobile','block_type','1',0,''),(170667,54511,'116508','furniture-mobile','background-color','$background-7',0,''),(170668,54511,'116508','furniture-mobile','padding-top','30',0,''),(170669,54511,'116508','furniture-mobile','padding-left','30',0,''),(170670,54511,'116508','furniture-mobile','padding-right','30',0,''),(170671,54511,'116508','furniture-mobile','padding-bottom','30',0,''),(170672,54511,'116508','furniture-mobile','margin-bottom','20',0,''),(170673,54511,'116508','furniture-mobile','style_class','hiding-box',0,''),(170674,54512,'116509','furniture-mobile','margin-bottom','20',0,''),(170675,54513,'116510','furniture-mobile','padding-top','10',0,''),(170676,54513,'116510','furniture-mobile','padding-left','20',0,''),(170677,54513,'116510','furniture-mobile','padding-right','20',0,''),(170678,54513,'116510','furniture-mobile','margin-top','20',0,''),(170679,54513,'116510','furniture-mobile','background-color','$background-6',0,''),(170680,54513,'116510','furniture-mobile','padding-bottom','8',0,''),(170681,54514,'116511','furniture-mobile','block_type','1',0,''),(170682,54514,'116511','furniture-mobile','background-color','$background-7',0,''),(170683,54514,'116511','furniture-mobile','padding-top','30',0,''),(170684,54514,'116511','furniture-mobile','padding-left','30',0,''),(170685,54514,'116511','furniture-mobile','padding-right','30',0,''),(170686,54514,'116511','furniture-mobile','padding-bottom','14',0,''),(170687,54514,'116511','furniture-mobile','margin-bottom','20',0,''),(170688,54514,'116511','furniture-mobile','style_class','hiding-box closeable-box',0,''),(170689,54515,'116512','furniture-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(170690,54515,'116512','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(170691,54516,'116513','furniture-mobile','style_class','closeable-content',0,''),(170692,54516,'116513','furniture-mobile','padding-bottom','20',0,''),(170693,54517,'116514','furniture-mobile','background-color','$background-7',0,''),(170694,54517,'116514','furniture-mobile','block_type','1',0,''),(170695,54517,'116514','furniture-mobile','padding-top','30',0,''),(170696,54517,'116514','furniture-mobile','padding-left','30',0,''),(170697,54517,'116514','furniture-mobile','padding-right','30',0,''),(170698,54517,'116514','furniture-mobile','padding-bottom','30',0,''),(170699,54517,'116514','furniture-mobile','margin-bottom','20',0,''),(170700,54517,'116514','furniture-mobile','style_class','hiding-box',0,''),(170701,54518,'116515','furniture-mobile','block_type','1',0,''),(170702,54518,'116515','furniture-mobile','content','\\_',0,'3'),(170703,54518,'116515','furniture-mobile','border-top-width','1',0,'3'),(170704,54518,'116515','furniture-mobile','border-top-color','$border-color-4',0,'3'),(170705,54518,'116515','furniture-mobile','display','block',0,'3'),(170706,54518,'116515','furniture-mobile','position','absolute',0,'3'),(170707,54518,'116515','furniture-mobile','top','19',0,'3'),(170708,54518,'116515','furniture-mobile','left','0',0,'3'),(170709,54518,'116515','furniture-mobile','right','0',0,'3'),(170710,54518,'116515','furniture-mobile','margin-top','-2',0,'3'),(170711,54518,'116515','furniture-mobile','position','relative',0,''),(170712,54519,'116516','furniture-mobile','box_align','2',0,''),(170713,54519,'116516','furniture-mobile','margin-bottom','10',0,''),(170714,54519,'116516','furniture-mobile','background-color','$background-7',0,''),(170715,54519,'116516','furniture-mobile','position','relative',0,''),(170716,54520,'116517','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(170717,54521,'116518','furniture-mobile','block_type','2',0,''),(170718,54521,'116518','furniture-mobile','schema','2-2',0,'2885'),(170719,54522,'116519','furniture-mobile','block_type','1',0,''),(170720,54522,'116519','furniture-mobile','padding-right','20',0,''),(170721,54522,'116519','furniture-mobile','padding-left','0',0,'2885'),(170722,54522,'116519','furniture-mobile','margin-bottom','20',0,'2885'),(170723,54522,'116519','furniture-mobile','padding-right','0',0,'2885'),(170724,54525,'116522','furniture-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(170725,54526,'116523','furniture-mobile','block_type','1',0,''),(170726,54526,'116523','furniture-mobile','padding-left','20',0,''),(170727,54526,'116523','furniture-mobile','padding-left','0',0,'2885'),(170728,54527,'116524','furniture-mobile','padding-bottom','10',0,''),(170729,54528,'116525','furniture-mobile','background-color','$background-6',0,''),(170730,54528,'116525','furniture-mobile','padding-top','10',0,''),(170731,54528,'116525','furniture-mobile','padding-left','10',0,''),(170732,54528,'116525','furniture-mobile','padding-right','10',0,''),(170733,54528,'116525','furniture-mobile','padding-bottom','10',0,''),(170734,54528,'116525','furniture-mobile','margin-top','10',0,''),(170735,54529,'116526','furniture-mobile','block_type','1',0,''),(170736,54529,'116526','furniture-mobile','padding-top','10',0,''),(170737,54529,'116526','furniture-mobile','padding-left','10',0,''),(170738,54529,'116526','furniture-mobile','padding-right','10',0,''),(170739,54529,'116526','furniture-mobile','padding-bottom','10',0,''),(170740,54529,'116526','furniture-mobile','background-color','$background-7',0,''),(170741,54529,'116526','furniture-mobile','style_class','order-summary',0,''),(170742,54529,'116526','furniture-mobile','margin-left','25',0,''),(170743,54529,'116526','furniture-mobile','margin-left','0',0,'2885'),(170744,54530,'116527','furniture-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(170745,54530,'116527','furniture-mobile','text-align','center',0,''),(170746,54530,'116527','furniture-mobile','font-size','14',0,''),(170747,54530,'116527','furniture-mobile','color','$color-font-9',0,''),(170748,54530,'116527','furniture-mobile','padding-top','10',0,''),(170749,54533,'1638957135.2709','furniture-mobile','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(170750,54534,'116529','furniture-mobile','block_type','1',0,''),(170751,54534,'116529','furniture-mobile','background-color','$background-6',0,''),(170752,54534,'116529','furniture-mobile','padding-top','30',0,''),(170753,54534,'116529','furniture-mobile','padding-bottom','30',0,''),(170754,54535,'116530','furniture-mobile','block_type','7',0,''),(170755,54536,'116531','furniture-mobile','block_type','1',0,''),(170756,54537,'116532','furniture-mobile','block_type','1',0,''),(170757,54537,'116532','furniture-mobile','background-color','$background-7',0,''),(170758,54537,'116532','furniture-mobile','padding-top','30',0,''),(170759,54537,'116532','furniture-mobile','padding-left','30',0,''),(170760,54537,'116532','furniture-mobile','padding-right','30',0,''),(170761,54537,'116532','furniture-mobile','padding-bottom','30',0,''),(170762,54537,'116532','furniture-mobile','margin-bottom','20',0,''),(170763,54537,'116532','furniture-mobile','style_class','hiding-box',0,''),(170764,54538,'116533','furniture-mobile','padding-top','10',0,''),(170765,54538,'116533','furniture-mobile','padding-left','20',0,''),(170766,54538,'116533','furniture-mobile','padding-right','20',0,''),(170767,54538,'116533','furniture-mobile','margin-top','20',0,''),(170768,54538,'116533','furniture-mobile','background-color','$background-6',0,''),(170769,54538,'116533','furniture-mobile','padding-bottom','8',0,''),(170770,54539,'116534','furniture-mobile','margin-bottom','20',0,''),(170771,54540,'116535','furniture-mobile','block_type','1',0,''),(170772,54540,'116535','furniture-mobile','padding-top','30',0,''),(170773,54540,'116535','furniture-mobile','padding-left','30',0,''),(170774,54540,'116535','furniture-mobile','padding-right','30',0,''),(170775,54540,'116535','furniture-mobile','padding-bottom','23',0,''),(170776,54540,'116535','furniture-mobile','margin-bottom','20',0,''),(170777,54540,'116535','furniture-mobile','background-color','$background-7',0,''),(170778,54540,'116535','furniture-mobile','style_class','hiding-box',0,''),(170779,54541,'116536','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(170780,54542,'116537','furniture-mobile','block_type','2',0,''),(170781,54543,'116538','furniture-mobile','padding-right','20',0,''),(170782,54544,'116539','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170783,54545,'116540','furniture-mobile','block_type','1',0,''),(170784,54545,'116540','furniture-mobile','padding-left','20',0,''),(170785,54546,'116541','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170786,54548,'116543','furniture-mobile','block_type','1',0,''),(170787,54548,'116543','furniture-mobile','padding-top','30',0,''),(170788,54548,'116543','furniture-mobile','padding-left','30',0,''),(170789,54548,'116543','furniture-mobile','padding-right','30',0,''),(170790,54548,'116543','furniture-mobile','padding-bottom','14',0,''),(170791,54548,'116543','furniture-mobile','margin-bottom','20',0,''),(170792,54548,'116543','furniture-mobile','background-color','$background-7',0,''),(170793,54548,'116543','furniture-mobile','style_class','hiding-box closeable-box',0,''),(170794,54549,'116544','furniture-mobile','block_type','2',0,''),(170795,54549,'116544','furniture-mobile','style_class','closeable-content',0,''),(170796,54550,'116545','furniture-mobile','padding-right','20',0,''),(170797,54550,'116545','furniture-mobile','padding-bottom','20',0,''),(170798,54551,'116546','furniture-mobile','padding-left','20',0,''),(170799,54551,'116546','furniture-mobile','padding-bottom','20',0,''),(170800,54552,'116547','furniture-mobile','padding-left','20',0,''),(170801,54552,'116547','furniture-mobile','padding-bottom','20',0,''),(170802,54553,'116548','furniture-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(170803,54553,'116548','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(170804,54554,'116549','furniture-mobile','block_type','1',0,''),(170805,54554,'116549','furniture-mobile','background-color','$background-7',0,''),(170806,54554,'116549','furniture-mobile','padding-top','30',0,''),(170807,54554,'116549','furniture-mobile','padding-left','30',0,''),(170808,54554,'116549','furniture-mobile','padding-right','30',0,''),(170809,54554,'116549','furniture-mobile','padding-bottom','14',0,''),(170810,54554,'116549','furniture-mobile','margin-bottom','20',0,''),(170811,54554,'116549','furniture-mobile','style_class','hiding-box closeable-box',0,''),(170812,54555,'116550','furniture-mobile','style_class','closeable-content',0,''),(170813,54555,'116550','furniture-mobile','padding-bottom','20',0,''),(170814,54556,'116551','furniture-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(170815,54556,'116551','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(170816,54557,'116552','furniture-mobile','block_type','1',0,''),(170817,54557,'116552','furniture-mobile','padding-top','10',0,''),(170818,54557,'116552','furniture-mobile','padding-left','10',0,''),(170819,54557,'116552','furniture-mobile','padding-right','10',0,''),(170820,54557,'116552','furniture-mobile','padding-bottom','10',0,''),(170821,54557,'116552','furniture-mobile','background-color','$background-7',0,''),(170822,54557,'116552','furniture-mobile','style_class','order-summary hiding-box',0,''),(170823,54557,'116552','furniture-mobile','margin-left','25',0,''),(170824,54558,'116553','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(170825,54559,'116554','furniture-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(170826,54559,'116554','furniture-mobile','text-align','center',0,''),(170827,54559,'116554','furniture-mobile','font-size','14',0,''),(170828,54559,'116554','furniture-mobile','color','$color-font-9',0,''),(170829,54559,'116554','furniture-mobile','padding-top','10',0,''),(170830,54560,'116555','furniture-mobile','margin-bottom','10',0,''),(170831,54562,'116557','furniture-mobile','hide_page','1',0,''),(170832,54562,'116557','furniture-mobile','hide_continue_button','1',0,''),(170833,54563,'116558','furniture-mobile','block_type','1',0,''),(170834,54565,'116560','furniture-mobile','block_type','4',0,''),(170835,54565,'116560','furniture-mobile','schema','4-2',0,'2906'),(170836,54566,'116561','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170837,54566,'116561','furniture-mobile','text-align','right',0,''),(170838,54566,'116561','furniture-mobile','padding-top','10',0,''),(170839,54566,'116561','furniture-mobile','font_size_measure','em',0,''),(170840,54566,'116561','furniture-mobile','font-size','1.2',0,''),(170841,54567,'116562','furniture-mobile','text-align','right',0,''),(170842,54568,'116563','furniture-mobile','block_type','2',0,''),(170843,54568,'116563','furniture-mobile','schema','2-2',0,'2885'),(170844,54569,'116564','furniture-mobile','block_type','1',0,''),(170845,54569,'116564','furniture-mobile','padding-right','20',0,''),(170846,54569,'116564','furniture-mobile','padding-right','0',0,'2885'),(170847,54571,'116566','furniture-mobile','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(170848,54572,'116567','furniture-mobile','block_type','1',0,''),(170849,54572,'116567','furniture-mobile','padding-left','20',0,''),(170850,54572,'116567','furniture-mobile','padding-left','0',0,'2885'),(170851,54574,'116569','furniture-mobile','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(170852,54575,'116570','furniture-mobile','block_type','2',0,''),(170853,54575,'116570','furniture-mobile','schema','2-2',0,'2885'),(170854,54576,'116571','furniture-mobile','block_type','1',0,''),(170855,54576,'116571','furniture-mobile','padding-right','20',0,''),(170856,54576,'116571','furniture-mobile','padding-right','0',0,'2885'),(170857,54577,'116572','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170858,54579,'116574','furniture-mobile','block_type','1',0,''),(170859,54579,'116574','furniture-mobile','padding-left','20',0,''),(170860,54579,'116574','furniture-mobile','padding-left','0',0,'2885'),(170861,54584,'116579','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170862,54585,'116580','furniture-mobile','margin-bottom','20',0,''),(170863,54586,'116581','furniture-mobile','block_type','1',0,''),(170864,54586,'116581','furniture-mobile','background-color','$background-6',0,''),(170865,54586,'116581','furniture-mobile','padding-top','30',0,''),(170866,54586,'116581','furniture-mobile','padding-bottom','30',0,''),(170867,54587,'116582','furniture-mobile','block_type','7',0,''),(170868,54587,'116582','furniture-mobile','schema','4-2',0,'2885'),(170869,54587,'116582','furniture-mobile','margin-bottom','30',0,''),(170870,54588,'116583','furniture-mobile','block_type','1',0,''),(170871,54588,'116583','furniture-mobile','padding-right','0',0,'2885'),(170872,54589,'116585','furniture-mobile','block_type','1',0,''),(170873,54589,'116585','furniture-mobile','background-color','$background-7',0,''),(170874,54589,'116585','furniture-mobile','padding-top','30',0,''),(170875,54589,'116585','furniture-mobile','padding-left','30',0,''),(170876,54589,'116585','furniture-mobile','padding-right','30',0,''),(170877,54589,'116585','furniture-mobile','padding-bottom','14',0,''),(170878,54589,'116585','furniture-mobile','margin-bottom','20',0,''),(170879,54589,'116585','furniture-mobile','style_class','hiding-box closeable-box',0,''),(170880,54590,'116586','furniture-mobile','style_class','closeable-content',0,''),(170881,54590,'116586','furniture-mobile','padding-bottom','20',0,''),(170882,54591,'116587','furniture-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(170883,54591,'116587','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(170884,54592,'116588','furniture-mobile','block_type','1',0,''),(170885,54592,'116588','furniture-mobile','background-color','$background-7',0,''),(170886,54592,'116588','furniture-mobile','padding-top','30',0,''),(170887,54592,'116588','furniture-mobile','padding-left','30',0,''),(170888,54592,'116588','furniture-mobile','padding-right','30',0,''),(170889,54592,'116588','furniture-mobile','padding-bottom','30',0,''),(170890,54592,'116588','furniture-mobile','margin-bottom','20',0,''),(170891,54592,'116588','furniture-mobile','style_class','hiding-box',0,''),(170892,54593,'116589','furniture-mobile','padding-top','10',0,''),(170893,54593,'116589','furniture-mobile','padding-left','20',0,''),(170894,54593,'116589','furniture-mobile','padding-right','20',0,''),(170895,54593,'116589','furniture-mobile','margin-top','20',0,''),(170896,54593,'116589','furniture-mobile','background-color','$background-6',0,''),(170897,54593,'116589','furniture-mobile','padding-bottom','8',0,''),(170898,54594,'116590','furniture-mobile','margin-bottom','20',0,''),(170899,54595,'116591','furniture-mobile','block_type','1',0,''),(170900,54595,'116591','furniture-mobile','padding-top','30',0,''),(170901,54595,'116591','furniture-mobile','padding-left','30',0,''),(170902,54595,'116591','furniture-mobile','padding-right','30',0,''),(170903,54595,'116591','furniture-mobile','padding-bottom','23',0,''),(170904,54595,'116591','furniture-mobile','margin-bottom','20',0,''),(170905,54595,'116591','furniture-mobile','background-color','$background-7',0,''),(170906,54595,'116591','furniture-mobile','style_class','hiding-box',0,''),(170907,54596,'116592','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(170908,54597,'116593','furniture-mobile','block_type','2',0,''),(170909,54597,'116593','furniture-mobile','schema','2-2',0,'2885'),(170910,54598,'116594','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170911,54599,'116595','furniture-mobile','padding-right','20',0,''),(170912,54599,'116595','furniture-mobile','padding-right','0',0,'2885'),(170913,54599,'116595','furniture-mobile','padding-bottom','20',0,'2885'),(170914,54600,'116596','furniture-mobile','block_type','1',0,''),(170915,54600,'116596','furniture-mobile','padding-left','20',0,''),(170916,54600,'116596','furniture-mobile','padding-left','0',0,'2885'),(170917,54602,'116598','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170918,54603,'116599','furniture-mobile','block_type','1',0,''),(170919,54603,'116599','furniture-mobile','padding-top','10',0,''),(170920,54603,'116599','furniture-mobile','padding-left','10',0,''),(170921,54603,'116599','furniture-mobile','padding-right','10',0,''),(170922,54603,'116599','furniture-mobile','padding-bottom','10',0,''),(170923,54603,'116599','furniture-mobile','background-color','$background-7',0,''),(170924,54603,'116599','furniture-mobile','style_class','order-summary',0,''),(170925,54603,'116599','furniture-mobile','margin-left','25',0,''),(170926,54605,'116601','furniture-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(170927,54605,'116601','furniture-mobile','text-align','center',0,''),(170928,54605,'116601','furniture-mobile','font-size','14',0,''),(170929,54605,'116601','furniture-mobile','color','$color-font-9',0,''),(170930,54605,'116601','furniture-mobile','padding-top','10',0,''),(170931,54606,'116602','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(170932,54607,'116603','furniture-mobile','margin-bottom','10',0,''),(170933,54609,'116604','furniture-mobile','block_type','1',0,''),(170934,54610,'116605','furniture-mobile','block_type','1',0,''),(170935,54610,'116605','furniture-mobile','padding-left','0',0,'2885'),(170936,54610,'116605','furniture-mobile','padding-right','20',0,''),(170937,54612,'116607','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170938,54613,'116608','furniture-mobile','block_type','1',0,''),(170939,54613,'116608','furniture-mobile','padding-left','20',0,''),(170940,54613,'116608','furniture-mobile','padding-left','0',0,'2885'),(170941,54618,'116613','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170942,54619,'116614','furniture-mobile','block_type','4',0,''),(170943,54619,'116614','furniture-mobile','schema','4-2',0,'2906'),(170944,54620,'116615','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170945,54620,'116615','furniture-mobile','text-align','center',0,''),(170946,54620,'116615','furniture-mobile','padding-top','10',0,''),(170947,54620,'116615','furniture-mobile','font_size_measure','em',0,''),(170948,54620,'116615','furniture-mobile','font-size','1.2',0,''),(170949,54621,'116616','furniture-mobile','text-align','center',0,''),(170950,54622,'116617','furniture-mobile','block_type','2',0,''),(170951,54623,'116618','furniture-mobile','block_type','1',0,''),(170952,54623,'116618','furniture-mobile','padding-left','0',0,'2885'),(170953,54623,'116618','furniture-mobile','padding-right','20',0,''),(170954,54625,'116620','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170955,54626,'116621','furniture-mobile','block_type','1',0,''),(170956,54626,'116621','furniture-mobile','padding-left','20',0,''),(170957,54626,'116621','furniture-mobile','padding-left','0',0,'2885'),(170958,54628,'116623','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170959,54632,'116627','furniture-mobile','block_type','4',0,''),(170960,54632,'116627','furniture-mobile','schema','4-2',0,'2906'),(170961,54633,'116628','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170962,54633,'116628','furniture-mobile','text-align','right',0,''),(170963,54633,'116628','furniture-mobile','padding-top','10',0,''),(170964,54633,'116628','furniture-mobile','font_size_measure','em',0,''),(170965,54633,'116628','furniture-mobile','font-size','1.2',0,''),(170966,54634,'116629','furniture-mobile','text-align','right',0,''),(170967,54635,'116630','furniture-mobile','block_type','4',0,''),(170968,54635,'116630','furniture-mobile','schema','4-2',0,'2906'),(170969,54636,'116631','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170970,54636,'116631','furniture-mobile','text-align','right',0,''),(170971,54636,'116631','furniture-mobile','padding-top','10',0,''),(170972,54636,'116631','furniture-mobile','font_size_measure','em',0,''),(170973,54636,'116631','furniture-mobile','font-size','1.2',0,''),(170974,54637,'116632','furniture-mobile','text-align','right',0,''),(170975,54638,'116633','furniture-mobile','block_type','2',0,''),(170976,54639,'116634','furniture-mobile','block_type','1',0,''),(170977,54639,'116634','furniture-mobile','padding-left','0',0,'2885'),(170978,54639,'116634','furniture-mobile','padding-right','20',0,''),(170979,54640,'116635','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170980,54642,'116637','furniture-mobile','block_type','1',0,''),(170981,54642,'116637','furniture-mobile','padding-left','20',0,''),(170982,54642,'116637','furniture-mobile','padding-left','0',0,'2885'),(170983,54647,'116642','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(170984,54648,'116643','furniture-mobile','block_type','4',0,''),(170985,54648,'116643','furniture-mobile','schema','4-2',0,'2906'),(170986,54649,'116644','furniture-mobile','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(170987,54649,'116644','furniture-mobile','text-align','right',0,''),(170988,54649,'116644','furniture-mobile','padding-top','10',0,''),(170989,54649,'116644','furniture-mobile','font_size_measure','em',0,''),(170990,54649,'116644','furniture-mobile','font-size','1.2',0,''),(170991,54650,'116645','furniture-mobile','text-align','right',0,''),(170992,54651,'116646','furniture-mobile','block_type','2',0,''),(170993,54652,'116647','furniture-mobile','block_type','1',0,''),(170994,54652,'116647','furniture-mobile','padding-left','0',0,'2885'),(170995,54652,'116647','furniture-mobile','padding-right','20',0,''),(170996,54654,'116649','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(170997,54655,'116650','furniture-mobile','block_type','1',0,''),(170998,54655,'116650','furniture-mobile','padding-left','20',0,''),(170999,54655,'116650','furniture-mobile','padding-left','0',0,'2885'),(171000,54659,'116654','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171001,54661,'116656','furniture-mobile','text','##PAYMENT_DETAILS##',0,''),(171002,54662,'116657','furniture-mobile','text','##PAYMENT_DETAILS##',0,''),(171003,54663,'116658','furniture-mobile','text','##PAYMENT_DETAILS##',0,''),(171004,54664,'116659','furniture-mobile','text','##PAYMENT_DETAILS##',0,''),(171005,54665,'116660','furniture-mobile','text','##PAYMENT_DETAILS##',0,''),(171006,54666,'116661','furniture-mobile','text','##PAYMENT_DETAILS##',0,''),(171007,54667,'120947','furniture-mobile','block_type','1',0,''),(171008,54667,'120947','furniture-mobile','background-color','$background-6',0,''),(171009,54667,'120947','furniture-mobile','padding-top','30',0,''),(171010,54667,'120947','furniture-mobile','padding-bottom','30',0,''),(171011,54668,'120948','furniture-mobile','block_type','7',0,''),(171012,54668,'120948','furniture-mobile','schema','4-2',0,'2885'),(171013,54669,'120949','furniture-mobile','block_type','1',0,''),(171014,54669,'120949','furniture-mobile','padding-right','0',0,'2885'),(171015,54670,'120950','furniture-mobile','block_type','1',0,''),(171016,54670,'120950','furniture-mobile','background-color','$background-7',0,''),(171017,54670,'120950','furniture-mobile','padding-top','30',0,''),(171018,54670,'120950','furniture-mobile','padding-left','30',0,''),(171019,54670,'120950','furniture-mobile','padding-right','30',0,''),(171020,54670,'120950','furniture-mobile','padding-bottom','30',0,''),(171021,54670,'120950','furniture-mobile','margin-bottom','20',0,''),(171022,54670,'120950','furniture-mobile','style_class','hiding-box',0,''),(171023,54671,'120951','furniture-mobile','padding-top','10',0,''),(171024,54671,'120951','furniture-mobile','padding-left','20',0,''),(171025,54671,'120951','furniture-mobile','padding-right','20',0,''),(171026,54671,'120951','furniture-mobile','margin-top','20',0,''),(171027,54671,'120951','furniture-mobile','background-color','$background-6',0,''),(171028,54671,'120951','furniture-mobile','padding-bottom','8',0,''),(171029,54672,'120952','furniture-mobile','margin-bottom','20',0,''),(171030,54673,'120953','furniture-mobile','background-color','$background-7',0,''),(171031,54673,'120953','furniture-mobile','block_type','1',0,''),(171032,54673,'120953','furniture-mobile','padding-top','30',0,''),(171033,54673,'120953','furniture-mobile','padding-left','30',0,''),(171034,54673,'120953','furniture-mobile','padding-right','30',0,''),(171035,54673,'120953','furniture-mobile','padding-bottom','30',0,''),(171036,54673,'120953','furniture-mobile','margin-bottom','20',0,''),(171037,54673,'120953','furniture-mobile','style_class','hiding-box',0,''),(171038,54674,'120954','furniture-mobile','block_type','1',0,''),(171039,54674,'120954','furniture-mobile','content','\\_',0,'3'),(171040,54674,'120954','furniture-mobile','border-top-width','1',0,'3'),(171041,54674,'120954','furniture-mobile','border-top-color','$border-color-4',0,'3'),(171042,54674,'120954','furniture-mobile','display','block',0,'3'),(171043,54674,'120954','furniture-mobile','position','absolute',0,'3'),(171044,54674,'120954','furniture-mobile','top','19',0,'3'),(171045,54674,'120954','furniture-mobile','left','0',0,'3'),(171046,54674,'120954','furniture-mobile','right','0',0,'3'),(171047,54674,'120954','furniture-mobile','margin-top','-2',0,'3'),(171048,54674,'120954','furniture-mobile','position','relative',0,''),(171049,54675,'120955','furniture-mobile','box_align','2',0,''),(171050,54675,'120955','furniture-mobile','margin-bottom','10',0,''),(171051,54675,'120955','furniture-mobile','background-color','$background-7',0,''),(171052,54675,'120955','furniture-mobile','position','relative',0,''),(171053,54676,'120956','furniture-mobile','background-color','$background-6',0,''),(171054,54676,'120956','furniture-mobile','padding-top','10',0,''),(171055,54676,'120956','furniture-mobile','padding-left','10',0,''),(171056,54676,'120956','furniture-mobile','padding-right','10',0,''),(171057,54676,'120956','furniture-mobile','padding-bottom','10',0,''),(171058,54676,'120956','furniture-mobile','margin-top','10',0,''),(171059,54677,'120957','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(171060,54678,'120958','furniture-mobile','block_type','2',0,''),(171061,54678,'120958','furniture-mobile','schema','2-2',0,'2885'),(171062,54679,'120959','furniture-mobile','block_type','1',0,''),(171063,54679,'120959','furniture-mobile','padding-right','20',0,''),(171064,54679,'120959','furniture-mobile','padding-left','0',0,'2885'),(171065,54679,'120959','furniture-mobile','margin-bottom','20',0,'2885'),(171066,54679,'120959','furniture-mobile','padding-right','0',0,'2885'),(171067,54682,'120962','furniture-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(171068,54683,'120963','furniture-mobile','block_type','1',0,''),(171069,54683,'120963','furniture-mobile','padding-left','20',0,''),(171070,54683,'120963','furniture-mobile','padding-left','0',0,'2885'),(171071,54685,'120965','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(171072,54686,'120966','furniture-mobile','border-top-width','1',0,''),(171073,54686,'120966','furniture-mobile','border-top-color','$border-color-4',0,''),(171074,54686,'120966','furniture-mobile','padding-top','13',0,''),(171075,54686,'120966','furniture-mobile','padding-bottom','10',0,''),(171076,54687,'120967','furniture-mobile','block_type','1',0,''),(171077,54687,'120967','furniture-mobile','background-color','$background-7',0,''),(171078,54687,'120967','furniture-mobile','padding-top','30',0,''),(171079,54687,'120967','furniture-mobile','padding-left','30',0,''),(171080,54687,'120967','furniture-mobile','padding-right','30',0,''),(171081,54687,'120967','furniture-mobile','padding-bottom','14',0,''),(171082,54687,'120967','furniture-mobile','margin-bottom','20',0,''),(171083,54687,'120967','furniture-mobile','style_class','hiding-box closeable-box',0,''),(171084,54688,'120968','furniture-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(171085,54688,'120968','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(171086,54689,'120969','furniture-mobile','style_class','closeable-content',0,''),(171087,54689,'120969','furniture-mobile','padding-bottom','20',0,''),(171088,54690,'120970','furniture-mobile','block_type','1',0,''),(171089,54690,'120970','furniture-mobile','padding-top','30',0,''),(171090,54690,'120970','furniture-mobile','padding-left','30',0,''),(171091,54690,'120970','furniture-mobile','padding-right','30',0,''),(171092,54690,'120970','furniture-mobile','padding-bottom','23',0,''),(171093,54690,'120970','furniture-mobile','margin-bottom','20',0,''),(171094,54690,'120970','furniture-mobile','background-color','$background-7',0,''),(171095,54690,'120970','furniture-mobile','style_class','hiding-box',0,''),(171096,54691,'120971','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(171097,54692,'120972','furniture-mobile','block_type','2',0,''),(171098,54692,'120972','furniture-mobile','schema','2-2',0,'2885'),(171099,54693,'120973','furniture-mobile','padding-right','20',0,''),(171100,54693,'120973','furniture-mobile','padding-right','0',0,'2885'),(171101,54693,'120973','furniture-mobile','padding-bottom','20',0,'2885'),(171102,54694,'120974','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171103,54695,'120975','furniture-mobile','block_type','1',0,''),(171104,54695,'120975','furniture-mobile','padding-left','20',0,''),(171105,54695,'120975','furniture-mobile','padding-left','0',0,'2885'),(171106,54697,'120977','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171107,54698,'120978','furniture-mobile','block_type','1',0,''),(171108,54698,'120978','furniture-mobile','padding-left','10',0,''),(171109,54698,'120978','furniture-mobile','padding-right','10',0,''),(171110,54698,'120978','furniture-mobile','padding-bottom','10',0,''),(171111,54698,'120978','furniture-mobile','background-color','$background-7',0,''),(171112,54698,'120978','furniture-mobile','style_class','order-summary',0,''),(171113,54698,'120978','furniture-mobile','margin-left','25',0,''),(171114,54698,'120978','furniture-mobile','margin-left','0',0,'2885'),(171115,54699,'120979','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171116,54700,'120980','furniture-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(171117,54700,'120980','furniture-mobile','text-align','center',0,''),(171118,54700,'120980','furniture-mobile','font-size','14',0,''),(171119,54700,'120980','furniture-mobile','color','$color-font-9',0,''),(171120,54700,'120980','furniture-mobile','padding-top','10',0,''),(171121,54701,'120981','furniture-mobile','margin-bottom','10',0,''),(171122,54703,'120983','furniture-mobile','hide_continue_button','1',0,''),(171123,54704,'116699','furniture-mobile','block_type','1',0,''),(171124,54704,'116699','furniture-mobile','background-color','$background-6',0,''),(171125,54704,'116699','furniture-mobile','padding-top','30',0,''),(171126,54704,'116699','furniture-mobile','padding-bottom','30',0,''),(171127,54705,'116700','furniture-mobile','block_type','7',0,''),(171128,54705,'116700','furniture-mobile','schema','7-2',0,'2885'),(171129,54706,'116701','furniture-mobile','block_type','1',0,''),(171130,54706,'116701','furniture-mobile','padding-right','0',0,'2885'),(171131,54707,'116703','furniture-mobile','block_type','1',0,''),(171132,54707,'116703','furniture-mobile','background-color','$background-7',0,''),(171133,54707,'116703','furniture-mobile','padding-top','30',0,''),(171134,54707,'116703','furniture-mobile','padding-left','30',0,''),(171135,54707,'116703','furniture-mobile','padding-right','30',0,''),(171136,54707,'116703','furniture-mobile','padding-bottom','30',0,''),(171137,54707,'116703','furniture-mobile','margin-bottom','20',0,''),(171138,54707,'116703','furniture-mobile','style_class','hiding-box',0,''),(171139,54708,'116704','furniture-mobile','margin-bottom','20',0,''),(171140,54709,'116705','furniture-mobile','padding-top','10',0,''),(171141,54709,'116705','furniture-mobile','padding-left','20',0,''),(171142,54709,'116705','furniture-mobile','padding-right','20',0,''),(171143,54709,'116705','furniture-mobile','margin-top','20',0,''),(171144,54709,'116705','furniture-mobile','background-color','$background-6',0,''),(171145,54709,'116705','furniture-mobile','padding-bottom','8',0,''),(171146,54710,'116706','furniture-mobile','background-color','$background-7',0,''),(171147,54710,'116706','furniture-mobile','block_type','1',0,''),(171148,54710,'116706','furniture-mobile','padding-top','30',0,''),(171149,54710,'116706','furniture-mobile','padding-left','30',0,''),(171150,54710,'116706','furniture-mobile','padding-right','30',0,''),(171151,54710,'116706','furniture-mobile','padding-bottom','30',0,''),(171152,54710,'116706','furniture-mobile','margin-bottom','20',0,''),(171153,54710,'116706','furniture-mobile','style_class','hiding-box',0,''),(171154,54711,'116707','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(171155,54712,'116708','furniture-mobile','background-color','$background-6',0,''),(171156,54712,'116708','furniture-mobile','padding-top','10',0,''),(171157,54712,'116708','furniture-mobile','padding-left','10',0,''),(171158,54712,'116708','furniture-mobile','padding-right','10',0,''),(171159,54712,'116708','furniture-mobile','padding-bottom','10',0,''),(171160,54712,'116708','furniture-mobile','margin-top','10',0,''),(171161,54713,'116709','furniture-mobile','block_type','1',0,''),(171162,54713,'116709','furniture-mobile','content','\\_',0,'3'),(171163,54713,'116709','furniture-mobile','border-top-width','1',0,'3'),(171164,54713,'116709','furniture-mobile','border-top-color','$border-color-4',0,'3'),(171165,54713,'116709','furniture-mobile','display','block',0,'3'),(171166,54713,'116709','furniture-mobile','position','absolute',0,'3'),(171167,54713,'116709','furniture-mobile','top','19',0,'3'),(171168,54713,'116709','furniture-mobile','left','0',0,'3'),(171169,54713,'116709','furniture-mobile','right','0',0,'3'),(171170,54713,'116709','furniture-mobile','margin-top','-2',0,'3'),(171171,54713,'116709','furniture-mobile','position','relative',0,''),(171172,54714,'116710','furniture-mobile','box_align','2',0,''),(171173,54714,'116710','furniture-mobile','margin-bottom','10',0,''),(171174,54714,'116710','furniture-mobile','background-color','$background-7',0,''),(171175,54714,'116710','furniture-mobile','position','relative',0,''),(171176,54715,'116711','furniture-mobile','block_type','2',0,''),(171177,54715,'116711','furniture-mobile','schema','2-2',0,'2885'),(171178,54716,'116712','furniture-mobile','block_type','1',0,''),(171179,54716,'116712','furniture-mobile','padding-right','20',0,''),(171180,54716,'116712','furniture-mobile','padding-left','0',0,'2885'),(171181,54716,'116712','furniture-mobile','margin-bottom','20',0,'2885'),(171182,54716,'116712','furniture-mobile','padding-right','0',0,'2885'),(171183,54719,'116715','furniture-mobile','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(171184,54720,'116716','furniture-mobile','block_type','1',0,''),(171185,54720,'116716','furniture-mobile','padding-left','20',0,''),(171186,54720,'116716','furniture-mobile','padding-left','0',0,'2885'),(171187,54722,'116718','furniture-mobile','border-top-width','1',0,''),(171188,54722,'116718','furniture-mobile','border-top-color','$border-color-4',0,''),(171189,54722,'116718','furniture-mobile','padding-top','13',0,''),(171190,54722,'116718','furniture-mobile','padding-bottom','10',0,''),(171191,54723,'116719','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(171192,54724,'116720','furniture-mobile','block_type','1',0,''),(171193,54724,'116720','furniture-mobile','padding-top','30',0,''),(171194,54724,'116720','furniture-mobile','padding-left','30',0,''),(171195,54724,'116720','furniture-mobile','padding-right','30',0,''),(171196,54724,'116720','furniture-mobile','padding-bottom','23',0,''),(171197,54724,'116720','furniture-mobile','margin-bottom','20',0,''),(171198,54724,'116720','furniture-mobile','background-color','$background-7',0,''),(171199,54724,'116720','furniture-mobile','style_class','hiding-box',0,''),(171200,54725,'116721','furniture-mobile','block_type','2',0,''),(171201,54725,'116721','furniture-mobile','schema','2-2',0,'2885'),(171202,54726,'116722','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171203,54727,'116723','furniture-mobile','padding-right','20',0,''),(171204,54727,'116723','furniture-mobile','padding-right','0',0,'2885'),(171205,54727,'116723','furniture-mobile','padding-bottom','20',0,'2885'),(171206,54728,'116724','furniture-mobile','block_type','1',0,''),(171207,54728,'116724','furniture-mobile','padding-left','20',0,''),(171208,54728,'116724','furniture-mobile','padding-left','0',0,'2885'),(171209,54729,'116725','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171210,54731,'116727','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(171211,54732,'116728','furniture-mobile','block_type','1',0,''),(171212,54732,'116728','furniture-mobile','background-color','$background-7',0,''),(171213,54732,'116728','furniture-mobile','padding-top','30',0,''),(171214,54732,'116728','furniture-mobile','padding-left','30',0,''),(171215,54732,'116728','furniture-mobile','padding-right','30',0,''),(171216,54732,'116728','furniture-mobile','padding-bottom','14',0,''),(171217,54732,'116728','furniture-mobile','margin-bottom','20',0,''),(171218,54732,'116728','furniture-mobile','style_class','hiding-box closeable-box',0,''),(171219,54733,'116729','furniture-mobile','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(171220,54733,'116729','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(171221,54734,'116730','furniture-mobile','style_class','closeable-content',0,''),(171222,54734,'116730','furniture-mobile','padding-bottom','20',0,''),(171223,54735,'116731','furniture-mobile','block_type','1',0,''),(171224,54735,'116731','furniture-mobile','padding-top','30',0,''),(171225,54735,'116731','furniture-mobile','padding-left','30',0,''),(171226,54735,'116731','furniture-mobile','padding-right','30',0,''),(171227,54735,'116731','furniture-mobile','padding-bottom','14',0,''),(171228,54735,'116731','furniture-mobile','margin-bottom','20',0,''),(171229,54735,'116731','furniture-mobile','background-color','$background-7',0,''),(171230,54735,'116731','furniture-mobile','style_class','hiding-box closeable-box',0,''),(171231,54736,'116732','furniture-mobile','block_type','2',0,''),(171232,54736,'116732','furniture-mobile','style_class','closeable-content',0,''),(171233,54736,'116732','furniture-mobile','schema','2-2',0,'2885'),(171234,54737,'116733','furniture-mobile','padding-right','20',0,''),(171235,54737,'116733','furniture-mobile','padding-bottom','20',0,''),(171236,54737,'116733','furniture-mobile','padding-right','0',0,'2885'),(171237,54738,'116734','furniture-mobile','padding-left','20',0,''),(171238,54738,'116734','furniture-mobile','padding-bottom','20',0,''),(171239,54738,'116734','furniture-mobile','padding-left','0',0,'2885'),(171240,54739,'116735','furniture-mobile','padding-left','20',0,''),(171241,54739,'116735','furniture-mobile','padding-bottom','20',0,''),(171242,54739,'116735','furniture-mobile','padding-left','0',0,'2885'),(171243,54740,'116736','furniture-mobile','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(171244,54740,'116736','furniture-mobile','style_class','closeable-heading closeable-event closed',0,''),(171245,54741,'116737','furniture-mobile','block_type','1',0,''),(171246,54741,'116737','furniture-mobile','padding-top','20',0,''),(171247,54741,'116737','furniture-mobile','padding-left','20',0,''),(171248,54741,'116737','furniture-mobile','padding-right','20',0,''),(171249,54741,'116737','furniture-mobile','padding-bottom','20',0,''),(171250,54741,'116737','furniture-mobile','background-color','$background-7',0,''),(171251,54741,'116737','furniture-mobile','style_class','order-summary',0,''),(171252,54741,'116737','furniture-mobile','margin-left','25',0,''),(171253,54741,'116737','furniture-mobile','padding-left','0',0,'2885'),(171254,54742,'116738','furniture-mobile','margin-bottom','10',0,''),(171255,54743,'116739','furniture-mobile','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(171256,54743,'116739','furniture-mobile','text-align','center',0,''),(171257,54743,'116739','furniture-mobile','font-size','14',0,''),(171258,54743,'116739','furniture-mobile','color','$color-font-9',0,''),(171259,54743,'116739','furniture-mobile','padding-top','10',0,''),(171260,54744,'116740','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171261,54746,'120986','furniture-mobile','hide_continue_button','1',0,''),(171262,54747,'116742','furniture-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(171263,54752,'116747','furniture-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(171264,54753,'116749','furniture-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(171265,54754,'116750','furniture-mobile','style_class','order-summary',0,''),(171266,54754,'116750','furniture-mobile','box_align','3',0,''),(171267,54754,'116750','furniture-mobile','width','400',0,''),(171268,54756,'116748','furniture-mobile','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(171269,54759,'116754','furniture-mobile','block_type','1',0,''),(171270,54760,'116755','furniture-mobile','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(171271,54761,'116756','furniture-mobile','float','right',0,''),(171272,54761,'116756','furniture-mobile','position','relative',0,''),(171273,54761,'116756','furniture-mobile','z-index','1',0,''),(171274,54761,'116756','furniture-mobile','top','30',0,''),(171275,54761,'116756','furniture-mobile','margin-bottom','-10',0,''),(171276,54762,'116757','furniture-mobile','margin-bottom','30',0,''),(171277,54763,'116758','furniture-mobile','block_type','1',0,''),(171278,54764,'116759','furniture-mobile','listing_type','CompareProduct',0,''),(171279,54765,'117665.000001','furniture-mobile','block_type','1',0,''),(171280,54765,'117665.000001','furniture-mobile','style_class','item-holder',0,''),(171281,54765,'117665.000001','furniture-mobile','padding-top','25',0,''),(171282,54765,'117665.000001','furniture-mobile','padding-left','25',0,''),(171283,54765,'117665.000001','furniture-mobile','padding-right','25',0,''),(171284,54765,'117665.000001','furniture-mobile','padding-bottom','25',0,''),(171285,54765,'117665.000001','furniture-mobile','text-align','left',0,''),(171286,54766,'120921.000001','furniture-mobile','block_type','1',0,''),(171287,54766,'120921.000001','furniture-mobile','style_class','item-wrapper',0,''),(171288,54767,'120919.000001','furniture-mobile','block_type','1',0,''),(171289,54767,'120919.000001','furniture-mobile','style_class','item-content',0,''),(171290,54768,'1638872990.9609','furniture-mobile','block_type','5',0,''),(171291,54770,'117677.000001','furniture-mobile','float','right',0,''),(171292,54771,'117675.000001','furniture-mobile','clear','none',0,''),(171293,54772,'117676.000001','furniture-mobile','margin-bottom','10',0,''),(171294,54773,'1638873112.0384','furniture-mobile','block_type','2',0,''),(171295,54775,'117673.000001','furniture-mobile','margin-bottom','7',0,''),(171296,54775,'117673.000001','furniture-mobile','text-align','right',0,''),(171297,54776,'116760','furniture-mobile','block_type','1',0,''),(171298,54776,'116760','furniture-mobile','style_class','item-holder',0,''),(171299,54776,'116760','furniture-mobile','padding-top','10',0,''),(171300,54776,'116760','furniture-mobile','padding-left','20',0,''),(171301,54776,'116760','furniture-mobile','padding-right','20',0,''),(171302,54776,'116760','furniture-mobile','padding-bottom','10',0,''),(171303,54776,'116760','furniture-mobile','text-align','left',0,''),(171304,54779,'116763','furniture-mobile','margin-bottom','10',0,''),(171305,54780,'116764','furniture-mobile','block_type','5',0,''),(171306,54782,'116766','furniture-mobile','clear','both',0,''),(171307,54783,'116767','furniture-mobile','block_type','2',0,''),(171308,54784,'116768','furniture-mobile','margin-bottom','7',0,''),(171309,54785,'116769','furniture-mobile','text-align','right',0,''),(171310,54785,'116769','furniture-mobile','margin-bottom','10',0,''),(171311,54785,'116769','furniture-mobile','float','right',0,''),(171312,54786,'116770','furniture-mobile','block_type','1',0,''),(171313,54786,'116770','furniture-mobile','background-color','$background-6',0,''),(171314,54786,'116770','furniture-mobile','padding-bottom','30',0,''),(171315,54786,'116770','furniture-mobile','style_class','checkout-order-confirmation',0,''),(171316,54787,'116771','furniture-mobile','block_type','4',0,''),(171317,54787,'116771','furniture-mobile','schema','4-2',0,'2885'),(171318,54788,'116772','furniture-mobile','block_type','1',0,''),(171319,54788,'116772','furniture-mobile','padding-right','40',0,''),(171320,54788,'116772','furniture-mobile','padding-right','0',0,'2885'),(171321,54789,'116773','furniture-mobile','block_type','1',0,''),(171322,54789,'116773','furniture-mobile','padding-right','30',0,''),(171323,54789,'116773','furniture-mobile','background-color','$background-7',0,''),(171324,54789,'116773','furniture-mobile','padding-top','20',0,''),(171325,54789,'116773','furniture-mobile','padding-left','30',0,''),(171326,54789,'116773','furniture-mobile','padding-bottom','20',0,''),(171327,54789,'116773','furniture-mobile','padding-left','20',0,'2885'),(171328,54789,'116773','furniture-mobile','padding-right','20',0,'2885'),(171329,54790,'116774','furniture-mobile','link','products',0,''),(171330,54790,'116774','furniture-mobile','float','right',0,''),(171331,54790,'116774','furniture-mobile','margin-top','-37',0,''),(171332,54792,'116776','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(171333,54793,'116777','furniture-mobile','block_type','1',0,''),(171334,54793,'116777','furniture-mobile','background-color','$background-7',0,''),(171335,54793,'116777','furniture-mobile','padding-top','20',0,''),(171336,54793,'116777','furniture-mobile','padding-bottom','20',0,''),(171337,54793,'116777','furniture-mobile','padding-left','30',0,''),(171338,54793,'116777','furniture-mobile','padding-right','30',0,''),(171339,54793,'116777','furniture-mobile','margin-bottom','20',0,''),(171340,54794,'116778','furniture-mobile','float','right',0,''),(171341,54794,'116778','furniture-mobile','margin-top','-37',0,''),(171342,54794,'116778','furniture-mobile','link','comments',0,''),(171343,54795,'116779','furniture-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(171344,54796,'116780','furniture-mobile','hide_parents','2',0,''),(171345,54797,'116781','furniture-mobile','block_type','2',0,''),(171346,54797,'116781','furniture-mobile','margin-bottom','20',0,''),(171347,54797,'116781','furniture-mobile','schema','2-2',0,'2876'),(171348,54797,'116781','furniture-mobile','background-color','$background-7',0,''),(171349,54798,'116782','furniture-mobile','block_type','1',0,''),(171350,54798,'116782','furniture-mobile','border-right-width','20',0,''),(171351,54798,'116782','furniture-mobile','border-right-color','$border-color-4',0,''),(171352,54798,'116782','furniture-mobile','margin-right','-10',0,''),(171353,54798,'116782','furniture-mobile','padding-right','30',0,''),(171354,54798,'116782','furniture-mobile','padding-top','20',0,''),(171355,54798,'116782','furniture-mobile','padding-left','30',0,''),(171356,54798,'116782','furniture-mobile','padding-bottom','20',0,''),(171357,54798,'116782','furniture-mobile','border-right-width','0',0,'2885'),(171358,54798,'116782','furniture-mobile','margin-right','0',0,'2885'),(171359,54798,'116782','furniture-mobile','margin-bottom','20',0,'2885'),(171360,54798,'116782','furniture-mobile','padding-left','20',0,'2885'),(171361,54798,'116782','furniture-mobile','padding-right','20',0,'2885'),(171362,54799,'116783','furniture-mobile','link','shipping_method',0,''),(171363,54799,'116783','furniture-mobile','float','right',0,''),(171364,54799,'116783','furniture-mobile','margin-top','-31',0,''),(171365,54801,'116785','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(171366,54801,'116785','furniture-mobile','padding-top','20',0,''),(171367,54802,'116786','furniture-mobile','link','contact_information',0,''),(171368,54802,'116786','furniture-mobile','margin-top','-31',0,''),(171369,54802,'116786','furniture-mobile','float','right',0,''),(171370,54803,'116787','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(171371,54803,'116787','furniture-mobile','clear','none',0,''),(171372,54805,'116789','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(171373,54806,'116790','furniture-mobile','link','shipping_address',0,''),(171374,54806,'116790','furniture-mobile','float','right',0,''),(171375,54806,'116790','furniture-mobile','margin-top','-31',0,''),(171376,54808,'116792','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(171377,54808,'116792','furniture-mobile','clear','none',0,''),(171378,54809,'116793','furniture-mobile','margin-bottom','20',0,''),(171379,54810,'116794','furniture-mobile','block_type','1',0,''),(171380,54810,'116794','furniture-mobile','padding-left','30',0,''),(171381,54810,'116794','furniture-mobile','border-left-width','20',0,''),(171382,54810,'116794','furniture-mobile','border-left-color','$border-color-4',0,''),(171383,54810,'116794','furniture-mobile','margin-left','-10',0,''),(171384,54810,'116794','furniture-mobile','padding-right','30',0,''),(171385,54810,'116794','furniture-mobile','padding-top','20',0,''),(171386,54810,'116794','furniture-mobile','padding-bottom','20',0,''),(171387,54810,'116794','furniture-mobile','border-left-width','0',0,'2885'),(171388,54811,'116795','furniture-mobile','link','payment_method',0,''),(171389,54811,'116795','furniture-mobile','float','right',0,''),(171390,54811,'116795','furniture-mobile','margin-top','-31',0,''),(171391,54812,'116796','furniture-mobile','link','billing_address',0,''),(171392,54812,'116796','furniture-mobile','float','right',0,''),(171393,54812,'116796','furniture-mobile','margin-top','-31',0,''),(171394,54814,'116798','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171395,54814,'116798','furniture-mobile','clear','none',0,''),(171396,54815,'116799','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(171397,54816,'116800','furniture-mobile','margin-bottom','20',0,''),(171398,54817,'116801','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171399,54817,'116801','furniture-mobile','clear','none',0,''),(171400,54819,'116803','furniture-mobile','block_type','1',0,''),(171401,54819,'116803','furniture-mobile','padding-top','20',0,''),(171402,54819,'116803','furniture-mobile','padding-left','20',0,''),(171403,54819,'116803','furniture-mobile','padding-right','20',0,''),(171404,54819,'116803','furniture-mobile','padding-bottom','20',0,''),(171405,54819,'116803','furniture-mobile','background-color','$background-7',0,''),(171406,54819,'116803','furniture-mobile','style_class','order-summary2 hiding-box',0,''),(171407,54820,'116804','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171408,54821,'116805','furniture-mobile','margin-bottom','20',0,''),(171409,54821,'116805','furniture-mobile','text-align','right',0,''),(171410,54823,'116807','furniture-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(171411,54824,'116808','furniture-mobile','block_type','1',0,''),(171412,54824,'116808','furniture-mobile','background-color','$background-6',0,''),(171413,54824,'116808','furniture-mobile','padding-bottom','30',0,''),(171414,54825,'116809','furniture-mobile','block_type','4',0,''),(171415,54825,'116809','furniture-mobile','schema','4-2',0,'2885'),(171416,54826,'116810','furniture-mobile','block_type','1',0,''),(171417,54826,'116810','furniture-mobile','padding-right','40',0,''),(171418,54826,'116810','furniture-mobile','padding-right','0',0,'2885'),(171419,54827,'116811','furniture-mobile','block_type','1',0,''),(171420,54827,'116811','furniture-mobile','background-color','$background-7',0,''),(171421,54827,'116811','furniture-mobile','padding-top','20',0,''),(171422,54827,'116811','furniture-mobile','padding-bottom','20',0,''),(171423,54827,'116811','furniture-mobile','padding-left','30',0,''),(171424,54827,'116811','furniture-mobile','padding-right','30',0,''),(171425,54827,'116811','furniture-mobile','margin-bottom','20',0,''),(171426,54828,'116812','furniture-mobile','hide_parents','2',0,''),(171427,54829,'116813','furniture-mobile','float','right',0,''),(171428,54829,'116813','furniture-mobile','margin-top','-37',0,''),(171429,54829,'116813','furniture-mobile','link','comments',0,''),(171430,54830,'116814','furniture-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(171431,54831,'116815','furniture-mobile','block_type','1',0,''),(171432,54831,'116815','furniture-mobile','padding-right','30',0,''),(171433,54831,'116815','furniture-mobile','background-color','$background-7',0,''),(171434,54831,'116815','furniture-mobile','padding-top','20',0,''),(171435,54831,'116815','furniture-mobile','padding-left','30',0,''),(171436,54831,'116815','furniture-mobile','padding-bottom','20',0,''),(171437,54831,'116815','furniture-mobile','padding-left','20',0,'2885'),(171438,54831,'116815','furniture-mobile','padding-right','20',0,'2885'),(171439,54832,'116816','furniture-mobile','link','products',0,''),(171440,54832,'116816','furniture-mobile','float','right',0,''),(171441,54832,'116816','furniture-mobile','margin-top','-37',0,''),(171442,54833,'116817','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(171443,54835,'116819','furniture-mobile','block_type','2',0,''),(171444,54835,'116819','furniture-mobile','margin-bottom','20',0,''),(171445,54835,'116819','furniture-mobile','schema','2-2',0,'2876'),(171446,54835,'116819','furniture-mobile','background-color','$background-7',0,''),(171447,54836,'116820','furniture-mobile','block_type','1',0,''),(171448,54836,'116820','furniture-mobile','border-right-width','20',0,''),(171449,54836,'116820','furniture-mobile','border-right-color','$border-color-4',0,''),(171450,54836,'116820','furniture-mobile','margin-right','-10',0,''),(171451,54836,'116820','furniture-mobile','padding-right','30',0,''),(171452,54836,'116820','furniture-mobile','padding-top','20',0,''),(171453,54836,'116820','furniture-mobile','padding-left','30',0,''),(171454,54836,'116820','furniture-mobile','padding-bottom','20',0,''),(171455,54836,'116820','furniture-mobile','border-right-width','0',0,'2885'),(171456,54836,'116820','furniture-mobile','margin-right','0',0,'2885'),(171457,54836,'116820','furniture-mobile','margin-bottom','20',0,'2885'),(171458,54836,'116820','furniture-mobile','padding-left','20',0,'2885'),(171459,54836,'116820','furniture-mobile','padding-right','20',0,'2885'),(171460,54837,'116821','furniture-mobile','link','shipping_address',0,''),(171461,54837,'116821','furniture-mobile','float','right',0,''),(171462,54837,'116821','furniture-mobile','margin-top','-31',0,''),(171463,54839,'116823','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(171464,54839,'116823','furniture-mobile','clear','none',0,''),(171465,54840,'116824','furniture-mobile','link','shipping_method',0,''),(171466,54840,'116824','furniture-mobile','float','right',0,''),(171467,54840,'116824','furniture-mobile','margin-top','-31',0,''),(171468,54841,'116825','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(171469,54841,'116825','furniture-mobile','clear','none',0,''),(171470,54842,'116826','furniture-mobile','margin-bottom','20',0,''),(171471,54843,'116827','furniture-mobile','block_type','1',0,''),(171472,54843,'116827','furniture-mobile','padding-left','30',0,''),(171473,54843,'116827','furniture-mobile','border-left-width','20',0,''),(171474,54843,'116827','furniture-mobile','border-left-color','$border-color-4',0,''),(171475,54843,'116827','furniture-mobile','margin-left','-10',0,''),(171476,54843,'116827','furniture-mobile','padding-right','30',0,''),(171477,54843,'116827','furniture-mobile','padding-top','20',0,''),(171478,54843,'116827','furniture-mobile','padding-bottom','20',0,''),(171479,54843,'116827','furniture-mobile','border-left-width','0',0,'2885'),(171480,54846,'116830','furniture-mobile','link','contact_information',0,''),(171481,54846,'116830','furniture-mobile','margin-top','-31',0,''),(171482,54846,'116830','furniture-mobile','float','right',0,''),(171483,54847,'116831','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(171484,54848,'116832','furniture-mobile','block_type','1',0,''),(171485,54848,'116832','furniture-mobile','padding-top','20',0,''),(171486,54848,'116832','furniture-mobile','padding-left','20',0,''),(171487,54848,'116832','furniture-mobile','padding-right','20',0,''),(171488,54848,'116832','furniture-mobile','padding-bottom','20',0,''),(171489,54848,'116832','furniture-mobile','background-color','$background-7',0,''),(171490,54848,'116832','furniture-mobile','style_class','order-summary',0,''),(171491,54849,'116833','furniture-mobile','margin-bottom','20',0,''),(171492,54849,'116833','furniture-mobile','text-align','right',0,''),(171493,54850,'116834','furniture-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(171494,54851,'116835','furniture-mobile','block_type','1',0,''),(171495,54851,'116835','furniture-mobile','background-color','$background-6',0,''),(171496,54851,'116835','furniture-mobile','padding-bottom','30',0,''),(171497,54852,'116836','furniture-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(171498,54853,'116837','furniture-mobile','block_type','4',0,''),(171499,54854,'116838','furniture-mobile','block_type','1',0,''),(171500,54854,'116838','furniture-mobile','padding-right','40',0,''),(171501,54855,'116839','furniture-mobile','block_type','2',0,''),(171502,54855,'116839','furniture-mobile','margin-bottom','20',0,''),(171503,54855,'116839','furniture-mobile','schema','2-2',0,'2876'),(171504,54855,'116839','furniture-mobile','background-color','$background-7',0,''),(171505,54856,'116840','furniture-mobile','block_type','1',0,''),(171506,54856,'116840','furniture-mobile','padding-right','0',0,'2876'),(171507,54856,'116840','furniture-mobile','border-right-width','20',0,''),(171508,54856,'116840','furniture-mobile','border-right-color','$border-color-4',0,''),(171509,54856,'116840','furniture-mobile','margin-right','-10',0,''),(171510,54856,'116840','furniture-mobile','padding-right','30',0,''),(171511,54856,'116840','furniture-mobile','padding-top','20',0,''),(171512,54856,'116840','furniture-mobile','padding-left','30',0,''),(171513,54856,'116840','furniture-mobile','padding-bottom','20',0,''),(171514,54857,'116841','furniture-mobile','link','contact_information',0,''),(171515,54857,'116841','furniture-mobile','float','right',0,''),(171516,54858,'116842','furniture-mobile','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(171517,54860,'116844','furniture-mobile','block_type','1',0,''),(171518,54860,'116844','furniture-mobile','padding-left','30',0,''),(171519,54860,'116844','furniture-mobile','padding-left','0',0,'2876'),(171520,54860,'116844','furniture-mobile','border-left-width','20',0,''),(171521,54860,'116844','furniture-mobile','border-left-color','$border-color-4',0,''),(171522,54860,'116844','furniture-mobile','margin-left','-10',0,''),(171523,54860,'116844','furniture-mobile','padding-right','30',0,''),(171524,54860,'116844','furniture-mobile','padding-top','20',0,''),(171525,54860,'116844','furniture-mobile','padding-bottom','20',0,''),(171526,54862,'116846','furniture-mobile','link','payment_method',0,''),(171527,54862,'116846','furniture-mobile','float','right',0,''),(171528,54862,'116846','furniture-mobile','margin-top','-31',0,''),(171529,54863,'116847','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171530,54863,'116847','furniture-mobile','clear','none',0,''),(171531,54864,'116848','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(171532,54865,'116849','furniture-mobile','link','billing_address',0,''),(171533,54865,'116849','furniture-mobile','float','right',0,''),(171534,54865,'116849','furniture-mobile','margin-top','-31',0,''),(171535,54866,'116850','furniture-mobile','margin-bottom','20',0,''),(171536,54867,'116851','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171537,54867,'116851','furniture-mobile','clear','none',0,''),(171538,54868,'116852','furniture-mobile','block_type','1',0,''),(171539,54868,'116852','furniture-mobile','background-color','$background-7',0,''),(171540,54868,'116852','furniture-mobile','padding-top','20',0,''),(171541,54868,'116852','furniture-mobile','padding-bottom','20',0,''),(171542,54868,'116852','furniture-mobile','padding-left','30',0,''),(171543,54868,'116852','furniture-mobile','padding-right','30',0,''),(171544,54868,'116852','furniture-mobile','margin-bottom','20',0,''),(171545,54869,'116853','furniture-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(171546,54870,'116854','furniture-mobile','hide_parents','2',0,''),(171547,54871,'116855','furniture-mobile','float','right',0,''),(171548,54871,'116855','furniture-mobile','margin-top','-37',0,''),(171549,54871,'116855','furniture-mobile','link','comments',0,''),(171550,54872,'116856','furniture-mobile','block_type','1',0,''),(171551,54872,'116856','furniture-mobile','padding-right','30',0,''),(171552,54872,'116856','furniture-mobile','padding-right','0',0,'2876'),(171553,54872,'116856','furniture-mobile','background-color','$background-7',0,''),(171554,54872,'116856','furniture-mobile','padding-top','20',0,''),(171555,54872,'116856','furniture-mobile','padding-left','30',0,''),(171556,54872,'116856','furniture-mobile','padding-bottom','20',0,''),(171557,54873,'116857','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(171558,54874,'116858','furniture-mobile','link','products',0,''),(171559,54874,'116858','furniture-mobile','float','right',0,''),(171560,54874,'116858','furniture-mobile','margin-top','-37',0,''),(171561,54876,'116860','furniture-mobile','block_type','1',0,''),(171562,54876,'116860','furniture-mobile','padding-top','20',0,''),(171563,54876,'116860','furniture-mobile','padding-left','20',0,''),(171564,54876,'116860','furniture-mobile','padding-right','20',0,''),(171565,54876,'116860','furniture-mobile','padding-bottom','20',0,''),(171566,54876,'116860','furniture-mobile','background-color','$background-7',0,''),(171567,54876,'116860','furniture-mobile','style_class','order-summary2 hiding-box',0,''),(171568,54877,'116861','furniture-mobile','margin-bottom','20',0,''),(171569,54877,'116861','furniture-mobile','text-align','right',0,''),(171570,54878,'116862','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171571,54880,'116864','furniture-mobile','block_type','1',0,''),(171572,54880,'116864','furniture-mobile','background-color','$background-6',0,''),(171573,54880,'116864','furniture-mobile','padding-bottom','30',0,''),(171574,54881,'116865','furniture-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(171575,54882,'116866','furniture-mobile','block_type','4',0,''),(171576,54882,'116866','furniture-mobile','schema','4-2',0,'2885'),(171577,54883,'116867','furniture-mobile','block_type','1',0,''),(171578,54883,'116867','furniture-mobile','padding-right','40',0,''),(171579,54883,'116867','furniture-mobile','padding-right','0',0,'2885'),(171580,54884,'116868','furniture-mobile','block_type','1',0,''),(171581,54884,'116868','furniture-mobile','background-color','$background-7',0,''),(171582,54884,'116868','furniture-mobile','padding-top','20',0,''),(171583,54884,'116868','furniture-mobile','padding-bottom','20',0,''),(171584,54884,'116868','furniture-mobile','padding-left','30',0,''),(171585,54884,'116868','furniture-mobile','padding-right','30',0,''),(171586,54884,'116868','furniture-mobile','margin-bottom','20',0,''),(171587,54885,'116869','furniture-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(171588,54886,'116870','furniture-mobile','hide_parents','2',0,''),(171589,54887,'116871','furniture-mobile','float','right',0,''),(171590,54887,'116871','furniture-mobile','margin-top','-37',0,''),(171591,54887,'116871','furniture-mobile','link','comments',0,''),(171592,54888,'116872','furniture-mobile','block_type','2',0,''),(171593,54888,'116872','furniture-mobile','margin-bottom','20',0,''),(171594,54888,'116872','furniture-mobile','schema','2-2',0,'2876'),(171595,54888,'116872','furniture-mobile','background-color','$background-7',0,''),(171596,54889,'116873','furniture-mobile','block_type','1',0,''),(171597,54889,'116873','furniture-mobile','border-right-width','20',0,''),(171598,54889,'116873','furniture-mobile','border-right-color','$border-color-4',0,''),(171599,54889,'116873','furniture-mobile','margin-right','-10',0,''),(171600,54889,'116873','furniture-mobile','padding-right','30',0,''),(171601,54889,'116873','furniture-mobile','padding-top','20',0,''),(171602,54889,'116873','furniture-mobile','padding-left','30',0,''),(171603,54889,'116873','furniture-mobile','padding-bottom','20',0,''),(171604,54889,'116873','furniture-mobile','border-right-width','0',0,'2885'),(171605,54889,'116873','furniture-mobile','margin-right','0',0,'2885'),(171606,54889,'116873','furniture-mobile','margin-bottom','20',0,'2885'),(171607,54889,'116873','furniture-mobile','padding-left','20',0,'2885'),(171608,54889,'116873','furniture-mobile','padding-right','20',0,'2885'),(171609,54890,'116874','furniture-mobile','link','contact_information',0,''),(171610,54890,'116874','furniture-mobile','margin-top','-31',0,''),(171611,54890,'116874','furniture-mobile','float','right',0,''),(171612,54893,'116877','furniture-mobile','link','payment_method',0,''),(171613,54893,'116877','furniture-mobile','float','right',0,''),(171614,54893,'116877','furniture-mobile','margin-top','-31',0,''),(171615,54894,'116878','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(171616,54894,'116878','furniture-mobile','padding-top','20',0,''),(171617,54895,'116879','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171618,54895,'116879','furniture-mobile','clear','none',0,''),(171619,54896,'116880','furniture-mobile','block_type','1',0,''),(171620,54896,'116880','furniture-mobile','padding-left','30',0,''),(171621,54896,'116880','furniture-mobile','border-left-width','20',0,''),(171622,54896,'116880','furniture-mobile','border-left-color','$border-color-4',0,''),(171623,54896,'116880','furniture-mobile','margin-left','-10',0,''),(171624,54896,'116880','furniture-mobile','padding-right','30',0,''),(171625,54896,'116880','furniture-mobile','padding-top','20',0,''),(171626,54896,'116880','furniture-mobile','padding-bottom','20',0,''),(171627,54896,'116880','furniture-mobile','border-left-width','0',0,'2885'),(171628,54897,'116881','furniture-mobile','margin-bottom','20',0,''),(171629,54898,'116882','furniture-mobile','link','billing_address',0,''),(171630,54898,'116882','furniture-mobile','float','right',0,''),(171631,54898,'116882','furniture-mobile','margin-top','-31',0,''),(171632,54899,'116883','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171633,54899,'116883','furniture-mobile','clear','none',0,''),(171634,54900,'116884','furniture-mobile','block_type','1',0,''),(171635,54900,'116884','furniture-mobile','padding-right','30',0,''),(171636,54900,'116884','furniture-mobile','background-color','$background-7',0,''),(171637,54900,'116884','furniture-mobile','padding-top','20',0,''),(171638,54900,'116884','furniture-mobile','padding-left','30',0,''),(171639,54900,'116884','furniture-mobile','padding-bottom','20',0,''),(171640,54900,'116884','furniture-mobile','padding-left','20',0,'2885'),(171641,54900,'116884','furniture-mobile','padding-right','20',0,'2885'),(171642,54901,'116885','furniture-mobile','link','products',0,''),(171643,54901,'116885','furniture-mobile','float','right',0,''),(171644,54901,'116885','furniture-mobile','margin-top','-37',0,''),(171645,54902,'116886','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(171646,54903,'116887','furniture-mobile','margin-bottom','20',0,''),(171647,54904,'116888','furniture-mobile','block_type','1',0,''),(171648,54904,'116888','furniture-mobile','padding-top','20',0,''),(171649,54904,'116888','furniture-mobile','padding-left','20',0,''),(171650,54904,'116888','furniture-mobile','padding-right','20',0,''),(171651,54904,'116888','furniture-mobile','padding-bottom','20',0,''),(171652,54904,'116888','furniture-mobile','background-color','$background-7',0,''),(171653,54904,'116888','furniture-mobile','style_class','order-summary',0,''),(171654,54905,'116889','furniture-mobile','margin-bottom','20',0,''),(171655,54905,'116889','furniture-mobile','text-align','right',0,''),(171656,54907,'116891','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171657,54908,'116892','furniture-mobile','block_type','1',0,''),(171658,54908,'116892','furniture-mobile','background-color','$background-6',0,''),(171659,54908,'116892','furniture-mobile','padding-bottom','30',0,''),(171660,54909,'116893','furniture-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(171661,54910,'116894','furniture-mobile','block_type','4',0,''),(171662,54910,'116894','furniture-mobile','schema','4-2',0,'2885'),(171663,54911,'116895','furniture-mobile','block_type','1',0,''),(171664,54911,'116895','furniture-mobile','padding-right','40',0,''),(171665,54911,'116895','furniture-mobile','padding-right','0',0,'2885'),(171666,54912,'116896','furniture-mobile','block_type','1',0,''),(171667,54912,'116896','furniture-mobile','padding-right','30',0,''),(171668,54912,'116896','furniture-mobile','background-color','$background-7',0,''),(171669,54912,'116896','furniture-mobile','padding-top','20',0,''),(171670,54912,'116896','furniture-mobile','padding-left','30',0,''),(171671,54912,'116896','furniture-mobile','padding-bottom','20',0,''),(171672,54912,'116896','furniture-mobile','padding-left','20',0,'2885'),(171673,54912,'116896','furniture-mobile','padding-right','20',0,'2885'),(171674,54914,'116898','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(171675,54915,'116899','furniture-mobile','link','products',0,''),(171676,54915,'116899','furniture-mobile','float','right',0,''),(171677,54915,'116899','furniture-mobile','margin-top','-37',0,''),(171678,54916,'116900','furniture-mobile','block_type','2',0,''),(171679,54916,'116900','furniture-mobile','margin-bottom','20',0,''),(171680,54916,'116900','furniture-mobile','schema','2-2',0,'2876'),(171681,54916,'116900','furniture-mobile','background-color','$background-7',0,''),(171682,54917,'116901','furniture-mobile','block_type','1',0,''),(171683,54917,'116901','furniture-mobile','border-right-width','20',0,''),(171684,54917,'116901','furniture-mobile','border-right-color','$border-color-4',0,''),(171685,54917,'116901','furniture-mobile','margin-right','-10',0,''),(171686,54917,'116901','furniture-mobile','padding-right','30',0,''),(171687,54917,'116901','furniture-mobile','padding-top','20',0,''),(171688,54917,'116901','furniture-mobile','padding-left','30',0,''),(171689,54917,'116901','furniture-mobile','padding-bottom','20',0,''),(171690,54917,'116901','furniture-mobile','border-right-width','0',0,'2885'),(171691,54917,'116901','furniture-mobile','margin-right','0',0,'2885'),(171692,54917,'116901','furniture-mobile','margin-bottom','20',0,'2885'),(171693,54917,'116901','furniture-mobile','padding-left','20',0,'2885'),(171694,54917,'116901','furniture-mobile','padding-right','20',0,'2885'),(171695,54918,'116902','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(171696,54919,'116903','furniture-mobile','link','contact_information',0,''),(171697,54919,'116903','furniture-mobile','margin-top','-31',0,''),(171698,54919,'116903','furniture-mobile','float','right',0,''),(171699,54920,'116904','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(171700,54920,'116904','furniture-mobile','clear','none',0,''),(171701,54922,'116906','furniture-mobile','margin-bottom','20',0,''),(171702,54924,'116908','furniture-mobile','link','shipping_address',0,''),(171703,54924,'116908','furniture-mobile','float','right',0,''),(171704,54924,'116908','furniture-mobile','margin-top','-31',0,''),(171705,54926,'116910','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(171706,54926,'116910','furniture-mobile','padding-top','20',0,''),(171707,54927,'116911','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(171708,54927,'116911','furniture-mobile','clear','none',0,''),(171709,54928,'116912','furniture-mobile','link','shipping_method',0,''),(171710,54928,'116912','furniture-mobile','float','right',0,''),(171711,54928,'116912','furniture-mobile','margin-top','-31',0,''),(171712,54929,'116913','furniture-mobile','block_type','1',0,''),(171713,54929,'116913','furniture-mobile','padding-left','30',0,''),(171714,54929,'116913','furniture-mobile','border-left-width','20',0,''),(171715,54929,'116913','furniture-mobile','border-left-color','$border-color-4',0,''),(171716,54929,'116913','furniture-mobile','margin-left','-10',0,''),(171717,54929,'116913','furniture-mobile','padding-right','30',0,''),(171718,54929,'116913','furniture-mobile','padding-top','20',0,''),(171719,54929,'116913','furniture-mobile','padding-bottom','20',0,''),(171720,54929,'116913','furniture-mobile','border-left-width','0',0,'2885'),(171721,54930,'116914','furniture-mobile','link','billing_address',0,''),(171722,54930,'116914','furniture-mobile','float','right',0,''),(171723,54930,'116914','furniture-mobile','margin-top','-31',0,''),(171724,54931,'116915','furniture-mobile','margin-bottom','20',0,''),(171725,54933,'116917','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(171726,54934,'116918','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171727,54934,'116918','furniture-mobile','clear','none',0,''),(171728,54935,'116919','furniture-mobile','link','payment_method',0,''),(171729,54935,'116919','furniture-mobile','float','right',0,''),(171730,54935,'116919','furniture-mobile','margin-top','-31',0,''),(171731,54936,'116920','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171732,54936,'116920','furniture-mobile','clear','none',0,''),(171733,54937,'116921','furniture-mobile','block_type','1',0,''),(171734,54937,'116921','furniture-mobile','background-color','$background-7',0,''),(171735,54937,'116921','furniture-mobile','padding-top','20',0,''),(171736,54937,'116921','furniture-mobile','padding-bottom','20',0,''),(171737,54937,'116921','furniture-mobile','padding-left','30',0,''),(171738,54937,'116921','furniture-mobile','padding-right','30',0,''),(171739,54937,'116921','furniture-mobile','margin-bottom','20',0,''),(171740,54938,'116922','furniture-mobile','hide_parents','2',0,''),(171741,54939,'116923','furniture-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(171742,54940,'116924','furniture-mobile','float','right',0,''),(171743,54940,'116924','furniture-mobile','margin-top','-37',0,''),(171744,54940,'116924','furniture-mobile','link','comments',0,''),(171745,54941,'116925','furniture-mobile','block_type','1',0,''),(171746,54941,'116925','furniture-mobile','padding-top','20',0,''),(171747,54941,'116925','furniture-mobile','padding-left','20',0,''),(171748,54941,'116925','furniture-mobile','padding-right','20',0,''),(171749,54941,'116925','furniture-mobile','padding-bottom','20',0,''),(171750,54941,'116925','furniture-mobile','background-color','$background-7',0,''),(171751,54941,'116925','furniture-mobile','style_class','order-summary',0,''),(171752,54942,'116926','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171753,54944,'116928','furniture-mobile','margin-bottom','20',0,''),(171754,54944,'116928','furniture-mobile','text-align','right',0,''),(171755,54945,'116929','furniture-mobile','block_type','1',0,''),(171756,54945,'116929','furniture-mobile','background-color','$background-6',0,''),(171757,54945,'116929','furniture-mobile','padding-bottom','30',0,''),(171758,54946,'116930','furniture-mobile','block_type','4',0,''),(171759,54946,'116930','furniture-mobile','schema','4-2',0,'2885'),(171760,54947,'116931','furniture-mobile','block_type','1',0,''),(171761,54947,'116931','furniture-mobile','padding-right','40',0,''),(171762,54947,'116931','furniture-mobile','padding-right','0',0,'2885'),(171763,54948,'116932','furniture-mobile','block_type','2',0,''),(171764,54948,'116932','furniture-mobile','margin-bottom','20',0,''),(171765,54948,'116932','furniture-mobile','schema','2-2',0,'2876'),(171766,54948,'116932','furniture-mobile','background-color','$background-7',0,''),(171767,54949,'116933','furniture-mobile','block_type','1',0,''),(171768,54949,'116933','furniture-mobile','border-right-width','20',0,''),(171769,54949,'116933','furniture-mobile','border-right-color','$border-color-4',0,''),(171770,54949,'116933','furniture-mobile','margin-right','-10',0,''),(171771,54949,'116933','furniture-mobile','padding-right','30',0,''),(171772,54949,'116933','furniture-mobile','padding-top','20',0,''),(171773,54949,'116933','furniture-mobile','padding-left','30',0,''),(171774,54949,'116933','furniture-mobile','padding-bottom','20',0,''),(171775,54949,'116933','furniture-mobile','border-right-width','0',0,'2885'),(171776,54949,'116933','furniture-mobile','margin-right','0',0,'2885'),(171777,54949,'116933','furniture-mobile','margin-bottom','20',0,'2885'),(171778,54949,'116933','furniture-mobile','padding-left','20',0,'2885'),(171779,54949,'116933','furniture-mobile','padding-right','20',0,'2885'),(171780,54950,'116934','furniture-mobile','margin-bottom','20',0,''),(171781,54951,'116935','furniture-mobile','link','shipping_address',0,''),(171782,54951,'116935','furniture-mobile','float','right',0,''),(171783,54951,'116935','furniture-mobile','margin-top','-31',0,''),(171784,54952,'116936','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(171785,54952,'116936','furniture-mobile','clear','none',0,''),(171786,54955,'116939','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(171787,54956,'116940','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(171788,54956,'116940','furniture-mobile','clear','none',0,''),(171789,54957,'116941','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(171790,54957,'116941','furniture-mobile','padding-top','20',0,''),(171791,54959,'116943','furniture-mobile','link','shipping_method',0,''),(171792,54959,'116943','furniture-mobile','float','right',0,''),(171793,54959,'116943','furniture-mobile','margin-top','-31',0,''),(171794,54960,'116944','furniture-mobile','link','contact_information',0,''),(171795,54960,'116944','furniture-mobile','margin-top','-31',0,''),(171796,54960,'116944','furniture-mobile','float','right',0,''),(171797,54961,'116945','furniture-mobile','block_type','1',0,''),(171798,54961,'116945','furniture-mobile','padding-left','30',0,''),(171799,54961,'116945','furniture-mobile','border-left-width','20',0,''),(171800,54961,'116945','furniture-mobile','border-left-color','$border-color-4',0,''),(171801,54961,'116945','furniture-mobile','margin-left','-10',0,''),(171802,54961,'116945','furniture-mobile','padding-right','30',0,''),(171803,54961,'116945','furniture-mobile','padding-top','20',0,''),(171804,54961,'116945','furniture-mobile','padding-bottom','20',0,''),(171805,54961,'116945','furniture-mobile','border-left-width','0',0,'2885'),(171806,54962,'116946','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(171807,54962,'116946','furniture-mobile','clear','none',0,''),(171808,54963,'116947','furniture-mobile','margin-bottom','20',0,''),(171809,54964,'116948','furniture-mobile','link','billing_address',0,''),(171810,54964,'116948','furniture-mobile','float','right',0,''),(171811,54964,'116948','furniture-mobile','margin-top','-31',0,''),(171812,54966,'116950','furniture-mobile','link','payment_method',0,''),(171813,54966,'116950','furniture-mobile','float','right',0,''),(171814,54966,'116950','furniture-mobile','margin-top','-31',0,''),(171815,54967,'116951','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(171816,54968,'116952','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(171817,54968,'116952','furniture-mobile','clear','none',0,''),(171818,54969,'116953','furniture-mobile','block_type','1',0,''),(171819,54969,'116953','furniture-mobile','padding-right','30',0,''),(171820,54969,'116953','furniture-mobile','background-color','$background-7',0,''),(171821,54969,'116953','furniture-mobile','padding-top','20',0,''),(171822,54969,'116953','furniture-mobile','padding-left','30',0,''),(171823,54969,'116953','furniture-mobile','padding-bottom','20',0,''),(171824,54969,'116953','furniture-mobile','padding-left','20',0,'2885'),(171825,54969,'116953','furniture-mobile','padding-right','20',0,'2885'),(171826,54970,'116954','furniture-mobile','link','products',0,''),(171827,54970,'116954','furniture-mobile','float','right',0,''),(171828,54970,'116954','furniture-mobile','margin-top','-37',0,''),(171829,54971,'116955','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(171830,54973,'116957','furniture-mobile','block_type','1',0,''),(171831,54973,'116957','furniture-mobile','background-color','$background-7',0,''),(171832,54973,'116957','furniture-mobile','padding-top','20',0,''),(171833,54973,'116957','furniture-mobile','padding-bottom','20',0,''),(171834,54973,'116957','furniture-mobile','padding-left','30',0,''),(171835,54973,'116957','furniture-mobile','padding-right','30',0,''),(171836,54973,'116957','furniture-mobile','margin-bottom','20',0,''),(171837,54974,'116958','furniture-mobile','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(171838,54975,'116959','furniture-mobile','float','right',0,''),(171839,54975,'116959','furniture-mobile','margin-top','-37',0,''),(171840,54975,'116959','furniture-mobile','link','comments',0,''),(171841,54976,'116960','furniture-mobile','hide_parents','2',0,''),(171842,54977,'116961','furniture-mobile','block_type','1',0,''),(171843,54977,'116961','furniture-mobile','padding-top','20',0,''),(171844,54977,'116961','furniture-mobile','padding-left','20',0,''),(171845,54977,'116961','furniture-mobile','padding-right','20',0,''),(171846,54977,'116961','furniture-mobile','padding-bottom','20',0,''),(171847,54977,'116961','furniture-mobile','background-color','$background-7',0,''),(171848,54977,'116961','furniture-mobile','style_class','order-summary',0,''),(171849,54979,'116963','furniture-mobile','margin-bottom','20',0,''),(171850,54979,'116963','furniture-mobile','text-align','right',0,''),(171851,54980,'116964','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(171852,54981,'116965','furniture-mobile','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(171853,54982,'116966','furniture-mobile','block_type','1',0,''),(171854,54984,'116968','furniture-mobile','block_type','2',0,''),(171855,54984,'116968','furniture-mobile','font-weight','400',0,''),(171856,54984,'116968','furniture-mobile','padding-bottom','20',0,''),(171857,54984,'116968','furniture-mobile','schema','2-2',0,'2885'),(171858,54985,'116969','furniture-mobile','show_captcha','on',0,''),(171859,54986,'116970','furniture-mobile','font-weight','400',0,''),(171860,54986,'116970','furniture-mobile','padding-left','40',0,''),(171861,54986,'116970','furniture-mobile','time_format','24',0,''),(171862,54986,'116970','furniture-mobile','show_icons','on',0,''),(171863,54986,'116970','furniture-mobile','padding-left','0',0,'2885'),(171864,54987,'116971','furniture-mobile','block_type','1',0,''),(171865,54988,'116972','furniture-mobile','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(171866,54989,'116973','furniture-mobile','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(171867,54989,'116973','furniture-mobile','margin-bottom','40',0,''),(171868,54990,'116102.000001','furniture-mobile','block_type','1',0,''),(171869,54991,'116103.000001','furniture-mobile','block_type','6',0,''),(171870,54991,'116103.000001','furniture-mobile','schema','6-3',0,'2885'),(171871,54992,'116104.000001','furniture-mobile','aria_name','account-menu',0,''),(171928,55012,'116109.000001','furniture-mobile','text','<h1>##CREDIT_AMOUNT_HISTORY##</h1>',0,''),(171929,55013,'1638895944.9672','furniture-mobile','margin-bottom','20',0,''),(171930,55014,'116974','furniture-mobile','width','680',0,''),(171931,55014,'116974','furniture-mobile','font-weight','normal',0,''),(171932,55014,'116974','furniture-mobile','font-size','12',0,''),(171933,55014,'116974','furniture-mobile','padding-top','20',0,''),(171934,55014,'116974','furniture-mobile','padding-bottom','20',0,''),(171935,55014,'116974','furniture-mobile','color','$color-font-8',0,''),(171936,55015,'116975','furniture-mobile','block_type','3',0,''),(171937,55015,'116975','furniture-mobile','font-weight','normal',0,''),(171938,55015,'116975','furniture-mobile','padding-top','20',0,''),(171939,55016,'116976','furniture-mobile','font-size','12',0,''),(171940,55017,'116977','furniture-mobile','text','<p>If undelivered please return to:</p>',1,''),(171941,55017,'116977','furniture-mobile','font-size','12',0,''),(171942,55017,'116977','furniture-mobile','font-weight','bold',0,''),(171943,55018,'116978','furniture-mobile','text','<p>Thank you for your order</p>',1,''),(171944,55018,'116978','furniture-mobile','color','$color-font-10',0,''),(171945,55018,'116978','furniture-mobile','font-size','13',0,''),(171946,55018,'116978','furniture-mobile','font-weight','bold',0,''),(171947,55018,'116978','furniture-mobile','padding-top','5',0,''),(171948,55018,'116978','furniture-mobile','text-align','center',0,''),(171949,55019,'116979','furniture-mobile','font-weight','400',0,''),(171950,55019,'116979','furniture-mobile','text-align','center',0,''),(171951,55019,'116979','furniture-mobile','padding-top','0',0,''),(171953,55019,'116979','furniture-mobile','padding-left','20',0,''),(171954,55019,'116979','furniture-mobile','padding-right','20',0,''),(171955,55020,'116980','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(171956,55020,'116980','furniture-mobile','font-size','12',0,''),(171957,55020,'116980','furniture-mobile','font-weight','bold',0,''),(171958,55020,'116980','furniture-mobile','text-align','right',0,''),(171959,55021,'116981','furniture-mobile','block_type','6',0,''),(171960,55021,'116981','furniture-mobile','font-weight','normal',0,''),(171961,55021,'116981','furniture-mobile','font-size','16',0,''),(171962,55022,'116982','furniture-mobile','text','<p>Email:</p>',1,''),(171963,55022,'116982','furniture-mobile','font-weight','normal',0,''),(171964,55022,'116982','furniture-mobile','text-align','right',0,''),(171965,55022,'116982','furniture-mobile','font-size','12',0,''),(171966,55023,'116983','furniture-mobile','font-weight','normal',0,''),(171967,55023,'116983','furniture-mobile','text-align','right',0,''),(171968,55023,'116983','furniture-mobile','font-size','12',0,''),(171969,55024,'116984','furniture-mobile','block_type','6',0,''),(171970,55024,'116984','furniture-mobile','font-weight','normal',0,''),(171971,55024,'116984','furniture-mobile','font-size','16',0,''),(171972,55025,'116985','furniture-mobile','text','<p>Phone:</p>',1,''),(171973,55025,'116985','furniture-mobile','font-weight','normal',0,''),(171974,55025,'116985','furniture-mobile','text-align','right',0,''),(171975,55025,'116985','furniture-mobile','font-size','12',0,''),(171976,55026,'116986','furniture-mobile','font-weight','normal',0,''),(171977,55026,'116986','furniture-mobile','text-align','right',0,''),(171978,55026,'116986','furniture-mobile','font-size','12',0,''),(171979,55027,'116987','furniture-mobile','font-weight','400',0,''),(171980,55027,'116987','furniture-mobile','padding-top','20',0,''),(171981,55027,'116987','furniture-mobile','padding-bottom','0',0,''),(171982,55027,'116987','furniture-mobile','font-size','12',0,''),(171983,55028,'116988','furniture-mobile','block_type','2',0,''),(171984,55028,'116988','furniture-mobile','font-weight','normal',0,''),(171985,55028,'116988','furniture-mobile','padding-bottom','20',0,''),(171986,55029,'116989','furniture-mobile','font-weight','400',0,''),(171987,55029,'116989','furniture-mobile','padding-top','20',0,''),(171989,55030,'116990','furniture-mobile','block_type','11',0,''),(171990,55030,'116990','furniture-mobile','font-weight','normal',0,''),(171991,55031,'116991','furniture-mobile','text','<p>Web:</p>',1,''),(171992,55031,'116991','furniture-mobile','font-weight','normal',0,''),(171993,55031,'116991','furniture-mobile','text-align','right',0,''),(171994,55032,'116992','furniture-mobile','font-weight','normal',0,''),(171995,55032,'116992','furniture-mobile','text-align','right',0,''),(171996,55033,'116993','furniture-mobile','block_type','11',0,''),(171997,55033,'116993','furniture-mobile','font-weight','normal',0,''),(171998,55034,'116994','furniture-mobile','text','<p>Phone:</p>',1,''),(171999,55034,'116994','furniture-mobile','font-weight','normal',0,''),(172000,55034,'116994','furniture-mobile','text-align','right',0,''),(172001,55035,'116995','furniture-mobile','font-weight','normal',0,''),(172002,55035,'116995','furniture-mobile','text-align','right',0,''),(172003,55036,'116996','furniture-mobile','block_type','11',0,''),(172004,55036,'116996','furniture-mobile','font-weight','normal',0,''),(172005,55037,'116997','furniture-mobile','text','<p>Email:</p>',1,''),(172006,55037,'116997','furniture-mobile','font-weight','normal',0,''),(172007,55037,'116997','furniture-mobile','text-align','right',0,''),(172008,55038,'116998','furniture-mobile','font-weight','normal',0,''),(172009,55038,'116998','furniture-mobile','text-align','right',0,''),(172010,55039,'116999','furniture-mobile','block_type','1',0,''),(172011,55040,'117000','furniture-mobile','font-weight','normal',0,''),(172012,55040,'117000','furniture-mobile','text-align','right',0,''),(172013,55040,'117000','furniture-mobile','padding-bottom','10',0,''),(172014,55040,'117000','furniture-mobile','address_spacer',',',0,''),(172015,55040,'117000','furniture-mobile','font-size','12',0,''),(172016,55041,'117001','furniture-mobile','block_type','5',0,''),(172017,55041,'117001','furniture-mobile','font-weight','normal',0,''),(172018,55041,'117001','furniture-mobile','border-bottom-width','1',0,''),(172019,55041,'117001','furniture-mobile','border-bottom-color','$border-color-4',0,''),(172020,55041,'117001','furniture-mobile','border-top-width','1',0,''),(172021,55041,'117001','furniture-mobile','border-top-color','$border-color-4',0,''),(172022,55041,'117001','furniture-mobile','border-left-color','$border-color-4',0,''),(172023,55041,'117001','furniture-mobile','border-left-width','1',0,''),(172024,55042,'117002','furniture-mobile','block_type','1',0,''),(172025,55042,'117002','furniture-mobile','font-weight','normal',0,''),(172026,55042,'117002','furniture-mobile','padding-top','10',0,''),(172027,55042,'117002','furniture-mobile','padding-left','10',0,''),(172028,55042,'117002','furniture-mobile','padding-right','10',0,''),(172029,55043,'117003','furniture-mobile','font-weight','400',0,''),(172030,55043,'117003','furniture-mobile','line-height','120',0,''),(172031,55043,'117003','furniture-mobile','line_height_measure','%',0,''),(172032,55043,'117003','furniture-mobile','font-size','12',0,''),(172033,55044,'117004','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(172034,55044,'117004','furniture-mobile','font-size','14',0,''),(172035,55044,'117004','furniture-mobile','font-weight','bold',0,''),(172036,55044,'117004','furniture-mobile','padding-bottom','10',0,''),(172037,55045,'117005','furniture-mobile','block_type','1',0,''),(172038,55045,'117005','furniture-mobile','background-color','$background-6',0,''),(172039,55045,'117005','furniture-mobile','padding-top','20',0,''),(172040,55045,'117005','furniture-mobile','padding-left','10',0,''),(172041,55045,'117005','furniture-mobile','padding-right','10',0,''),(172042,55045,'117005','furniture-mobile','padding-bottom','20',0,''),(172043,55045,'117005','furniture-mobile','font-size','14',0,''),(172044,55046,'117006','furniture-mobile','block_type','4',0,''),(172045,55046,'117006','furniture-mobile','font-weight','normal',0,''),(172046,55046,'117006','furniture-mobile','border-top-width','1',0,''),(172047,55046,'117006','furniture-mobile','border-top-color','$border-color-4',0,''),(172048,55046,'117006','furniture-mobile','border-left-width','1',0,''),(172049,55046,'117006','furniture-mobile','border-left-color','$border-color-4',0,''),(172050,55046,'117006','furniture-mobile','border-right-width','1',0,''),(172051,55046,'117006','furniture-mobile','border-right-color','$border-color-4',0,''),(172052,55046,'117006','furniture-mobile','border-bottom-width','1',0,''),(172053,55046,'117006','furniture-mobile','border-bottom-color','$border-color-4',0,''),(172054,55047,'117007','furniture-mobile','block_type','2',0,''),(172055,55047,'117007','furniture-mobile','font-weight','normal',0,''),(172056,55047,'117007','furniture-mobile','border-right-width','1',0,''),(172057,55047,'117007','furniture-mobile','border-right-color','$border-color-4',0,''),(172058,55048,'117008','furniture-mobile','block_type','1',0,''),(172059,55048,'117008','furniture-mobile','font-weight','400',0,''),(172060,55048,'117008','furniture-mobile','background-color','$background-6',0,''),(172061,55048,'117008','furniture-mobile','padding-top','10',0,''),(172062,55048,'117008','furniture-mobile','padding-left','10',0,''),(172063,55048,'117008','furniture-mobile','padding-right','10',0,''),(172064,55048,'117008','furniture-mobile','padding-bottom','30',0,''),(172065,55049,'117009','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(172066,55049,'117009','furniture-mobile','font-size','14',0,''),(172067,55049,'117009','furniture-mobile','font-weight','bold',0,''),(172068,55050,'117010','furniture-mobile','font-size','12',0,''),(172069,55051,'117011','furniture-mobile','block_type','1',0,''),(172070,55051,'117011','furniture-mobile','font-weight','normal',0,''),(172071,55051,'117011','furniture-mobile','padding-top','10',0,''),(172072,55051,'117011','furniture-mobile','padding-left','10',0,''),(172073,55051,'117011','furniture-mobile','padding-right','10',0,''),(172074,55051,'117011','furniture-mobile','padding-bottom','10',0,''),(172075,55052,'117012','furniture-mobile','font-weight','normal',0,''),(172076,55053,'117013','furniture-mobile','text','<p>CUSTOMER:</p>',1,''),(172077,55053,'117013','furniture-mobile','font-size','13',0,''),(172078,55053,'117013','furniture-mobile','font-weight','bold',0,''),(172079,55054,'117014','furniture-mobile','text','<p>PHONE NUMBER:</p>',1,''),(172080,55054,'117014','furniture-mobile','font-size','14',0,''),(172081,55054,'117014','furniture-mobile','font-weight','bold',0,''),(172082,55054,'117014','furniture-mobile','padding-top','10',0,''),(172083,55055,'117015','furniture-mobile','font-weight','normal',0,''),(172084,55057,'117017','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(172085,55057,'117017','furniture-mobile','font-weight','bold',0,''),(172086,55057,'117017','furniture-mobile','font-size','14',0,''),(172087,55057,'117017','furniture-mobile','padding-top','10',0,''),(172088,55058,'117018','furniture-mobile','block_type','2',0,''),(172089,55058,'117018','furniture-mobile','font-weight','normal',0,''),(172090,55058,'117018','furniture-mobile','border-top-width','1',0,''),(172091,55058,'117018','furniture-mobile','border-top-color','$border-color-4',0,''),(172092,55058,'117018','furniture-mobile','border-right-width','1',0,''),(172093,55058,'117018','furniture-mobile','border-right-color','$border-color-4',0,''),(172094,55059,'117019','furniture-mobile','block_type','1',0,''),(172095,55059,'117019','furniture-mobile','font-weight','normal',0,''),(172096,55059,'117019','furniture-mobile','padding-top','10',0,''),(172097,55059,'117019','furniture-mobile','padding-left','10',0,''),(172098,55059,'117019','furniture-mobile','padding-right','10',0,''),(172099,55059,'117019','furniture-mobile','padding-bottom','10',0,''),(172100,55059,'117019','furniture-mobile','border-right-width','1',0,''),(172101,55059,'117019','furniture-mobile','border-right-color','$border-color-4',0,''),(172102,55061,'117021','furniture-mobile','text','<p>Shipping via</p>',1,''),(172103,55061,'117021','furniture-mobile','font-weight','bold',0,''),(172104,55061,'117021','furniture-mobile','font-size','14',0,''),(172105,55062,'117022','furniture-mobile','block_type','1',0,''),(172106,55062,'117022','furniture-mobile','font-weight','normal',0,''),(172107,55062,'117022','furniture-mobile','padding-top','10',0,''),(172108,55062,'117022','furniture-mobile','padding-left','10',0,''),(172109,55062,'117022','furniture-mobile','padding-right','10',0,''),(172110,55062,'117022','furniture-mobile','padding-bottom','10',0,''),(172111,55063,'117023','furniture-mobile','text','<p>Shipping service</p>',1,''),(172112,55063,'117023','furniture-mobile','font-weight','bold',0,''),(172113,55063,'117023','furniture-mobile','font-size','14',0,''),(172114,55065,'117025','furniture-mobile','font-size','14',0,''),(172115,55065,'117025','furniture-mobile','font-weight','bold',0,''),(172116,55065,'117025','furniture-mobile','text-align','center',0,''),(172117,55065,'117025','furniture-mobile','padding-bottom','10',0,''),(172118,55065,'117025','furniture-mobile','padding-top','10',0,''),(172119,55066,'117026','furniture-mobile','text','<p>Payment date:</p>',1,''),(172120,55066,'117026','furniture-mobile','font-weight','bold',0,''),(172121,55066,'117026','furniture-mobile','text-align','center',0,''),(172122,55066,'117026','furniture-mobile','font-size','12',0,''),(172123,55067,'117027','furniture-mobile','font-weight','normal',0,''),(172124,55067,'117027','furniture-mobile','text-align','center',0,''),(172125,55067,'117027','furniture-mobile','padding-bottom','10',0,''),(172130,55069,'117034','furniture-mobile','text-align','center',0,''),(172131,55069,'117034','furniture-mobile','padding-top','10',0,''),(172132,55070,'1639155816.3893','furniture-mobile','block_type','1',0,''),(172133,55071,'117028','furniture-mobile','padding-top','30',0,''),(172134,55071,'117028','furniture-mobile','padding-bottom','30',0,''),(172135,55075,'117032','furniture-mobile','col_in_row','4',0,''),(172136,55075,'117032','furniture-mobile','listing_type','productListing',0,''),(172137,55075,'117032','furniture-mobile','view_as','carousel',0,''),(172138,55075,'117032','furniture-mobile','col_in_row','3',0,'2885'),(172139,55075,'117032','furniture-mobile','col_in_row','2',0,'2876'),(172140,55075,'117032','furniture-mobile','col_in_row','1',0,'2906'),(172141,55077,'1639485067.5512','furniture-mobile','padding-top','30',0,''),(172142,55077,'1639485067.5512','furniture-mobile','padding-bottom','30',0,''),(172143,55079,'1639154415.2739','furniture-mobile','block_type','1',0,''),(172144,55081,'117036','furniture-mobile','heading_type','h1',0,''),(172145,55082,'1639419797.9718','furniture-mobile','page_id','4',0,''),(172146,55082,'1639419797.9718','furniture-mobile','padding-top','30',0,''),(172147,55082,'1639419797.9718','furniture-mobile','padding-bottom','30',0,''),(172148,55085,'117039','furniture-mobile','text-align','center',0,''),(172149,55085,'117039','furniture-mobile','padding-top','10',0,''),(172150,55090,'117044','furniture-mobile','block_type','1',0,''),(172151,55091,'117045','furniture-mobile','block_type','1',0,''),(172152,55091,'117045','furniture-mobile','max-width','800',0,''),(172153,55091,'117045','furniture-mobile','margin','0 auto',0,''),(172154,55091,'117045','furniture-mobile','background-color','$background-7',0,''),(172155,55092,'117046','furniture-mobile','color','$color-font-8',0,''),(172156,55092,'117046','furniture-mobile','font-size','12',0,''),(172157,55092,'117046','furniture-mobile','padding-top','20',0,''),(172158,55092,'117046','furniture-mobile','padding-bottom','20',0,''),(172159,55092,'117046','furniture-mobile','border-top-width','1',0,''),(172160,55092,'117046','furniture-mobile','border-top-color','$border-color-4',0,''),(172161,55093,'117047','furniture-mobile','font-weight','normal',0,''),(172162,55093,'117047','furniture-mobile','padding-top','20',0,''),(172163,55093,'117047','furniture-mobile','padding-left','10',0,''),(172164,55093,'117047','furniture-mobile','padding-right','10',0,''),(172165,55093,'117047','furniture-mobile','padding-bottom','20',0,''),(172166,55093,'117047','furniture-mobile','color','$color-font-8',0,''),(172167,55093,'117047','furniture-mobile','font-size','14',0,''),(172168,55094,'117048','furniture-mobile','block_type','7',0,''),(172169,55094,'117048','furniture-mobile','font-weight','normal',0,''),(172170,55094,'117048','furniture-mobile','background-color','$background-2',0,''),(172171,55094,'117048','furniture-mobile','padding-top','5',0,''),(172172,55094,'117048','furniture-mobile','padding-left','10',0,''),(172173,55094,'117048','furniture-mobile','padding-right','10',0,''),(172174,55094,'117048','furniture-mobile','padding-bottom','5',0,''),(172175,55095,'117049','furniture-mobile','color','$color-font-1',0,''),(172176,55095,'117049','furniture-mobile','font-size','14',0,''),(172177,55095,'117049','furniture-mobile','font-weight','normal',0,''),(172178,55096,'117050','furniture-mobile','font-weight','normal',0,''),(172179,55096,'117050','furniture-mobile','text-align','right',0,''),(172180,55096,'117050','furniture-mobile','color','$color-font-1',0,''),(172181,55096,'117050','furniture-mobile','font-size','12',0,''),(172182,55097,'117051','furniture-mobile','font-weight','normal',0,''),(172183,55097,'117051','furniture-mobile','padding-bottom','10',0,''),(172184,55097,'117051','furniture-mobile','padding-top','10',0,''),(172185,55097,'117051','furniture-mobile','logo_from','theme',0,''),(172186,55097,'117051','furniture-mobile','padding-left','20',0,''),(172187,55097,'117051','furniture-mobile','background-color','$background-1',0,''),(172188,55098,'117052','furniture-mobile','block_type','1',0,''),(172189,55099,'117053','furniture-mobile','block_type','1',0,''),(172190,55099,'117053','furniture-mobile','max-width','800',0,''),(172191,55099,'117053','furniture-mobile','margin','0 auto',0,''),(172192,55099,'117053','furniture-mobile','background-color','$background-7',0,''),(172193,55100,'117054','furniture-mobile','color','$color-font-8',0,''),(172194,55100,'117054','furniture-mobile','font-size','12',0,''),(172195,55100,'117054','furniture-mobile','padding-top','20',0,''),(172196,55100,'117054','furniture-mobile','padding-bottom','20',0,''),(172197,55100,'117054','furniture-mobile','border-top-width','1',0,''),(172198,55100,'117054','furniture-mobile','border-top-color','$border-color-4',0,''),(172199,55101,'117055','furniture-mobile','font-weight','normal',0,''),(172200,55101,'117055','furniture-mobile','padding-bottom','10',0,''),(172201,55101,'117055','furniture-mobile','background-color','$background-2',0,''),(172202,55101,'117055','furniture-mobile','logo','themes/furniture-mobile/img/logo-white-1.png',1,''),(172203,55101,'117055','furniture-mobile','padding-left','20',0,''),(172204,55101,'117055','furniture-mobile','padding-top','10',0,''),(172205,55102,'117056','furniture-mobile','font-weight','normal',0,''),(172206,55102,'117056','furniture-mobile','padding-top','20',0,''),(172207,55102,'117056','furniture-mobile','padding-left','10',0,''),(172208,55102,'117056','furniture-mobile','padding-right','10',0,''),(172209,55102,'117056','furniture-mobile','padding-bottom','20',0,''),(172210,55102,'117056','furniture-mobile','color','$color-font-8',0,''),(172211,55102,'117056','furniture-mobile','font-size','14',0,''),(172212,55103,'117057','furniture-mobile','block_type','7',0,''),(172213,55103,'117057','furniture-mobile','font-weight','normal',0,''),(172214,55103,'117057','furniture-mobile','background-color','$background-2',0,''),(172215,55103,'117057','furniture-mobile','padding-top','5',0,''),(172216,55103,'117057','furniture-mobile','padding-left','10',0,''),(172217,55103,'117057','furniture-mobile','padding-right','10',0,''),(172218,55103,'117057','furniture-mobile','padding-bottom','5',0,''),(172219,55104,'117058','furniture-mobile','color','$color-font-1',0,''),(172220,55104,'117058','furniture-mobile','font-size','15',0,''),(172221,55104,'117058','furniture-mobile','font-weight','700',0,''),(172222,55105,'117059','furniture-mobile','font-weight','normal',0,''),(172223,55105,'117059','furniture-mobile','text-align','right',0,''),(172224,55105,'117059','furniture-mobile','color','$color-font-9',0,''),(172225,55105,'117059','furniture-mobile','font-size','12',0,''),(172226,55106,'117060','furniture-mobile','block_type','1',0,''),(172227,55106,'117060','furniture-mobile','background-color','$background-6',0,''),(172228,55107,'117061','furniture-mobile','block_type','1',0,''),(172229,55107,'117061','furniture-mobile','max-width','800',0,''),(172230,55107,'117061','furniture-mobile','margin','0 auto',0,''),(172231,55108,'117062','furniture-mobile','block_type','1',0,''),(172232,55108,'117062','furniture-mobile','background-color','$background-7',0,''),(172233,55108,'117062','furniture-mobile','padding-top','20',0,''),(172234,55108,'117062','furniture-mobile','padding-left','20',0,''),(172235,55108,'117062','furniture-mobile','padding-right','20',0,''),(172236,55108,'117062','furniture-mobile','padding-bottom','20',0,''),(172237,55109,'117063','furniture-mobile','font-weight','normal',0,''),(172238,55109,'117063','furniture-mobile','padding-top','20',0,''),(172239,55109,'117063','furniture-mobile','padding-bottom','20',0,''),(172240,55109,'117063','furniture-mobile','color','$color-font-8',0,''),(172241,55109,'117063','furniture-mobile','font-size','14',0,''),(172242,55110,'117064','furniture-mobile','block_type','7',0,''),(172243,55110,'117064','furniture-mobile','font-weight','normal',0,''),(172244,55110,'117064','furniture-mobile','padding-left','10',0,''),(172245,55110,'117064','furniture-mobile','padding-right','10',0,''),(172246,55110,'117064','furniture-mobile','padding-bottom','15',0,''),(172247,55110,'117064','furniture-mobile','border-bottom-width','1',0,''),(172248,55110,'117064','furniture-mobile','border-bottom-color','$border-color-4',0,''),(172249,55111,'117065','furniture-mobile','color','$color-font-8',0,''),(172250,55111,'117065','furniture-mobile','font-size','14',0,''),(172251,55111,'117065','furniture-mobile','font-weight','700',0,''),(172252,55112,'117066','furniture-mobile','font-weight','normal',0,''),(172253,55112,'117066','furniture-mobile','text-align','right',0,''),(172254,55112,'117066','furniture-mobile','color','$color-font-9',0,''),(172255,55112,'117066','furniture-mobile','font-size','11',0,''),(172256,55112,'117066','furniture-mobile','text-transform','uppercase',0,''),(172257,55113,'117067','furniture-mobile','color','$color-font-9',0,''),(172258,55113,'117067','furniture-mobile','font-size','12',0,''),(172259,55113,'117067','furniture-mobile','padding-top','20',0,''),(172260,55113,'117067','furniture-mobile','padding-bottom','20',0,''),(172261,55113,'117067','furniture-mobile','text-align','center',0,''),(172262,55114,'117068','furniture-mobile','font-weight','normal',0,''),(172263,55114,'117068','furniture-mobile','padding-bottom','10',0,''),(172264,55114,'117068','furniture-mobile','padding-top','10',0,''),(172265,55114,'117068','furniture-mobile','text-align','center',0,''),(172266,55114,'117068','furniture-mobile','logo_from','theme',0,''),(172267,55115,'117069','furniture-mobile','block_type','1',0,''),(172268,55115,'117069','furniture-mobile','background-color','$background-6',0,''),(172269,55115,'117069','furniture-mobile','padding-top','20',0,''),(172270,55115,'117069','furniture-mobile','padding-bottom','20',0,''),(172271,55116,'117070','furniture-mobile','block_type','1',0,''),(172272,55116,'117070','furniture-mobile','max-width','800',0,''),(172273,55116,'117070','furniture-mobile','margin','0 auto',0,''),(172274,55117,'117071','furniture-mobile','color','$color-font-9',0,''),(172275,55117,'117071','furniture-mobile','font-size','12',0,''),(172276,55117,'117071','furniture-mobile','padding-top','20',0,''),(172277,55117,'117071','furniture-mobile','padding-bottom','20',0,''),(172278,55117,'117071','furniture-mobile','text-align','left',0,''),(172279,55118,'117072','furniture-mobile','block_type','1',0,''),(172280,55118,'117072','furniture-mobile','background-color','$background-7',0,''),(172281,55118,'117072','furniture-mobile','padding-top','20',0,''),(172282,55118,'117072','furniture-mobile','padding-left','20',0,''),(172283,55118,'117072','furniture-mobile','padding-right','20',0,''),(172284,55118,'117072','furniture-mobile','padding-bottom','20',0,''),(172285,55118,'117072','furniture-mobile','border-top-width','1',0,''),(172286,55118,'117072','furniture-mobile','border-left-width','1',0,''),(172287,55118,'117072','furniture-mobile','border-right-width','1',0,''),(172288,55118,'117072','furniture-mobile','border-bottom-width','1',0,''),(172289,55118,'117072','furniture-mobile','border-top-color','$border-color-4',0,''),(172290,55118,'117072','furniture-mobile','border-left-color','$border-color-4',0,''),(172291,55118,'117072','furniture-mobile','border-bottom-color','$border-color-4',0,''),(172292,55118,'117072','furniture-mobile','border-right-color','$border-color-4',0,''),(172293,55119,'117073','furniture-mobile','block_type','2',0,''),(172294,55120,'117074','furniture-mobile','font-weight','normal',0,''),(172295,55120,'117074','furniture-mobile','padding-bottom','10',0,''),(172296,55120,'117074','furniture-mobile','padding-top','10',0,''),(172297,55120,'117074','furniture-mobile','logo_from','theme',0,''),(172298,55121,'117075','furniture-mobile','font-weight','normal',0,''),(172299,55121,'117075','furniture-mobile','text-align','right',0,''),(172300,55121,'117075','furniture-mobile','color','$color-font-9',0,''),(172301,55121,'117075','furniture-mobile','font-size','11',0,''),(172302,55121,'117075','furniture-mobile','text-transform','uppercase',0,''),(172303,55122,'117076','furniture-mobile','color','$color-font-8',0,''),(172304,55122,'117076','furniture-mobile','font-size','14',0,''),(172305,55122,'117076','furniture-mobile','font-weight','700',0,''),(172306,55122,'117076','furniture-mobile','text-align','right',0,''),(172307,55123,'117077','furniture-mobile','font-weight','normal',0,''),(172308,55123,'117077','furniture-mobile','padding-top','20',0,''),(172309,55123,'117077','furniture-mobile','padding-bottom','20',0,''),(172310,55123,'117077','furniture-mobile','color','$color-font-8',0,''),(172311,55123,'117077','furniture-mobile','font-size','14',0,''),(172312,55124,'121029','furniture-mobile','block_type','1',0,''),(172313,55127,'121032','furniture-mobile','margin-bottom','30',0,''),(172314,55128,'121025','furniture-mobile','block_type','1',0,''),(172315,55129,'121026','furniture-mobile','text','<h1>CATALOGUE</h1>',0,''),(172316,55131,'117078','furniture-mobile','block_type','1',0,''),(172317,55131,'117078','furniture-mobile','font-weight','normal',0,''),(172318,55131,'117078','furniture-mobile','padding-top','20',0,''),(172319,55131,'117078','furniture-mobile','background-color','$background-2',0,''),(172320,55131,'117078','furniture-mobile','style_class','preFooter',0,''),(172321,55131,'117078','furniture-mobile','padding-bottom','25',0,''),(172322,55132,'120866','furniture-mobile','block_type','6',0,''),(172323,55132,'120866','furniture-mobile','schema','6-3',0,'2876'),(172324,55133,'117091','furniture-mobile','view_item','data_format',0,''),(172325,55133,'117091','furniture-mobile','address_spacer',',<span> </span>',0,''),(172326,55133,'117091','furniture-mobile','color','$color-font-3',0,''),(172327,55133,'117091','furniture-mobile','data_format_content','<div>##TITLE##</div><div>Location: ##POST_ADDRESS##</div><div>Phone number: ##TELEPHONE##</div>',0,''),(172328,55133,'117091','furniture-mobile','margin-top','20',0,'2876'),(172329,55134,'120868','furniture-mobile','logo_from','theme',0,''),(172330,55134,'120868','furniture-mobile','margin-bottom','25',0,''),(172331,55134,'120868','furniture-mobile','padding-right','20',0,''),(172332,55134,'120868','furniture-mobile','display_none','1',0,'2876'),(172333,55135,'120871','furniture-mobile','block_type','1',0,''),(172334,55135,'120871','furniture-mobile','padding-left','15',0,''),(172335,55135,'120871','furniture-mobile','padding-right','15',0,''),(172336,55135,'120871','furniture-mobile','border-left-width','1',0,''),(172337,55135,'120871','furniture-mobile','border-right-width','1',0,''),(172338,55135,'120871','furniture-mobile','border-left-color','$border-color-2',0,''),(172339,55135,'120871','furniture-mobile','border-right-color','$border-color-2',0,''),(172340,55135,'120871','furniture-mobile','padding-left','0',0,'2876'),(172341,55135,'120871','furniture-mobile','padding-right','0',0,'2876'),(172342,55135,'120871','furniture-mobile','border-left-width','0',0,'2876'),(172343,55135,'120871','furniture-mobile','border-right-width','0',0,'2876'),(172344,55136,'117085','furniture-mobile','class','menu-style-2',0,''),(172345,55136,'117085','furniture-mobile','type','builder',0,''),(172346,55136,'117085','furniture-mobile','style','3',0,''),(172347,55136,'117085','furniture-mobile','lev2_vis','click',0,'2885'),(172348,55137,'117093','furniture-mobile','block_type','1',0,''),(172349,55137,'117093','furniture-mobile','font-weight','400',0,''),(172350,55137,'117093','furniture-mobile','padding-top','20',0,''),(172351,55137,'117093','furniture-mobile','padding-bottom','20',0,''),(172352,55137,'117093','furniture-mobile','schema','2-2',0,''),(172353,55137,'117093','furniture-mobile','schema','2-3',0,'2885'),(172354,55137,'117093','furniture-mobile','background-color','$background-1',0,''),(172355,55138,'117094','furniture-mobile','color','$color-font-3',0,''),(172356,55138,'117094','furniture-mobile','text-align','center',0,''),(172357,55138,'117094','furniture-mobile','font-size','14',0,''),(172358,55139,'117096','furniture-mobile','block_type','5',0,''),(172359,55140,'117097','furniture-mobile','text','##TEXT_LANGUAGE##',0,''),(172360,55142,'117099','furniture-mobile','block_type','5',0,''),(172361,55143,'117100','furniture-mobile','text','##TEXT_CURRENCY##',0,''),(172362,55145,'117102','furniture-mobile','block_type','1',0,''),(172363,55145,'117102','furniture-mobile','font-weight','normal',0,''),(172364,55146,'117103','furniture-mobile','block_type','2',0,''),(172365,55146,'117103','furniture-mobile','font-weight','normal',0,''),(172366,55146,'117103','furniture-mobile','padding-bottom','20',0,''),(172367,55147,'117104','furniture-mobile','block_type','1',0,''),(172368,55147,'117104','furniture-mobile','margin-right','20',0,''),(172369,55150,'117107','furniture-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(172370,55150,'117107','furniture-mobile','font-weight','normal',0,''),(172371,55150,'117107','furniture-mobile','padding-bottom','20',0,''),(172372,55152,'117109','furniture-mobile','block_type','1',0,''),(172373,55152,'117109','furniture-mobile','font-weight','normal',0,''),(172374,55152,'117109','furniture-mobile','style_class','gift-card-view',0,''),(172375,55152,'117109','furniture-mobile','text-align','center',0,''),(172376,55152,'117109','furniture-mobile','padding-bottom','20',0,''),(172377,55152,'117109','furniture-mobile','background-color','$background-2',0,''),(172378,55152,'117109','furniture-mobile','padding-left','20',0,''),(172379,55152,'117109','furniture-mobile','padding-right','20',0,''),(172380,55152,'117109','furniture-mobile','color','$color-font-3',0,''),(172381,55153,'117110','furniture-mobile','block_type','1',0,''),(172382,55153,'117110','furniture-mobile','font-weight','normal',0,''),(172383,55153,'117110','furniture-mobile','padding-top','10',0,''),(172384,55154,'117111','furniture-mobile','font-size','12',0,''),(172385,55154,'117111','furniture-mobile','font-weight','bold',0,''),(172386,55154,'117111','furniture-mobile','text-align','center',0,''),(172387,55154,'117111','furniture-mobile','style_class','email',0,''),(172388,55155,'117112','furniture-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(172389,55155,'117112','furniture-mobile','font-weight','normal',0,''),(172390,55155,'117112','furniture-mobile','text-align','center',0,''),(172391,55155,'117112','furniture-mobile','font-size','12',0,''),(172392,55155,'117112','furniture-mobile','padding-top','10',0,''),(172393,55155,'117112','furniture-mobile','padding-bottom','5',0,''),(172394,55155,'117112','furniture-mobile','border-top-width','1',0,''),(172395,55155,'117112','furniture-mobile','border-top-color','$border-color-8',0,''),(172396,55156,'117113','furniture-mobile','font-size','12',0,''),(172397,55156,'117113','furniture-mobile','font-weight','bold',0,''),(172398,55156,'117113','furniture-mobile','text-align','center',0,''),(172399,55156,'117113','furniture-mobile','style_class','phone',0,''),(172400,55156,'117113','furniture-mobile','padding-bottom','5',0,''),(172401,55157,'117114','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(172402,55157,'117114','furniture-mobile','font-weight','normal',0,''),(172403,55157,'117114','furniture-mobile','text-align','center',0,''),(172404,55157,'117114','furniture-mobile','padding-top','20',0,''),(172405,55157,'117114','furniture-mobile','padding-bottom','10',0,''),(172406,55157,'117114','furniture-mobile','style_class','question-ico',0,''),(172407,55157,'117114','furniture-mobile','border-top-width','1',0,''),(172408,55157,'117114','furniture-mobile','border-top-color','$border-color-8',0,''),(172409,55157,'117114','furniture-mobile','font-size','18',0,''),(172410,55158,'117115','furniture-mobile','text','<p>osCommerce</p>\n',1,''),(172411,55158,'117115','furniture-mobile','font-family','$font-1',0,''),(172412,55158,'117115','furniture-mobile','font-size','24',0,''),(172413,55158,'117115','furniture-mobile','font-weight','normal',0,''),(172414,55158,'117115','furniture-mobile','text-align','center',0,''),(172415,55158,'117115','furniture-mobile','padding-top','10',0,''),(172416,55158,'117115','furniture-mobile','padding-bottom','20',0,''),(172417,55159,'117116','furniture-mobile','block_type','4',0,''),(172418,55159,'117116','furniture-mobile','color','$color-font-7',0,''),(172419,55159,'117116','furniture-mobile','font-size','30',0,''),(172420,55159,'117116','furniture-mobile','font-weight','normal',0,''),(172421,55159,'117116','furniture-mobile','background-color','$background-9',0,''),(172422,55159,'117116','furniture-mobile','padding-top','5',0,''),(172423,55159,'117116','furniture-mobile','padding-left','10',0,''),(172424,55159,'117116','furniture-mobile','padding-right','10',0,''),(172425,55159,'117116','furniture-mobile','padding-bottom','5',0,''),(172426,55160,'117117','furniture-mobile','text','<p>Your code is:</p>',1,''),(172427,55160,'117117','furniture-mobile','font-weight','normal',0,''),(172428,55162,'117119','furniture-mobile','font-weight','normal',0,''),(172429,55162,'117119','furniture-mobile','text-align','center',0,''),(172430,55162,'117119','furniture-mobile','padding-bottom','20',0,''),(172431,55163,'117120','furniture-mobile','font-size','60',0,''),(172432,55163,'117120','furniture-mobile','font-weight','bold',0,''),(172433,55163,'117120','furniture-mobile','text-align','center',0,''),(172434,55163,'117120','furniture-mobile','line-height','100',0,''),(172435,55163,'117120','furniture-mobile','padding-bottom','20',0,''),(172436,55163,'117120','furniture-mobile','line_height_measure','px',0,''),(172437,55164,'117121','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(172438,55164,'117121','furniture-mobile','font-size','18',0,''),(172439,55164,'117121','furniture-mobile','font-weight','normal',0,''),(172440,55164,'117121','furniture-mobile','text-align','center',0,''),(172441,55164,'117121','furniture-mobile','padding-top','20',0,''),(172442,55164,'117121','furniture-mobile','padding-bottom','10',0,''),(172443,55164,'117121','furniture-mobile','border-top-width','1',0,''),(172444,55164,'117121','furniture-mobile','border-top-color','$border-color-8',0,''),(172445,55165,'117123','furniture-mobile','logo','themes/furniture-mobile/img/Logo-1.jpg',1,''),(172446,55165,'117123','furniture-mobile','logo_from','theme',0,''),(172447,55165,'117123','furniture-mobile','padding-top','20',0,''),(172448,55165,'117123','furniture-mobile','text-align','center',0,''),(172449,55166,'117124','furniture-mobile','text','<p>GIFT CARD</p>',1,''),(172450,55166,'117124','furniture-mobile','font-size','30',0,''),(172451,55166,'117124','furniture-mobile','font-weight','normal',0,''),(172452,55166,'117124','furniture-mobile','border-top-width','1',0,''),(172453,55166,'117124','furniture-mobile','border-top-color','$border-color-8',0,''),(172454,55166,'117124','furniture-mobile','style_class','gift-ico',0,''),(172455,55166,'117124','furniture-mobile','text-align','center',0,''),(172456,55166,'117124','furniture-mobile','padding-top','15',0,''),(172457,55167,'117125','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(172458,55167,'117125','furniture-mobile','font-weight','normal',0,''),(172459,55167,'117125','furniture-mobile','text-align','center',0,''),(172460,55167,'117125','furniture-mobile','padding-bottom','10',0,''),(172461,55167,'117125','furniture-mobile','font-size','14',0,''),(172462,55168,'117126','furniture-mobile','block_type','1',0,''),(172463,55168,'117126','furniture-mobile','font-weight','normal',0,''),(172464,55168,'117126','furniture-mobile','style_class','gift-card-view',0,''),(172465,55168,'117126','furniture-mobile','text-align','center',0,''),(172466,55168,'117126','furniture-mobile','padding-bottom','20',0,''),(172467,55168,'117126','furniture-mobile','background-color','$background-10',0,''),(172468,55168,'117126','furniture-mobile','padding-left','20',0,''),(172469,55168,'117126','furniture-mobile','padding-right','20',0,''),(172470,55168,'117126','furniture-mobile','color','$color-font-3',0,''),(172471,55169,'117127','furniture-mobile','font-size','60',0,''),(172472,55169,'117127','furniture-mobile','font-weight','bold',0,''),(172473,55169,'117127','furniture-mobile','text-align','center',0,''),(172474,55169,'117127','furniture-mobile','line-height','100',0,''),(172475,55169,'117127','furniture-mobile','padding-bottom','20',0,''),(172476,55169,'117127','furniture-mobile','line_height_measure','px',0,''),(172477,55170,'117128','furniture-mobile','block_type','4',0,''),(172478,55170,'117128','furniture-mobile','color','$color-font-1',0,''),(172479,55170,'117128','furniture-mobile','font-size','30',0,''),(172480,55170,'117128','furniture-mobile','font-weight','normal',0,''),(172481,55170,'117128','furniture-mobile','background-color','$background-5',0,''),(172482,55170,'117128','furniture-mobile','padding-top','5',0,''),(172483,55170,'117128','furniture-mobile','padding-left','10',0,''),(172484,55170,'117128','furniture-mobile','padding-right','10',0,''),(172485,55170,'117128','furniture-mobile','padding-bottom','5',0,''),(172486,55171,'117129','furniture-mobile','text','<p>Your code is:</p>',1,''),(172487,55171,'117129','furniture-mobile','font-weight','normal',0,''),(172488,55173,'117131','furniture-mobile','block_type','1',0,''),(172489,55173,'117131','furniture-mobile','font-weight','normal',0,''),(172490,55173,'117131','furniture-mobile','padding-top','10',0,''),(172491,55174,'117132','furniture-mobile','font-size','12',0,''),(172492,55174,'117132','furniture-mobile','font-weight','bold',0,''),(172493,55174,'117132','furniture-mobile','text-align','center',0,''),(172494,55174,'117132','furniture-mobile','style_class','email',0,''),(172495,55175,'117133','furniture-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(172496,55175,'117133','furniture-mobile','font-weight','normal',0,''),(172497,55175,'117133','furniture-mobile','text-align','center',0,''),(172498,55175,'117133','furniture-mobile','font-size','12',0,''),(172499,55175,'117133','furniture-mobile','padding-top','10',0,''),(172500,55175,'117133','furniture-mobile','padding-bottom','5',0,''),(172501,55175,'117133','furniture-mobile','border-top-width','1',0,''),(172502,55175,'117133','furniture-mobile','border-top-color','$border-color-8',0,''),(172503,55176,'117134','furniture-mobile','font-size','12',0,''),(172504,55176,'117134','furniture-mobile','font-weight','bold',0,''),(172505,55176,'117134','furniture-mobile','text-align','center',0,''),(172506,55176,'117134','furniture-mobile','style_class','phone',0,''),(172507,55176,'117134','furniture-mobile','padding-bottom','5',0,''),(172508,55177,'117135','furniture-mobile','font-weight','normal',0,''),(172509,55177,'117135','furniture-mobile','text-align','center',0,''),(172510,55177,'117135','furniture-mobile','padding-bottom','20',0,''),(172511,55178,'117136','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(172512,55178,'117136','furniture-mobile','font-size','18',0,''),(172513,55178,'117136','furniture-mobile','font-weight','normal',0,''),(172514,55178,'117136','furniture-mobile','text-align','center',0,''),(172515,55178,'117136','furniture-mobile','padding-top','20',0,''),(172516,55178,'117136','furniture-mobile','padding-bottom','10',0,''),(172517,55178,'117136','furniture-mobile','border-top-width','1',0,''),(172518,55178,'117136','furniture-mobile','border-top-color','$border-color-8',0,''),(172519,55179,'117137','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(172520,55179,'117137','furniture-mobile','font-weight','normal',0,''),(172521,55179,'117137','furniture-mobile','text-align','center',0,''),(172522,55179,'117137','furniture-mobile','padding-bottom','10',0,''),(172523,55179,'117137','furniture-mobile','font-size','14',0,''),(172524,55180,'117138','furniture-mobile','text','<p>GIFT CARD</p>',1,''),(172525,55180,'117138','furniture-mobile','font-size','30',0,''),(172526,55180,'117138','furniture-mobile','font-weight','normal',0,''),(172527,55180,'117138','furniture-mobile','border-top-width','1',0,''),(172528,55180,'117138','furniture-mobile','border-top-color','$border-color-8',0,''),(172529,55180,'117138','furniture-mobile','style_class','gift-ico',0,''),(172530,55180,'117138','furniture-mobile','text-align','center',0,''),(172531,55180,'117138','furniture-mobile','padding-top','15',0,''),(172532,55181,'117139','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(172533,55181,'117139','furniture-mobile','font-weight','normal',0,''),(172534,55181,'117139','furniture-mobile','text-align','center',0,''),(172535,55181,'117139','furniture-mobile','padding-top','20',0,''),(172536,55181,'117139','furniture-mobile','padding-bottom','10',0,''),(172537,55181,'117139','furniture-mobile','style_class','question-ico',0,''),(172538,55181,'117139','furniture-mobile','border-top-width','1',0,''),(172539,55181,'117139','furniture-mobile','border-top-color','$border-color-8',0,''),(172540,55181,'117139','furniture-mobile','font-size','18',0,''),(172541,55182,'1638804282.8587','furniture-mobile','logo_from','theme',0,''),(172542,55182,'1638804282.8587','furniture-mobile','padding-top','20',0,''),(172543,55182,'1638804282.8587','furniture-mobile','text-align','center',0,''),(172544,55182,'1638804282.8587','furniture-mobile','padding-bottom','20',0,''),(172545,55183,'117141','furniture-mobile','block_type','1',0,''),(172546,55183,'117141','furniture-mobile','font-weight','normal',0,''),(172547,55183,'117141','furniture-mobile','style_class','gift-card-view',0,''),(172548,55183,'117141','furniture-mobile','text-align','center',0,''),(172549,55183,'117141','furniture-mobile','padding-bottom','20',0,''),(172550,55183,'117141','furniture-mobile','background-color','$background-10',0,''),(172551,55183,'117141','furniture-mobile','padding-left','20',0,''),(172552,55183,'117141','furniture-mobile','padding-right','20',0,''),(172553,55183,'117141','furniture-mobile','color','$color-font-3',0,''),(172554,55184,'117142','furniture-mobile','block_type','1',0,''),(172555,55184,'117142','furniture-mobile','font-weight','normal',0,''),(172556,55184,'117142','furniture-mobile','padding-top','10',0,''),(172557,55185,'117143','furniture-mobile','font-size','12',0,''),(172558,55185,'117143','furniture-mobile','font-weight','bold',0,''),(172559,55185,'117143','furniture-mobile','text-align','center',0,''),(172560,55185,'117143','furniture-mobile','style_class','email',0,''),(172561,55185,'117143','furniture-mobile','color','$color-font-1',0,''),(172562,55186,'117144','furniture-mobile','font-size','12',0,''),(172563,55186,'117144','furniture-mobile','font-weight','bold',0,''),(172564,55186,'117144','furniture-mobile','text-align','center',0,''),(172565,55186,'117144','furniture-mobile','style_class','phone',0,''),(172566,55186,'117144','furniture-mobile','padding-bottom','5',0,''),(172567,55186,'117144','furniture-mobile','color','$color-font-1',0,''),(172568,55187,'117145','furniture-mobile','text','If you require further assistance please contact us',0,''),(172569,55187,'117145','furniture-mobile','font-size','12',0,''),(172570,55187,'117145','furniture-mobile','color','$color-font-1',0,''),(172571,55187,'117145','furniture-mobile','text-align','center',0,''),(172572,55187,'117145','furniture-mobile','padding-top','10',0,''),(172573,55188,'117146','furniture-mobile','block_type','4',0,''),(172574,55188,'117146','furniture-mobile','color','$color-font-1',0,''),(172575,55188,'117146','furniture-mobile','font-size','30',0,''),(172576,55188,'117146','furniture-mobile','font-weight','normal',0,''),(172577,55188,'117146','furniture-mobile','background-color','$background-5',0,''),(172578,55188,'117146','furniture-mobile','padding-top','5',0,''),(172579,55188,'117146','furniture-mobile','padding-left','10',0,''),(172580,55188,'117146','furniture-mobile','padding-right','10',0,''),(172581,55188,'117146','furniture-mobile','padding-bottom','5',0,''),(172582,55189,'117147','furniture-mobile','text','Your code is:',0,''),(172583,55189,'117147','furniture-mobile','font-size','30',0,''),(172584,55189,'117147','furniture-mobile','color','$color-font-1',0,''),(172585,55190,'117148','furniture-mobile','color','$color-font-1',0,''),(172586,55190,'117148','furniture-mobile','font-size','30',0,''),(172587,55191,'117149','furniture-mobile','block_type','1',0,''),(172588,55192,'117150','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(172589,55192,'117150','furniture-mobile','font-size','18',0,''),(172590,55192,'117150','furniture-mobile','font-weight','normal',0,''),(172591,55192,'117150','furniture-mobile','text-align','center',0,''),(172592,55192,'117150','furniture-mobile','padding-top','20',0,''),(172593,55192,'117150','furniture-mobile','padding-bottom','10',0,''),(172594,55192,'117150','furniture-mobile','border-top-width','1',0,''),(172595,55192,'117150','furniture-mobile','border-top-color','$border-color-8',0,''),(172602,55194,'117152','furniture-mobile','border-top-color','$border-color-8',0,''),(172603,55194,'117152','furniture-mobile','border-top-width','1',0,''),(172604,55194,'117152','furniture-mobile','padding-top','20',0,''),(172605,55194,'117152','furniture-mobile','font-size','30',0,''),(172606,55194,'117152','furniture-mobile','text-align','center',0,''),(172607,55194,'117152','furniture-mobile','color','$color-font-1',0,''),(172608,55194,'117152','furniture-mobile','text','GIFT CARD',0,''),(172609,55195,'117153','furniture-mobile','text-align','center',0,''),(172610,55195,'117153','furniture-mobile','font-weight','bold',0,''),(172611,55195,'117153','furniture-mobile','font-size','60',0,''),(172612,55195,'117153','furniture-mobile','color','$color-font-1',0,''),(172613,55196,'117154','furniture-mobile','font-size','20',0,''),(172614,55196,'117154','furniture-mobile','text-align','center',0,''),(172615,55196,'117154','furniture-mobile','color','$color-font-1',0,''),(172616,55196,'117154','furniture-mobile','padding-top','20',0,''),(172617,55196,'117154','furniture-mobile','padding-bottom','20',0,''),(172618,55197,'117155','furniture-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(172619,55197,'117155','furniture-mobile','text-align','center',0,''),(172620,55197,'117155','furniture-mobile','color','$color-font-1',0,''),(172621,55197,'117155','furniture-mobile','font-size','14',0,''),(172622,55197,'117155','furniture-mobile','padding-bottom','20',0,''),(172623,55198,'117156','furniture-mobile','text','WHAT TO DO NEXT:',0,''),(172624,55198,'117156','furniture-mobile','font-size','18',0,''),(172625,55198,'117156','furniture-mobile','text-align','center',0,''),(172626,55198,'117156','furniture-mobile','color','$color-font-1',0,''),(172627,55198,'117156','furniture-mobile','padding-top','20',0,''),(172628,55198,'117156','furniture-mobile','padding-bottom','10',0,''),(172629,55198,'117156','furniture-mobile','border-top-width','1',0,''),(172630,55198,'117156','furniture-mobile','border-top-color','$border-color-8',0,''),(172631,55200,'117158','furniture-mobile','block_type','1',0,''),(172632,55200,'117158','furniture-mobile','font-weight','normal',0,''),(172633,55200,'117158','furniture-mobile','style_class','gift-card-view',0,''),(172634,55200,'117158','furniture-mobile','text-align','center',0,''),(172635,55200,'117158','furniture-mobile','padding-bottom','20',0,''),(172636,55200,'117158','furniture-mobile','background-color','$background-2',0,''),(172637,55200,'117158','furniture-mobile','padding-left','20',0,''),(172638,55200,'117158','furniture-mobile','padding-right','20',0,''),(172639,55200,'117158','furniture-mobile','color','$color-font-3',0,''),(172640,55201,'117159','furniture-mobile','block_type','1',0,''),(172641,55201,'117159','furniture-mobile','font-weight','normal',0,''),(172642,55201,'117159','furniture-mobile','padding-top','10',0,''),(172643,55202,'117160','furniture-mobile','font-size','12',0,''),(172644,55202,'117160','furniture-mobile','font-weight','bold',0,''),(172645,55202,'117160','furniture-mobile','text-align','center',0,''),(172646,55202,'117160','furniture-mobile','style_class','email',0,''),(172647,55202,'117160','furniture-mobile','color','$color-font-1',0,''),(172648,55203,'117161','furniture-mobile','font-size','12',0,''),(172649,55203,'117161','furniture-mobile','font-weight','bold',0,''),(172650,55203,'117161','furniture-mobile','text-align','center',0,''),(172651,55203,'117161','furniture-mobile','style_class','phone',0,''),(172652,55203,'117161','furniture-mobile','padding-bottom','5',0,''),(172653,55203,'117161','furniture-mobile','color','$color-font-1',0,''),(172654,55204,'117162','furniture-mobile','text','If you require further assistance please contact us',0,''),(172655,55204,'117162','furniture-mobile','font-size','12',0,''),(172656,55204,'117162','furniture-mobile','color','$color-font-1',0,''),(172657,55204,'117162','furniture-mobile','text-align','center',0,''),(172658,55204,'117162','furniture-mobile','padding-top','10',0,''),(172659,55205,'117163','furniture-mobile','block_type','2',0,''),(172660,55205,'117163','furniture-mobile','color','$color-font-1',0,''),(172661,55205,'117163','furniture-mobile','font-size','30',0,''),(172662,55205,'117163','furniture-mobile','font-weight','normal',0,''),(172663,55205,'117163','furniture-mobile','background-color','$background-5',0,''),(172664,55205,'117163','furniture-mobile','padding-top','5',0,''),(172665,55205,'117163','furniture-mobile','padding-left','10',0,''),(172666,55205,'117163','furniture-mobile','padding-right','10',0,''),(172667,55205,'117163','furniture-mobile','padding-bottom','5',0,''),(172668,55206,'117164','furniture-mobile','text','Your code is:',0,''),(172669,55206,'117164','furniture-mobile','font-size','30',0,''),(172670,55206,'117164','furniture-mobile','color','$color-font-1',0,''),(172671,55207,'117165','furniture-mobile','color','$color-font-1',0,''),(172672,55207,'117165','furniture-mobile','font-size','30',0,''),(172673,55208,'117166','furniture-mobile','block_type','1',0,''),(172674,55209,'117167','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(172675,55209,'117167','furniture-mobile','font-size','18',0,''),(172676,55209,'117167','furniture-mobile','font-weight','normal',0,''),(172677,55209,'117167','furniture-mobile','text-align','center',0,''),(172678,55209,'117167','furniture-mobile','padding-top','20',0,''),(172679,55209,'117167','furniture-mobile','padding-bottom','10',0,''),(172680,55209,'117167','furniture-mobile','border-top-width','1',0,''),(172681,55209,'117167','furniture-mobile','border-top-color','$border-color-8',0,''),(172682,55210,'117169','furniture-mobile','border-top-color','$border-color-8',0,''),(172683,55210,'117169','furniture-mobile','border-top-width','1',0,''),(172684,55210,'117169','furniture-mobile','padding-top','20',0,''),(172685,55210,'117169','furniture-mobile','font-size','30',0,''),(172686,55210,'117169','furniture-mobile','text-align','center',0,''),(172687,55210,'117169','furniture-mobile','color','$color-font-1',0,''),(172688,55210,'117169','furniture-mobile','text','GIFT CARD',0,''),(172689,55211,'117170','furniture-mobile','text-align','center',0,''),(172690,55211,'117170','furniture-mobile','font-weight','bold',0,''),(172691,55211,'117170','furniture-mobile','font-size','60',0,''),(172692,55211,'117170','furniture-mobile','color','$color-font-1',0,''),(172693,55212,'117171','furniture-mobile','font-size','20',0,''),(172694,55212,'117171','furniture-mobile','text-align','center',0,''),(172695,55212,'117171','furniture-mobile','color','$color-font-1',0,''),(172696,55212,'117171','furniture-mobile','padding-top','20',0,''),(172697,55212,'117171','furniture-mobile','padding-bottom','20',0,''),(172698,55213,'117172','furniture-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(172699,55213,'117172','furniture-mobile','text-align','center',0,''),(172700,55213,'117172','furniture-mobile','color','$color-font-1',0,''),(172701,55213,'117172','furniture-mobile','font-size','14',0,''),(172702,55213,'117172','furniture-mobile','padding-bottom','20',0,''),(172703,55214,'117173','furniture-mobile','text','WHAT TO DO NEXT:',0,''),(172704,55214,'117173','furniture-mobile','font-size','18',0,''),(172705,55214,'117173','furniture-mobile','text-align','center',0,''),(172706,55214,'117173','furniture-mobile','color','$color-font-1',0,''),(172707,55214,'117173','furniture-mobile','padding-top','20',0,''),(172708,55214,'117173','furniture-mobile','padding-bottom','10',0,''),(172709,55214,'117173','furniture-mobile','border-top-width','1',0,''),(172710,55214,'117173','furniture-mobile','border-top-color','$border-color-8',0,''),(172711,55215,'1638978695.8384','furniture-mobile','logo_from','theme',0,''),(172712,55215,'1638978695.8384','furniture-mobile','text-align','center',0,''),(172713,55215,'1638978695.8384','furniture-mobile','padding-top','20',0,''),(172714,55215,'1638978695.8384','furniture-mobile','padding-bottom','20',0,''),(172715,55216,'117175','furniture-mobile','block_type','1',0,''),(172716,55216,'117175','furniture-mobile','padding-left','20',0,''),(172717,55216,'117175','furniture-mobile','padding-right','20',0,''),(172718,55216,'117175','furniture-mobile','padding-bottom','20',0,''),(172719,55218,'117177','furniture-mobile','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(172720,55218,'117177','furniture-mobile','text-align','center',0,''),(172721,55219,'117178','furniture-mobile','block_type','1',0,''),(172722,55219,'117178','furniture-mobile','font-weight','normal',0,''),(172723,55219,'117178','furniture-mobile','style_class','gift-card-view',0,''),(172724,55219,'117178','furniture-mobile','text-align','center',0,''),(172725,55219,'117178','furniture-mobile','padding-bottom','20',0,''),(172726,55219,'117178','furniture-mobile','background-color','$background-4',0,''),(172727,55219,'117178','furniture-mobile','padding-left','20',0,''),(172728,55219,'117178','furniture-mobile','padding-right','20',0,''),(172729,55219,'117178','furniture-mobile','color','$color-font-3',0,''),(172730,55220,'117179','furniture-mobile','block_type','4',0,''),(172731,55220,'117179','furniture-mobile','color','$color-font-1',0,''),(172732,55220,'117179','furniture-mobile','font-size','30',0,''),(172733,55220,'117179','furniture-mobile','font-weight','normal',0,''),(172734,55220,'117179','furniture-mobile','background-color','$background-5',0,''),(172735,55220,'117179','furniture-mobile','padding-top','5',0,''),(172736,55220,'117179','furniture-mobile','padding-left','10',0,''),(172737,55220,'117179','furniture-mobile','padding-right','10',0,''),(172738,55220,'117179','furniture-mobile','padding-bottom','5',0,''),(172739,55221,'117180','furniture-mobile','text','<p>Your code is:</p>',1,''),(172740,55221,'117180','furniture-mobile','font-weight','normal',0,''),(172741,55223,'117182','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',1,''),(172742,55223,'117182','furniture-mobile','font-weight','normal',0,''),(172743,55223,'117182','furniture-mobile','text-align','center',0,''),(172744,55223,'117182','furniture-mobile','padding-top','20',0,''),(172745,55223,'117182','furniture-mobile','padding-bottom','10',0,''),(172746,55223,'117182','furniture-mobile','style_class','question-ico',0,''),(172747,55223,'117182','furniture-mobile','border-top-width','1',0,''),(172748,55223,'117182','furniture-mobile','border-top-color','$border-color-8',0,''),(172749,55223,'117182','furniture-mobile','font-size','18',0,''),(172750,55224,'117184','furniture-mobile','block_type','1',0,''),(172751,55224,'117184','furniture-mobile','font-weight','normal',0,''),(172752,55224,'117184','furniture-mobile','padding-top','10',0,''),(172753,55225,'117185','furniture-mobile','text','<p>If you require further assistance please contact us</p>',1,''),(172754,55225,'117185','furniture-mobile','font-weight','normal',0,''),(172755,55225,'117185','furniture-mobile','text-align','center',0,''),(172756,55225,'117185','furniture-mobile','font-size','12',0,''),(172757,55225,'117185','furniture-mobile','padding-top','10',0,''),(172758,55225,'117185','furniture-mobile','padding-bottom','5',0,''),(172759,55225,'117185','furniture-mobile','border-top-width','1',0,''),(172760,55225,'117185','furniture-mobile','border-top-color','$border-color-8',0,''),(172761,55226,'117186','furniture-mobile','font-size','12',0,''),(172762,55226,'117186','furniture-mobile','font-weight','bold',0,''),(172763,55226,'117186','furniture-mobile','text-align','center',0,''),(172764,55226,'117186','furniture-mobile','style_class','email',0,''),(172765,55227,'117187','furniture-mobile','font-size','12',0,''),(172766,55227,'117187','furniture-mobile','font-weight','bold',0,''),(172767,55227,'117187','furniture-mobile','text-align','center',0,''),(172768,55227,'117187','furniture-mobile','style_class','phone',0,''),(172769,55227,'117187','furniture-mobile','padding-bottom','5',0,''),(172770,55228,'117188','furniture-mobile','font-weight','normal',0,''),(172771,55228,'117188','furniture-mobile','text-align','center',0,''),(172772,55228,'117188','furniture-mobile','padding-bottom','20',0,''),(172773,55229,'117189','furniture-mobile','text','<p>GIFT CARD</p>',1,''),(172774,55229,'117189','furniture-mobile','font-size','30',0,''),(172775,55229,'117189','furniture-mobile','font-weight','normal',0,''),(172776,55229,'117189','furniture-mobile','border-top-width','1',0,''),(172777,55229,'117189','furniture-mobile','border-top-color','$border-color-8',0,''),(172778,55229,'117189','furniture-mobile','style_class','gift-ico',0,''),(172779,55229,'117189','furniture-mobile','text-align','center',0,''),(172780,55229,'117189','furniture-mobile','padding-top','15',0,''),(172781,55230,'117190','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(172782,55230,'117190','furniture-mobile','font-size','18',0,''),(172783,55230,'117190','furniture-mobile','font-weight','normal',0,''),(172784,55230,'117190','furniture-mobile','text-align','center',0,''),(172785,55230,'117190','furniture-mobile','padding-top','20',0,''),(172786,55230,'117190','furniture-mobile','padding-bottom','10',0,''),(172787,55230,'117190','furniture-mobile','border-top-width','1',0,''),(172788,55230,'117190','furniture-mobile','border-top-color','$border-color-8',0,''),(172789,55231,'117191','furniture-mobile','font-size','60',0,''),(172790,55231,'117191','furniture-mobile','font-weight','bold',0,''),(172791,55231,'117191','furniture-mobile','text-align','center',0,''),(172792,55231,'117191','furniture-mobile','line-height','100',0,''),(172793,55231,'117191','furniture-mobile','padding-bottom','20',0,''),(172794,55231,'117191','furniture-mobile','line_height_measure','px',0,''),(172795,55232,'117192','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(172796,55232,'117192','furniture-mobile','font-weight','normal',0,''),(172797,55232,'117192','furniture-mobile','text-align','center',0,''),(172798,55232,'117192','furniture-mobile','padding-bottom','10',0,''),(172799,55232,'117192','furniture-mobile','font-size','14',0,''),(172800,55233,'1638804328.7281','furniture-mobile','logo_from','theme',0,''),(172801,55233,'1638804328.7281','furniture-mobile','padding-top','20',0,''),(172802,55233,'1638804328.7281','furniture-mobile','text-align','center',0,''),(172803,55233,'1638804328.7281','furniture-mobile','padding-bottom','20',0,''),(172804,55234,'117193','furniture-mobile','block_type','1',0,''),(172805,55234,'117193','furniture-mobile','font-weight','normal',0,''),(172806,55234,'117193','furniture-mobile','style_class','gift-card-view',0,''),(172807,55234,'117193','furniture-mobile','text-align','center',0,''),(172808,55234,'117193','furniture-mobile','padding-bottom','20',0,''),(172809,55234,'117193','furniture-mobile','background-color','$background-4',0,''),(172810,55234,'117193','furniture-mobile','padding-left','20',0,''),(172811,55234,'117193','furniture-mobile','padding-right','20',0,''),(172812,55234,'117193','furniture-mobile','color','$color-font-3',0,''),(172813,55235,'117194','furniture-mobile','block_type','1',0,''),(172814,55235,'117194','furniture-mobile','font-weight','normal',0,''),(172815,55235,'117194','furniture-mobile','padding-top','10',0,''),(172816,55236,'117195','furniture-mobile','font-size','12',0,''),(172817,55236,'117195','furniture-mobile','font-weight','bold',0,''),(172818,55236,'117195','furniture-mobile','text-align','center',0,''),(172819,55236,'117195','furniture-mobile','style_class','email',0,''),(172820,55236,'117195','furniture-mobile','color','$color-font-1',0,''),(172821,55237,'117196','furniture-mobile','font-size','12',0,''),(172822,55237,'117196','furniture-mobile','font-weight','bold',0,''),(172823,55237,'117196','furniture-mobile','text-align','center',0,''),(172824,55237,'117196','furniture-mobile','style_class','phone',0,''),(172825,55237,'117196','furniture-mobile','padding-bottom','5',0,''),(172826,55237,'117196','furniture-mobile','color','$color-font-1',0,''),(172827,55238,'117197','furniture-mobile','text','If you require further assistance please contact us',0,''),(172828,55238,'117197','furniture-mobile','font-size','12',0,''),(172829,55238,'117197','furniture-mobile','color','$color-font-1',0,''),(172830,55238,'117197','furniture-mobile','text-align','center',0,''),(172831,55238,'117197','furniture-mobile','padding-top','10',0,''),(172832,55239,'117198','furniture-mobile','block_type','4',0,''),(172833,55239,'117198','furniture-mobile','color','$color-font-1',0,''),(172834,55239,'117198','furniture-mobile','font-size','30',0,''),(172835,55239,'117198','furniture-mobile','font-weight','normal',0,''),(172836,55239,'117198','furniture-mobile','background-color','$background-5',0,''),(172837,55239,'117198','furniture-mobile','padding-top','5',0,''),(172838,55239,'117198','furniture-mobile','padding-left','10',0,''),(172839,55239,'117198','furniture-mobile','padding-right','10',0,''),(172840,55239,'117198','furniture-mobile','padding-bottom','5',0,''),(172841,55240,'117199','furniture-mobile','text','Your code is:',0,''),(172842,55240,'117199','furniture-mobile','font-size','30',0,''),(172843,55240,'117199','furniture-mobile','color','$color-font-1',0,''),(172844,55241,'117200','furniture-mobile','color','$color-font-1',0,''),(172845,55241,'117200','furniture-mobile','font-size','30',0,''),(172846,55242,'117201','furniture-mobile','block_type','1',0,''),(172847,55243,'117202','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',1,''),(172848,55243,'117202','furniture-mobile','font-size','18',0,''),(172849,55243,'117202','furniture-mobile','font-weight','normal',0,''),(172850,55243,'117202','furniture-mobile','text-align','center',0,''),(172851,55243,'117202','furniture-mobile','padding-top','20',0,''),(172852,55243,'117202','furniture-mobile','padding-bottom','10',0,''),(172853,55243,'117202','furniture-mobile','border-top-width','1',0,''),(172854,55243,'117202','furniture-mobile','border-top-color','$border-color-8',0,''),(172855,55244,'117203','furniture-mobile','text','HOLBI',0,''),(172856,55244,'117203','furniture-mobile','color','$color-font-1',0,''),(172857,55244,'117203','furniture-mobile','font-size','24',0,''),(172858,55244,'117203','furniture-mobile','padding-top','20',0,''),(172859,55244,'117203','furniture-mobile','text-align','center',0,''),(172860,55244,'117203','furniture-mobile','padding-bottom','20',0,''),(172861,55245,'117204','furniture-mobile','border-top-color','$border-color-8',0,''),(172862,55245,'117204','furniture-mobile','border-top-width','1',0,''),(172863,55245,'117204','furniture-mobile','padding-top','20',0,''),(172864,55245,'117204','furniture-mobile','font-size','30',0,''),(172865,55245,'117204','furniture-mobile','text-align','center',0,''),(172866,55245,'117204','furniture-mobile','color','$color-font-1',0,''),(172867,55245,'117204','furniture-mobile','text','GIFT CARD',0,''),(172868,55246,'117205','furniture-mobile','text-align','center',0,''),(172869,55246,'117205','furniture-mobile','font-weight','bold',0,''),(172870,55246,'117205','furniture-mobile','font-size','60',0,''),(172871,55246,'117205','furniture-mobile','color','$color-font-1',0,''),(172872,55247,'117206','furniture-mobile','font-size','20',0,''),(172873,55247,'117206','furniture-mobile','text-align','center',0,''),(172874,55247,'117206','furniture-mobile','color','$color-font-1',0,''),(172875,55247,'117206','furniture-mobile','padding-top','20',0,''),(172876,55247,'117206','furniture-mobile','padding-bottom','20',0,''),(172877,55248,'117207','furniture-mobile','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(172878,55248,'117207','furniture-mobile','text-align','center',0,''),(172879,55248,'117207','furniture-mobile','color','$color-font-1',0,''),(172880,55248,'117207','furniture-mobile','font-size','14',0,''),(172881,55248,'117207','furniture-mobile','padding-bottom','20',0,''),(172882,55249,'117208','furniture-mobile','text','WHAT TO DO NEXT:',0,''),(172883,55249,'117208','furniture-mobile','font-size','18',0,''),(172884,55249,'117208','furniture-mobile','text-align','center',0,''),(172885,55249,'117208','furniture-mobile','color','$color-font-1',0,''),(172886,55249,'117208','furniture-mobile','padding-top','20',0,''),(172887,55249,'117208','furniture-mobile','padding-bottom','10',0,''),(172888,55249,'117208','furniture-mobile','border-top-width','1',0,''),(172889,55249,'117208','furniture-mobile','border-top-color','$border-color-8',0,''),(172890,55250,'117209','furniture-mobile','block_type','1',0,''),(172891,55250,'117209','furniture-mobile','font-weight','400',0,''),(172892,55250,'117209','furniture-mobile','background-color','$background-2',0,''),(172893,55250,'117209','furniture-mobile','visibility_checkout','1',0,''),(172894,55250,'117209','furniture-mobile','style_class','menu-header',0,''),(172895,55251,'117210','furniture-mobile','class','menu-style-1',0,''),(172896,55251,'117210','furniture-mobile','box_align','4',0,''),(172897,55251,'117210','furniture-mobile','font-weight','400',0,''),(172898,55251,'117210','furniture-mobile','hide_menu','on',0,''),(172899,55251,'117210','furniture-mobile','color','$color-font-1',0,''),(172900,55251,'117210','furniture-mobile','hide_menu','1',0,'2885'),(172901,55251,'117210','furniture-mobile','show_new','1',0,''),(172902,55251,'117210','furniture-mobile','type','builder',0,''),(172903,55251,'117210','furniture-mobile','style','1',0,'2945'),(172904,55251,'117210','furniture-mobile','burger_icon','1',0,'2885'),(172905,55251,'117210','furniture-mobile','style','2',0,'2885'),(172906,55251,'117210','furniture-mobile','open_from','left',0,'2885'),(172907,55251,'117210','furniture-mobile','lev2_vis','over',0,'2945'),(172908,55251,'117210','furniture-mobile','lev2_display','down',0,'2945'),(172909,55251,'117210','furniture-mobile','lev2_vis','click',0,'2885'),(172910,55251,'117210','furniture-mobile','lev3_vis','over',0,'2945'),(172911,55251,'117210','furniture-mobile','lev4_vis','over',0,'2945'),(172912,55251,'117210','furniture-mobile','lev5_vis','over',0,'2945'),(172913,55251,'117210','furniture-mobile','lev5_display','lra',0,'2945'),(172914,55251,'117210','furniture-mobile','lev4_display','lra',0,'2945'),(172915,55251,'117210','furniture-mobile','lev3_display','lra',0,'2945'),(172916,55251,'117210','furniture-mobile','position','horizontal_flex',0,'2945'),(172917,55251,'117210','furniture-mobile','z-index','92',0,''),(172918,55252,'117212','furniture-mobile','block_type','1',0,''),(172919,55252,'117212','furniture-mobile','padding-top','3',0,''),(172920,55252,'117212','furniture-mobile','padding-top','0',0,'2906'),(172921,55252,'117212','furniture-mobile','padding-bottom','0',0,'2906'),(172922,55252,'117212','furniture-mobile','background-color','$background-1',0,''),(172923,55252,'117212','furniture-mobile','color','$color-font-1',0,''),(172924,55252,'117212','furniture-mobile','style_class','header-middle',0,''),(172925,55253,'117213','furniture-mobile','font-weight','400',0,''),(172926,55253,'117213','furniture-mobile','box_align','1',0,''),(172928,55253,'117213','furniture-mobile','text-align','center',0,'2906'),(172929,55253,'117213','furniture-mobile','width_measure','%',0,'2906'),(172930,55253,'117213','furniture-mobile','logo_from','theme',0,''),(172931,55253,'117213','furniture-mobile','float','left',0,''),(172932,55253,'117213','furniture-mobile','clear','both',0,''),(172933,55253,'117213','furniture-mobile','margin-top','22',0,''),(172934,55253,'117213','furniture-mobile','margin-bottom','22',0,''),(172935,55253,'117213','furniture-mobile','width','100',0,'2885'),(172936,55253,'117213','furniture-mobile','padding-top','10',0,'2885'),(172937,55253,'117213','furniture-mobile','padding-bottom','10',0,'2885'),(172938,55253,'117213','furniture-mobile','margin-top','1',0,'2885'),(172939,55253,'117213','furniture-mobile','margin-bottom','9',0,'2885'),(172940,55253,'117213','furniture-mobile','position','relative',0,''),(172941,55253,'117213','furniture-mobile','z-index','5',0,''),(172942,55254,'117214','furniture-mobile','font-weight','400',0,''),(172943,55254,'117214','furniture-mobile','visibility_checkout','1',0,''),(172944,55254,'117214','furniture-mobile','float','right',0,''),(172945,55254,'117214','furniture-mobile','clear','none',0,''),(172946,55254,'117214','furniture-mobile','margin-top','42',0,''),(172947,55254,'117214','furniture-mobile','margin-top','7',0,'2885'),(172948,55254,'117214','furniture-mobile','color','$color-font-7',0,''),(172949,55255,'117215','furniture-mobile','box_align','1',0,''),(172950,55255,'117215','furniture-mobile','visibility_cart','1',0,''),(172951,55255,'117215','furniture-mobile','visibility_checkout','1',0,''),(172952,55256,'117216','furniture-mobile','font-weight','400',0,''),(172953,55256,'117216','furniture-mobile','box_align','3',0,''),(172954,55256,'117216','furniture-mobile','only_icon','on',0,''),(172955,55256,'117216','furniture-mobile','color','$color-font-4',0,''),(172956,55256,'117216','furniture-mobile','margin-top','34',0,''),(172957,55256,'117216','furniture-mobile','margin-top','7',0,'2885'),(172958,55256,'117216','furniture-mobile','items','1',0,''),(172959,55256,'117216','furniture-mobile','total','1',0,''),(172960,55256,'117216','furniture-mobile','show_products','dropdown',0,''),(172961,55257,'117217','furniture-mobile','font-weight','normal',0,''),(172962,55257,'117217','furniture-mobile','box_align','3',0,''),(172963,55257,'117217','furniture-mobile','only_icon','on',0,''),(172964,55257,'117217','furniture-mobile','margin-top','34',0,''),(172965,55257,'117217','furniture-mobile','margin-left','20',0,''),(172966,55257,'117217','furniture-mobile','margin-top','7',0,'2885'),(172967,55257,'117217','furniture-mobile','margin-left','10',0,'2885'),(172968,55257,'117217','furniture-mobile','link_or_dropdown','1',0,''),(172969,55258,'117218','furniture-mobile','float','left',0,''),(172970,55258,'117218','furniture-mobile','clear','none',0,''),(172971,55258,'117218','furniture-mobile','logo','themes/furniture-mobile/img/header-img-1.png',1,''),(172972,55258,'117218','furniture-mobile','display_none','1',0,'2890'),(172973,55259,'120877','furniture-mobile','text','<span class=\"searchIcon\"></span>',0,''),(172974,55259,'120877','furniture-mobile','box_align','3',0,''),(172975,55259,'120877','furniture-mobile','margin-top','34',0,''),(172976,55259,'120877','furniture-mobile','margin-top','15',0,'2906'),(172977,55260,'117219','furniture-mobile','block_type','1',0,''),(172978,55260,'117219','furniture-mobile','border-bottom-width','1',0,''),(172979,55260,'117219','furniture-mobile','border-bottom-color','$border-color-2',0,''),(172980,55260,'117219','furniture-mobile','font-weight','normal',0,''),(172981,55260,'117219','furniture-mobile','visibility_checkout','1',0,''),(172982,55260,'117219','furniture-mobile','background-color','$background-1',0,''),(172983,55260,'117219','furniture-mobile','color','$color-font-1',0,''),(172984,55260,'117219','furniture-mobile','display_none','1',0,'2885'),(172985,55261,'117220','furniture-mobile','block_type','1',0,''),(172986,55261,'117220','furniture-mobile','font-weight','400',0,''),(172987,55261,'117220','furniture-mobile','schema','2-2',0,''),(172988,55261,'117220','furniture-mobile','schema','5-1',0,'2885'),(172989,55262,'117221','furniture-mobile','class','menu-horizontal',0,''),(172990,55262,'117221','furniture-mobile','box_align','1',0,''),(172991,55262,'117221','furniture-mobile','font-weight','400',0,''),(172992,55262,'117221','furniture-mobile','float','left',0,''),(172993,55262,'117221','furniture-mobile','display_none','1',0,'2906'),(172994,55263,'117222','furniture-mobile','box_align','3',0,''),(172995,55263,'117222','furniture-mobile','font-weight','normal',0,''),(172996,55263,'117222','furniture-mobile','padding-top','2',0,''),(172997,55263,'117222','furniture-mobile','padding-bottom','1',0,''),(172998,55263,'117222','furniture-mobile','padding-top','0',0,'2885'),(172999,55263,'117222','furniture-mobile','padding-right','0',0,'2885'),(173000,55263,'117222','furniture-mobile','padding-bottom','0',0,'2885'),(173001,55263,'117222','furniture-mobile','padding-left','0',0,'2885'),(173002,55264,'117223','furniture-mobile','box_align','3',0,''),(173003,55264,'117223','furniture-mobile','font-weight','normal',0,''),(173004,55264,'117223','furniture-mobile','padding-top','2',0,''),(173005,55264,'117223','furniture-mobile','border-left-width','1',0,''),(173006,55264,'117223','furniture-mobile','border-left-color','$border-color-4',0,''),(173007,55264,'117223','furniture-mobile','padding-bottom','1',0,''),(173008,55264,'117223','furniture-mobile','padding-top','0',0,'2885'),(173009,55264,'117223','furniture-mobile','padding-right','0',0,'2885'),(173010,55264,'117223','furniture-mobile','padding-bottom','0',0,'2885'),(173011,55264,'117223','furniture-mobile','padding-left','0',0,'2885'),(173012,55268,'117224','furniture-mobile','block_type','1',0,''),(173013,55274,'117229','furniture-mobile','width','680',0,''),(173014,55274,'117229','furniture-mobile','font-weight','normal',0,''),(173015,55274,'117229','furniture-mobile','font-size','12',0,''),(173016,55274,'117229','furniture-mobile','padding-top','20',0,''),(173017,55274,'117229','furniture-mobile','padding-bottom','20',0,''),(173018,55274,'117229','furniture-mobile','color','$color-font-8',0,''),(173019,55275,'117230','furniture-mobile','block_type','4',0,''),(173020,55275,'117230','furniture-mobile','font-weight','normal',0,''),(173021,55275,'117230','furniture-mobile','border-top-width','1',0,''),(173022,55275,'117230','furniture-mobile','border-top-color','$border-color-4',0,''),(173023,55275,'117230','furniture-mobile','border-left-width','1',0,''),(173024,55275,'117230','furniture-mobile','border-left-color','$border-color-4',0,''),(173025,55275,'117230','furniture-mobile','border-right-width','1',0,''),(173026,55275,'117230','furniture-mobile','border-right-color','$border-color-4',0,''),(173027,55275,'117230','furniture-mobile','border-bottom-width','1',0,''),(173028,55275,'117230','furniture-mobile','border-bottom-color','$border-color-4',0,''),(173029,55276,'117231','furniture-mobile','block_type','2',0,''),(173030,55276,'117231','furniture-mobile','font-weight','normal',0,''),(173031,55276,'117231','furniture-mobile','border-top-width','1',0,''),(173032,55276,'117231','furniture-mobile','border-top-color','$border-color-4',0,''),(173033,55276,'117231','furniture-mobile','border-right-width','1',0,''),(173034,55276,'117231','furniture-mobile','border-right-color','$border-color-4',0,''),(173035,55277,'117232','furniture-mobile','block_type','1',0,''),(173036,55277,'117232','furniture-mobile','font-weight','normal',0,''),(173037,55277,'117232','furniture-mobile','padding-top','10',0,''),(173038,55277,'117232','furniture-mobile','padding-left','10',0,''),(173039,55277,'117232','furniture-mobile','padding-right','10',0,''),(173040,55277,'117232','furniture-mobile','padding-bottom','10',0,''),(173041,55277,'117232','furniture-mobile','border-right-width','1',0,''),(173042,55277,'117232','furniture-mobile','border-right-color','$border-color-4',0,''),(173043,55279,'117234','furniture-mobile','text','<p>Shipping via</p>',1,''),(173044,55279,'117234','furniture-mobile','font-weight','bold',0,''),(173045,55279,'117234','furniture-mobile','font-size','14',0,''),(173046,55280,'117235','furniture-mobile','block_type','1',0,''),(173047,55280,'117235','furniture-mobile','font-weight','normal',0,''),(173048,55280,'117235','furniture-mobile','padding-top','10',0,''),(173049,55280,'117235','furniture-mobile','padding-left','10',0,''),(173050,55280,'117235','furniture-mobile','padding-right','10',0,''),(173051,55280,'117235','furniture-mobile','padding-bottom','10',0,''),(173052,55281,'117236','furniture-mobile','text','<p>Shipping service</p>',1,''),(173053,55281,'117236','furniture-mobile','font-weight','bold',0,''),(173054,55281,'117236','furniture-mobile','font-size','14',0,''),(173055,55283,'117238','furniture-mobile','block_type','2',0,''),(173056,55283,'117238','furniture-mobile','font-weight','normal',0,''),(173057,55283,'117238','furniture-mobile','border-right-width','1',0,''),(173058,55283,'117238','furniture-mobile','border-right-color','$border-color-4',0,''),(173059,55284,'117239','furniture-mobile','block_type','1',0,''),(173060,55284,'117239','furniture-mobile','font-weight','400',0,''),(173061,55284,'117239','furniture-mobile','background-color','$background-6',0,''),(173062,55284,'117239','furniture-mobile','padding-top','10',0,''),(173063,55284,'117239','furniture-mobile','padding-left','10',0,''),(173064,55284,'117239','furniture-mobile','padding-right','10',0,''),(173065,55284,'117239','furniture-mobile','padding-bottom','30',0,''),(173066,55285,'117240','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(173067,55285,'117240','furniture-mobile','font-size','14',0,''),(173068,55285,'117240','furniture-mobile','font-weight','bold',0,''),(173069,55286,'117241','furniture-mobile','font-size','12',0,''),(173070,55288,'117242','furniture-mobile','block_type','1',0,''),(173071,55288,'117242','furniture-mobile','font-weight','normal',0,''),(173072,55288,'117242','furniture-mobile','padding-top','10',0,''),(173073,55288,'117242','furniture-mobile','padding-left','10',0,''),(173074,55288,'117242','furniture-mobile','padding-right','10',0,''),(173075,55288,'117242','furniture-mobile','padding-bottom','10',0,''),(173076,55289,'117243','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(173077,55289,'117243','furniture-mobile','font-weight','bold',0,''),(173078,55289,'117243','furniture-mobile','font-size','14',0,''),(173079,55289,'117243','furniture-mobile','padding-top','10',0,''),(173080,55290,'117244','furniture-mobile','font-weight','normal',0,''),(173081,55291,'117245','furniture-mobile','font-weight','normal',0,''),(173082,55292,'117246','furniture-mobile','text','<p>CUSTOMER:</p>',1,''),(173083,55292,'117246','furniture-mobile','font-size','13',0,''),(173084,55292,'117246','furniture-mobile','font-weight','bold',0,''),(173085,55293,'117247','furniture-mobile','text','<p>PHONE NUMBER:</p>',1,''),(173086,55293,'117247','furniture-mobile','font-size','14',0,''),(173087,55293,'117247','furniture-mobile','font-weight','bold',0,''),(173088,55293,'117247','furniture-mobile','padding-top','10',0,''),(173089,55295,'117249','furniture-mobile','font-weight','normal',0,''),(173090,55295,'117249','furniture-mobile','text-align','center',0,''),(173091,55295,'117249','furniture-mobile','padding-bottom','20',0,''),(173092,55296,'117250','furniture-mobile','text','<p>Payment Method:</p>',1,''),(173093,55296,'117250','furniture-mobile','font-weight','bold',0,''),(173094,55296,'117250','furniture-mobile','text-align','center',0,''),(173095,55297,'117251','furniture-mobile','text','<p>Payment date:</p>',1,''),(173096,55297,'117251','furniture-mobile','font-weight','bold',0,''),(173097,55297,'117251','furniture-mobile','text-align','center',0,''),(173098,55297,'117251','furniture-mobile','font-size','12',0,''),(173099,55298,'117252','furniture-mobile','font-size','14',0,''),(173100,55298,'117252','furniture-mobile','font-weight','bold',0,''),(173101,55298,'117252','furniture-mobile','text-align','center',0,''),(173102,55298,'117252','furniture-mobile','padding-bottom','10',0,''),(173103,55298,'117252','furniture-mobile','padding-top','10',0,''),(173104,55299,'117253','furniture-mobile','font-weight','normal',0,''),(173105,55299,'117253','furniture-mobile','text-align','center',0,''),(173106,55299,'117253','furniture-mobile','padding-bottom','10',0,''),(173107,55300,'117254','furniture-mobile','font-weight','normal',0,''),(173108,55300,'117254','furniture-mobile','text-align','center',0,''),(173109,55301,'117255','furniture-mobile','block_type','3',0,''),(173110,55301,'117255','furniture-mobile','font-weight','normal',0,''),(173111,55301,'117255','furniture-mobile','padding-top','20',0,''),(173112,55302,'117256','furniture-mobile','font-size','12',0,''),(173113,55303,'117257','furniture-mobile','text','<p>If undelivered please return to:</p>',1,''),(173114,55303,'117257','furniture-mobile','font-size','12',0,''),(173115,55303,'117257','furniture-mobile','font-weight','bold',0,''),(173116,55304,'117258','furniture-mobile','text','<p>Thank you for your order</p>',1,''),(173117,55304,'117258','furniture-mobile','color','$color-font-10',0,''),(173118,55304,'117258','furniture-mobile','font-size','13',0,''),(173119,55304,'117258','furniture-mobile','font-weight','bold',0,''),(173120,55304,'117258','furniture-mobile','padding-top','5',0,''),(173121,55304,'117258','furniture-mobile','text-align','center',0,''),(173122,55305,'117260','furniture-mobile','block_type','6',0,''),(173123,55305,'117260','furniture-mobile','font-weight','normal',0,''),(173124,55305,'117260','furniture-mobile','font-size','16',0,''),(173125,55306,'117261','furniture-mobile','text','<p>Email:</p>',1,''),(173126,55306,'117261','furniture-mobile','font-weight','normal',0,''),(173127,55306,'117261','furniture-mobile','text-align','right',0,''),(173128,55306,'117261','furniture-mobile','font-size','12',0,''),(173129,55307,'117262','furniture-mobile','font-weight','normal',0,''),(173130,55307,'117262','furniture-mobile','text-align','right',0,''),(173131,55307,'117262','furniture-mobile','font-size','12',0,''),(173132,55308,'117263','furniture-mobile','block_type','6',0,''),(173133,55308,'117263','furniture-mobile','font-weight','normal',0,''),(173134,55308,'117263','furniture-mobile','font-size','16',0,''),(173135,55309,'117264','furniture-mobile','text','<p>Phone:</p>',1,''),(173136,55309,'117264','furniture-mobile','font-weight','normal',0,''),(173137,55309,'117264','furniture-mobile','text-align','right',0,''),(173138,55309,'117264','furniture-mobile','font-size','12',0,''),(173139,55310,'117265','furniture-mobile','font-weight','normal',0,''),(173140,55310,'117265','furniture-mobile','text-align','right',0,''),(173141,55310,'117265','furniture-mobile','font-size','12',0,''),(173142,55311,'117266','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(173143,55311,'117266','furniture-mobile','font-size','12',0,''),(173144,55311,'117266','furniture-mobile','font-weight','bold',0,''),(173145,55311,'117266','furniture-mobile','text-align','right',0,''),(173146,55312,'117267','furniture-mobile','font-weight','400',0,''),(173147,55312,'117267','furniture-mobile','padding-top','20',0,''),(173148,55312,'117267','furniture-mobile','padding-bottom','0',0,''),(173149,55312,'117267','furniture-mobile','font-size','12',0,''),(173150,55313,'117268','furniture-mobile','block_type','5',0,''),(173151,55313,'117268','furniture-mobile','font-weight','normal',0,''),(173152,55313,'117268','furniture-mobile','border-bottom-width','1',0,''),(173153,55313,'117268','furniture-mobile','border-bottom-color','$border-color-4',0,''),(173154,55313,'117268','furniture-mobile','border-top-width','1',0,''),(173155,55313,'117268','furniture-mobile','border-top-color','$border-color-4',0,''),(173156,55313,'117268','furniture-mobile','border-left-color','$border-color-4',0,''),(173157,55313,'117268','furniture-mobile','border-left-width','1',0,''),(173158,55314,'117269','furniture-mobile','block_type','1',0,''),(173159,55314,'117269','furniture-mobile','font-weight','normal',0,''),(173160,55314,'117269','furniture-mobile','padding-top','10',0,''),(173161,55314,'117269','furniture-mobile','padding-left','10',0,''),(173162,55314,'117269','furniture-mobile','padding-right','10',0,''),(173163,55315,'117270','furniture-mobile','font-weight','400',0,''),(173164,55315,'117270','furniture-mobile','line-height','120',0,''),(173165,55315,'117270','furniture-mobile','line_height_measure','%',0,''),(173166,55315,'117270','furniture-mobile','font-size','12',0,''),(173167,55316,'117271','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(173168,55316,'117271','furniture-mobile','font-size','14',0,''),(173169,55316,'117271','furniture-mobile','font-weight','bold',0,''),(173170,55316,'117271','furniture-mobile','padding-bottom','10',0,''),(173171,55317,'117272','furniture-mobile','block_type','1',0,''),(173172,55317,'117272','furniture-mobile','background-color','$background-6',0,''),(173173,55317,'117272','furniture-mobile','padding-top','20',0,''),(173174,55317,'117272','furniture-mobile','padding-left','10',0,''),(173175,55317,'117272','furniture-mobile','padding-right','10',0,''),(173176,55317,'117272','furniture-mobile','padding-bottom','20',0,''),(173177,55317,'117272','furniture-mobile','font-size','14',0,''),(173178,55318,'117273','furniture-mobile','font-weight','normal',0,''),(173179,55318,'117273','furniture-mobile','text-align','right',0,''),(173180,55318,'117273','furniture-mobile','font-size','14',0,''),(173181,55318,'117273','furniture-mobile','box_align','3',0,''),(173182,55319,'117274','furniture-mobile','block_type','2',0,''),(173183,55319,'117274','furniture-mobile','font-weight','normal',0,''),(173184,55319,'117274','furniture-mobile','padding-bottom','20',0,''),(173185,55320,'117275','furniture-mobile','font-weight','400',0,''),(173186,55320,'117275','furniture-mobile','padding-top','20',0,''),(173187,55320,'117275','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',1,''),(173188,55320,'117275','furniture-mobile','padding-bottom','20',0,''),(173189,55321,'117276','furniture-mobile','block_type','11',0,''),(173190,55321,'117276','furniture-mobile','font-weight','normal',0,''),(173191,55322,'117277','furniture-mobile','text','<p>Web:</p>',1,''),(173192,55322,'117277','furniture-mobile','font-weight','normal',0,''),(173193,55322,'117277','furniture-mobile','text-align','right',0,''),(173194,55323,'117278','furniture-mobile','font-weight','normal',0,''),(173195,55323,'117278','furniture-mobile','text-align','right',0,''),(173196,55324,'117279','furniture-mobile','block_type','11',0,''),(173197,55324,'117279','furniture-mobile','font-weight','normal',0,''),(173198,55325,'117280','furniture-mobile','text','<p>Email:</p>',1,''),(173199,55325,'117280','furniture-mobile','font-weight','normal',0,''),(173200,55325,'117280','furniture-mobile','text-align','right',0,''),(173201,55326,'117281','furniture-mobile','font-weight','normal',0,''),(173202,55326,'117281','furniture-mobile','text-align','right',0,''),(173203,55327,'117282','furniture-mobile','block_type','1',0,''),(173204,55328,'117283','furniture-mobile','font-weight','normal',0,''),(173205,55328,'117283','furniture-mobile','text-align','right',0,''),(173206,55328,'117283','furniture-mobile','padding-bottom','10',0,''),(173207,55328,'117283','furniture-mobile','address_spacer',',',0,''),(173208,55328,'117283','furniture-mobile','font-size','12',0,''),(173209,55329,'117284','furniture-mobile','block_type','11',0,''),(173210,55329,'117284','furniture-mobile','font-weight','normal',0,''),(173211,55330,'117285','furniture-mobile','text','<p>Phone:</p>',1,''),(173212,55330,'117285','furniture-mobile','font-weight','normal',0,''),(173213,55330,'117285','furniture-mobile','text-align','right',0,''),(173214,55331,'117286','furniture-mobile','font-weight','normal',0,''),(173215,55331,'117286','furniture-mobile','text-align','right',0,''),(173216,55332,'1640103567.8175','furniture-mobile','column_qty','1',0,''),(173217,55332,'1640103567.8175','furniture-mobile','column_name','1',0,''),(173218,55332,'1640103567.8175','furniture-mobile','column_model','1',0,''),(173219,55333,'1640180896.2131','furniture-mobile','block_type','1',0,''),(173220,55334,'1639994189.268','furniture-mobile','background_image','themes/furniture-mobile/img/paid2.png',0,''),(173221,55334,'1639994189.268','furniture-mobile','background-position','center',0,''),(173222,55334,'1639994189.268','furniture-mobile','background-repeat','no-repeat',0,''),(173223,55334,'1639994189.268','furniture-mobile','position','absolute',0,''),(173224,55334,'1639994189.268','furniture-mobile','width','100',0,''),(173225,55334,'1639994189.268','furniture-mobile','width_measure','%',0,''),(173226,55334,'1639994189.268','furniture-mobile','height','100',0,''),(173227,55334,'1639994189.268','furniture-mobile','height_measure','%',0,''),(173228,55334,'1639994189.268','furniture-mobile','top','0',0,''),(173229,55334,'1639994189.268','furniture-mobile','left','0',0,''),(173230,55334,'1639994189.268','furniture-mobile','opacity','0.7',0,''),(173231,55335,'1639996119.9463','furniture-mobile','position','absolute',0,''),(173232,55335,'1639996119.9463','furniture-mobile','top','0',0,''),(173233,55335,'1639996119.9463','furniture-mobile','left','0',0,''),(173234,55335,'1639996119.9463','furniture-mobile','width','100',0,''),(173235,55335,'1639996119.9463','furniture-mobile','width_measure','%',0,''),(173236,55335,'1639996119.9463','furniture-mobile','min_width_measure','%',0,''),(173237,55335,'1639996119.9463','furniture-mobile','background_image','themes/furniture-mobile/img/unpaind.png',0,''),(173238,55335,'1639996119.9463','furniture-mobile','background-position','center',0,''),(173239,55335,'1639996119.9463','furniture-mobile','background-repeat','no-repeat',0,''),(173240,55335,'1639996119.9463','furniture-mobile','height','100',0,''),(173241,55335,'1639996119.9463','furniture-mobile','height_measure','%',0,''),(173242,55336,'117287','furniture-mobile','block_type','1',0,''),(173243,55336,'117287','furniture-mobile','padding-top','20',0,''),(173244,55337,'117288','furniture-mobile','tab_1','RETURNING CUSTOMER',1,''),(173245,55337,'117288','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(173246,55338,'117289','furniture-mobile','max-width','600',0,''),(173247,55338,'117289','furniture-mobile','margin_left_measure','auto',0,''),(173248,55338,'117289','furniture-mobile','margin_right_measure','auto',0,''),(173249,55339,'117290','furniture-mobile','block_type','8',0,''),(173250,55339,'117290','furniture-mobile','schema','8-6',0,'2885'),(173251,55340,'117291','furniture-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(173252,55341,'117292','furniture-mobile','block_type','1',0,''),(173253,55341,'117292','furniture-mobile','padding-left','20',0,''),(173254,55341,'117292','furniture-mobile','padding-right','20',0,''),(173255,55342,'117293','furniture-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(173256,55344,'117295','furniture-mobile','block_type','1',0,''),(173257,55345,'117296','furniture-mobile','text','##TEXT_OR##',0,''),(173258,55345,'117296','furniture-mobile','font-size','18',0,''),(173259,55345,'117296','furniture-mobile','font-weight','700',0,''),(173260,55345,'117296','furniture-mobile','padding-top','15',0,''),(173261,55345,'117296','furniture-mobile','text-align','center',0,''),(173262,55345,'117296','furniture-mobile','content','\\_',0,'3'),(173263,55345,'117296','furniture-mobile','height','5',0,'3'),(173264,55345,'117296','furniture-mobile','width','70',0,'3'),(173265,55345,'117296','furniture-mobile','display','inline-block',0,'3'),(173266,55345,'117296','furniture-mobile','border-top-width','1',0,'3'),(173267,55345,'117296','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173268,55345,'117296','furniture-mobile','margin-left','10',0,'3'),(173269,55345,'117296','furniture-mobile','margin-right','10',0,'3'),(173270,55345,'117296','furniture-mobile','content','\\_',0,'4'),(173271,55345,'117296','furniture-mobile','display','inline-block',0,'4'),(173272,55345,'117296','furniture-mobile','width','70',0,'4'),(173273,55345,'117296','furniture-mobile','height','5',0,'4'),(173274,55345,'117296','furniture-mobile','border-top-width','1',0,'4'),(173275,55345,'117296','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173276,55345,'117296','furniture-mobile','margin-left','10',0,'4'),(173277,55345,'117296','furniture-mobile','margin-right','10',0,'4'),(173278,55345,'117296','furniture-mobile','position','relative',0,''),(173279,55345,'117296','furniture-mobile','top','-10',0,''),(173280,55346,'117297','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173281,55346,'117297','furniture-mobile','font-size','26',0,''),(173282,55346,'117297','furniture-mobile','font-family','$font-1',0,''),(173283,55346,'117297','furniture-mobile','padding-top','15',0,''),(173284,55346,'117297','furniture-mobile','padding-bottom','15',0,''),(173285,55346,'117297','furniture-mobile','text-align','center',0,''),(173286,55347,'117298','furniture-mobile','text-align','center',0,''),(173287,55347,'117298','furniture-mobile','hide_parents','2',0,''),(173288,55348,'117299','furniture-mobile','block_type','1',0,''),(173289,55348,'117299','furniture-mobile','padding-top','40',0,''),(173290,55348,'117299','furniture-mobile','background-color','$background-6',0,''),(173291,55348,'117299','furniture-mobile','padding-bottom','40',0,''),(173292,55348,'117299','furniture-mobile','style_class','checkout-login-wrap',0,''),(173293,55349,'117300','furniture-mobile','block_type','2',0,''),(173294,55349,'117300','furniture-mobile','background-color','$background-7',0,''),(173295,55349,'117300','furniture-mobile','max-width','830',0,''),(173296,55349,'117300','furniture-mobile','margin_left_measure','auto',0,''),(173297,55349,'117300','furniture-mobile','margin_right_measure','auto',0,''),(173298,55349,'117300','furniture-mobile','padding-top','40',0,''),(173299,55349,'117300','furniture-mobile','padding-bottom','40',0,''),(173300,55349,'117300','furniture-mobile','schema','2-3',0,'2885'),(173301,55350,'117301','furniture-mobile','text-align','center',0,''),(173302,55350,'117301','furniture-mobile','margin-bottom','40',0,''),(173303,55351,'117302','furniture-mobile','text-align','center',0,''),(173304,55352,'117303','furniture-mobile','text','##TEXT_OR##',0,''),(173305,55352,'117303','furniture-mobile','font-size','18',0,''),(173306,55352,'117303','furniture-mobile','font-weight','700',0,''),(173307,55352,'117303','furniture-mobile','text-align','center',0,''),(173308,55352,'117303','furniture-mobile','content','\\_',0,'3'),(173309,55352,'117303','furniture-mobile','height','5',0,'3'),(173310,55352,'117303','furniture-mobile','width','70',0,'3'),(173311,55352,'117303','furniture-mobile','display','inline-block',0,'3'),(173312,55352,'117303','furniture-mobile','border-top-width','1',0,'3'),(173313,55352,'117303','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173314,55352,'117303','furniture-mobile','margin-left','10',0,'3'),(173315,55352,'117303','furniture-mobile','margin-right','10',0,'3'),(173316,55352,'117303','furniture-mobile','content','\\_',0,'4'),(173317,55352,'117303','furniture-mobile','display','inline-block',0,'4'),(173318,55352,'117303','furniture-mobile','width','70',0,'4'),(173319,55352,'117303','furniture-mobile','height','5',0,'4'),(173320,55352,'117303','furniture-mobile','border-top-width','1',0,'4'),(173321,55352,'117303','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173322,55352,'117303','furniture-mobile','margin-left','10',0,'4'),(173323,55352,'117303','furniture-mobile','margin-right','10',0,'4'),(173324,55352,'117303','furniture-mobile','position','relative',0,''),(173325,55352,'117303','furniture-mobile','padding-top','10',0,''),(173326,55352,'117303','furniture-mobile','padding-bottom','10',0,''),(173327,55353,'117304','furniture-mobile','block_type','1',0,''),(173328,55354,'117305','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173329,55354,'117305','furniture-mobile','font-size','18',0,''),(173330,55354,'117305','furniture-mobile','font-family','$font-1',0,''),(173331,55354,'117305','furniture-mobile','padding-top','15',0,''),(173332,55354,'117305','furniture-mobile','padding-bottom','15',0,''),(173333,55354,'117305','furniture-mobile','text-align','center',0,''),(173334,55354,'117305','furniture-mobile','text-transform','uppercase',0,''),(173335,55355,'117306','furniture-mobile','text-align','center',0,''),(173336,55355,'117306','furniture-mobile','hide_parents','2',0,''),(173337,55356,'117307','furniture-mobile','text','##NEW_CUSTOMER##',0,''),(173338,55356,'117307','furniture-mobile','font-size','18',0,''),(173339,55356,'117307','furniture-mobile','font-family','$font-1',0,''),(173340,55356,'117307','furniture-mobile','text-align','center',0,''),(173341,55356,'117307','furniture-mobile','text-transform','uppercase',0,''),(173342,55356,'117307','furniture-mobile','margin-bottom','10',0,''),(173343,55357,'117308','furniture-mobile','max-width','230',0,''),(173344,55357,'117308','furniture-mobile','margin_left_measure','auto',0,''),(173345,55357,'117308','furniture-mobile','margin_right_measure','auto',0,''),(173346,55358,'117309','furniture-mobile','text','##RETURNING_CUSTOMER##',0,''),(173347,55358,'117309','furniture-mobile','font-size','18',0,''),(173348,55358,'117309','furniture-mobile','font-family','$font-1',0,''),(173349,55358,'117309','furniture-mobile','text-transform','uppercase',0,''),(173350,55358,'117309','furniture-mobile','text-align','center',0,''),(173351,55359,'117310','furniture-mobile','block_type','1',0,''),(173352,55359,'117310','furniture-mobile','padding-top','20',0,''),(173353,55360,'117311','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(173354,55360,'117311','furniture-mobile','tab_2','RETURNING CUSTOMER',1,''),(173355,55360,'117311','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(173356,55361,'117312','furniture-mobile','block_type','8',0,''),(173357,55362,'117313','furniture-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(173358,55363,'117314','furniture-mobile','block_type','1',0,''),(173359,55363,'117314','furniture-mobile','padding-left','20',0,''),(173360,55363,'117314','furniture-mobile','padding-right','20',0,''),(173361,55365,'117316','furniture-mobile','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(173362,55365,'117316','furniture-mobile','border-top-width','1',0,''),(173363,55365,'117316','furniture-mobile','border-top-color','$border-color-4',0,''),(173364,55367,'117318','furniture-mobile','block_type','8',0,''),(173365,55368,'117319','furniture-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(173366,55369,'117320','furniture-mobile','block_type','1',0,''),(173367,55369,'117320','furniture-mobile','padding-left','20',0,''),(173368,55369,'117320','furniture-mobile','padding-right','20',0,''),(173369,55370,'117321','furniture-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(173370,55372,'117323','furniture-mobile','text-align','center',0,''),(173371,55373,'117324','furniture-mobile','text','##TEXT_OR##',0,''),(173372,55373,'117324','furniture-mobile','font-size','18',0,''),(173373,55373,'117324','furniture-mobile','font-weight','700',0,''),(173374,55373,'117324','furniture-mobile','padding-top','15',0,''),(173375,55373,'117324','furniture-mobile','text-align','center',0,''),(173376,55373,'117324','furniture-mobile','content','\\_',0,'3'),(173377,55373,'117324','furniture-mobile','height','5',0,'3'),(173378,55373,'117324','furniture-mobile','width','70',0,'3'),(173379,55373,'117324','furniture-mobile','display','inline-block',0,'3'),(173380,55373,'117324','furniture-mobile','border-top-width','1',0,'3'),(173381,55373,'117324','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173382,55373,'117324','furniture-mobile','margin-left','10',0,'3'),(173383,55373,'117324','furniture-mobile','margin-right','10',0,'3'),(173384,55373,'117324','furniture-mobile','content','\\_',0,'4'),(173385,55373,'117324','furniture-mobile','display','inline-block',0,'4'),(173386,55373,'117324','furniture-mobile','width','70',0,'4'),(173387,55373,'117324','furniture-mobile','height','5',0,'4'),(173388,55373,'117324','furniture-mobile','border-top-width','1',0,'4'),(173389,55373,'117324','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173390,55373,'117324','furniture-mobile','margin-left','10',0,'4'),(173391,55373,'117324','furniture-mobile','margin-right','10',0,'4'),(173392,55373,'117324','furniture-mobile','position','relative',0,''),(173393,55373,'117324','furniture-mobile','top','-10',0,''),(173394,55374,'117325','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173395,55374,'117325','furniture-mobile','font-size','26',0,''),(173396,55374,'117325','furniture-mobile','font-family','$font-1',0,''),(173397,55374,'117325','furniture-mobile','padding-top','15',0,''),(173398,55374,'117325','furniture-mobile','padding-bottom','15',0,''),(173399,55374,'117325','furniture-mobile','text-align','center',0,''),(173400,55375,'117326','furniture-mobile','block_type','1',0,''),(173401,55375,'117326','furniture-mobile','padding-top','20',0,''),(173402,55376,'117327','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(173403,55376,'117327','furniture-mobile','tab_2','RETURNING CUSTOMER',1,''),(173404,55376,'117327','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(173405,55377,'117328','furniture-mobile','block_type','8',0,''),(173406,55378,'117329','furniture-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(173407,55381,'117332','furniture-mobile','block_type','8',0,''),(173408,55382,'117333','furniture-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(173409,55384,'117335','furniture-mobile','block_type','1',0,''),(173410,55384,'117335','furniture-mobile','padding-left','20',0,''),(173411,55384,'117335','furniture-mobile','padding-right','20',0,''),(173412,55386,'117337','furniture-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(173413,55387,'117338','furniture-mobile','text','##TEXT_OR##',0,''),(173414,55387,'117338','furniture-mobile','font-size','18',0,''),(173415,55387,'117338','furniture-mobile','font-weight','700',0,''),(173416,55387,'117338','furniture-mobile','padding-top','15',0,''),(173417,55387,'117338','furniture-mobile','text-align','center',0,''),(173418,55387,'117338','furniture-mobile','content','\\_',0,'3'),(173419,55387,'117338','furniture-mobile','height','5',0,'3'),(173420,55387,'117338','furniture-mobile','width','70',0,'3'),(173421,55387,'117338','furniture-mobile','display','inline-block',0,'3'),(173422,55387,'117338','furniture-mobile','border-top-width','1',0,'3'),(173423,55387,'117338','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173424,55387,'117338','furniture-mobile','margin-left','10',0,'3'),(173425,55387,'117338','furniture-mobile','margin-right','10',0,'3'),(173426,55387,'117338','furniture-mobile','content','\\_',0,'4'),(173427,55387,'117338','furniture-mobile','display','inline-block',0,'4'),(173428,55387,'117338','furniture-mobile','width','70',0,'4'),(173429,55387,'117338','furniture-mobile','height','5',0,'4'),(173430,55387,'117338','furniture-mobile','border-top-width','1',0,'4'),(173431,55387,'117338','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173432,55387,'117338','furniture-mobile','margin-left','10',0,'4'),(173433,55387,'117338','furniture-mobile','margin-right','10',0,'4'),(173434,55387,'117338','furniture-mobile','position','relative',0,''),(173435,55387,'117338','furniture-mobile','top','-10',0,''),(173436,55388,'117339','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173437,55388,'117339','furniture-mobile','font-size','26',0,''),(173438,55388,'117339','furniture-mobile','font-family','$font-1',0,''),(173439,55388,'117339','furniture-mobile','padding-top','15',0,''),(173440,55388,'117339','furniture-mobile','padding-bottom','15',0,''),(173441,55388,'117339','furniture-mobile','text-align','center',0,''),(173442,55389,'117340','furniture-mobile','text-align','center',0,''),(173443,55390,'117341','furniture-mobile','block_type','1',0,''),(173444,55390,'117341','furniture-mobile','padding-top','20',0,''),(173445,55391,'117342','furniture-mobile','text-align','center',0,''),(173446,55392,'117343','furniture-mobile','text','##TEXT_OR##',0,''),(173447,55392,'117343','furniture-mobile','font-size','18',0,''),(173448,55392,'117343','furniture-mobile','font-weight','700',0,''),(173449,55392,'117343','furniture-mobile','padding-top','15',0,''),(173450,55392,'117343','furniture-mobile','text-align','center',0,''),(173451,55392,'117343','furniture-mobile','content','\\_',0,'3'),(173452,55392,'117343','furniture-mobile','height','5',0,'3'),(173453,55392,'117343','furniture-mobile','width','70',0,'3'),(173454,55392,'117343','furniture-mobile','display','inline-block',0,'3'),(173455,55392,'117343','furniture-mobile','border-top-width','1',0,'3'),(173456,55392,'117343','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173457,55392,'117343','furniture-mobile','margin-left','10',0,'3'),(173458,55392,'117343','furniture-mobile','margin-right','10',0,'3'),(173459,55392,'117343','furniture-mobile','content','\\_',0,'4'),(173460,55392,'117343','furniture-mobile','display','inline-block',0,'4'),(173461,55392,'117343','furniture-mobile','width','70',0,'4'),(173462,55392,'117343','furniture-mobile','height','5',0,'4'),(173463,55392,'117343','furniture-mobile','border-top-width','1',0,'4'),(173464,55392,'117343','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173465,55392,'117343','furniture-mobile','margin-left','10',0,'4'),(173466,55392,'117343','furniture-mobile','margin-right','10',0,'4'),(173467,55392,'117343','furniture-mobile','position','relative',0,''),(173468,55392,'117343','furniture-mobile','top','-10',0,''),(173469,55393,'117344','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(173470,55393,'117344','furniture-mobile','tab_2','RETURNING CUSTOMER',1,''),(173471,55393,'117344','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(173472,55394,'117345','furniture-mobile','block_type','8',0,''),(173473,55395,'117346','furniture-mobile','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(173474,55398,'117349','furniture-mobile','block_type','8',0,''),(173475,55399,'117350','furniture-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(173476,55400,'117351','furniture-mobile','block_type','1',0,''),(173477,55400,'117351','furniture-mobile','padding-left','20',0,''),(173478,55400,'117351','furniture-mobile','padding-right','20',0,''),(173479,55402,'117353','furniture-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(173480,55403,'117354','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173481,55403,'117354','furniture-mobile','font-size','26',0,''),(173482,55403,'117354','furniture-mobile','font-family','$font-1',0,''),(173483,55403,'117354','furniture-mobile','padding-top','15',0,''),(173484,55403,'117354','furniture-mobile','padding-bottom','15',0,''),(173485,55403,'117354','furniture-mobile','text-align','center',0,''),(173486,55404,'117355','furniture-mobile','block_type','1',0,''),(173487,55404,'117355','furniture-mobile','padding-top','40',0,''),(173488,55404,'117355','furniture-mobile','background-color','$background-6',0,''),(173489,55404,'117355','furniture-mobile','padding-bottom','40',0,''),(173490,55405,'117356','furniture-mobile','block_type','2',0,''),(173491,55405,'117356','furniture-mobile','background-color','$background-7',0,''),(173492,55405,'117356','furniture-mobile','max-width','830',0,''),(173493,55405,'117356','furniture-mobile','margin_left_measure','auto',0,''),(173494,55405,'117356','furniture-mobile','margin_right_measure','auto',0,''),(173495,55405,'117356','furniture-mobile','padding-top','40',0,''),(173496,55405,'117356','furniture-mobile','padding-bottom','40',0,''),(173497,55405,'117356','furniture-mobile','schema','2-3',0,'2885'),(173498,55406,'117357','furniture-mobile','block_type','1',0,''),(173499,55407,'117358','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173500,55407,'117358','furniture-mobile','font-size','18',0,''),(173501,55407,'117358','furniture-mobile','font-family','$font-1',0,''),(173502,55407,'117358','furniture-mobile','padding-top','15',0,''),(173503,55407,'117358','furniture-mobile','padding-bottom','15',0,''),(173504,55407,'117358','furniture-mobile','text-align','center',0,''),(173505,55407,'117358','furniture-mobile','text-transform','uppercase',0,''),(173506,55408,'117359','furniture-mobile','text-align','center',0,''),(173507,55408,'117359','furniture-mobile','hide_parents','2',0,''),(173508,55409,'117360','furniture-mobile','text-align','center',0,''),(173509,55410,'117361','furniture-mobile','text-align','center',0,''),(173510,55410,'117361','furniture-mobile','margin-bottom','40',0,''),(173511,55411,'117362','furniture-mobile','text','##TEXT_OR##',0,''),(173512,55411,'117362','furniture-mobile','font-size','18',0,''),(173513,55411,'117362','furniture-mobile','font-weight','700',0,''),(173514,55411,'117362','furniture-mobile','text-align','center',0,''),(173515,55411,'117362','furniture-mobile','content','\\_',0,'3'),(173516,55411,'117362','furniture-mobile','height','5',0,'3'),(173517,55411,'117362','furniture-mobile','width','70',0,'3'),(173518,55411,'117362','furniture-mobile','display','inline-block',0,'3'),(173519,55411,'117362','furniture-mobile','border-top-width','1',0,'3'),(173520,55411,'117362','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173521,55411,'117362','furniture-mobile','margin-left','10',0,'3'),(173522,55411,'117362','furniture-mobile','margin-right','10',0,'3'),(173523,55411,'117362','furniture-mobile','content','\\_',0,'4'),(173524,55411,'117362','furniture-mobile','display','inline-block',0,'4'),(173525,55411,'117362','furniture-mobile','width','70',0,'4'),(173526,55411,'117362','furniture-mobile','height','5',0,'4'),(173527,55411,'117362','furniture-mobile','border-top-width','1',0,'4'),(173528,55411,'117362','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173529,55411,'117362','furniture-mobile','margin-left','10',0,'4'),(173530,55411,'117362','furniture-mobile','margin-right','10',0,'4'),(173531,55411,'117362','furniture-mobile','position','relative',0,''),(173532,55411,'117362','furniture-mobile','padding-top','10',0,''),(173533,55411,'117362','furniture-mobile','padding-bottom','10',0,''),(173534,55412,'117363','furniture-mobile','text','##NEW_CUSTOMER##',0,''),(173535,55412,'117363','furniture-mobile','font-size','18',0,''),(173536,55412,'117363','furniture-mobile','font-family','$font-1',0,''),(173537,55412,'117363','furniture-mobile','text-align','center',0,''),(173538,55412,'117363','furniture-mobile','text-transform','uppercase',0,''),(173539,55412,'117363','furniture-mobile','margin-bottom','10',0,''),(173540,55413,'117364','furniture-mobile','text','##RETURNING_CUSTOMER##',0,''),(173541,55413,'117364','furniture-mobile','font-size','18',0,''),(173542,55413,'117364','furniture-mobile','font-family','$font-1',0,''),(173543,55413,'117364','furniture-mobile','text-transform','uppercase',0,''),(173544,55413,'117364','furniture-mobile','text-align','center',0,''),(173545,55414,'117365','furniture-mobile','max-width','230',0,''),(173546,55414,'117365','furniture-mobile','margin_left_measure','auto',0,''),(173547,55414,'117365','furniture-mobile','margin_right_measure','auto',0,''),(173548,55415,'117366','furniture-mobile','block_type','1',0,''),(173549,55415,'117366','furniture-mobile','padding-top','40',0,''),(173550,55415,'117366','furniture-mobile','background-color','$background-6',0,''),(173551,55415,'117366','furniture-mobile','padding-bottom','40',0,''),(173552,55416,'117367','furniture-mobile','block_type','2',0,''),(173553,55416,'117367','furniture-mobile','background-color','$background-7',0,''),(173554,55416,'117367','furniture-mobile','max-width','830',0,''),(173555,55416,'117367','furniture-mobile','margin_left_measure','auto',0,''),(173556,55416,'117367','furniture-mobile','margin_right_measure','auto',0,''),(173557,55416,'117367','furniture-mobile','padding-top','40',0,''),(173558,55416,'117367','furniture-mobile','padding-bottom','40',0,''),(173559,55416,'117367','furniture-mobile','schema','2-3',0,'2885'),(173560,55417,'117368','furniture-mobile','text','##NEW_CUSTOMER##',0,''),(173561,55417,'117368','furniture-mobile','font-size','18',0,''),(173562,55417,'117368','furniture-mobile','font-family','$font-1',0,''),(173563,55417,'117368','furniture-mobile','text-align','center',0,''),(173564,55417,'117368','furniture-mobile','text-transform','uppercase',0,''),(173565,55417,'117368','furniture-mobile','margin-bottom','10',0,''),(173566,55418,'117369','furniture-mobile','text-align','center',0,''),(173567,55419,'117370','furniture-mobile','text-align','center',0,''),(173568,55419,'117370','furniture-mobile','margin-bottom','40',0,''),(173569,55420,'117371','furniture-mobile','text','##TEXT_OR##',0,''),(173570,55420,'117371','furniture-mobile','font-size','18',0,''),(173571,55420,'117371','furniture-mobile','font-weight','700',0,''),(173572,55420,'117371','furniture-mobile','text-align','center',0,''),(173573,55420,'117371','furniture-mobile','content','\\_',0,'3'),(173574,55420,'117371','furniture-mobile','height','5',0,'3'),(173575,55420,'117371','furniture-mobile','width','70',0,'3'),(173576,55420,'117371','furniture-mobile','display','inline-block',0,'3'),(173577,55420,'117371','furniture-mobile','border-top-width','1',0,'3'),(173578,55420,'117371','furniture-mobile','border-top-color','$border-color-4',0,'3'),(173579,55420,'117371','furniture-mobile','margin-left','10',0,'3'),(173580,55420,'117371','furniture-mobile','margin-right','10',0,'3'),(173581,55420,'117371','furniture-mobile','content','\\_',0,'4'),(173582,55420,'117371','furniture-mobile','display','inline-block',0,'4'),(173583,55420,'117371','furniture-mobile','width','70',0,'4'),(173584,55420,'117371','furniture-mobile','height','5',0,'4'),(173585,55420,'117371','furniture-mobile','border-top-width','1',0,'4'),(173586,55420,'117371','furniture-mobile','border-top-color','$border-color-4',0,'4'),(173587,55420,'117371','furniture-mobile','margin-left','10',0,'4'),(173588,55420,'117371','furniture-mobile','margin-right','10',0,'4'),(173589,55420,'117371','furniture-mobile','position','relative',0,''),(173590,55420,'117371','furniture-mobile','padding-top','10',0,''),(173591,55420,'117371','furniture-mobile','padding-bottom','10',0,''),(173592,55421,'117372','furniture-mobile','block_type','1',0,''),(173593,55422,'117373','furniture-mobile','text','##LOGIN_WITH_SOCIAL##',0,''),(173594,55422,'117373','furniture-mobile','font-size','18',0,''),(173595,55422,'117373','furniture-mobile','font-family','$font-1',0,''),(173596,55422,'117373','furniture-mobile','padding-top','15',0,''),(173597,55422,'117373','furniture-mobile','padding-bottom','15',0,''),(173598,55422,'117373','furniture-mobile','text-align','center',0,''),(173599,55422,'117373','furniture-mobile','text-transform','uppercase',0,''),(173600,55423,'117374','furniture-mobile','text-align','center',0,''),(173601,55423,'117374','furniture-mobile','hide_parents','2',0,''),(173602,55424,'117375','furniture-mobile','text','##RETURNING_CUSTOMER##',0,''),(173603,55424,'117375','furniture-mobile','font-size','18',0,''),(173604,55424,'117375','furniture-mobile','font-family','$font-1',0,''),(173605,55424,'117375','furniture-mobile','text-transform','uppercase',0,''),(173606,55424,'117375','furniture-mobile','text-align','center',0,''),(173607,55425,'117376','furniture-mobile','max-width','230',0,''),(173608,55425,'117376','furniture-mobile','margin_left_measure','auto',0,''),(173609,55425,'117376','furniture-mobile','margin_right_measure','auto',0,''),(173610,55426,'117377','furniture-mobile','block_type','1',0,''),(173611,55427,'117378','furniture-mobile','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(173612,55427,'117378','furniture-mobile','margin-bottom','30',0,''),(173613,55428,'117379','furniture-mobile','block_type','1',0,''),(173614,55429,'117380','furniture-mobile','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(173615,55429,'117380','furniture-mobile','margin-bottom','30',0,''),(173616,55430,'117386','furniture-mobile','block_type','1',0,''),(173617,55430,'117386','furniture-mobile','font-weight','normal',0,''),(173618,55431,'120856','furniture-mobile','block_type','1',0,''),(173619,55431,'120856','furniture-mobile','style_class','lowestPricedBox',0,''),(173620,55432,'120857','furniture-mobile','banners_group','21',0,''),(173621,55433,'120858','furniture-mobile','block_type','3',0,''),(173622,55433,'120858','furniture-mobile','style_class','tripleBanner',0,''),(173623,55434,'120859','furniture-mobile','text','<div>Returns and Exchanges</div>\n<div>30 Day Satisfaction Guarantee</div>\n',0,''),(173624,55434,'120859','furniture-mobile','style_class','returns',0,''),(173625,55435,'120860','furniture-mobile','text','<div>Warranty</div>\n<div>Min 12 months manufacturer’s warranty</div>',0,''),(173626,55435,'120860','furniture-mobile','style_class','warranty',0,''),(173627,55436,'120861','furniture-mobile','text','<div>Track your order</div>\n<div>Check the current status of your order</div>',0,''),(173628,55436,'120861','furniture-mobile','style_class','track',0,''),(173629,55437,'120862','furniture-mobile','block_type','1',0,''),(173630,55438,'117389','furniture-mobile','col_in_row','4',0,''),(173631,55438,'117389','furniture-mobile','view_as','carousel',0,''),(173632,55438,'117389','furniture-mobile','show_attributes','1',0,''),(173633,55438,'117389','furniture-mobile','col_in_row','3',0,'2885'),(173634,55438,'117389','furniture-mobile','col_in_row','2',0,'2876'),(173635,55438,'117389','furniture-mobile','col_in_row','1',0,'2906'),(173636,55438,'117389','furniture-mobile','listing_type','productListing',0,''),(173637,55438,'117389','furniture-mobile','show_qty_input','1',0,''),(173638,55438,'117389','furniture-mobile','show_compare','1',0,''),(173639,55438,'117389','furniture-mobile','lazy_load','1',0,''),(173640,55438,'117389','furniture-mobile','show_model','1',0,''),(173641,55438,'117389','furniture-mobile','show_properties','1',0,''),(173642,55438,'117389','furniture-mobile','show_bonus_points','1',0,''),(173643,55438,'117389','furniture-mobile','show_buy_button','1',0,''),(173644,55438,'117389','furniture-mobile','show_view_button','1',0,''),(173645,55438,'117389','furniture-mobile','show_wishlist_button','1',0,''),(173646,55438,'117389','furniture-mobile','hide_parents','2',0,''),(173647,55439,'121014','furniture-mobile','text','<h2>Furniture deals</h2>',0,''),(173648,55440,'120864','furniture-mobile','block_type','1',0,''),(173649,55440,'120864','furniture-mobile','style_class','shopByCollectionBox',0,''),(173650,55440,'120864','furniture-mobile','padding-bottom','30',0,''),(173651,55441,'120865','furniture-mobile','banners_group','Shop_by_co',0,''),(173652,55441,'120865','furniture-mobile','banners_type','banner',0,''),(173653,55442,'121015','furniture-mobile','text','<h2>Shop by collection</h2> ',0,''),(173654,55443,'1683022993.8509','furniture-mobile','block_type','1',0,''),(173655,55443,'1683022993.8509','furniture-mobile','style_class','mainBanner',0,''),(173656,55444,'1683023028.4274','furniture-mobile','banners_type','carousel',0,''),(173657,55444,'1683023028.4274','furniture-mobile','banners_group','3',0,''),(173658,55445,'117394','furniture-mobile','block_type','1',0,''),(173659,55446,'117395','furniture-mobile','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(173660,55448,'117397','furniture-mobile','block_type','1',0,''),(173661,55448,'117397','furniture-mobile','padding-top','40',0,''),(173662,55448,'117397','furniture-mobile','padding-bottom','80',0,''),(173663,55449,'117398','furniture-mobile','block_type','6',0,''),(173664,55450,'117399','furniture-mobile','block_type','1',0,''),(173665,55450,'117399','furniture-mobile','padding-top','20',0,''),(173666,55450,'117399','furniture-mobile','padding-left','20',0,''),(173667,55450,'117399','furniture-mobile','padding-right','20',0,''),(173668,55450,'117399','furniture-mobile','padding-bottom','20',0,''),(173669,55450,'117399','furniture-mobile','border-top-width','1',0,''),(173670,55450,'117399','furniture-mobile','border-left-width','1',0,''),(173671,55450,'117399','furniture-mobile','border-right-width','1',0,''),(173672,55450,'117399','furniture-mobile','border-bottom-width','1',0,''),(173673,55450,'117399','furniture-mobile','border-top-color','$border-color-4',0,''),(173674,55450,'117399','furniture-mobile','border-left-color','$border-color-4',0,''),(173675,55450,'117399','furniture-mobile','border-right-color','$border-color-4',0,''),(173676,55450,'117399','furniture-mobile','border-bottom-color','$border-color-4',0,''),(173677,55450,'117399','furniture-mobile','margin-right','20',0,''),(173678,55453,'117402','furniture-mobile','block_type','1',0,''),(173679,55453,'117402','furniture-mobile','padding-top','20',0,''),(173680,55454,'117403','furniture-mobile','block_type','6',0,''),(173681,55455,'117404','furniture-mobile','padding-right','20',0,''),(173682,55457,'117406','furniture-mobile','block_type','1',0,''),(173683,55457,'117406','furniture-mobile','padding-top','20',0,''),(173684,55458,'117407','furniture-mobile','block_type','6',0,''),(173685,55459,'117408','furniture-mobile','padding-right','20',0,''),(173686,55461,'117410','furniture-mobile','block_type','1',0,''),(173687,55461,'117410','furniture-mobile','style_class','account-password-wrap',0,''),(173688,55462,'117411','furniture-mobile','block_type','6',0,''),(173689,55462,'117411','furniture-mobile','schema','6-3',0,'2885'),(173690,55463,'117412','furniture-mobile','aria_name','account-menu',0,''),(173747,55484,'117414','furniture-mobile','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(173748,55485,'117415','furniture-mobile','block_type','1',0,''),(173749,55485,'117415','furniture-mobile','padding-top','20',0,''),(173750,55486,'117416','furniture-mobile','tab_1','RETURNING CUSTOMER',1,''),(173751,55486,'117416','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(173752,55487,'117417','furniture-mobile','max-width','800',0,''),(173753,55487,'117417','furniture-mobile','margin_left_measure','auto',0,''),(173754,55487,'117417','furniture-mobile','margin_right_measure','auto',0,''),(173755,55488,'117418','furniture-mobile','block_type','8',0,''),(173756,55489,'117419','furniture-mobile','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(173757,55490,'117420','furniture-mobile','block_type','1',0,''),(173758,55490,'117420','furniture-mobile','padding-left','20',0,''),(173759,55490,'117420','furniture-mobile','padding-right','20',0,''),(173760,55492,'117422','furniture-mobile','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(173761,55493,'117423','furniture-mobile','block_type','1',0,''),(173762,55494,'117424','furniture-mobile','block_type','1',0,''),(173763,55495,'117425','furniture-mobile','margin-left','0',0,''),(173764,55495,'117425','furniture-mobile','margin-right','0',0,''),(173765,55495,'117425','furniture-mobile','margin-bottom','20',0,''),(173766,55496,'117426','furniture-mobile','margin-bottom','30',0,''),(173767,55497,'117427','furniture-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(173768,55498,'117428','furniture-mobile','block_type','1',0,''),(173769,55500,'117430','furniture-mobile','block_type','6',0,''),(173770,55500,'117430','furniture-mobile','font-weight','400',0,''),(173771,55500,'117430','furniture-mobile','schema','6-2',0,'2906'),(173772,55500,'117430','furniture-mobile','schema','6-2',0,'2885'),(173773,55501,'117431','furniture-mobile','font-weight','400',0,''),(173774,55501,'117431','furniture-mobile','padding-right','40',0,''),(173775,55501,'117431','furniture-mobile','padding-right','0',0,'2906'),(173776,55501,'117431','furniture-mobile','padding-right','0',0,'2885'),(173777,55502,'117432','furniture-mobile','col_in_row','3',0,''),(173778,55502,'117432','furniture-mobile','products_align','left',0,''),(173779,55502,'117432','furniture-mobile','font-weight','400',0,''),(173780,55502,'117432','furniture-mobile','show_qty_input','0',0,''),(173781,55502,'117432','furniture-mobile','listing_type','productListing',0,''),(173782,55502,'117432','furniture-mobile','listing_type_rows','no',0,''),(173783,55502,'117432','furniture-mobile','show_buy_button_b2b','on',0,''),(173784,55502,'117432','furniture-mobile','show_wishlist_button_b2b','1',0,''),(173785,55502,'117432','furniture-mobile','show_compare_b2b','1',0,''),(173786,55502,'117432','furniture-mobile','show_stock','0',0,''),(173787,55502,'117432','furniture-mobile','show_description','0',0,''),(173788,55502,'117432','furniture-mobile','show_model','0',0,''),(173789,55502,'117432','furniture-mobile','show_properties','0',0,''),(173790,55502,'117432','furniture-mobile','show_rating','0',0,''),(173791,55502,'117432','furniture-mobile','show_rating_counts','0',0,''),(173792,55502,'117432','furniture-mobile','show_price','0',0,''),(173793,55502,'117432','furniture-mobile','show_buy_button','0',0,''),(173794,55502,'117432','furniture-mobile','show_view_button','0',0,''),(173795,55502,'117432','furniture-mobile','show_wishlist_button','0',0,''),(173796,55502,'117432','furniture-mobile','show_compare','0',0,''),(173797,55502,'117432','furniture-mobile','show_name_rows','0',0,''),(173798,55502,'117432','furniture-mobile','show_image_rows','0',0,''),(173799,55502,'117432','furniture-mobile','show_stock_rows','0',0,''),(173800,55502,'117432','furniture-mobile','show_description_rows','0',0,''),(173801,55502,'117432','furniture-mobile','show_model_rows','0',0,''),(173802,55502,'117432','furniture-mobile','show_properties_rows','0',0,''),(173803,55502,'117432','furniture-mobile','show_rating_rows','0',0,''),(173804,55502,'117432','furniture-mobile','show_rating_counts_rows','0',0,''),(173805,55502,'117432','furniture-mobile','show_price_rows','0',0,''),(173806,55502,'117432','furniture-mobile','show_buy_button_rows','0',0,''),(173807,55502,'117432','furniture-mobile','show_qty_input_rows','0',0,''),(173808,55502,'117432','furniture-mobile','show_view_button_rows','0',0,''),(173809,55502,'117432','furniture-mobile','show_wishlist_button_rows','0',0,''),(173810,55502,'117432','furniture-mobile','show_compare_rows','0',0,''),(173811,55502,'117432','furniture-mobile','show_name_b2b','0',0,''),(173812,55502,'117432','furniture-mobile','show_image_b2b','0',0,''),(173813,55502,'117432','furniture-mobile','show_stock_b2b','0',0,''),(173814,55502,'117432','furniture-mobile','show_description_b2b','0',0,''),(173815,55502,'117432','furniture-mobile','show_model_b2b','0',0,''),(173816,55502,'117432','furniture-mobile','show_properties_b2b','0',0,''),(173817,55502,'117432','furniture-mobile','show_rating_b2b','0',0,''),(173818,55502,'117432','furniture-mobile','show_rating_counts_b2b','0',0,''),(173819,55502,'117432','furniture-mobile','show_price_b2b','0',0,''),(173820,55502,'117432','furniture-mobile','show_qty_input_b2b','0',0,''),(173821,55502,'117432','furniture-mobile','show_view_button_b2b','0',0,''),(173822,55502,'117432','furniture-mobile','show_attributes_b2b','0',0,''),(173823,55502,'117432','furniture-mobile','items_on_page','9',0,''),(173824,55502,'117432','furniture-mobile','col_in_row','2',0,'2885'),(173825,55502,'117432','furniture-mobile','col_in_row','1',0,'2906'),(173826,55502,'117432','furniture-mobile','product_names_teg','h2',0,''),(173827,55504,'117434','furniture-mobile','block_type','5',0,''),(173828,55504,'117434','furniture-mobile','padding-top','10',0,''),(173829,55504,'117434','furniture-mobile','padding-bottom','10',0,''),(173830,55504,'117434','furniture-mobile','schema','5-2',0,'2906'),(173831,55504,'117434','furniture-mobile','border-top-color','$border-color-4',0,''),(173832,55504,'117434','furniture-mobile','border-top-width','1',0,''),(173833,55506,'117436','furniture-mobile','float','right',0,''),(173834,55507,'117437','furniture-mobile','listing_type','productListing',0,''),(173835,55509,'117439','furniture-mobile','block_type','1',0,''),(173836,55509,'117439','furniture-mobile','padding-top','10',0,''),(173837,55509,'117439','furniture-mobile','padding-bottom','10',0,''),(173838,55509,'117439','furniture-mobile','border-bottom-width','1',0,''),(173839,55509,'117439','furniture-mobile','border-bottom-color','$border-color-4',0,''),(173840,55509,'117439','furniture-mobile','margin-left','0',0,''),(173841,55509,'117439','furniture-mobile','margin-right','0',0,''),(173842,55510,'117440','furniture-mobile','float','right',0,''),(173843,55510,'117440','furniture-mobile','display','none',0,'2906'),(173844,55511,'117441','furniture-mobile','float','left',0,''),(173845,55511,'117441','furniture-mobile','clear','none',0,''),(173846,55511,'117441','furniture-mobile','margin-left','20',0,''),(173847,55511,'117441','furniture-mobile','display','none',0,'2906'),(173848,55512,'117442','furniture-mobile','margin-right','20',0,''),(173849,55512,'117442','furniture-mobile','float','right',0,''),(173850,55512,'117442','furniture-mobile','clear','none',0,''),(173851,55512,'117442','furniture-mobile','display','none',0,'2885'),(173852,55513,'117443','furniture-mobile','float','left',0,''),(173853,55513,'117443','furniture-mobile','clear','none',0,''),(173854,55513,'117443','furniture-mobile','sort_pos_3','1',0,''),(173855,55513,'117443','furniture-mobile','sort_pos_4','2',0,''),(173856,55513,'117443','furniture-mobile','sort_pos_10','3',0,''),(173857,55513,'117443','furniture-mobile','sort_pos_9','4',0,''),(173858,55513,'117443','furniture-mobile','sort_pos_11','5',0,''),(173859,55513,'117443','furniture-mobile','sort_pos_12','6',0,''),(173860,55513,'117443','furniture-mobile','sort_pos_14','7',0,''),(173861,55513,'117443','furniture-mobile','sort_pos_13','8',0,''),(173862,55513,'117443','furniture-mobile','sort_pos_8','9',0,''),(173863,55513,'117443','furniture-mobile','sort_pos_7','10',0,''),(173864,55513,'117443','furniture-mobile','sort_pos_2','11',0,''),(173865,55513,'117443','furniture-mobile','sort_pos_1','12',0,''),(173866,55513,'117443','furniture-mobile','sort_pos_6','13',0,''),(173867,55513,'117443','furniture-mobile','sort_pos_5','14',0,''),(173868,55513,'117443','furniture-mobile','sort_pos_0','15',0,''),(173869,55513,'117443','furniture-mobile','sort_hide_10','1',0,''),(173870,55513,'117443','furniture-mobile','sort_hide_9','1',0,''),(173871,55513,'117443','furniture-mobile','hide_icons','1',0,''),(173872,55513,'117443','furniture-mobile','sort_hide_16','1',0,''),(173873,55513,'117443','furniture-mobile','sort_hide_15','1',0,''),(173874,55513,'117443','furniture-mobile','sort_hide_3','0',0,''),(173875,55513,'117443','furniture-mobile','sort_hide_4','0',0,''),(173876,55513,'117443','furniture-mobile','sort_hide_11','1',0,''),(173877,55513,'117443','furniture-mobile','sort_hide_12','1',0,''),(173878,55513,'117443','furniture-mobile','sort_hide_14','1',0,''),(173879,55513,'117443','furniture-mobile','sort_hide_13','1',0,''),(173880,55513,'117443','furniture-mobile','sort_hide_8','0',0,''),(173881,55513,'117443','furniture-mobile','sort_hide_7','0',0,''),(173882,55513,'117443','furniture-mobile','sort_hide_2','1',0,''),(173883,55513,'117443','furniture-mobile','sort_hide_1','1',0,''),(173884,55513,'117443','furniture-mobile','sort_hide_6','1',0,''),(173885,55513,'117443','furniture-mobile','sort_hide_5','1',0,''),(173886,55513,'117443','furniture-mobile','sort_hide_0','1',0,''),(173887,55514,'117444','furniture-mobile','block_type','1',0,''),(173888,55515,'117445','furniture-mobile','margin-bottom','30',0,''),(173889,55516,'117446','furniture-mobile','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(173890,55517,'117447','furniture-mobile','block_type','1',0,''),(173891,55518,'117448','furniture-mobile','block_type','5',0,''),(173892,55518,'117448','furniture-mobile','padding-top','10',0,''),(173893,55518,'117448','furniture-mobile','padding-bottom','10',0,''),(173894,55518,'117448','furniture-mobile','schema','5-2',0,'2906'),(173895,55518,'117448','furniture-mobile','border-top-color','$border-color-4',0,''),(173896,55518,'117448','furniture-mobile','border-top-width','1',0,''),(173897,55519,'117449','furniture-mobile','padding-top','3',0,''),(173898,55520,'117450','furniture-mobile','float','right',0,''),(173899,55520,'117450','furniture-mobile','height','31',0,''),(173900,55521,'117451','furniture-mobile','col_in_row','4',0,''),(173901,55521,'117451','furniture-mobile','products_align','left',0,''),(173902,55521,'117451','furniture-mobile','font-weight','400',0,''),(173903,55521,'117451','furniture-mobile','listing_type','productListing',0,''),(173904,55521,'117451','furniture-mobile','listing_type_rows','Rows',0,''),(173905,55521,'117451','furniture-mobile','show_buy_button_b2b','on',0,''),(173906,55521,'117451','furniture-mobile','show_wishlist_button_b2b','1',0,''),(173907,55521,'117451','furniture-mobile','show_compare_b2b','1',0,''),(173908,55521,'117451','furniture-mobile','listing_type_b2b','b2b',0,''),(173909,55521,'117451','furniture-mobile','show_image','0',0,''),(173910,55521,'117451','furniture-mobile','show_stock','0',0,''),(173911,55521,'117451','furniture-mobile','show_description','0',0,''),(173912,55521,'117451','furniture-mobile','show_model','0',0,''),(173913,55521,'117451','furniture-mobile','show_properties','0',0,''),(173914,55521,'117451','furniture-mobile','show_rating','0',0,''),(173915,55521,'117451','furniture-mobile','show_rating_counts','0',0,''),(173916,55521,'117451','furniture-mobile','show_price','0',0,''),(173917,55521,'117451','furniture-mobile','show_buy_button','0',0,''),(173918,55521,'117451','furniture-mobile','show_view_button','0',0,''),(173919,55521,'117451','furniture-mobile','show_wishlist_button','0',0,''),(173920,55521,'117451','furniture-mobile','show_compare','0',0,''),(173921,55521,'117451','furniture-mobile','show_name_rows','0',0,''),(173922,55521,'117451','furniture-mobile','show_image_rows','0',0,''),(173923,55521,'117451','furniture-mobile','show_stock_rows','0',0,''),(173924,55521,'117451','furniture-mobile','show_description_rows','0',0,''),(173925,55521,'117451','furniture-mobile','show_model_rows','0',0,''),(173926,55521,'117451','furniture-mobile','show_properties_rows','0',0,''),(173927,55521,'117451','furniture-mobile','show_rating_rows','0',0,''),(173928,55521,'117451','furniture-mobile','show_rating_counts_rows','0',0,''),(173929,55521,'117451','furniture-mobile','show_price_rows','0',0,''),(173930,55521,'117451','furniture-mobile','show_buy_button_rows','0',0,''),(173931,55521,'117451','furniture-mobile','show_qty_input_rows','0',0,''),(173932,55521,'117451','furniture-mobile','show_view_button_rows','0',0,''),(173933,55521,'117451','furniture-mobile','show_wishlist_button_rows','0',0,''),(173934,55521,'117451','furniture-mobile','show_compare_rows','0',0,''),(173935,55521,'117451','furniture-mobile','show_name_b2b','0',0,''),(173936,55521,'117451','furniture-mobile','show_image_b2b','0',0,''),(173937,55521,'117451','furniture-mobile','show_stock_b2b','0',0,''),(173938,55521,'117451','furniture-mobile','show_description_b2b','0',0,''),(173939,55521,'117451','furniture-mobile','show_model_b2b','0',0,''),(173940,55521,'117451','furniture-mobile','show_properties_b2b','0',0,''),(173941,55521,'117451','furniture-mobile','show_rating_b2b','0',0,''),(173942,55521,'117451','furniture-mobile','show_rating_counts_b2b','0',0,''),(173943,55521,'117451','furniture-mobile','show_price_b2b','0',0,''),(173944,55521,'117451','furniture-mobile','show_qty_input_b2b','0',0,''),(173945,55521,'117451','furniture-mobile','show_view_button_b2b','0',0,''),(173946,55521,'117451','furniture-mobile','show_attributes_b2b','0',0,''),(173947,55521,'117451','furniture-mobile','items_on_page','12',0,''),(173948,55521,'117451','furniture-mobile','col_in_row','2',0,'2885'),(173949,55521,'117451','furniture-mobile','col_in_row','1',0,'2906'),(173950,55521,'117451','furniture-mobile','product_names_teg','h2',0,''),(173951,55524,'117454','furniture-mobile','block_type','1',0,''),(173952,55525,'117455','furniture-mobile','block_type','1',0,''),(173953,55525,'117455','furniture-mobile','padding-top','10',0,''),(173954,55525,'117455','furniture-mobile','padding-bottom','10',0,''),(173955,55525,'117455','furniture-mobile','border-bottom-width','1',0,''),(173956,55525,'117455','furniture-mobile','border-bottom-color','$border-color-4',0,''),(173957,55525,'117455','furniture-mobile','margin-left','0',0,''),(173958,55525,'117455','furniture-mobile','margin-right','0',0,''),(173959,55526,'117456','furniture-mobile','clear','none',0,''),(173960,55526,'117456','furniture-mobile','float','left',0,''),(173961,55526,'117456','furniture-mobile','padding-top','3',0,''),(173962,55526,'117456','furniture-mobile','margin-left','20',0,''),(173963,55527,'117457','furniture-mobile','float','right',0,''),(173964,55527,'117457','furniture-mobile','display','none',0,'2906'),(173965,55528,'117458','furniture-mobile','margin-right','20',0,''),(173966,55528,'117458','furniture-mobile','float','right',0,''),(173967,55528,'117458','furniture-mobile','clear','none',0,''),(173968,55528,'117458','furniture-mobile','display','none',0,'2885'),(173969,55529,'117459','furniture-mobile','float','left',0,''),(173970,55529,'117459','furniture-mobile','clear','none',0,''),(173971,55529,'117459','furniture-mobile','margin-left','20',0,''),(173972,55529,'117459','furniture-mobile','display','none',0,'2906'),(173973,55530,'117460','furniture-mobile','float','left',0,''),(173974,55530,'117460','furniture-mobile','clear','none',0,''),(173975,55530,'117460','furniture-mobile','sort_pos_3','2',0,''),(173976,55530,'117460','furniture-mobile','sort_pos_4','1',0,''),(173977,55530,'117460','furniture-mobile','sort_pos_10','5',0,''),(173978,55530,'117460','furniture-mobile','sort_pos_9','6',0,''),(173979,55530,'117460','furniture-mobile','sort_pos_11','7',0,''),(173980,55530,'117460','furniture-mobile','sort_pos_12','8',0,''),(173981,55530,'117460','furniture-mobile','sort_pos_14','9',0,''),(173982,55530,'117460','furniture-mobile','sort_pos_13','10',0,''),(173983,55530,'117460','furniture-mobile','sort_pos_8','11',0,''),(173984,55530,'117460','furniture-mobile','sort_pos_7','12',0,''),(173985,55530,'117460','furniture-mobile','sort_pos_2','13',0,''),(173986,55530,'117460','furniture-mobile','sort_pos_1','14',0,''),(173987,55530,'117460','furniture-mobile','sort_pos_6','15',0,''),(173988,55530,'117460','furniture-mobile','sort_pos_5','16',0,''),(173989,55530,'117460','furniture-mobile','sort_pos_0','17',0,''),(173990,55530,'117460','furniture-mobile','sort_hide_10','1',0,''),(173991,55530,'117460','furniture-mobile','sort_hide_9','1',0,''),(173992,55530,'117460','furniture-mobile','sort_pos_15','4',0,''),(173993,55530,'117460','furniture-mobile','sort_pos_16','3',0,''),(173994,55530,'117460','furniture-mobile','sort_hide_4','0',0,''),(173995,55530,'117460','furniture-mobile','sort_hide_3','0',0,''),(173996,55530,'117460','furniture-mobile','sort_hide_16','1',0,''),(173997,55530,'117460','furniture-mobile','sort_hide_15','1',0,''),(173998,55530,'117460','furniture-mobile','sort_hide_11','1',0,''),(173999,55530,'117460','furniture-mobile','sort_hide_12','1',0,''),(174000,55530,'117460','furniture-mobile','sort_hide_14','1',0,''),(174001,55530,'117460','furniture-mobile','sort_hide_13','1',0,''),(174002,55530,'117460','furniture-mobile','sort_hide_8','0',0,''),(174003,55530,'117460','furniture-mobile','sort_hide_7','0',0,''),(174004,55530,'117460','furniture-mobile','sort_hide_2','1',0,''),(174005,55530,'117460','furniture-mobile','sort_hide_1','1',0,''),(174006,55530,'117460','furniture-mobile','sort_hide_6','1',0,''),(174007,55530,'117460','furniture-mobile','sort_hide_5','1',0,''),(174008,55530,'117460','furniture-mobile','sort_hide_0','1',0,''),(174009,55530,'117460','furniture-mobile','hide_icons','1',0,''),(174010,55531,'117461','furniture-mobile','margin-bottom','20',0,''),(174011,55532,'117462','furniture-mobile','block_type','1',0,''),(174012,55532,'117462','furniture-mobile','style_class','account-order-history',0,''),(174013,55533,'117463','furniture-mobile','block_type','6',0,''),(174014,55533,'117463','furniture-mobile','schema','6-3',0,'2885'),(174015,55534,'117464','furniture-mobile','aria_name','account-menu',0,''),(174072,55554,'117465','furniture-mobile','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(174073,55555,'117466','furniture-mobile','link','Order History Info',0,''),(174074,55555,'117466','furniture-mobile','text','TEXT_VIEW',0,''),(174075,55555,'117466','furniture-mobile','show_pagenation','1',0,''),(174076,55555,'117466','furniture-mobile','link_pay','Order pay',0,''),(174077,55555,'117466','furniture-mobile','margin-bottom','20',0,''),(174078,55556,'117467','furniture-mobile','block_type','1',0,''),(174079,55556,'117467','furniture-mobile','style_class','account-order-history-info',0,''),(174080,55557,'117468','furniture-mobile','block_type','6',0,''),(174081,55557,'117468','furniture-mobile','schema','6-3',0,'2885'),(174082,55558,'117469','furniture-mobile','aria_name','account-menu',0,''),(174139,55578,'117470','furniture-mobile','float','right',0,''),(174140,55578,'117470','furniture-mobile','clear','none',0,''),(174141,55578,'117470','furniture-mobile','margin-left','20',0,''),(174142,55580,'117472','furniture-mobile','float','right',0,''),(174143,55580,'117472','furniture-mobile','clear','none',0,''),(174144,55580,'117472','furniture-mobile','like_button','2',0,''),(174145,55580,'117472','furniture-mobile','link','Order pay',0,''),(174146,55581,'117473','furniture-mobile','block_type','2',0,''),(174147,55581,'117473','furniture-mobile','padding-top','20',0,''),(174148,55581,'117473','furniture-mobile','margin-bottom','20',0,''),(174149,55582,'117474','furniture-mobile','like_button','1',0,''),(174150,55582,'117474','furniture-mobile','text','IMAGE_BUTTON_BACK',0,''),(174151,55582,'117474','furniture-mobile','link','Order History',0,''),(174152,55583,'117475','furniture-mobile','text-align','right',0,''),(174153,55584,'117476','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(174154,55586,'117478','furniture-mobile','float','right',0,''),(174155,55586,'117478','furniture-mobile','clear','none',0,''),(174156,55586,'117478','furniture-mobile','margin-left','20',0,''),(174157,55588,'117480','furniture-mobile','clear','both',0,''),(174158,55589,'117481','furniture-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(174159,55591,'117483','furniture-mobile','float','left',0,''),(174160,55592,'117484','furniture-mobile','block_type','3',0,''),(174161,55592,'117484','furniture-mobile','clear','both',0,''),(174162,55592,'117484','furniture-mobile','padding-top','20',0,''),(174163,55593,'117485','furniture-mobile','block_type','1',0,''),(174164,55593,'117485','furniture-mobile','margin-bottom','20',0,''),(174165,55593,'117485','furniture-mobile','padding-right','20',0,''),(174166,55594,'117486','furniture-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(174167,55595,'117487','furniture-mobile','padding-left','30',0,''),(174168,55595,'117487','furniture-mobile','orders_data','telephone',0,''),(174169,55595,'117487','furniture-mobile','hide_parents','2',0,''),(174170,55596,'117488','furniture-mobile','block_type','1',0,''),(174171,55596,'117488','furniture-mobile','padding-right','20',0,''),(174172,55596,'117488','furniture-mobile','padding-bottom','20',0,''),(174173,55597,'117489','furniture-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(174174,55598,'117490','furniture-mobile','orders_data','name',0,''),(174175,55598,'117490','furniture-mobile','padding-left','30',0,''),(174176,55599,'117491','furniture-mobile','block_type','1',0,''),(174177,55599,'117491','furniture-mobile','padding-right','20',0,''),(174178,55599,'117491','furniture-mobile','margin-bottom','20',0,''),(174179,55600,'117492','furniture-mobile','short_view','1',0,''),(174180,55600,'117492','furniture-mobile','hide_parents','2',0,''),(174181,55601,'117493','furniture-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(174182,55602,'117494','furniture-mobile','link','Tracking numbers',0,''),(174183,55602,'117494','furniture-mobile','text','MORE_TRACKING_NUMBER',0,''),(174184,55602,'117494','furniture-mobile','popup','1',0,''),(174185,55602,'117494','furniture-mobile','order_id','1',0,''),(174186,55602,'117494','furniture-mobile','popup_class','tracking-numbers-popup',0,''),(174187,55602,'117494','furniture-mobile','font-weight','700',0,''),(174188,55602,'117494','furniture-mobile','font-size','18',0,''),(174189,55603,'117495','furniture-mobile','block_type','1',0,''),(174190,55603,'117495','furniture-mobile','padding-right','20',0,''),(174191,55604,'117496','furniture-mobile','orders_data','shipping_method',0,''),(174192,55604,'117496','furniture-mobile','padding-left','30',0,''),(174193,55605,'117497','furniture-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(174194,55606,'117498','furniture-mobile','block_type','1',0,''),(174195,55606,'117498','furniture-mobile','padding-right','20',0,''),(174196,55606,'117498','furniture-mobile','padding-bottom','20',0,''),(174197,55607,'117499','furniture-mobile','orders_data','delivery_address',0,''),(174198,55607,'117499','furniture-mobile','padding-left','30',0,''),(174199,55608,'117500','furniture-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(174200,55609,'117501','furniture-mobile','block_type','1',0,''),(174201,55610,'117502','furniture-mobile','orders_data','payment_method',0,''),(174202,55610,'117502','furniture-mobile','padding-left','30',0,''),(174203,55611,'117503','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(174204,55612,'117504','furniture-mobile','block_type','1',0,''),(174205,55612,'117504','furniture-mobile','padding-bottom','20',0,''),(174206,55613,'117505','furniture-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(174207,55614,'117506','furniture-mobile','orders_data','billing_address',0,''),(174208,55614,'117506','furniture-mobile','padding-left','30',0,''),(174209,55615,'117507','furniture-mobile','block_type','1',0,''),(174210,55615,'117507','furniture-mobile','style_class','account-order-pay',0,''),(174211,55616,'117508','furniture-mobile','block_type','6',0,''),(174212,55616,'117508','furniture-mobile','schema','6-3',0,'2885'),(174213,55617,'117509','furniture-mobile','aria_name','account-menu',0,''),(174270,55638,'117511','furniture-mobile','block_type','3',0,''),(174271,55639,'117512','furniture-mobile','block_type','1',0,''),(174272,55639,'117512','furniture-mobile','padding-right','20',0,''),(174273,55639,'117512','furniture-mobile','padding-bottom','20',0,''),(174274,55640,'117513','furniture-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(174275,55641,'117514','furniture-mobile','orders_data','name',0,''),(174276,55641,'117514','furniture-mobile','padding-left','30',0,''),(174277,55642,'117515','furniture-mobile','block_type','1',0,''),(174278,55643,'117516','furniture-mobile','padding-left','30',0,''),(174279,55644,'117517','furniture-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(174280,55645,'117518','furniture-mobile','block_type','1',0,''),(174281,55645,'117518','furniture-mobile','padding-right','20',0,''),(174282,55645,'117518','furniture-mobile','padding-bottom','20',0,''),(174283,55646,'117519','furniture-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(174284,55647,'117520','furniture-mobile','orders_data','delivery_address',0,''),(174285,55647,'117520','furniture-mobile','padding-left','30',0,''),(174286,55648,'117521','furniture-mobile','block_type','1',0,''),(174287,55648,'117521','furniture-mobile','padding-right','20',0,''),(174288,55649,'117522','furniture-mobile','orders_data','shipping_method',0,''),(174289,55649,'117522','furniture-mobile','padding-left','30',0,''),(174290,55650,'117523','furniture-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(174291,55651,'117524','furniture-mobile','block_type','1',0,''),(174292,55652,'117525','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(174293,55653,'117526','furniture-mobile','orders_data','payment_method',0,''),(174294,55653,'117526','furniture-mobile','padding-left','30',0,''),(174295,55654,'117527','furniture-mobile','block_type','1',0,''),(174296,55654,'117527','furniture-mobile','padding-bottom','20',0,''),(174297,55655,'117528','furniture-mobile','orders_data','billing_address',0,''),(174298,55655,'117528','furniture-mobile','padding-left','30',0,''),(174299,55656,'117529','furniture-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(174300,55657,'117530','furniture-mobile','margin-bottom','20',0,''),(174301,55657,'117530','furniture-mobile','orders_data','name',0,''),(174302,55658,'117531','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(174303,55661,'117534','furniture-mobile','width','680',0,''),(174304,55661,'117534','furniture-mobile','font-weight','400',0,''),(174305,55661,'117534','furniture-mobile','font-size','12',0,''),(174306,55661,'117534','furniture-mobile','padding-top','20',0,''),(174307,55661,'117534','furniture-mobile','padding-bottom','20',0,''),(174308,55662,'117535','furniture-mobile','block_type','2',0,''),(174309,55662,'117535','furniture-mobile','font-weight','normal',0,''),(174310,55662,'117535','furniture-mobile','padding-bottom','20',0,''),(174311,55663,'117536','furniture-mobile','font-weight','400',0,''),(174312,55663,'117536','furniture-mobile','text-align','center',0,''),(174313,55663,'117536','furniture-mobile','padding-top','10',0,''),(174314,55663,'117536','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',1,''),(174315,55664,'117537','furniture-mobile','block_type','11',0,''),(174316,55664,'117537','furniture-mobile','font-weight','normal',0,''),(174317,55665,'117538','furniture-mobile','text','<p>Email:</p>',1,''),(174318,55665,'117538','furniture-mobile','font-weight','normal',0,''),(174319,55665,'117538','furniture-mobile','text-align','right',0,''),(174320,55666,'117539','furniture-mobile','font-weight','normal',0,''),(174321,55666,'117539','furniture-mobile','text-align','right',0,''),(174322,55667,'117540','furniture-mobile','block_type','11',0,''),(174323,55667,'117540','furniture-mobile','font-weight','normal',0,''),(174324,55668,'117541','furniture-mobile','text','<p>Phone:</p>',1,''),(174325,55668,'117541','furniture-mobile','font-weight','normal',0,''),(174326,55668,'117541','furniture-mobile','text-align','right',0,''),(174327,55669,'117542','furniture-mobile','font-weight','normal',0,''),(174328,55669,'117542','furniture-mobile','text-align','right',0,''),(174329,55670,'117543','furniture-mobile','block_type','1',0,''),(174330,55671,'117544','furniture-mobile','font-weight','400',0,''),(174331,55671,'117544','furniture-mobile','text-align','right',0,''),(174332,55671,'117544','furniture-mobile','padding-bottom','10',0,''),(174333,55671,'117544','furniture-mobile','address_spacer',',',0,''),(174334,55671,'117544','furniture-mobile','font-size','12',0,''),(174335,55672,'117545','furniture-mobile','block_type','11',0,''),(174336,55672,'117545','furniture-mobile','font-weight','400',0,''),(174337,55673,'117546','furniture-mobile','text','<p>Web:</p>',1,''),(174338,55673,'117546','furniture-mobile','font-weight','400',0,''),(174339,55673,'117546','furniture-mobile','text-align','right',0,''),(174340,55674,'117547','furniture-mobile','font-weight','normal',0,''),(174341,55674,'117547','furniture-mobile','text-align','right',0,''),(174342,55675,'117548','furniture-mobile','font-weight','normal',0,''),(174343,55675,'117548','furniture-mobile','padding-top','20',0,''),(174344,55675,'117548','furniture-mobile','font-size','12',0,''),(174345,55676,'117549','furniture-mobile','block_type','1',0,''),(174346,55676,'117549','furniture-mobile','font-weight','normal',0,''),(174347,55676,'117549','furniture-mobile','padding-top','10',0,''),(174348,55676,'117549','furniture-mobile','padding-bottom','10',0,''),(174349,55678,'117551','furniture-mobile','text','<p>If undelivered please return to:</p>',1,''),(174350,55678,'117551','furniture-mobile','font-weight','bold',0,''),(174351,55679,'117552','furniture-mobile','block_type','4',0,''),(174352,55679,'117552','furniture-mobile','font-weight','400',0,''),(174353,55679,'117552','furniture-mobile','border-top-width','1',0,''),(174354,55679,'117552','furniture-mobile','border-top-color','$border-color-4',0,''),(174355,55679,'117552','furniture-mobile','border-left-width','1',0,''),(174356,55679,'117552','furniture-mobile','border-left-color','$border-color-4',0,''),(174357,55679,'117552','furniture-mobile','border-right-width','1',0,''),(174358,55679,'117552','furniture-mobile','border-right-color','$border-color-4',0,''),(174359,55679,'117552','furniture-mobile','border-bottom-width','1',0,''),(174360,55679,'117552','furniture-mobile','border-bottom-color','$border-color-4',0,''),(174361,55680,'117553','furniture-mobile','block_type','2',0,''),(174362,55680,'117553','furniture-mobile','font-weight','normal',0,''),(174363,55680,'117553','furniture-mobile','border-right-width','1',0,''),(174364,55680,'117553','furniture-mobile','border-right-color','$border-color-4',0,''),(174365,55681,'117554','furniture-mobile','block_type','1',0,''),(174366,55681,'117554','furniture-mobile','font-weight','normal',0,''),(174367,55681,'117554','furniture-mobile','border-right-width','1',0,''),(174368,55681,'117554','furniture-mobile','border-right-color','$border-color-4',0,''),(174369,55681,'117554','furniture-mobile','background-color','$background-6',0,''),(174370,55681,'117554','furniture-mobile','padding-top','10',0,''),(174371,55681,'117554','furniture-mobile','padding-left','10',0,''),(174372,55681,'117554','furniture-mobile','padding-right','10',0,''),(174373,55681,'117554','furniture-mobile','padding-bottom','10',0,''),(174374,55682,'117555','furniture-mobile','font-size','12',0,''),(174375,55682,'117555','furniture-mobile','font-weight','normal',0,''),(174376,55683,'117556','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(174377,55683,'117556','furniture-mobile','font-size','13',0,''),(174378,55683,'117556','furniture-mobile','font-weight','bold',0,''),(174379,55683,'117556','furniture-mobile','padding-bottom','10',0,''),(174380,55684,'117557','furniture-mobile','block_type','1',0,''),(174381,55684,'117557','furniture-mobile','font-weight','normal',0,''),(174382,55684,'117557','furniture-mobile','padding-top','10',0,''),(174383,55684,'117557','furniture-mobile','padding-left','10',0,''),(174384,55684,'117557','furniture-mobile','padding-right','10',0,''),(174385,55684,'117557','furniture-mobile','padding-bottom','10',0,''),(174386,55685,'117558','furniture-mobile','text','<p>CUSTOMER:</p>',1,''),(174387,55685,'117558','furniture-mobile','font-size','13',0,''),(174388,55685,'117558','furniture-mobile','font-weight','bold',0,''),(174389,55686,'117559','furniture-mobile','font-size','12',0,''),(174390,55688,'117561','furniture-mobile','text','<p>PHONE NUMBER:</p>',1,''),(174391,55688,'117561','furniture-mobile','font-size','13',0,''),(174392,55688,'117561','furniture-mobile','font-weight','bold',0,''),(174393,55688,'117561','furniture-mobile','padding-top','10',0,''),(174394,55689,'117562','furniture-mobile','font-size','12',0,''),(174395,55690,'117563','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(174396,55690,'117563','furniture-mobile','font-size','13',0,''),(174397,55690,'117563','furniture-mobile','font-weight','bold',0,''),(174398,55690,'117563','furniture-mobile','padding-top','10',0,''),(174399,55691,'117564','furniture-mobile','block_type','2',0,''),(174400,55691,'117564','furniture-mobile','font-weight','normal',0,''),(174401,55691,'117564','furniture-mobile','border-right-width','1',0,''),(174402,55691,'117564','furniture-mobile','border-right-color','$border-color-4',0,''),(174403,55691,'117564','furniture-mobile','border-top-width','1',0,''),(174404,55691,'117564','furniture-mobile','border-top-color','$border-color-4',0,''),(174405,55692,'117565','furniture-mobile','block_type','1',0,''),(174406,55692,'117565','furniture-mobile','font-weight','normal',0,''),(174407,55692,'117565','furniture-mobile','padding-top','10',0,''),(174408,55692,'117565','furniture-mobile','padding-left','10',0,''),(174409,55692,'117565','furniture-mobile','padding-right','10',0,''),(174410,55692,'117565','furniture-mobile','padding-bottom','10',0,''),(174411,55692,'117565','furniture-mobile','border-right-width','1',0,''),(174412,55692,'117565','furniture-mobile','border-right-color','$border-color-4',0,''),(174413,55694,'117567','furniture-mobile','text','<p>Shipping via</p>',1,''),(174414,55694,'117567','furniture-mobile','font-weight','bold',0,''),(174415,55695,'117568','furniture-mobile','block_type','1',0,''),(174416,55695,'117568','furniture-mobile','font-weight','normal',0,''),(174417,55695,'117568','furniture-mobile','padding-top','10',0,''),(174418,55695,'117568','furniture-mobile','padding-left','10',0,''),(174419,55695,'117568','furniture-mobile','padding-right','10',0,''),(174420,55695,'117568','furniture-mobile','padding-bottom','10',0,''),(174421,55697,'117570','furniture-mobile','text','<p>Shipping service</p>',1,''),(174422,55697,'117570','furniture-mobile','font-weight','bold',0,''),(174423,55698,'117571','furniture-mobile','font-weight','normal',0,''),(174424,55698,'117571','furniture-mobile','text-align','center',0,''),(174425,55698,'117571','furniture-mobile','padding-top','40',0,''),(174426,55700,'1639661081.5616','furniture-mobile','padding-top','15',0,''),(174427,55701,'117572','furniture-mobile','block_type','1',0,''),(174428,55702,'117573','furniture-mobile','block_type','8',0,''),(174429,55703,'1638807246.6206','furniture-mobile','text','<span></span>',0,''),(174430,55704,'117574','furniture-mobile','text','##TEXT_MAIN##',0,''),(174431,55704,'117574','furniture-mobile','margin-bottom','20',0,''),(174432,55704,'117574','furniture-mobile','text-align','center',0,''),(174433,55705,'117575','furniture-mobile','margin-bottom','20',0,''),(174434,55706,'117576','furniture-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(174435,55708,'117578','furniture-mobile','block_type','2',0,''),(174436,55709,'117579','furniture-mobile','block_type','1',0,''),(174437,55709,'117579','furniture-mobile','style_class','product',0,''),(174438,55709,'117579','furniture-mobile','padding-right','10',0,''),(174439,55709,'117579','furniture-mobile','padding-bottom','20',0,''),(174440,55710,'117580','furniture-mobile','block_type','1',0,''),(174441,55711,'117581','furniture-mobile','product_element','products_name',0,''),(174442,55711,'117581','furniture-mobile','font-family','$font-1',0,''),(174443,55711,'117581','furniture-mobile','padding-bottom','10',0,''),(174444,55711,'117581','furniture-mobile','font-size','16',0,''),(174445,55712,'117582','furniture-mobile','block_type','2',0,''),(174446,55713,'117583','furniture-mobile','product_element','image',0,''),(174447,55713,'117583','furniture-mobile','padding-right','10',0,''),(174448,55714,'117584','furniture-mobile','product_element','products_price_old',0,''),(174449,55714,'117584','furniture-mobile','font-family','$font-1',0,''),(174450,55714,'117584','furniture-mobile','font-size','14',0,''),(174451,55714,'117584','furniture-mobile','text-decoration','line-through',0,''),(174452,55715,'117585','furniture-mobile','product_element','products_price',0,''),(174453,55715,'117585','furniture-mobile','font-family','$font-1',0,''),(174454,55715,'117585','furniture-mobile','font-size','20',0,''),(174455,55715,'117585','furniture-mobile','padding-top','20',0,''),(174456,55716,'117586','furniture-mobile','block_type','1',0,''),(174457,55716,'117586','furniture-mobile','style_class','product',0,''),(174458,55716,'117586','furniture-mobile','padding-left','10',0,''),(174459,55716,'117586','furniture-mobile','padding-bottom','20',0,''),(174460,55717,'117587','furniture-mobile','block_type','2',0,''),(174461,55718,'117588','furniture-mobile','product_element','image',0,''),(174462,55718,'117588','furniture-mobile','padding-right','10',0,''),(174463,55719,'117589','furniture-mobile','font-size','14',0,''),(174464,55719,'117589','furniture-mobile','font-family','$font-1',0,''),(174465,55719,'117589','furniture-mobile','text-decoration','line-through',0,''),(174466,55719,'117589','furniture-mobile','product_element','products_price_old',0,''),(174467,55720,'117590','furniture-mobile','product_element','products_price',0,''),(174468,55720,'117590','furniture-mobile','font-family','$font-1',0,''),(174469,55720,'117590','furniture-mobile','font-size','20',0,''),(174470,55720,'117590','furniture-mobile','padding-top','20',0,''),(174471,55721,'117591','furniture-mobile','block_type','1',0,''),(174472,55722,'117592','furniture-mobile','product_element','products_name',0,''),(174473,55722,'117592','furniture-mobile','font-family','$font-1',0,''),(174474,55722,'117592','furniture-mobile','font-size','16',0,''),(174475,55722,'117592','furniture-mobile','padding-bottom','10',0,''),(174476,55723,'117593','furniture-mobile','font-size','30',0,''),(174477,55723,'117593','furniture-mobile','font-family','$font-1',0,''),(174478,55723,'117593','furniture-mobile','text-align','center',0,''),(174479,55723,'117593','furniture-mobile','padding-bottom','50',0,''),(174480,55724,'117594','furniture-mobile','padding-bottom','20',0,''),(174481,55724,'117594','furniture-mobile','text-align','center',0,''),(174482,55725,'117595','furniture-mobile','width','680',0,''),(174483,55726,'117596','furniture-mobile','padding-top','200',0,''),(174484,55726,'117596','furniture-mobile','padding-left','200',0,''),(174485,55726,'117596','furniture-mobile','logo','themes/furniture-mobile/img/oscommerce_logo-1.jpg',1,''),(174486,55727,'117597','furniture-mobile','text','osCommerce 4',1,''),(174487,55727,'117597','furniture-mobile','font-family','$font-1',0,''),(174488,55727,'117597','furniture-mobile','font-size','40',0,''),(174489,55727,'117597','furniture-mobile','padding-top','50',0,''),(174490,55727,'117597','furniture-mobile','text-align','center',0,''),(174491,55728,'117598','furniture-mobile','block_type','2',0,''),(174492,55728,'117598','furniture-mobile','border-top-width','1',0,''),(174493,55728,'117598','furniture-mobile','border-top-color','$border-color-4',0,''),(174494,55729,'117599','furniture-mobile','text-align','right',0,''),(174495,55729,'117599','furniture-mobile','padding-top','15',0,''),(174496,55729,'117599','furniture-mobile','padding-bottom','15',0,''),(174497,55729,'117599','furniture-mobile','font-size','14',0,''),(174498,55730,'117600','furniture-mobile','font-family','$font-1',0,''),(174499,55730,'117600','furniture-mobile','text-align','center',0,''),(174500,55730,'117600','furniture-mobile','font-size','20',0,''),(174501,55730,'117600','furniture-mobile','color','$color-font-7',0,''),(174502,55730,'117600','furniture-mobile','border-bottom-width','1',0,''),(174503,55730,'117600','furniture-mobile','border-bottom-color','$border-color-4',0,''),(174504,55730,'117600','furniture-mobile','padding-top','10',0,''),(174505,55730,'117600','furniture-mobile','padding-bottom','10',0,''),(174506,55731,'117601','furniture-mobile','block_type','1',0,''),(174507,55732,'117602','furniture-mobile','block_type','6',0,''),(174508,55732,'117602','furniture-mobile','schema','6-3',0,'2885'),(174509,55733,'117603','furniture-mobile','aria_name','account-menu',0,''),(174566,55753,'117604','furniture-mobile','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(174567,55754,'117606','furniture-mobile','max_items','10',0,''),(174568,55754,'117606','furniture-mobile','padding-bottom','20',0,''),(174569,55755,'117607','furniture-mobile','block_type','1',0,''),(174570,55755,'117607','furniture-mobile','padding-top','20',0,''),(174571,55755,'117607','furniture-mobile','padding-left','20',0,''),(174572,55755,'117607','furniture-mobile','padding-right','20',0,''),(174573,55755,'117607','furniture-mobile','padding-bottom','20',0,''),(174574,55756,'117608','furniture-mobile','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(174575,55758,'117610','furniture-mobile','block_type','1',0,''),(174576,55759,'117611','furniture-mobile','margin_left_measure','auto',0,''),(174577,55759,'117611','furniture-mobile','margin_right_measure','auto',0,''),(174578,55759,'117611','furniture-mobile','max-width','560',0,''),(174579,55760,'117612','furniture-mobile','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(174580,55761,'117613','furniture-mobile','margin-bottom','30',0,''),(174581,55762,'117614','furniture-mobile','block_type','1',0,''),(174582,55762,'117614','furniture-mobile','padding-top','25',0,''),(174583,55762,'117614','furniture-mobile','padding-bottom','25',0,''),(174584,55762,'117614','furniture-mobile','style_class','catalog-product-wrap',0,''),(174585,55763,'120997','furniture-mobile','block_type','1',0,''),(174586,55764,'117646','furniture-mobile','tab_1','Product Overview',1,''),(174587,55764,'117646','furniture-mobile','tab_2','Delivery and returns',1,''),(174588,55764,'117646','furniture-mobile','font-weight','400',0,''),(174589,55764,'117646','furniture-mobile','tab_3','Assembly',1,''),(174590,55765,'117647','furniture-mobile','hTagsInline','block',0,''),(174591,55766,'117648','furniture-mobile','margin-bottom','20',0,''),(174592,55766,'117648','furniture-mobile','max-width','500',0,''),(174593,55767,'121011','furniture-mobile','text','<span></span>',0,''),(174594,55769,'117654','furniture-mobile','font-weight','normal',0,''),(174595,55769,'117654','furniture-mobile','padding-bottom','20',0,''),(174596,55769,'117654','furniture-mobile','show_compare','1',0,''),(174597,55769,'117654','furniture-mobile','show_cart_button','1',0,''),(174598,55769,'117654','furniture-mobile','listing_type','productListing',0,''),(174599,55769,'117654','furniture-mobile','col_in_row','4',0,''),(174600,55769,'117654','furniture-mobile','view_as','carousel',0,''),(174601,55770,'121002','furniture-mobile','tab_1','Customer also bought',0,''),(174602,55770,'121002','furniture-mobile','tab_2','You recently viewed',0,''),(174603,55770,'121002','furniture-mobile','margin-bottom','20',0,''),(174604,55771,'117645','furniture-mobile','font-weight','400',0,''),(174605,55771,'117645','furniture-mobile','padding-bottom','20',0,''),(174606,55771,'117645','furniture-mobile','show_qty_input','1',0,''),(174607,55771,'117645','furniture-mobile','show_compare','1',0,''),(174608,55771,'117645','furniture-mobile','listing_type','productListing',0,''),(174609,55771,'117645','furniture-mobile','view_as','carousel',0,''),(174610,55771,'117645','furniture-mobile','show_name','0',0,''),(174611,55771,'117645','furniture-mobile','show_image','0',0,''),(174612,55771,'117645','furniture-mobile','show_stock','0',0,''),(174613,55771,'117645','furniture-mobile','show_description','0',0,''),(174614,55771,'117645','furniture-mobile','show_model','1',0,''),(174615,55771,'117645','furniture-mobile','show_properties','1',0,''),(174616,55771,'117645','furniture-mobile','show_rating','0',0,''),(174617,55771,'117645','furniture-mobile','show_rating_counts','0',0,''),(174618,55771,'117645','furniture-mobile','show_price','0',0,''),(174619,55771,'117645','furniture-mobile','show_buy_button','1',0,''),(174620,55771,'117645','furniture-mobile','show_view_button','1',0,''),(174621,55771,'117645','furniture-mobile','show_wishlist_button','1',0,''),(174622,55771,'117645','furniture-mobile','display','none',0,'2885'),(174623,55771,'117645','furniture-mobile','product_names_teg','h2',0,''),(174624,55771,'117645','furniture-mobile','show_attributes','1',0,''),(174625,55771,'117645','furniture-mobile','col_in_row','4',0,''),(174626,55771,'117645','furniture-mobile','show_bonus_points','1',0,''),(174627,55772,'117641','furniture-mobile','font-weight','400',0,''),(174628,55772,'117641','furniture-mobile','padding-bottom','20',0,''),(174629,55772,'117641','furniture-mobile','show_compare','1',0,''),(174630,55772,'117641','furniture-mobile','show_name','0',0,''),(174631,55772,'117641','furniture-mobile','show_image','0',0,''),(174632,55772,'117641','furniture-mobile','show_stock','0',0,''),(174633,55772,'117641','furniture-mobile','show_description','0',0,''),(174634,55772,'117641','furniture-mobile','show_model','1',0,''),(174635,55772,'117641','furniture-mobile','show_properties','1',0,''),(174636,55772,'117641','furniture-mobile','show_rating','0',0,''),(174637,55772,'117641','furniture-mobile','show_rating_counts','0',0,''),(174638,55772,'117641','furniture-mobile','show_price','0',0,''),(174639,55772,'117641','furniture-mobile','show_buy_button','1',0,''),(174640,55772,'117641','furniture-mobile','show_view_button','1',0,''),(174641,55772,'117641','furniture-mobile','show_wishlist_button','1',0,''),(174642,55772,'117641','furniture-mobile','listing_type','productListing',0,''),(174643,55772,'117641','furniture-mobile','col_in_row','2',0,'2885'),(174644,55772,'117641','furniture-mobile','col_in_row','1',0,'2906'),(174645,55772,'117641','furniture-mobile','col_in_row','4',0,''),(174646,55772,'117641','furniture-mobile','view_as','carousel',0,''),(174647,55772,'117641','furniture-mobile','show_bonus_points','1',0,''),(174648,55772,'117641','furniture-mobile','show_qty_input','1',0,''),(174649,55772,'117641','furniture-mobile','show_attributes','1',0,''),(174650,55773,'121004','furniture-mobile','block_type','3',0,''),(174651,55773,'121004','furniture-mobile','style_class','tripleBanner',0,''),(174652,55774,'121005','furniture-mobile','text','<div>Returns and Exchanges</div>\n<div>30 Day Satisfaction Guarantee</div>\n',0,''),(174653,55774,'121005','furniture-mobile','style_class','returns',0,''),(174654,55775,'121006','furniture-mobile','text','<div>Warranty</div>\n<div>Min 12 months manufacturer’s warranty</div>',0,''),(174655,55775,'121006','furniture-mobile','style_class','warranty',0,''),(174656,55776,'121007','furniture-mobile','text','<div>Track your order</div>\n<div>Check the current status of your order</div>',0,''),(174657,55776,'121007','furniture-mobile','style_class','track',0,''),(174658,55777,'121010','furniture-mobile','block_type','1',0,''),(174659,55778,'117649','furniture-mobile','padding-bottom','10',0,''),(174660,55778,'117649','furniture-mobile','padding-top','5',0,''),(174661,55779,'1639053401.678','furniture-mobile','block_type','1',0,''),(174662,55780,'117616','furniture-mobile','block_type','2',0,''),(174663,55780,'117616','furniture-mobile','font-weight','400',0,''),(174664,55780,'117616','furniture-mobile','padding-bottom','20',0,''),(174665,55780,'117616','furniture-mobile','schema','2-2',0,'2906'),(174666,55780,'117616','furniture-mobile','schema','2-2',0,'2885'),(174667,55781,'117618','furniture-mobile','font-weight','400',0,''),(174668,55781,'117618','furniture-mobile','padding-top','20',0,''),(174669,55781,'117618','furniture-mobile','padding-right','20',0,''),(174670,55781,'117618','furniture-mobile','box_align','4',0,''),(174671,55781,'117618','furniture-mobile','margin-bottom','50',0,''),(174672,55781,'117618','furniture-mobile','align_position','horizontal',0,''),(174673,55782,'117620','furniture-mobile','float','left',0,''),(174674,55783,'1638463239.7427','furniture-mobile','padding-right','20',0,''),(174675,55783,'1638463239.7427','furniture-mobile','margin-bottom','20',0,''),(174676,55784,'1639416584.6039','furniture-mobile','padding-bottom','20',0,''),(174677,55788,'120988','furniture-mobile','block_type','2',0,''),(174678,55788,'120988','furniture-mobile','schema','2-2',0,'2890'),(174679,55789,'121009','furniture-mobile','block_type','1',0,''),(174680,55789,'121009','furniture-mobile','padding-right','9',0,''),(174681,55789,'121009','furniture-mobile','padding-right','0',0,'2890'),(174682,55790,'117629','furniture-mobile','cat_description','on',0,''),(174683,55790,'117629','furniture-mobile','length_description','250',0,''),(174684,55790,'117629','furniture-mobile','padding-bottom','7',0,''),(174685,55790,'117629','furniture-mobile','link_description','1',0,''),(174686,55790,'117629','furniture-mobile','border-bottom-width','1',0,''),(174687,55790,'117629','furniture-mobile','border-bottom-color','$border-color-3',0,''),(174688,55791,'117638','furniture-mobile','margin-bottom','7',0,''),(174689,55791,'117638','furniture-mobile','border-bottom-width','1',0,''),(174690,55791,'117638','furniture-mobile','border-bottom-color','$border-color-3',0,''),(174691,55792,'121016','furniture-mobile','text','<div class=\"warranty\">\n <div class=\"title\">##TITLE_WARRANTY_PRODUCT##</div>\n <div class=\"seeDetails\"><a href=\"warranty\">##TITLE_SEE_DETAILS_PRODUCT##</a></div>\n</div>\n<div class=\"delivery\">\n <div class=\"title\">##TITLE_DELIVERY_PRODUCT##</div>\n <div class=\"seeDetails\"><a href=\"shipping\">##TITLE_SEE_DETAILS_PRODUCT##</a></div>\n</div>',0,''),(174692,55792,'121016','furniture-mobile','style_class','warrantyProduct',0,''),(174693,55792,'121016','furniture-mobile','margin-bottom','20',0,''),(174694,55795,'121008','furniture-mobile','block_type','1',0,''),(174695,55795,'121008','furniture-mobile','padding-left','9',0,''),(174696,55795,'121008','furniture-mobile','margin-top','20',0,'2890'),(174697,55795,'121008','furniture-mobile','padding-left','0',0,'2890'),(174698,55796,'120991','furniture-mobile','block_type','1',0,''),(174699,55796,'120991','furniture-mobile','style_class','productNavigation',0,''),(174700,55796,'120991','furniture-mobile','border-top-width','1',0,''),(174701,55796,'120991','furniture-mobile','border-left-width','1',0,''),(174702,55796,'120991','furniture-mobile','border-right-width','1',0,''),(174703,55796,'120991','furniture-mobile','border-bottom-width','1',0,''),(174704,55796,'120991','furniture-mobile','border-top-color','$border-color-3',0,''),(174705,55796,'120991','furniture-mobile','border-left-color','$border-color-3',0,''),(174706,55796,'120991','furniture-mobile','border-right-color','$border-color-3',0,''),(174707,55796,'120991','furniture-mobile','border-bottom-color','$border-color-3',0,''),(174708,55797,'120989','furniture-mobile','padding-top','15',0,''),(174709,55797,'120989','furniture-mobile','padding-left','20',0,''),(174710,55797,'120989','furniture-mobile','padding-right','20',0,''),(174711,55797,'120989','furniture-mobile','padding-bottom','20',0,''),(174712,55797,'120989','furniture-mobile','border-bottom-width','1',0,''),(174713,55797,'120989','furniture-mobile','border-bottom-color','$border-color-3',0,''),(174714,55798,'120990','furniture-mobile','block_type','1',0,''),(174715,55798,'120990','furniture-mobile','padding-top','20',0,''),(174716,55798,'120990','furniture-mobile','padding-left','20',0,''),(174717,55798,'120990','furniture-mobile','padding-right','20',0,''),(174718,55798,'120990','furniture-mobile','padding-bottom','20',0,''),(174719,55799,'117622','furniture-mobile','text-align','center',0,''),(174720,55799,'117622','furniture-mobile','padding-bottom','10',0,''),(174721,55799,'117622','furniture-mobile','border-bottom-color','$border-color-3',0,''),(174722,55799,'117622','furniture-mobile','border-bottom-width','1',0,''),(174723,55799,'117622','furniture-mobile','margin-bottom','10',0,''),(174724,55799,'117622','furniture-mobile','padding-top','10',0,''),(174725,55799,'117622','furniture-mobile','margin-top','10',0,''),(174726,55799,'117622','furniture-mobile','border-top-color','$border-color-3',0,''),(174727,55799,'117622','furniture-mobile','border-top-width','1',0,''),(174728,55800,'117624','furniture-mobile','font-size','38',0,''),(174729,55800,'117624','furniture-mobile','font-weight','400',0,''),(174730,55800,'117624','furniture-mobile','line-height','35',0,''),(174731,55800,'117624','furniture-mobile','font-family','$font-1',0,''),(174732,55800,'117624','furniture-mobile','line_height_measure','px',0,''),(174733,55800,'117624','furniture-mobile','padding-top','5',0,''),(174734,55800,'117624','furniture-mobile','text-align','center',0,''),(174735,55800,'117624','furniture-mobile','padding-bottom','15',0,''),(174736,55801,'117625','furniture-mobile','box_align','2',0,''),(174737,55801,'117625','furniture-mobile','margin-bottom','15',0,'2885'),(174738,55801,'117625','furniture-mobile','text-align','right',0,'2885'),(174739,55801,'117625','furniture-mobile','padding-top','5',0,''),(174740,55801,'117625','furniture-mobile','text-align','center',0,''),(174741,55801,'117625','furniture-mobile','margin-bottom','25',0,''),(174742,55802,'117627','furniture-mobile','text-align','center',0,''),(174743,55802,'117627','furniture-mobile','width','100',0,'2876'),(174744,55802,'117627','furniture-mobile','width_measure','%',0,'2876'),(174745,55802,'117627','furniture-mobile','float','none',0,'2876'),(174746,55802,'117627','furniture-mobile','hide_additional_buttons','1',0,''),(174747,55802,'117627','furniture-mobile','margin-bottom','15',0,''),(174748,55803,'117628','furniture-mobile','text-align','center',0,''),(174749,55804,'117635','furniture-mobile','text-align','center',0,''),(174750,55805,'117640','furniture-mobile','text-align','center',0,''),(174751,55806,'1642500303.417','furniture-mobile','margin-bottom','10',0,''),(174752,55807,'1639582674.022','furniture-mobile','block_type','2',0,''),(174753,55808,'117626','furniture-mobile','margin-bottom','15',0,''),(174754,55808,'117626','furniture-mobile','padding-top','15',0,''),(174755,55809,'117639','furniture-mobile','font-weight','400',0,''),(174756,55810,'117644','furniture-mobile','font-weight','normal',0,''),(174757,55810,'117644','furniture-mobile','padding-top','10',0,''),(174758,55810,'117644','furniture-mobile','padding-bottom','10',0,''),(174759,55810,'117644','furniture-mobile','box_align','4',0,''),(174760,55811,'120996','furniture-mobile','block_type','1',0,''),(174761,55812,'117651','furniture-mobile','font-weight','normal',0,''),(174762,55812,'117651','furniture-mobile','padding-bottom','20',0,''),(174763,55814,'120998','furniture-mobile','block_type','1',0,''),(174764,55814,'120998','furniture-mobile','padding-bottom','30',0,''),(174765,55815,'121000','furniture-mobile','reviews_count','right',0,''),(174766,55815,'121000','furniture-mobile','display','inline-block',0,''),(174767,55815,'121000','furniture-mobile','padding-right','12',0,''),(174768,55815,'121000','furniture-mobile','border-right-width','1',0,''),(174769,55815,'121000','furniture-mobile','border-right-color','$border-color-6',0,''),(174770,55815,'121000','furniture-mobile','line-height','1',0,''),(174771,55816,'121001','furniture-mobile','text','##TEXT_WRITE_REVIEW##',0,''),(174772,55816,'121001','furniture-mobile','style_class','writeReview',0,''),(174773,55816,'121001','furniture-mobile','display','inline-block',0,''),(174774,55816,'121001','furniture-mobile','padding-left','12',0,''),(174775,55816,'121001','furniture-mobile','line-height','1',0,''),(174776,55816,'121001','furniture-mobile','font-size','14',0,''),(174777,55817,'1639053523.9657','furniture-mobile','block_type','1',0,''),(174778,55817,'1639053523.9657','furniture-mobile','background-color','$background-6',0,''),(174779,55817,'1639053523.9657','furniture-mobile','padding-top','25',0,''),(174780,55817,'1639053523.9657','furniture-mobile','padding-bottom','25',0,''),(174781,55818,'1638963486.2331','furniture-mobile','background-color','$background-7',0,''),(174782,55818,'1638963486.2331','furniture-mobile','padding-top','20',0,''),(174783,55818,'1638963486.2331','furniture-mobile','padding-left','20',0,''),(174784,55818,'1638963486.2331','furniture-mobile','padding-right','20',0,''),(174785,55818,'1638963486.2331','furniture-mobile','padding-bottom','20',0,''),(174786,55819,'1639149261.0383','furniture-mobile','padding-top','20',0,''),(174787,55819,'1639149261.0383','furniture-mobile','padding-bottom','20',0,''),(174788,55819,'1639149261.0383','furniture-mobile','padding-left','20',0,''),(174789,55819,'1639149261.0383','furniture-mobile','padding-right','20',0,''),(174790,55819,'1639149261.0383','furniture-mobile','background-color','$background-7',0,''),(174791,55820,'1639659357.0881','furniture-mobile','block_type','1',0,''),(174792,55820,'1639659357.0881','furniture-mobile','background-color','$background-7',0,''),(174793,55820,'1639659357.0881','furniture-mobile','padding-top','20',0,''),(174794,55820,'1639659357.0881','furniture-mobile','padding-left','20',0,''),(174795,55820,'1639659357.0881','furniture-mobile','padding-right','20',0,''),(174796,55820,'1639659357.0881','furniture-mobile','padding-bottom','20',0,''),(174797,55820,'1639659357.0881','furniture-mobile','margin-bottom','20',0,''),(174798,55821,'1639659044.5523','furniture-mobile','count_products','4',0,''),(174799,55821,'1639659044.5523','furniture-mobile','view_as','carousel',0,''),(174800,55821,'1639659044.5523','furniture-mobile','col_in_row','4',0,''),(174801,55821,'1639659044.5523','furniture-mobile','listing_type','productListing',0,''),(174802,55821,'1639659044.5523','furniture-mobile','col_in_row','3',0,'2885'),(174803,55821,'1639659044.5523','furniture-mobile','col_in_row','2',0,'2876'),(174804,55821,'1639659044.5523','furniture-mobile','col_in_row','1',0,'2906'),(174805,55832,'117665','furniture-mobile','block_type','1',0,''),(174806,55832,'117665','furniture-mobile','style_class','item-holder',0,''),(174807,55832,'117665','furniture-mobile','padding-top','25',0,''),(174808,55832,'117665','furniture-mobile','padding-left','25',0,''),(174809,55832,'117665','furniture-mobile','padding-right','25',0,''),(174810,55832,'117665','furniture-mobile','padding-bottom','25',0,''),(174811,55832,'117665','furniture-mobile','text-align','left',0,''),(174812,55833,'120921','furniture-mobile','block_type','1',0,''),(174813,55833,'120921','furniture-mobile','style_class','item-wrapper',0,''),(174814,55834,'120896','furniture-mobile','block_type','1',0,''),(174815,55834,'120896','furniture-mobile','style_class','item-nav',0,''),(174816,55838,'120919','furniture-mobile','block_type','1',0,''),(174817,55838,'120919','furniture-mobile','style_class','item-content',0,''),(174818,55840,'117668','furniture-mobile','description_characters','90',0,''),(174819,55843,'117673','furniture-mobile','margin-bottom','7',0,''),(174820,55844,'117675','furniture-mobile','clear','both',0,''),(174821,55845,'117676','furniture-mobile','margin-bottom','10',0,''),(174822,55848,'117678','furniture-mobile','block_type','1',0,''),(174823,55848,'117678','furniture-mobile','padding-bottom','30',0,''),(174824,55849,'117679','furniture-mobile','block_type','6',0,''),(174825,55849,'117679','furniture-mobile','font-weight','400',0,''),(174826,55849,'117679','furniture-mobile','schema','6-2',0,'2906'),(174827,55849,'117679','furniture-mobile','schema','6-2',0,'2885'),(174828,55850,'117680','furniture-mobile','font-weight','400',0,''),(174829,55850,'117680','furniture-mobile','padding-right','40',0,''),(174830,55850,'117680','furniture-mobile','padding-right','0',0,'2906'),(174831,55850,'117680','furniture-mobile','padding-right','0',0,'2885'),(174832,55850,'117680','furniture-mobile','margin-bottom','20',0,''),(174833,55851,'117681','furniture-mobile','margin-bottom','20',0,''),(174834,55852,'120916','furniture-mobile','block_type','1',0,''),(174835,55852,'120916','furniture-mobile','padding-right','40',0,''),(174836,55852,'120916','furniture-mobile','style_class','leftCategories',0,''),(174837,55852,'120916','furniture-mobile','padding-bottom','25',0,''),(174838,55852,'120916','furniture-mobile','padding-right','0',0,'2885'),(174839,55853,'120918','furniture-mobile','block_type','1',0,''),(174840,55853,'120918','furniture-mobile','background-color','$background-6',0,''),(174841,55854,'120884','furniture-mobile','type','default',0,''),(174842,55854,'120884','furniture-mobile','class','menu-simple',0,''),(174843,55854,'120884','furniture-mobile','style_class','LeftCategories',0,''),(174844,55855,'120917','furniture-mobile','text','##TEXT_CATEGORIES##',0,''),(174845,55855,'120917','furniture-mobile','padding-top','10',0,''),(174846,55855,'120917','furniture-mobile','padding-left','25',0,''),(174847,55855,'120917','furniture-mobile','padding-right','25',0,''),(174848,55855,'120917','furniture-mobile','padding-bottom','10',0,''),(174849,55855,'120917','furniture-mobile','color','$color-font-7',0,''),(174850,55855,'120917','furniture-mobile','font-size','24',0,''),(174851,55855,'120917','furniture-mobile','font-weight','bold',0,''),(174852,55857,'117683','furniture-mobile','block_type','1',0,''),(174853,55857,'117683','furniture-mobile','padding-top','10',0,''),(174854,55857,'117683','furniture-mobile','padding-bottom','10',0,''),(174855,55857,'117683','furniture-mobile','border-bottom-width','1',0,''),(174856,55857,'117683','furniture-mobile','border-bottom-color','$border-color-3',0,''),(174857,55857,'117683','furniture-mobile','margin-left','0',0,''),(174858,55857,'117683','furniture-mobile','margin-right','0',0,''),(174859,55858,'117684','furniture-mobile','float','left',0,''),(174860,55858,'117684','furniture-mobile','clear','none',0,''),(174861,55858,'117684','furniture-mobile','sort_pos_3','2',0,''),(174862,55858,'117684','furniture-mobile','sort_pos_4','1',0,''),(174863,55858,'117684','furniture-mobile','sort_pos_10','5',0,''),(174864,55858,'117684','furniture-mobile','sort_pos_9','6',0,''),(174865,55858,'117684','furniture-mobile','sort_pos_11','7',0,''),(174866,55858,'117684','furniture-mobile','sort_pos_12','8',0,''),(174867,55858,'117684','furniture-mobile','sort_pos_14','9',0,''),(174868,55858,'117684','furniture-mobile','sort_pos_13','10',0,''),(174869,55858,'117684','furniture-mobile','sort_pos_8','11',0,''),(174870,55858,'117684','furniture-mobile','sort_pos_7','12',0,''),(174871,55858,'117684','furniture-mobile','sort_pos_2','13',0,''),(174872,55858,'117684','furniture-mobile','sort_pos_1','14',0,''),(174873,55858,'117684','furniture-mobile','sort_pos_6','15',0,''),(174874,55858,'117684','furniture-mobile','sort_pos_5','16',0,''),(174875,55858,'117684','furniture-mobile','sort_pos_0','17',0,''),(174876,55858,'117684','furniture-mobile','sort_hide_10','1',0,''),(174877,55858,'117684','furniture-mobile','sort_hide_9','1',0,''),(174878,55858,'117684','furniture-mobile','sort_pos_15','4',0,''),(174879,55858,'117684','furniture-mobile','sort_pos_16','3',0,''),(174880,55858,'117684','furniture-mobile','sort_hide_4','0',0,''),(174881,55858,'117684','furniture-mobile','sort_hide_3','0',0,''),(174882,55858,'117684','furniture-mobile','sort_hide_16','1',0,''),(174883,55858,'117684','furniture-mobile','sort_hide_15','1',0,''),(174884,55858,'117684','furniture-mobile','sort_hide_11','1',0,''),(174885,55858,'117684','furniture-mobile','sort_hide_12','1',0,''),(174886,55858,'117684','furniture-mobile','sort_hide_14','1',0,''),(174887,55858,'117684','furniture-mobile','sort_hide_13','1',0,''),(174888,55858,'117684','furniture-mobile','sort_hide_8','0',0,''),(174889,55858,'117684','furniture-mobile','sort_hide_7','0',0,''),(174890,55858,'117684','furniture-mobile','sort_hide_2','1',0,''),(174891,55858,'117684','furniture-mobile','sort_hide_1','1',0,''),(174892,55858,'117684','furniture-mobile','sort_hide_6','1',0,''),(174893,55858,'117684','furniture-mobile','sort_hide_5','1',0,''),(174894,55858,'117684','furniture-mobile','sort_hide_0','1',0,''),(174895,55858,'117684','furniture-mobile','hide_icons','1',0,''),(174896,55859,'117685','furniture-mobile','float','right',0,''),(174897,55859,'117685','furniture-mobile','display','none',0,'2906'),(174898,55860,'117686','furniture-mobile','float','left',0,''),(174899,55860,'117686','furniture-mobile','clear','none',0,''),(174900,55860,'117686','furniture-mobile','margin-left','20',0,''),(174901,55860,'117686','furniture-mobile','display','none',0,'2906'),(174902,55860,'117686','furniture-mobile','display','none',0,'2890'),(174903,55861,'117687','furniture-mobile','margin-right','20',0,''),(174904,55861,'117687','furniture-mobile','float','right',0,''),(174905,55861,'117687','furniture-mobile','clear','none',0,''),(174906,55861,'117687','furniture-mobile','display','none',0,'2885'),(174907,55862,'117688','furniture-mobile','block_type','5',0,''),(174908,55862,'117688','furniture-mobile','padding-top','10',0,''),(174909,55862,'117688','furniture-mobile','padding-bottom','10',0,''),(174910,55862,'117688','furniture-mobile','schema','5-2',0,'2906'),(174911,55862,'117688','furniture-mobile','border-top-color','$border-color-3',0,''),(174912,55862,'117688','furniture-mobile','border-top-width','1',0,''),(174913,55863,'117689','furniture-mobile','padding-top','3',0,''),(174914,55864,'117690','furniture-mobile','float','right',0,''),(174915,55864,'117690','furniture-mobile','height','31',0,''),(174916,55865,'117691','furniture-mobile','col_in_row','3',0,''),(174917,55865,'117691','furniture-mobile','products_align','left',0,''),(174918,55865,'117691','furniture-mobile','font-weight','400',0,''),(174919,55865,'117691','furniture-mobile','listing_type','productListing',0,''),(174920,55865,'117691','furniture-mobile','listing_type_rows','Rows',0,''),(174921,55865,'117691','furniture-mobile','show_buy_button_b2b','on',0,''),(174922,55865,'117691','furniture-mobile','show_wishlist_button_b2b','1',0,''),(174923,55865,'117691','furniture-mobile','show_compare_b2b','1',0,''),(174924,55865,'117691','furniture-mobile','listing_type_b2b','b2b',0,''),(174925,55865,'117691','furniture-mobile','show_image','0',0,''),(174926,55865,'117691','furniture-mobile','show_stock','0',0,''),(174927,55865,'117691','furniture-mobile','show_description','0',0,''),(174928,55865,'117691','furniture-mobile','show_rating','0',0,''),(174929,55865,'117691','furniture-mobile','show_rating_counts','0',0,''),(174930,55865,'117691','furniture-mobile','show_price','0',0,''),(174931,55865,'117691','furniture-mobile','show_view_button','0',0,''),(174932,55865,'117691','furniture-mobile','show_wishlist_button','0',0,''),(174933,55865,'117691','furniture-mobile','show_compare','0',0,''),(174934,55865,'117691','furniture-mobile','show_name_rows','0',0,''),(174935,55865,'117691','furniture-mobile','show_image_rows','0',0,''),(174936,55865,'117691','furniture-mobile','show_stock_rows','0',0,''),(174937,55865,'117691','furniture-mobile','show_description_rows','0',0,''),(174938,55865,'117691','furniture-mobile','show_model_rows','0',0,''),(174939,55865,'117691','furniture-mobile','show_properties_rows','0',0,''),(174940,55865,'117691','furniture-mobile','show_rating_rows','0',0,''),(174941,55865,'117691','furniture-mobile','show_rating_counts_rows','0',0,''),(174942,55865,'117691','furniture-mobile','show_price_rows','0',0,''),(174943,55865,'117691','furniture-mobile','show_buy_button_rows','0',0,''),(174944,55865,'117691','furniture-mobile','show_qty_input_rows','0',0,''),(174945,55865,'117691','furniture-mobile','show_view_button_rows','0',0,''),(174946,55865,'117691','furniture-mobile','show_wishlist_button_rows','0',0,''),(174947,55865,'117691','furniture-mobile','show_compare_rows','0',0,''),(174948,55865,'117691','furniture-mobile','show_name_b2b','0',0,''),(174949,55865,'117691','furniture-mobile','show_image_b2b','0',0,''),(174950,55865,'117691','furniture-mobile','show_stock_b2b','0',0,''),(174951,55865,'117691','furniture-mobile','show_description_b2b','0',0,''),(174952,55865,'117691','furniture-mobile','show_model_b2b','0',0,''),(174953,55865,'117691','furniture-mobile','show_properties_b2b','0',0,''),(174954,55865,'117691','furniture-mobile','show_rating_b2b','0',0,''),(174955,55865,'117691','furniture-mobile','show_rating_counts_b2b','0',0,''),(174956,55865,'117691','furniture-mobile','show_price_b2b','0',0,''),(174957,55865,'117691','furniture-mobile','show_qty_input_b2b','0',0,''),(174958,55865,'117691','furniture-mobile','show_view_button_b2b','0',0,''),(174959,55865,'117691','furniture-mobile','show_attributes_b2b','0',0,''),(174960,55865,'117691','furniture-mobile','items_on_page','9',0,''),(174961,55865,'117691','furniture-mobile','col_in_row','2',0,'2885'),(174962,55865,'117691','furniture-mobile','col_in_row','1',0,'2906'),(174963,55865,'117691','furniture-mobile','product_names_teg','h2',0,''),(174964,55865,'117691','furniture-mobile','padding-top','20',0,''),(174965,55865,'117691','furniture-mobile','padding-bottom','20',0,''),(174966,55865,'117691','furniture-mobile','col_in_row','2',0,'2890'),(174967,55866,'120912','furniture-mobile','block_type','5',0,''),(174968,55866,'120912','furniture-mobile','padding-top','10',0,''),(174969,55866,'120912','furniture-mobile','schema','5-2',0,'2906'),(174970,55867,'120913','furniture-mobile','padding-top','3',0,''),(174971,55868,'120914','furniture-mobile','float','right',0,''),(174972,55868,'120914','furniture-mobile','height','31',0,''),(174973,55869,'1639760443.0645','furniture-mobile','carousel','1',0,''),(174974,55869,'1639760443.0645','furniture-mobile','col_in_row','4',0,''),(174975,55869,'1639760443.0645','furniture-mobile','fancibox','1',0,''),(174976,55871,'117693','furniture-mobile','block_type','1',0,''),(174977,55872,'117694','furniture-mobile','margin-bottom','20',0,''),(174978,55876,'117696','furniture-mobile','block_type','1',0,''),(174979,55878,'117698','furniture-mobile','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(174980,55879,'117699','furniture-mobile','width','680',0,''),(174981,55879,'117699','furniture-mobile','font-weight','normal',0,''),(174982,55879,'117699','furniture-mobile','font-size','12',0,''),(174983,55879,'117699','furniture-mobile','padding-top','20',0,''),(174984,55879,'117699','furniture-mobile','padding-bottom','20',0,''),(174985,55879,'117699','furniture-mobile','color','$color-font-8',0,''),(174986,55880,'117700','furniture-mobile','font-weight','400',0,''),(174987,55880,'117700','furniture-mobile','padding-top','20',0,''),(174988,55880,'117700','furniture-mobile','padding-bottom','0',0,''),(174989,55880,'117700','furniture-mobile','font-size','12',0,''),(174990,55881,'117701','furniture-mobile','block_type','3',0,''),(174991,55881,'117701','furniture-mobile','font-weight','normal',0,''),(174992,55881,'117701','furniture-mobile','padding-top','20',0,''),(174993,55882,'117702','furniture-mobile','text','<p>If undelivered please return to:</p>',1,''),(174994,55882,'117702','furniture-mobile','font-size','12',0,''),(174995,55882,'117702','furniture-mobile','font-weight','bold',0,''),(174996,55883,'117703','furniture-mobile','font-size','12',0,''),(174997,55884,'117704','furniture-mobile','text','<p>Thank you for your order</p>',1,''),(174998,55884,'117704','furniture-mobile','color','$color-font-10',0,''),(174999,55884,'117704','furniture-mobile','font-size','13',0,''),(175000,55884,'117704','furniture-mobile','font-weight','bold',0,''),(175001,55884,'117704','furniture-mobile','padding-top','5',0,''),(175002,55884,'117704','furniture-mobile','text-align','center',0,''),(175003,55885,'117705','furniture-mobile','font-weight','400',0,''),(175004,55885,'117705','furniture-mobile','text-align','center',0,''),(175005,55885,'117705','furniture-mobile','padding-top','0',0,''),(175007,55885,'117705','furniture-mobile','padding-left','20',0,''),(175008,55885,'117705','furniture-mobile','padding-right','20',0,''),(175009,55886,'117706','furniture-mobile','block_type','6',0,''),(175010,55886,'117706','furniture-mobile','font-weight','normal',0,''),(175011,55886,'117706','furniture-mobile','font-size','16',0,''),(175012,55887,'117707','furniture-mobile','text','<p>Email:</p>',1,''),(175013,55887,'117707','furniture-mobile','font-weight','normal',0,''),(175014,55887,'117707','furniture-mobile','text-align','right',0,''),(175015,55887,'117707','furniture-mobile','font-size','12',0,''),(175016,55888,'117708','furniture-mobile','font-weight','normal',0,''),(175017,55888,'117708','furniture-mobile','text-align','right',0,''),(175018,55888,'117708','furniture-mobile','font-size','12',0,''),(175019,55889,'117709','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(175020,55889,'117709','furniture-mobile','font-size','12',0,''),(175021,55889,'117709','furniture-mobile','font-weight','bold',0,''),(175022,55889,'117709','furniture-mobile','text-align','right',0,''),(175023,55890,'117710','furniture-mobile','block_type','6',0,''),(175024,55890,'117710','furniture-mobile','font-weight','normal',0,''),(175025,55890,'117710','furniture-mobile','font-size','16',0,''),(175026,55891,'117711','furniture-mobile','text','<p>Phone:</p>',1,''),(175027,55891,'117711','furniture-mobile','font-weight','normal',0,''),(175028,55891,'117711','furniture-mobile','text-align','right',0,''),(175029,55891,'117711','furniture-mobile','font-size','12',0,''),(175030,55892,'117712','furniture-mobile','font-weight','normal',0,''),(175031,55892,'117712','furniture-mobile','text-align','right',0,''),(175032,55892,'117712','furniture-mobile','font-size','12',0,''),(175033,55893,'117713','furniture-mobile','block_type','2',0,''),(175034,55893,'117713','furniture-mobile','font-weight','normal',0,''),(175035,55893,'117713','furniture-mobile','padding-bottom','20',0,''),(175036,55894,'117714','furniture-mobile','font-weight','400',0,''),(175037,55894,'117714','furniture-mobile','padding-top','20',0,''),(175039,55895,'117715','furniture-mobile','block_type','11',0,''),(175040,55895,'117715','furniture-mobile','font-weight','normal',0,''),(175041,55896,'117716','furniture-mobile','text','<p>Phone:</p>',1,''),(175042,55896,'117716','furniture-mobile','font-weight','normal',0,''),(175043,55896,'117716','furniture-mobile','text-align','right',0,''),(175044,55897,'117717','furniture-mobile','font-weight','normal',0,''),(175045,55897,'117717','furniture-mobile','text-align','right',0,''),(175046,55898,'117718','furniture-mobile','block_type','11',0,''),(175047,55898,'117718','furniture-mobile','font-weight','normal',0,''),(175048,55899,'117719','furniture-mobile','text','<p>Web:</p>',1,''),(175049,55899,'117719','furniture-mobile','font-weight','normal',0,''),(175050,55899,'117719','furniture-mobile','text-align','right',0,''),(175051,55900,'117720','furniture-mobile','font-weight','normal',0,''),(175052,55900,'117720','furniture-mobile','text-align','right',0,''),(175053,55901,'117721','furniture-mobile','block_type','1',0,''),(175054,55902,'117722','furniture-mobile','font-weight','normal',0,''),(175055,55902,'117722','furniture-mobile','text-align','right',0,''),(175056,55902,'117722','furniture-mobile','padding-bottom','10',0,''),(175057,55902,'117722','furniture-mobile','address_spacer',',',0,''),(175058,55902,'117722','furniture-mobile','font-size','12',0,''),(175059,55903,'117723','furniture-mobile','block_type','11',0,''),(175060,55903,'117723','furniture-mobile','font-weight','normal',0,''),(175061,55904,'117724','furniture-mobile','text','<p>Email:</p>',1,''),(175062,55904,'117724','furniture-mobile','font-weight','normal',0,''),(175063,55904,'117724','furniture-mobile','text-align','right',0,''),(175064,55905,'117725','furniture-mobile','font-weight','normal',0,''),(175065,55905,'117725','furniture-mobile','text-align','right',0,''),(175066,55906,'117726','furniture-mobile','block_type','4',0,''),(175067,55906,'117726','furniture-mobile','font-weight','normal',0,''),(175068,55906,'117726','furniture-mobile','border-top-width','1',0,''),(175069,55906,'117726','furniture-mobile','border-top-color','$border-color-4',0,''),(175070,55906,'117726','furniture-mobile','border-left-width','1',0,''),(175071,55906,'117726','furniture-mobile','border-left-color','$border-color-4',0,''),(175072,55906,'117726','furniture-mobile','border-right-width','1',0,''),(175073,55906,'117726','furniture-mobile','border-right-color','$border-color-4',0,''),(175074,55906,'117726','furniture-mobile','border-bottom-width','1',0,''),(175075,55906,'117726','furniture-mobile','border-bottom-color','$border-color-4',0,''),(175076,55907,'117727','furniture-mobile','block_type','2',0,''),(175077,55907,'117727','furniture-mobile','font-weight','normal',0,''),(175078,55907,'117727','furniture-mobile','border-right-width','1',0,''),(175079,55907,'117727','furniture-mobile','border-right-color','$border-color-4',0,''),(175080,55908,'117728','furniture-mobile','block_type','1',0,''),(175081,55908,'117728','furniture-mobile','font-weight','400',0,''),(175082,55908,'117728','furniture-mobile','background-color','$background-6',0,''),(175083,55908,'117728','furniture-mobile','padding-top','10',0,''),(175084,55908,'117728','furniture-mobile','padding-left','10',0,''),(175085,55908,'117728','furniture-mobile','padding-right','10',0,''),(175086,55908,'117728','furniture-mobile','padding-bottom','30',0,''),(175087,55909,'117729','furniture-mobile','font-size','12',0,''),(175088,55910,'117730','furniture-mobile','text','<p>ADDRESS:</p>\n',1,''),(175089,55910,'117730','furniture-mobile','font-size','14',0,''),(175090,55910,'117730','furniture-mobile','font-weight','bold',0,''),(175091,55911,'117731','furniture-mobile','block_type','1',0,''),(175092,55911,'117731','furniture-mobile','font-weight','normal',0,''),(175093,55911,'117731','furniture-mobile','padding-top','10',0,''),(175094,55911,'117731','furniture-mobile','padding-left','10',0,''),(175095,55911,'117731','furniture-mobile','padding-right','10',0,''),(175096,55911,'117731','furniture-mobile','padding-bottom','10',0,''),(175097,55913,'117733','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(175098,55913,'117733','furniture-mobile','font-weight','bold',0,''),(175099,55913,'117733','furniture-mobile','font-size','14',0,''),(175100,55913,'117733','furniture-mobile','padding-top','10',0,''),(175101,55914,'117734','furniture-mobile','font-weight','normal',0,''),(175102,55915,'117735','furniture-mobile','font-weight','normal',0,''),(175103,55916,'117736','furniture-mobile','text','<p>PHONE NUMBER:</p>',1,''),(175104,55916,'117736','furniture-mobile','font-size','14',0,''),(175105,55916,'117736','furniture-mobile','font-weight','bold',0,''),(175106,55916,'117736','furniture-mobile','padding-top','10',0,''),(175107,55917,'117737','furniture-mobile','text','<p>CUSTOMER:</p>',1,''),(175108,55917,'117737','furniture-mobile','font-size','13',0,''),(175109,55917,'117737','furniture-mobile','font-weight','bold',0,''),(175110,55918,'117738','furniture-mobile','font-size','14',0,''),(175111,55918,'117738','furniture-mobile','font-weight','bold',0,''),(175112,55918,'117738','furniture-mobile','text-align','center',0,''),(175113,55918,'117738','furniture-mobile','padding-bottom','10',0,''),(175114,55918,'117738','furniture-mobile','padding-top','10',0,''),(175115,55919,'117739','furniture-mobile','text','<p>Order date:</p>\n',1,''),(175116,55919,'117739','furniture-mobile','font-weight','bold',0,''),(175117,55919,'117739','furniture-mobile','text-align','center',0,''),(175118,55919,'117739','furniture-mobile','font-size','12',0,''),(175119,55920,'117740','furniture-mobile','font-weight','normal',0,''),(175120,55920,'117740','furniture-mobile','text-align','center',0,''),(175121,55920,'117740','furniture-mobile','padding-bottom','10',0,''),(175122,55921,'117741','furniture-mobile','block_type','5',0,''),(175123,55921,'117741','furniture-mobile','font-weight','normal',0,''),(175124,55921,'117741','furniture-mobile','border-bottom-width','1',0,''),(175125,55921,'117741','furniture-mobile','border-bottom-color','$border-color-4',0,''),(175126,55921,'117741','furniture-mobile','border-top-width','1',0,''),(175127,55921,'117741','furniture-mobile','border-top-color','$border-color-4',0,''),(175128,55921,'117741','furniture-mobile','border-left-color','$border-color-4',0,''),(175129,55921,'117741','furniture-mobile','border-left-width','1',0,''),(175130,55922,'117742','furniture-mobile','block_type','1',0,''),(175131,55922,'117742','furniture-mobile','font-weight','normal',0,''),(175132,55922,'117742','furniture-mobile','padding-top','10',0,''),(175133,55922,'117742','furniture-mobile','padding-left','10',0,''),(175134,55922,'117742','furniture-mobile','padding-right','10',0,''),(175135,55923,'117743','furniture-mobile','font-weight','400',0,''),(175136,55923,'117743','furniture-mobile','line-height','120',0,''),(175137,55923,'117743','furniture-mobile','line_height_measure','%',0,''),(175138,55923,'117743','furniture-mobile','font-size','12',0,''),(175139,55924,'117744','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(175140,55924,'117744','furniture-mobile','font-size','14',0,''),(175141,55924,'117744','furniture-mobile','font-weight','bold',0,''),(175142,55924,'117744','furniture-mobile','padding-bottom','10',0,''),(175145,55928,'117745','furniture-mobile','block_type','1',0,''),(175146,55929,'117746','furniture-mobile','block_type','6',0,''),(175147,55929,'117746','furniture-mobile','schema','6-3',0,'2885'),(175148,55930,'117747','furniture-mobile','aria_name','account-menu',0,''),(175205,55950,'117748','furniture-mobile','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(175206,55951,'117749','furniture-mobile','link','Quotation Info',0,''),(175207,55951,'117749','furniture-mobile','margin-bottom','20',0,''),(175208,55952,'117750','furniture-mobile','block_type','1',0,''),(175209,55953,'117751','furniture-mobile','block_type','6',0,''),(175210,55953,'117751','furniture-mobile','schema','6-3',0,'2885'),(175211,55954,'117752','furniture-mobile','aria_name','account-menu',0,''),(175268,55974,'117753','furniture-mobile','block_type','3',0,''),(175269,55975,'117754','furniture-mobile','block_type','1',0,''),(175270,55975,'117754','furniture-mobile','padding-right','20',0,''),(175271,55975,'117754','furniture-mobile','padding-bottom','20',0,''),(175272,55976,'117755','furniture-mobile','orders_data','name',0,''),(175273,55977,'117756','furniture-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(175274,55978,'117757','furniture-mobile','block_type','1',0,''),(175275,55978,'117757','furniture-mobile','padding-right','20',0,''),(175276,55978,'117757','furniture-mobile','padding-bottom','20',0,''),(175277,55979,'117758','furniture-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(175278,55980,'117759','furniture-mobile','orders_data','telephone',0,''),(175279,55981,'117760','furniture-mobile','block_type','1',0,''),(175280,55981,'117760','furniture-mobile','padding-right','20',0,''),(175281,55982,'117761','furniture-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(175282,55983,'117762','furniture-mobile','orders_data','shipping_method',0,''),(175283,55984,'117763','furniture-mobile','block_type','1',0,''),(175284,55984,'117763','furniture-mobile','padding-right','20',0,''),(175285,55984,'117763','furniture-mobile','padding-bottom','20',0,''),(175286,55985,'117764','furniture-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(175287,55986,'117765','furniture-mobile','orders_data','delivery_address',0,''),(175288,55987,'117766','furniture-mobile','block_type','1',0,''),(175289,55987,'117766','furniture-mobile','padding-bottom','20',0,''),(175290,55988,'117767','furniture-mobile','orders_data','billing_address',0,''),(175291,55989,'117768','furniture-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(175292,55990,'117769','furniture-mobile','block_type','1',0,''),(175293,55991,'117770','furniture-mobile','orders_data','payment_method',0,''),(175294,55992,'117771','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(175295,55993,'117772','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(175296,55995,'117774','furniture-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(175297,55998,'117777','furniture-mobile','block_type','2',0,''),(175298,55998,'117777','furniture-mobile','padding-top','20',0,''),(175299,55998,'117777','furniture-mobile','margin-bottom','20',0,''),(175300,55999,'117778','furniture-mobile','like_button','1',0,''),(175301,55999,'117778','furniture-mobile','text','IMAGE_BUTTON_BACK',0,''),(175302,55999,'117778','furniture-mobile','link','Quotations',0,''),(175303,56000,'117779','furniture-mobile','text','<h1>##HEADING_TITLE##</h1>',0,''),(175304,56001,'117780','furniture-mobile','padding-top','20',0,''),(175305,56001,'117780','furniture-mobile','padding-bottom','20',0,''),(175306,56001,'117780','furniture-mobile','block_type','1',0,''),(175307,56001,'117780','furniture-mobile','background-color','$background-6',0,''),(175308,56003,'117782','furniture-mobile','block_type','4',0,''),(175309,56003,'117782','furniture-mobile','schema','4-2',0,'2885'),(175310,56003,'117782','furniture-mobile','schema','4-2',0,'2876'),(175311,56004,'117783','furniture-mobile','background-color','$background-7',0,''),(175312,56005,'117784','furniture-mobile','block_type','1',0,''),(175313,56005,'117784','furniture-mobile','style_class','order-summary',0,''),(175314,56005,'117784','furniture-mobile','margin-left','30',0,''),(175315,56005,'117784','furniture-mobile','margin-left','0',0,'2885'),(175316,56006,'117785','furniture-mobile','block_type','1',0,''),(175317,56006,'117785','furniture-mobile','padding-left','20',0,''),(175318,56006,'117785','furniture-mobile','padding-right','20',0,''),(175319,56006,'117785','furniture-mobile','padding-bottom','30',0,''),(175320,56007,'117786','furniture-mobile','max-width','300',0,'2885'),(175321,56007,'117786','furniture-mobile','margin_left_measure','auto',0,'2885'),(175322,56007,'117786','furniture-mobile','margin_right_measure','auto',0,'2885'),(175323,56007,'117786','furniture-mobile','margin-bottom','0',0,''),(175324,56009,'117788','furniture-mobile','block_type','1',0,''),(175325,56010,'117789','furniture-mobile','block_type','6',0,''),(175326,56010,'117789','furniture-mobile','schema','6-3',0,'2885'),(175327,56011,'117790','furniture-mobile','aria_name','account-menu',0,''),(175384,56031,'117791','furniture-mobile','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(175385,56032,'117792','furniture-mobile','margin-bottom','20',0,''),(175386,56033,'117793','furniture-mobile','block_type','1',0,''),(175387,56035,'117795','furniture-mobile','pagination','bottom',0,''),(175388,56036,'117796','furniture-mobile','width','800',0,''),(175389,56037,'117797','furniture-mobile','block_type','11',0,''),(175390,56037,'117797','furniture-mobile','border-top-width','1',0,''),(175391,56037,'117797','furniture-mobile','border-left-width','1',0,''),(175392,56037,'117797','furniture-mobile','border-right-width','1',0,''),(175393,56037,'117797','furniture-mobile','border-bottom-width','1',0,''),(175394,56037,'117797','furniture-mobile','border-top-color','$border-color-5',0,''),(175395,56037,'117797','furniture-mobile','border-left-color','$border-color-5',0,''),(175396,56037,'117797','furniture-mobile','border-right-color','$border-color-5',0,''),(175397,56037,'117797','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175398,56038,'117798','furniture-mobile','block_type','1',0,''),(175399,56038,'117798','furniture-mobile','border-right-width','1',0,''),(175400,56038,'117798','furniture-mobile','border-right-color','$border-color-5',0,''),(175401,56038,'117798','furniture-mobile','padding-top','10',0,''),(175402,56038,'117798','furniture-mobile','padding-right','10',0,''),(175403,56038,'117798','furniture-mobile','padding-bottom','10',0,''),(175404,56039,'117799','furniture-mobile','block_type','9',0,''),(175405,56040,'117800','furniture-mobile','text','1.',0,''),(175406,56040,'117800','furniture-mobile','font-size','12',0,''),(175407,56040,'117800','furniture-mobile','text-align','right',0,''),(175408,56040,'117800','furniture-mobile','padding-right','5',0,''),(175409,56041,'117801','furniture-mobile','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(175410,56041,'117801','furniture-mobile','font-size','12',0,''),(175411,56041,'117801','furniture-mobile','padding-bottom','5',0,''),(175412,56042,'117802','furniture-mobile','block_type','9',0,''),(175413,56043,'117803','furniture-mobile','text','4.',0,''),(175414,56043,'117803','furniture-mobile','font-size','12',0,''),(175415,56043,'117803','furniture-mobile','text-align','right',0,''),(175416,56043,'117803','furniture-mobile','margin-right','5',0,''),(175417,56044,'117804','furniture-mobile','text','Our Replacement Department will process your request.',0,''),(175418,56044,'117804','furniture-mobile','font-size','12',0,''),(175419,56044,'117804','furniture-mobile','padding-bottom','5',0,''),(175420,56045,'117805','furniture-mobile','block_type','9',0,''),(175421,56046,'117806','furniture-mobile','text','3.',0,''),(175422,56046,'117806','furniture-mobile','font-size','12',0,''),(175423,56046,'117806','furniture-mobile','text-align','right',0,''),(175424,56046,'117806','furniture-mobile','margin-right','5',0,''),(175425,56047,'117807','furniture-mobile','text','Return the authorized item(s) per shipping instructions.',0,''),(175426,56047,'117807','furniture-mobile','font-size','12',0,''),(175427,56047,'117807','furniture-mobile','padding-bottom','5',0,''),(175428,56048,'117808','furniture-mobile','block_type','9',0,''),(175429,56049,'117809','furniture-mobile','text','2.',0,''),(175430,56049,'117809','furniture-mobile','font-size','12',0,''),(175431,56049,'117809','furniture-mobile','text-align','right',0,''),(175432,56049,'117809','furniture-mobile','margin-right','5',0,''),(175433,56050,'117810','furniture-mobile','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(175434,56050,'117810','furniture-mobile','font-size','12',0,''),(175435,56050,'117810','furniture-mobile','padding-bottom','5',0,''),(175436,56051,'117811','furniture-mobile','block_type','1',0,''),(175437,56051,'117811','furniture-mobile','padding-left','15',0,''),(175438,56052,'117812','furniture-mobile','text','Replacement Policy:',0,''),(175439,56052,'117812','furniture-mobile','font-size','14',0,''),(175440,56052,'117812','furniture-mobile','padding-bottom','5',0,''),(175441,56052,'117812','furniture-mobile','font-weight','bold',0,''),(175442,56053,'117813','furniture-mobile','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(175443,56053,'117813','furniture-mobile','font-size','11',0,''),(175444,56053,'117813','furniture-mobile','font-style','italic',0,''),(175445,56053,'117813','furniture-mobile','padding-bottom','5',0,''),(175446,56054,'117814','furniture-mobile','block_type','1',0,''),(175447,56054,'117814','furniture-mobile','border-bottom-width','1',0,''),(175448,56054,'117814','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175449,56055,'117815','furniture-mobile','text','Return Material Authorization (RMA) Form',0,''),(175450,56055,'117815','furniture-mobile','text-align','center',0,''),(175451,56055,'117815','furniture-mobile','font-size','16',0,''),(175452,56055,'117815','furniture-mobile','font-weight','bold',0,''),(175453,56056,'117816','furniture-mobile','text-align','center',0,''),(175454,56056,'117816','furniture-mobile','logo','themes/furniture-mobile/img/Furntech-1.jpg',1,''),(175455,56056,'117816','furniture-mobile','padding-top','10',0,''),(175456,56056,'117816','furniture-mobile','padding-bottom','10',0,''),(175457,56057,'117817','furniture-mobile','block_type','1',0,''),(175458,56057,'117817','furniture-mobile','padding-top','10',0,''),(175459,56057,'117817','furniture-mobile','padding-left','10',0,''),(175460,56057,'117817','furniture-mobile','padding-right','10',0,''),(175461,56057,'117817','furniture-mobile','padding-bottom','20',0,''),(175462,56058,'117818','furniture-mobile','block_type','2',0,''),(175463,56058,'117818','furniture-mobile','padding-top','5',0,''),(175464,56059,'117819','furniture-mobile','block_type','11',0,''),(175465,56060,'117820','furniture-mobile','text','Email:',0,''),(175466,56060,'117820','furniture-mobile','font-size','12',0,''),(175467,56061,'117821','furniture-mobile','data','rrDelivery_email_address',0,''),(175468,56061,'117821','furniture-mobile','font-size','12',0,''),(175469,56062,'117822','furniture-mobile','block_type','11',0,''),(175470,56063,'117823','furniture-mobile','text','Phone:',0,''),(175471,56063,'117823','furniture-mobile','font-size','12',0,''),(175472,56064,'117824','furniture-mobile','data','rrDelivery_telephone',0,''),(175473,56064,'117824','furniture-mobile','font-size','12',0,''),(175474,56065,'117825','furniture-mobile','block_type','2',0,''),(175475,56065,'117825','furniture-mobile','padding-top','5',0,''),(175476,56066,'117826','furniture-mobile','block_type','11',0,''),(175477,56067,'117827','furniture-mobile','text','Country:',0,''),(175478,56067,'117827','furniture-mobile','font-size','12',0,''),(175479,56068,'117828','furniture-mobile','data','rrDelivery_country',0,''),(175480,56068,'117828','furniture-mobile','font-size','12',0,''),(175481,56069,'117829','furniture-mobile','block_type','11',0,''),(175482,56070,'117830','furniture-mobile','text','Postcode:',0,''),(175483,56070,'117830','furniture-mobile','font-size','12',0,''),(175484,56071,'117831','furniture-mobile','data','rrDelivery_postcode',0,''),(175485,56071,'117831','furniture-mobile','font-size','12',0,''),(175486,56072,'117832','furniture-mobile','block_type','2',0,''),(175487,56072,'117832','furniture-mobile','padding-top','5',0,''),(175488,56073,'117833','furniture-mobile','block_type','11',0,''),(175489,56074,'117834','furniture-mobile','text','City:',0,''),(175490,56074,'117834','furniture-mobile','font-size','12',0,''),(175491,56075,'117835','furniture-mobile','data','rrDelivery_city',0,''),(175492,56075,'117835','furniture-mobile','font-size','12',0,''),(175493,56076,'117836','furniture-mobile','block_type','11',0,''),(175494,56077,'117837','furniture-mobile','text','State:',0,''),(175495,56077,'117837','furniture-mobile','font-size','12',0,''),(175496,56078,'117838','furniture-mobile','data','rrDelivery_state',0,''),(175497,56078,'117838','furniture-mobile','font-size','12',0,''),(175498,56079,'117839','furniture-mobile','block_type','9',0,''),(175499,56079,'117839','furniture-mobile','padding-top','5',0,''),(175500,56080,'117840','furniture-mobile','text','Address:',0,''),(175501,56080,'117840','furniture-mobile','font-size','12',0,''),(175502,56081,'117841','furniture-mobile','data','rrDelivery_street_address',0,''),(175503,56081,'117841','furniture-mobile','font-size','12',0,''),(175504,56082,'117842','furniture-mobile','block_type','2',0,''),(175505,56083,'117843','furniture-mobile','block_type','11',0,''),(175506,56084,'117844','furniture-mobile','text','Company:',0,''),(175507,56084,'117844','furniture-mobile','font-size','12',0,''),(175508,56085,'117845','furniture-mobile','data','rrDelivery_company',0,''),(175509,56085,'117845','furniture-mobile','font-size','12',0,''),(175510,56086,'117846','furniture-mobile','block_type','2',0,''),(175511,56087,'117847','furniture-mobile','text','Contact Name:',0,''),(175512,56087,'117847','furniture-mobile','font-size','12',0,''),(175513,56088,'117848','furniture-mobile','data','rrDelivery_name',0,''),(175514,56088,'117848','furniture-mobile','font-size','12',0,''),(175515,56089,'117849','furniture-mobile','block_type','2',0,''),(175516,56089,'117849','furniture-mobile','padding-left','10',0,''),(175517,56089,'117849','furniture-mobile','padding-top','20',0,''),(175518,56089,'117849','furniture-mobile','padding-right','10',0,''),(175519,56090,'117850','furniture-mobile','block_type','5',0,''),(175520,56091,'117851','furniture-mobile','text','RMA No:',0,''),(175521,56091,'117851','furniture-mobile','font-size','12',0,''),(175522,56091,'117851','furniture-mobile','font-weight','bold',0,''),(175523,56092,'117852','furniture-mobile','data','rrNumber',0,''),(175524,56092,'117852','furniture-mobile','font-size','12',0,''),(175525,56092,'117852','furniture-mobile','font-weight','bold',0,''),(175526,56093,'117853','furniture-mobile','block_type','2',0,''),(175527,56094,'117854','furniture-mobile','text','Date Issued:',0,''),(175528,56094,'117854','furniture-mobile','font-size','12',0,''),(175529,56094,'117854','furniture-mobile','font-weight','bold',0,''),(175530,56095,'117855','furniture-mobile','data','rrDateCreate',0,''),(175531,56095,'117855','furniture-mobile','font-size','12',0,''),(175532,56095,'117855','furniture-mobile','font-weight','bold',0,''),(175533,56096,'117856','furniture-mobile','block_type','1',0,''),(175534,56097,'117857','furniture-mobile','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(175535,56097,'117857','furniture-mobile','font-size','12',0,''),(175536,56097,'117857','furniture-mobile','font-style','italic',0,''),(175537,56097,'117857','furniture-mobile','padding-bottom','20',0,''),(175538,56099,'117859','furniture-mobile','block_type','1',0,''),(175539,56099,'117859','furniture-mobile','border-top-width','1',0,''),(175540,56099,'117859','furniture-mobile','border-left-width','1',0,''),(175541,56099,'117859','furniture-mobile','border-right-width','1',0,''),(175542,56099,'117859','furniture-mobile','border-bottom-width','1',0,''),(175543,56099,'117859','furniture-mobile','border-top-color','$border-color-5',0,''),(175544,56099,'117859','furniture-mobile','border-left-color','$border-color-5',0,''),(175545,56099,'117859','furniture-mobile','border-right-color','$border-color-5',0,''),(175546,56099,'117859','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175547,56100,'117860','furniture-mobile','block_type','11',0,''),(175548,56101,'117861','furniture-mobile','block_type','1',0,''),(175549,56101,'117861','furniture-mobile','padding-top','10',0,''),(175550,56101,'117861','furniture-mobile','padding-right','10',0,''),(175551,56101,'117861','furniture-mobile','padding-bottom','10',0,''),(175552,56101,'117861','furniture-mobile','border-right-width','1',0,''),(175553,56101,'117861','furniture-mobile','border-right-color','$border-color-5',0,''),(175554,56102,'117862','furniture-mobile','block_type','9',0,''),(175555,56103,'117863','furniture-mobile','text','4.',0,''),(175556,56103,'117863','furniture-mobile','font-size','12',0,''),(175557,56103,'117863','furniture-mobile','text-align','right',0,''),(175558,56103,'117863','furniture-mobile','padding-right','5',0,''),(175559,56104,'117864','furniture-mobile','font-size','11',0,''),(175560,56104,'117864','furniture-mobile','font-style','italic',0,''),(175561,56104,'117864','furniture-mobile','padding-bottom','5',0,''),(175562,56105,'117865','furniture-mobile','text','Ship returned items to:',0,''),(175563,56105,'117865','furniture-mobile','font-size','12',0,''),(175564,56105,'117865','furniture-mobile','padding-bottom','5',0,''),(175565,56106,'117866','furniture-mobile','block_type','9',0,''),(175566,56107,'117867','furniture-mobile','text','3.',0,''),(175567,56107,'117867','furniture-mobile','font-size','12',0,''),(175568,56107,'117867','furniture-mobile','text-align','right',0,''),(175569,56107,'117867','furniture-mobile','padding-right','5',0,''),(175570,56108,'117868','furniture-mobile','text','Ship only the items that are authorized.',0,''),(175571,56108,'117868','furniture-mobile','font-size','12',0,''),(175572,56108,'117868','furniture-mobile','padding-bottom','10',0,''),(175573,56109,'117869','furniture-mobile','block_type','9',0,''),(175574,56110,'117870','furniture-mobile','text','1.',0,''),(175575,56110,'117870','furniture-mobile','font-size','12',0,''),(175576,56110,'117870','furniture-mobile','text-align','right',0,''),(175577,56110,'117870','furniture-mobile','padding-right','5',0,''),(175578,56111,'117871','furniture-mobile','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(175579,56111,'117871','furniture-mobile','font-size','12',0,''),(175580,56111,'117871','furniture-mobile','padding-bottom','10',0,''),(175581,56112,'117872','furniture-mobile','block_type','1',0,''),(175582,56113,'117873','furniture-mobile','text','Shipping Instructions:',0,''),(175583,56113,'117873','furniture-mobile','font-weight','bold',0,''),(175584,56113,'117873','furniture-mobile','font-size','14',0,''),(175585,56113,'117873','furniture-mobile','padding-bottom','5',0,''),(175586,56113,'117873','furniture-mobile','padding-left','10',0,''),(175587,56114,'117874','furniture-mobile','block_type','9',0,''),(175588,56115,'117875','furniture-mobile','text','2.',0,''),(175589,56115,'117875','furniture-mobile','font-size','12',0,''),(175590,56115,'117875','furniture-mobile','text-align','right',0,''),(175591,56115,'117875','furniture-mobile','padding-right','5',0,''),(175592,56116,'117876','furniture-mobile','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(175593,56116,'117876','furniture-mobile','font-size','12',0,''),(175594,56116,'117876','furniture-mobile','padding-bottom','10',0,''),(175595,56117,'117877','furniture-mobile','block_type','1',0,''),(175596,56117,'117877','furniture-mobile','padding-left','10',0,''),(175597,56117,'117877','furniture-mobile','padding-right','10',0,''),(175598,56117,'117877','furniture-mobile','padding-bottom','10',0,''),(175599,56118,'117878','furniture-mobile','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(175600,56118,'117878','furniture-mobile','font-size','11',0,''),(175601,56118,'117878','furniture-mobile','font-style','italic',0,''),(175602,56119,'117879','furniture-mobile','block_type','1',0,''),(175603,56119,'117879','furniture-mobile','padding-top','10',0,''),(175604,56119,'117879','furniture-mobile','padding-left','40',0,''),(175605,56119,'117879','furniture-mobile','padding-right','40',0,''),(175606,56119,'117879','furniture-mobile','padding-bottom','10',0,''),(175607,56120,'117880','furniture-mobile','block_type','1',0,''),(175608,56120,'117880','furniture-mobile','padding-top','10',0,''),(175609,56120,'117880','furniture-mobile','padding-left','10',0,''),(175610,56120,'117880','furniture-mobile','padding-right','10',0,''),(175611,56120,'117880','furniture-mobile','padding-bottom','10',0,''),(175612,56120,'117880','furniture-mobile','border-top-width','1',0,''),(175613,56120,'117880','furniture-mobile','border-left-width','1',0,''),(175614,56120,'117880','furniture-mobile','border-right-width','1',0,''),(175615,56120,'117880','furniture-mobile','border-bottom-width','1',0,''),(175616,56120,'117880','furniture-mobile','border-top-color','$border-color-5',0,''),(175617,56120,'117880','furniture-mobile','border-left-color','$border-color-5',0,''),(175618,56120,'117880','furniture-mobile','border-right-color','$border-color-5',0,''),(175619,56120,'117880','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175620,56121,'117881','furniture-mobile','block_type','3',0,''),(175621,56122,'117882','furniture-mobile','data','rrDelivery_name',0,''),(175622,56122,'117882','furniture-mobile','font-size','9',0,''),(175623,56123,'117883','furniture-mobile','block_type','2',0,''),(175624,56124,'117884','furniture-mobile','text','RMA#:',0,''),(175625,56124,'117884','furniture-mobile','font-size','10',0,''),(175626,56125,'117885','furniture-mobile','data','rrNumber',0,''),(175627,56125,'117885','furniture-mobile','font-size','9',0,''),(175628,56126,'117886','furniture-mobile','block_type','5',0,''),(175629,56127,'117887','furniture-mobile','font-size','9',0,''),(175630,56128,'117888','furniture-mobile','block_type','1',0,''),(175631,56128,'117888','furniture-mobile','padding-left','10',0,''),(175632,56128,'117888','furniture-mobile','padding-right','10',0,''),(175633,56128,'117888','furniture-mobile','padding-bottom','10',0,''),(175634,56129,'117889','furniture-mobile','text','Use this space for additional Comments:',0,''),(175635,56129,'117889','furniture-mobile','font-size','11',0,''),(175636,56129,'117889','furniture-mobile','font-style','italic',0,''),(175637,56130,'117890','furniture-mobile','text','&nbsp;',0,''),(175638,56130,'117890','furniture-mobile','border-bottom-width','1',0,''),(175639,56130,'117890','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175640,56131,'117891','furniture-mobile','text','&nbsp;',0,''),(175641,56131,'117891','furniture-mobile','border-bottom-width','1',0,''),(175642,56131,'117891','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175643,56131,'117891','furniture-mobile','padding-top','5',0,''),(175644,56132,'117892','furniture-mobile','text','&nbsp;',0,''),(175645,56132,'117892','furniture-mobile','border-bottom-width','1',0,''),(175646,56132,'117892','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175647,56132,'117892','furniture-mobile','padding-top','5',0,''),(175648,56133,'117893','furniture-mobile','text','&nbsp;',0,''),(175649,56133,'117893','furniture-mobile','border-bottom-width','1',0,''),(175650,56133,'117893','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175651,56133,'117893','furniture-mobile','padding-top','5',0,''),(175652,56134,'117894','furniture-mobile','block_type','3',0,''),(175653,56134,'117894','furniture-mobile','padding-top','10',0,''),(175654,56134,'117894','furniture-mobile','padding-bottom','10',0,''),(175655,56134,'117894','furniture-mobile','padding-right','10',0,''),(175656,56135,'117895','furniture-mobile','font-size','11',0,''),(175657,56135,'117895','furniture-mobile','font-weight','bold',0,''),(175658,56135,'117895','furniture-mobile','text','Return Approval:',0,''),(175659,56135,'117895','furniture-mobile','padding-top','5',0,''),(175660,56135,'117895','furniture-mobile','padding-left','10',0,''),(175661,56136,'117896','furniture-mobile','border-bottom-width','1',0,''),(175662,56136,'117896','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175663,56136,'117896','furniture-mobile','text','&nbsp;',0,''),(175664,56137,'117897','furniture-mobile','block_type','5',0,''),(175665,56138,'117898','furniture-mobile','text','Date:',0,''),(175666,56138,'117898','furniture-mobile','padding-top','5',0,''),(175667,56138,'117898','furniture-mobile','font-size','11',0,''),(175668,56138,'117898','furniture-mobile','font-weight','bold',0,''),(175669,56138,'117898','furniture-mobile','padding-left','5',0,''),(175670,56139,'117899','furniture-mobile','text','&nbsp;',0,''),(175671,56139,'117899','furniture-mobile','border-bottom-width','1',0,''),(175672,56139,'117899','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175673,56140,'117900','furniture-mobile','block_type','3',0,''),(175674,56140,'117900','furniture-mobile','padding-right','10',0,''),(175675,56141,'117901','furniture-mobile','text','Customer Signature:',0,''),(175676,56141,'117901','furniture-mobile','font-weight','bold',0,''),(175677,56141,'117901','furniture-mobile','font-size','11',0,''),(175678,56141,'117901','furniture-mobile','padding-top','5',0,''),(175679,56141,'117901','furniture-mobile','padding-left','10',0,''),(175680,56142,'117902','furniture-mobile','text','&nbsp;',0,''),(175681,56142,'117902','furniture-mobile','border-bottom-width','1',0,''),(175682,56142,'117902','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175683,56143,'117903','furniture-mobile','block_type','5',0,''),(175684,56144,'117904','furniture-mobile','text','Date:',0,''),(175685,56144,'117904','furniture-mobile','padding-top','5',0,''),(175686,56144,'117904','furniture-mobile','font-size','11',0,''),(175687,56144,'117904','furniture-mobile','font-weight','bold',0,''),(175688,56144,'117904','furniture-mobile','padding-left','5',0,''),(175689,56145,'117905','furniture-mobile','text','&nbsp;',0,''),(175690,56145,'117905','furniture-mobile','border-bottom-width','1',0,''),(175691,56145,'117905','furniture-mobile','border-bottom-color','$border-color-5',0,''),(175692,56146,'117906','furniture-mobile','block_type','1',0,''),(175693,56146,'117906','furniture-mobile','style_class','item-holder',0,''),(175694,56146,'117906','furniture-mobile','padding-top','25',0,''),(175695,56146,'117906','furniture-mobile','padding-bottom','25',0,''),(175696,56146,'117906','furniture-mobile','text-align','left',0,''),(175697,56146,'117906','furniture-mobile','border-top-width','1',0,''),(175698,56146,'117906','furniture-mobile','border-top-color','$border-color-3',0,''),(175699,56147,'117907','furniture-mobile','block_type','7',0,''),(175700,56147,'117907','furniture-mobile','schema','7-2',0,'2885'),(175701,56148,'117908','furniture-mobile','block_type','5',0,''),(175702,56148,'117908','furniture-mobile','schema','5-2',0,'2885'),(175703,56149,'117909','furniture-mobile','clear','none',0,''),(175704,56149,'117909','furniture-mobile','padding-right','20',0,''),(175705,56150,'117910','furniture-mobile','padding-right','20',0,''),(175706,56150,'117910','furniture-mobile','max-width','300',0,'2885'),(175707,56150,'117910','furniture-mobile','margin_left_measure','auto',0,'2885'),(175708,56150,'117910','furniture-mobile','margin_right_measure','auto',0,'2885'),(175709,56151,'117914','furniture-mobile','padding-right','20',0,''),(175710,56152,'117915','furniture-mobile','description_characters','200',0,''),(175711,56152,'117915','furniture-mobile','clear','none',0,''),(175712,56152,'117915','furniture-mobile','padding-right','20',0,''),(175713,56153,'117916','furniture-mobile','clear','none',0,''),(175714,56154,'117917','furniture-mobile','margin-bottom','20',0,''),(175715,56157,'117918','furniture-mobile','block_type','1',0,''),(175716,56157,'117918','furniture-mobile','padding-left','40',0,''),(175717,56157,'117918','furniture-mobile','style_class','right-aria',0,''),(175718,56157,'117918','furniture-mobile','padding-left','0',0,'2885'),(175719,56158,'117911','furniture-mobile','block_type','1',0,''),(175720,56158,'117911','furniture-mobile','text-align','center',0,''),(175721,56159,'117912','furniture-mobile','margin-top','4',0,''),(175722,56159,'117912','furniture-mobile','margin-bottom','7',0,''),(175723,56160,'117913','furniture-mobile','padding-top','6',0,''),(175724,56160,'117913','furniture-mobile','padding-left','5',0,''),(175725,56161,'117919','furniture-mobile','margin-bottom','15',0,''),(175726,56161,'117919','furniture-mobile','text-align','right',0,''),(175727,56162,'117920','furniture-mobile','margin-bottom','10',0,''),(175728,56162,'117920','furniture-mobile','text-align','center',0,''),(175729,56163,'117922','furniture-mobile','text-align','right',0,''),(175730,56163,'117922','furniture-mobile','margin-bottom','15',0,''),(175731,56164,'117924','furniture-mobile','text-align','center',0,''),(175732,56164,'117924','furniture-mobile','margin-bottom','10',0,''),(175733,56165,'120924','furniture-mobile','block_type','1',0,''),(175734,56165,'120924','furniture-mobile','style_class','item-nav',0,''),(175735,56169,'117925','furniture-mobile','block_type','1',0,''),(175736,56169,'117925','furniture-mobile','padding-top','20',0,''),(175737,56169,'117925','furniture-mobile','padding-bottom','20',0,''),(175738,56169,'117925','furniture-mobile','background-color','$background-6',0,''),(175739,56171,'117927','furniture-mobile','block_type','7',0,''),(175740,56171,'117927','furniture-mobile','schema','4-2',0,'2885'),(175741,56172,'117928','furniture-mobile','padding-bottom','20',0,''),(175742,56172,'117928','furniture-mobile','background-color','$background-7',0,''),(175743,56173,'117929','furniture-mobile','style_class','order-summary',0,''),(175744,56173,'117929','furniture-mobile','padding-left','25',0,''),(175745,56173,'117929','furniture-mobile','block_type','1',0,''),(175746,56173,'117929','furniture-mobile','padding-left','0',0,'2885'),(175747,56173,'117929','furniture-mobile','margin-top','30',0,'2885'),(175748,56174,'117930','furniture-mobile','block_type','1',0,''),(175749,56174,'117930','furniture-mobile','padding-left','20',0,''),(175750,56174,'117930','furniture-mobile','padding-right','20',0,''),(175751,56174,'117930','furniture-mobile','padding-bottom','20',0,''),(175752,56174,'117930','furniture-mobile','padding-top','20',0,''),(175753,56175,'117931','furniture-mobile','max-width','300',0,'2885'),(175754,56175,'117931','furniture-mobile','margin_left_measure','auto',0,'2885'),(175755,56175,'117931','furniture-mobile','margin_right_measure','auto',0,'2885'),(175756,56176,'117932','furniture-mobile','block_type','1',0,''),(175757,56176,'117932','furniture-mobile','style_class','account-samples',0,''),(175758,56177,'117933','furniture-mobile','block_type','6',0,''),(175759,56177,'117933','furniture-mobile','schema','6-3',0,'2885'),(175760,56178,'117934','furniture-mobile','aria_name','account-menu',0,''),(175817,56198,'117935','furniture-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(175818,56199,'117936','furniture-mobile','show_pagenation','1',0,''),(175819,56199,'117936','furniture-mobile','link','Sample Info',0,''),(175820,56199,'117936','furniture-mobile','margin-bottom','20',0,''),(175821,56200,'117937','furniture-mobile','block_type','1',0,''),(175822,56200,'117937','furniture-mobile','style_class','account-sample-info',0,''),(175823,56201,'117938','furniture-mobile','block_type','6',0,''),(175824,56201,'117938','furniture-mobile','schema','6-3',0,'2885'),(175825,56202,'117939','furniture-mobile','aria_name','account-menu',0,''),(175882,56222,'117940','furniture-mobile','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(175883,56223,'117941','furniture-mobile','block_type','2',0,''),(175884,56223,'117941','furniture-mobile','padding-top','20',0,''),(175885,56223,'117941','furniture-mobile','margin-bottom','20',0,''),(175886,56224,'117942','furniture-mobile','like_button','1',0,''),(175887,56224,'117942','furniture-mobile','text','IMAGE_BUTTON_BACK',0,''),(175888,56224,'117942','furniture-mobile','link','Samples',0,''),(175889,56226,'117944','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(175890,56229,'117947','furniture-mobile','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(175891,56230,'117948','furniture-mobile','block_type','3',0,''),(175892,56231,'117949','furniture-mobile','block_type','1',0,''),(175893,56231,'117949','furniture-mobile','padding-right','20',0,''),(175894,56231,'117949','furniture-mobile','padding-bottom','20',0,''),(175895,56232,'117950','furniture-mobile','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(175896,56233,'117951','furniture-mobile','orders_data','telephone',0,''),(175897,56234,'117952','furniture-mobile','block_type','1',0,''),(175898,56234,'117952','furniture-mobile','padding-right','20',0,''),(175899,56234,'117952','furniture-mobile','padding-bottom','20',0,''),(175900,56235,'117953','furniture-mobile','orders_data','name',0,''),(175901,56236,'117954','furniture-mobile','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(175902,56237,'117955','furniture-mobile','block_type','1',0,''),(175903,56237,'117955','furniture-mobile','padding-right','20',0,''),(175904,56238,'117956','furniture-mobile','orders_data','shipping_method',0,''),(175905,56239,'117957','furniture-mobile','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(175906,56240,'117958','furniture-mobile','block_type','1',0,''),(175907,56240,'117958','furniture-mobile','padding-right','20',0,''),(175908,56240,'117958','furniture-mobile','padding-bottom','20',0,''),(175909,56241,'117959','furniture-mobile','orders_data','delivery_address',0,''),(175910,56242,'117960','furniture-mobile','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(175911,56243,'117961','furniture-mobile','block_type','1',0,''),(175912,56244,'117962','furniture-mobile','orders_data','payment_method',0,''),(175913,56245,'117963','furniture-mobile','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(175914,56246,'117964','furniture-mobile','block_type','1',0,''),(175915,56246,'117964','furniture-mobile','padding-bottom','20',0,''),(175916,56247,'117965','furniture-mobile','orders_data','billing_address',0,''),(175917,56248,'117966','furniture-mobile','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(175918,56249,'117967','furniture-mobile','block_type','1',0,''),(175919,56250,'117968','furniture-mobile','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(175920,56251,'117969','furniture-mobile','block_type','6',0,''),(175921,56252,'117970','furniture-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(175922,56253,'117971','furniture-mobile','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(175923,56254,'117972','furniture-mobile','text','<div class=\"heading-4\">Categories</div>',0,''),(175924,56257,'117975','furniture-mobile','class','menu-simple',0,''),(175925,56259,'117977','furniture-mobile','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(175926,56260,'120878','furniture-mobile','float','left',0,''),(175927,56260,'120878','furniture-mobile','margin-right','10',0,''),(175928,56261,'117978','furniture-mobile','block_type','1',0,''),(175929,56262,'117979','furniture-mobile','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(175930,56262,'117979','furniture-mobile','style_class','middle-form',0,''),(175931,56263,'117980','furniture-mobile','style_class','middle-form',0,''),(175932,56264,'117981','furniture-mobile','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(175933,56265,'117982','furniture-mobile','style_class','middle-form',0,''),(175934,56265,'117982','furniture-mobile','margin-bottom','30',0,''),(175935,56266,'117983','furniture-mobile','block_type','1',0,''),(175936,56267,'117984','furniture-mobile','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(175937,56267,'117984','furniture-mobile','padding-top','100',0,''),(175938,56267,'117984','furniture-mobile','margin-bottom','100',0,''),(175939,56267,'117984','furniture-mobile','text-align','center',0,''),(175940,56267,'117984','furniture-mobile','font-size','20',0,''),(175941,56268,'117985','furniture-mobile','block_type','1',0,''),(175942,56269,'117986','furniture-mobile','block_type','6',0,''),(175943,56269,'117986','furniture-mobile','schema','6-3',0,'2885'),(175944,56270,'117987','furniture-mobile','aria_name','account-menu',0,''),(176001,56290,'117988','furniture-mobile','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(176002,56291,'117989','furniture-mobile','text','##SUBSCRIPTION_TEXT##',0,''),(176003,56293,'117991','furniture-mobile','block_type','1',0,''),(176004,56293,'117991','furniture-mobile','style_class','checkout-success-wrap',0,''),(176005,56294,'117992','furniture-mobile','block_type','1',0,''),(176006,56294,'117992','furniture-mobile','font-weight','normal',0,''),(176007,56295,'117993','furniture-mobile','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>\n',0,''),(176008,56296,'117994','furniture-mobile','block_type','1',0,''),(176009,56296,'117994','furniture-mobile','text-align','center',0,''),(176010,56296,'117994','furniture-mobile','padding-top','30',0,''),(176011,56296,'117994','furniture-mobile','margin-bottom','200',0,''),(176012,56297,'117995','furniture-mobile','display','inline-block',0,''),(176013,56298,'117996','furniture-mobile','display','inline-block',0,''),(176014,56298,'117996','furniture-mobile','clear','none',0,''),(176015,56298,'117996','furniture-mobile','margin-left','20',0,''),(176016,56299,'1639413072.5477','furniture-mobile','box_align','4',0,''),(176017,56299,'1639413072.5477','furniture-mobile','margin-top','15',0,''),(176018,56300,'117997','furniture-mobile','block_type','1',0,''),(176019,56301,'117998','furniture-mobile','block_type','1',0,''),(176020,56301,'117998','furniture-mobile','font-weight','normal',0,''),(176021,56302,'117999','furniture-mobile','block_type','1',0,''),(176022,56302,'117999','furniture-mobile','text-align','center',0,''),(176023,56302,'117999','furniture-mobile','padding-top','30',0,''),(176024,56302,'117999','furniture-mobile','margin-bottom','200',0,''),(176025,56303,'118000','furniture-mobile','display','inline-block',0,''),(176026,56303,'118000','furniture-mobile','clear','none',0,''),(176027,56303,'118000','furniture-mobile','margin-left','20',0,''),(176028,56304,'118001','furniture-mobile','display','inline-block',0,''),(176029,56305,'118002','furniture-mobile','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(176034,56310,'118007','furniture-mobile','width','680',0,''),(176035,56310,'118007','furniture-mobile','font-weight','normal',0,''),(176036,56310,'118007','furniture-mobile','font-size','12',0,''),(176037,56310,'118007','furniture-mobile','padding-top','20',0,''),(176038,56310,'118007','furniture-mobile','padding-bottom','20',0,''),(176039,56310,'118007','furniture-mobile','color','$color-font-8',0,''),(176040,56311,'118008','furniture-mobile','block_type','5',0,''),(176041,56311,'118008','furniture-mobile','font-weight','normal',0,''),(176042,56311,'118008','furniture-mobile','border-bottom-width','1',0,''),(176043,56311,'118008','furniture-mobile','border-bottom-color','$border-color-4',0,''),(176044,56311,'118008','furniture-mobile','border-top-width','1',0,''),(176045,56311,'118008','furniture-mobile','border-top-color','$border-color-4',0,''),(176046,56311,'118008','furniture-mobile','border-left-color','$border-color-4',0,''),(176047,56311,'118008','furniture-mobile','border-left-width','1',0,''),(176048,56312,'118009','furniture-mobile','block_type','1',0,''),(176049,56312,'118009','furniture-mobile','font-weight','normal',0,''),(176050,56312,'118009','furniture-mobile','padding-top','10',0,''),(176051,56312,'118009','furniture-mobile','padding-left','10',0,''),(176052,56312,'118009','furniture-mobile','padding-right','10',0,''),(176053,56313,'118010','furniture-mobile','font-weight','400',0,''),(176054,56313,'118010','furniture-mobile','line-height','120',0,''),(176055,56313,'118010','furniture-mobile','line_height_measure','%',0,''),(176056,56313,'118010','furniture-mobile','font-size','12',0,''),(176057,56314,'118011','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',1,''),(176058,56314,'118011','furniture-mobile','font-size','14',0,''),(176059,56314,'118011','furniture-mobile','font-weight','bold',0,''),(176060,56314,'118011','furniture-mobile','padding-bottom','10',0,''),(176061,56315,'118012','furniture-mobile','block_type','1',0,''),(176062,56315,'118012','furniture-mobile','background-color','$background-6',0,''),(176063,56315,'118012','furniture-mobile','padding-top','20',0,''),(176064,56315,'118012','furniture-mobile','padding-left','10',0,''),(176065,56315,'118012','furniture-mobile','padding-right','10',0,''),(176066,56315,'118012','furniture-mobile','padding-bottom','20',0,''),(176067,56315,'118012','furniture-mobile','font-size','14',0,''),(176068,56316,'118013','furniture-mobile','font-weight','normal',0,''),(176069,56316,'118013','furniture-mobile','text-align','right',0,''),(176070,56316,'118013','furniture-mobile','font-size','14',0,''),(176071,56316,'118013','furniture-mobile','box_align','3',0,''),(176072,56317,'118014','furniture-mobile','block_type','3',0,''),(176073,56317,'118014','furniture-mobile','font-weight','normal',0,''),(176074,56317,'118014','furniture-mobile','padding-top','20',0,''),(176075,56318,'118015','furniture-mobile','text','<p>If undelivered please return to:</p>',1,''),(176076,56318,'118015','furniture-mobile','font-size','12',0,''),(176077,56318,'118015','furniture-mobile','font-weight','bold',0,''),(176078,56319,'118016','furniture-mobile','font-size','12',0,''),(176079,56320,'118018','furniture-mobile','text','<p>Thank you for your order</p>',1,''),(176080,56320,'118018','furniture-mobile','color','$color-font-10',0,''),(176081,56320,'118018','furniture-mobile','font-size','13',0,''),(176082,56320,'118018','furniture-mobile','font-weight','bold',0,''),(176083,56320,'118018','furniture-mobile','padding-top','5',0,''),(176084,56320,'118018','furniture-mobile','text-align','center',0,''),(176085,56321,'118019','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',1,''),(176086,56321,'118019','furniture-mobile','font-size','12',0,''),(176087,56321,'118019','furniture-mobile','font-weight','bold',0,''),(176088,56321,'118019','furniture-mobile','text-align','right',0,''),(176089,56322,'118020','furniture-mobile','block_type','6',0,''),(176090,56322,'118020','furniture-mobile','font-weight','normal',0,''),(176091,56322,'118020','furniture-mobile','font-size','16',0,''),(176092,56323,'118021','furniture-mobile','text','<p>Email:</p>',1,''),(176093,56323,'118021','furniture-mobile','font-weight','normal',0,''),(176094,56323,'118021','furniture-mobile','text-align','right',0,''),(176095,56323,'118021','furniture-mobile','font-size','12',0,''),(176096,56324,'118022','furniture-mobile','font-weight','normal',0,''),(176097,56324,'118022','furniture-mobile','text-align','right',0,''),(176098,56324,'118022','furniture-mobile','font-size','12',0,''),(176099,56325,'118023','furniture-mobile','block_type','6',0,''),(176100,56325,'118023','furniture-mobile','font-weight','normal',0,''),(176101,56325,'118023','furniture-mobile','font-size','16',0,''),(176102,56326,'118024','furniture-mobile','text','<p>Phone:</p>',1,''),(176103,56326,'118024','furniture-mobile','font-weight','normal',0,''),(176104,56326,'118024','furniture-mobile','text-align','right',0,''),(176105,56326,'118024','furniture-mobile','font-size','12',0,''),(176106,56327,'118025','furniture-mobile','font-weight','normal',0,''),(176107,56327,'118025','furniture-mobile','text-align','right',0,''),(176108,56327,'118025','furniture-mobile','font-size','12',0,''),(176109,56328,'118026','furniture-mobile','font-weight','400',0,''),(176110,56328,'118026','furniture-mobile','padding-top','20',0,''),(176111,56328,'118026','furniture-mobile','padding-bottom','0',0,''),(176112,56328,'118026','furniture-mobile','font-size','12',0,''),(176113,56329,'118027','furniture-mobile','block_type','2',0,''),(176114,56329,'118027','furniture-mobile','font-weight','normal',0,''),(176115,56329,'118027','furniture-mobile','padding-bottom','20',0,''),(176116,56330,'118028','furniture-mobile','block_type','11',0,''),(176117,56330,'118028','furniture-mobile','font-weight','normal',0,''),(176118,56331,'118029','furniture-mobile','text','<p>Email:</p>',1,''),(176119,56331,'118029','furniture-mobile','font-weight','normal',0,''),(176120,56331,'118029','furniture-mobile','text-align','right',0,''),(176121,56332,'118030','furniture-mobile','font-weight','normal',0,''),(176122,56332,'118030','furniture-mobile','text-align','right',0,''),(176123,56333,'118031','furniture-mobile','block_type','11',0,''),(176124,56333,'118031','furniture-mobile','font-weight','normal',0,''),(176125,56334,'118032','furniture-mobile','text','<p>Web:</p>',1,''),(176126,56334,'118032','furniture-mobile','font-weight','normal',0,''),(176127,56334,'118032','furniture-mobile','text-align','right',0,''),(176128,56335,'118033','furniture-mobile','font-weight','normal',0,''),(176129,56335,'118033','furniture-mobile','text-align','right',0,''),(176130,56336,'118034','furniture-mobile','block_type','1',0,''),(176131,56337,'118035','furniture-mobile','font-weight','normal',0,''),(176132,56337,'118035','furniture-mobile','text-align','right',0,''),(176133,56337,'118035','furniture-mobile','padding-bottom','10',0,''),(176134,56337,'118035','furniture-mobile','address_spacer',',',0,''),(176135,56337,'118035','furniture-mobile','font-size','12',0,''),(176136,56338,'118036','furniture-mobile','block_type','11',0,''),(176137,56338,'118036','furniture-mobile','font-weight','normal',0,''),(176138,56339,'118037','furniture-mobile','text','<p>Phone:</p>',1,''),(176139,56339,'118037','furniture-mobile','font-weight','normal',0,''),(176140,56339,'118037','furniture-mobile','text-align','right',0,''),(176141,56340,'118038','furniture-mobile','font-weight','normal',0,''),(176142,56340,'118038','furniture-mobile','text-align','right',0,''),(176143,56341,'118039','furniture-mobile','block_type','4',0,''),(176144,56341,'118039','furniture-mobile','font-weight','normal',0,''),(176145,56341,'118039','furniture-mobile','border-top-width','1',0,''),(176146,56341,'118039','furniture-mobile','border-top-color','$border-color-4',0,''),(176147,56341,'118039','furniture-mobile','border-left-width','1',0,''),(176148,56341,'118039','furniture-mobile','border-left-color','$border-color-4',0,''),(176149,56341,'118039','furniture-mobile','border-right-width','1',0,''),(176150,56341,'118039','furniture-mobile','border-right-color','$border-color-4',0,''),(176151,56341,'118039','furniture-mobile','border-bottom-width','1',0,''),(176152,56341,'118039','furniture-mobile','border-bottom-color','$border-color-4',0,''),(176153,56342,'118040','furniture-mobile','block_type','2',0,''),(176154,56342,'118040','furniture-mobile','font-weight','normal',0,''),(176155,56342,'118040','furniture-mobile','border-top-width','1',0,''),(176156,56342,'118040','furniture-mobile','border-top-color','$border-color-4',0,''),(176157,56342,'118040','furniture-mobile','border-right-width','1',0,''),(176158,56342,'118040','furniture-mobile','border-right-color','$border-color-4',0,''),(176159,56343,'118041','furniture-mobile','block_type','1',0,''),(176160,56343,'118041','furniture-mobile','font-weight','normal',0,''),(176161,56343,'118041','furniture-mobile','padding-top','10',0,''),(176162,56343,'118041','furniture-mobile','padding-left','10',0,''),(176163,56343,'118041','furniture-mobile','padding-right','10',0,''),(176164,56343,'118041','furniture-mobile','padding-bottom','10',0,''),(176165,56343,'118041','furniture-mobile','border-right-width','1',0,''),(176166,56343,'118041','furniture-mobile','border-right-color','$border-color-4',0,''),(176167,56344,'118042','furniture-mobile','text','<p>Shipping via</p>',1,''),(176168,56344,'118042','furniture-mobile','font-weight','bold',0,''),(176169,56344,'118042','furniture-mobile','font-size','14',0,''),(176170,56346,'118044','furniture-mobile','block_type','1',0,''),(176171,56346,'118044','furniture-mobile','font-weight','normal',0,''),(176172,56346,'118044','furniture-mobile','padding-top','10',0,''),(176173,56346,'118044','furniture-mobile','padding-left','10',0,''),(176174,56346,'118044','furniture-mobile','padding-right','10',0,''),(176175,56346,'118044','furniture-mobile','padding-bottom','10',0,''),(176176,56347,'118045','furniture-mobile','text','<p>Shipping service</p>',1,''),(176177,56347,'118045','furniture-mobile','font-weight','bold',0,''),(176178,56347,'118045','furniture-mobile','font-size','14',0,''),(176179,56349,'118047','furniture-mobile','block_type','2',0,''),(176180,56349,'118047','furniture-mobile','font-weight','normal',0,''),(176181,56349,'118047','furniture-mobile','border-right-width','1',0,''),(176182,56349,'118047','furniture-mobile','border-right-color','$border-color-4',0,''),(176183,56350,'118048','furniture-mobile','block_type','1',0,''),(176184,56350,'118048','furniture-mobile','font-weight','400',0,''),(176185,56350,'118048','furniture-mobile','background-color','$background-6',0,''),(176186,56350,'118048','furniture-mobile','padding-top','10',0,''),(176187,56350,'118048','furniture-mobile','padding-left','10',0,''),(176188,56350,'118048','furniture-mobile','padding-right','10',0,''),(176189,56350,'118048','furniture-mobile','padding-bottom','30',0,''),(176190,56351,'118049','furniture-mobile','font-size','12',0,''),(176191,56352,'118050','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',1,''),(176192,56352,'118050','furniture-mobile','font-size','14',0,''),(176193,56352,'118050','furniture-mobile','font-weight','bold',0,''),(176194,56353,'118051','furniture-mobile','block_type','1',0,''),(176195,56353,'118051','furniture-mobile','font-weight','normal',0,''),(176196,56353,'118051','furniture-mobile','padding-top','10',0,''),(176197,56353,'118051','furniture-mobile','padding-left','10',0,''),(176198,56353,'118051','furniture-mobile','padding-right','10',0,''),(176199,56353,'118051','furniture-mobile','padding-bottom','10',0,''),(176200,56354,'118052','furniture-mobile','font-weight','normal',0,''),(176201,56355,'118053','furniture-mobile','text','<p>PHONE NUMBER:</p>',1,''),(176202,56355,'118053','furniture-mobile','font-size','14',0,''),(176203,56355,'118053','furniture-mobile','font-weight','bold',0,''),(176204,56355,'118053','furniture-mobile','padding-top','10',0,''),(176205,56357,'118055','furniture-mobile','font-weight','normal',0,''),(176206,56358,'118056','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',1,''),(176207,56358,'118056','furniture-mobile','font-weight','bold',0,''),(176208,56358,'118056','furniture-mobile','font-size','14',0,''),(176209,56358,'118056','furniture-mobile','padding-top','10',0,''),(176210,56359,'118057','furniture-mobile','text','<p>CUSTOMER:</p>',1,''),(176211,56359,'118057','furniture-mobile','font-size','13',0,''),(176212,56359,'118057','furniture-mobile','font-weight','bold',0,''),(176213,56360,'118058','furniture-mobile','font-weight','normal',0,''),(176214,56360,'118058','furniture-mobile','text-align','center',0,''),(176215,56360,'118058','furniture-mobile','padding-bottom','10',0,''),(176216,56361,'118059','furniture-mobile','text','<p>Payment date:</p>',1,''),(176217,56361,'118059','furniture-mobile','font-weight','bold',0,''),(176218,56361,'118059','furniture-mobile','text-align','center',0,''),(176219,56361,'118059','furniture-mobile','font-size','12',0,''),(176220,56362,'118060','furniture-mobile','text','<p>Payment Method:</p>',1,''),(176221,56362,'118060','furniture-mobile','font-weight','bold',0,''),(176222,56362,'118060','furniture-mobile','text-align','center',0,''),(176223,56363,'118061','furniture-mobile','font-size','14',0,''),(176224,56363,'118061','furniture-mobile','font-weight','bold',0,''),(176225,56363,'118061','furniture-mobile','text-align','center',0,''),(176226,56363,'118061','furniture-mobile','padding-bottom','10',0,''),(176227,56363,'118061','furniture-mobile','padding-top','10',0,''),(176228,56364,'118062','furniture-mobile','font-weight','normal',0,''),(176229,56364,'118062','furniture-mobile','text-align','center',0,''),(176230,56364,'118062','furniture-mobile','padding-bottom','20',0,''),(176231,56365,'118063','furniture-mobile','font-weight','normal',0,''),(176232,56365,'118063','furniture-mobile','text-align','center',0,''),(176233,56366,'118064','furniture-mobile','block_type','1',0,''),(176234,56366,'118064','furniture-mobile','padding-top','35',0,''),(176235,56366,'118064','furniture-mobile','padding-bottom','35',0,''),(176236,56367,'118065','furniture-mobile','block_type','7',0,''),(176237,56367,'118065','furniture-mobile','schema','7-2',0,'2885'),(176238,56368,'118066','furniture-mobile','block_type','1',0,''),(176239,56368,'118066','furniture-mobile','style_class','blog_list_content',0,''),(176240,56370,'118068','furniture-mobile','text-align','center',0,''),(176241,56371,'118069','furniture-mobile','aria_name','blogsidebar',0,''),(176242,56371,'118069','furniture-mobile','style_class','blogsidebar',0,''),(176244,56376,'118070','furniture-mobile','block_type','1',0,''),(176245,56376,'118070','furniture-mobile','padding-top','35',0,''),(176246,56376,'118070','furniture-mobile','padding-bottom','35',0,''),(176247,56377,'118071','furniture-mobile','banners_group','blog',0,''),(176248,56377,'118071','furniture-mobile','margin-bottom','40',0,''),(176249,56378,'118072','furniture-mobile','block_type','7',0,''),(176250,56378,'118072','furniture-mobile','schema','7-1',0,'2885'),(176251,56379,'118073','furniture-mobile','block_type','1',0,''),(176252,56379,'118073','furniture-mobile','style_class','blog_list_content',0,''),(176253,56380,'118074','furniture-mobile','text-align','center',0,''),(176254,56380,'118074','furniture-mobile','hide_parents','1',0,''),(176255,56381,'118075','furniture-mobile','items_on_page','12',0,''),(176256,56381,'118075','furniture-mobile','items_cut_off','200',0,''),(176257,56382,'118076','furniture-mobile','aria_name','blogsidebar',0,''),(176258,56382,'118076','furniture-mobile','padding-left','35',0,''),(176259,56382,'118076','furniture-mobile','style_class','blogsidebar',0,''),(176260,56382,'118076','furniture-mobile','padding-left','15',0,'2890'),(176262,56387,'118077','furniture-mobile','block_type','1',0,''),(176263,56387,'118077','furniture-mobile','padding-top','35',0,''),(176264,56387,'118077','furniture-mobile','padding-bottom','35',0,''),(176265,56388,'118078','furniture-mobile','block_type','7',0,''),(176266,56388,'118078','furniture-mobile','schema','7-2',0,'2885'),(176267,56389,'118079','furniture-mobile','count_products','8',0,''),(176268,56389,'118079','furniture-mobile','col_in_row','4',0,''),(176269,56389,'118079','furniture-mobile','view_as','carousel',0,''),(176270,56389,'118079','furniture-mobile','show_stock','1',0,''),(176271,56389,'118079','furniture-mobile','show_description','1',0,''),(176272,56389,'118079','furniture-mobile','show_properties','1',0,''),(176273,56389,'118079','furniture-mobile','show_rating','1',0,''),(176274,56389,'118079','furniture-mobile','show_rating_counts','1',0,''),(176275,56389,'118079','furniture-mobile','show_qty_input','1',0,''),(176276,56389,'118079','furniture-mobile','show_wishlist_button','1',0,''),(176277,56389,'118079','furniture-mobile','show_compare','1',0,''),(176278,56389,'118079','furniture-mobile','col_in_row','3',0,'2890'),(176279,56389,'118079','furniture-mobile','col_in_row','2',0,'2885'),(176280,56389,'118079','furniture-mobile','col_in_row','1',0,'2906'),(176281,56389,'118079','furniture-mobile','listing_type','productListing',0,''),(176282,56390,'118080','furniture-mobile','block_type','1',0,''),(176283,56390,'118080','furniture-mobile','style_class','blog-white-bg',0,''),(176284,56390,'118080','furniture-mobile','padding-bottom','20',0,''),(176285,56392,'118082','furniture-mobile','text-align','center',0,''),(176286,56395,'118085','furniture-mobile','block_type','1',0,''),(176287,56395,'118085','furniture-mobile','padding-top','20',0,''),(176288,56395,'118085','furniture-mobile','margin-top','20',0,''),(176289,56395,'118085','furniture-mobile','border-top-width','1',0,''),(176290,56395,'118085','furniture-mobile','border-top-color','$border-color-4',0,''),(176291,56395,'118085','furniture-mobile','clear','both',0,''),(176292,56396,'118086','furniture-mobile','box_align','4',0,''),(176293,56396,'118086','furniture-mobile','text-align','center',0,''),(176294,56397,'118087','furniture-mobile','aria_name','blogsidebar',0,''),(176295,56397,'118087','furniture-mobile','style_class','blogsidebar',0,''),(176297,56402,'118088','furniture-mobile','block_type','1',0,''),(176298,56402,'118088','furniture-mobile','padding-top','35',0,''),(176299,56402,'118088','furniture-mobile','padding-bottom','35',0,''),(176300,56403,'118089','furniture-mobile','block_type','7',0,''),(176301,56403,'118089','furniture-mobile','schema','7-2',0,'2885'),(176302,56404,'118090','furniture-mobile','block_type','1',0,''),(176303,56404,'118090','furniture-mobile','style_class','blog_list_content',0,''),(176304,56406,'118092','furniture-mobile','text-align','center',0,''),(176305,56406,'118092','furniture-mobile','hide_parents','1',0,''),(176306,56407,'118093','furniture-mobile','aria_name','blogsidebar',0,''),(176307,56407,'118093','furniture-mobile','style_class','blogsidebar',0,''),(176308,56408,'116208','furniture-mobile','block_type','1',0,''),(176309,56412,'118094','furniture-mobile','block_type','1',0,''),(176310,56413,'118095','furniture-mobile','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(176311,56415,'118097','furniture-mobile','block_type','1',0,''),(176312,56416,'118098','furniture-mobile','text','<div class=\"heading-2\">##DISCOUNT##</div>',0,''),(176313,56416,'118098','furniture-mobile','text-align','center',0,''),(176314,56417,'118099','furniture-mobile','block_type','2',0,''),(176315,56417,'118099','furniture-mobile','margin-bottom','20',0,''),(176316,56418,'118100','furniture-mobile','block_type','1',0,''),(176317,56418,'118100','furniture-mobile','padding-right','20',0,''),(176318,56419,'118101','furniture-mobile','field','57',0,''),(176319,56420,'118102','furniture-mobile','field','56',0,''),(176320,56421,'118103','furniture-mobile','block_type','1',0,''),(176321,56421,'118103','furniture-mobile','padding-left','20',0,''),(176322,56422,'118104','furniture-mobile','field','59',0,''),(176323,56423,'118105','furniture-mobile','field','58',0,''),(176324,56424,'118106','furniture-mobile','block_type','2',0,''),(176325,56424,'118106','furniture-mobile','margin-bottom','20',0,''),(176326,56425,'118107','furniture-mobile','block_type','1',0,''),(176327,56425,'118107','furniture-mobile','padding-right','20',0,''),(176328,56426,'118108','furniture-mobile','field','51',0,''),(176329,56427,'118109','furniture-mobile','field','52',0,''),(176330,56428,'118110','furniture-mobile','text','<div class=\"heading-2\">##TEXT_CUSTOMER_DETAILS##</div>',0,''),(176331,56428,'118110','furniture-mobile','text-align','center',0,''),(176332,56429,'118111','furniture-mobile','block_type','2',0,''),(176333,56430,'118112','furniture-mobile','block_type','1',0,''),(176334,56430,'118112','furniture-mobile','padding-right','20',0,''),(176335,56431,'118113','furniture-mobile','group','15',0,''),(176336,56432,'118114','furniture-mobile','block_type','2',0,''),(176337,56432,'118114','furniture-mobile','border-bottom-width','1',0,''),(176338,56432,'118114','furniture-mobile','border-bottom-color','$border-color-4',0,''),(176339,56432,'118114','furniture-mobile','padding-bottom','10',0,''),(176340,56432,'118114','furniture-mobile','margin-bottom','20',0,''),(176341,56433,'118115','furniture-mobile','block_type','1',0,''),(176342,56433,'118115','furniture-mobile','padding-right','10',0,''),(176343,56434,'118116','furniture-mobile','field','73',0,''),(176344,56435,'118117','furniture-mobile','field','69',0,''),(176345,56436,'118118','furniture-mobile','field','71',0,''),(176346,56437,'118119','furniture-mobile','field','75',0,''),(176347,56438,'118120','furniture-mobile','block_type','1',0,''),(176348,56438,'118120','furniture-mobile','padding-left','10',0,''),(176349,56439,'118121','furniture-mobile','field','76',0,''),(176350,56440,'118122','furniture-mobile','field','70',0,''),(176351,56441,'118123','furniture-mobile','field','72',0,''),(176352,56442,'118124','furniture-mobile','field','74',0,''),(176353,56443,'118125','furniture-mobile','block_type','2',0,''),(176354,56444,'118126','furniture-mobile','field','68',0,''),(176355,56444,'118126','furniture-mobile','padding-right','10',0,''),(176356,56445,'118127','furniture-mobile','text','<div class=\"heading-3\">##CATEGORY_COMPANY##</div>',0,''),(176357,56446,'118128','furniture-mobile','block_type','1',0,''),(176358,56446,'118128','furniture-mobile','padding-left','20',0,''),(176359,56447,'118129','furniture-mobile','group','16',0,''),(176360,56448,'118130','furniture-mobile','text','<div class=\"heading-3\">##OWNERS_DETAILS##</div>',0,''),(176361,56449,'118131','furniture-mobile','block_type','2',0,''),(176362,56450,'118132','furniture-mobile','block_type','1',0,''),(176363,56450,'118132','furniture-mobile','padding-right','10',0,''),(176364,56451,'118133','furniture-mobile','field','84',0,''),(176365,56452,'118134','furniture-mobile','field','80',0,''),(176366,56453,'118135','furniture-mobile','field','82',0,''),(176367,56454,'118136','furniture-mobile','block_type','1',0,''),(176368,56454,'118136','furniture-mobile','padding-left','10',0,''),(176369,56455,'118137','furniture-mobile','field','81',0,''),(176370,56456,'118138','furniture-mobile','field','85',0,''),(176371,56457,'118139','furniture-mobile','field','83',0,''),(176372,56458,'118140','furniture-mobile','block_type','2',0,''),(176373,56459,'118141','furniture-mobile','block_type','1',0,''),(176374,56459,'118141','furniture-mobile','padding-right','10',0,''),(176375,56460,'118142','furniture-mobile','field','79',0,''),(176376,56461,'118143','furniture-mobile','field','77',0,''),(176377,56462,'118144','furniture-mobile','block_type','1',0,''),(176378,56462,'118144','furniture-mobile','padding-left','10',0,''),(176379,56463,'118145','furniture-mobile','field','78',0,''),(176380,56464,'118146','furniture-mobile','text','<h1>##TRADE_FORM##</h1>',0,''),(176381,56465,'118147','furniture-mobile','block_type','2',0,''),(176382,56465,'118147','furniture-mobile','margin-bottom','20',0,''),(176383,56466,'118148','furniture-mobile','block_type','1',0,''),(176384,56466,'118148','furniture-mobile','padding-right','20',0,''),(176385,56467,'118149','furniture-mobile','field','54',0,''),(176386,56468,'118150','furniture-mobile','field','53',0,''),(176387,56469,'118151','furniture-mobile','block_type','1',0,''),(176388,56469,'118151','furniture-mobile','padding-left','20',0,''),(176389,56470,'118152','furniture-mobile','field','55',0,''),(176390,56471,'118153','furniture-mobile','text','<div class=\"heading-2\">##TRADE_REFERENCES##</div>',0,''),(176391,56471,'118153','furniture-mobile','text-align','center',0,''),(176392,56472,'118154','furniture-mobile','text','<div class=\"heading-2\">##BANK_ACCOUNT_DETAILS##</div>',0,''),(176393,56472,'118154','furniture-mobile','text-align','center',0,''),(176394,56473,'118155','furniture-mobile','block_type','2',0,''),(176395,56473,'118155','furniture-mobile','margin-bottom','20',0,''),(176396,56474,'118156','furniture-mobile','block_type','1',0,''),(176397,56474,'118156','furniture-mobile','padding-right','20',0,''),(176398,56475,'118157','furniture-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 1</div>',0,''),(176399,56476,'118158','furniture-mobile','field','60',0,''),(176400,56477,'118159','furniture-mobile','field','62',0,''),(176401,56478,'118160','furniture-mobile','field','61',0,''),(176402,56479,'118161','furniture-mobile','block_type','1',0,''),(176403,56479,'118161','furniture-mobile','padding-left','20',0,''),(176404,56480,'118162','furniture-mobile','text','<div class=\"heading-3\">##TRADE_REFERENCES## 2</div>',0,''),(176405,56481,'118163','furniture-mobile','field','63',0,''),(176406,56482,'118164','furniture-mobile','field','64',0,''),(176407,56483,'118165','furniture-mobile','field','65',0,''),(176408,56484,'118166','furniture-mobile','text','<div class=\"heading-2\">##TEXT_DECLARATION##</div>',0,''),(176409,56484,'118166','furniture-mobile','text-align','center',0,''),(176410,56485,'118167','furniture-mobile','block_type','2',0,''),(176411,56485,'118167','furniture-mobile','margin-bottom','20',0,''),(176412,56486,'118168','furniture-mobile','block_type','1',0,''),(176413,56486,'118168','furniture-mobile','padding-right','20',0,''),(176414,56487,'118169','furniture-mobile','field','66',0,''),(176415,56488,'118170','furniture-mobile','block_type','1',0,''),(176416,56488,'118170','furniture-mobile','padding-left','20',0,''),(176417,56489,'118171','furniture-mobile','field','67',0,''),(176418,56490,'118172','furniture-mobile','block_type','2',0,''),(176419,56490,'118172','furniture-mobile','margin-bottom','20',0,''),(176420,56492,'118174','furniture-mobile','float','right',0,''),(176421,56492,'118174','furniture-mobile','margin-left','20',0,''),(176422,56493,'118175','furniture-mobile','float','right',0,''),(176423,56493,'118175','furniture-mobile','clear','none',0,''),(176424,56494,'118176','furniture-mobile','block_type','2',0,''),(176425,56494,'118176','furniture-mobile','margin-bottom','20',0,''),(176426,56495,'118177','furniture-mobile','block_type','1',0,''),(176427,56495,'118177','furniture-mobile','padding-right','20',0,''),(176428,56496,'118178','furniture-mobile','field','50',0,''),(176429,56497,'118179','furniture-mobile','field','49',0,''),(176430,56498,'118180','furniture-mobile','block_type','1',0,''),(176431,56499,'118181','furniture-mobile','block_type','1',0,''),(176432,56500,'118182','furniture-mobile','text','Scottish books of exceptional value',0,''),(176433,56500,'118182','furniture-mobile','font-size','20',0,''),(176434,56500,'118182','furniture-mobile','text-align','center',0,''),(176435,56500,'118182','furniture-mobile','padding-top','20',0,''),(176436,56501,'118183','furniture-mobile','block_type','14',0,''),(176437,56502,'118184','furniture-mobile','text','Name in Full',0,''),(176438,56502,'118184','furniture-mobile','text-align','right',0,''),(176439,56503,'118185','furniture-mobile','field','66',0,''),(176440,56503,'118185','furniture-mobile','padding-left','10',0,''),(176441,56503,'118185','furniture-mobile','border-bottom-width','1',0,''),(176442,56503,'118185','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176443,56504,'118186','furniture-mobile','text','Position',0,''),(176444,56504,'118186','furniture-mobile','text-align','right',0,''),(176445,56505,'118187','furniture-mobile','field','67',0,''),(176446,56505,'118187','furniture-mobile','border-bottom-width','1',0,''),(176447,56505,'118187','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176448,56505,'118187','furniture-mobile','padding-left','10',0,''),(176449,56506,'118188','furniture-mobile','block_type','14',0,''),(176450,56507,'118189','furniture-mobile','text','Signed',0,''),(176451,56507,'118189','furniture-mobile','text-align','right',0,''),(176452,56508,'118190','furniture-mobile','text','&nbsp;',0,''),(176453,56508,'118190','furniture-mobile','border-bottom-width','1',0,''),(176454,56508,'118190','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176455,56509,'118191','furniture-mobile','text','Date',0,''),(176456,56509,'118191','furniture-mobile','text-align','right',0,''),(176457,56510,'118192','furniture-mobile','text','&nbsp;',0,''),(176458,56510,'118192','furniture-mobile','border-bottom-width','1',0,''),(176459,56510,'118192','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176460,56511,'118193','furniture-mobile','block_type','6',0,''),(176461,56512,'118194','furniture-mobile','text','Name',0,''),(176462,56512,'118194','furniture-mobile','text-align','right',0,''),(176463,56512,'118194','furniture-mobile','font-size','16',0,''),(176464,56513,'118195','furniture-mobile','field','60',0,''),(176465,56513,'118195','furniture-mobile','border-bottom-width','1',0,''),(176466,56513,'118195','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176467,56513,'118195','furniture-mobile','padding-left','10',0,''),(176468,56514,'118196','furniture-mobile','block_type','1',0,''),(176469,56515,'118197','furniture-mobile','text','I would like to open a trade account with Vladislav B. Malyshev and agree to abide by their General Terms & Conditions –\na signed copy of which is returned to them with this form in the supplied SAE. I have retained a copy for my reference. I\nam authorised to sign on behalf of the company I represent.',0,''),(176470,56515,'118197','furniture-mobile','font-size','15',0,''),(176471,56515,'118197','furniture-mobile','padding-left','10',0,''),(176472,56515,'118197','furniture-mobile','padding-right','10',0,''),(176473,56516,'118198','furniture-mobile','block_type','6',0,''),(176474,56516,'118198','furniture-mobile','padding-bottom','20',0,''),(176475,56517,'118199','furniture-mobile','text','Telephone No.',0,''),(176476,56517,'118199','furniture-mobile','text-align','right',0,''),(176477,56518,'118200','furniture-mobile','field','62',0,''),(176478,56518,'118200','furniture-mobile','border-bottom-width','1',0,''),(176479,56518,'118200','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176480,56518,'118200','furniture-mobile','padding-left','10',0,''),(176481,56519,'118201','furniture-mobile','block_type','1',0,''),(176482,56519,'118201','furniture-mobile','padding-bottom','10',0,''),(176483,56520,'118202','furniture-mobile','background-color','$background-1',0,''),(176484,56520,'118202','furniture-mobile','color','$color-font-1',0,''),(176485,56520,'118202','furniture-mobile','font-size','20',0,''),(176486,56520,'118202','furniture-mobile','text','Customer Details',0,''),(176487,56520,'118202','furniture-mobile','padding-left','10',0,''),(176488,56520,'118202','furniture-mobile','padding-right','10',0,''),(176489,56521,'118203','furniture-mobile','block_type','1',0,''),(176490,56521,'118203','furniture-mobile','padding-bottom','10',0,''),(176491,56522,'118204','furniture-mobile','background-color','$background-1',0,''),(176492,56522,'118204','furniture-mobile','color','$color-font-1',0,''),(176493,56522,'118204','furniture-mobile','font-size','20',0,''),(176494,56522,'118204','furniture-mobile','text','Trade References',0,''),(176495,56522,'118204','furniture-mobile','padding-left','10',0,''),(176496,56522,'118204','furniture-mobile','padding-right','10',0,''),(176497,56523,'118205','furniture-mobile','block_type','6',0,''),(176498,56524,'118206','furniture-mobile','text','Address',0,''),(176499,56524,'118206','furniture-mobile','text-align','right',0,''),(176500,56525,'118207','furniture-mobile','field','61',0,''),(176501,56525,'118207','furniture-mobile','border-bottom-width','1',0,''),(176502,56525,'118207','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176503,56525,'118207','furniture-mobile','padding-left','10',0,''),(176504,56526,'118208','furniture-mobile','block_type','6',0,''),(176505,56527,'118209','furniture-mobile','text','Address',0,''),(176506,56527,'118209','furniture-mobile','text-align','right',0,''),(176507,56528,'118210','furniture-mobile','field','55',0,''),(176508,56528,'118210','furniture-mobile','border-bottom-width','1',0,''),(176509,56528,'118210','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176510,56528,'118210','furniture-mobile','padding-left','10',0,''),(176511,56529,'118211','furniture-mobile','block_type','14',0,''),(176512,56529,'118211','furniture-mobile','padding-bottom','20',0,''),(176513,56530,'118212','furniture-mobile','text','33.33% Sale or Return',0,''),(176514,56530,'118212','furniture-mobile','text-align','right',0,''),(176515,56530,'118212','furniture-mobile','font-size','16',0,''),(176516,56531,'118213','furniture-mobile','block_type','13',0,''),(176517,56532,'118214','furniture-mobile','field','56',0,''),(176518,56532,'118214','furniture-mobile','padding-left','10',0,''),(176519,56533,'118215','furniture-mobile','text','35% Firm',0,''),(176520,56533,'118215','furniture-mobile','text-align','right',0,''),(176521,56534,'118216','furniture-mobile','field','58',0,''),(176522,56534,'118216','furniture-mobile','padding-left','10',0,''),(176523,56535,'118217','furniture-mobile','block_type','10',0,''),(176524,56536,'118218','furniture-mobile','block_type','6',0,''),(176525,56537,'118219','furniture-mobile','text','Bank Name',0,''),(176526,56537,'118219','furniture-mobile','text-align','right',0,''),(176527,56537,'118219','furniture-mobile','font-size','16',0,''),(176528,56538,'118220','furniture-mobile','field','53',0,''),(176529,56538,'118220','furniture-mobile','border-bottom-width','1',0,''),(176530,56538,'118220','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176531,56538,'118220','furniture-mobile','padding-left','10',0,''),(176532,56539,'118221','furniture-mobile','block_type','1',0,''),(176533,56539,'118221','furniture-mobile','padding-top','20',0,''),(176534,56539,'118221','furniture-mobile','padding-bottom','10',0,''),(176535,56540,'118222','furniture-mobile','background-color','$background-1',0,''),(176536,56540,'118222','furniture-mobile','color','$color-font-1',0,''),(176537,56540,'118222','furniture-mobile','font-size','20',0,''),(176538,56540,'118222','furniture-mobile','text','Discount (%)',0,''),(176539,56540,'118222','furniture-mobile','padding-left','10',0,''),(176540,56540,'118222','furniture-mobile','padding-right','10',0,''),(176541,56541,'118223','furniture-mobile','block_type','6',0,''),(176542,56541,'118223','furniture-mobile','padding-bottom','20',0,''),(176543,56542,'118224','furniture-mobile','text','Account No',0,''),(176544,56542,'118224','furniture-mobile','text-align','right',0,''),(176545,56543,'118225','furniture-mobile','field','54',0,''),(176546,56543,'118225','furniture-mobile','border-bottom-width','1',0,''),(176547,56543,'118225','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176548,56543,'118225','furniture-mobile','padding-left','10',0,''),(176549,56544,'118226','furniture-mobile','block_type','1',0,''),(176550,56544,'118226','furniture-mobile','padding-bottom','10',0,''),(176551,56545,'118227','furniture-mobile','background-color','$background-1',0,''),(176552,56545,'118227','furniture-mobile','color','$color-font-1',0,''),(176553,56545,'118227','furniture-mobile','font-size','20',0,''),(176554,56545,'118227','furniture-mobile','text','Bank Account Details',0,''),(176555,56545,'118227','furniture-mobile','padding-left','10',0,''),(176556,56545,'118227','furniture-mobile','padding-right','10',0,''),(176557,56546,'118228','furniture-mobile','block_type','6',0,''),(176558,56546,'118228','furniture-mobile','padding-bottom','20',0,''),(176559,56547,'118229','furniture-mobile','text','Nature of Business',0,''),(176560,56547,'118229','furniture-mobile','text-align','right',0,''),(176561,56548,'118230','furniture-mobile','field','52',0,''),(176562,56548,'118230','furniture-mobile','border-bottom-width','1',0,''),(176563,56548,'118230','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176564,56548,'118230','furniture-mobile','padding-left','10',0,''),(176565,56549,'118231','furniture-mobile','block_type','6',0,''),(176566,56550,'118232','furniture-mobile','text','Telephone No.',0,''),(176567,56550,'118232','furniture-mobile','text-align','right',0,''),(176568,56551,'118233','furniture-mobile','field','79',0,''),(176569,56551,'118233','furniture-mobile','border-bottom-width','1',0,''),(176570,56551,'118233','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176571,56551,'118233','furniture-mobile','padding-left','10',0,''),(176572,56552,'118234','furniture-mobile','block_type','6',0,''),(176573,56553,'118235','furniture-mobile','text','Address',0,''),(176574,56553,'118235','furniture-mobile','text-align','right',0,''),(176575,56554,'118236','furniture-mobile','fields','company_street_address, company_suburb, company_city',0,''),(176576,56554,'118236','furniture-mobile','padding-left','10',0,''),(176577,56554,'118236','furniture-mobile','border-bottom-width','1',0,''),(176578,56554,'118236','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176579,56555,'118237','furniture-mobile','block_type','6',0,''),(176580,56556,'118238','furniture-mobile','text','Postcode',0,''),(176581,56556,'118238','furniture-mobile','text-align','right',0,''),(176582,56557,'118239','furniture-mobile','field','80',0,''),(176583,56557,'118239','furniture-mobile','border-bottom-width','1',0,''),(176584,56557,'118239','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176585,56557,'118239','furniture-mobile','padding-left','10',0,''),(176586,56558,'118240','furniture-mobile','block_type','6',0,''),(176587,56559,'118241','furniture-mobile','text','Address',0,''),(176588,56559,'118241','furniture-mobile','text-align','right',0,''),(176589,56560,'118242','furniture-mobile','fields','oner_street_address, owner_suburb, owner_city',0,''),(176590,56560,'118242','furniture-mobile','padding-left','10',0,''),(176591,56560,'118242','furniture-mobile','border-bottom-width','1',0,''),(176592,56560,'118242','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176593,56561,'118243','furniture-mobile','block_type','6',0,''),(176594,56562,'118244','furniture-mobile','text','Email',0,''),(176595,56562,'118244','furniture-mobile','text-align','right',0,''),(176596,56563,'118245','furniture-mobile','field','70',0,''),(176597,56563,'118245','furniture-mobile','border-bottom-width','1',0,''),(176598,56563,'118245','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176599,56563,'118245','furniture-mobile','padding-left','10',0,''),(176600,56564,'118246','furniture-mobile','block_type','6',0,''),(176601,56564,'118246','furniture-mobile','margin-top','20',0,''),(176602,56565,'118247','furniture-mobile','text','Owner’s Name',0,''),(176603,56565,'118247','furniture-mobile','text-align','right',0,''),(176604,56566,'118248','furniture-mobile','fields','owner_firstname owner_lastname',0,''),(176605,56566,'118248','furniture-mobile','padding-left','10',0,''),(176606,56566,'118248','furniture-mobile','border-bottom-width','1',0,''),(176607,56566,'118248','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176608,56567,'118249','furniture-mobile','block_type','6',0,''),(176609,56567,'118249','furniture-mobile','padding-bottom','20',0,''),(176610,56568,'118250','furniture-mobile','text','Telephone No.',0,''),(176611,56568,'118250','furniture-mobile','text-align','right',0,''),(176612,56569,'118251','furniture-mobile','block_type','11',0,''),(176613,56570,'118252','furniture-mobile','field','69',0,''),(176614,56570,'118252','furniture-mobile','border-bottom-width','1',0,''),(176615,56570,'118252','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176616,56570,'118252','furniture-mobile','padding-left','10',0,''),(176617,56570,'118252','furniture-mobile','cells','34',0,''),(176618,56571,'118253','furniture-mobile','block_type','5',0,''),(176619,56572,'118254','furniture-mobile','text','Fax No.',0,''),(176620,56572,'118254','furniture-mobile','text-align','right',0,''),(176621,56573,'118255','furniture-mobile','field','51',0,''),(176622,56573,'118255','furniture-mobile','padding-left','10',0,''),(176623,56573,'118255','furniture-mobile','border-bottom-width','1',0,''),(176624,56573,'118255','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176625,56574,'118256','furniture-mobile','block_type','1',0,''),(176626,56575,'118257','furniture-mobile','background-color','$background-1',0,''),(176627,56575,'118257','furniture-mobile','color','$color-font-1',0,''),(176628,56575,'118257','furniture-mobile','font-size','20',0,''),(176629,56575,'118257','furniture-mobile','text','Customer Details',0,''),(176630,56575,'118257','furniture-mobile','padding-left','10',0,''),(176631,56575,'118257','furniture-mobile','padding-right','10',0,''),(176632,56576,'118258','furniture-mobile','block_type','2',0,''),(176633,56577,'118259','furniture-mobile','block_type','2',0,''),(176634,56577,'118259','furniture-mobile','padding-top','5',0,''),(176635,56578,'118260','furniture-mobile','block_type','10',0,''),(176636,56579,'118261','furniture-mobile','text','Limited Company',0,''),(176637,56579,'118261','furniture-mobile','font-size','16',0,''),(176638,56580,'118262','furniture-mobile','field','49',0,''),(176639,56580,'118262','furniture-mobile','padding-left','5',0,''),(176640,56581,'118263','furniture-mobile','block_type','10',0,''),(176641,56582,'118264','furniture-mobile','text','Sole Trader',0,''),(176642,56582,'118264','furniture-mobile','text-align','center',0,''),(176643,56583,'118265','furniture-mobile','field','50',0,''),(176644,56583,'118265','furniture-mobile','padding-left','5',0,''),(176645,56584,'118266','furniture-mobile','block_type','2',0,''),(176646,56584,'118266','furniture-mobile','color','$color-font-1',0,''),(176647,56584,'118266','furniture-mobile','background-color','$background-1',0,''),(176648,56585,'118267','furniture-mobile','view_item','name',0,''),(176649,56585,'118267','furniture-mobile','color','$color-font-1',0,''),(176650,56585,'118267','furniture-mobile','font-size','40',0,''),(176651,56586,'118268','furniture-mobile','text','New Account Form',0,''),(176652,56586,'118268','furniture-mobile','font-size','20',0,''),(176653,56586,'118268','furniture-mobile','color','$color-font-1',0,''),(176654,56586,'118268','furniture-mobile','padding-top','20',0,''),(176655,56587,'118269','furniture-mobile','block_type','5',0,''),(176656,56588,'118270','furniture-mobile','view_item','data_format',0,''),(176657,56588,'118270','furniture-mobile','data_format_content','##STREET_ADDRESS##, ##SUBURB##,\n##CITY##, ##POSTCODE##\nTel: ##TELEPHONE##\nEmail: ##EMAIL_ADDRESS##\n',0,''),(176658,56588,'118270','furniture-mobile','font-size','14',0,''),(176659,56589,'118271','furniture-mobile','block_type','6',0,''),(176660,56590,'118272','furniture-mobile','text','Business Name',0,''),(176661,56590,'118272','furniture-mobile','text-align','right',0,''),(176662,56591,'118273','furniture-mobile','field','68',0,''),(176663,56591,'118273','furniture-mobile','border-bottom-width','1',0,''),(176664,56591,'118273','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176665,56591,'118273','furniture-mobile','padding-left','10',0,''),(176666,56592,'118274','furniture-mobile','block_type','6',0,''),(176667,56593,'118275','furniture-mobile','text','Postcode',0,''),(176668,56593,'118275','furniture-mobile','text-align','right',0,''),(176669,56594,'118276','furniture-mobile','field','71',0,''),(176670,56594,'118276','furniture-mobile','border-bottom-width','1',0,''),(176671,56594,'118276','furniture-mobile','border-bottom-color','$border-color-5',0,''),(176672,56594,'118276','furniture-mobile','padding-left','10',0,''),(176677,56598,'118280','furniture-mobile','margin-bottom','20',0,''),(176678,56598,'118280','furniture-mobile','max-width','500',0,''),(176797,56636,'118318','furniture-mobile','block_type','1',0,''),(176798,56637,'118319','furniture-mobile','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(176799,56637,'118319','furniture-mobile','padding-top','100',0,''),(176800,56637,'118319','furniture-mobile','margin-bottom','100',0,''),(176801,56637,'118319','furniture-mobile','text-align','center',0,''),(176802,56637,'118319','furniture-mobile','font-size','20',0,''),(176803,56638,'118320','furniture-mobile','block_type','1',0,''),(176804,56638,'118320','furniture-mobile','background-color','$background-6',0,''),(176805,56638,'118320','furniture-mobile','padding-bottom','30',0,''),(176806,56639,'118321','furniture-mobile','block_type','4',0,''),(176807,56639,'118321','furniture-mobile','schema','4-2',0,'2885'),(176808,56640,'118322','furniture-mobile','block_type','1',0,''),(176809,56640,'118322','furniture-mobile','padding-right','40',0,''),(176810,56640,'118322','furniture-mobile','padding-right','0',0,'2885'),(176811,56641,'118323','furniture-mobile','block_type','2',0,''),(176812,56641,'118323','furniture-mobile','margin-bottom','20',0,''),(176813,56641,'118323','furniture-mobile','schema','2-2',0,'2876'),(176814,56641,'118323','furniture-mobile','background-color','$background-7',0,''),(176815,56642,'118324','furniture-mobile','block_type','1',0,''),(176816,56642,'118324','furniture-mobile','border-right-width','20',0,''),(176817,56642,'118324','furniture-mobile','border-right-color','$border-color-4',0,''),(176818,56642,'118324','furniture-mobile','margin-right','-10',0,''),(176819,56642,'118324','furniture-mobile','padding-right','30',0,''),(176820,56642,'118324','furniture-mobile','padding-top','20',0,''),(176821,56642,'118324','furniture-mobile','padding-left','30',0,''),(176822,56642,'118324','furniture-mobile','padding-bottom','20',0,''),(176823,56642,'118324','furniture-mobile','border-right-width','0',0,'2885'),(176824,56642,'118324','furniture-mobile','margin-right','0',0,'2885'),(176825,56642,'118324','furniture-mobile','margin-bottom','20',0,'2885'),(176826,56642,'118324','furniture-mobile','padding-left','20',0,'2885'),(176827,56642,'118324','furniture-mobile','padding-right','20',0,'2885'),(176828,56644,'118326','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(176829,56644,'118326','furniture-mobile','clear','none',0,''),(176830,56645,'118327','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(176831,56645,'118327','furniture-mobile','clear','none',0,''),(176832,56646,'118328','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(176833,56648,'118330','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(176834,56648,'118330','furniture-mobile','padding-top','20',0,''),(176835,56651,'118333','furniture-mobile','margin-bottom','20',0,''),(176836,56652,'118334','furniture-mobile','block_type','1',0,''),(176837,56652,'118334','furniture-mobile','padding-left','30',0,''),(176838,56652,'118334','furniture-mobile','border-left-width','20',0,''),(176839,56652,'118334','furniture-mobile','border-left-color','$border-color-4',0,''),(176840,56652,'118334','furniture-mobile','margin-left','-10',0,''),(176841,56652,'118334','furniture-mobile','padding-right','30',0,''),(176842,56652,'118334','furniture-mobile','padding-top','20',0,''),(176843,56652,'118334','furniture-mobile','padding-bottom','20',0,''),(176844,56652,'118334','furniture-mobile','border-left-width','0',0,'2885'),(176845,56653,'118335','furniture-mobile','margin-bottom','20',0,''),(176846,56655,'118337','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(176847,56656,'118338','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(176848,56656,'118338','furniture-mobile','clear','none',0,''),(176849,56657,'118339','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(176850,56657,'118339','furniture-mobile','clear','none',0,''),(176851,56658,'118340','furniture-mobile','block_type','1',0,''),(176852,56658,'118340','furniture-mobile','padding-right','30',0,''),(176853,56658,'118340','furniture-mobile','background-color','$background-7',0,''),(176854,56658,'118340','furniture-mobile','padding-top','20',0,''),(176855,56658,'118340','furniture-mobile','padding-left','30',0,''),(176856,56658,'118340','furniture-mobile','padding-bottom','20',0,''),(176857,56658,'118340','furniture-mobile','padding-left','20',0,'2885'),(176858,56658,'118340','furniture-mobile','padding-right','20',0,'2885'),(176859,56660,'118342','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(176860,56661,'118343','furniture-mobile','block_type','1',0,''),(176861,56661,'118343','furniture-mobile','padding-top','20',0,''),(176862,56661,'118343','furniture-mobile','padding-left','20',0,''),(176863,56661,'118343','furniture-mobile','padding-right','20',0,''),(176864,56661,'118343','furniture-mobile','padding-bottom','20',0,''),(176865,56661,'118343','furniture-mobile','background-color','$background-7',0,''),(176866,56661,'118343','furniture-mobile','style_class','order-summary',0,''),(176867,56662,'118344','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(176868,56666,'118348','furniture-mobile','block_type','1',0,''),(176869,56666,'118348','furniture-mobile','background-color','$background-6',0,''),(176870,56666,'118348','furniture-mobile','padding-bottom','30',0,''),(176871,56667,'118349','furniture-mobile','block_type','4',0,''),(176872,56667,'118349','furniture-mobile','schema','4-2',0,'2885'),(176873,56668,'118350','furniture-mobile','block_type','1',0,''),(176874,56668,'118350','furniture-mobile','padding-right','40',0,''),(176875,56668,'118350','furniture-mobile','padding-right','0',0,'2885'),(176876,56669,'118351','furniture-mobile','block_type','2',0,''),(176877,56669,'118351','furniture-mobile','margin-bottom','20',0,''),(176878,56669,'118351','furniture-mobile','schema','2-2',0,'2876'),(176879,56669,'118351','furniture-mobile','background-color','$background-7',0,''),(176880,56670,'118352','furniture-mobile','block_type','1',0,''),(176881,56670,'118352','furniture-mobile','border-right-width','20',0,''),(176882,56670,'118352','furniture-mobile','border-right-color','$border-color-4',0,''),(176883,56670,'118352','furniture-mobile','margin-right','-10',0,''),(176884,56670,'118352','furniture-mobile','padding-right','30',0,''),(176885,56670,'118352','furniture-mobile','padding-top','20',0,''),(176886,56670,'118352','furniture-mobile','padding-left','30',0,''),(176887,56670,'118352','furniture-mobile','padding-bottom','20',0,''),(176888,56670,'118352','furniture-mobile','border-right-width','0',0,'2885'),(176889,56670,'118352','furniture-mobile','margin-right','0',0,'2885'),(176890,56670,'118352','furniture-mobile','margin-bottom','20',0,'2885'),(176891,56670,'118352','furniture-mobile','padding-left','20',0,'2885'),(176892,56670,'118352','furniture-mobile','padding-right','20',0,'2885'),(176893,56671,'118353','furniture-mobile','margin-bottom','20',0,''),(176894,56674,'118356','furniture-mobile','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(176895,56674,'118356','furniture-mobile','padding-top','20',0,''),(176896,56676,'118358','furniture-mobile','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(176897,56676,'118358','furniture-mobile','clear','none',0,''),(176898,56678,'118360','furniture-mobile','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(176899,56679,'118361','furniture-mobile','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(176900,56679,'118361','furniture-mobile','clear','none',0,''),(176901,56681,'118362','furniture-mobile','block_type','1',0,''),(176902,56681,'118362','furniture-mobile','padding-left','30',0,''),(176903,56681,'118362','furniture-mobile','border-left-width','20',0,''),(176904,56681,'118362','furniture-mobile','border-left-color','$border-color-4',0,''),(176905,56681,'118362','furniture-mobile','margin-left','-10',0,''),(176906,56681,'118362','furniture-mobile','padding-right','30',0,''),(176907,56681,'118362','furniture-mobile','padding-top','20',0,''),(176908,56681,'118362','furniture-mobile','padding-bottom','20',0,''),(176909,56681,'118362','furniture-mobile','border-left-width','0',0,'2885'),(176910,56682,'118363','furniture-mobile','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(176911,56683,'118364','furniture-mobile','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(176912,56683,'118364','furniture-mobile','clear','none',0,''),(176913,56684,'118365','furniture-mobile','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(176914,56684,'118365','furniture-mobile','clear','none',0,''),(176915,56685,'118366','furniture-mobile','margin-bottom','20',0,''),(176916,56686,'118367','furniture-mobile','orders_data','name',0,''),(176917,56687,'118368','furniture-mobile','block_type','1',0,''),(176918,56687,'118368','furniture-mobile','padding-right','30',0,''),(176919,56687,'118368','furniture-mobile','background-color','$background-7',0,''),(176920,56687,'118368','furniture-mobile','padding-top','20',0,''),(176921,56687,'118368','furniture-mobile','padding-left','30',0,''),(176922,56687,'118368','furniture-mobile','padding-bottom','20',0,''),(176923,56687,'118368','furniture-mobile','padding-left','20',0,'2885'),(176924,56687,'118368','furniture-mobile','padding-right','20',0,'2885'),(176925,56688,'118369','furniture-mobile','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(176926,56690,'118371','furniture-mobile','block_type','1',0,''),(176927,56690,'118371','furniture-mobile','padding-top','20',0,''),(176928,56690,'118371','furniture-mobile','padding-left','20',0,''),(176929,56690,'118371','furniture-mobile','padding-right','20',0,''),(176930,56690,'118371','furniture-mobile','padding-bottom','20',0,''),(176931,56690,'118371','furniture-mobile','background-color','$background-7',0,''),(176932,56690,'118371','furniture-mobile','style_class','order-summary',0,''),(176933,56693,'118374','furniture-mobile','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(176934,56695,'118392','furniture-mobile','margin-bottom','10',0,''),(176935,56696,'1639406339.5675','furniture-mobile','block_type','1',0,''),(176936,56697,'118381','furniture-mobile','margin-bottom','30',0,''),(176937,56698,'118382','furniture-mobile','like_button','1',0,''),(176938,56698,'118382','furniture-mobile','text-align','center',0,''),(176939,56698,'118382','furniture-mobile','margin-bottom','20',0,''),(176940,56698,'118382','furniture-mobile','margin-top','20',0,''),(176941,56698,'118382','furniture-mobile','padding-top','30',0,''),(176942,56698,'118382','furniture-mobile','border-top-width','1',0,''),(176943,56698,'118382','furniture-mobile','border-top-color','$border-color-3',0,''),(176944,56698,'118382','furniture-mobile','padding-bottom','30',0,''),(176945,56698,'118382','furniture-mobile','border-bottom-width','1',0,''),(176946,56698,'118382','furniture-mobile','border-bottom-color','$border-color-3',0,''),(176947,56699,'118383','furniture-mobile','block_type','13',0,''),(176948,56699,'118383','furniture-mobile','margin-bottom','20',0,''),(176949,56699,'118383','furniture-mobile','schema','13-2',0,'2890'),(176950,56699,'118383','furniture-mobile','schema','13-4',0,'2876'),(176951,56700,'118384','furniture-mobile','position','relative',0,''),(176952,56700,'118384','furniture-mobile','margin-top','-100',0,''),(176953,56700,'118384','furniture-mobile','margin-top','-50',0,'2876'),(176954,56701,'118385','furniture-mobile','font-family','$font-1',0,''),(176955,56701,'118385','furniture-mobile','font-size','18',0,''),(176956,56701,'118385','furniture-mobile','margin-bottom','10',0,''),(176957,56701,'118385','furniture-mobile','text-align','center',0,'2890'),(176958,56702,'118386','furniture-mobile','font-family','$font-1',0,''),(176959,56702,'118386','furniture-mobile','font-size','30',0,''),(176960,56702,'118386','furniture-mobile','text-transform','uppercase',0,''),(176961,56702,'118386','furniture-mobile','text-align','center',0,'2890'),(176962,56702,'118386','furniture-mobile','font-size','26',0,'2876'),(176963,56702,'118386','furniture-mobile','padding-top','20',0,'2885'),(176964,56703,'118387','furniture-mobile','block_type','1',0,''),(176965,56703,'118387','furniture-mobile','float','left',0,''),(176966,56703,'118387','furniture-mobile','float','none',0,'2890'),(176967,56704,'118388','furniture-mobile','display','inline-block',0,''),(176968,56704,'118388','furniture-mobile','font-weight','700',0,''),(176969,56705,'118389','furniture-mobile','font-weight','700',0,''),(176970,56705,'118389','furniture-mobile','clear','none',0,''),(176971,56705,'118389','furniture-mobile','padding-left','20',0,''),(176972,56705,'118389','furniture-mobile','display','inline-block',0,''),(176973,56706,'118390','furniture-mobile','clear','none',0,''),(176974,56706,'118390','furniture-mobile','padding-left','20',0,''),(176975,56706,'118390','furniture-mobile','font-weight','700',0,''),(176976,56706,'118390','furniture-mobile','display','inline-block',0,''),(176977,56707,'118391','furniture-mobile','font-weight','700',0,''),(176978,56707,'118391','furniture-mobile','text-align','right',0,''),(176979,56707,'118391','furniture-mobile','text-align','center',0,'2876'),(176980,56707,'118391','furniture-mobile','padding-top','15',0,'2876'),(176988,56711,'118396','furniture-mobile','block_type','1',0,''),(176989,56711,'118396','furniture-mobile','padding-top','20',0,''),(176990,56711,'118396','furniture-mobile','padding-bottom','20',0,''),(176991,56712,'118397','furniture-mobile','block_type','1',0,''),(176992,56712,'118397','furniture-mobile','border-top-width','1',0,''),(176993,56712,'118397','furniture-mobile','border-left-width','1',0,''),(176994,56712,'118397','furniture-mobile','border-right-width','1',0,''),(176995,56712,'118397','furniture-mobile','border-bottom-width','1',0,''),(176996,56712,'118397','furniture-mobile','border-top-color','$border-color-3',0,''),(176997,56712,'118397','furniture-mobile','border-left-color','$border-color-3',0,''),(176998,56712,'118397','furniture-mobile','border-right-color','$border-color-3',0,''),(176999,56712,'118397','furniture-mobile','border-bottom-color','$border-color-3',0,''),(177000,56712,'118397','furniture-mobile','padding-top','15',0,''),(177001,56712,'118397','furniture-mobile','padding-left','15',0,''),(177002,56712,'118397','furniture-mobile','padding-right','15',0,''),(177003,56712,'118397','furniture-mobile','padding-bottom','15',0,''),(177004,56712,'118397','furniture-mobile','margin-bottom','50',0,''),(177005,56713,'118398','furniture-mobile','block_type','1',0,''),(177006,56713,'118398','furniture-mobile','padding-top','20',0,''),(177007,56713,'118398','furniture-mobile','padding-left','20',0,''),(177008,56713,'118398','furniture-mobile','padding-right','20',0,''),(177009,56713,'118398','furniture-mobile','background-color','$background-7',0,''),(177010,56713,'118398','furniture-mobile','padding-top','10',0,'2906'),(177011,56713,'118398','furniture-mobile','padding-left','0',0,'2906'),(177012,56713,'118398','furniture-mobile','padding-right','0',0,'2906'),(177013,56715,'118400','furniture-mobile','text','<h1>##FIND_REGISTRY##</h1>',0,''),(177014,56717,'118402','furniture-mobile','padding-top','10',0,''),(177015,56717,'118402','furniture-mobile','padding-bottom','10',0,''),(177016,56717,'118402','furniture-mobile','border-top-width','1',0,''),(177017,56717,'118402','furniture-mobile','border-top-color','$border-color-4',0,''),(177018,56717,'118402','furniture-mobile','text-align','right',0,''),(177019,56718,'118403','furniture-mobile','block_type','1',0,''),(177020,56719,'118404','furniture-mobile','block_type','8',0,''),(177021,56719,'118404','furniture-mobile','schema','8-6',0,'2885'),(177022,56720,'1639410195.9973','furniture-mobile','text','<span></span>',0,''),(177023,56721,'118405','furniture-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_PERSONALIZED_URL##</div>',0,''),(177024,56723,'118407','furniture-mobile','text','<div class=\"heading-3\">##INVITE_GUESTS##</div>',0,''),(177025,56724,'118408','furniture-mobile','margin-bottom','30',0,''),(177026,56725,'118410','furniture-mobile','margin-top','-100',0,''),(177027,56726,'118411','furniture-mobile','text','<h1>##SHARE_YOUR_WEDDING_REGISTRY##</h1>',0,''),(177028,56726,'118411','furniture-mobile','margin-top','-80',0,''),(177029,56726,'118411','furniture-mobile','margin-top','0',0,'2885'),(177030,56728,'1639405874.8749','furniture-mobile','block_type','1',0,''),(177031,56728,'1639405874.8749','furniture-mobile','padding-bottom','30',0,''),(177032,56730,'118413','furniture-mobile','text','<h1>##CREATE_WR_SUCCESS_MESSAGE##</h1>',0,''),(177033,56731,'1639393156.401','furniture-mobile','block_type','1',0,''),(177034,56732,'118414','furniture-mobile','block_type','2',0,''),(177035,56732,'118414','furniture-mobile','schema','2-2',0,'2885'),(177036,56733,'118415','furniture-mobile','block_type','1',0,''),(177037,56733,'118415','furniture-mobile','padding-right','15',0,''),(177038,56733,'118415','furniture-mobile','padding-right','0',0,'2885'),(177039,56734,'118416','furniture-mobile','text','<div class=\"heading-3\">##SHARE_YOUR_REGISTRY##</div>',0,''),(177040,56735,'118417','furniture-mobile','padding-bottom','15',0,''),(177041,56735,'118417','furniture-mobile','padding-top','15',0,''),(177042,56735,'118417','furniture-mobile','padding-left','15',0,''),(177043,56735,'118417','furniture-mobile','padding-right','15',0,''),(177044,56735,'118417','furniture-mobile','margin-bottom','20',0,''),(177045,56735,'118417','furniture-mobile','border-top-width','1',0,''),(177046,56735,'118417','furniture-mobile','border-left-width','1',0,''),(177047,56735,'118417','furniture-mobile','border-right-width','1',0,''),(177048,56735,'118417','furniture-mobile','border-bottom-width','1',0,''),(177049,56735,'118417','furniture-mobile','border-top-color','$border-color-3',0,''),(177050,56735,'118417','furniture-mobile','border-left-color','$border-color-3',0,''),(177051,56735,'118417','furniture-mobile','border-right-color','$border-color-3',0,''),(177052,56735,'118417','furniture-mobile','border-bottom-color','$border-color-3',0,''),(177053,56736,'118418','furniture-mobile','text','<div class=\"heading-3\">##TEXT_WEDDING_DETAILS##</div>',0,''),(177054,56737,'118419','furniture-mobile','text','<div class=\"heading-3\">##TEXT_NAMES##</div>',0,''),(177055,56738,'118420','furniture-mobile','margin-bottom','20',0,''),(177056,56738,'118420','furniture-mobile','padding-top','15',0,''),(177057,56738,'118420','furniture-mobile','padding-left','15',0,''),(177058,56738,'118420','furniture-mobile','padding-right','15',0,''),(177059,56738,'118420','furniture-mobile','padding-bottom','15',0,''),(177060,56738,'118420','furniture-mobile','border-top-width','1',0,''),(177061,56738,'118420','furniture-mobile','border-left-width','1',0,''),(177062,56738,'118420','furniture-mobile','border-right-width','1',0,''),(177063,56738,'118420','furniture-mobile','border-bottom-width','1',0,''),(177064,56738,'118420','furniture-mobile','border-top-color','$border-color-3',0,''),(177065,56738,'118420','furniture-mobile','border-left-color','$border-color-3',0,''),(177066,56738,'118420','furniture-mobile','border-right-color','$border-color-3',0,''),(177067,56738,'118420','furniture-mobile','border-bottom-color','$border-color-3',0,''),(177068,56739,'118421','furniture-mobile','margin-bottom','20',0,''),(177069,56739,'118421','furniture-mobile','padding-top','15',0,''),(177070,56739,'118421','furniture-mobile','padding-left','15',0,''),(177071,56739,'118421','furniture-mobile','padding-right','15',0,''),(177072,56739,'118421','furniture-mobile','padding-bottom','15',0,''),(177073,56739,'118421','furniture-mobile','border-top-width','1',0,''),(177074,56739,'118421','furniture-mobile','border-left-width','1',0,''),(177075,56739,'118421','furniture-mobile','border-right-width','1',0,''),(177076,56739,'118421','furniture-mobile','border-bottom-width','1',0,''),(177077,56739,'118421','furniture-mobile','border-top-color','$border-color-3',0,''),(177078,56739,'118421','furniture-mobile','border-left-color','$border-color-3',0,''),(177079,56739,'118421','furniture-mobile','border-right-color','$border-color-3',0,''),(177080,56739,'118421','furniture-mobile','border-bottom-color','$border-color-3',0,''),(177081,56740,'118422','furniture-mobile','block_type','1',0,''),(177082,56740,'118422','furniture-mobile','padding-left','15',0,''),(177083,56740,'118422','furniture-mobile','padding-left','0',0,'2885'),(177084,56741,'118423','furniture-mobile','margin-bottom','20',0,''),(177085,56741,'118423','furniture-mobile','padding-top','15',0,''),(177086,56741,'118423','furniture-mobile','padding-left','15',0,''),(177087,56741,'118423','furniture-mobile','padding-right','15',0,''),(177088,56741,'118423','furniture-mobile','padding-bottom','15',0,''),(177089,56741,'118423','furniture-mobile','border-top-width','1',0,''),(177090,56741,'118423','furniture-mobile','border-left-width','1',0,''),(177091,56741,'118423','furniture-mobile','border-right-width','1',0,''),(177092,56741,'118423','furniture-mobile','border-bottom-width','1',0,''),(177093,56741,'118423','furniture-mobile','border-top-color','$border-color-3',0,''),(177094,56741,'118423','furniture-mobile','border-left-color','$border-color-3',0,''),(177095,56741,'118423','furniture-mobile','border-right-color','$border-color-3',0,''),(177096,56741,'118423','furniture-mobile','border-bottom-color','$border-color-3',0,''),(177097,56742,'118424','furniture-mobile','text','<div class=\"heading-3\">##UPLOAD_PHOTO##</div>',0,''),(177098,56743,'118425','furniture-mobile','margin-bottom','20',0,''),(177099,56743,'118425','furniture-mobile','padding-top','15',0,''),(177100,56743,'118425','furniture-mobile','padding-left','15',0,''),(177101,56743,'118425','furniture-mobile','padding-right','15',0,''),(177102,56743,'118425','furniture-mobile','padding-bottom','15',0,''),(177103,56743,'118425','furniture-mobile','border-top-width','1',0,''),(177104,56743,'118425','furniture-mobile','border-left-width','1',0,''),(177105,56743,'118425','furniture-mobile','border-right-width','1',0,''),(177106,56743,'118425','furniture-mobile','border-bottom-width','1',0,''),(177107,56743,'118425','furniture-mobile','border-top-color','$border-color-3',0,''),(177108,56743,'118425','furniture-mobile','border-left-color','$border-color-3',0,''),(177109,56743,'118425','furniture-mobile','border-right-color','$border-color-3',0,''),(177110,56743,'118425','furniture-mobile','border-bottom-color','$border-color-3',0,''),(177111,56744,'118426','furniture-mobile','margin-bottom','20',0,''),(177112,56744,'118426','furniture-mobile','padding-left','1',0,''),(177113,56745,'118427','furniture-mobile','text','<div class=\"heading-3\">##TEXT_SHIPPING_DETAILS##</div>',0,''),(177114,56746,'118428','furniture-mobile','text','<div class=\"heading-3\">##TEXT_ADDITIONAL_INFORMATION##</div>',0,''),(177115,56747,'118429','furniture-mobile','block_type','2',0,''),(177116,56747,'118429','furniture-mobile','margin-bottom','20',0,''),(177117,56749,'118431','furniture-mobile','text-align','right',0,''),(177118,56750,'118432','furniture-mobile','text','<h1>##WEDDING_REGISTRY_FORM_HEADING##</h1>',0,''),(177119,56752,'1639500465.781','furniture-mobile','block_type','1',0,''),(177120,56753,'118433','furniture-mobile','block_type','13',0,''),(177121,56753,'118433','furniture-mobile','margin-bottom','20',0,''),(177122,56753,'118433','furniture-mobile','margin-top','10',0,''),(177123,56753,'118433','furniture-mobile','schema','13-2',0,'2885'),(177124,56753,'118433','furniture-mobile','schema','13-4',0,'2876'),(177125,56754,'118434','furniture-mobile','position','relative',0,''),(177126,56754,'118434','furniture-mobile','margin-top','-100',0,''),(177127,56755,'118435','furniture-mobile','font-family','$font-1',0,''),(177128,56755,'118435','furniture-mobile','font-size','18',0,''),(177129,56755,'118435','furniture-mobile','margin-bottom','10',0,''),(177130,56755,'118435','furniture-mobile','text-align','center',0,'2885'),(177131,56756,'118436','furniture-mobile','font-family','$font-1',0,''),(177138,56758,'118438','furniture-mobile','padding-top','30',0,''),(177139,56758,'118438','furniture-mobile','padding-bottom','30',0,''),(177140,56759,'118440','furniture-mobile','block_type','1',0,''),(177141,56760,'118441','furniture-mobile','block_type','6',0,''),(177142,56760,'118441','furniture-mobile','schema','6-3',0,'2885'),(177143,56761,'118442','furniture-mobile','aria_name','account-menu',0,''),(177144,56762,'116126','furniture-mobile','block_type','1',0,''),(177145,56762,'116126','furniture-mobile','padding-top','70',0,''),(177146,56762,'116126','furniture-mobile','padding-right','30',0,''),(177147,56762,'116126','furniture-mobile','padding-bottom','30',0,''),(177148,56762,'116126','furniture-mobile','padding-top','0',0,'2885'),(177149,56762,'116126','furniture-mobile','padding-left','0',0,'2885'),(177150,56762,'116126','furniture-mobile','padding-right','0',0,'2885'),(177151,56762,'116126','furniture-mobile','padding-bottom','0',0,'2885'),(177152,56763,'116127','furniture-mobile','block_type','1',0,''),(177153,56763,'116127','furniture-mobile','padding-right','20',0,''),(177154,56763,'116127','furniture-mobile','style_class','account-menu',0,''),(177155,56763,'116127','furniture-mobile','padding-top','20',0,''),(177156,56763,'116127','furniture-mobile','margin-bottom','20',0,''),(177157,56763,'116127','furniture-mobile','background-color','$background-6',0,''),(177158,56763,'116127','furniture-mobile','padding-left','20',0,''),(177159,56763,'116127','furniture-mobile','padding-bottom','20',0,''),(177160,56764,'116128','furniture-mobile','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(177161,56764,'116128','furniture-mobile','style_class','heading-settings',0,''),(177162,56765,'116129','furniture-mobile','link','logoff',0,''),(177163,56766,'116130','furniture-mobile','link','delete',0,''),(177164,56766,'116130','furniture-mobile','text','DELETE_ACCOUNT',0,''),(177165,56767,'116131','furniture-mobile','text','TEXT_DASHBOARD',0,''),(177166,56767,'116131','furniture-mobile','font-family','$font-1',0,''),(177167,56767,'116131','furniture-mobile','font-size','18',0,''),(177168,56767,'116131','furniture-mobile','text-transform','uppercase',0,''),(177169,56768,'116132','furniture-mobile','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(177170,56768,'116132','furniture-mobile','style_class','heading-saved-lists',0,''),(177171,56769,'116133','furniture-mobile','link','Personal Catalog',0,''),(177172,56769,'116133','furniture-mobile','text','TEXT_PERSONAL_CATALOG',0,''),(177173,56769,'116133','furniture-mobile','hide_link','personal_catalog',0,''),(177174,56770,'116134','furniture-mobile','link','Order History',0,''),(177175,56770,'116134','furniture-mobile','text','HEADING_ORDER_HISTORY',0,''),(177176,56770,'116134','furniture-mobile','active_link','Order History Info,Order pay',0,''),(177177,56771,'116135','furniture-mobile','link','Address Book',0,''),(177178,56771,'116135','furniture-mobile','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(177179,56772,'116136','furniture-mobile','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(177180,56772,'116136','furniture-mobile','style_class','heading-ordered-items',0,''),(177181,56773,'116137','furniture-mobile','link','Wishlist',0,''),(177182,56773,'116137','furniture-mobile','hide_link','wishlist',0,''),(177183,56773,'116137','furniture-mobile','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(177184,56774,'116138','furniture-mobile','link','My password',0,''),(177185,56774,'116138','furniture-mobile','text','TEXT_MY_PASSWORD',0,''),(177186,56775,'116139','furniture-mobile','link','Samples',0,''),(177187,56775,'116139','furniture-mobile','text','TEXT_HEADING_SAMPLE_CART',0,''),(177188,56775,'116139','furniture-mobile','hide_link','samples',0,''),(177189,56776,'116140','furniture-mobile','link','Review',0,''),(177190,56776,'116140','furniture-mobile','text','REVIEWS',0,''),(177191,56777,'116141','furniture-mobile','link','Quotations',0,''),(177192,56777,'116141','furniture-mobile','hide_link','quotations',0,''),(177193,56777,'116141','furniture-mobile','text','TEXT_HEADING_QUOTE_CART',0,''),(177194,56778,'116142','furniture-mobile','link','Account edit',0,''),(177195,56778,'116142','furniture-mobile','text','ACCOUNT_EDIT',0,''),(177196,56779,'116143','furniture-mobile','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(177197,56779,'116143','furniture-mobile','style_class','heading-settings',0,''),(177198,56780,'116144','furniture-mobile','link','trade_form',0,''),(177199,56780,'116144','furniture-mobile','text','TRADE_FORM',0,''),(177200,56781,'118443','furniture-mobile','margin-bottom','20',0,''),(177201,56782,'118444','furniture-mobile','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(177202,56783,'118445','furniture-mobile','block_type','1',0,''),(177203,56783,'118445','furniture-mobile','padding-top','20',0,''),(177204,56783,'118445','furniture-mobile','padding-bottom','20',0,''),(177205,56785,'118447','furniture-mobile','padding-top','20',0,''),(177206,56785,'118447','furniture-mobile','padding-bottom','20',0,''),(177210,54383,'116379','furniture-mobile','margin-top','15',0,''),(177250,3291,'113763','watch-mobile','margin-top','15',0,''),(177251,3682,'114160','watch-mobile','padding-left','15',0,''),(177252,3682,'114160','watch-mobile','padding-right','15',0,''),(336065,108861,'117044','splash','block_type','1',0,''),(336066,108862,'117045','splash','block_type','1',0,''),(336067,108862,'117045','splash','max-width','800',0,''),(336068,108862,'117045','splash','margin','0 auto',0,''),(336069,108862,'117045','splash','background-color','#ffffff',0,''),(336070,108863,'117046','splash','color','#424242',0,''),(336071,108863,'117046','splash','font-size','12',0,''),(336072,108863,'117046','splash','padding-top','20',0,''),(336073,108863,'117046','splash','padding-bottom','20',0,''),(336074,108863,'117046','splash','border-top-width','1',0,''),(336075,108863,'117046','splash','border-top-color','#e0e0e0',0,''),(336076,108864,'117047','splash','font-weight','normal',0,''),(336077,108864,'117047','splash','padding-top','20',0,''),(336078,108864,'117047','splash','padding-left','10',0,''),(336079,108864,'117047','splash','padding-right','10',0,''),(336080,108864,'117047','splash','padding-bottom','20',0,''),(336081,108864,'117047','splash','color','#424242',0,''),(336082,108864,'117047','splash','font-size','14',0,''),(336083,108865,'117048','splash','block_type','7',0,''),(336084,108865,'117048','splash','font-weight','normal',0,''),(336085,108865,'117048','splash','background-color','#212121',0,''),(336086,108865,'117048','splash','padding-top','5',0,''),(336087,108865,'117048','splash','padding-left','10',0,''),(336088,108865,'117048','splash','padding-right','10',0,''),(336089,108865,'117048','splash','padding-bottom','5',0,''),(336090,108866,'117049','splash','color','#ffffff',0,''),(336091,108866,'117049','splash','font-size','14',0,''),(336092,108866,'117049','splash','font-weight','normal',0,''),(336093,108867,'117050','splash','font-weight','normal',0,''),(336094,108867,'117050','splash','text-align','right',0,''),(336095,108867,'117050','splash','color','#ffffff',0,''),(336096,108867,'117050','splash','font-size','12',0,''),(336097,108868,'117051','splash','font-weight','normal',0,''),(336098,108868,'117051','splash','padding-bottom','10',0,''),(336099,108868,'117051','splash','padding-top','10',0,''),(336100,108868,'117051','splash','padding-left','20',0,''),(336101,108868,'117051','splash','background-color','#000000',0,''),(336102,108868,'117051','splash','logo','themes/splash/img/oscommerce_logo_(2)-1.png',1,''),(336103,108869,'1661353033.436213','splash','block_type','1',0,''),(336104,108870,'1661353033.440468','splash','show_heading','h1',0,''),(336105,108872,'1661353032.24842','splash','width','680',0,''),(336106,108872,'1661353032.24842','splash','font-weight','normal',0,''),(336107,108872,'1661353032.24842','splash','font-size','12',0,''),(336108,108872,'1661353032.24842','splash','padding-top','20',0,''),(336109,108872,'1661353032.24842','splash','padding-bottom','20',0,''),(336110,108872,'1661353032.24842','splash','color','#424242',0,''),(336111,108873,'1661353032.270236','splash','block_type','4',0,''),(336112,108873,'1661353032.270236','splash','font-weight','normal',0,''),(336113,108873,'1661353032.270236','splash','border-top-width','1',0,''),(336114,108873,'1661353032.270236','splash','border-top-color','#e0e0e0',0,''),(336115,108873,'1661353032.270236','splash','border-left-width','1',0,''),(336116,108873,'1661353032.270236','splash','border-left-color','#e0e0e0',0,''),(336117,108873,'1661353032.270236','splash','border-right-width','1',0,''),(336118,108873,'1661353032.270236','splash','border-right-color','#e0e0e0',0,''),(336119,108873,'1661353032.270236','splash','border-bottom-width','1',0,''),(336120,108873,'1661353032.270236','splash','border-bottom-color','#e0e0e0',0,''),(336121,108874,'1661353032.296769','splash','block_type','2',0,''),(336122,108874,'1661353032.296769','splash','font-weight','normal',0,''),(336123,108874,'1661353032.296769','splash','border-top-width','1',0,''),(336124,108874,'1661353032.296769','splash','border-top-color','#e0e0e0',0,''),(336125,108874,'1661353032.296769','splash','border-right-width','1',0,''),(336126,108874,'1661353032.296769','splash','border-right-color','#e0e0e0',0,''),(336127,108875,'1661353032.306393','splash','block_type','1',0,''),(336128,108875,'1661353032.306393','splash','font-weight','normal',0,''),(336129,108875,'1661353032.306393','splash','padding-top','10',0,''),(336130,108875,'1661353032.306393','splash','padding-left','10',0,''),(336131,108875,'1661353032.306393','splash','padding-right','10',0,''),(336132,108875,'1661353032.306393','splash','padding-bottom','10',0,''),(336133,108875,'1661353032.306393','splash','border-right-width','1',0,''),(336134,108875,'1661353032.306393','splash','border-right-color','#e0e0e0',0,''),(336135,108877,'1661353032.323757','splash','text','##TEXT_INVOICE_SHIPPING_VIA##',0,''),(336136,108877,'1661353032.323757','splash','font-size','14',0,''),(336137,108877,'1661353032.323757','splash','font-weight','bold',0,''),(336138,108878,'1661353032.337230','splash','block_type','1',0,''),(336139,108878,'1661353032.337230','splash','font-weight','normal',0,''),(336140,108878,'1661353032.337230','splash','padding-top','10',0,''),(336141,108878,'1661353032.337230','splash','padding-left','10',0,''),(336142,108878,'1661353032.337230','splash','padding-right','10',0,''),(336143,108878,'1661353032.337230','splash','padding-bottom','10',0,''),(336144,108880,'1661353032.34962','splash','text','##TEXT_INVOICE_SHIPPING_SERVICE##',0,''),(336145,108880,'1661353032.34962','splash','font-size','14',0,''),(336146,108880,'1661353032.34962','splash','font-weight','bold',0,''),(336147,108881,'1661353032.356416','splash','block_type','2',0,''),(336148,108881,'1661353032.356416','splash','font-weight','normal',0,''),(336149,108881,'1661353032.356416','splash','border-right-width','1',0,''),(336150,108881,'1661353032.356416','splash','border-right-color','#e0e0e0',0,''),(336151,108882,'1661353032.363923','splash','block_type','1',0,''),(336152,108882,'1661353032.363923','splash','font-weight','400',0,''),(336153,108882,'1661353032.363923','splash','background-color','#eeeeee',0,''),(336154,108882,'1661353032.363923','splash','padding-top','10',0,''),(336155,108882,'1661353032.363923','splash','padding-left','10',0,''),(336156,108882,'1661353032.363923','splash','padding-right','10',0,''),(336157,108882,'1661353032.363923','splash','padding-bottom','30',0,''),(336158,108883,'1661353032.374368','splash','font-size','12',0,''),(336159,108884,'1661353032.380968','splash','text','##TEXT_INVOICE_ADDRESS##',0,''),(336160,108884,'1661353032.380968','splash','font-size','14',0,''),(336161,108884,'1661353032.380968','splash','font-weight','bold',0,''),(336162,108884,'1661353032.380968','splash','text-transform','uppercase',0,''),(336163,108886,'1661353032.39417','splash','block_type','1',0,''),(336164,108886,'1661353032.39417','splash','font-weight','normal',0,''),(336165,108886,'1661353032.39417','splash','padding-top','10',0,''),(336166,108886,'1661353032.39417','splash','padding-left','10',0,''),(336167,108886,'1661353032.39417','splash','padding-right','10',0,''),(336168,108886,'1661353032.39417','splash','padding-bottom','10',0,''),(336169,108887,'1661353032.40481','splash','font-weight','normal',0,''),(336170,108888,'1661353032.410660','splash','font-weight','normal',0,''),(336171,108890,'1661353032.4242','splash','text','##TEXT_INVOICE_CUSTOMER##',0,''),(336172,108890,'1661353032.4242','splash','font-size','14',0,''),(336173,108890,'1661353032.4242','splash','font-weight','bold',0,''),(336174,108890,'1661353032.4242','splash','text-transform','uppercase',0,''),(336175,108891,'1661353032.430173','splash','text','##TEXT_INVOICE_PHONE_NUMBER##',0,''),(336176,108891,'1661353032.430173','splash','text-transform','uppercase',0,''),(336177,108891,'1661353032.430173','splash','font-weight','bold',0,''),(336178,108891,'1661353032.430173','splash','font-size','14',0,''),(336179,108891,'1661353032.430173','splash','padding-top','10',0,''),(336180,108892,'1661353032.440350','splash','text','##TEXT_INVOICE_EMAIL_ADDRESS##',0,''),(336181,108892,'1661353032.440350','splash','font-size','14',0,''),(336182,108892,'1661353032.440350','splash','font-weight','bold',0,''),(336183,108892,'1661353032.440350','splash','text-transform','uppercase',0,''),(336184,108892,'1661353032.440350','splash','padding-top','10',0,''),(336185,108893,'1661353032.449537','splash','font-weight','normal',0,''),(336186,108893,'1661353032.449537','splash','text-align','center',0,''),(336187,108893,'1661353032.449537','splash','padding-bottom','20',0,''),(336188,108894,'1661353032.456412','splash','font-size','14',0,''),(336189,108894,'1661353032.456412','splash','font-weight','bold',0,''),(336190,108894,'1661353032.456412','splash','text-align','center',0,''),(336191,108894,'1661353032.456412','splash','padding-bottom','10',0,''),(336192,108894,'1661353032.456412','splash','padding-top','10',0,''),(336193,108895,'1661353032.464888','splash','font-weight','normal',0,''),(336194,108895,'1661353032.464888','splash','text-align','center',0,''),(336195,108895,'1661353032.464888','splash','padding-bottom','10',0,''),(336196,108896,'1661353032.471888','splash','font-weight','normal',0,''),(336197,108896,'1661353032.471888','splash','text-align','center',0,''),(336198,108897,'1661353032.47812','splash','text','##TEXT_INVOICE_PAYMENT_DATE##',0,''),(336199,108897,'1661353032.47812','splash','font-size','12',0,''),(336200,108897,'1661353032.47812','splash','font-weight','bold',0,''),(336201,108897,'1661353032.47812','splash','text-align','center',0,''),(336202,108898,'1661353032.486692','splash','text','##TEXT_INVOICE_PAYMENT_METHOD##',0,''),(336203,108898,'1661353032.486692','splash','font-size','12',0,''),(336204,108898,'1661353032.486692','splash','font-weight','bold',0,''),(336205,108898,'1661353032.486692','splash','text-align','center',0,''),(336206,108899,'1661353032.495713','splash','block_type','3',0,''),(336207,108899,'1661353032.495713','splash','font-weight','normal',0,''),(336208,108899,'1661353032.495713','splash','padding-top','20',0,''),(336209,108900,'1661353032.50157','splash','font-size','12',0,''),(336210,108901,'1661353032.50664','splash','text','##TEXT_INVOICE_IF_UNDELIVERED##',0,''),(336211,108901,'1661353032.50664','splash','font-size','12',0,''),(336212,108901,'1661353032.50664','splash','font-weight','bold',0,''),(336213,108902,'1661353032.514429','splash','text','##TEXT_INVOICE_THANK_YOU_FOR_ORDER##',0,''),(336214,108902,'1661353032.514429','splash','color','#1da1f2',0,''),(336215,108902,'1661353032.514429','splash','font-size','13',0,''),(336216,108902,'1661353032.514429','splash','font-weight','bold',0,''),(336217,108902,'1661353032.514429','splash','text-align','center',0,''),(336218,108902,'1661353032.514429','splash','padding-top','5',0,''),(336219,108903,'1661353032.527783','splash','block_type','6',0,''),(336220,108903,'1661353032.527783','splash','font-weight','normal',0,''),(336221,108903,'1661353032.527783','splash','font-size','16',0,''),(336222,108904,'1661353032.533932','splash','text','##TEXT_INVOICE_EMAIL##',0,''),(336223,108904,'1661353032.533932','splash','font-size','12',0,''),(336224,108904,'1661353032.533932','splash','text-align','right',0,''),(336225,108904,'1661353032.533932','splash','font-weight','400',0,''),(336226,108905,'1661353032.54216','splash','font-weight','normal',0,''),(336227,108905,'1661353032.54216','splash','text-align','right',0,''),(336228,108905,'1661353032.54216','splash','font-size','12',0,''),(336229,108906,'1661353032.549414','splash','block_type','6',0,''),(336230,108906,'1661353032.549414','splash','font-weight','normal',0,''),(336231,108906,'1661353032.549414','splash','font-size','16',0,''),(336232,108907,'1661353032.556356','splash','text','##TEXT_INVOICE_PHONE##',0,''),(336233,108907,'1661353032.556356','splash','font-size','12',0,''),(336234,108907,'1661353032.556356','splash','font-weight','400',0,''),(336235,108907,'1661353032.556356','splash','text-align','right',0,''),(336236,108908,'1661353032.56487','splash','font-weight','normal',0,''),(336237,108908,'1661353032.56487','splash','text-align','right',0,''),(336238,108908,'1661353032.56487','splash','font-size','12',0,''),(336239,108909,'1661353032.572983','splash','text','##TEXT_INVOICE_SOMETHING_WRONG##',0,''),(336240,108909,'1661353032.572983','splash','font-size','12',0,''),(336241,108909,'1661353032.572983','splash','font-weight','bold',0,''),(336242,108909,'1661353032.572983','splash','text-align','right',0,''),(336243,108910,'1661353032.588254','splash','font-weight','400',0,''),(336244,108910,'1661353032.588254','splash','padding-top','20',0,''),(336245,108910,'1661353032.588254','splash','padding-bottom','0',0,''),(336246,108910,'1661353032.588254','splash','font-size','12',0,''),(336247,108911,'1661353032.596366','splash','block_type','5',0,''),(336248,108911,'1661353032.596366','splash','font-weight','normal',0,''),(336249,108911,'1661353032.596366','splash','border-bottom-width','1',0,''),(336250,108911,'1661353032.596366','splash','border-bottom-color','#e0e0e0',0,''),(336251,108911,'1661353032.596366','splash','border-top-width','1',0,''),(336252,108911,'1661353032.596366','splash','border-top-color','#e0e0e0',0,''),(336253,108911,'1661353032.596366','splash','border-left-color','#e0e0e0',0,''),(336254,108911,'1661353032.596366','splash','border-left-width','1',0,''),(336255,108912,'1661353032.616225','splash','block_type','1',0,''),(336256,108912,'1661353032.616225','splash','font-weight','normal',0,''),(336257,108912,'1661353032.616225','splash','padding-top','10',0,''),(336258,108912,'1661353032.616225','splash','padding-left','10',0,''),(336259,108912,'1661353032.616225','splash','padding-right','10',0,''),(336260,108913,'1661353032.624746','splash','font-weight','400',0,''),(336261,108913,'1661353032.624746','splash','line-height','120',0,''),(336262,108913,'1661353032.624746','splash','line_height_measure','%',0,''),(336263,108913,'1661353032.624746','splash','font-size','12',0,''),(336264,108914,'1661353032.6344','splash','text','##SHIPPING_ADDRESS##',0,''),(336265,108914,'1661353032.6344','splash','font-size','14',0,''),(336266,108914,'1661353032.6344','splash','text-transform','uppercase',0,''),(336267,108914,'1661353032.6344','splash','font-weight','bold',0,''),(336268,108914,'1661353032.6344','splash','padding-bottom','10',0,''),(336269,108915,'1661353032.645291','splash','block_type','1',0,''),(336270,108915,'1661353032.645291','splash','background-color','#eeeeee',0,''),(336271,108915,'1661353032.645291','splash','padding-top','20',0,''),(336272,108915,'1661353032.645291','splash','padding-left','10',0,''),(336273,108915,'1661353032.645291','splash','padding-right','10',0,''),(336274,108915,'1661353032.645291','splash','padding-bottom','20',0,''),(336275,108915,'1661353032.645291','splash','font-size','14',0,''),(336276,108916,'1661353032.656840','splash','font-weight','normal',0,''),(336277,108916,'1661353032.656840','splash','text-align','right',0,''),(336278,108916,'1661353032.656840','splash','font-size','12',0,''),(336279,108916,'1661353032.656840','splash','box_align','3',0,''),(336280,108917,'1661353032.665237','splash','block_type','2',0,''),(336281,108917,'1661353032.665237','splash','font-weight','normal',0,''),(336282,108917,'1661353032.665237','splash','padding-bottom','20',0,''),(336283,108918,'1661353032.672459','splash','logo','themes/splash/img/oscommerce_logo.jpg',1,''),(336284,108919,'1661353032.693794','splash','block_type','11',0,''),(336285,108919,'1661353032.693794','splash','font-weight','normal',0,''),(336286,108920,'1661353032.699666','splash','text','##TEXT_INVOICE_WEB##',0,''),(336287,108920,'1661353032.699666','splash','text-align','right',0,''),(336288,108921,'1661353032.705757','splash','font-weight','normal',0,''),(336289,108921,'1661353032.705757','splash','text-align','right',0,''),(336290,108922,'1661353032.712713','splash','block_type','11',0,''),(336291,108922,'1661353032.712713','splash','font-weight','normal',0,''),(336292,108923,'1661353032.717779','splash','text','##TEXT_INVOICE_EMAIL##',0,''),(336293,108923,'1661353032.717779','splash','font-weight','400',0,''),(336294,108923,'1661353032.717779','splash','text-align','right',0,''),(336295,108924,'1661353032.724733','splash','font-weight','normal',0,''),(336296,108924,'1661353032.724733','splash','text-align','right',0,''),(336297,108925,'1661353032.729329','splash','block_type','1',0,''),(336298,108926,'1661353032.73418','splash','font-weight','normal',0,''),(336299,108926,'1661353032.73418','splash','text-align','right',0,''),(336300,108926,'1661353032.73418','splash','padding-bottom','10',0,''),(336301,108926,'1661353032.73418','splash','address_spacer',',',0,''),(336302,108926,'1661353032.73418','splash','font-size','12',0,''),(336303,108927,'1661353032.745349','splash','block_type','11',0,''),(336304,108927,'1661353032.745349','splash','font-weight','normal',0,''),(336305,108928,'1661353032.752179','splash','text','##TEXT_INVOICE_PHONE##',0,''),(336306,108928,'1661353032.752179','splash','text-align','right',0,''),(336307,108928,'1661353032.752179','splash','font-weight','400',0,''),(336308,108929,'1661353032.759958','splash','font-weight','normal',0,''),(336309,108929,'1661353032.759958','splash','text-align','right',0,''),(336310,108930,'1661353032.765438','splash','column_qty','1',0,''),(336311,108930,'1661353032.765438','splash','column_name','1',0,''),(336312,108930,'1661353032.765438','splash','column_model','1',0,''),(336313,108931,'1640168549.8258','splash','block_type','1',0,''),(336314,108931,'1640168549.8258','splash','background_image','themes/splash/img/bg2.jpg',0,''),(336315,108931,'1640168549.8258','splash','background-size','contain',0,''),(336316,108931,'1640168549.8258','splash','background-repeat','no-repeat',0,''),(336317,108931,'1640168549.8258','splash','style_class','mainbg',0,''),(336318,108932,'1640168603.5833','splash','block_type','1',0,''),(336319,108933,'1640168618.7708','splash','logo','themes/splash/img/oscommerce_logo (2).png',1,''),(336320,108933,'1640168618.7708','splash','margin-top','30',0,''),(336321,108933,'1640168618.7708','splash','margin-bottom','30',0,''),(336322,108933,'1640168618.7708','splash','box_align','2',0,''),(336323,108934,'1640181569.3506','splash','block_type','1',0,''),(336324,108935,'1640168851.5282','splash','block_type','3',0,''),(336325,108935,'1640168851.5282','splash','schema','3-6',0,'5107'),(336326,108936,'1640169872.1589','splash','logo','themes/splash/img/Splash_furniture_BGlogo.png',1,''),(336327,108936,'1640169872.1589','splash','box_align','2',0,''),(336328,108936,'1640169872.1589','splash','style_class','scale',0,''),(336329,108936,'1640169872.1589','splash','img_link','furniture/',1,''),(336330,108936,'1640169872.1589','splash','target_blank','1',1,''),(336331,108937,'1640276640.1123','splash','text','<h1>osCommerce v4 Splash page</h1>\r\n\r\n<p>osCommerce supports multiple sales CHANNELS.</p>\r\n\r\n<p>Your installation of osCommerce comes with &nbsp;&quot;Furniture&quot;, &quot;Watch&quot;, &quot;B2B Supermarket&quot;, and &quot;Print shop&quot; Ecommerce sales channels and &quot;cms&quot; brochure website example.</p>\r\n\r\n<p>Each sales channel has its own URLs, design, and demo product sets.</p>\r\n\r\n<p>&quot;Admin&quot; is the back end of your osCommerce.</p>\r\n\r\n<p>Use osCommerce Wiki to learn how to manage sales channels, &nbsp;assign design themes, and content to the sales channels.<br />\r\nThank you for choosing &nbsp;osCommerce - the most powerful on-premise open source Ecommerce platform!</p>\r\n',1,''),(336332,108937,'1640276640.1123','splash','color','#ffffff',0,''),(336333,108937,'1640276640.1123','splash','font-size','16',0,''),(336334,108937,'1640276640.1123','splash','text-align','center',0,''),(336335,108937,'1640276640.1123','splash','padding-top','50',0,'5107'),(336336,108937,'1640276640.1123','splash','padding-left','30',0,'5107'),(336337,108937,'1640276640.1123','splash','padding-right','30',0,'5107'),(336338,108937,'1640276640.1123','splash','padding-bottom','50',0,'5107'),(336339,108937,'1640276640.1123','splash','font-size','14',0,'5109'),(336340,108938,'1640170154.7803','splash','logo','themes/splash/img/Splash_watch_BGlogo.png',1,''),(336341,108938,'1640170154.7803','splash','box_align','2',0,''),(336342,108938,'1640170154.7803','splash','style_class','scale',0,''),(336343,108938,'1640170154.7803','splash','img_link','watch/',1,''),(336344,108938,'1640170154.7803','splash','target_blank','1',1,''),(336345,108938,'1640170154.7803','splash','padding-top','30',0,'5107'),(336346,108939,'1645204049.8114','splash','block_type','3',0,''),(336347,108939,'1645204049.8114','splash','schema','3-6',0,'5107'),(336348,108940,'1640170023.0001','splash','logo','themes/splash/img/print shop.jpg',1,''),(336349,108940,'1640170023.0001','splash','box_align','2',0,''),(336350,108940,'1640170023.0001','splash','margin-top','30',0,''),(336351,108940,'1640170023.0001','splash','margin-bottom','30',0,''),(336352,108940,'1640170023.0001','splash','img_link','printshop/',1,''),(336353,108940,'1640170023.0001','splash','style_class','scale',0,''),(336354,108940,'1640170023.0001','splash','target_blank','1',1,''),(336355,108941,'1640170023.1491','splash','logo','themes/splash/img/Splash_admin_BGlogo.png',1,''),(336356,108941,'1640170023.1491','splash','box_align','2',0,''),(336357,108941,'1640170023.1491','splash','margin-top','30',0,''),(336358,108941,'1640170023.1491','splash','margin-bottom','30',0,''),(336359,108941,'1640170023.1491','splash','img_link','admin/',1,''),(336360,108941,'1640170023.1491','splash','style_class','scale',0,''),(336361,108941,'1640170023.1491','splash','target_blank','1',1,''),(336362,108942,'1640170023','splash','logo','themes/splash/img/b2b supermarket.jpg',1,''),(336363,108942,'1640170023','splash','box_align','2',0,''),(336364,108942,'1640170023','splash','margin-top','30',0,''),(336365,108942,'1640170023','splash','margin-bottom','30',0,''),(336366,108942,'1640170023','splash','img_link','b2b-supermarket/',1,''),(336367,108942,'1640170023','splash','style_class','scale',0,''),(336368,108942,'1640170023','splash','target_blank','1',1,''),(336369,108943,'1661353032.958564','splash','width','680',0,''),(336370,108943,'1661353032.958564','splash','font-weight','400',0,''),(336371,108943,'1661353032.958564','splash','font-size','12',0,''),(336372,108943,'1661353032.958564','splash','padding-top','20',0,''),(336373,108943,'1661353032.958564','splash','padding-bottom','20',0,''),(336374,108944,'1661353032.968771','splash','block_type','2',0,''),(336375,108944,'1661353032.968771','splash','font-weight','normal',0,''),(336376,108944,'1661353032.968771','splash','padding-bottom','20',0,''),(336377,108945,'1661353032.975845','splash','font-weight','400',0,''),(336378,108945,'1661353032.975845','splash','padding-top','10',0,''),(336379,108945,'1661353032.975845','splash','logo','themes/splash/img/oscommerce_logo-1.jpg',1,''),(336380,108946,'1661353032.991276','splash','block_type','11',0,''),(336381,108946,'1661353032.991276','splash','font-weight','normal',0,''),(336382,108947,'1661353032.99777','splash','text','##TEXT_INVOICE_EMAIL##',0,''),(336383,108947,'1661353032.99777','splash','text-align','right',0,''),(336384,108948,'1661353033.00539','splash','font-weight','normal',0,''),(336385,108948,'1661353033.00539','splash','text-align','right',0,''),(336386,108949,'1661353033.010798','splash','block_type','11',0,''),(336387,108949,'1661353033.010798','splash','font-weight','normal',0,''),(336388,108950,'1661353033.017634','splash','text','##TEXT_INVOICE_PHONE##',0,''),(336389,108950,'1661353033.017634','splash','font-weight','400',0,''),(336390,108950,'1661353033.017634','splash','text-align','right',0,''),(336391,108951,'1661353033.027946','splash','font-weight','normal',0,''),(336392,108951,'1661353033.027946','splash','text-align','right',0,''),(336393,108952,'1661353033.033296','splash','block_type','1',0,''),(336394,108953,'1661353033.03754','splash','font-weight','400',0,''),(336395,108953,'1661353033.03754','splash','text-align','right',0,''),(336396,108953,'1661353033.03754','splash','padding-bottom','10',0,''),(336397,108953,'1661353033.03754','splash','address_spacer',',',0,''),(336398,108953,'1661353033.03754','splash','font-size','12',0,''),(336399,108954,'1661353033.046342','splash','block_type','11',0,''),(336400,108954,'1661353033.046342','splash','font-weight','400',0,''),(336401,108955,'1661353033.052669','splash','text','##TEXT_INVOICE_WEB##',0,''),(336402,108955,'1661353033.052669','splash','text-align','right',0,''),(336403,108956,'1661353033.060721','splash','font-weight','normal',0,''),(336404,108956,'1661353033.060721','splash','text-align','right',0,''),(336405,108957,'1661353033.065977','splash','font-weight','normal',0,''),(336406,108957,'1661353033.065977','splash','padding-top','20',0,''),(336407,108957,'1661353033.065977','splash','font-size','12',0,''),(336408,108958,'1661353033.073678','splash','block_type','1',0,''),(336409,108958,'1661353033.073678','splash','font-weight','normal',0,''),(336410,108958,'1661353033.073678','splash','padding-top','10',0,''),(336411,108958,'1661353033.073678','splash','padding-bottom','10',0,''),(336412,108960,'1661353033.085331','splash','text','##TEXT_INVOICE_IF_UNDELIVERED##',0,''),(336413,108960,'1661353033.085331','splash','font-weight','bold',0,''),(336414,108961,'1661353033.093224','splash','block_type','4',0,''),(336415,108961,'1661353033.093224','splash','font-weight','400',0,''),(336416,108961,'1661353033.093224','splash','border-top-width','1',0,''),(336417,108961,'1661353033.093224','splash','border-top-color','#e0e0e0',0,''),(336418,108961,'1661353033.093224','splash','border-left-width','1',0,''),(336419,108961,'1661353033.093224','splash','border-left-color','#e0e0e0',0,''),(336420,108961,'1661353033.093224','splash','border-right-width','1',0,''),(336421,108961,'1661353033.093224','splash','border-right-color','#e0e0e0',0,''),(336422,108961,'1661353033.093224','splash','border-bottom-width','1',0,''),(336423,108961,'1661353033.093224','splash','border-bottom-color','#e0e0e0',0,''),(336424,108962,'1661353033.108992','splash','block_type','2',0,''),(336425,108962,'1661353033.108992','splash','font-weight','normal',0,''),(336426,108962,'1661353033.108992','splash','border-right-width','1',0,''),(336427,108962,'1661353033.108992','splash','border-right-color','#e0e0e0',0,''),(336428,108963,'1661353033.11758','splash','block_type','1',0,''),(336429,108963,'1661353033.11758','splash','font-weight','normal',0,''),(336430,108963,'1661353033.11758','splash','border-right-width','1',0,''),(336431,108963,'1661353033.11758','splash','border-right-color','#e0e0e0',0,''),(336432,108963,'1661353033.11758','splash','background-color','#eeeeee',0,''),(336433,108963,'1661353033.11758','splash','padding-top','10',0,''),(336434,108963,'1661353033.11758','splash','padding-left','10',0,''),(336435,108963,'1661353033.11758','splash','padding-right','10',0,''),(336436,108963,'1661353033.11758','splash','padding-bottom','10',0,''),(336437,108964,'1661353033.129825','splash','font-size','12',0,''),(336438,108964,'1661353033.129825','splash','font-weight','normal',0,''),(336439,108965,'1661353033.136397','splash','text','##SHIPPING_ADDRESS##:',0,''),(336440,108965,'1661353033.136397','splash','font-size','13',0,''),(336441,108965,'1661353033.136397','splash','font-weight','bold',0,''),(336442,108965,'1661353033.136397','splash','text-transform','uppercase',0,''),(336443,108966,'1661353033.145276','splash','block_type','1',0,''),(336444,108966,'1661353033.145276','splash','font-weight','normal',0,''),(336445,108966,'1661353033.145276','splash','padding-top','10',0,''),(336446,108966,'1661353033.145276','splash','padding-left','10',0,''),(336447,108966,'1661353033.145276','splash','padding-right','10',0,''),(336448,108966,'1661353033.145276','splash','padding-bottom','10',0,''),(336449,108967,'1661353033.15637','splash','font-size','12',0,''),(336450,108969,'1661353033.16397','splash','font-size','12',0,''),(336451,108970,'1661353033.168995','splash','text','##TEXT_INVOICE_CUSTOMER##',0,''),(336452,108970,'1661353033.168995','splash','font-size','13',0,''),(336453,108970,'1661353033.168995','splash','font-weight','bold',0,''),(336454,108970,'1661353033.168995','splash','text-transform','uppercase',0,''),(336455,108971,'1661353033.176872','splash','text','##TEXT_INVOICE_PHONE_NUMBER##',0,''),(336456,108971,'1661353033.176872','splash','font-size','13',0,''),(336457,108971,'1661353033.176872','splash','font-weight','bold',0,''),(336458,108971,'1661353033.176872','splash','text-transform','uppercase',0,''),(336459,108971,'1661353033.176872','splash','padding-top','10',0,''),(336460,108972,'1661353033.185817','splash','text','##TEXT_INVOICE_EMAIL_ADDRESS##',0,''),(336461,108972,'1661353033.185817','splash','font-size','13',0,''),(336462,108972,'1661353033.185817','splash','font-weight','bold',0,''),(336463,108972,'1661353033.185817','splash','text-transform','uppercase',0,''),(336464,108972,'1661353033.185817','splash','padding-top','10',0,''),(336465,108973,'1661353033.197558','splash','block_type','2',0,''),(336466,108973,'1661353033.197558','splash','font-weight','normal',0,''),(336467,108973,'1661353033.197558','splash','border-right-width','1',0,''),(336468,108973,'1661353033.197558','splash','border-right-color','#e0e0e0',0,''),(336469,108973,'1661353033.197558','splash','border-top-width','1',0,''),(336470,108973,'1661353033.197558','splash','border-top-color','#e0e0e0',0,''),(336471,108974,'1661353033.208111','splash','block_type','1',0,''),(336472,108974,'1661353033.208111','splash','font-weight','normal',0,''),(336473,108974,'1661353033.208111','splash','padding-top','10',0,''),(336474,108974,'1661353033.208111','splash','padding-left','10',0,''),(336475,108974,'1661353033.208111','splash','padding-right','10',0,''),(336476,108974,'1661353033.208111','splash','padding-bottom','10',0,''),(336477,108974,'1661353033.208111','splash','border-right-width','1',0,''),(336478,108974,'1661353033.208111','splash','border-right-color','#e0e0e0',0,''),(336479,108976,'1661353033.22360','splash','text','##TEXT_INVOICE_SHIPPING_VIA##',0,''),(336480,108976,'1661353033.22360','splash','font-weight','bold',0,''),(336481,108977,'1661353033.2314','splash','block_type','1',0,''),(336482,108977,'1661353033.2314','splash','font-weight','normal',0,''),(336483,108977,'1661353033.2314','splash','padding-top','10',0,''),(336484,108977,'1661353033.2314','splash','padding-left','10',0,''),(336485,108977,'1661353033.2314','splash','padding-right','10',0,''),(336486,108977,'1661353033.2314','splash','padding-bottom','10',0,''),(336487,108979,'1661353033.243986','splash','text','##TEXT_INVOICE_SHIPPING_SERVICE##',0,''),(336488,108979,'1661353033.243986','splash','font-weight','bold',0,''),(336489,108980,'1661353033.250617','splash','font-weight','normal',0,''),(336490,108980,'1661353033.250617','splash','text-align','center',0,''),(336491,108980,'1661353033.250617','splash','padding-top','40',0,''),(336492,108981,'1661353033.258425','splash','padding-top','15',0,''),(336493,108983,'74684','splash','block_type','2',0,''),(336494,108984,'74685','splash','block_type','1',0,''),(336495,108984,'74685','splash','style_class','product',0,''),(336496,108984,'74685','splash','padding-right','10',0,''),(336497,108984,'74685','splash','padding-bottom','20',0,''),(336498,108985,'74686','splash','block_type','1',0,''),(336499,108986,'74687','splash','product_element','products_name',0,''),(336500,108986,'74687','splash','font-family','Varela Round',0,''),(336501,108986,'74687','splash','padding-bottom','10',0,''),(336502,108986,'74687','splash','font-size','16',0,''),(336503,108987,'74688','splash','block_type','2',0,''),(336504,108988,'74689','splash','product_element','image',0,''),(336505,108988,'74689','splash','padding-right','10',0,''),(336506,108989,'74690','splash','product_element','products_price_old',0,''),(336507,108989,'74690','splash','font-family','Varela Round',0,''),(336508,108989,'74690','splash','font-size','14',0,''),(336509,108989,'74690','splash','text-decoration','line-through',0,''),(336510,108990,'74691','splash','product_element','products_price',0,''),(336511,108990,'74691','splash','font-family','Varela Round',0,''),(336512,108990,'74691','splash','font-size','20',0,''),(336513,108990,'74691','splash','padding-top','20',0,''),(336514,108991,'74692','splash','block_type','1',0,''),(336515,108991,'74692','splash','style_class','product',0,''),(336516,108991,'74692','splash','padding-left','10',0,''),(336517,108991,'74692','splash','padding-bottom','20',0,''),(336518,108992,'74693','splash','block_type','2',0,''),(336519,108993,'74694','splash','product_element','image',0,''),(336520,108993,'74694','splash','padding-right','10',0,''),(336521,108994,'74695','splash','font-size','14',0,''),(336522,108994,'74695','splash','font-family','Varela Round',0,''),(336523,108994,'74695','splash','text-decoration','line-through',0,''),(336524,108994,'74695','splash','product_element','products_price_old',0,''),(336525,108995,'74696','splash','product_element','products_price',0,''),(336526,108995,'74696','splash','font-family','Varela Round',0,''),(336527,108995,'74696','splash','font-size','20',0,''),(336528,108995,'74696','splash','padding-top','20',0,''),(336529,108996,'74697','splash','block_type','1',0,''),(336530,108997,'74698','splash','product_element','products_name',0,''),(336531,108997,'74698','splash','font-family','Varela Round',0,''),(336532,108997,'74698','splash','font-size','16',0,''),(336533,108997,'74698','splash','padding-bottom','10',0,''),(336534,108998,'74700','splash','padding-bottom','20',0,''),(336535,108998,'74700','splash','text-align','center',0,''),(336536,108999,'74699','splash','font-size','30',0,''),(336537,108999,'74699','splash','font-family','Varela Round',0,''),(336538,108999,'74699','splash','text-align','center',0,''),(336539,108999,'74699','splash','padding-bottom','50',0,''),(336540,109000,'74701','splash','width','680',0,''),(336541,109001,'74702','splash','padding-top','200',0,''),(336542,109001,'74702','splash','padding-left','200',0,''),(336543,109001,'74702','splash','logo','themes/splash/img/oscommerce_logo.jpg',1,''),(336544,109002,'74703','splash','text','osCommerce 4',1,''),(336545,109002,'74703','splash','font-family','Varela Round',0,''),(336546,109002,'74703','splash','font-size','40',0,''),(336547,109002,'74703','splash','padding-top','50',0,''),(336548,109002,'74703','splash','text-align','center',0,''),(336549,109003,'74704','splash','block_type','2',0,''),(336550,109003,'74704','splash','border-top-width','1',0,''),(336551,109003,'74704','splash','border-top-color','#e0e0e0',0,''),(336552,109004,'74705','splash','text-align','right',0,''),(336553,109004,'74705','splash','padding-top','15',0,''),(336554,109004,'74705','splash','padding-bottom','15',0,''),(336555,109004,'74705','splash','font-size','14',0,''),(336556,109005,'74706','splash','font-family','Varela Round',0,''),(336557,109005,'74706','splash','text-align','center',0,''),(336558,109005,'74706','splash','font-size','20',0,''),(336559,109005,'74706','splash','color','#183d78',0,''),(336560,109005,'74706','splash','border-bottom-width','1',0,''),(336561,109005,'74706','splash','border-bottom-color','#e0e0e0',0,''),(336562,109005,'74706','splash','padding-top','10',0,''),(336563,109005,'74706','splash','padding-bottom','10',0,''),(336708,3158,'115992','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',2,''),(336709,3189,'113675','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',2,''),(336710,3888,'114358','watch-mobile','text','<p>Shipping via</p>',2,''),(336711,3892,'114362','watch-mobile','text','<p>Shipping service</p>',2,''),(336712,3896,'114366','watch-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(336713,3898,'114368','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(336714,3901,'114371','watch-mobile','text','<p>PHONE NUMBER:</p>',2,''),(336715,3902,'114372','watch-mobile','text','<p>CUSTOMER:</p>',2,''),(336716,3905,'114375','watch-mobile','text','<p>Payment date:</p>',2,''),(336717,3909,'114379','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(336719,3917,'114387','watch-mobile','text','<p>Email:</p>',2,''),(336720,3920,'114390','watch-mobile','text','<p>Phone:</p>',2,''),(336721,3923,'114393','watch-mobile','text','<p>Web:</p>',2,''),(336722,3928,'114398','watch-mobile','text','<p>If undelivered please return to:</p>',2,''),(336723,3929,'114399','watch-mobile','text','<p>Thank you for your order</p>',2,''),(336725,3932,'114402','watch-mobile','text','<p>Phone:</p>',2,''),(336726,3935,'114405','watch-mobile','text','<p>Email:</p>',2,''),(336727,3937,'114407','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(336728,3956,'75618','watch-mobile','logo','themes/watch-mobile/img/watchlogo-1-1.png',2,''),(336729,3959,'75621','watch-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',2,''),(336730,3970,'114422','watch-mobile','logo','themes/watch-mobile/img/logo-white-1.png',2,''),(336731,3991,'75629','watch-mobile','text','Account',2,''),(336732,3996,'75635','watch-mobile','text','Shop',2,''),(336733,3998,'75637','watch-mobile','text','Products',2,''),(336734,4002,'75642','watch-mobile','text','Contact Us',2,''),(336735,4014,'75655','watch-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(336736,4017,'75658','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(336737,4018,'75659','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336738,4019,'75660','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(336739,4020,'75661','watch-mobile','text','<p>GIFT CARD</p>',2,''),(336740,4022,'75663','watch-mobile','text','<p>Your code is:</p>',2,''),(336741,4026,'75667','watch-mobile','text','<p>HOLBI</p>',2,''),(336742,4028,'75669','watch-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(336743,4031,'114448','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(336744,4032,'114449','watch-mobile','text','<p>GIFT CARD</p>',2,''),(336745,4033,'114450','watch-mobile','logo','themes/watch-mobile/img/logo-1.png',2,''),(336746,4034,'114451','watch-mobile','logo','themes/watch-mobile/img/bestseller-1.png',2,''),(336747,4035,'114452','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336748,4039,'114456','watch-mobile','text','<p>Your code is:</p>',2,''),(336749,4041,'114458','watch-mobile','text','<p>HOLBI</p>',2,''),(336750,4042,'114459','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(336751,4045,'114462','watch-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(336752,4048,'114465','watch-mobile','text','<p>HOLBI</p>',2,''),(336753,4049,'114466','watch-mobile','text','<p>GIFT CARD</p>',2,''),(336754,4050,'114467','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(336755,4052,'114469','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(336756,4053,'114470','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336757,4056,'114473','watch-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(336758,4059,'114476','watch-mobile','text','<p>Your code is:</p>',2,''),(336759,4071,'114488','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336760,4088,'114505','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336761,4100,'114517','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(336762,4101,'114518','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336763,4103,'114520','watch-mobile','text','<p>GIFT CARD</p>',2,''),(336764,4105,'114522','watch-mobile','text','<p>HOLBI</p>',2,''),(336765,4109,'114526','watch-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(336766,4110,'114527','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(336767,4112,'114529','watch-mobile','text','<p>Your code is:</p>',2,''),(336768,4123,'114540','watch-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(336769,4130,'75671','watch-mobile','logo','themes/watch-mobile/img/oscommerce_logo.png',2,''),(336770,4144,'75693','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(336771,4149,'75698','watch-mobile','logo','themes/watch-mobile/img/watchlogo-2-1.png',2,''),(336772,4151,'75700','watch-mobile','text','<p>Phone:</p>',2,''),(336773,4156,'75705','watch-mobile','text','<p>Web:</p>',2,''),(336774,4159,'75708','watch-mobile','text','<p>Email:</p>',2,''),(336775,4162,'75711','watch-mobile','text','<p>If undelivered please return to:</p>',2,''),(336776,4164,'75713','watch-mobile','text','<p>Thank you for your order</p>',2,''),(336778,4167,'75716','watch-mobile','text','<p>Email:</p>',2,''),(336779,4170,'75719','watch-mobile','text','<p>Phone:</p>',2,''),(336780,4172,'75721','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(336781,4176,'75725','watch-mobile','text','<p>Shipping via</p>',2,''),(336782,4180,'75729','watch-mobile','text','<p>Shipping service</p>',2,''),(336783,4183,'75732','watch-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(336784,4187,'75736','watch-mobile','text','<p>CUSTOMER:</p>',2,''),(336785,4189,'75738','watch-mobile','text','<p>PHONE NUMBER:</p>',2,''),(336786,4190,'75739','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(336787,4196,'75745','watch-mobile','text','<p>Payment date:</p>',2,''),(336788,4197,'75746','watch-mobile','text','<p>Payment Method:</p>',2,''),(336789,4199,'94803','watch-mobile','tab_1','RETURNING CUSTOMER',2,''),(336790,4199,'94803','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(336791,4221,'114562','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(336792,4221,'114562','watch-mobile','tab_2','RETURNING CUSTOMER',2,''),(336793,4221,'114562','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(336794,4237,'114578','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(336795,4237,'114578','watch-mobile','tab_2','RETURNING CUSTOMER',2,''),(336796,4237,'114578','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(336797,4250,'114591','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(336798,4250,'114591','watch-mobile','tab_2','RETURNING CUSTOMER',2,''),(336799,4250,'114591','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(336800,4291,'75750','watch-mobile','tab_1','New products',2,''),(336801,4291,'75750','watch-mobile','tab_2','Specials products',2,''),(336802,4291,'75750','watch-mobile','tab_3','Featured',2,''),(336803,4324,'114653','watch-mobile','tab_1','RETURNING CUSTOMER',2,''),(336804,4324,'114653','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(336805,4446,'75764','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(336806,4452,'75770','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(336807,4453,'75771','watch-mobile','text','<p>CUSTOMER:</p>',2,''),(336808,4454,'75772','watch-mobile','text','<p>PHONE NUMBER:</p>',2,''),(336809,4458,'75776','watch-mobile','text','<p>Shipping via</p>',2,''),(336810,4460,'75778','watch-mobile','text','<p>Shipping service</p>',2,''),(336811,4464,'75782','watch-mobile','text','<p>If undelivered please return to:</p>',2,''),(336812,4467,'75785','watch-mobile','logo','themes/watch-mobile/img/watchlogo-3.png',2,''),(336813,4471,'75789','watch-mobile','text','<p>Phone:</p>',2,''),(336814,4474,'75792','watch-mobile','text','<p>Web:</p>',2,''),(336815,4477,'75795','watch-mobile','text','<p>Email:</p>',2,''),(336817,4504,'75817','watch-mobile','text','osCommerce 4',2,''),(336818,4539,'75840','watch-mobile','tab_1','Description',2,''),(336819,4539,'75840','watch-mobile','tab_2','Reviews',2,''),(336820,4584,'114794','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(336821,4589,'114799','watch-mobile','text','<p>ADDRESS:</p>\n',2,''),(336822,4592,'114802','watch-mobile','text','<p>CUSTOMER:</p>',2,''),(336823,4593,'114803','watch-mobile','text','<p>PHONE NUMBER:</p>',2,''),(336824,4594,'114804','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(336825,4598,'114808','watch-mobile','text','<p>Order date:</p>\n',2,''),(336827,4606,'114816','watch-mobile','text','<p>Email:</p>',2,''),(336828,4609,'114819','watch-mobile','text','<p>Web:</p>',2,''),(336829,4612,'114822','watch-mobile','text','<p>Phone:</p>',2,''),(336830,4616,'114826','watch-mobile','text','<p>If undelivered please return to:</p>',2,''),(336831,4617,'114827','watch-mobile','text','<p>Thank you for your order</p>',2,''),(336833,4620,'114830','watch-mobile','text','<p>Phone:</p>',2,''),(336834,4622,'114832','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(336835,4624,'114834','watch-mobile','text','<p>Email:</p>',2,''),(336836,4664,'75868','watch-mobile','text','<h1>Quotations</h1>',2,''),(336837,4781,'114988','watch-mobile','logo','themes/watch-mobile/img/Furntech-1.jpg',2,''),(336838,4805,'75872','watch-mobile','text','<h1>Samples</h1>',2,''),(336839,4891,'75875','watch-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',2,''),(336840,4910,'115079','watch-mobile','text','<p>Phone:</p>',2,''),(336841,4913,'115082','watch-mobile','text','<p>Web:</p>',2,''),(336842,4916,'115085','watch-mobile','text','<p>Email:</p>',2,''),(336843,4921,'115090','watch-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(336844,4924,'115093','watch-mobile','text','<p>PHONE NUMBER:</p>',2,''),(336845,4925,'115094','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(336846,4926,'115095','watch-mobile','text','<p>CUSTOMER:</p>',2,''),(336847,4932,'115101','watch-mobile','text','<p>Shipping via</p>',2,''),(336848,4936,'115105','watch-mobile','text','<p>Shipping service</p>',2,''),(336849,4937,'115106','watch-mobile','text','<p>Payment date:</p>',2,''),(336850,4939,'115108','watch-mobile','text','<p>Payment Method:</p>',2,''),(336851,4944,'115113','watch-mobile','text','<p>If undelivered please return to:</p>',2,''),(336853,4947,'115116','watch-mobile','text','<p>Thank you for your order</p>',2,''),(336854,4949,'115118','watch-mobile','text','<p>Phone:</p>',2,''),(336855,4951,'115120','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(336856,4953,'115122','watch-mobile','text','<p>Email:</p>',2,''),(336857,4959,'115128','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(336986,13141,'118691','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',2,''),(336987,13172,'118722','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',2,''),(336988,13877,'119427','printshop-mobile','text','<p>Shipping via</p>',2,''),(336989,13881,'119431','printshop-mobile','text','<p>Shipping service</p>',2,''),(336990,13885,'119435','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(336991,13887,'119437','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(336992,13890,'119440','printshop-mobile','text','<p>PHONE NUMBER:</p>',2,''),(336993,13891,'119441','printshop-mobile','text','<p>CUSTOMER:</p>',2,''),(336994,13894,'119444','printshop-mobile','text','<p>Payment date:</p>',2,''),(336995,13898,'119448','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(336997,13906,'119456','printshop-mobile','text','<p>Email:</p>',2,''),(336998,13909,'119459','printshop-mobile','text','<p>Phone:</p>',2,''),(336999,13912,'119462','printshop-mobile','text','<p>Web:</p>',2,''),(337000,13917,'119467','printshop-mobile','text','<p>If undelivered please return to:</p>',2,''),(337001,13918,'119468','printshop-mobile','text','<p>Thank you for your order</p>',2,''),(337003,13921,'119471','printshop-mobile','text','<p>Phone:</p>',2,''),(337004,13924,'119474','printshop-mobile','text','<p>Email:</p>',2,''),(337005,13926,'119476','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337006,13948,'119498','printshop-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',2,''),(337007,13959,'119509','printshop-mobile','logo','themes/printshop-mobile/img/logo-white-1.png',2,''),(337008,13980,'119530','printshop-mobile','text','Account',2,''),(337009,13985,'119535','printshop-mobile','text','Account',2,''),(337010,13987,'119537','printshop-mobile','text','Account',2,''),(337011,13991,'119541','printshop-mobile','text','Account',2,''),(337012,14003,'119553','printshop-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337013,14006,'119556','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337014,14007,'119557','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337015,14008,'119558','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(337016,14009,'119559','printshop-mobile','text','<p>GIFT CARD</p>',2,''),(337017,14011,'119561','printshop-mobile','text','<p>Your code is:</p>',2,''),(337018,14015,'119565','printshop-mobile','text','<p>HOLBI</p>',2,''),(337019,14017,'119567','printshop-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(337020,14020,'119570','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(337021,14021,'119571','printshop-mobile','text','<p>GIFT CARD</p>',2,''),(337022,14022,'119572','printshop-mobile','logo','themes/printshop-mobile/img/logo-1.png',2,''),(337023,14023,'119573','printshop-mobile','logo','themes/printshop-mobile/img/bestseller-1.png',2,''),(337024,14024,'119574','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337025,14028,'119578','printshop-mobile','text','<p>Your code is:</p>',2,''),(337026,14030,'119580','printshop-mobile','text','<p>HOLBI</p>',2,''),(337027,14031,'119581','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337028,14034,'119584','printshop-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337029,14037,'119587','printshop-mobile','text','<p>HOLBI</p>',2,''),(337030,14038,'119588','printshop-mobile','text','<p>GIFT CARD</p>',2,''),(337031,14039,'119589','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337032,14041,'119591','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(337033,14042,'119592','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337034,14045,'119595','printshop-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337035,14048,'119598','printshop-mobile','text','<p>Your code is:</p>',2,''),(337036,14060,'119610','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337037,14077,'119627','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337038,14089,'119639','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(337039,14090,'119640','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337040,14092,'119642','printshop-mobile','text','<p>GIFT CARD</p>',2,''),(337041,14094,'119644','printshop-mobile','text','<p>HOLBI</p>',2,''),(337042,14098,'119648','printshop-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337043,14099,'119649','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337044,14101,'119651','printshop-mobile','text','<p>Your code is:</p>',2,''),(337045,14112,'119662','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337046,14119,'119669','printshop-mobile','logo','themes/printshop-mobile/img/oscommerce_logo.png',2,''),(337047,14122,'119672','printshop-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',2,''),(337048,14124,'119674','printshop-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',2,''),(337049,14125,'119675','printshop-mobile','logo','themes/printshop-mobile/img/check-2.png',2,''),(337050,14141,'119691','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337052,14148,'119698','printshop-mobile','text','<p>Phone:</p>',2,''),(337053,14153,'119703','printshop-mobile','text','<p>Web:</p>',2,''),(337054,14156,'119706','printshop-mobile','text','<p>Email:</p>',2,''),(337055,14159,'119709','printshop-mobile','text','<p>If undelivered please return to:</p>',2,''),(337056,14161,'119711','printshop-mobile','text','<p>Thank you for your order</p>',2,''),(337058,14164,'119714','printshop-mobile','text','<p>Email:</p>',2,''),(337059,14167,'119717','printshop-mobile','text','<p>Phone:</p>',2,''),(337060,14169,'119719','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337061,14173,'119723','printshop-mobile','text','<p>Shipping via</p>',2,''),(337062,14177,'119727','printshop-mobile','text','<p>Shipping service</p>',2,''),(337063,14180,'119730','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337064,14184,'119734','printshop-mobile','text','<p>CUSTOMER:</p>',2,''),(337065,14186,'119736','printshop-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337066,14187,'119737','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337067,14193,'119743','printshop-mobile','text','<p>Payment date:</p>',2,''),(337068,14194,'119744','printshop-mobile','text','<p>Payment Method:</p>',2,''),(337069,14196,'119746','printshop-mobile','tab_1','RETURNING CUSTOMER',2,''),(337070,14196,'119746','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(337071,14218,'119768','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337072,14218,'119768','printshop-mobile','tab_2','RETURNING CUSTOMER',2,''),(337073,14218,'119768','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337074,14234,'119784','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337075,14234,'119784','printshop-mobile','tab_2','RETURNING CUSTOMER',2,''),(337076,14234,'119784','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337077,14247,'119797','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337078,14247,'119797','printshop-mobile','tab_2','RETURNING CUSTOMER',2,''),(337079,14247,'119797','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337080,14288,'119838','printshop-mobile','tab_1','New products',2,''),(337081,14288,'119838','printshop-mobile','tab_2','Specials products',2,''),(337082,14288,'119838','printshop-mobile','tab_3','Featured',2,''),(337083,14321,'119871','printshop-mobile','tab_1','RETURNING CUSTOMER',2,''),(337084,14321,'119871','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(337085,14443,'119993','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337086,14449,'119999','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337087,14450,'120000','printshop-mobile','text','<p>CUSTOMER:</p>',2,''),(337088,14451,'120001','printshop-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337089,14455,'120005','printshop-mobile','text','<p>Shipping via</p>',2,''),(337090,14457,'120007','printshop-mobile','text','<p>Shipping service</p>',2,''),(337091,14461,'120011','printshop-mobile','text','<p>If undelivered please return to:</p>',2,''),(337093,14468,'120018','printshop-mobile','text','<p>Phone:</p>',2,''),(337094,14471,'120021','printshop-mobile','text','<p>Web:</p>',2,''),(337095,14474,'120024','printshop-mobile','text','<p>Email:</p>',2,''),(337097,14501,'120051','printshop-mobile','text','osCommerce 4',2,''),(337098,14536,'120086','printshop-mobile','tab_1','Description',2,''),(337099,14536,'120086','printshop-mobile','tab_2','Reviews',2,''),(337100,14581,'120131','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337101,14586,'120136','printshop-mobile','text','<p>ADDRESS:</p>\n',2,''),(337102,14589,'120139','printshop-mobile','text','<p>CUSTOMER:</p>',2,''),(337103,14590,'120140','printshop-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337104,14591,'120141','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337105,14595,'120145','printshop-mobile','text','<p>Order date:</p>\n',2,''),(337107,14603,'120153','printshop-mobile','text','<p>Email:</p>',2,''),(337108,14606,'120156','printshop-mobile','text','<p>Web:</p>',2,''),(337109,14609,'120159','printshop-mobile','text','<p>Phone:</p>',2,''),(337110,14613,'120163','printshop-mobile','text','<p>If undelivered please return to:</p>',2,''),(337111,14614,'120164','printshop-mobile','text','<p>Thank you for your order</p>',2,''),(337113,14617,'120167','printshop-mobile','text','<p>Phone:</p>',2,''),(337114,14619,'120169','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337115,14621,'120171','printshop-mobile','text','<p>Email:</p>',2,''),(337116,14661,'120211','printshop-mobile','text','<h1>Quotations</h1>',2,''),(337117,14778,'120328','printshop-mobile','logo','themes/printshop-mobile/img/Furntech-1.jpg',2,''),(337118,14802,'120352','printshop-mobile','text','<h1>Samples</h1>',2,''),(337119,14888,'120438','printshop-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',2,''),(337120,14907,'120457','printshop-mobile','text','<p>Phone:</p>',2,''),(337121,14910,'120460','printshop-mobile','text','<p>Web:</p>',2,''),(337122,14913,'120463','printshop-mobile','text','<p>Email:</p>',2,''),(337123,14918,'120468','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337124,14921,'120471','printshop-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337125,14922,'120472','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337126,14923,'120473','printshop-mobile','text','<p>CUSTOMER:</p>',2,''),(337127,14929,'120479','printshop-mobile','text','<p>Shipping via</p>',2,''),(337128,14933,'120483','printshop-mobile','text','<p>Shipping service</p>',2,''),(337129,14934,'120484','printshop-mobile','text','<p>Payment date:</p>',2,''),(337130,14936,'120486','printshop-mobile','text','<p>Payment Method:</p>',2,''),(337131,14941,'120491','printshop-mobile','text','<p>If undelivered please return to:</p>',2,''),(337133,14944,'120494','printshop-mobile','text','<p>Thank you for your order</p>',2,''),(337134,14946,'120496','printshop-mobile','text','<p>Phone:</p>',2,''),(337135,14948,'120498','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337136,14950,'120500','printshop-mobile','text','<p>Email:</p>',2,''),(337137,14956,'120506','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337262,18022,'118691','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',2,''),(337263,18053,'118722','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',2,''),(337264,18758,'119427','deals-mobile','text','<p>Shipping via</p>',2,''),(337265,18762,'119431','deals-mobile','text','<p>Shipping service</p>',2,''),(337266,18766,'119435','deals-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337267,18768,'119437','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337268,18771,'119440','deals-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337269,18772,'119441','deals-mobile','text','<p>CUSTOMER:</p>',2,''),(337270,18775,'119444','deals-mobile','text','<p>Payment date:</p>',2,''),(337271,18779,'119448','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337273,18787,'119456','deals-mobile','text','<p>Email:</p>',2,''),(337274,18790,'119459','deals-mobile','text','<p>Phone:</p>',2,''),(337275,18793,'119462','deals-mobile','text','<p>Web:</p>',2,''),(337276,18798,'119467','deals-mobile','text','<p>If undelivered please return to:</p>',2,''),(337277,18799,'119468','deals-mobile','text','<p>Thank you for your order</p>',2,''),(337279,18802,'119471','deals-mobile','text','<p>Phone:</p>',2,''),(337280,18805,'119474','deals-mobile','text','<p>Email:</p>',2,''),(337281,18807,'119476','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337282,18829,'119498','deals-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',2,''),(337283,18840,'119509','deals-mobile','logo','themes/deals-mobile/img/logo-white-1.png',2,''),(337284,18861,'119530','deals-mobile','text','Account',2,''),(337285,18866,'119535','deals-mobile','text','Account',2,''),(337286,18868,'119537','deals-mobile','text','Account',2,''),(337287,18872,'119541','deals-mobile','text','Account',2,''),(337288,18884,'119553','deals-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337289,18887,'119556','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337290,18888,'119557','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337291,18889,'119558','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(337292,18890,'119559','deals-mobile','text','<p>GIFT CARD</p>',2,''),(337293,18892,'119561','deals-mobile','text','<p>Your code is:</p>',2,''),(337294,18896,'119565','deals-mobile','text','<p>HOLBI</p>',2,''),(337295,18898,'119567','deals-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(337296,18901,'119570','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(337297,18902,'119571','deals-mobile','text','<p>GIFT CARD</p>',2,''),(337298,18903,'119572','deals-mobile','logo','themes/deals-mobile/img/logo-1.png',2,''),(337299,18904,'119573','deals-mobile','logo','themes/deals-mobile/img/bestseller-1.png',2,''),(337300,18905,'119574','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337301,18909,'119578','deals-mobile','text','<p>Your code is:</p>',2,''),(337302,18911,'119580','deals-mobile','text','<p>HOLBI</p>',2,''),(337303,18912,'119581','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337304,18915,'119584','deals-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337305,18918,'119587','deals-mobile','text','<p>HOLBI</p>',2,''),(337306,18919,'119588','deals-mobile','text','<p>GIFT CARD</p>',2,''),(337307,18920,'119589','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337308,18922,'119591','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(337309,18923,'119592','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337310,18926,'119595','deals-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337311,18929,'119598','deals-mobile','text','<p>Your code is:</p>',2,''),(337312,18941,'119610','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337313,18958,'119627','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337314,18970,'119639','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',2,''),(337315,18971,'119640','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337316,18973,'119642','deals-mobile','text','<p>GIFT CARD</p>',2,''),(337317,18975,'119644','deals-mobile','text','<p>HOLBI</p>',2,''),(337318,18979,'119648','deals-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337319,18980,'119649','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337320,18982,'119651','deals-mobile','text','<p>Your code is:</p>',2,''),(337321,18993,'119662','deals-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337322,19000,'119669','deals-mobile','logo','themes/deals-mobile/img/oscommerce_logo.png',2,''),(337323,19003,'119672','deals-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',2,''),(337324,19005,'119674','deals-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',2,''),(337325,19006,'119675','deals-mobile','logo','themes/deals-mobile/img/check-2.png',2,''),(337326,19022,'119691','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337328,19029,'119698','deals-mobile','text','<p>Phone:</p>',2,''),(337329,19034,'119703','deals-mobile','text','<p>Web:</p>',2,''),(337330,19037,'119706','deals-mobile','text','<p>Email:</p>',2,''),(337331,19040,'119709','deals-mobile','text','<p>If undelivered please return to:</p>',2,''),(337332,19042,'119711','deals-mobile','text','<p>Thank you for your order</p>',2,''),(337334,19045,'119714','deals-mobile','text','<p>Email:</p>',2,''),(337335,19048,'119717','deals-mobile','text','<p>Phone:</p>',2,''),(337336,19050,'119719','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337337,19054,'119723','deals-mobile','text','<p>Shipping via</p>',2,''),(337338,19058,'119727','deals-mobile','text','<p>Shipping service</p>',2,''),(337339,19061,'119730','deals-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337340,19065,'119734','deals-mobile','text','<p>CUSTOMER:</p>',2,''),(337341,19067,'119736','deals-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337342,19068,'119737','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337343,19074,'119743','deals-mobile','text','<p>Payment date:</p>',2,''),(337344,19075,'119744','deals-mobile','text','<p>Payment Method:</p>',2,''),(337345,19077,'119746','deals-mobile','tab_1','RETURNING CUSTOMER',2,''),(337346,19077,'119746','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(337347,19099,'119768','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337348,19099,'119768','deals-mobile','tab_2','RETURNING CUSTOMER',2,''),(337349,19099,'119768','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337350,19115,'119784','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337351,19115,'119784','deals-mobile','tab_2','RETURNING CUSTOMER',2,''),(337352,19115,'119784','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337353,19128,'119797','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337354,19128,'119797','deals-mobile','tab_2','RETURNING CUSTOMER',2,''),(337355,19128,'119797','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337356,19169,'119838','deals-mobile','tab_1','New products',2,''),(337357,19169,'119838','deals-mobile','tab_2','Specials products',2,''),(337358,19169,'119838','deals-mobile','tab_3','Featured',2,''),(337359,19202,'119871','deals-mobile','tab_1','RETURNING CUSTOMER',2,''),(337360,19202,'119871','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(337361,19324,'119993','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337362,19330,'119999','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337363,19331,'120000','deals-mobile','text','<p>CUSTOMER:</p>',2,''),(337364,19332,'120001','deals-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337365,19336,'120005','deals-mobile','text','<p>Shipping via</p>',2,''),(337366,19338,'120007','deals-mobile','text','<p>Shipping service</p>',2,''),(337367,19342,'120011','deals-mobile','text','<p>If undelivered please return to:</p>',2,''),(337369,19349,'120018','deals-mobile','text','<p>Phone:</p>',2,''),(337370,19352,'120021','deals-mobile','text','<p>Web:</p>',2,''),(337371,19355,'120024','deals-mobile','text','<p>Email:</p>',2,''),(337373,19382,'120051','deals-mobile','text','osCommerce 4',2,''),(337374,19417,'120086','deals-mobile','tab_1','Description',2,''),(337375,19417,'120086','deals-mobile','tab_2','Reviews',2,''),(337376,19462,'120131','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337377,19467,'120136','deals-mobile','text','<p>ADDRESS:</p>\n',2,''),(337378,19470,'120139','deals-mobile','text','<p>CUSTOMER:</p>',2,''),(337379,19471,'120140','deals-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337380,19472,'120141','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337381,19476,'120145','deals-mobile','text','<p>Order date:</p>\n',2,''),(337383,19484,'120153','deals-mobile','text','<p>Email:</p>',2,''),(337384,19487,'120156','deals-mobile','text','<p>Web:</p>',2,''),(337385,19490,'120159','deals-mobile','text','<p>Phone:</p>',2,''),(337386,19494,'120163','deals-mobile','text','<p>If undelivered please return to:</p>',2,''),(337387,19495,'120164','deals-mobile','text','<p>Thank you for your order</p>',2,''),(337389,19498,'120167','deals-mobile','text','<p>Phone:</p>',2,''),(337390,19500,'120169','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337391,19502,'120171','deals-mobile','text','<p>Email:</p>',2,''),(337392,19542,'120211','deals-mobile','text','<h1>Quotations</h1>',2,''),(337393,19659,'120328','deals-mobile','logo','themes/deals-mobile/img/Furntech-1.jpg',2,''),(337394,19683,'120352','deals-mobile','text','<h1>Samples</h1>',2,''),(337395,19769,'120438','deals-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',2,''),(337396,19788,'120457','deals-mobile','text','<p>Phone:</p>',2,''),(337397,19791,'120460','deals-mobile','text','<p>Web:</p>',2,''),(337398,19794,'120463','deals-mobile','text','<p>Email:</p>',2,''),(337399,19799,'120468','deals-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337400,19802,'120471','deals-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337401,19803,'120472','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337402,19804,'120473','deals-mobile','text','<p>CUSTOMER:</p>',2,''),(337403,19810,'120479','deals-mobile','text','<p>Shipping via</p>',2,''),(337404,19814,'120483','deals-mobile','text','<p>Shipping service</p>',2,''),(337405,19815,'120484','deals-mobile','text','<p>Payment date:</p>',2,''),(337406,19817,'120486','deals-mobile','text','<p>Payment Method:</p>',2,''),(337407,19822,'120491','deals-mobile','text','<p>If undelivered please return to:</p>',2,''),(337409,19825,'120494','deals-mobile','text','<p>Thank you for your order</p>',2,''),(337410,19827,'120496','deals-mobile','text','<p>Phone:</p>',2,''),(337411,19829,'120498','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337412,19831,'120500','deals-mobile','text','<p>Email:</p>',2,''),(337413,19837,'120506','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337546,54257,'116269','furniture-mobile','logo','themes/furniture-mobile/img/payicons-1.png',2,''),(337547,55017,'116977','furniture-mobile','text','<p>If undelivered please return to:</p>',2,''),(337548,55018,'116978','furniture-mobile','text','<p>Thank you for your order</p>',2,''),(337550,55020,'116980','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337551,55022,'116982','furniture-mobile','text','<p>Email:</p>',2,''),(337552,55025,'116985','furniture-mobile','text','<p>Phone:</p>',2,''),(337554,55031,'116991','furniture-mobile','text','<p>Web:</p>',2,''),(337555,55034,'116994','furniture-mobile','text','<p>Phone:</p>',2,''),(337556,55037,'116997','furniture-mobile','text','<p>Email:</p>',2,''),(337557,55044,'117004','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337558,55049,'117009','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337559,55053,'117013','furniture-mobile','text','<p>CUSTOMER:</p>',2,''),(337560,55054,'117014','furniture-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337561,55057,'117017','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337562,55061,'117021','furniture-mobile','text','<p>Shipping via</p>',2,''),(337563,55063,'117023','furniture-mobile','text','<p>Shipping service</p>',2,''),(337564,55066,'117026','furniture-mobile','text','<p>Payment date:</p>',2,''),(337565,55101,'117055','furniture-mobile','logo','themes/furniture-mobile/img/logo-white-1.png',2,''),(337566,55150,'117107','furniture-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(337567,55155,'117112','furniture-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337568,55157,'117114','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337569,55158,'117115','furniture-mobile','text','<p>osCommerce</p>\n',2,''),(337570,55160,'117117','furniture-mobile','text','<p>Your code is:</p>',2,''),(337571,55164,'117121','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337572,55165,'117123','furniture-mobile','logo','themes/furniture-mobile/img/Logo-1.jpg',2,''),(337573,55166,'117124','furniture-mobile','text','<p>GIFT CARD</p>',2,''),(337574,55167,'117125','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(337575,55171,'117129','furniture-mobile','text','<p>Your code is:</p>',2,''),(337576,55175,'117133','furniture-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337577,55178,'117136','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337578,55179,'117137','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(337579,55180,'117138','furniture-mobile','text','<p>GIFT CARD</p>',2,''),(337580,55181,'117139','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337581,55192,'117150','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337582,55209,'117167','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337583,55221,'117180','furniture-mobile','text','<p>Your code is:</p>',2,''),(337584,55223,'117182','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',2,''),(337585,55225,'117185','furniture-mobile','text','<p>If you require further assistance please contact us</p>',2,''),(337586,55229,'117189','furniture-mobile','text','<p>GIFT CARD</p>',2,''),(337587,55230,'117190','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337588,55232,'117192','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(337589,55243,'117202','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',2,''),(337591,55258,'117218','furniture-mobile','logo','themes/furniture-mobile/img/header-img-1.png',2,''),(337592,55279,'117234','furniture-mobile','text','<p>Shipping via</p>',2,''),(337593,55281,'117236','furniture-mobile','text','<p>Shipping service</p>',2,''),(337594,55285,'117240','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337595,55289,'117243','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337596,55292,'117246','furniture-mobile','text','<p>CUSTOMER:</p>',2,''),(337597,55293,'117247','furniture-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337598,55296,'117250','furniture-mobile','text','<p>Payment Method:</p>',2,''),(337599,55297,'117251','furniture-mobile','text','<p>Payment date:</p>',2,''),(337600,55303,'117257','furniture-mobile','text','<p>If undelivered please return to:</p>',2,''),(337601,55304,'117258','furniture-mobile','text','<p>Thank you for your order</p>',2,''),(337602,55306,'117261','furniture-mobile','text','<p>Email:</p>',2,''),(337603,55309,'117264','furniture-mobile','text','<p>Phone:</p>',2,''),(337604,55311,'117266','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337605,55316,'117271','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337606,55320,'117275','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',2,''),(337607,55322,'117277','furniture-mobile','text','<p>Web:</p>',2,''),(337608,55325,'117280','furniture-mobile','text','<p>Email:</p>',2,''),(337609,55330,'117285','furniture-mobile','text','<p>Phone:</p>',2,''),(337610,55337,'117288','furniture-mobile','tab_1','RETURNING CUSTOMER',2,''),(337611,55337,'117288','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(337612,55360,'117311','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337613,55360,'117311','furniture-mobile','tab_2','RETURNING CUSTOMER',2,''),(337614,55360,'117311','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337615,55376,'117327','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337616,55376,'117327','furniture-mobile','tab_2','RETURNING CUSTOMER',2,''),(337617,55376,'117327','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337618,55393,'117344','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(337619,55393,'117344','furniture-mobile','tab_2','RETURNING CUSTOMER',2,''),(337620,55393,'117344','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(337621,55486,'117416','furniture-mobile','tab_1','RETURNING CUSTOMER',2,''),(337622,55486,'117416','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(337623,55663,'117536','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',2,''),(337624,55665,'117538','furniture-mobile','text','<p>Email:</p>',2,''),(337625,55668,'117541','furniture-mobile','text','<p>Phone:</p>',2,''),(337626,55673,'117546','furniture-mobile','text','<p>Web:</p>',2,''),(337627,55678,'117551','furniture-mobile','text','<p>If undelivered please return to:</p>',2,''),(337628,55683,'117556','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337629,55685,'117558','furniture-mobile','text','<p>CUSTOMER:</p>',2,''),(337630,55688,'117561','furniture-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337631,55690,'117563','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337632,55694,'117567','furniture-mobile','text','<p>Shipping via</p>',2,''),(337633,55697,'117570','furniture-mobile','text','<p>Shipping service</p>',2,''),(337634,55726,'117596','furniture-mobile','logo','themes/furniture-mobile/img/oscommerce_logo-1.jpg',2,''),(337635,55727,'117597','furniture-mobile','text','osCommerce 4',2,''),(337636,55764,'117646','furniture-mobile','tab_1','Product Overview',2,''),(337637,55764,'117646','furniture-mobile','tab_2','Delivery and returns',2,''),(337638,55764,'117646','furniture-mobile','tab_3','Assembly',2,''),(337639,55882,'117702','furniture-mobile','text','<p>If undelivered please return to:</p>',2,''),(337640,55884,'117704','furniture-mobile','text','<p>Thank you for your order</p>',2,''),(337642,55887,'117707','furniture-mobile','text','<p>Email:</p>',2,''),(337643,55889,'117709','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337644,55891,'117711','furniture-mobile','text','<p>Phone:</p>',2,''),(337646,55896,'117716','furniture-mobile','text','<p>Phone:</p>',2,''),(337647,55899,'117719','furniture-mobile','text','<p>Web:</p>',2,''),(337648,55904,'117724','furniture-mobile','text','<p>Email:</p>',2,''),(337649,55910,'117730','furniture-mobile','text','<p>ADDRESS:</p>\n',2,''),(337650,55913,'117733','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337651,55916,'117736','furniture-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337652,55917,'117737','furniture-mobile','text','<p>CUSTOMER:</p>',2,''),(337653,55919,'117739','furniture-mobile','text','<p>Order date:</p>\n',2,''),(337654,55924,'117744','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337655,56056,'117816','furniture-mobile','logo','themes/furniture-mobile/img/Furntech-1.jpg',2,''),(337656,56314,'118011','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',2,''),(337657,56318,'118015','furniture-mobile','text','<p>If undelivered please return to:</p>',2,''),(337658,56320,'118018','furniture-mobile','text','<p>Thank you for your order</p>',2,''),(337659,56321,'118019','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',2,''),(337660,56323,'118021','furniture-mobile','text','<p>Email:</p>',2,''),(337661,56326,'118024','furniture-mobile','text','<p>Phone:</p>',2,''),(337662,56331,'118029','furniture-mobile','text','<p>Email:</p>',2,''),(337663,56334,'118032','furniture-mobile','text','<p>Web:</p>',2,''),(337664,56339,'118037','furniture-mobile','text','<p>Phone:</p>',2,''),(337665,56344,'118042','furniture-mobile','text','<p>Shipping via</p>',2,''),(337666,56347,'118045','furniture-mobile','text','<p>Shipping service</p>',2,''),(337667,56352,'118050','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',2,''),(337668,56355,'118053','furniture-mobile','text','<p>PHONE NUMBER:</p>',2,''),(337669,56358,'118056','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',2,''),(337670,56359,'118057','furniture-mobile','text','<p>CUSTOMER:</p>',2,''),(337671,56361,'118059','furniture-mobile','text','<p>Payment date:</p>',2,''),(337672,56362,'118060','furniture-mobile','text','<p>Payment Method:</p>',2,''),(337937,108868,'117051','splash','logo','themes/splash/img/oscommerce_logo_(2)-1.png',2,''),(337938,108918,'1661353032.672459','splash','logo','themes/splash/img/oscommerce_logo.jpg',2,''),(337939,108933,'1640168618.7708','splash','logo','themes/splash/img/oscommerce_logo (2).png',2,''),(337940,108936,'1640169872.1589','splash','img_link','furniture/',2,''),(337941,108936,'1640169872.1589','splash','logo','themes/splash/img/Splash_furniture_BGlogo.png',2,''),(337942,108936,'1640169872.1589','splash','target_blank','1',2,''),(337943,108937,'1640276640.1123','splash','text','<h1>osCommerce v4 Splash page</h1>\r\n\r\n<p>osCommerce supports multiple sales CHANNELS.</p>\r\n\r\n<p>Your installation of osCommerce comes with &nbsp;&quot;Furniture&quot;, &quot;Watch&quot;, &quot;B2B Supermarket&quot;, and &quot;Print shop&quot; Ecommerce sales channels and &quot;cms&quot; brochure website example.</p>\r\n\r\n<p>Each sales channel has its own URLs, design, and demo product sets.</p>\r\n\r\n<p>&quot;Admin&quot; is the back end of your osCommerce.</p>\r\n\r\n<p>Use osCommerce Wiki to learn how to manage sales channels, &nbsp;assign design themes, and content to the sales channels.<br />\r\nThank you for choosing &nbsp;osCommerce - the most powerful on-premise open source Ecommerce platform!</p>\r\n',2,''),(337944,108938,'1640170154.7803','splash','img_link','watch/',2,''),(337945,108938,'1640170154.7803','splash','logo','themes/splash/img/Splash_watch_BGlogo.png',2,''),(337946,108938,'1640170154.7803','splash','target_blank','1',2,''),(337947,108940,'1640170023.0001','splash','img_link','printshop/',2,''),(337948,108940,'1640170023.0001','splash','logo','themes/splash/img/print shop.jpg',2,''),(337949,108940,'1640170023.0001','splash','target_blank','1',2,''),(337950,108941,'1640170023.1491','splash','img_link','admin/',2,''),(337951,108941,'1640170023.1491','splash','logo','themes/splash/img/Splash_admin_BGlogo.png',2,''),(337952,108941,'1640170023.1491','splash','target_blank','1',2,''),(337953,108942,'1640170023','splash','img_link','b2b-supermarket/',2,''),(337954,108942,'1640170023','splash','logo','themes/splash/img/b2b supermarket.jpg',2,''),(337955,108942,'1640170023','splash','target_blank','1',2,''),(337956,108945,'1661353032.975845','splash','logo','themes/splash/img/oscommerce_logo-1.jpg',2,''),(337957,109001,'74702','splash','logo','themes/splash/img/oscommerce_logo.jpg',2,''),(337958,109002,'74703','splash','text','osCommerce 4',2,''),(338090,3158,'115992','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',3,''),(338091,3189,'113675','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',3,''),(338092,3888,'114358','watch-mobile','text','<p>Shipping via</p>',3,''),(338093,3892,'114362','watch-mobile','text','<p>Shipping service</p>',3,''),(338094,3896,'114366','watch-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338095,3898,'114368','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338096,3901,'114371','watch-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338097,3902,'114372','watch-mobile','text','<p>CUSTOMER:</p>',3,''),(338098,3905,'114375','watch-mobile','text','<p>Payment date:</p>',3,''),(338099,3909,'114379','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338101,3917,'114387','watch-mobile','text','<p>Email:</p>',3,''),(338102,3920,'114390','watch-mobile','text','<p>Phone:</p>',3,''),(338103,3923,'114393','watch-mobile','text','<p>Web:</p>',3,''),(338104,3928,'114398','watch-mobile','text','<p>If undelivered please return to:</p>',3,''),(338105,3929,'114399','watch-mobile','text','<p>Thank you for your order</p>',3,''),(338107,3932,'114402','watch-mobile','text','<p>Phone:</p>',3,''),(338108,3935,'114405','watch-mobile','text','<p>Email:</p>',3,''),(338109,3937,'114407','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338110,3956,'75618','watch-mobile','logo','themes/watch-mobile/img/watchlogo-1-1.png',3,''),(338111,3959,'75621','watch-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',3,''),(338112,3970,'114422','watch-mobile','logo','themes/watch-mobile/img/logo-white-1.png',3,''),(338113,3991,'75629','watch-mobile','text','Account',3,''),(338114,3996,'75635','watch-mobile','text','Shop',3,''),(338115,3998,'75637','watch-mobile','text','Products',3,''),(338116,4002,'75642','watch-mobile','text','Contact Us',3,''),(338117,4014,'75655','watch-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338118,4017,'75658','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338119,4018,'75659','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338120,4019,'75660','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(338121,4020,'75661','watch-mobile','text','<p>GIFT CARD</p>',3,''),(338122,4022,'75663','watch-mobile','text','<p>Your code is:</p>',3,''),(338123,4026,'75667','watch-mobile','text','<p>HOLBI</p>',3,''),(338124,4028,'75669','watch-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(338125,4031,'114448','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338126,4032,'114449','watch-mobile','text','<p>GIFT CARD</p>',3,''),(338127,4033,'114450','watch-mobile','logo','themes/watch-mobile/img/logo-1.png',3,''),(338128,4034,'114451','watch-mobile','logo','themes/watch-mobile/img/bestseller-1.png',3,''),(338129,4035,'114452','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338130,4039,'114456','watch-mobile','text','<p>Your code is:</p>',3,''),(338131,4041,'114458','watch-mobile','text','<p>HOLBI</p>',3,''),(338132,4042,'114459','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338133,4045,'114462','watch-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338134,4048,'114465','watch-mobile','text','<p>HOLBI</p>',3,''),(338135,4049,'114466','watch-mobile','text','<p>GIFT CARD</p>',3,''),(338136,4050,'114467','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338137,4052,'114469','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338138,4053,'114470','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338139,4056,'114473','watch-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338140,4059,'114476','watch-mobile','text','<p>Your code is:</p>',3,''),(338141,4071,'114488','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338142,4088,'114505','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338143,4100,'114517','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338144,4101,'114518','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338145,4103,'114520','watch-mobile','text','<p>GIFT CARD</p>',3,''),(338146,4105,'114522','watch-mobile','text','<p>HOLBI</p>',3,''),(338147,4109,'114526','watch-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338148,4110,'114527','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338149,4112,'114529','watch-mobile','text','<p>Your code is:</p>',3,''),(338150,4123,'114540','watch-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338151,4130,'75671','watch-mobile','logo','themes/watch-mobile/img/oscommerce_logo.png',3,''),(338152,4144,'75693','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338153,4149,'75698','watch-mobile','logo','themes/watch-mobile/img/watchlogo-2-1.png',3,''),(338154,4151,'75700','watch-mobile','text','<p>Phone:</p>',3,''),(338155,4156,'75705','watch-mobile','text','<p>Web:</p>',3,''),(338156,4159,'75708','watch-mobile','text','<p>Email:</p>',3,''),(338157,4162,'75711','watch-mobile','text','<p>If undelivered please return to:</p>',3,''),(338158,4164,'75713','watch-mobile','text','<p>Thank you for your order</p>',3,''),(338160,4167,'75716','watch-mobile','text','<p>Email:</p>',3,''),(338161,4170,'75719','watch-mobile','text','<p>Phone:</p>',3,''),(338162,4172,'75721','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338163,4176,'75725','watch-mobile','text','<p>Shipping via</p>',3,''),(338164,4180,'75729','watch-mobile','text','<p>Shipping service</p>',3,''),(338165,4183,'75732','watch-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338166,4187,'75736','watch-mobile','text','<p>CUSTOMER:</p>',3,''),(338167,4189,'75738','watch-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338168,4190,'75739','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338169,4196,'75745','watch-mobile','text','<p>Payment date:</p>',3,''),(338170,4197,'75746','watch-mobile','text','<p>Payment Method:</p>',3,''),(338171,4199,'94803','watch-mobile','tab_1','RETURNING CUSTOMER',3,''),(338172,4199,'94803','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338173,4221,'114562','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338174,4221,'114562','watch-mobile','tab_2','RETURNING CUSTOMER',3,''),(338175,4221,'114562','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338176,4237,'114578','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338177,4237,'114578','watch-mobile','tab_2','RETURNING CUSTOMER',3,''),(338178,4237,'114578','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338179,4250,'114591','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338180,4250,'114591','watch-mobile','tab_2','RETURNING CUSTOMER',3,''),(338181,4250,'114591','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338182,4291,'75750','watch-mobile','tab_1','New products',3,''),(338183,4291,'75750','watch-mobile','tab_2','Specials products',3,''),(338184,4291,'75750','watch-mobile','tab_3','Featured',3,''),(338185,4324,'114653','watch-mobile','tab_1','RETURNING CUSTOMER',3,''),(338186,4324,'114653','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338187,4446,'75764','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338188,4452,'75770','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338189,4453,'75771','watch-mobile','text','<p>CUSTOMER:</p>',3,''),(338190,4454,'75772','watch-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338191,4458,'75776','watch-mobile','text','<p>Shipping via</p>',3,''),(338192,4460,'75778','watch-mobile','text','<p>Shipping service</p>',3,''),(338193,4464,'75782','watch-mobile','text','<p>If undelivered please return to:</p>',3,''),(338194,4467,'75785','watch-mobile','logo','themes/watch-mobile/img/watchlogo-3.png',3,''),(338195,4471,'75789','watch-mobile','text','<p>Phone:</p>',3,''),(338196,4474,'75792','watch-mobile','text','<p>Web:</p>',3,''),(338197,4477,'75795','watch-mobile','text','<p>Email:</p>',3,''),(338199,4504,'75817','watch-mobile','text','osCommerce 4',3,''),(338200,4539,'75840','watch-mobile','tab_1','Description',3,''),(338201,4539,'75840','watch-mobile','tab_2','Reviews',3,''),(338202,4584,'114794','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338203,4589,'114799','watch-mobile','text','<p>ADDRESS:</p>\n',3,''),(338204,4592,'114802','watch-mobile','text','<p>CUSTOMER:</p>',3,''),(338205,4593,'114803','watch-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338206,4594,'114804','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338207,4598,'114808','watch-mobile','text','<p>Order date:</p>\n',3,''),(338209,4606,'114816','watch-mobile','text','<p>Email:</p>',3,''),(338210,4609,'114819','watch-mobile','text','<p>Web:</p>',3,''),(338211,4612,'114822','watch-mobile','text','<p>Phone:</p>',3,''),(338212,4616,'114826','watch-mobile','text','<p>If undelivered please return to:</p>',3,''),(338213,4617,'114827','watch-mobile','text','<p>Thank you for your order</p>',3,''),(338215,4620,'114830','watch-mobile','text','<p>Phone:</p>',3,''),(338216,4622,'114832','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338217,4624,'114834','watch-mobile','text','<p>Email:</p>',3,''),(338218,4664,'75868','watch-mobile','text','<h1>Quotations</h1>',3,''),(338219,4781,'114988','watch-mobile','logo','themes/watch-mobile/img/Furntech-1.jpg',3,''),(338220,4805,'75872','watch-mobile','text','<h1>Samples</h1>',3,''),(338221,4891,'75875','watch-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',3,''),(338222,4910,'115079','watch-mobile','text','<p>Phone:</p>',3,''),(338223,4913,'115082','watch-mobile','text','<p>Web:</p>',3,''),(338224,4916,'115085','watch-mobile','text','<p>Email:</p>',3,''),(338225,4921,'115090','watch-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338226,4924,'115093','watch-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338227,4925,'115094','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338228,4926,'115095','watch-mobile','text','<p>CUSTOMER:</p>',3,''),(338229,4932,'115101','watch-mobile','text','<p>Shipping via</p>',3,''),(338230,4936,'115105','watch-mobile','text','<p>Shipping service</p>',3,''),(338231,4937,'115106','watch-mobile','text','<p>Payment date:</p>',3,''),(338232,4939,'115108','watch-mobile','text','<p>Payment Method:</p>',3,''),(338233,4944,'115113','watch-mobile','text','<p>If undelivered please return to:</p>',3,''),(338235,4947,'115116','watch-mobile','text','<p>Thank you for your order</p>',3,''),(338236,4949,'115118','watch-mobile','text','<p>Phone:</p>',3,''),(338237,4951,'115120','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338238,4953,'115122','watch-mobile','text','<p>Email:</p>',3,''),(338239,4959,'115128','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338368,13141,'118691','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',3,''),(338369,13172,'118722','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',3,''),(338370,13877,'119427','printshop-mobile','text','<p>Shipping via</p>',3,''),(338371,13881,'119431','printshop-mobile','text','<p>Shipping service</p>',3,''),(338372,13885,'119435','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338373,13887,'119437','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338374,13890,'119440','printshop-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338375,13891,'119441','printshop-mobile','text','<p>CUSTOMER:</p>',3,''),(338376,13894,'119444','printshop-mobile','text','<p>Payment date:</p>',3,''),(338377,13898,'119448','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338379,13906,'119456','printshop-mobile','text','<p>Email:</p>',3,''),(338380,13909,'119459','printshop-mobile','text','<p>Phone:</p>',3,''),(338381,13912,'119462','printshop-mobile','text','<p>Web:</p>',3,''),(338382,13917,'119467','printshop-mobile','text','<p>If undelivered please return to:</p>',3,''),(338383,13918,'119468','printshop-mobile','text','<p>Thank you for your order</p>',3,''),(338385,13921,'119471','printshop-mobile','text','<p>Phone:</p>',3,''),(338386,13924,'119474','printshop-mobile','text','<p>Email:</p>',3,''),(338387,13926,'119476','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338388,13948,'119498','printshop-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',3,''),(338389,13959,'119509','printshop-mobile','logo','themes/printshop-mobile/img/logo-white-1.png',3,''),(338390,13980,'119530','printshop-mobile','text','Account',3,''),(338391,13985,'119535','printshop-mobile','text','Account',3,''),(338392,13987,'119537','printshop-mobile','text','Account',3,''),(338393,13991,'119541','printshop-mobile','text','Account',3,''),(338394,14003,'119553','printshop-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338395,14006,'119556','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338396,14007,'119557','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338397,14008,'119558','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(338398,14009,'119559','printshop-mobile','text','<p>GIFT CARD</p>',3,''),(338399,14011,'119561','printshop-mobile','text','<p>Your code is:</p>',3,''),(338400,14015,'119565','printshop-mobile','text','<p>HOLBI</p>',3,''),(338401,14017,'119567','printshop-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(338402,14020,'119570','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338403,14021,'119571','printshop-mobile','text','<p>GIFT CARD</p>',3,''),(338404,14022,'119572','printshop-mobile','logo','themes/printshop-mobile/img/logo-1.png',3,''),(338405,14023,'119573','printshop-mobile','logo','themes/printshop-mobile/img/bestseller-1.png',3,''),(338406,14024,'119574','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338407,14028,'119578','printshop-mobile','text','<p>Your code is:</p>',3,''),(338408,14030,'119580','printshop-mobile','text','<p>HOLBI</p>',3,''),(338409,14031,'119581','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338410,14034,'119584','printshop-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338411,14037,'119587','printshop-mobile','text','<p>HOLBI</p>',3,''),(338412,14038,'119588','printshop-mobile','text','<p>GIFT CARD</p>',3,''),(338413,14039,'119589','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338414,14041,'119591','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338415,14042,'119592','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338416,14045,'119595','printshop-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338417,14048,'119598','printshop-mobile','text','<p>Your code is:</p>',3,''),(338418,14060,'119610','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338419,14077,'119627','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338420,14089,'119639','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338421,14090,'119640','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338422,14092,'119642','printshop-mobile','text','<p>GIFT CARD</p>',3,''),(338423,14094,'119644','printshop-mobile','text','<p>HOLBI</p>',3,''),(338424,14098,'119648','printshop-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338425,14099,'119649','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338426,14101,'119651','printshop-mobile','text','<p>Your code is:</p>',3,''),(338427,14112,'119662','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338428,14119,'119669','printshop-mobile','logo','themes/printshop-mobile/img/oscommerce_logo.png',3,''),(338429,14122,'119672','printshop-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',3,''),(338430,14124,'119674','printshop-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',3,''),(338431,14125,'119675','printshop-mobile','logo','themes/printshop-mobile/img/check-2.png',3,''),(338432,14141,'119691','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338434,14148,'119698','printshop-mobile','text','<p>Phone:</p>',3,''),(338435,14153,'119703','printshop-mobile','text','<p>Web:</p>',3,''),(338436,14156,'119706','printshop-mobile','text','<p>Email:</p>',3,''),(338437,14159,'119709','printshop-mobile','text','<p>If undelivered please return to:</p>',3,''),(338438,14161,'119711','printshop-mobile','text','<p>Thank you for your order</p>',3,''),(338440,14164,'119714','printshop-mobile','text','<p>Email:</p>',3,''),(338441,14167,'119717','printshop-mobile','text','<p>Phone:</p>',3,''),(338442,14169,'119719','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338443,14173,'119723','printshop-mobile','text','<p>Shipping via</p>',3,''),(338444,14177,'119727','printshop-mobile','text','<p>Shipping service</p>',3,''),(338445,14180,'119730','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338446,14184,'119734','printshop-mobile','text','<p>CUSTOMER:</p>',3,''),(338447,14186,'119736','printshop-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338448,14187,'119737','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338449,14193,'119743','printshop-mobile','text','<p>Payment date:</p>',3,''),(338450,14194,'119744','printshop-mobile','text','<p>Payment Method:</p>',3,''),(338451,14196,'119746','printshop-mobile','tab_1','RETURNING CUSTOMER',3,''),(338452,14196,'119746','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338453,14218,'119768','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338454,14218,'119768','printshop-mobile','tab_2','RETURNING CUSTOMER',3,''),(338455,14218,'119768','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338456,14234,'119784','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338457,14234,'119784','printshop-mobile','tab_2','RETURNING CUSTOMER',3,''),(338458,14234,'119784','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338459,14247,'119797','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338460,14247,'119797','printshop-mobile','tab_2','RETURNING CUSTOMER',3,''),(338461,14247,'119797','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338462,14288,'119838','printshop-mobile','tab_1','New products',3,''),(338463,14288,'119838','printshop-mobile','tab_2','Specials products',3,''),(338464,14288,'119838','printshop-mobile','tab_3','Featured',3,''),(338465,14321,'119871','printshop-mobile','tab_1','RETURNING CUSTOMER',3,''),(338466,14321,'119871','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338467,14443,'119993','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338468,14449,'119999','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338469,14450,'120000','printshop-mobile','text','<p>CUSTOMER:</p>',3,''),(338470,14451,'120001','printshop-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338471,14455,'120005','printshop-mobile','text','<p>Shipping via</p>',3,''),(338472,14457,'120007','printshop-mobile','text','<p>Shipping service</p>',3,''),(338473,14461,'120011','printshop-mobile','text','<p>If undelivered please return to:</p>',3,''),(338475,14468,'120018','printshop-mobile','text','<p>Phone:</p>',3,''),(338476,14471,'120021','printshop-mobile','text','<p>Web:</p>',3,''),(338477,14474,'120024','printshop-mobile','text','<p>Email:</p>',3,''),(338479,14501,'120051','printshop-mobile','text','osCommerce 4',3,''),(338480,14536,'120086','printshop-mobile','tab_1','Description',3,''),(338481,14536,'120086','printshop-mobile','tab_2','Reviews',3,''),(338482,14581,'120131','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338483,14586,'120136','printshop-mobile','text','<p>ADDRESS:</p>\n',3,''),(338484,14589,'120139','printshop-mobile','text','<p>CUSTOMER:</p>',3,''),(338485,14590,'120140','printshop-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338486,14591,'120141','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338487,14595,'120145','printshop-mobile','text','<p>Order date:</p>\n',3,''),(338489,14603,'120153','printshop-mobile','text','<p>Email:</p>',3,''),(338490,14606,'120156','printshop-mobile','text','<p>Web:</p>',3,''),(338491,14609,'120159','printshop-mobile','text','<p>Phone:</p>',3,''),(338492,14613,'120163','printshop-mobile','text','<p>If undelivered please return to:</p>',3,''),(338493,14614,'120164','printshop-mobile','text','<p>Thank you for your order</p>',3,''),(338495,14617,'120167','printshop-mobile','text','<p>Phone:</p>',3,''),(338496,14619,'120169','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338497,14621,'120171','printshop-mobile','text','<p>Email:</p>',3,''),(338498,14661,'120211','printshop-mobile','text','<h1>Quotations</h1>',3,''),(338499,14778,'120328','printshop-mobile','logo','themes/printshop-mobile/img/Furntech-1.jpg',3,''),(338500,14802,'120352','printshop-mobile','text','<h1>Samples</h1>',3,''),(338501,14888,'120438','printshop-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',3,''),(338502,14907,'120457','printshop-mobile','text','<p>Phone:</p>',3,''),(338503,14910,'120460','printshop-mobile','text','<p>Web:</p>',3,''),(338504,14913,'120463','printshop-mobile','text','<p>Email:</p>',3,''),(338505,14918,'120468','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338506,14921,'120471','printshop-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338507,14922,'120472','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338508,14923,'120473','printshop-mobile','text','<p>CUSTOMER:</p>',3,''),(338509,14929,'120479','printshop-mobile','text','<p>Shipping via</p>',3,''),(338510,14933,'120483','printshop-mobile','text','<p>Shipping service</p>',3,''),(338511,14934,'120484','printshop-mobile','text','<p>Payment date:</p>',3,''),(338512,14936,'120486','printshop-mobile','text','<p>Payment Method:</p>',3,''),(338513,14941,'120491','printshop-mobile','text','<p>If undelivered please return to:</p>',3,''),(338515,14944,'120494','printshop-mobile','text','<p>Thank you for your order</p>',3,''),(338516,14946,'120496','printshop-mobile','text','<p>Phone:</p>',3,''),(338517,14948,'120498','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338518,14950,'120500','printshop-mobile','text','<p>Email:</p>',3,''),(338519,14956,'120506','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338644,18022,'118691','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',3,''),(338645,18053,'118722','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',3,''),(338646,18758,'119427','deals-mobile','text','<p>Shipping via</p>',3,''),(338647,18762,'119431','deals-mobile','text','<p>Shipping service</p>',3,''),(338648,18766,'119435','deals-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338649,18768,'119437','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338650,18771,'119440','deals-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338651,18772,'119441','deals-mobile','text','<p>CUSTOMER:</p>',3,''),(338652,18775,'119444','deals-mobile','text','<p>Payment date:</p>',3,''),(338653,18779,'119448','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338655,18787,'119456','deals-mobile','text','<p>Email:</p>',3,''),(338656,18790,'119459','deals-mobile','text','<p>Phone:</p>',3,''),(338657,18793,'119462','deals-mobile','text','<p>Web:</p>',3,''),(338658,18798,'119467','deals-mobile','text','<p>If undelivered please return to:</p>',3,''),(338659,18799,'119468','deals-mobile','text','<p>Thank you for your order</p>',3,''),(338661,18802,'119471','deals-mobile','text','<p>Phone:</p>',3,''),(338662,18805,'119474','deals-mobile','text','<p>Email:</p>',3,''),(338663,18807,'119476','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338664,18829,'119498','deals-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',3,''),(338665,18840,'119509','deals-mobile','logo','themes/deals-mobile/img/logo-white-1.png',3,''),(338666,18861,'119530','deals-mobile','text','Account',3,''),(338667,18866,'119535','deals-mobile','text','Account',3,''),(338668,18868,'119537','deals-mobile','text','Account',3,''),(338669,18872,'119541','deals-mobile','text','Account',3,''),(338670,18884,'119553','deals-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338671,18887,'119556','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338672,18888,'119557','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338673,18889,'119558','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(338674,18890,'119559','deals-mobile','text','<p>GIFT CARD</p>',3,''),(338675,18892,'119561','deals-mobile','text','<p>Your code is:</p>',3,''),(338676,18896,'119565','deals-mobile','text','<p>HOLBI</p>',3,''),(338677,18898,'119567','deals-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(338678,18901,'119570','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338679,18902,'119571','deals-mobile','text','<p>GIFT CARD</p>',3,''),(338680,18903,'119572','deals-mobile','logo','themes/deals-mobile/img/logo-1.png',3,''),(338681,18904,'119573','deals-mobile','logo','themes/deals-mobile/img/bestseller-1.png',3,''),(338682,18905,'119574','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338683,18909,'119578','deals-mobile','text','<p>Your code is:</p>',3,''),(338684,18911,'119580','deals-mobile','text','<p>HOLBI</p>',3,''),(338685,18912,'119581','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338686,18915,'119584','deals-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338687,18918,'119587','deals-mobile','text','<p>HOLBI</p>',3,''),(338688,18919,'119588','deals-mobile','text','<p>GIFT CARD</p>',3,''),(338689,18920,'119589','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338690,18922,'119591','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338691,18923,'119592','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338692,18926,'119595','deals-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338693,18929,'119598','deals-mobile','text','<p>Your code is:</p>',3,''),(338694,18941,'119610','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338695,18958,'119627','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338696,18970,'119639','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',3,''),(338697,18971,'119640','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338698,18973,'119642','deals-mobile','text','<p>GIFT CARD</p>',3,''),(338699,18975,'119644','deals-mobile','text','<p>HOLBI</p>',3,''),(338700,18979,'119648','deals-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338701,18980,'119649','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338702,18982,'119651','deals-mobile','text','<p>Your code is:</p>',3,''),(338703,18993,'119662','deals-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338704,19000,'119669','deals-mobile','logo','themes/deals-mobile/img/oscommerce_logo.png',3,''),(338705,19003,'119672','deals-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',3,''),(338706,19005,'119674','deals-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',3,''),(338707,19006,'119675','deals-mobile','logo','themes/deals-mobile/img/check-2.png',3,''),(338708,19022,'119691','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338710,19029,'119698','deals-mobile','text','<p>Phone:</p>',3,''),(338711,19034,'119703','deals-mobile','text','<p>Web:</p>',3,''),(338712,19037,'119706','deals-mobile','text','<p>Email:</p>',3,''),(338713,19040,'119709','deals-mobile','text','<p>If undelivered please return to:</p>',3,''),(338714,19042,'119711','deals-mobile','text','<p>Thank you for your order</p>',3,''),(338716,19045,'119714','deals-mobile','text','<p>Email:</p>',3,''),(338717,19048,'119717','deals-mobile','text','<p>Phone:</p>',3,''),(338718,19050,'119719','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338719,19054,'119723','deals-mobile','text','<p>Shipping via</p>',3,''),(338720,19058,'119727','deals-mobile','text','<p>Shipping service</p>',3,''),(338721,19061,'119730','deals-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338722,19065,'119734','deals-mobile','text','<p>CUSTOMER:</p>',3,''),(338723,19067,'119736','deals-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338724,19068,'119737','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338725,19074,'119743','deals-mobile','text','<p>Payment date:</p>',3,''),(338726,19075,'119744','deals-mobile','text','<p>Payment Method:</p>',3,''),(338727,19077,'119746','deals-mobile','tab_1','RETURNING CUSTOMER',3,''),(338728,19077,'119746','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338729,19099,'119768','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338730,19099,'119768','deals-mobile','tab_2','RETURNING CUSTOMER',3,''),(338731,19099,'119768','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338732,19115,'119784','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338733,19115,'119784','deals-mobile','tab_2','RETURNING CUSTOMER',3,''),(338734,19115,'119784','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338735,19128,'119797','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338736,19128,'119797','deals-mobile','tab_2','RETURNING CUSTOMER',3,''),(338737,19128,'119797','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338738,19169,'119838','deals-mobile','tab_1','New products',3,''),(338739,19169,'119838','deals-mobile','tab_2','Specials products',3,''),(338740,19169,'119838','deals-mobile','tab_3','Featured',3,''),(338741,19202,'119871','deals-mobile','tab_1','RETURNING CUSTOMER',3,''),(338742,19202,'119871','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338743,19324,'119993','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338744,19330,'119999','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338745,19331,'120000','deals-mobile','text','<p>CUSTOMER:</p>',3,''),(338746,19332,'120001','deals-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338747,19336,'120005','deals-mobile','text','<p>Shipping via</p>',3,''),(338748,19338,'120007','deals-mobile','text','<p>Shipping service</p>',3,''),(338749,19342,'120011','deals-mobile','text','<p>If undelivered please return to:</p>',3,''),(338751,19349,'120018','deals-mobile','text','<p>Phone:</p>',3,''),(338752,19352,'120021','deals-mobile','text','<p>Web:</p>',3,''),(338753,19355,'120024','deals-mobile','text','<p>Email:</p>',3,''),(338755,19382,'120051','deals-mobile','text','osCommerce 4',3,''),(338756,19417,'120086','deals-mobile','tab_1','Description',3,''),(338757,19417,'120086','deals-mobile','tab_2','Reviews',3,''),(338758,19462,'120131','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338759,19467,'120136','deals-mobile','text','<p>ADDRESS:</p>\n',3,''),(338760,19470,'120139','deals-mobile','text','<p>CUSTOMER:</p>',3,''),(338761,19471,'120140','deals-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338762,19472,'120141','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338763,19476,'120145','deals-mobile','text','<p>Order date:</p>\n',3,''),(338765,19484,'120153','deals-mobile','text','<p>Email:</p>',3,''),(338766,19487,'120156','deals-mobile','text','<p>Web:</p>',3,''),(338767,19490,'120159','deals-mobile','text','<p>Phone:</p>',3,''),(338768,19494,'120163','deals-mobile','text','<p>If undelivered please return to:</p>',3,''),(338769,19495,'120164','deals-mobile','text','<p>Thank you for your order</p>',3,''),(338771,19498,'120167','deals-mobile','text','<p>Phone:</p>',3,''),(338772,19500,'120169','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338773,19502,'120171','deals-mobile','text','<p>Email:</p>',3,''),(338774,19542,'120211','deals-mobile','text','<h1>Quotations</h1>',3,''),(338775,19659,'120328','deals-mobile','logo','themes/deals-mobile/img/Furntech-1.jpg',3,''),(338776,19683,'120352','deals-mobile','text','<h1>Samples</h1>',3,''),(338777,19769,'120438','deals-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',3,''),(338778,19788,'120457','deals-mobile','text','<p>Phone:</p>',3,''),(338779,19791,'120460','deals-mobile','text','<p>Web:</p>',3,''),(338780,19794,'120463','deals-mobile','text','<p>Email:</p>',3,''),(338781,19799,'120468','deals-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338782,19802,'120471','deals-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338783,19803,'120472','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338784,19804,'120473','deals-mobile','text','<p>CUSTOMER:</p>',3,''),(338785,19810,'120479','deals-mobile','text','<p>Shipping via</p>',3,''),(338786,19814,'120483','deals-mobile','text','<p>Shipping service</p>',3,''),(338787,19815,'120484','deals-mobile','text','<p>Payment date:</p>',3,''),(338788,19817,'120486','deals-mobile','text','<p>Payment Method:</p>',3,''),(338789,19822,'120491','deals-mobile','text','<p>If undelivered please return to:</p>',3,''),(338791,19825,'120494','deals-mobile','text','<p>Thank you for your order</p>',3,''),(338792,19827,'120496','deals-mobile','text','<p>Phone:</p>',3,''),(338793,19829,'120498','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338794,19831,'120500','deals-mobile','text','<p>Email:</p>',3,''),(338795,19837,'120506','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338928,54257,'116269','furniture-mobile','logo','themes/furniture-mobile/img/payicons-1.png',3,''),(338929,55017,'116977','furniture-mobile','text','<p>If undelivered please return to:</p>',3,''),(338930,55018,'116978','furniture-mobile','text','<p>Thank you for your order</p>',3,''),(338932,55020,'116980','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338933,55022,'116982','furniture-mobile','text','<p>Email:</p>',3,''),(338934,55025,'116985','furniture-mobile','text','<p>Phone:</p>',3,''),(338936,55031,'116991','furniture-mobile','text','<p>Web:</p>',3,''),(338937,55034,'116994','furniture-mobile','text','<p>Phone:</p>',3,''),(338938,55037,'116997','furniture-mobile','text','<p>Email:</p>',3,''),(338939,55044,'117004','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338940,55049,'117009','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338941,55053,'117013','furniture-mobile','text','<p>CUSTOMER:</p>',3,''),(338942,55054,'117014','furniture-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338943,55057,'117017','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338944,55061,'117021','furniture-mobile','text','<p>Shipping via</p>',3,''),(338945,55063,'117023','furniture-mobile','text','<p>Shipping service</p>',3,''),(338946,55066,'117026','furniture-mobile','text','<p>Payment date:</p>',3,''),(338947,55101,'117055','furniture-mobile','logo','themes/furniture-mobile/img/logo-white-1.png',3,''),(338948,55150,'117107','furniture-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(338949,55155,'117112','furniture-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338950,55157,'117114','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338951,55158,'117115','furniture-mobile','text','<p>osCommerce</p>\n',3,''),(338952,55160,'117117','furniture-mobile','text','<p>Your code is:</p>',3,''),(338953,55164,'117121','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338954,55165,'117123','furniture-mobile','logo','themes/furniture-mobile/img/Logo-1.jpg',3,''),(338955,55166,'117124','furniture-mobile','text','<p>GIFT CARD</p>',3,''),(338956,55167,'117125','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(338957,55171,'117129','furniture-mobile','text','<p>Your code is:</p>',3,''),(338958,55175,'117133','furniture-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338959,55178,'117136','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338960,55179,'117137','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(338961,55180,'117138','furniture-mobile','text','<p>GIFT CARD</p>',3,''),(338962,55181,'117139','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338963,55192,'117150','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338964,55209,'117167','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338965,55221,'117180','furniture-mobile','text','<p>Your code is:</p>',3,''),(338966,55223,'117182','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',3,''),(338967,55225,'117185','furniture-mobile','text','<p>If you require further assistance please contact us</p>',3,''),(338968,55229,'117189','furniture-mobile','text','<p>GIFT CARD</p>',3,''),(338969,55230,'117190','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338970,55232,'117192','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(338971,55243,'117202','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',3,''),(338973,55258,'117218','furniture-mobile','logo','themes/furniture-mobile/img/header-img-1.png',3,''),(338974,55279,'117234','furniture-mobile','text','<p>Shipping via</p>',3,''),(338975,55281,'117236','furniture-mobile','text','<p>Shipping service</p>',3,''),(338976,55285,'117240','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(338977,55289,'117243','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(338978,55292,'117246','furniture-mobile','text','<p>CUSTOMER:</p>',3,''),(338979,55293,'117247','furniture-mobile','text','<p>PHONE NUMBER:</p>',3,''),(338980,55296,'117250','furniture-mobile','text','<p>Payment Method:</p>',3,''),(338981,55297,'117251','furniture-mobile','text','<p>Payment date:</p>',3,''),(338982,55303,'117257','furniture-mobile','text','<p>If undelivered please return to:</p>',3,''),(338983,55304,'117258','furniture-mobile','text','<p>Thank you for your order</p>',3,''),(338984,55306,'117261','furniture-mobile','text','<p>Email:</p>',3,''),(338985,55309,'117264','furniture-mobile','text','<p>Phone:</p>',3,''),(338986,55311,'117266','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(338987,55316,'117271','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(338988,55320,'117275','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',3,''),(338989,55322,'117277','furniture-mobile','text','<p>Web:</p>',3,''),(338990,55325,'117280','furniture-mobile','text','<p>Email:</p>',3,''),(338991,55330,'117285','furniture-mobile','text','<p>Phone:</p>',3,''),(338992,55337,'117288','furniture-mobile','tab_1','RETURNING CUSTOMER',3,''),(338993,55337,'117288','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(338994,55360,'117311','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338995,55360,'117311','furniture-mobile','tab_2','RETURNING CUSTOMER',3,''),(338996,55360,'117311','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(338997,55376,'117327','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(338998,55376,'117327','furniture-mobile','tab_2','RETURNING CUSTOMER',3,''),(338999,55376,'117327','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(339000,55393,'117344','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(339001,55393,'117344','furniture-mobile','tab_2','RETURNING CUSTOMER',3,''),(339002,55393,'117344','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(339003,55486,'117416','furniture-mobile','tab_1','RETURNING CUSTOMER',3,''),(339004,55486,'117416','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(339005,55663,'117536','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',3,''),(339006,55665,'117538','furniture-mobile','text','<p>Email:</p>',3,''),(339007,55668,'117541','furniture-mobile','text','<p>Phone:</p>',3,''),(339008,55673,'117546','furniture-mobile','text','<p>Web:</p>',3,''),(339009,55678,'117551','furniture-mobile','text','<p>If undelivered please return to:</p>',3,''),(339010,55683,'117556','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(339011,55685,'117558','furniture-mobile','text','<p>CUSTOMER:</p>',3,''),(339012,55688,'117561','furniture-mobile','text','<p>PHONE NUMBER:</p>',3,''),(339013,55690,'117563','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(339014,55694,'117567','furniture-mobile','text','<p>Shipping via</p>',3,''),(339015,55697,'117570','furniture-mobile','text','<p>Shipping service</p>',3,''),(339016,55726,'117596','furniture-mobile','logo','themes/furniture-mobile/img/oscommerce_logo-1.jpg',3,''),(339017,55727,'117597','furniture-mobile','text','osCommerce 4',3,''),(339018,55764,'117646','furniture-mobile','tab_1','Product Overview',3,''),(339019,55764,'117646','furniture-mobile','tab_2','Delivery and returns',3,''),(339020,55764,'117646','furniture-mobile','tab_3','Assembly',3,''),(339021,55882,'117702','furniture-mobile','text','<p>If undelivered please return to:</p>',3,''),(339022,55884,'117704','furniture-mobile','text','<p>Thank you for your order</p>',3,''),(339024,55887,'117707','furniture-mobile','text','<p>Email:</p>',3,''),(339025,55889,'117709','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(339026,55891,'117711','furniture-mobile','text','<p>Phone:</p>',3,''),(339028,55896,'117716','furniture-mobile','text','<p>Phone:</p>',3,''),(339029,55899,'117719','furniture-mobile','text','<p>Web:</p>',3,''),(339030,55904,'117724','furniture-mobile','text','<p>Email:</p>',3,''),(339031,55910,'117730','furniture-mobile','text','<p>ADDRESS:</p>\n',3,''),(339032,55913,'117733','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(339033,55916,'117736','furniture-mobile','text','<p>PHONE NUMBER:</p>',3,''),(339034,55917,'117737','furniture-mobile','text','<p>CUSTOMER:</p>',3,''),(339035,55919,'117739','furniture-mobile','text','<p>Order date:</p>\n',3,''),(339036,55924,'117744','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(339037,56056,'117816','furniture-mobile','logo','themes/furniture-mobile/img/Furntech-1.jpg',3,''),(339038,56314,'118011','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',3,''),(339039,56318,'118015','furniture-mobile','text','<p>If undelivered please return to:</p>',3,''),(339040,56320,'118018','furniture-mobile','text','<p>Thank you for your order</p>',3,''),(339041,56321,'118019','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',3,''),(339042,56323,'118021','furniture-mobile','text','<p>Email:</p>',3,''),(339043,56326,'118024','furniture-mobile','text','<p>Phone:</p>',3,''),(339044,56331,'118029','furniture-mobile','text','<p>Email:</p>',3,''),(339045,56334,'118032','furniture-mobile','text','<p>Web:</p>',3,''),(339046,56339,'118037','furniture-mobile','text','<p>Phone:</p>',3,''),(339047,56344,'118042','furniture-mobile','text','<p>Shipping via</p>',3,''),(339048,56347,'118045','furniture-mobile','text','<p>Shipping service</p>',3,''),(339049,56352,'118050','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',3,''),(339050,56355,'118053','furniture-mobile','text','<p>PHONE NUMBER:</p>',3,''),(339051,56358,'118056','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',3,''),(339052,56359,'118057','furniture-mobile','text','<p>CUSTOMER:</p>',3,''),(339053,56361,'118059','furniture-mobile','text','<p>Payment date:</p>',3,''),(339054,56362,'118060','furniture-mobile','text','<p>Payment Method:</p>',3,''),(339319,108868,'117051','splash','logo','themes/splash/img/oscommerce_logo_(2)-1.png',3,''),(339320,108918,'1661353032.672459','splash','logo','themes/splash/img/oscommerce_logo.jpg',3,''),(339321,108933,'1640168618.7708','splash','logo','themes/splash/img/oscommerce_logo (2).png',3,''),(339322,108936,'1640169872.1589','splash','img_link','furniture/',3,''),(339323,108936,'1640169872.1589','splash','logo','themes/splash/img/Splash_furniture_BGlogo.png',3,''),(339324,108936,'1640169872.1589','splash','target_blank','1',3,''),(339325,108937,'1640276640.1123','splash','text','<h1>osCommerce v4 Splash page</h1>\r\n\r\n<p>osCommerce supports multiple sales CHANNELS.</p>\r\n\r\n<p>Your installation of osCommerce comes with &nbsp;&quot;Furniture&quot;, &quot;Watch&quot;, &quot;B2B Supermarket&quot;, and &quot;Print shop&quot; Ecommerce sales channels and &quot;cms&quot; brochure website example.</p>\r\n\r\n<p>Each sales channel has its own URLs, design, and demo product sets.</p>\r\n\r\n<p>&quot;Admin&quot; is the back end of your osCommerce.</p>\r\n\r\n<p>Use osCommerce Wiki to learn how to manage sales channels, &nbsp;assign design themes, and content to the sales channels.<br />\r\nThank you for choosing &nbsp;osCommerce - the most powerful on-premise open source Ecommerce platform!</p>\r\n',3,''),(339326,108938,'1640170154.7803','splash','img_link','watch/',3,''),(339327,108938,'1640170154.7803','splash','logo','themes/splash/img/Splash_watch_BGlogo.png',3,''),(339328,108938,'1640170154.7803','splash','target_blank','1',3,''),(339329,108940,'1640170023.0001','splash','img_link','printshop/',3,''),(339330,108940,'1640170023.0001','splash','logo','themes/splash/img/print shop.jpg',3,''),(339331,108940,'1640170023.0001','splash','target_blank','1',3,''),(339332,108941,'1640170023.1491','splash','img_link','admin/',3,''),(339333,108941,'1640170023.1491','splash','logo','themes/splash/img/Splash_admin_BGlogo.png',3,''),(339334,108941,'1640170023.1491','splash','target_blank','1',3,''),(339335,108942,'1640170023','splash','img_link','b2b-supermarket/',3,''),(339336,108942,'1640170023','splash','logo','themes/splash/img/b2b supermarket.jpg',3,''),(339337,108942,'1640170023','splash','target_blank','1',3,''),(339338,108945,'1661353032.975845','splash','logo','themes/splash/img/oscommerce_logo-1.jpg',3,''),(339339,109001,'74702','splash','logo','themes/splash/img/oscommerce_logo.jpg',3,''),(339340,109002,'74703','splash','text','osCommerce 4',3,''),(339472,3158,'115992','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',4,''),(339473,3189,'113675','watch-mobile','logo','themes/watch-mobile/img/payicons-2.png',4,''),(339474,3888,'114358','watch-mobile','text','<p>Shipping via</p>',4,''),(339475,3892,'114362','watch-mobile','text','<p>Shipping service</p>',4,''),(339476,3896,'114366','watch-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(339477,3898,'114368','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339478,3901,'114371','watch-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339479,3902,'114372','watch-mobile','text','<p>CUSTOMER:</p>',4,''),(339480,3905,'114375','watch-mobile','text','<p>Payment date:</p>',4,''),(339481,3909,'114379','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339483,3917,'114387','watch-mobile','text','<p>Email:</p>',4,''),(339484,3920,'114390','watch-mobile','text','<p>Phone:</p>',4,''),(339485,3923,'114393','watch-mobile','text','<p>Web:</p>',4,''),(339486,3928,'114398','watch-mobile','text','<p>If undelivered please return to:</p>',4,''),(339487,3929,'114399','watch-mobile','text','<p>Thank you for your order</p>',4,''),(339489,3932,'114402','watch-mobile','text','<p>Phone:</p>',4,''),(339490,3935,'114405','watch-mobile','text','<p>Email:</p>',4,''),(339491,3937,'114407','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339492,3956,'75618','watch-mobile','logo','themes/watch-mobile/img/watchlogo-1-1.png',4,''),(339493,3959,'75621','watch-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',4,''),(339494,3970,'114422','watch-mobile','logo','themes/watch-mobile/img/logo-white-1.png',4,''),(339495,3991,'75629','watch-mobile','text','Account',4,''),(339496,3996,'75635','watch-mobile','text','Shop',4,''),(339497,3998,'75637','watch-mobile','text','Products',4,''),(339498,4002,'75642','watch-mobile','text','Contact Us',4,''),(339499,4014,'75655','watch-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339500,4017,'75658','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339501,4018,'75659','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339502,4019,'75660','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(339503,4020,'75661','watch-mobile','text','<p>GIFT CARD</p>',4,''),(339504,4022,'75663','watch-mobile','text','<p>Your code is:</p>',4,''),(339505,4026,'75667','watch-mobile','text','<p>HOLBI</p>',4,''),(339506,4028,'75669','watch-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(339507,4031,'114448','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(339508,4032,'114449','watch-mobile','text','<p>GIFT CARD</p>',4,''),(339509,4033,'114450','watch-mobile','logo','themes/watch-mobile/img/logo-1.png',4,''),(339510,4034,'114451','watch-mobile','logo','themes/watch-mobile/img/bestseller-1.png',4,''),(339511,4035,'114452','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339512,4039,'114456','watch-mobile','text','<p>Your code is:</p>',4,''),(339513,4041,'114458','watch-mobile','text','<p>HOLBI</p>',4,''),(339514,4042,'114459','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339515,4045,'114462','watch-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339516,4048,'114465','watch-mobile','text','<p>HOLBI</p>',4,''),(339517,4049,'114466','watch-mobile','text','<p>GIFT CARD</p>',4,''),(339518,4050,'114467','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339519,4052,'114469','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(339520,4053,'114470','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339521,4056,'114473','watch-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339522,4059,'114476','watch-mobile','text','<p>Your code is:</p>',4,''),(339523,4071,'114488','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339524,4088,'114505','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339525,4100,'114517','watch-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(339526,4101,'114518','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339527,4103,'114520','watch-mobile','text','<p>GIFT CARD</p>',4,''),(339528,4105,'114522','watch-mobile','text','<p>HOLBI</p>',4,''),(339529,4109,'114526','watch-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339530,4110,'114527','watch-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339531,4112,'114529','watch-mobile','text','<p>Your code is:</p>',4,''),(339532,4123,'114540','watch-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339533,4130,'75671','watch-mobile','logo','themes/watch-mobile/img/oscommerce_logo.png',4,''),(339534,4144,'75693','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339535,4149,'75698','watch-mobile','logo','themes/watch-mobile/img/watchlogo-2-1.png',4,''),(339536,4151,'75700','watch-mobile','text','<p>Phone:</p>',4,''),(339537,4156,'75705','watch-mobile','text','<p>Web:</p>',4,''),(339538,4159,'75708','watch-mobile','text','<p>Email:</p>',4,''),(339539,4162,'75711','watch-mobile','text','<p>If undelivered please return to:</p>',4,''),(339540,4164,'75713','watch-mobile','text','<p>Thank you for your order</p>',4,''),(339542,4167,'75716','watch-mobile','text','<p>Email:</p>',4,''),(339543,4170,'75719','watch-mobile','text','<p>Phone:</p>',4,''),(339544,4172,'75721','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339545,4176,'75725','watch-mobile','text','<p>Shipping via</p>',4,''),(339546,4180,'75729','watch-mobile','text','<p>Shipping service</p>',4,''),(339547,4183,'75732','watch-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(339548,4187,'75736','watch-mobile','text','<p>CUSTOMER:</p>',4,''),(339549,4189,'75738','watch-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339550,4190,'75739','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339551,4196,'75745','watch-mobile','text','<p>Payment date:</p>',4,''),(339552,4197,'75746','watch-mobile','text','<p>Payment Method:</p>',4,''),(339553,4199,'94803','watch-mobile','tab_1','RETURNING CUSTOMER',4,''),(339554,4199,'94803','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(339555,4221,'114562','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(339556,4221,'114562','watch-mobile','tab_2','RETURNING CUSTOMER',4,''),(339557,4221,'114562','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(339558,4237,'114578','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(339559,4237,'114578','watch-mobile','tab_2','RETURNING CUSTOMER',4,''),(339560,4237,'114578','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(339561,4250,'114591','watch-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(339562,4250,'114591','watch-mobile','tab_2','RETURNING CUSTOMER',4,''),(339563,4250,'114591','watch-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(339564,4291,'75750','watch-mobile','tab_1','New products',4,''),(339565,4291,'75750','watch-mobile','tab_2','Specials products',4,''),(339566,4291,'75750','watch-mobile','tab_3','Featured',4,''),(339567,4324,'114653','watch-mobile','tab_1','RETURNING CUSTOMER',4,''),(339568,4324,'114653','watch-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(339569,4446,'75764','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339570,4452,'75770','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339571,4453,'75771','watch-mobile','text','<p>CUSTOMER:</p>',4,''),(339572,4454,'75772','watch-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339573,4458,'75776','watch-mobile','text','<p>Shipping via</p>',4,''),(339574,4460,'75778','watch-mobile','text','<p>Shipping service</p>',4,''),(339575,4464,'75782','watch-mobile','text','<p>If undelivered please return to:</p>',4,''),(339576,4467,'75785','watch-mobile','logo','themes/watch-mobile/img/watchlogo-3.png',4,''),(339577,4471,'75789','watch-mobile','text','<p>Phone:</p>',4,''),(339578,4474,'75792','watch-mobile','text','<p>Web:</p>',4,''),(339579,4477,'75795','watch-mobile','text','<p>Email:</p>',4,''),(339581,4504,'75817','watch-mobile','text','osCommerce 4',4,''),(339582,4539,'75840','watch-mobile','tab_1','Description',4,''),(339583,4539,'75840','watch-mobile','tab_2','Reviews',4,''),(339584,4584,'114794','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339585,4589,'114799','watch-mobile','text','<p>ADDRESS:</p>\n',4,''),(339586,4592,'114802','watch-mobile','text','<p>CUSTOMER:</p>',4,''),(339587,4593,'114803','watch-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339588,4594,'114804','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339589,4598,'114808','watch-mobile','text','<p>Order date:</p>\n',4,''),(339591,4606,'114816','watch-mobile','text','<p>Email:</p>',4,''),(339592,4609,'114819','watch-mobile','text','<p>Web:</p>',4,''),(339593,4612,'114822','watch-mobile','text','<p>Phone:</p>',4,''),(339594,4616,'114826','watch-mobile','text','<p>If undelivered please return to:</p>',4,''),(339595,4617,'114827','watch-mobile','text','<p>Thank you for your order</p>',4,''),(339597,4620,'114830','watch-mobile','text','<p>Phone:</p>',4,''),(339598,4622,'114832','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339599,4624,'114834','watch-mobile','text','<p>Email:</p>',4,''),(339600,4664,'75868','watch-mobile','text','<h1>Quotations</h1>',4,''),(339601,4781,'114988','watch-mobile','logo','themes/watch-mobile/img/Furntech-1.jpg',4,''),(339602,4805,'75872','watch-mobile','text','<h1>Samples</h1>',4,''),(339603,4891,'75875','watch-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',4,''),(339604,4910,'115079','watch-mobile','text','<p>Phone:</p>',4,''),(339605,4913,'115082','watch-mobile','text','<p>Web:</p>',4,''),(339606,4916,'115085','watch-mobile','text','<p>Email:</p>',4,''),(339607,4921,'115090','watch-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(339608,4924,'115093','watch-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339609,4925,'115094','watch-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339610,4926,'115095','watch-mobile','text','<p>CUSTOMER:</p>',4,''),(339611,4932,'115101','watch-mobile','text','<p>Shipping via</p>',4,''),(339612,4936,'115105','watch-mobile','text','<p>Shipping service</p>',4,''),(339613,4937,'115106','watch-mobile','text','<p>Payment date:</p>',4,''),(339614,4939,'115108','watch-mobile','text','<p>Payment Method:</p>',4,''),(339615,4944,'115113','watch-mobile','text','<p>If undelivered please return to:</p>',4,''),(339617,4947,'115116','watch-mobile','text','<p>Thank you for your order</p>',4,''),(339618,4949,'115118','watch-mobile','text','<p>Phone:</p>',4,''),(339619,4951,'115120','watch-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339620,4953,'115122','watch-mobile','text','<p>Email:</p>',4,''),(339621,4959,'115128','watch-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339750,13141,'118691','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',4,''),(339751,13172,'118722','printshop-mobile','logo','themes/printshop-mobile/img/payicons-2.png',4,''),(339752,13877,'119427','printshop-mobile','text','<p>Shipping via</p>',4,''),(339753,13881,'119431','printshop-mobile','text','<p>Shipping service</p>',4,''),(339754,13885,'119435','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(339755,13887,'119437','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339756,13890,'119440','printshop-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339757,13891,'119441','printshop-mobile','text','<p>CUSTOMER:</p>',4,''),(339758,13894,'119444','printshop-mobile','text','<p>Payment date:</p>',4,''),(339759,13898,'119448','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339761,13906,'119456','printshop-mobile','text','<p>Email:</p>',4,''),(339762,13909,'119459','printshop-mobile','text','<p>Phone:</p>',4,''),(339763,13912,'119462','printshop-mobile','text','<p>Web:</p>',4,''),(339764,13917,'119467','printshop-mobile','text','<p>If undelivered please return to:</p>',4,''),(339765,13918,'119468','printshop-mobile','text','<p>Thank you for your order</p>',4,''),(339767,13921,'119471','printshop-mobile','text','<p>Phone:</p>',4,''),(339768,13924,'119474','printshop-mobile','text','<p>Email:</p>',4,''),(339769,13926,'119476','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339770,13948,'119498','printshop-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',4,''),(339771,13959,'119509','printshop-mobile','logo','themes/printshop-mobile/img/logo-white-1.png',4,''),(339772,13980,'119530','printshop-mobile','text','Account',4,''),(339773,13985,'119535','printshop-mobile','text','Account',4,''),(339774,13987,'119537','printshop-mobile','text','Account',4,''),(339775,13991,'119541','printshop-mobile','text','Account',4,''),(339776,14003,'119553','printshop-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339777,14006,'119556','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339778,14007,'119557','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339779,14008,'119558','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(339780,14009,'119559','printshop-mobile','text','<p>GIFT CARD</p>',4,''),(339781,14011,'119561','printshop-mobile','text','<p>Your code is:</p>',4,''),(339782,14015,'119565','printshop-mobile','text','<p>HOLBI</p>',4,''),(339783,14017,'119567','printshop-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(339784,14020,'119570','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(339785,14021,'119571','printshop-mobile','text','<p>GIFT CARD</p>',4,''),(339786,14022,'119572','printshop-mobile','logo','themes/printshop-mobile/img/logo-1.png',4,''),(339787,14023,'119573','printshop-mobile','logo','themes/printshop-mobile/img/bestseller-1.png',4,''),(339788,14024,'119574','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339789,14028,'119578','printshop-mobile','text','<p>Your code is:</p>',4,''),(339790,14030,'119580','printshop-mobile','text','<p>HOLBI</p>',4,''),(339791,14031,'119581','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339792,14034,'119584','printshop-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339793,14037,'119587','printshop-mobile','text','<p>HOLBI</p>',4,''),(339794,14038,'119588','printshop-mobile','text','<p>GIFT CARD</p>',4,''),(339795,14039,'119589','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339796,14041,'119591','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(339797,14042,'119592','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339798,14045,'119595','printshop-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339799,14048,'119598','printshop-mobile','text','<p>Your code is:</p>',4,''),(339800,14060,'119610','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339801,14077,'119627','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339802,14089,'119639','printshop-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(339803,14090,'119640','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339804,14092,'119642','printshop-mobile','text','<p>GIFT CARD</p>',4,''),(339805,14094,'119644','printshop-mobile','text','<p>HOLBI</p>',4,''),(339806,14098,'119648','printshop-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(339807,14099,'119649','printshop-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(339808,14101,'119651','printshop-mobile','text','<p>Your code is:</p>',4,''),(339809,14112,'119662','printshop-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(339810,14119,'119669','printshop-mobile','logo','themes/printshop-mobile/img/oscommerce_logo.png',4,''),(339811,14122,'119672','printshop-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',4,''),(339812,14124,'119674','printshop-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',4,''),(339813,14125,'119675','printshop-mobile','logo','themes/printshop-mobile/img/check-2.png',4,''),(339814,14141,'119691','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339816,14148,'119698','printshop-mobile','text','<p>Phone:</p>',4,''),(339817,14153,'119703','printshop-mobile','text','<p>Web:</p>',4,''),(339818,14156,'119706','printshop-mobile','text','<p>Email:</p>',4,''),(339819,14159,'119709','printshop-mobile','text','<p>If undelivered please return to:</p>',4,''),(339820,14161,'119711','printshop-mobile','text','<p>Thank you for your order</p>',4,''),(339822,14164,'119714','printshop-mobile','text','<p>Email:</p>',4,''),(339823,14167,'119717','printshop-mobile','text','<p>Phone:</p>',4,''),(339824,14169,'119719','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339825,14173,'119723','printshop-mobile','text','<p>Shipping via</p>',4,''),(339826,14177,'119727','printshop-mobile','text','<p>Shipping service</p>',4,''),(339827,14180,'119730','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(339828,14184,'119734','printshop-mobile','text','<p>CUSTOMER:</p>',4,''),(339829,14186,'119736','printshop-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339830,14187,'119737','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339831,14193,'119743','printshop-mobile','text','<p>Payment date:</p>',4,''),(339832,14194,'119744','printshop-mobile','text','<p>Payment Method:</p>',4,''),(339833,14196,'119746','printshop-mobile','tab_1','RETURNING CUSTOMER',4,''),(339834,14196,'119746','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(339835,14218,'119768','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(339836,14218,'119768','printshop-mobile','tab_2','RETURNING CUSTOMER',4,''),(339837,14218,'119768','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(339838,14234,'119784','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(339839,14234,'119784','printshop-mobile','tab_2','RETURNING CUSTOMER',4,''),(339840,14234,'119784','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(339841,14247,'119797','printshop-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(339842,14247,'119797','printshop-mobile','tab_2','RETURNING CUSTOMER',4,''),(339843,14247,'119797','printshop-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(339844,14288,'119838','printshop-mobile','tab_1','New products',4,''),(339845,14288,'119838','printshop-mobile','tab_2','Specials products',4,''),(339846,14288,'119838','printshop-mobile','tab_3','Featured',4,''),(339847,14321,'119871','printshop-mobile','tab_1','RETURNING CUSTOMER',4,''),(339848,14321,'119871','printshop-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(339849,14443,'119993','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339850,14449,'119999','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339851,14450,'120000','printshop-mobile','text','<p>CUSTOMER:</p>',4,''),(339852,14451,'120001','printshop-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339853,14455,'120005','printshop-mobile','text','<p>Shipping via</p>',4,''),(339854,14457,'120007','printshop-mobile','text','<p>Shipping service</p>',4,''),(339855,14461,'120011','printshop-mobile','text','<p>If undelivered please return to:</p>',4,''),(339857,14468,'120018','printshop-mobile','text','<p>Phone:</p>',4,''),(339858,14471,'120021','printshop-mobile','text','<p>Web:</p>',4,''),(339859,14474,'120024','printshop-mobile','text','<p>Email:</p>',4,''),(339861,14501,'120051','printshop-mobile','text','osCommerce 4',4,''),(339862,14536,'120086','printshop-mobile','tab_1','Description',4,''),(339863,14536,'120086','printshop-mobile','tab_2','Reviews',4,''),(339864,14581,'120131','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(339865,14586,'120136','printshop-mobile','text','<p>ADDRESS:</p>\n',4,''),(339866,14589,'120139','printshop-mobile','text','<p>CUSTOMER:</p>',4,''),(339867,14590,'120140','printshop-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339868,14591,'120141','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339869,14595,'120145','printshop-mobile','text','<p>Order date:</p>\n',4,''),(339871,14603,'120153','printshop-mobile','text','<p>Email:</p>',4,''),(339872,14606,'120156','printshop-mobile','text','<p>Web:</p>',4,''),(339873,14609,'120159','printshop-mobile','text','<p>Phone:</p>',4,''),(339874,14613,'120163','printshop-mobile','text','<p>If undelivered please return to:</p>',4,''),(339875,14614,'120164','printshop-mobile','text','<p>Thank you for your order</p>',4,''),(339877,14617,'120167','printshop-mobile','text','<p>Phone:</p>',4,''),(339878,14619,'120169','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339879,14621,'120171','printshop-mobile','text','<p>Email:</p>',4,''),(339880,14661,'120211','printshop-mobile','text','<h1>Quotations</h1>',4,''),(339881,14778,'120328','printshop-mobile','logo','themes/printshop-mobile/img/Furntech-1.jpg',4,''),(339882,14802,'120352','printshop-mobile','text','<h1>Samples</h1>',4,''),(339883,14888,'120438','printshop-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',4,''),(339884,14907,'120457','printshop-mobile','text','<p>Phone:</p>',4,''),(339885,14910,'120460','printshop-mobile','text','<p>Web:</p>',4,''),(339886,14913,'120463','printshop-mobile','text','<p>Email:</p>',4,''),(339887,14918,'120468','printshop-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(339888,14921,'120471','printshop-mobile','text','<p>PHONE NUMBER:</p>',4,''),(339889,14922,'120472','printshop-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(339890,14923,'120473','printshop-mobile','text','<p>CUSTOMER:</p>',4,''),(339891,14929,'120479','printshop-mobile','text','<p>Shipping via</p>',4,''),(339892,14933,'120483','printshop-mobile','text','<p>Shipping service</p>',4,''),(339893,14934,'120484','printshop-mobile','text','<p>Payment date:</p>',4,''),(339894,14936,'120486','printshop-mobile','text','<p>Payment Method:</p>',4,''),(339895,14941,'120491','printshop-mobile','text','<p>If undelivered please return to:</p>',4,''),(339897,14944,'120494','printshop-mobile','text','<p>Thank you for your order</p>',4,''),(339898,14946,'120496','printshop-mobile','text','<p>Phone:</p>',4,''),(339899,14948,'120498','printshop-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(339900,14950,'120500','printshop-mobile','text','<p>Email:</p>',4,''),(339901,14956,'120506','printshop-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340026,18022,'118691','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',4,''),(340027,18053,'118722','deals-mobile','logo','themes/deals-mobile/img/payicons-2.png',4,''),(340028,18758,'119427','deals-mobile','text','<p>Shipping via</p>',4,''),(340029,18762,'119431','deals-mobile','text','<p>Shipping service</p>',4,''),(340030,18766,'119435','deals-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(340031,18768,'119437','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340032,18771,'119440','deals-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340033,18772,'119441','deals-mobile','text','<p>CUSTOMER:</p>',4,''),(340034,18775,'119444','deals-mobile','text','<p>Payment date:</p>',4,''),(340035,18779,'119448','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340037,18787,'119456','deals-mobile','text','<p>Email:</p>',4,''),(340038,18790,'119459','deals-mobile','text','<p>Phone:</p>',4,''),(340039,18793,'119462','deals-mobile','text','<p>Web:</p>',4,''),(340040,18798,'119467','deals-mobile','text','<p>If undelivered please return to:</p>',4,''),(340041,18799,'119468','deals-mobile','text','<p>Thank you for your order</p>',4,''),(340043,18802,'119471','deals-mobile','text','<p>Phone:</p>',4,''),(340044,18805,'119474','deals-mobile','text','<p>Email:</p>',4,''),(340045,18807,'119476','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340046,18829,'119498','deals-mobile','text','<p>This is an automatically generated email. We can not reply to a reply to this email.</p>',4,''),(340047,18840,'119509','deals-mobile','logo','themes/deals-mobile/img/logo-white-1.png',4,''),(340048,18861,'119530','deals-mobile','text','Account',4,''),(340049,18866,'119535','deals-mobile','text','Account',4,''),(340050,18868,'119537','deals-mobile','text','Account',4,''),(340051,18872,'119541','deals-mobile','text','Account',4,''),(340052,18884,'119553','deals-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340053,18887,'119556','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340054,18888,'119557','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340055,18889,'119558','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(340056,18890,'119559','deals-mobile','text','<p>GIFT CARD</p>',4,''),(340057,18892,'119561','deals-mobile','text','<p>Your code is:</p>',4,''),(340058,18896,'119565','deals-mobile','text','<p>HOLBI</p>',4,''),(340059,18898,'119567','deals-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(340060,18901,'119570','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(340061,18902,'119571','deals-mobile','text','<p>GIFT CARD</p>',4,''),(340062,18903,'119572','deals-mobile','logo','themes/deals-mobile/img/logo-1.png',4,''),(340063,18904,'119573','deals-mobile','logo','themes/deals-mobile/img/bestseller-1.png',4,''),(340064,18905,'119574','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340065,18909,'119578','deals-mobile','text','<p>Your code is:</p>',4,''),(340066,18911,'119580','deals-mobile','text','<p>HOLBI</p>',4,''),(340067,18912,'119581','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340068,18915,'119584','deals-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340069,18918,'119587','deals-mobile','text','<p>HOLBI</p>',4,''),(340070,18919,'119588','deals-mobile','text','<p>GIFT CARD</p>',4,''),(340071,18920,'119589','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340072,18922,'119591','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(340073,18923,'119592','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340074,18926,'119595','deals-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340075,18929,'119598','deals-mobile','text','<p>Your code is:</p>',4,''),(340076,18941,'119610','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340077,18958,'119627','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340078,18970,'119639','deals-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk</p>',4,''),(340079,18971,'119640','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340080,18973,'119642','deals-mobile','text','<p>GIFT CARD</p>',4,''),(340081,18975,'119644','deals-mobile','text','<p>HOLBI</p>',4,''),(340082,18979,'119648','deals-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340083,18980,'119649','deals-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340084,18982,'119651','deals-mobile','text','<p>Your code is:</p>',4,''),(340085,18993,'119662','deals-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340086,19000,'119669','deals-mobile','logo','themes/deals-mobile/img/oscommerce_logo.png',4,''),(340087,19003,'119672','deals-mobile','text','Want&nbsp; to&nbsp; have&nbsp; a&nbsp; super fast, feature-rich, secure online store (just like&nbsp; this one!) for your own business? Just <a href=\"https://www.holbi.co.uk/contact-us\" style=\"text-decoration: underline\">follow this link</a> and fill in&nbsp; the&nbsp; form&nbsp; to&nbsp; receive&nbsp; a&nbsp; free&nbsp; advise&nbsp; from&nbsp; one of our business development experts.',4,''),(340088,19005,'119674','deals-mobile','text','<p><strong>High security&nbsp;</strong>formats are supported</p>',4,''),(340089,19006,'119675','deals-mobile','logo','themes/deals-mobile/img/check-2.png',4,''),(340090,19022,'119691','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340092,19029,'119698','deals-mobile','text','<p>Phone:</p>',4,''),(340093,19034,'119703','deals-mobile','text','<p>Web:</p>',4,''),(340094,19037,'119706','deals-mobile','text','<p>Email:</p>',4,''),(340095,19040,'119709','deals-mobile','text','<p>If undelivered please return to:</p>',4,''),(340096,19042,'119711','deals-mobile','text','<p>Thank you for your order</p>',4,''),(340098,19045,'119714','deals-mobile','text','<p>Email:</p>',4,''),(340099,19048,'119717','deals-mobile','text','<p>Phone:</p>',4,''),(340100,19050,'119719','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340101,19054,'119723','deals-mobile','text','<p>Shipping via</p>',4,''),(340102,19058,'119727','deals-mobile','text','<p>Shipping service</p>',4,''),(340103,19061,'119730','deals-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(340104,19065,'119734','deals-mobile','text','<p>CUSTOMER:</p>',4,''),(340105,19067,'119736','deals-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340106,19068,'119737','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340107,19074,'119743','deals-mobile','text','<p>Payment date:</p>',4,''),(340108,19075,'119744','deals-mobile','text','<p>Payment Method:</p>',4,''),(340109,19077,'119746','deals-mobile','tab_1','RETURNING CUSTOMER',4,''),(340110,19077,'119746','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(340111,19099,'119768','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(340112,19099,'119768','deals-mobile','tab_2','RETURNING CUSTOMER',4,''),(340113,19099,'119768','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(340114,19115,'119784','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(340115,19115,'119784','deals-mobile','tab_2','RETURNING CUSTOMER',4,''),(340116,19115,'119784','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(340117,19128,'119797','deals-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(340118,19128,'119797','deals-mobile','tab_2','RETURNING CUSTOMER',4,''),(340119,19128,'119797','deals-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(340120,19169,'119838','deals-mobile','tab_1','New products',4,''),(340121,19169,'119838','deals-mobile','tab_2','Specials products',4,''),(340122,19169,'119838','deals-mobile','tab_3','Featured',4,''),(340123,19202,'119871','deals-mobile','tab_1','RETURNING CUSTOMER',4,''),(340124,19202,'119871','deals-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(340125,19324,'119993','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340126,19330,'119999','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340127,19331,'120000','deals-mobile','text','<p>CUSTOMER:</p>',4,''),(340128,19332,'120001','deals-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340129,19336,'120005','deals-mobile','text','<p>Shipping via</p>',4,''),(340130,19338,'120007','deals-mobile','text','<p>Shipping service</p>',4,''),(340131,19342,'120011','deals-mobile','text','<p>If undelivered please return to:</p>',4,''),(340133,19349,'120018','deals-mobile','text','<p>Phone:</p>',4,''),(340134,19352,'120021','deals-mobile','text','<p>Web:</p>',4,''),(340135,19355,'120024','deals-mobile','text','<p>Email:</p>',4,''),(340137,19382,'120051','deals-mobile','text','osCommerce 4',4,''),(340138,19417,'120086','deals-mobile','tab_1','Description',4,''),(340139,19417,'120086','deals-mobile','tab_2','Reviews',4,''),(340140,19462,'120131','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340141,19467,'120136','deals-mobile','text','<p>ADDRESS:</p>\n',4,''),(340142,19470,'120139','deals-mobile','text','<p>CUSTOMER:</p>',4,''),(340143,19471,'120140','deals-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340144,19472,'120141','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340145,19476,'120145','deals-mobile','text','<p>Order date:</p>\n',4,''),(340147,19484,'120153','deals-mobile','text','<p>Email:</p>',4,''),(340148,19487,'120156','deals-mobile','text','<p>Web:</p>',4,''),(340149,19490,'120159','deals-mobile','text','<p>Phone:</p>',4,''),(340150,19494,'120163','deals-mobile','text','<p>If undelivered please return to:</p>',4,''),(340151,19495,'120164','deals-mobile','text','<p>Thank you for your order</p>',4,''),(340153,19498,'120167','deals-mobile','text','<p>Phone:</p>',4,''),(340154,19500,'120169','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340155,19502,'120171','deals-mobile','text','<p>Email:</p>',4,''),(340156,19542,'120211','deals-mobile','text','<h1>Quotations</h1>',4,''),(340157,19659,'120328','deals-mobile','logo','themes/deals-mobile/img/Furntech-1.jpg',4,''),(340158,19683,'120352','deals-mobile','text','<h1>Samples</h1>',4,''),(340159,19769,'120438','deals-mobile','text','<div class=\"page-success\">\r\n<div class=\"text-1\">Thank you</div>\r\n\r\n<div class=\"text-2\">We\'ve received your order</div>\r\n\r\n<div class=\"text-3\">We\'ll send you order status update by email</div>\r\n</div>',4,''),(340160,19788,'120457','deals-mobile','text','<p>Phone:</p>',4,''),(340161,19791,'120460','deals-mobile','text','<p>Web:</p>',4,''),(340162,19794,'120463','deals-mobile','text','<p>Email:</p>',4,''),(340163,19799,'120468','deals-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(340164,19802,'120471','deals-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340165,19803,'120472','deals-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340166,19804,'120473','deals-mobile','text','<p>CUSTOMER:</p>',4,''),(340167,19810,'120479','deals-mobile','text','<p>Shipping via</p>',4,''),(340168,19814,'120483','deals-mobile','text','<p>Shipping service</p>',4,''),(340169,19815,'120484','deals-mobile','text','<p>Payment date:</p>',4,''),(340170,19817,'120486','deals-mobile','text','<p>Payment Method:</p>',4,''),(340171,19822,'120491','deals-mobile','text','<p>If undelivered please return to:</p>',4,''),(340173,19825,'120494','deals-mobile','text','<p>Thank you for your order</p>',4,''),(340174,19827,'120496','deals-mobile','text','<p>Phone:</p>',4,''),(340175,19829,'120498','deals-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340176,19831,'120500','deals-mobile','text','<p>Email:</p>',4,''),(340177,19837,'120506','deals-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340310,54257,'116269','furniture-mobile','logo','themes/furniture-mobile/img/payicons-1.png',4,''),(340311,55017,'116977','furniture-mobile','text','<p>If undelivered please return to:</p>',4,''),(340312,55018,'116978','furniture-mobile','text','<p>Thank you for your order</p>',4,''),(340314,55020,'116980','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340315,55022,'116982','furniture-mobile','text','<p>Email:</p>',4,''),(340316,55025,'116985','furniture-mobile','text','<p>Phone:</p>',4,''),(340318,55031,'116991','furniture-mobile','text','<p>Web:</p>',4,''),(340319,55034,'116994','furniture-mobile','text','<p>Phone:</p>',4,''),(340320,55037,'116997','furniture-mobile','text','<p>Email:</p>',4,''),(340321,55044,'117004','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340322,55049,'117009','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(340323,55053,'117013','furniture-mobile','text','<p>CUSTOMER:</p>',4,''),(340324,55054,'117014','furniture-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340325,55057,'117017','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340326,55061,'117021','furniture-mobile','text','<p>Shipping via</p>',4,''),(340327,55063,'117023','furniture-mobile','text','<p>Shipping service</p>',4,''),(340328,55066,'117026','furniture-mobile','text','<p>Payment date:</p>',4,''),(340329,55101,'117055','furniture-mobile','logo','themes/furniture-mobile/img/logo-white-1.png',4,''),(340330,55150,'117107','furniture-mobile','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(340331,55155,'117112','furniture-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340332,55157,'117114','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340333,55158,'117115','furniture-mobile','text','<p>osCommerce</p>\n',4,''),(340334,55160,'117117','furniture-mobile','text','<p>Your code is:</p>',4,''),(340335,55164,'117121','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340336,55165,'117123','furniture-mobile','logo','themes/furniture-mobile/img/Logo-1.jpg',4,''),(340337,55166,'117124','furniture-mobile','text','<p>GIFT CARD</p>',4,''),(340338,55167,'117125','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(340339,55171,'117129','furniture-mobile','text','<p>Your code is:</p>',4,''),(340340,55175,'117133','furniture-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340341,55178,'117136','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340342,55179,'117137','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(340343,55180,'117138','furniture-mobile','text','<p>GIFT CARD</p>',4,''),(340344,55181,'117139','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340345,55192,'117150','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340346,55209,'117167','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340347,55221,'117180','furniture-mobile','text','<p>Your code is:</p>',4,''),(340348,55223,'117182','furniture-mobile','text','<p>WHAT TO DO NEXT:</p>',4,''),(340349,55225,'117185','furniture-mobile','text','<p>If you require further assistance please contact us</p>',4,''),(340350,55229,'117189','furniture-mobile','text','<p>GIFT CARD</p>',4,''),(340351,55230,'117190','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340352,55232,'117192','furniture-mobile','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(340353,55243,'117202','furniture-mobile','text','<p>PERSONAL MESSAGE</p>',4,''),(340355,55258,'117218','furniture-mobile','logo','themes/furniture-mobile/img/header-img-1.png',4,''),(340356,55279,'117234','furniture-mobile','text','<p>Shipping via</p>',4,''),(340357,55281,'117236','furniture-mobile','text','<p>Shipping service</p>',4,''),(340358,55285,'117240','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(340359,55289,'117243','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340360,55292,'117246','furniture-mobile','text','<p>CUSTOMER:</p>',4,''),(340361,55293,'117247','furniture-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340362,55296,'117250','furniture-mobile','text','<p>Payment Method:</p>',4,''),(340363,55297,'117251','furniture-mobile','text','<p>Payment date:</p>',4,''),(340364,55303,'117257','furniture-mobile','text','<p>If undelivered please return to:</p>',4,''),(340365,55304,'117258','furniture-mobile','text','<p>Thank you for your order</p>',4,''),(340366,55306,'117261','furniture-mobile','text','<p>Email:</p>',4,''),(340367,55309,'117264','furniture-mobile','text','<p>Phone:</p>',4,''),(340368,55311,'117266','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340369,55316,'117271','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340370,55320,'117275','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',4,''),(340371,55322,'117277','furniture-mobile','text','<p>Web:</p>',4,''),(340372,55325,'117280','furniture-mobile','text','<p>Email:</p>',4,''),(340373,55330,'117285','furniture-mobile','text','<p>Phone:</p>',4,''),(340374,55337,'117288','furniture-mobile','tab_1','RETURNING CUSTOMER',4,''),(340375,55337,'117288','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(340376,55360,'117311','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(340377,55360,'117311','furniture-mobile','tab_2','RETURNING CUSTOMER',4,''),(340378,55360,'117311','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(340379,55376,'117327','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(340380,55376,'117327','furniture-mobile','tab_2','RETURNING CUSTOMER',4,''),(340381,55376,'117327','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(340382,55393,'117344','furniture-mobile','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(340383,55393,'117344','furniture-mobile','tab_2','RETURNING CUSTOMER',4,''),(340384,55393,'117344','furniture-mobile','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(340385,55486,'117416','furniture-mobile','tab_1','RETURNING CUSTOMER',4,''),(340386,55486,'117416','furniture-mobile','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(340387,55663,'117536','furniture-mobile','logo','themes/furniture-mobile/img/logonew-1.jpg',4,''),(340388,55665,'117538','furniture-mobile','text','<p>Email:</p>',4,''),(340389,55668,'117541','furniture-mobile','text','<p>Phone:</p>',4,''),(340390,55673,'117546','furniture-mobile','text','<p>Web:</p>',4,''),(340391,55678,'117551','furniture-mobile','text','<p>If undelivered please return to:</p>',4,''),(340392,55683,'117556','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340393,55685,'117558','furniture-mobile','text','<p>CUSTOMER:</p>',4,''),(340394,55688,'117561','furniture-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340395,55690,'117563','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340396,55694,'117567','furniture-mobile','text','<p>Shipping via</p>',4,''),(340397,55697,'117570','furniture-mobile','text','<p>Shipping service</p>',4,''),(340398,55726,'117596','furniture-mobile','logo','themes/furniture-mobile/img/oscommerce_logo-1.jpg',4,''),(340399,55727,'117597','furniture-mobile','text','osCommerce 4',4,''),(340400,55764,'117646','furniture-mobile','tab_1','Product Overview',4,''),(340401,55764,'117646','furniture-mobile','tab_2','Delivery and returns',4,''),(340402,55764,'117646','furniture-mobile','tab_3','Assembly',4,''),(340403,55882,'117702','furniture-mobile','text','<p>If undelivered please return to:</p>',4,''),(340404,55884,'117704','furniture-mobile','text','<p>Thank you for your order</p>',4,''),(340406,55887,'117707','furniture-mobile','text','<p>Email:</p>',4,''),(340407,55889,'117709','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340408,55891,'117711','furniture-mobile','text','<p>Phone:</p>',4,''),(340410,55896,'117716','furniture-mobile','text','<p>Phone:</p>',4,''),(340411,55899,'117719','furniture-mobile','text','<p>Web:</p>',4,''),(340412,55904,'117724','furniture-mobile','text','<p>Email:</p>',4,''),(340413,55910,'117730','furniture-mobile','text','<p>ADDRESS:</p>\n',4,''),(340414,55913,'117733','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340415,55916,'117736','furniture-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340416,55917,'117737','furniture-mobile','text','<p>CUSTOMER:</p>',4,''),(340417,55919,'117739','furniture-mobile','text','<p>Order date:</p>\n',4,''),(340418,55924,'117744','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340419,56056,'117816','furniture-mobile','logo','themes/furniture-mobile/img/Furntech-1.jpg',4,''),(340420,56314,'118011','furniture-mobile','text','<p>SHIPPING ADDRESS:</p>',4,''),(340421,56318,'118015','furniture-mobile','text','<p>If undelivered please return to:</p>',4,''),(340422,56320,'118018','furniture-mobile','text','<p>Thank you for your order</p>',4,''),(340423,56321,'118019','furniture-mobile','text','<p>If something has gone wrong please contact us at:</p>',4,''),(340424,56323,'118021','furniture-mobile','text','<p>Email:</p>',4,''),(340425,56326,'118024','furniture-mobile','text','<p>Phone:</p>',4,''),(340426,56331,'118029','furniture-mobile','text','<p>Email:</p>',4,''),(340427,56334,'118032','furniture-mobile','text','<p>Web:</p>',4,''),(340428,56339,'118037','furniture-mobile','text','<p>Phone:</p>',4,''),(340429,56344,'118042','furniture-mobile','text','<p>Shipping via</p>',4,''),(340430,56347,'118045','furniture-mobile','text','<p>Shipping service</p>',4,''),(340431,56352,'118050','furniture-mobile','text','<p>INVOICE ADDRESS:</p>',4,''),(340432,56355,'118053','furniture-mobile','text','<p>PHONE NUMBER:</p>',4,''),(340433,56358,'118056','furniture-mobile','text','<p>E-MAIL ADDRESS:</p>',4,''),(340434,56359,'118057','furniture-mobile','text','<p>CUSTOMER:</p>',4,''),(340435,56361,'118059','furniture-mobile','text','<p>Payment date:</p>',4,''),(340436,56362,'118060','furniture-mobile','text','<p>Payment Method:</p>',4,''),(340701,108868,'117051','splash','logo','themes/splash/img/oscommerce_logo_(2)-1.png',4,''),(340702,108918,'1661353032.672459','splash','logo','themes/splash/img/oscommerce_logo.jpg',4,''),(340703,108933,'1640168618.7708','splash','logo','themes/splash/img/oscommerce_logo (2).png',4,''),(340704,108936,'1640169872.1589','splash','img_link','furniture/',4,''),(340705,108936,'1640169872.1589','splash','logo','themes/splash/img/Splash_furniture_BGlogo.png',4,''),(340706,108936,'1640169872.1589','splash','target_blank','1',4,''),(340707,108937,'1640276640.1123','splash','text','<h1>osCommerce v4 Splash page</h1>\r\n\r\n<p>osCommerce supports multiple sales CHANNELS.</p>\r\n\r\n<p>Your installation of osCommerce comes with &nbsp;&quot;Furniture&quot;, &quot;Watch&quot;, &quot;B2B Supermarket&quot;, and &quot;Print shop&quot; Ecommerce sales channels and &quot;cms&quot; brochure website example.</p>\r\n\r\n<p>Each sales channel has its own URLs, design, and demo product sets.</p>\r\n\r\n<p>&quot;Admin&quot; is the back end of your osCommerce.</p>\r\n\r\n<p>Use osCommerce Wiki to learn how to manage sales channels, &nbsp;assign design themes, and content to the sales channels.<br />\r\nThank you for choosing &nbsp;osCommerce - the most powerful on-premise open source Ecommerce platform!</p>\r\n',4,''),(340708,108938,'1640170154.7803','splash','img_link','watch/',4,''),(340709,108938,'1640170154.7803','splash','logo','themes/splash/img/Splash_watch_BGlogo.png',4,''),(340710,108938,'1640170154.7803','splash','target_blank','1',4,''),(340711,108940,'1640170023.0001','splash','img_link','printshop/',4,''),(340712,108940,'1640170023.0001','splash','logo','themes/splash/img/print shop.jpg',4,''),(340713,108940,'1640170023.0001','splash','target_blank','1',4,''),(340714,108941,'1640170023.1491','splash','img_link','admin/',4,''),(340715,108941,'1640170023.1491','splash','logo','themes/splash/img/Splash_admin_BGlogo.png',4,''),(340716,108941,'1640170023.1491','splash','target_blank','1',4,''),(340717,108942,'1640170023','splash','img_link','b2b-supermarket/',4,''),(340718,108942,'1640170023','splash','logo','themes/splash/img/b2b supermarket.jpg',4,''),(340719,108942,'1640170023','splash','target_blank','1',4,''),(340720,108945,'1661353032.975845','splash','logo','themes/splash/img/oscommerce_logo-1.jpg',4,''),(340721,109001,'74702','splash','logo','themes/splash/img/oscommerce_logo.jpg',4,''),(340722,109002,'74703','splash','text','osCommerce 4',4,''),(340832,109007,'116005','furniture','text','##TEXT_PAGE_NOT_FOUND##',0,''),(340833,109007,'116005','furniture','text-align','center',0,''),(340834,109007,'116005','furniture','padding-top','100',0,''),(340835,109007,'116005','furniture','padding-bottom','100',0,''),(340836,109008,'116006','furniture','block_type','1',0,''),(340955,109024,'116022','furniture','block_type','1',0,''),(341074,109040,'116038','furniture','block_type','1',0,''),(341193,109056,'116054','furniture','block_type','1',0,''),(341312,109072,'116070','furniture','block_type','1',0,''),(341431,109088,'116086','furniture','block_type','1',0,''),(341550,109104,'116102','furniture','block_type','1',0,''),(341551,109104,'116102','furniture','style_class','account-index',0,''),(341788,109167,'116145','furniture','block_type','1',0,''),(341789,109167,'116145','furniture','style_class','account-edit-wrap',0,''),(341851,109191,'116150','furniture','block_type','1',0,''),(341852,109191,'116150','furniture','style_class','account-address-book',0,''),(341923,109216,'116156','furniture','block_type','1',0,''),(341924,109216,'116156','furniture','style_class','account-address-book-process',0,''),(341986,109240,'117906.000001','furniture','block_type','1',0,''),(341987,109240,'117906.000001','furniture','style_class','item-holder',0,''),(341988,109240,'117906.000001','furniture','padding-top','25',0,''),(341989,109240,'117906.000001','furniture','padding-bottom','25',0,''),(341990,109240,'117906.000001','furniture','text-align','left',0,''),(341991,109240,'117906.000001','furniture','border-top-width','1',0,''),(341992,109240,'117906.000001','furniture','border-top-color','$content-border-1',0,''),(341993,109241,'117907.000001','furniture','block_type','7',0,''),(341994,109241,'117907.000001','furniture','schema','7-2',0,'5140'),(341995,109242,'117908.000001','furniture','block_type','5',0,''),(341996,109242,'117908.000001','furniture','schema','5-2',0,'5140'),(341997,109243,'117909.000001','furniture','clear','none',0,''),(341998,109243,'117909.000001','furniture','padding-right','20',0,''),(341999,109244,'117910.000001','furniture','padding-right','20',0,''),(342000,109244,'117910.000001','furniture','max-width','300',0,'5140'),(342001,109244,'117910.000001','furniture','margin_left_measure','auto',0,'5140'),(342002,109244,'117910.000001','furniture','margin_right_measure','auto',0,'5140'),(342003,109245,'117914.000001','furniture','padding-right','20',0,''),(342004,109246,'117915.000001','furniture','description_characters','200',0,''),(342005,109246,'117915.000001','furniture','clear','none',0,''),(342006,109246,'117915.000001','furniture','padding-right','20',0,''),(342007,109247,'117916.000001','furniture','clear','none',0,''),(342008,109248,'117917.000001','furniture','margin-bottom','20',0,''),(342009,109250,'117918.000001','furniture','block_type','1',0,''),(342010,109250,'117918.000001','furniture','padding-left','40',0,''),(342011,109250,'117918.000001','furniture','style_class','right-aria',0,''),(342012,109250,'117918.000001','furniture','padding-left','0',0,'5140'),(342013,109251,'117911.000001','furniture','block_type','1',0,''),(342014,109251,'117911.000001','furniture','text-align','center',0,''),(342015,109252,'117912.000001','furniture','margin-top','4',0,''),(342016,109252,'117912.000001','furniture','margin-bottom','7',0,''),(342017,109253,'117913.000001','furniture','padding-top','6',0,''),(342018,109253,'117913.000001','furniture','padding-left','5',0,''),(342019,109254,'117919.000001','furniture','margin-bottom','15',0,''),(342020,109254,'117919.000001','furniture','text-align','right',0,''),(342021,109255,'117920.000001','furniture','margin-bottom','10',0,''),(342022,109255,'117920.000001','furniture','text-align','center',0,''),(342023,109256,'117922.000001','furniture','text-align','right',0,''),(342024,109256,'117922.000001','furniture','margin-bottom','15',0,''),(342025,109257,'117924.000001','furniture','text-align','center',0,''),(342026,109257,'117924.000001','furniture','margin-bottom','10',0,''),(342027,109258,'120924.000001','furniture','block_type','1',0,''),(342028,109258,'120924.000001','furniture','style_class','item-nav',0,''),(342029,109262,'116176','furniture','block_type','1',0,''),(342030,109262,'116176','furniture','style_class','item-holder',0,''),(342031,109262,'116176','furniture','padding-top','25',0,''),(342032,109262,'116176','furniture','padding-left','25',0,''),(342033,109262,'116176','furniture','padding-right','25',0,''),(342034,109262,'116176','furniture','padding-bottom','25',0,''),(342035,109262,'116176','furniture','text-align','left',0,''),(342036,109264,'116178','furniture','margin-bottom','7',0,''),(342037,109265,'116179','furniture','clear','both',0,''),(342038,109268,'116182','furniture','block_type','1',0,''),(342039,109268,'116182','furniture','style_class','item-holder',0,''),(342040,109268,'116182','furniture','padding-top','25',0,''),(342041,109268,'116182','furniture','padding-left','25',0,''),(342042,109268,'116182','furniture','padding-right','25',0,''),(342043,109268,'116182','furniture','padding-bottom','25',0,''),(342044,109268,'116182','furniture','text-align','left',0,''),(342045,109269,'116183','furniture','block_type','5',0,'');
INSERT INTO `design_boxes_settings_tmp` VALUES (342046,109272,'116186','furniture','margin-bottom','7',0,''),(342047,109273,'116187','furniture','clear','both',0,''),(342048,109274,'116188','furniture','block_type','1',0,''),(342049,109275,'116189','furniture','block_type','6',0,''),(342050,109275,'116189','furniture','font-weight','400',0,''),(342051,109275,'116189','furniture','schema','6-2',0,'5161'),(342052,109275,'116189','furniture','schema','6-2',0,'5140'),(342053,109276,'116190','furniture','font-weight','400',0,''),(342054,109276,'116190','furniture','padding-right','40',0,''),(342055,109276,'116190','furniture','padding-right','0',0,'5161'),(342056,109276,'116190','furniture','padding-right','0',0,'5140'),(342057,109277,'116191','furniture','block_type','5',0,''),(342058,109277,'116191','furniture','padding-top','10',0,''),(342059,109277,'116191','furniture','padding-bottom','10',0,''),(342060,109277,'116191','furniture','schema','5-2',0,'5161'),(342061,109277,'116191','furniture','border-top-color','$content-border-1',0,''),(342062,109277,'116191','furniture','border-top-width','1',0,''),(342063,109279,'116193','furniture','float','right',0,''),(342064,109281,'116195','furniture','col_in_row','3',0,''),(342065,109281,'116195','furniture','products_align','left',0,''),(342066,109281,'116195','furniture','font-weight','400',0,''),(342067,109281,'116195','furniture','show_qty_input','0',0,''),(342068,109281,'116195','furniture','listing_type','productListing',0,''),(342069,109281,'116195','furniture','listing_type_rows','no',0,''),(342070,109281,'116195','furniture','show_buy_button_b2b','on',0,''),(342071,109281,'116195','furniture','show_wishlist_button_b2b','1',0,''),(342072,109281,'116195','furniture','show_compare_b2b','1',0,''),(342073,109281,'116195','furniture','show_stock','0',0,''),(342074,109281,'116195','furniture','show_description','0',0,''),(342075,109281,'116195','furniture','show_model','0',0,''),(342076,109281,'116195','furniture','show_properties','0',0,''),(342077,109281,'116195','furniture','show_rating','0',0,''),(342078,109281,'116195','furniture','show_rating_counts','0',0,''),(342079,109281,'116195','furniture','show_price','0',0,''),(342080,109281,'116195','furniture','show_buy_button','0',0,''),(342081,109281,'116195','furniture','show_view_button','0',0,''),(342082,109281,'116195','furniture','show_wishlist_button','0',0,''),(342083,109281,'116195','furniture','show_compare','0',0,''),(342084,109281,'116195','furniture','show_name_rows','0',0,''),(342085,109281,'116195','furniture','show_image_rows','0',0,''),(342086,109281,'116195','furniture','show_stock_rows','0',0,''),(342087,109281,'116195','furniture','show_description_rows','0',0,''),(342088,109281,'116195','furniture','show_model_rows','0',0,''),(342089,109281,'116195','furniture','show_properties_rows','0',0,''),(342090,109281,'116195','furniture','show_rating_rows','0',0,''),(342091,109281,'116195','furniture','show_rating_counts_rows','0',0,''),(342092,109281,'116195','furniture','show_price_rows','0',0,''),(342093,109281,'116195','furniture','show_buy_button_rows','0',0,''),(342094,109281,'116195','furniture','show_qty_input_rows','0',0,''),(342095,109281,'116195','furniture','show_view_button_rows','0',0,''),(342096,109281,'116195','furniture','show_wishlist_button_rows','0',0,''),(342097,109281,'116195','furniture','show_compare_rows','0',0,''),(342098,109281,'116195','furniture','show_name_b2b','0',0,''),(342099,109281,'116195','furniture','show_image_b2b','0',0,''),(342100,109281,'116195','furniture','show_stock_b2b','0',0,''),(342101,109281,'116195','furniture','show_description_b2b','0',0,''),(342102,109281,'116195','furniture','show_model_b2b','0',0,''),(342103,109281,'116195','furniture','show_properties_b2b','0',0,''),(342104,109281,'116195','furniture','show_rating_b2b','0',0,''),(342105,109281,'116195','furniture','show_rating_counts_b2b','0',0,''),(342106,109281,'116195','furniture','show_price_b2b','0',0,''),(342107,109281,'116195','furniture','show_qty_input_b2b','0',0,''),(342108,109281,'116195','furniture','show_view_button_b2b','0',0,''),(342109,109281,'116195','furniture','show_attributes_b2b','0',0,''),(342110,109281,'116195','furniture','items_on_page','9',0,''),(342111,109281,'116195','furniture','col_in_row','2',0,'5140'),(342112,109281,'116195','furniture','col_in_row','1',0,'5161'),(342113,109281,'116195','furniture','product_names_teg','h2',0,''),(342114,109282,'116196','furniture','listing_type','productListing',0,''),(342115,109283,'116197','furniture','block_type','1',0,''),(342116,109283,'116197','furniture','padding-top','10',0,''),(342117,109283,'116197','furniture','padding-bottom','10',0,''),(342118,109283,'116197','furniture','border-bottom-width','1',0,''),(342119,109283,'116197','furniture','border-bottom-color','$content-border-1',0,''),(342120,109283,'116197','furniture','margin-left','0',0,''),(342121,109283,'116197','furniture','margin-right','0',0,''),(342122,109284,'116198','furniture','float','right',0,''),(342123,109284,'116198','furniture','display','none',0,'5161'),(342124,109285,'116199','furniture','margin-right','20',0,''),(342125,109285,'116199','furniture','float','right',0,''),(342126,109285,'116199','furniture','clear','none',0,''),(342127,109285,'116199','furniture','display','none',0,'5140'),(342128,109286,'116200','furniture','float','left',0,''),(342129,109286,'116200','furniture','clear','none',0,''),(342130,109286,'116200','furniture','margin-left','20',0,''),(342131,109286,'116200','furniture','display','none',0,'5161'),(342132,109287,'116201','furniture','float','left',0,''),(342133,109287,'116201','furniture','clear','none',0,''),(342134,109287,'116201','furniture','sort_pos_3','1',0,''),(342135,109287,'116201','furniture','sort_pos_4','2',0,''),(342136,109287,'116201','furniture','sort_pos_10','3',0,''),(342137,109287,'116201','furniture','sort_pos_9','4',0,''),(342138,109287,'116201','furniture','sort_pos_11','5',0,''),(342139,109287,'116201','furniture','sort_pos_12','6',0,''),(342140,109287,'116201','furniture','sort_pos_14','7',0,''),(342141,109287,'116201','furniture','sort_pos_13','8',0,''),(342142,109287,'116201','furniture','sort_pos_8','9',0,''),(342143,109287,'116201','furniture','sort_pos_7','10',0,''),(342144,109287,'116201','furniture','sort_pos_2','11',0,''),(342145,109287,'116201','furniture','sort_pos_1','12',0,''),(342146,109287,'116201','furniture','sort_pos_6','13',0,''),(342147,109287,'116201','furniture','sort_pos_5','14',0,''),(342148,109287,'116201','furniture','sort_pos_0','15',0,''),(342149,109287,'116201','furniture','sort_hide_10','1',0,''),(342150,109287,'116201','furniture','sort_hide_9','1',0,''),(342151,109287,'116201','furniture','hide_icons','1',0,''),(342152,109287,'116201','furniture','sort_hide_16','1',0,''),(342153,109287,'116201','furniture','sort_hide_15','1',0,''),(342154,109287,'116201','furniture','sort_hide_3','0',0,''),(342155,109287,'116201','furniture','sort_hide_4','0',0,''),(342156,109287,'116201','furniture','sort_hide_11','1',0,''),(342157,109287,'116201','furniture','sort_hide_12','1',0,''),(342158,109287,'116201','furniture','sort_hide_14','1',0,''),(342159,109287,'116201','furniture','sort_hide_13','1',0,''),(342160,109287,'116201','furniture','sort_hide_8','0',0,''),(342161,109287,'116201','furniture','sort_hide_7','0',0,''),(342162,109287,'116201','furniture','sort_hide_2','1',0,''),(342163,109287,'116201','furniture','sort_hide_1','1',0,''),(342164,109287,'116201','furniture','sort_hide_6','1',0,''),(342165,109287,'116201','furniture','sort_hide_5','1',0,''),(342166,109287,'116201','furniture','sort_hide_0','1',0,''),(342167,109290,'1683103176.926637','furniture','block_type','1',0,''),(342168,109290,'1683103176.926637','furniture','font-weight','normal',0,''),(342169,109290,'1683103176.926637','furniture','padding-top','20',0,''),(342170,109290,'1683103176.926637','furniture','background-color','$content-bg-2',0,''),(342171,109290,'1683103176.926637','furniture','style_class','shopping-cart-index',0,''),(342172,109291,'1683103176.947325','furniture','block_type','4',0,''),(342173,109291,'1683103176.947325','furniture','schema','4-1',0,'5145'),(342174,109291,'1683103176.947325','furniture','schema','4-2',0,'5140'),(342175,109292,'1683103176.971768','furniture','block_type','1',0,''),(342176,109292,'1683103176.971768','furniture','background-color','$content-bg-1',0,''),(342177,109292,'1683103176.971768','furniture','margin-bottom','25',0,''),(342178,109292,'1683103176.971768','furniture','padding-left','25',0,''),(342179,109292,'1683103176.971768','furniture','padding-right','25',0,''),(342180,109292,'1683103176.971768','furniture','padding-bottom','25',0,''),(342181,109293,'1683103176.974446','furniture','padding-top','20',0,''),(342182,109293,'1683103176.974446','furniture','padding-bottom','20',0,''),(342183,109294,'1683103176.975161','furniture','block_type','2',0,''),(342184,109294,'1683103176.975161','furniture','padding-bottom','20',0,''),(342185,109294,'1683103176.975161','furniture','padding-top','20',0,''),(342186,109294,'1683103176.975161','furniture','border-bottom-color','$content-border-1',0,''),(342187,109294,'1683103176.975161','furniture','border-bottom-width','1',0,''),(342188,109294,'1683103176.975161','furniture','schema','2-2',0,'5140'),(342189,109295,'1683103176.976938','furniture','float','left',0,''),(342190,109295,'1683103176.976938','furniture','float','none',0,'5140'),(342191,109296,'1683103176.977748','furniture','text-align','right',0,''),(342192,109296,'1683103176.977748','furniture','clear','none',0,''),(342193,109296,'1683103176.977748','furniture','float','right',0,''),(342194,109296,'1683103176.977748','furniture','padding-top','22',0,''),(342195,109296,'1683103176.977748','furniture','float','none',0,'5140'),(342196,109296,'1683103176.977748','furniture','text-align','left',0,'5140'),(342197,109297,'1683103176.9792','furniture','float','right',0,''),(342198,109297,'1683103176.9792','furniture','padding-top','26',0,''),(342199,109297,'1683103176.9792','furniture','float','none',0,'5140'),(342200,109297,'1683103176.9792','furniture','text-align','left',0,'5140'),(342201,109298,'1683103176.9841','furniture','block_type','3',0,''),(342202,109298,'1683103176.9841','furniture','font-weight','400',0,''),(342203,109298,'1683103176.9841','furniture','schema','2-2',0,'5131'),(342204,109298,'1683103176.9841','furniture','style_class','closeable-content',0,''),(342205,109298,'1683103176.9841','furniture','padding-top','10',0,''),(342206,109300,'1683103176.982975','furniture','padding-right','24',0,''),(342207,109300,'1683103176.982975','furniture','padding-right','0',0,'5131'),(342208,109300,'1683103176.982975','furniture','padding-bottom','20',0,'5131'),(342209,109301,'1683103176.983866','furniture','text-align','right',0,''),(342210,109302,'1683103176.985151','furniture','text','<div><span>##TEXT_YOUR_SHOPPING_CART##</span></div>',0,''),(342211,109302,'1683103176.985151','furniture','font-size','36',0,''),(342212,109302,'1683103176.985151','furniture','text-align','center',0,''),(342213,109302,'1683103176.985151','furniture','padding-top','20',0,''),(342214,109302,'1683103176.985151','furniture','margin-bottom','20',0,''),(342215,109302,'1683103176.985151','furniture','style_class','cartTitle',0,''),(342216,109302,'1683103176.985151','furniture','font-weight','600',0,''),(342217,109303,'1683103176.987818','furniture','block_type','1',0,''),(342218,109303,'1683103176.987818','furniture','padding-top','20',0,''),(342219,109303,'1683103176.987818','furniture','padding-bottom','20',0,''),(342220,109303,'1683103176.987818','furniture','padding-left','25',0,''),(342221,109303,'1683103176.987818','furniture','padding-right','25',0,''),(342222,109303,'1683103176.987818','furniture','background-color','$content-bg-1',0,''),(342223,109303,'1683103176.987818','furniture','margin-bottom','30',0,''),(342224,109304,'1683103176.989631','furniture','hide_parents','2',0,''),(342225,109305,'1683103176.99020','furniture','text','<div class=\"heading-3\">##TEXT_GA_PRODUCTS##</div>',0,''),(342226,109305,'1683103176.99020','furniture','style_class','shipping-ico',0,''),(342227,109306,'1683103176.992136','furniture','block_type','1',0,''),(342228,109306,'1683103176.992136','furniture','background-color','$content-bg-1',0,''),(342229,109306,'1683103176.992136','furniture','padding-top','20',0,''),(342230,109306,'1683103176.992136','furniture','padding-left','25',0,''),(342231,109306,'1683103176.992136','furniture','padding-right','25',0,''),(342232,109306,'1683103176.992136','furniture','padding-bottom','20',0,''),(342233,109306,'1683103176.992136','furniture','margin-bottom','30',0,''),(342234,109306,'1683103176.992136','furniture','style_class','closeable-box',0,''),(342235,109306,'1683103176.992136','furniture','display','none',0,'5140'),(342236,109307,'1683103176.99416','furniture','text','<div class=\"heading-3\">##TEXT_SHIPPING##</div>',0,''),(342237,109307,'1683103176.99416','furniture','style_class','shipping-ico',0,''),(342238,109308,'1683103176.995796','furniture','font-weight','normal',0,''),(342239,109308,'1683103176.995796','furniture','hide_parents','2',0,''),(342240,109309,'1683103176.996373','furniture','listing_type','productListing',0,''),(342241,109309,'1683103176.996373','furniture','col_in_row','4',0,''),(342242,109309,'1683103176.996373','furniture','show_popup','1',0,''),(342243,109309,'1683103176.996373','furniture','col_in_row','3',0,'5140'),(342244,109309,'1683103176.996373','furniture','col_in_row','2',0,'5131'),(342245,109309,'1683103176.996373','furniture','col_in_row','1',0,'5161'),(342246,109309,'1683103176.996373','furniture','padding-top','20',0,''),(342247,109309,'1683103176.996373','furniture','padding-left','25',0,''),(342248,109309,'1683103176.996373','furniture','padding-right','25',0,''),(342249,109309,'1683103176.996373','furniture','padding-bottom','20',0,''),(342250,109309,'1683103176.996373','furniture','background-color','$content-bg-1',0,''),(342251,109309,'1683103176.996373','furniture','margin-bottom','25',0,''),(342252,109310,'1683103176.999540','furniture','style_class','order-summary',0,''),(342253,109310,'1683103176.999540','furniture','block_type','1',0,''),(342254,109310,'1683103176.999540','furniture','margin-left','25',0,''),(342255,109310,'1683103176.999540','furniture','margin-left','0',0,'5140'),(342256,109310,'1683103176.999540','furniture','margin-bottom','30',0,'5140'),(342257,109310,'1683103176.999540','furniture','padding-left','10',0,''),(342258,109310,'1683103176.999540','furniture','padding-right','10',0,''),(342259,109310,'1683103176.999540','furniture','padding-bottom','10',0,''),(342260,109310,'1683103176.999540','furniture','background-color','$content-bg-1',0,''),(342261,109311,'1683103177.002177','furniture','block_type','1',0,''),(342262,109312,'1683103177.003296','furniture','font-weight','400',0,''),(342263,109312,'1683103177.003296','furniture','padding-right','0',0,'5131'),(342264,109312,'1683103177.003296','furniture','padding-bottom','20',0,'5131'),(342265,109313,'1683103177.016825','furniture','font-weight','400',0,''),(342266,109313,'1683103177.016825','furniture','box_align','4',0,''),(342267,109313,'1683103177.016825','furniture','text-align','center',0,'5131'),(342268,109313,'1683103177.016825','furniture','float','none',0,'5131'),(342269,109313,'1683103177.016825','furniture','width','100',0,'5131'),(342270,109313,'1683103177.016825','furniture','width_measure','%',0,'5131'),(342271,109314,'1683103177.018382','furniture','style_class','top-totals',0,''),(342272,109315,'1683103177.018993','furniture','style_class','bottom-totals',0,''),(342273,109316,'1683103177.019577','furniture','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(342278,109327,'116272','furniture','block_type','1',0,''),(342279,109328,'116273','furniture','block_type','6',0,''),(342280,109328,'116273','furniture','font-weight','400',0,''),(342281,109328,'116273','furniture','schema','6-2',0,'5161'),(342282,109328,'116273','furniture','schema','6-2',0,'5140'),(342283,109329,'116274','furniture','font-weight','400',0,''),(342284,109329,'116274','furniture','padding-right','40',0,''),(342285,109329,'116274','furniture','padding-right','0',0,'5161'),(342286,109329,'116274','furniture','padding-right','0',0,'5140'),(342287,109331,'116275','furniture','col_in_row','3',0,''),(342288,109331,'116275','furniture','products_align','left',0,''),(342289,109331,'116275','furniture','font-weight','400',0,''),(342290,109331,'116275','furniture','show_qty_input','0',0,''),(342291,109331,'116275','furniture','listing_type','productListing',0,''),(342292,109331,'116275','furniture','listing_type_rows','Rows',0,''),(342293,109331,'116275','furniture','show_buy_button_b2b','on',0,''),(342294,109331,'116275','furniture','show_wishlist_button_b2b','1',0,''),(342295,109331,'116275','furniture','show_compare_b2b','1',0,''),(342296,109331,'116275','furniture','show_stock','0',0,''),(342297,109331,'116275','furniture','show_description','0',0,''),(342298,109331,'116275','furniture','show_model','0',0,''),(342299,109331,'116275','furniture','show_properties','0',0,''),(342300,109331,'116275','furniture','show_rating','0',0,''),(342301,109331,'116275','furniture','show_rating_counts','0',0,''),(342302,109331,'116275','furniture','show_price','0',0,''),(342303,109331,'116275','furniture','show_buy_button','0',0,''),(342304,109331,'116275','furniture','show_view_button','0',0,''),(342305,109331,'116275','furniture','show_wishlist_button','0',0,''),(342306,109331,'116275','furniture','show_compare','0',0,''),(342307,109331,'116275','furniture','show_name_rows','0',0,''),(342308,109331,'116275','furniture','show_image_rows','0',0,''),(342309,109331,'116275','furniture','show_stock_rows','0',0,''),(342310,109331,'116275','furniture','show_description_rows','0',0,''),(342311,109331,'116275','furniture','show_model_rows','0',0,''),(342312,109331,'116275','furniture','show_properties_rows','0',0,''),(342313,109331,'116275','furniture','show_rating_rows','0',0,''),(342314,109331,'116275','furniture','show_rating_counts_rows','0',0,''),(342315,109331,'116275','furniture','show_price_rows','0',0,''),(342316,109331,'116275','furniture','show_buy_button_rows','0',0,''),(342317,109331,'116275','furniture','show_qty_input_rows','0',0,''),(342318,109331,'116275','furniture','show_view_button_rows','0',0,''),(342319,109331,'116275','furniture','show_wishlist_button_rows','0',0,''),(342320,109331,'116275','furniture','show_compare_rows','0',0,''),(342321,109331,'116275','furniture','show_name_b2b','0',0,''),(342322,109331,'116275','furniture','show_image_b2b','0',0,''),(342323,109331,'116275','furniture','show_stock_b2b','0',0,''),(342324,109331,'116275','furniture','show_description_b2b','0',0,''),(342325,109331,'116275','furniture','show_model_b2b','0',0,''),(342326,109331,'116275','furniture','show_properties_b2b','0',0,''),(342327,109331,'116275','furniture','show_rating_b2b','0',0,''),(342328,109331,'116275','furniture','show_rating_counts_b2b','0',0,''),(342329,109331,'116275','furniture','show_price_b2b','0',0,''),(342330,109331,'116275','furniture','show_qty_input_b2b','0',0,''),(342331,109331,'116275','furniture','show_view_button_b2b','0',0,''),(342332,109331,'116275','furniture','show_attributes_b2b','0',0,''),(342333,109331,'116275','furniture','items_on_page','9',0,''),(342334,109331,'116275','furniture','col_in_row','2',0,'5140'),(342335,109331,'116275','furniture','col_in_row','1',0,'5161'),(342336,109331,'116275','furniture','product_names_teg','h2',0,''),(342337,109333,'116277','furniture','block_type','5',0,''),(342338,109333,'116277','furniture','padding-top','10',0,''),(342339,109333,'116277','furniture','padding-bottom','10',0,''),(342340,109333,'116277','furniture','schema','5-2',0,'5161'),(342341,109333,'116277','furniture','border-top-color','$content-border-1',0,''),(342342,109333,'116277','furniture','border-top-width','1',0,''),(342343,109335,'116279','furniture','float','right',0,''),(342344,109336,'116280','furniture','listing_type','productListing',0,''),(342345,109338,'116282','furniture','block_type','1',0,''),(342346,109338,'116282','furniture','padding-top','10',0,''),(342347,109338,'116282','furniture','padding-bottom','10',0,''),(342348,109338,'116282','furniture','border-bottom-width','1',0,''),(342349,109338,'116282','furniture','border-bottom-color','$content-border-1',0,''),(342350,109338,'116282','furniture','margin-left','0',0,''),(342351,109338,'116282','furniture','margin-right','0',0,''),(342352,109339,'116283','furniture','float','right',0,''),(342353,109339,'116283','furniture','display','none',0,'5161'),(342354,109340,'116284','furniture','margin-right','20',0,''),(342355,109340,'116284','furniture','float','right',0,''),(342356,109340,'116284','furniture','clear','none',0,''),(342357,109340,'116284','furniture','display','none',0,'5140'),(342358,109341,'116285','furniture','float','left',0,''),(342359,109341,'116285','furniture','clear','none',0,''),(342360,109341,'116285','furniture','margin-left','20',0,''),(342361,109341,'116285','furniture','display','none',0,'5161'),(342362,109341,'116285','furniture','display','none',0,'5145'),(342363,109342,'116286','furniture','float','left',0,''),(342364,109342,'116286','furniture','clear','none',0,''),(342365,109342,'116286','furniture','sort_pos_3','2',0,''),(342366,109342,'116286','furniture','sort_pos_4','3',0,''),(342367,109342,'116286','furniture','sort_pos_10','11',0,''),(342368,109342,'116286','furniture','sort_pos_9','10',0,''),(342369,109342,'116286','furniture','sort_pos_11','12',0,''),(342370,109342,'116286','furniture','sort_pos_12','13',0,''),(342371,109342,'116286','furniture','sort_pos_14','15',0,''),(342372,109342,'116286','furniture','sort_pos_13','14',0,''),(342373,109342,'116286','furniture','sort_pos_8','4',0,''),(342374,109342,'116286','furniture','sort_pos_7','5',0,''),(342375,109342,'116286','furniture','sort_pos_2','7',0,''),(342376,109342,'116286','furniture','sort_pos_1','6',0,''),(342377,109342,'116286','furniture','sort_pos_6','9',0,''),(342378,109342,'116286','furniture','sort_pos_5','8',0,''),(342379,109342,'116286','furniture','sort_pos_0','1',0,''),(342380,109342,'116286','furniture','sort_hide_10','1',0,''),(342381,109342,'116286','furniture','sort_hide_9','1',0,''),(342382,109342,'116286','furniture','hide_icons','1',0,''),(342383,109342,'116286','furniture','sort_hide_16','1',0,''),(342384,109342,'116286','furniture','sort_hide_15','1',0,''),(342385,109342,'116286','furniture','sort_hide_3','0',0,''),(342386,109342,'116286','furniture','sort_hide_4','0',0,''),(342387,109342,'116286','furniture','sort_hide_11','1',0,''),(342388,109342,'116286','furniture','sort_hide_12','1',0,''),(342389,109342,'116286','furniture','sort_hide_14','1',0,''),(342390,109342,'116286','furniture','sort_hide_13','1',0,''),(342391,109342,'116286','furniture','sort_hide_8','0',0,''),(342392,109342,'116286','furniture','sort_hide_7','0',0,''),(342393,109342,'116286','furniture','sort_hide_2','1',0,''),(342394,109342,'116286','furniture','sort_hide_1','1',0,''),(342395,109342,'116286','furniture','sort_hide_6','1',0,''),(342396,109342,'116286','furniture','sort_hide_5','1',0,''),(342397,109342,'116286','furniture','sort_hide_0','0',0,''),(342398,109342,'116286','furniture','sort_pos_15','16',0,''),(342399,109342,'116286','furniture','sort_pos_16','17',0,''),(342400,109349,'116293','furniture','block_type','1',0,''),(342401,109351,'116295','furniture','block_type','6',0,''),(342402,109351,'116295','furniture','font-weight','400',0,''),(342403,109351,'116295','furniture','schema','6-2',0,'5161'),(342404,109351,'116295','furniture','schema','6-2',0,'5140'),(342405,109352,'116296','furniture','font-weight','400',0,''),(342406,109352,'116296','furniture','padding-right','40',0,''),(342407,109352,'116296','furniture','padding-right','0',0,'5161'),(342408,109352,'116296','furniture','padding-right','0',0,'5140'),(342409,109354,'116298','furniture','col_in_row','3',0,''),(342410,109354,'116298','furniture','products_align','left',0,''),(342411,109354,'116298','furniture','font-weight','400',0,''),(342412,109354,'116298','furniture','show_qty_input','0',0,''),(342413,109354,'116298','furniture','listing_type','productListing',0,''),(342414,109354,'116298','furniture','listing_type_rows','no',0,''),(342415,109354,'116298','furniture','show_buy_button_b2b','on',0,''),(342416,109354,'116298','furniture','show_wishlist_button_b2b','1',0,''),(342417,109354,'116298','furniture','show_compare_b2b','1',0,''),(342418,109354,'116298','furniture','show_stock','0',0,''),(342419,109354,'116298','furniture','show_description','0',0,''),(342420,109354,'116298','furniture','show_model','0',0,''),(342421,109354,'116298','furniture','show_properties','0',0,''),(342422,109354,'116298','furniture','show_rating','0',0,''),(342423,109354,'116298','furniture','show_rating_counts','0',0,''),(342424,109354,'116298','furniture','show_price','0',0,''),(342425,109354,'116298','furniture','show_buy_button','0',0,''),(342426,109354,'116298','furniture','show_view_button','0',0,''),(342427,109354,'116298','furniture','show_wishlist_button','0',0,''),(342428,109354,'116298','furniture','show_compare','0',0,''),(342429,109354,'116298','furniture','show_name_rows','0',0,''),(342430,109354,'116298','furniture','show_image_rows','0',0,''),(342431,109354,'116298','furniture','show_stock_rows','0',0,''),(342432,109354,'116298','furniture','show_description_rows','0',0,''),(342433,109354,'116298','furniture','show_model_rows','0',0,''),(342434,109354,'116298','furniture','show_properties_rows','0',0,''),(342435,109354,'116298','furniture','show_rating_rows','0',0,''),(342436,109354,'116298','furniture','show_rating_counts_rows','0',0,''),(342437,109354,'116298','furniture','show_price_rows','0',0,''),(342438,109354,'116298','furniture','show_buy_button_rows','0',0,''),(342439,109354,'116298','furniture','show_qty_input_rows','0',0,''),(342440,109354,'116298','furniture','show_view_button_rows','0',0,''),(342441,109354,'116298','furniture','show_wishlist_button_rows','0',0,''),(342442,109354,'116298','furniture','show_compare_rows','0',0,''),(342443,109354,'116298','furniture','show_name_b2b','0',0,''),(342444,109354,'116298','furniture','show_image_b2b','0',0,''),(342445,109354,'116298','furniture','show_stock_b2b','0',0,''),(342446,109354,'116298','furniture','show_description_b2b','0',0,''),(342447,109354,'116298','furniture','show_model_b2b','0',0,''),(342448,109354,'116298','furniture','show_properties_b2b','0',0,''),(342449,109354,'116298','furniture','show_rating_b2b','0',0,''),(342450,109354,'116298','furniture','show_rating_counts_b2b','0',0,''),(342451,109354,'116298','furniture','show_price_b2b','0',0,''),(342452,109354,'116298','furniture','show_qty_input_b2b','0',0,''),(342453,109354,'116298','furniture','show_view_button_b2b','0',0,''),(342454,109354,'116298','furniture','show_attributes_b2b','0',0,''),(342455,109354,'116298','furniture','items_on_page','9',0,''),(342456,109354,'116298','furniture','col_in_row','2',0,'5140'),(342457,109354,'116298','furniture','col_in_row','1',0,'5161'),(342458,109354,'116298','furniture','product_names_teg','h2',0,''),(342459,109355,'116299','furniture','block_type','1',0,''),(342460,109355,'116299','furniture','padding-top','10',0,''),(342461,109355,'116299','furniture','padding-bottom','10',0,''),(342462,109355,'116299','furniture','border-bottom-width','1',0,''),(342463,109355,'116299','furniture','border-bottom-color','$content-border-1',0,''),(342464,109355,'116299','furniture','margin-left','0',0,''),(342465,109355,'116299','furniture','margin-right','0',0,''),(342466,109356,'116300','furniture','float','left',0,''),(342467,109356,'116300','furniture','clear','none',0,''),(342468,109356,'116300','furniture','sort_pos_3','1',0,''),(342469,109356,'116300','furniture','sort_pos_4','2',0,''),(342470,109356,'116300','furniture','sort_pos_10','3',0,''),(342471,109356,'116300','furniture','sort_pos_9','4',0,''),(342472,109356,'116300','furniture','sort_pos_11','5',0,''),(342473,109356,'116300','furniture','sort_pos_12','6',0,''),(342474,109356,'116300','furniture','sort_pos_14','7',0,''),(342475,109356,'116300','furniture','sort_pos_13','8',0,''),(342476,109356,'116300','furniture','sort_pos_8','9',0,''),(342477,109356,'116300','furniture','sort_pos_7','10',0,''),(342478,109356,'116300','furniture','sort_pos_2','11',0,''),(342479,109356,'116300','furniture','sort_pos_1','12',0,''),(342480,109356,'116300','furniture','sort_pos_6','13',0,''),(342481,109356,'116300','furniture','sort_pos_5','14',0,''),(342482,109356,'116300','furniture','sort_pos_0','15',0,''),(342483,109356,'116300','furniture','sort_hide_10','1',0,''),(342484,109356,'116300','furniture','sort_hide_9','1',0,''),(342485,109356,'116300','furniture','hide_icons','1',0,''),(342486,109356,'116300','furniture','sort_hide_16','1',0,''),(342487,109356,'116300','furniture','sort_hide_15','1',0,''),(342488,109356,'116300','furniture','sort_hide_3','0',0,''),(342489,109356,'116300','furniture','sort_hide_4','0',0,''),(342490,109356,'116300','furniture','sort_hide_11','1',0,''),(342491,109356,'116300','furniture','sort_hide_12','1',0,''),(342492,109356,'116300','furniture','sort_hide_14','1',0,''),(342493,109356,'116300','furniture','sort_hide_13','1',0,''),(342494,109356,'116300','furniture','sort_hide_8','0',0,''),(342495,109356,'116300','furniture','sort_hide_7','0',0,''),(342496,109356,'116300','furniture','sort_hide_2','1',0,''),(342497,109356,'116300','furniture','sort_hide_1','1',0,''),(342498,109356,'116300','furniture','sort_hide_6','1',0,''),(342499,109356,'116300','furniture','sort_hide_5','1',0,''),(342500,109356,'116300','furniture','sort_hide_0','1',0,''),(342501,109357,'116301','furniture','float','left',0,''),(342502,109357,'116301','furniture','clear','none',0,''),(342503,109357,'116301','furniture','margin-left','20',0,''),(342504,109357,'116301','furniture','display','none',0,'5161'),(342505,109358,'116302','furniture','margin-right','20',0,''),(342506,109358,'116302','furniture','float','right',0,''),(342507,109358,'116302','furniture','clear','none',0,''),(342508,109358,'116302','furniture','display','none',0,'5140'),(342509,109359,'116303','furniture','float','right',0,''),(342510,109359,'116303','furniture','display','none',0,'5161'),(342511,109360,'116304','furniture','listing_type','productListing',0,''),(342512,109362,'116306','furniture','block_type','5',0,''),(342513,109362,'116306','furniture','padding-top','10',0,''),(342514,109362,'116306','furniture','padding-bottom','10',0,''),(342515,109362,'116306','furniture','schema','5-2',0,'5161'),(342516,109362,'116306','furniture','border-top-color','$content-border-1',0,''),(342517,109362,'116306','furniture','border-top-width','1',0,''),(342518,109364,'116308','furniture','float','right',0,''),(342519,109365,'116309','furniture','block_type','1',0,''),(342520,109368,'116312','furniture','block_type','1',0,''),(342521,109368,'116312','furniture','padding-top','10',0,''),(342522,109368,'116312','furniture','padding-bottom','10',0,''),(342523,109368,'116312','furniture','border-bottom-width','1',0,''),(342524,109368,'116312','furniture','border-bottom-color','$content-border-1',0,''),(342525,109368,'116312','furniture','margin-left','0',0,''),(342526,109368,'116312','furniture','margin-right','0',0,''),(342527,109369,'116313','furniture','float','left',0,''),(342528,109369,'116313','furniture','clear','none',0,''),(342529,109369,'116313','furniture','margin-left','20',0,''),(342530,109369,'116313','furniture','display','none',0,'5161'),(342531,109370,'116314','furniture','float','left',0,''),(342532,109370,'116314','furniture','clear','none',0,''),(342533,109370,'116314','furniture','sort_pos_3','2',0,''),(342534,109370,'116314','furniture','sort_pos_4','3',0,''),(342535,109370,'116314','furniture','sort_pos_10','11',0,''),(342536,109370,'116314','furniture','sort_pos_9','10',0,''),(342537,109370,'116314','furniture','sort_pos_11','12',0,''),(342538,109370,'116314','furniture','sort_pos_12','13',0,''),(342539,109370,'116314','furniture','sort_pos_14','15',0,''),(342540,109370,'116314','furniture','sort_pos_13','14',0,''),(342541,109370,'116314','furniture','sort_pos_8','4',0,''),(342542,109370,'116314','furniture','sort_pos_7','5',0,''),(342543,109370,'116314','furniture','sort_pos_2','7',0,''),(342544,109370,'116314','furniture','sort_pos_1','6',0,''),(342545,109370,'116314','furniture','sort_pos_6','9',0,''),(342546,109370,'116314','furniture','sort_pos_5','8',0,''),(342547,109370,'116314','furniture','sort_pos_0','1',0,''),(342548,109370,'116314','furniture','sort_hide_10','1',0,''),(342549,109370,'116314','furniture','sort_hide_9','1',0,''),(342550,109370,'116314','furniture','hide_icons','1',0,''),(342551,109370,'116314','furniture','sort_hide_16','1',0,''),(342552,109370,'116314','furniture','sort_hide_15','1',0,''),(342553,109370,'116314','furniture','sort_hide_3','0',0,''),(342554,109370,'116314','furniture','sort_hide_4','0',0,''),(342555,109370,'116314','furniture','sort_hide_11','1',0,''),(342556,109370,'116314','furniture','sort_hide_12','1',0,''),(342557,109370,'116314','furniture','sort_hide_14','1',0,''),(342558,109370,'116314','furniture','sort_hide_13','1',0,''),(342559,109370,'116314','furniture','sort_hide_8','0',0,''),(342560,109370,'116314','furniture','sort_hide_7','0',0,''),(342561,109370,'116314','furniture','sort_hide_2','1',0,''),(342562,109370,'116314','furniture','sort_hide_1','1',0,''),(342563,109370,'116314','furniture','sort_hide_6','1',0,''),(342564,109370,'116314','furniture','sort_hide_5','1',0,''),(342565,109370,'116314','furniture','sort_hide_0','0',0,''),(342566,109370,'116314','furniture','sort_pos_15','16',0,''),(342567,109370,'116314','furniture','sort_pos_16','17',0,''),(342568,109371,'116315','furniture','margin-right','20',0,''),(342569,109371,'116315','furniture','float','right',0,''),(342570,109371,'116315','furniture','clear','none',0,''),(342571,109371,'116315','furniture','display','none',0,'5140'),(342572,109372,'116316','furniture','float','right',0,''),(342573,109372,'116316','furniture','display','none',0,'5161'),(342574,109373,'116317','furniture','clear','none',0,''),(342575,109373,'116317','furniture','float','left',0,''),(342576,109373,'116317','furniture','padding-top','3',0,''),(342577,109373,'116317','furniture','padding-left','20',0,''),(342578,109374,'116318','furniture','block_type','5',0,''),(342579,109374,'116318','furniture','padding-top','10',0,''),(342580,109374,'116318','furniture','padding-bottom','10',0,''),(342581,109374,'116318','furniture','schema','5-2',0,'5161'),(342582,109374,'116318','furniture','border-top-color','$content-border-1',0,''),(342583,109374,'116318','furniture','border-top-width','1',0,''),(342584,109376,'116320','furniture','float','right',0,''),(342585,109377,'116321','furniture','col_in_row','4',0,''),(342586,109377,'116321','furniture','products_align','left',0,''),(342587,109377,'116321','furniture','font-weight','400',0,''),(342588,109377,'116321','furniture','show_qty_input','0',0,''),(342589,109377,'116321','furniture','listing_type','productListing',0,''),(342590,109377,'116321','furniture','listing_type_rows','Rows',0,''),(342591,109377,'116321','furniture','show_buy_button_b2b','on',0,''),(342592,109377,'116321','furniture','show_wishlist_button_b2b','1',0,''),(342593,109377,'116321','furniture','show_compare_b2b','1',0,''),(342594,109377,'116321','furniture','listing_type_b2b','b2b',0,''),(342595,109377,'116321','furniture','show_image','0',0,''),(342596,109377,'116321','furniture','show_stock','0',0,''),(342597,109377,'116321','furniture','show_description','0',0,''),(342598,109377,'116321','furniture','show_model','0',0,''),(342599,109377,'116321','furniture','show_properties','0',0,''),(342600,109377,'116321','furniture','show_rating','0',0,''),(342601,109377,'116321','furniture','show_rating_counts','0',0,''),(342602,109377,'116321','furniture','show_price','0',0,''),(342603,109377,'116321','furniture','show_buy_button','0',0,''),(342604,109377,'116321','furniture','show_view_button','0',0,''),(342605,109377,'116321','furniture','show_wishlist_button','0',0,''),(342606,109377,'116321','furniture','show_compare','0',0,''),(342607,109377,'116321','furniture','show_name_rows','0',0,''),(342608,109377,'116321','furniture','show_image_rows','0',0,''),(342609,109377,'116321','furniture','show_stock_rows','0',0,''),(342610,109377,'116321','furniture','show_description_rows','0',0,''),(342611,109377,'116321','furniture','show_model_rows','0',0,''),(342612,109377,'116321','furniture','show_properties_rows','0',0,''),(342613,109377,'116321','furniture','show_rating_rows','0',0,''),(342614,109377,'116321','furniture','show_rating_counts_rows','0',0,''),(342615,109377,'116321','furniture','show_price_rows','0',0,''),(342616,109377,'116321','furniture','show_buy_button_rows','0',0,''),(342617,109377,'116321','furniture','show_qty_input_rows','0',0,''),(342618,109377,'116321','furniture','show_view_button_rows','0',0,''),(342619,109377,'116321','furniture','show_wishlist_button_rows','0',0,''),(342620,109377,'116321','furniture','show_compare_rows','0',0,''),(342621,109377,'116321','furniture','show_name_b2b','0',0,''),(342622,109377,'116321','furniture','show_image_b2b','0',0,''),(342623,109377,'116321','furniture','show_stock_b2b','0',0,''),(342624,109377,'116321','furniture','show_description_b2b','0',0,''),(342625,109377,'116321','furniture','show_model_b2b','0',0,''),(342626,109377,'116321','furniture','show_properties_b2b','0',0,''),(342627,109377,'116321','furniture','show_rating_b2b','0',0,''),(342628,109377,'116321','furniture','show_rating_counts_b2b','0',0,''),(342629,109377,'116321','furniture','show_price_b2b','0',0,''),(342630,109377,'116321','furniture','show_qty_input_b2b','0',0,''),(342631,109377,'116321','furniture','show_view_button_b2b','0',0,''),(342632,109377,'116321','furniture','show_attributes_b2b','0',0,''),(342633,109377,'116321','furniture','items_on_page','12',0,''),(342634,109377,'116321','furniture','col_in_row','2',0,'5140'),(342635,109377,'116321','furniture','col_in_row','1',0,'5161'),(342636,109377,'116321','furniture','product_names_teg','h2',0,''),(342637,109380,'1693847444.869439','furniture','block_type','1',0,''),(342638,109380,'1693847444.869439','furniture','background-color','$content-bg-2',0,''),(342639,109380,'1693847444.869439','furniture','padding-top','30',0,''),(342640,109380,'1693847444.869439','furniture','padding-bottom','30',0,''),(342641,109380,'1693847444.869439','furniture','style_class','checkout-index-wrap',0,''),(342642,109380,'1693847444.869439','furniture','color','$content-color-2',0,''),(342643,109381,'1693847444.885847','furniture','block_type','7',0,''),(342644,109381,'1693847444.885847','furniture','schema','4-2',0,'5140'),(342645,109382,'1693847444.888529','furniture','block_type','1',0,''),(342646,109382,'1693847444.888529','furniture','padding-right','0',0,'5140'),(342647,109383,'1693847444.8951','furniture','block_type','1',0,''),(342648,109383,'1693847444.8951','furniture','background-color','$content-bg-1',0,''),(342649,109383,'1693847444.8951','furniture','padding-top','20',0,''),(342650,109383,'1693847444.8951','furniture','padding-left','30',0,''),(342651,109383,'1693847444.8951','furniture','padding-right','30',0,''),(342652,109383,'1693847444.8951','furniture','padding-bottom','14',0,''),(342653,109383,'1693847444.8951','furniture','margin-bottom','20',0,''),(342654,109383,'1693847444.8951','furniture','style_class','hiding-box closeable-box',0,''),(342655,109383,'1693847444.8951','furniture','color','$content-color-1',0,''),(342656,109384,'1693847444.891978','furniture','style_class','closeable-content',0,''),(342657,109384,'1693847444.891978','furniture','padding-bottom','20',0,''),(342658,109385,'1693847444.893451','furniture','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(342659,109385,'1693847444.893451','furniture','style_class','closeable-heading closeable-event closed',0,''),(342660,109386,'1693847444.898927','furniture','block_type','1',0,''),(342661,109386,'1693847444.898927','furniture','padding-top','30',0,''),(342662,109386,'1693847444.898927','furniture','padding-left','30',0,''),(342663,109386,'1693847444.898927','furniture','padding-right','30',0,''),(342664,109386,'1693847444.898927','furniture','padding-bottom','14',0,''),(342665,109386,'1693847444.898927','furniture','background-color','$content-bg-1',0,''),(342666,109386,'1693847444.898927','furniture','style_class','hiding-box closeable-box',0,''),(342667,109386,'1693847444.898927','furniture','margin-bottom','20',0,''),(342668,109386,'1693847444.898927','furniture','color','$content-color-1',0,''),(342669,109387,'1693847444.90129','furniture','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(342670,109387,'1693847444.90129','furniture','style_class','closeable-heading closeable-event closed',0,''),(342671,109388,'1693847444.902745','furniture','block_type','2',0,''),(342672,109388,'1693847444.902745','furniture','style_class','closeable-content',0,''),(342673,109388,'1693847444.902745','furniture','schema','2-2',0,'5140'),(342674,109389,'1693847444.904471','furniture','padding-right','20',0,''),(342675,109389,'1693847444.904471','furniture','padding-bottom','20',0,''),(342676,109389,'1693847444.904471','furniture','padding-right','0',0,'5140'),(342677,109390,'1693847444.906639','furniture','padding-left','20',0,''),(342678,109390,'1693847444.906639','furniture','padding-bottom','20',0,''),(342679,109390,'1693847444.906639','furniture','padding-left','0',0,'5140'),(342680,109391,'1693847444.908631','furniture','padding-left','20',0,''),(342681,109391,'1693847444.908631','furniture','padding-bottom','20',0,''),(342682,109391,'1693847444.908631','furniture','padding-left','0',0,'5140'),(342683,109392,'1693847444.910474','furniture','background-color','$content-bg-1',0,''),(342684,109392,'1693847444.910474','furniture','block_type','1',0,''),(342685,109392,'1693847444.910474','furniture','padding-top','30',0,''),(342686,109392,'1693847444.910474','furniture','padding-left','30',0,''),(342687,109392,'1693847444.910474','furniture','padding-right','30',0,''),(342688,109392,'1693847444.910474','furniture','padding-bottom','30',0,''),(342689,109392,'1693847444.910474','furniture','margin-bottom','20',0,''),(342690,109392,'1693847444.910474','furniture','style_class','hiding-box',0,''),(342691,109392,'1693847444.910474','furniture','color','$content-color-1',0,''),(342692,109393,'1693847444.912443','furniture','block_type','1',0,''),(342693,109393,'1693847444.912443','furniture','content','\\_',0,'3'),(342694,109393,'1693847444.912443','furniture','border-top-width','1',0,'3'),(342695,109393,'1693847444.912443','furniture','border-top-color','$content-border-2',0,'3'),(342696,109393,'1693847444.912443','furniture','display','block',0,'3'),(342697,109393,'1693847444.912443','furniture','position','absolute',0,'3'),(342698,109393,'1693847444.912443','furniture','top','19',0,'3'),(342699,109393,'1693847444.912443','furniture','left','0',0,'3'),(342700,109393,'1693847444.912443','furniture','right','0',0,'3'),(342701,109393,'1693847444.912443','furniture','margin-top','-2',0,'3'),(342702,109393,'1693847444.912443','furniture','position','relative',0,''),(342703,109394,'1693847444.914967','furniture','box_align','2',0,''),(342704,109394,'1693847444.914967','furniture','margin-bottom','10',0,''),(342705,109394,'1693847444.914967','furniture','background-color','$content-bg-1',0,''),(342706,109394,'1693847444.914967','furniture','position','relative',0,''),(342707,109395,'1693847444.921382','furniture','background-color','$content-bg-2',0,''),(342708,109395,'1693847444.921382','furniture','padding-top','10',0,''),(342709,109395,'1693847444.921382','furniture','padding-left','10',0,''),(342710,109395,'1693847444.921382','furniture','padding-right','10',0,''),(342711,109395,'1693847444.921382','furniture','padding-bottom','10',0,''),(342712,109395,'1693847444.921382','furniture','margin-top','10',0,''),(342713,109396,'1693847444.923161','furniture','block_type','2',0,''),(342714,109396,'1693847444.923161','furniture','schema','2-2',0,'5140'),(342715,109397,'1693847444.924488','furniture','block_type','1',0,''),(342716,109397,'1693847444.924488','furniture','padding-right','20',0,''),(342717,109397,'1693847444.924488','furniture','padding-left','0',0,'5140'),(342718,109397,'1693847444.924488','furniture','margin-bottom','20',0,'5140'),(342719,109397,'1693847444.924488','furniture','padding-right','0',0,'5140'),(342720,109398,'1693847444.926170','furniture','address_in','popup',0,''),(342721,109399,'1693847444.928743','furniture','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(342722,109402,'1693847444.934659','furniture','block_type','1',0,''),(342723,109402,'1693847444.934659','furniture','padding-left','20',0,''),(342724,109402,'1693847444.934659','furniture','padding-left','0',0,'5140'),(342725,109404,'1693847444.9487','furniture','border-top-width','1',0,''),(342726,109404,'1693847444.9487','furniture','border-top-color','$content-border-2',0,''),(342727,109404,'1693847444.9487','furniture','padding-top','13',0,''),(342728,109404,'1693847444.9487','furniture','padding-bottom','10',0,''),(342729,109405,'1693847444.942192','furniture','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(342730,109406,'1693847444.946113','furniture','show_day','next_day',0,''),(342731,109408,'1693847444.95160','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(342732,109409,'1693847444.954571','furniture','block_type','1',0,''),(342733,109409,'1693847444.954571','furniture','padding-left','30',0,''),(342734,109409,'1693847444.954571','furniture','padding-right','30',0,''),(342735,109409,'1693847444.954571','furniture','padding-bottom','30',0,''),(342736,109409,'1693847444.954571','furniture','margin-bottom','20',0,''),(342737,109409,'1693847444.954571','furniture','style_class','hiding-box',0,''),(342738,109409,'1693847444.954571','furniture','background-color','$content-bg-1',0,''),(342739,109409,'1693847444.954571','furniture','color','$content-color-1',0,''),(342740,109410,'1693847444.956524','furniture','margin-bottom','20',0,''),(342741,109411,'1693847444.960635','furniture','padding-top','10',0,''),(342742,109411,'1693847444.960635','furniture','padding-left','20',0,''),(342743,109411,'1693847444.960635','furniture','padding-right','20',0,''),(342744,109411,'1693847444.960635','furniture','margin-top','20',0,''),(342745,109411,'1693847444.960635','furniture','padding-bottom','8',0,''),(342746,109413,'1693847444.965195','furniture','block_type','1',0,''),(342747,109413,'1693847444.965195','furniture','padding-top','30',0,''),(342748,109413,'1693847444.965195','furniture','padding-left','30',0,''),(342749,109413,'1693847444.965195','furniture','padding-right','30',0,''),(342750,109413,'1693847444.965195','furniture','padding-bottom','23',0,''),(342751,109413,'1693847444.965195','furniture','margin-bottom','20',0,''),(342752,109413,'1693847444.965195','furniture','background-color','$content-bg-1',0,''),(342753,109413,'1693847444.965195','furniture','style_class','hiding-box',0,''),(342754,109414,'1693847444.967253','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(342755,109415,'1693847444.96852','furniture','block_type','2',0,''),(342756,109415,'1693847444.96852','furniture','schema','2-2',0,'5140'),(342757,109416,'1693847444.969566','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(342758,109417,'1693847444.97077','furniture','padding-right','20',0,''),(342759,109417,'1693847444.97077','furniture','padding-right','0',0,'5140'),(342760,109417,'1693847444.97077','furniture','padding-bottom','20',0,'5140'),(342761,109417,'1693847444.97077','furniture','address_in','popup',0,''),(342762,109418,'1693847444.97415','furniture','block_type','1',0,''),(342763,109418,'1693847444.97415','furniture','padding-left','20',0,''),(342764,109418,'1693847444.97415','furniture','padding-left','0',0,'5140'),(342765,109420,'1693847444.97623','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(342766,109421,'1693847444.977354','furniture','block_type','1',0,''),(342767,109421,'1693847444.977354','furniture','background-color','$content-bg-1',0,''),(342768,109421,'1693847444.977354','furniture','padding-top','20',0,''),(342769,109421,'1693847444.977354','furniture','padding-left','30',0,''),(342770,109421,'1693847444.977354','furniture','padding-right','30',0,''),(342771,109421,'1693847444.977354','furniture','padding-bottom','20',0,''),(342772,109421,'1693847444.977354','furniture','margin-bottom','20',0,''),(342773,109421,'1693847444.977354','furniture','color','$content-color-1',0,''),(342774,109423,'1693847444.979723','furniture','block_type','1',0,''),(342775,109423,'1693847444.979723','furniture','padding-top','10',0,''),(342776,109423,'1693847444.979723','furniture','padding-left','10',0,''),(342777,109423,'1693847444.979723','furniture','padding-right','10',0,''),(342778,109423,'1693847444.979723','furniture','padding-bottom','10',0,''),(342779,109423,'1693847444.979723','furniture','background-color','$content-bg-1',0,''),(342780,109423,'1693847444.979723','furniture','style_class','order-summary',0,''),(342781,109423,'1693847444.979723','furniture','margin-left','25',0,''),(342782,109423,'1693847444.979723','furniture','margin-left','0',0,'5140'),(342783,109423,'1693847444.979723','furniture','color','$content-color-1',0,''),(342784,109424,'1693847444.98495','furniture','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(342785,109424,'1693847444.98495','furniture','text-align','center',0,''),(342786,109424,'1693847444.98495','furniture','font-size','14',0,''),(342787,109424,'1693847444.98495','furniture','color','$content-color-1',0,''),(342788,109424,'1693847444.98495','furniture','padding-top','10',0,''),(342789,109425,'1693847444.986544','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(342790,109426,'1693847444.987613','furniture','hide_page','1',0,''),(342791,109426,'1693847444.987613','furniture','hide_continue_button','1',0,''),(342792,109427,'1693847444.988926','furniture','margin-bottom','10',0,''),(342793,109429,'116368','furniture','block_type','1',0,''),(342794,109431,'116370','furniture','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(342795,109432,'116371','furniture','link','products',0,''),(342796,109432,'116371','furniture','margin-top','-33',0,''),(342797,109432,'116371','furniture','float','right',0,''),(342798,109433,'116372','furniture','block_type','2',0,''),(342799,109433,'116372','furniture','margin-bottom','20',0,''),(342800,109433,'116372','furniture','schema','2-2',0,'5131'),(342801,109434,'116373','furniture','block_type','1',0,''),(342802,109434,'116373','furniture','padding-right','20',0,''),(342803,109434,'116373','furniture','padding-right','0',0,'5131'),(342804,109435,'116374','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(342805,109435,'116374','furniture','clear','none',0,''),(342806,109437,'116376','furniture','padding-left','20',0,''),(342807,109437,'116376','furniture','block_type','1',0,''),(342808,109437,'116376','furniture','padding-left','0',0,'5131'),(342809,109439,'116378','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(342810,109439,'116378','furniture','clear','none',0,''),(342811,109440,'116380','furniture','block_type','2',0,''),(342812,109440,'116380','furniture','margin-bottom','20',0,''),(342813,109440,'116380','furniture','schema','2-2',0,'5131'),(342814,109441,'116381','furniture','block_type','1',0,''),(342815,109441,'116381','furniture','padding-right','20',0,''),(342816,109441,'116381','furniture','padding-right','0',0,'5131'),(342817,109443,'116383','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(342818,109443,'116383','furniture','clear','none',0,''),(342819,109444,'116384','furniture','block_type','1',0,''),(342820,109444,'116384','furniture','padding-left','20',0,''),(342821,109444,'116384','furniture','padding-left','0',0,'5131'),(342822,109445,'116385','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(342823,109445,'116385','furniture','clear','none',0,''),(342824,109447,'116387','furniture','margin-bottom','20',0,''),(342825,109447,'116387','furniture','text-align','right',0,''),(342826,109449,'116379','furniture','text-align','right',0,''),(342827,109449,'116379','furniture','margin-bottom','20',0,''),(342828,109449,'116379','furniture','margin-top','20',0,''),(342829,109450,'116402','furniture','block_type','1',0,''),(342830,109451,'116403','furniture','text-align','right',0,''),(342831,109451,'116403','furniture','margin-bottom','20',0,''),(342832,109452,'116404','furniture','block_type','2',0,''),(342833,109452,'116404','furniture','margin-bottom','20',0,''),(342834,109452,'116404','furniture','schema','2-2',0,'5131'),(342835,109453,'116405','furniture','block_type','1',0,''),(342836,109453,'116405','furniture','padding-right','20',0,''),(342837,109453,'116405','furniture','padding-right','0',0,'5131'),(342838,109454,'116406','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(342839,109454,'116406','furniture','clear','none',0,''),(342840,109456,'116408','furniture','block_type','1',0,''),(342841,109456,'116408','furniture','padding-left','20',0,''),(342842,109456,'116408','furniture','padding-left','0',0,'5131'),(342843,109457,'116409','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(342844,109457,'116409','furniture','clear','none',0,''),(342845,109459,'116411','furniture','margin-bottom','20',0,''),(342846,109459,'116411','furniture','text-align','right',0,''),(342847,109462,'116414','furniture','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(342848,109463,'116389','furniture','block_type','1',0,''),(342849,109464,'116390','furniture','margin-bottom','20',0,''),(342850,109465,'116391','furniture','margin-bottom','20',0,''),(342851,109465,'116391','furniture','text-align','right',0,''),(342852,109466,'116392','furniture','text-align','right',0,''),(342853,109466,'116392','furniture','margin-bottom','20',0,''),(342854,109467,'116393','furniture','block_type','2',0,''),(342855,109467,'116393','furniture','margin-bottom','20',0,''),(342856,109467,'116393','furniture','schema','2-2',0,'5131'),(342857,109468,'116394','furniture','block_type','1',0,''),(342858,109468,'116394','furniture','padding-right','20',0,''),(342859,109468,'116394','furniture','padding-right','0',0,'5131'),(342860,109470,'116396','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(342861,109470,'116396','furniture','clear','none',0,''),(342862,109471,'116397','furniture','block_type','1',0,''),(342863,109471,'116397','furniture','padding-left','20',0,''),(342864,109471,'116397','furniture','padding-left','0',0,'5131'),(342865,109473,'116399','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(342866,109473,'116399','furniture','clear','none',0,''),(342867,109474,'116400','furniture','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(342868,109475,'116401','furniture','margin-bottom','20',0,''),(342869,109476,'116415','furniture','block_type','1',0,''),(342870,109477,'116416','furniture','block_type','2',0,''),(342871,109477,'116416','furniture','margin-bottom','20',0,''),(342872,109477,'116416','furniture','schema','2-2',0,'5131'),(342873,109478,'116417','furniture','block_type','1',0,''),(342874,109478,'116417','furniture','padding-right','20',0,''),(342875,109478,'116417','furniture','padding-right','0',0,'5131'),(342876,109480,'116419','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(342877,109480,'116419','furniture','clear','none',0,''),(342878,109481,'116420','furniture','block_type','1',0,''),(342879,109481,'116420','furniture','padding-left','20',0,''),(342880,109481,'116420','furniture','padding-left','0',0,'5131'),(342881,109483,'116422','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(342882,109483,'116422','furniture','clear','none',0,''),(342883,109484,'116423','furniture','margin-bottom','20',0,''),(342884,109485,'116424','furniture','margin-bottom','20',0,''),(342885,109486,'116425','furniture','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(342886,109487,'116426','furniture','link','products',0,''),(342887,109487,'116426','furniture','margin-top','-33',0,''),(342888,109487,'116426','furniture','float','right',0,''),(342889,109488,'116427','furniture','text-align','right',0,''),(342890,109488,'116427','furniture','margin-bottom','20',0,''),(342891,109489,'116428','furniture','margin-bottom','20',0,''),(342892,109489,'116428','furniture','text-align','right',0,''),(342893,109490,'116429','furniture','block_type','2',0,''),(342894,109490,'116429','furniture','margin-bottom','20',0,''),(342895,109490,'116429','furniture','schema','2-2',0,'5131'),(342896,109491,'116430','furniture','block_type','1',0,''),(342897,109491,'116430','furniture','padding-right','20',0,''),(342898,109491,'116430','furniture','padding-right','0',0,'5131'),(342899,109492,'116431','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(342900,109492,'116431','furniture','clear','none',0,''),(342901,109494,'116433','furniture','padding-left','20',0,''),(342902,109494,'116433','furniture','block_type','1',0,''),(342903,109494,'116433','furniture','padding-left','0',0,'5131'),(342904,109495,'116434','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(342905,109495,'116434','furniture','clear','none',0,''),(342906,109497,'116436','furniture','text','##TEXT_CONFIRMATION##',0,''),(342907,109498,'116437','furniture','text','##TEXT_CONFIRMATION##',0,''),(342908,109499,'116439','furniture','text','##TEXT_CONFIRMATION##',0,''),(342909,109500,'116438','furniture','text','##TEXT_CONFIRMATION##',0,''),(342910,109501,'116440','furniture','text','##TEXT_CONFIRMATION##',0,''),(342911,109502,'116441','furniture','text','##TEXT_CONFIRMATION##',0,''),(342912,109503,'116442','furniture','block_type','2',0,''),(342913,109504,'116443','furniture','block_type','1',0,''),(342914,109504,'116443','furniture','padding-right','20',0,''),(342915,109505,'116444','furniture','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(342916,109507,'116446','furniture','block_type','1',0,''),(342917,109507,'116446','furniture','padding-left','20',0,''),(342918,109507,'116446','furniture','padding-left','0',0,'5140'),(342919,109508,'116447','furniture','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(342920,109510,'116449','furniture','block_type','4',0,''),(342921,109510,'116449','furniture','schema','4-2',0,'5161'),(342922,109510,'116449','furniture','padding-top','20',0,''),(342923,109511,'116450','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(342924,109511,'116450','furniture','text-align','right',0,''),(342925,109511,'116450','furniture','padding-top','10',0,''),(342926,109511,'116450','furniture','font_size_measure','em',0,''),(342927,109511,'116450','furniture','font-size','1.2',0,''),(342928,109512,'116451','furniture','text-align','right',0,''),(342929,109513,'116452','furniture','block_type','2',0,''),(342930,109514,'116453','furniture','block_type','1',0,''),(342931,109514,'116453','furniture','padding-right','20',0,''),(342932,109514,'116453','furniture','padding-right','0',0,'5140'),(342933,109516,'116456','furniture','block_type','1',0,''),(342934,109516,'116456','furniture','padding-right','0',0,'5140'),(342935,109516,'116456','furniture','padding-left','20',0,''),(342936,109519,'116459','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(342937,109521,'116461','furniture','block_type','2',0,''),(342938,109522,'116462','furniture','block_type','1',0,''),(342939,109522,'116462','furniture','padding-right','20',0,''),(342940,109524,'116464','furniture','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(342941,109525,'116465','furniture','block_type','1',0,''),(342942,109525,'116465','furniture','padding-left','20',0,''),(342943,109525,'116465','furniture','padding-left','0',0,'5140'),(342944,109526,'116466','furniture','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(342945,109528,'116468','furniture','block_type','4',0,''),(342946,109528,'116468','furniture','schema','4-2',0,'5161'),(342947,109529,'116469','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(342948,109529,'116469','furniture','text-align','right',0,''),(342949,109529,'116469','furniture','padding-top','10',0,''),(342950,109529,'116469','furniture','font_size_measure','em',0,''),(342951,109529,'116469','furniture','font-size','1.2',0,''),(342952,109530,'116470','furniture','text-align','right',0,''),(342953,109531,'116471','furniture','block_type','2',0,''),(342954,109532,'116472','furniture','block_type','1',0,''),(342955,109532,'116472','furniture','padding-right','20',0,''),(342956,109532,'116472','furniture','padding-right','0',0,'5140'),(342957,109534,'116474','furniture','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(342958,109535,'116475','furniture','block_type','1',0,''),(342959,109535,'116475','furniture','padding-right','0',0,'5140'),(342960,109535,'116475','furniture','padding-left','20',0,''),(342961,109537,'116477','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(342962,109540,'116480','furniture','block_type','4',0,''),(342963,109540,'116480','furniture','schema','4-2',0,'5161'),(342964,109541,'116481','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(342965,109541,'116481','furniture','text-align','right',0,''),(342966,109541,'116481','furniture','padding-top','10',0,''),(342967,109541,'116481','furniture','font_size_measure','em',0,''),(342968,109541,'116481','furniture','font-size','1.2',0,''),(342969,109542,'116482','furniture','text-align','right',0,''),(342970,109543,'116483','furniture','block_type','2',0,''),(342971,109544,'116484','furniture','block_type','1',0,''),(342972,109544,'116484','furniture','padding-right','20',0,''),(342973,109546,'116486','furniture','block_type','1',0,''),(342974,109546,'116486','furniture','padding-left','20',0,''),(342975,109546,'116486','furniture','padding-left','0',0,'5140'),(342976,109547,'116487','furniture','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(342977,109549,'116489','furniture','block_type','4',0,''),(342978,109549,'116489','furniture','schema','4-2',0,'5161'),(342979,109550,'116490','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(342980,109550,'116490','furniture','text-align','right',0,''),(342981,109550,'116490','furniture','padding-top','10',0,''),(342982,109550,'116490','furniture','font_size_measure','em',0,''),(342983,109550,'116490','furniture','font-size','1.2',0,''),(342984,109551,'116491','furniture','text-align','right',0,''),(342985,109552,'116492','furniture','block_type','2',0,''),(342986,109553,'116493','furniture','block_type','1',0,''),(342987,109553,'116493','furniture','padding-right','20',0,''),(342988,109555,'116495','furniture','block_type','1',0,''),(342989,109555,'116495','furniture','padding-left','20',0,''),(342990,109555,'116495','furniture','padding-left','0',0,'5140'),(342991,109557,'116497','furniture','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(342992,109558,'116498','furniture','text','##DELIVERY_DETAILS##',0,''),(342993,109559,'116499','furniture','text','##DELIVERY_DETAILS##',0,''),(342994,109560,'116501','furniture','text','##CONTACT_INFORMATION##',0,''),(342995,109561,'116500','furniture','text','##CONTACT_INFORMATION##',0,''),(342996,109562,'116502','furniture','text','##DELIVERY_DETAILS##',0,''),(342997,109563,'116503','furniture','text','##DELIVERY_DETAILS##',0,''),(342998,109564,'116504','furniture','block_type','1',0,''),(342999,109564,'116504','furniture','background-color','$content-bg-2',0,''),(343000,109564,'116504','furniture','padding-top','30',0,''),(343001,109564,'116504','furniture','padding-bottom','30',0,''),(343002,109565,'116505','furniture','block_type','7',0,''),(343003,109565,'116505','furniture','schema','4-2',0,'5140'),(343004,109566,'116506','furniture','block_type','1',0,''),(343005,109566,'116506','furniture','padding-right','0',0,'5140'),(343006,109567,'116508','furniture','block_type','1',0,''),(343007,109567,'116508','furniture','background-color','$content-bg-1',0,''),(343008,109567,'116508','furniture','padding-top','30',0,''),(343009,109567,'116508','furniture','padding-left','30',0,''),(343010,109567,'116508','furniture','padding-right','30',0,''),(343011,109567,'116508','furniture','padding-bottom','30',0,''),(343012,109567,'116508','furniture','margin-bottom','20',0,''),(343013,109567,'116508','furniture','style_class','hiding-box',0,''),(343014,109568,'116509','furniture','margin-bottom','20',0,''),(343015,109569,'116510','furniture','padding-top','10',0,''),(343016,109569,'116510','furniture','padding-left','20',0,''),(343017,109569,'116510','furniture','padding-right','20',0,''),(343018,109569,'116510','furniture','margin-top','20',0,''),(343019,109569,'116510','furniture','background-color','$content-bg-2',0,''),(343020,109569,'116510','furniture','padding-bottom','8',0,''),(343021,109570,'116511','furniture','block_type','1',0,''),(343022,109570,'116511','furniture','background-color','$content-bg-1',0,''),(343023,109570,'116511','furniture','padding-top','30',0,''),(343024,109570,'116511','furniture','padding-left','30',0,''),(343025,109570,'116511','furniture','padding-right','30',0,''),(343026,109570,'116511','furniture','padding-bottom','14',0,''),(343027,109570,'116511','furniture','margin-bottom','20',0,''),(343028,109570,'116511','furniture','style_class','hiding-box closeable-box',0,''),(343029,109571,'116512','furniture','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(343030,109571,'116512','furniture','style_class','closeable-heading closeable-event closed',0,''),(343031,109572,'116513','furniture','style_class','closeable-content',0,''),(343032,109572,'116513','furniture','padding-bottom','20',0,''),(343033,109573,'116514','furniture','background-color','$content-bg-1',0,''),(343034,109573,'116514','furniture','block_type','1',0,''),(343035,109573,'116514','furniture','padding-top','30',0,''),(343036,109573,'116514','furniture','padding-left','30',0,''),(343037,109573,'116514','furniture','padding-right','30',0,''),(343038,109573,'116514','furniture','padding-bottom','30',0,''),(343039,109573,'116514','furniture','margin-bottom','20',0,''),(343040,109573,'116514','furniture','style_class','hiding-box',0,''),(343041,109574,'116515','furniture','block_type','1',0,''),(343042,109574,'116515','furniture','content','\\_',0,'3'),(343043,109574,'116515','furniture','border-top-width','1',0,'3'),(343044,109574,'116515','furniture','border-top-color','$content-border-1',0,'3'),(343045,109574,'116515','furniture','display','block',0,'3'),(343046,109574,'116515','furniture','position','absolute',0,'3'),(343047,109574,'116515','furniture','top','19',0,'3'),(343048,109574,'116515','furniture','left','0',0,'3'),(343049,109574,'116515','furniture','right','0',0,'3'),(343050,109574,'116515','furniture','margin-top','-2',0,'3'),(343051,109574,'116515','furniture','position','relative',0,''),(343052,109575,'116516','furniture','box_align','2',0,''),(343053,109575,'116516','furniture','margin-bottom','10',0,''),(343054,109575,'116516','furniture','background-color','$content-bg-1',0,''),(343055,109575,'116516','furniture','position','relative',0,''),(343056,109576,'116517','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(343057,109577,'116518','furniture','block_type','2',0,''),(343058,109577,'116518','furniture','schema','2-2',0,'5140'),(343059,109578,'116519','furniture','block_type','1',0,''),(343060,109578,'116519','furniture','padding-right','20',0,''),(343061,109578,'116519','furniture','padding-left','0',0,'5140'),(343062,109578,'116519','furniture','margin-bottom','20',0,'5140'),(343063,109578,'116519','furniture','padding-right','0',0,'5140'),(343064,109581,'116522','furniture','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(343065,109582,'116523','furniture','block_type','1',0,''),(343066,109582,'116523','furniture','padding-left','20',0,''),(343067,109582,'116523','furniture','padding-left','0',0,'5140'),(343068,109583,'116524','furniture','padding-bottom','10',0,''),(343069,109584,'116525','furniture','background-color','$content-bg-2',0,''),(343070,109584,'116525','furniture','padding-top','10',0,''),(343071,109584,'116525','furniture','padding-left','10',0,''),(343072,109584,'116525','furniture','padding-right','10',0,''),(343073,109584,'116525','furniture','padding-bottom','10',0,''),(343074,109584,'116525','furniture','margin-top','10',0,''),(343075,109585,'116526','furniture','block_type','1',0,''),(343076,109585,'116526','furniture','padding-top','10',0,''),(343077,109585,'116526','furniture','padding-left','10',0,''),(343078,109585,'116526','furniture','padding-right','10',0,''),(343079,109585,'116526','furniture','padding-bottom','10',0,''),(343080,109585,'116526','furniture','background-color','$content-bg-1',0,''),(343081,109585,'116526','furniture','style_class','order-summary',0,''),(343082,109585,'116526','furniture','margin-left','25',0,''),(343083,109585,'116526','furniture','margin-left','0',0,'5140'),(343084,109586,'116527','furniture','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(343085,109586,'116527','furniture','text-align','center',0,''),(343086,109586,'116527','furniture','font-size','14',0,''),(343087,109586,'116527','furniture','color','$fade-color-1',0,''),(343088,109586,'116527','furniture','padding-top','10',0,''),(343089,109589,'1638957135.2709','furniture','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(343090,109590,'116529','furniture','block_type','1',0,''),(343091,109590,'116529','furniture','background-color','$content-bg-2',0,''),(343092,109590,'116529','furniture','padding-top','30',0,''),(343093,109590,'116529','furniture','padding-bottom','30',0,''),(343094,109590,'116529','furniture','color','$content-color-2',0,''),(343095,109591,'116530','furniture','block_type','7',0,''),(343096,109592,'116531','furniture','block_type','1',0,''),(343097,109593,'116532','furniture','block_type','1',0,''),(343098,109593,'116532','furniture','background-color','$content-bg-1',0,''),(343099,109593,'116532','furniture','padding-top','30',0,''),(343100,109593,'116532','furniture','padding-left','30',0,''),(343101,109593,'116532','furniture','padding-right','30',0,''),(343102,109593,'116532','furniture','padding-bottom','30',0,''),(343103,109593,'116532','furniture','margin-bottom','20',0,''),(343104,109593,'116532','furniture','style_class','hiding-box',0,''),(343105,109593,'116532','furniture','color','$content-color-1',0,''),(343106,109594,'116533','furniture','padding-top','10',0,''),(343107,109594,'116533','furniture','padding-left','20',0,''),(343108,109594,'116533','furniture','padding-right','20',0,''),(343109,109594,'116533','furniture','margin-top','20',0,''),(343110,109594,'116533','furniture','background-color','$content-bg-2',0,''),(343111,109594,'116533','furniture','padding-bottom','8',0,''),(343112,109594,'116533','furniture','color','$content-color-2',0,''),(343113,109595,'116534','furniture','margin-bottom','20',0,''),(343114,109596,'116535','furniture','block_type','1',0,''),(343115,109596,'116535','furniture','padding-top','30',0,''),(343116,109596,'116535','furniture','padding-left','30',0,''),(343117,109596,'116535','furniture','padding-right','30',0,''),(343118,109596,'116535','furniture','padding-bottom','23',0,''),(343119,109596,'116535','furniture','margin-bottom','20',0,''),(343120,109596,'116535','furniture','background-color','$content-bg-1',0,''),(343121,109596,'116535','furniture','style_class','hiding-box',0,''),(343122,109596,'116535','furniture','color','$content-color-1',0,''),(343123,109597,'116536','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(343124,109598,'116537','furniture','block_type','2',0,''),(343125,109599,'116538','furniture','padding-right','20',0,''),(343126,109600,'116539','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343127,109601,'116540','furniture','block_type','1',0,''),(343128,109601,'116540','furniture','padding-left','20',0,''),(343129,109602,'116541','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343130,109604,'116543','furniture','block_type','1',0,''),(343131,109604,'116543','furniture','padding-top','30',0,''),(343132,109604,'116543','furniture','padding-left','30',0,''),(343133,109604,'116543','furniture','padding-right','30',0,''),(343134,109604,'116543','furniture','padding-bottom','14',0,''),(343135,109604,'116543','furniture','margin-bottom','20',0,''),(343136,109604,'116543','furniture','background-color','$content-bg-1',0,''),(343137,109604,'116543','furniture','style_class','hiding-box closeable-box',0,''),(343138,109604,'116543','furniture','color','$content-color-1',0,''),(343139,109605,'116544','furniture','block_type','2',0,''),(343140,109605,'116544','furniture','style_class','closeable-content',0,''),(343141,109606,'116545','furniture','padding-right','20',0,''),(343142,109606,'116545','furniture','padding-bottom','20',0,''),(343143,109607,'116546','furniture','padding-left','20',0,''),(343144,109607,'116546','furniture','padding-bottom','20',0,''),(343145,109608,'116547','furniture','padding-left','20',0,''),(343146,109608,'116547','furniture','padding-bottom','20',0,''),(343147,109609,'116548','furniture','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(343148,109609,'116548','furniture','style_class','closeable-heading closeable-event closed',0,''),(343149,109610,'116549','furniture','block_type','1',0,''),(343150,109610,'116549','furniture','background-color','$content-bg-1',0,''),(343151,109610,'116549','furniture','padding-top','30',0,''),(343152,109610,'116549','furniture','padding-left','30',0,''),(343153,109610,'116549','furniture','padding-right','30',0,''),(343154,109610,'116549','furniture','padding-bottom','14',0,''),(343155,109610,'116549','furniture','margin-bottom','20',0,''),(343156,109610,'116549','furniture','style_class','hiding-box closeable-box',0,''),(343157,109610,'116549','furniture','color','$content-color-1',0,''),(343158,109611,'116550','furniture','style_class','closeable-content',0,''),(343159,109611,'116550','furniture','padding-bottom','20',0,''),(343160,109612,'116551','furniture','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(343161,109612,'116551','furniture','style_class','closeable-heading closeable-event closed',0,''),(343162,109613,'116552','furniture','block_type','1',0,''),(343163,109613,'116552','furniture','padding-top','10',0,''),(343164,109613,'116552','furniture','padding-left','10',0,''),(343165,109613,'116552','furniture','padding-right','10',0,''),(343166,109613,'116552','furniture','padding-bottom','10',0,''),(343167,109613,'116552','furniture','background-color','$content-bg-1',0,''),(343168,109613,'116552','furniture','style_class','order-summary hiding-box',0,''),(343169,109613,'116552','furniture','margin-left','25',0,''),(343170,109613,'116552','furniture','color','$content-color-1',0,''),(343171,109614,'116553','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(343172,109615,'116554','furniture','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(343173,109615,'116554','furniture','text-align','center',0,''),(343174,109615,'116554','furniture','font-size','14',0,''),(343175,109615,'116554','furniture','color','$fade-color-1',0,''),(343176,109615,'116554','furniture','padding-top','10',0,''),(343177,109616,'116555','furniture','margin-bottom','10',0,''),(343178,109618,'116557','furniture','hide_page','1',0,''),(343179,109618,'116557','furniture','hide_continue_button','1',0,''),(343180,109619,'116558','furniture','block_type','1',0,''),(343181,109621,'116560','furniture','block_type','4',0,''),(343182,109621,'116560','furniture','schema','4-2',0,'5161'),(343183,109622,'116561','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(343184,109622,'116561','furniture','text-align','right',0,''),(343185,109622,'116561','furniture','padding-top','10',0,''),(343186,109622,'116561','furniture','font_size_measure','em',0,''),(343187,109622,'116561','furniture','font-size','1.2',0,''),(343188,109623,'116562','furniture','text-align','right',0,''),(343189,109624,'116563','furniture','block_type','2',0,''),(343190,109624,'116563','furniture','schema','2-2',0,'5140'),(343191,109625,'116564','furniture','block_type','1',0,''),(343192,109625,'116564','furniture','padding-right','20',0,''),(343193,109625,'116564','furniture','padding-right','0',0,'5140'),(343194,109627,'116566','furniture','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(343195,109628,'116567','furniture','block_type','1',0,''),(343196,109628,'116567','furniture','padding-left','20',0,''),(343197,109628,'116567','furniture','padding-left','0',0,'5140'),(343198,109630,'116569','furniture','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(343199,109631,'116570','furniture','block_type','2',0,''),(343200,109631,'116570','furniture','schema','2-2',0,'5140'),(343201,109632,'116571','furniture','block_type','1',0,''),(343202,109632,'116571','furniture','padding-right','20',0,''),(343203,109632,'116571','furniture','padding-right','0',0,'5140'),(343204,109633,'116572','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343205,109635,'116574','furniture','block_type','1',0,''),(343206,109635,'116574','furniture','padding-left','20',0,''),(343207,109635,'116574','furniture','padding-left','0',0,'5140'),(343208,109640,'116579','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343209,109641,'116580','furniture','margin-bottom','20',0,''),(343210,109642,'116581','furniture','block_type','1',0,''),(343211,109642,'116581','furniture','background-color','$content-bg-2',0,''),(343212,109642,'116581','furniture','padding-top','30',0,''),(343213,109642,'116581','furniture','padding-bottom','30',0,''),(343214,109643,'116582','furniture','block_type','7',0,''),(343215,109643,'116582','furniture','schema','4-2',0,'5140'),(343216,109643,'116582','furniture','margin-bottom','30',0,''),(343217,109644,'116583','furniture','block_type','1',0,''),(343218,109644,'116583','furniture','padding-right','0',0,'5140'),(343219,109645,'116585','furniture','block_type','1',0,''),(343220,109645,'116585','furniture','background-color','$content-bg-1',0,''),(343221,109645,'116585','furniture','padding-top','30',0,''),(343222,109645,'116585','furniture','padding-left','30',0,''),(343223,109645,'116585','furniture','padding-right','30',0,''),(343224,109645,'116585','furniture','padding-bottom','14',0,''),(343225,109645,'116585','furniture','margin-bottom','20',0,''),(343226,109645,'116585','furniture','style_class','hiding-box closeable-box',0,''),(343227,109646,'116586','furniture','style_class','closeable-content',0,''),(343228,109646,'116586','furniture','padding-bottom','20',0,''),(343229,109647,'116587','furniture','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(343230,109647,'116587','furniture','style_class','closeable-heading closeable-event closed',0,''),(343231,109648,'116588','furniture','block_type','1',0,''),(343232,109648,'116588','furniture','background-color','$content-bg-1',0,''),(343233,109648,'116588','furniture','padding-top','30',0,''),(343234,109648,'116588','furniture','padding-left','30',0,''),(343235,109648,'116588','furniture','padding-right','30',0,''),(343236,109648,'116588','furniture','padding-bottom','30',0,''),(343237,109648,'116588','furniture','margin-bottom','20',0,''),(343238,109648,'116588','furniture','style_class','hiding-box',0,''),(343239,109649,'116589','furniture','padding-top','10',0,''),(343240,109649,'116589','furniture','padding-left','20',0,''),(343241,109649,'116589','furniture','padding-right','20',0,''),(343242,109649,'116589','furniture','margin-top','20',0,''),(343243,109649,'116589','furniture','background-color','$content-bg-2',0,''),(343244,109649,'116589','furniture','padding-bottom','8',0,''),(343245,109650,'116590','furniture','margin-bottom','20',0,''),(343246,109651,'116591','furniture','block_type','1',0,''),(343247,109651,'116591','furniture','padding-top','30',0,''),(343248,109651,'116591','furniture','padding-left','30',0,''),(343249,109651,'116591','furniture','padding-right','30',0,''),(343250,109651,'116591','furniture','padding-bottom','23',0,''),(343251,109651,'116591','furniture','margin-bottom','20',0,''),(343252,109651,'116591','furniture','background-color','$content-bg-1',0,''),(343253,109651,'116591','furniture','style_class','hiding-box',0,''),(343254,109652,'116592','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(343255,109653,'116593','furniture','block_type','2',0,''),(343256,109653,'116593','furniture','schema','2-2',0,'5140'),(343257,109654,'116594','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343258,109655,'116595','furniture','padding-right','20',0,''),(343259,109655,'116595','furniture','padding-right','0',0,'5140'),(343260,109655,'116595','furniture','padding-bottom','20',0,'5140'),(343261,109656,'116596','furniture','block_type','1',0,''),(343262,109656,'116596','furniture','padding-left','20',0,''),(343263,109656,'116596','furniture','padding-left','0',0,'5140'),(343264,109658,'116598','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343265,109659,'116599','furniture','block_type','1',0,''),(343266,109659,'116599','furniture','padding-top','10',0,''),(343267,109659,'116599','furniture','padding-left','10',0,''),(343268,109659,'116599','furniture','padding-right','10',0,''),(343269,109659,'116599','furniture','padding-bottom','10',0,''),(343270,109659,'116599','furniture','background-color','$content-bg-1',0,''),(343271,109659,'116599','furniture','style_class','order-summary',0,''),(343272,109659,'116599','furniture','margin-left','25',0,''),(343273,109661,'116601','furniture','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(343274,109661,'116601','furniture','text-align','center',0,''),(343275,109661,'116601','furniture','font-size','14',0,''),(343276,109661,'116601','furniture','color','$fade-color-1',0,''),(343277,109661,'116601','furniture','padding-top','10',0,''),(343278,109662,'116602','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(343279,109663,'116603','furniture','margin-bottom','10',0,''),(343280,109665,'116604','furniture','block_type','2',0,''),(343281,109666,'116605','furniture','block_type','1',0,''),(343282,109666,'116605','furniture','padding-left','0',0,'5140'),(343283,109666,'116605','furniture','padding-right','20',0,''),(343284,109668,'116607','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343285,109669,'116608','furniture','block_type','1',0,''),(343286,109669,'116608','furniture','padding-left','20',0,''),(343287,109669,'116608','furniture','padding-left','0',0,'5140'),(343288,109674,'116613','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343289,109675,'116614','furniture','block_type','4',0,''),(343290,109675,'116614','furniture','schema','4-2',0,'5161'),(343291,109676,'116615','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(343292,109676,'116615','furniture','text-align','right',0,''),(343293,109676,'116615','furniture','padding-top','10',0,''),(343294,109676,'116615','furniture','font_size_measure','em',0,''),(343295,109676,'116615','furniture','font-size','1.2',0,''),(343296,109677,'116616','furniture','text-align','right',0,''),(343297,109678,'116617','furniture','block_type','2',0,''),(343298,109679,'116618','furniture','block_type','1',0,''),(343299,109679,'116618','furniture','padding-left','0',0,'5140'),(343300,109679,'116618','furniture','padding-right','20',0,''),(343301,109681,'116620','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343302,109682,'116621','furniture','block_type','1',0,''),(343303,109682,'116621','furniture','padding-left','20',0,''),(343304,109682,'116621','furniture','padding-left','0',0,'5140'),(343305,109684,'116623','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343306,109688,'116627','furniture','block_type','4',0,''),(343307,109688,'116627','furniture','schema','4-2',0,'5161'),(343308,109689,'116628','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(343309,109689,'116628','furniture','text-align','right',0,''),(343310,109689,'116628','furniture','padding-top','10',0,''),(343311,109689,'116628','furniture','font_size_measure','em',0,''),(343312,109689,'116628','furniture','font-size','1.2',0,''),(343313,109690,'116629','furniture','text-align','right',0,''),(343314,109691,'116630','furniture','block_type','4',0,''),(343315,109691,'116630','furniture','schema','4-2',0,'5161'),(343316,109692,'116631','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(343317,109692,'116631','furniture','text-align','right',0,''),(343318,109692,'116631','furniture','padding-top','10',0,''),(343319,109692,'116631','furniture','font_size_measure','em',0,''),(343320,109692,'116631','furniture','font-size','1.2',0,''),(343321,109693,'116632','furniture','text-align','right',0,''),(343322,109694,'116633','furniture','block_type','2',0,''),(343323,109695,'116634','furniture','block_type','1',0,''),(343324,109695,'116634','furniture','padding-left','0',0,'5140'),(343325,109695,'116634','furniture','padding-right','20',0,''),(343326,109696,'116635','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343327,109698,'116637','furniture','block_type','1',0,''),(343328,109698,'116637','furniture','padding-left','20',0,''),(343329,109698,'116637','furniture','padding-left','0',0,'5140'),(343330,109703,'116642','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343331,109704,'116643','furniture','block_type','4',0,''),(343332,109704,'116643','furniture','schema','4-2',0,'5161'),(343333,109705,'116644','furniture','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(343334,109705,'116644','furniture','text-align','right',0,''),(343335,109705,'116644','furniture','padding-top','10',0,''),(343336,109705,'116644','furniture','font_size_measure','em',0,''),(343337,109705,'116644','furniture','font-size','1.2',0,''),(343338,109706,'116645','furniture','text-align','right',0,''),(343339,109707,'116646','furniture','block_type','2',0,''),(343340,109708,'116647','furniture','block_type','1',0,''),(343341,109708,'116647','furniture','padding-left','0',0,'5140'),(343342,109708,'116647','furniture','padding-right','20',0,''),(343343,109710,'116649','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343344,109711,'116650','furniture','block_type','1',0,''),(343345,109711,'116650','furniture','padding-left','20',0,''),(343346,109711,'116650','furniture','padding-left','0',0,'5140'),(343347,109715,'116654','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343348,109717,'116656','furniture','text','##PAYMENT_DETAILS##',0,''),(343349,109718,'116657','furniture','text','##PAYMENT_DETAILS##',0,''),(343350,109719,'116658','furniture','text','##PAYMENT_DETAILS##',0,''),(343351,109720,'116659','furniture','text','##PAYMENT_DETAILS##',0,''),(343352,109721,'116660','furniture','text','##PAYMENT_DETAILS##',0,''),(343353,109722,'116661','furniture','text','##PAYMENT_DETAILS##',0,''),(343354,109723,'120947','furniture','block_type','1',0,''),(343355,109723,'120947','furniture','background-color','$content-bg-2',0,''),(343356,109723,'120947','furniture','padding-top','30',0,''),(343357,109723,'120947','furniture','padding-bottom','30',0,''),(343358,109724,'120948','furniture','block_type','7',0,''),(343359,109724,'120948','furniture','schema','4-2',0,'5140'),(343360,109725,'120949','furniture','block_type','1',0,''),(343361,109725,'120949','furniture','padding-right','0',0,'5140'),(343362,109726,'120950','furniture','block_type','1',0,''),(343363,109726,'120950','furniture','background-color','$content-bg-1',0,''),(343364,109726,'120950','furniture','padding-top','30',0,''),(343365,109726,'120950','furniture','padding-left','30',0,''),(343366,109726,'120950','furniture','padding-right','30',0,''),(343367,109726,'120950','furniture','padding-bottom','30',0,''),(343368,109726,'120950','furniture','margin-bottom','20',0,''),(343369,109726,'120950','furniture','style_class','hiding-box',0,''),(343370,109727,'120951','furniture','padding-top','10',0,''),(343371,109727,'120951','furniture','padding-left','20',0,''),(343372,109727,'120951','furniture','padding-right','20',0,''),(343373,109727,'120951','furniture','margin-top','20',0,''),(343374,109727,'120951','furniture','background-color','$content-bg-2',0,''),(343375,109727,'120951','furniture','padding-bottom','8',0,''),(343376,109728,'120952','furniture','margin-bottom','20',0,''),(343377,109729,'120953','furniture','background-color','$content-bg-1',0,''),(343378,109729,'120953','furniture','block_type','1',0,''),(343379,109729,'120953','furniture','padding-top','30',0,''),(343380,109729,'120953','furniture','padding-left','30',0,''),(343381,109729,'120953','furniture','padding-right','30',0,''),(343382,109729,'120953','furniture','padding-bottom','30',0,''),(343383,109729,'120953','furniture','margin-bottom','20',0,''),(343384,109729,'120953','furniture','style_class','hiding-box',0,''),(343385,109730,'120954','furniture','block_type','1',0,''),(343386,109730,'120954','furniture','content','\\_',0,'3'),(343387,109730,'120954','furniture','border-top-width','1',0,'3'),(343388,109730,'120954','furniture','border-top-color','$content-border-1',0,'3'),(343389,109730,'120954','furniture','display','block',0,'3'),(343390,109730,'120954','furniture','position','absolute',0,'3'),(343391,109730,'120954','furniture','top','19',0,'3'),(343392,109730,'120954','furniture','left','0',0,'3'),(343393,109730,'120954','furniture','right','0',0,'3'),(343394,109730,'120954','furniture','margin-top','-2',0,'3'),(343395,109730,'120954','furniture','position','relative',0,''),(343396,109731,'120955','furniture','box_align','2',0,''),(343397,109731,'120955','furniture','margin-bottom','10',0,''),(343398,109731,'120955','furniture','background-color','$content-bg-1',0,''),(343399,109731,'120955','furniture','position','relative',0,''),(343400,109732,'120956','furniture','background-color','$content-bg-2',0,''),(343401,109732,'120956','furniture','padding-top','10',0,''),(343402,109732,'120956','furniture','padding-left','10',0,''),(343403,109732,'120956','furniture','padding-right','10',0,''),(343404,109732,'120956','furniture','padding-bottom','10',0,''),(343405,109732,'120956','furniture','margin-top','10',0,''),(343406,109733,'120957','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(343407,109734,'120958','furniture','block_type','2',0,''),(343408,109734,'120958','furniture','schema','2-2',0,'5140'),(343409,109735,'120959','furniture','block_type','1',0,''),(343410,109735,'120959','furniture','padding-right','20',0,''),(343411,109735,'120959','furniture','padding-left','0',0,'5140'),(343412,109735,'120959','furniture','margin-bottom','20',0,'5140'),(343413,109735,'120959','furniture','padding-right','0',0,'5140'),(343414,109738,'120962','furniture','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(343415,109739,'120963','furniture','block_type','1',0,''),(343416,109739,'120963','furniture','padding-left','20',0,''),(343417,109739,'120963','furniture','padding-left','0',0,'5140'),(343418,109741,'120965','furniture','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(343419,109742,'120966','furniture','border-top-width','1',0,''),(343420,109742,'120966','furniture','border-top-color','$content-border-1',0,''),(343421,109742,'120966','furniture','padding-top','13',0,''),(343422,109742,'120966','furniture','padding-bottom','10',0,''),(343423,109743,'120967','furniture','block_type','1',0,''),(343424,109743,'120967','furniture','background-color','$content-bg-1',0,''),(343425,109743,'120967','furniture','padding-top','30',0,''),(343426,109743,'120967','furniture','padding-left','30',0,''),(343427,109743,'120967','furniture','padding-right','30',0,''),(343428,109743,'120967','furniture','padding-bottom','14',0,''),(343429,109743,'120967','furniture','margin-bottom','20',0,''),(343430,109743,'120967','furniture','style_class','hiding-box closeable-box',0,''),(343431,109744,'120968','furniture','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(343432,109744,'120968','furniture','style_class','closeable-heading closeable-event closed',0,''),(343433,109745,'120969','furniture','style_class','closeable-content',0,''),(343434,109745,'120969','furniture','padding-bottom','20',0,''),(343435,109746,'120970','furniture','block_type','1',0,''),(343436,109746,'120970','furniture','padding-top','30',0,''),(343437,109746,'120970','furniture','padding-left','30',0,''),(343438,109746,'120970','furniture','padding-right','30',0,''),(343439,109746,'120970','furniture','padding-bottom','23',0,''),(343440,109746,'120970','furniture','margin-bottom','20',0,''),(343441,109746,'120970','furniture','background-color','$content-bg-1',0,''),(343442,109746,'120970','furniture','style_class','hiding-box',0,''),(343443,109747,'120971','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(343444,109748,'120972','furniture','block_type','2',0,''),(343445,109748,'120972','furniture','schema','2-2',0,'5140'),(343446,109749,'120973','furniture','padding-right','20',0,''),(343447,109749,'120973','furniture','padding-right','0',0,'5140'),(343448,109749,'120973','furniture','padding-bottom','20',0,'5140'),(343449,109750,'120974','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343450,109751,'120975','furniture','block_type','1',0,''),(343451,109751,'120975','furniture','padding-left','20',0,''),(343452,109751,'120975','furniture','padding-left','0',0,'5140'),(343453,109753,'120977','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343454,109754,'120978','furniture','block_type','1',0,''),(343455,109754,'120978','furniture','padding-left','10',0,''),(343456,109754,'120978','furniture','padding-right','10',0,''),(343457,109754,'120978','furniture','padding-bottom','10',0,''),(343458,109754,'120978','furniture','background-color','$content-bg-1',0,''),(343459,109754,'120978','furniture','style_class','order-summary',0,''),(343460,109754,'120978','furniture','margin-left','25',0,''),(343461,109754,'120978','furniture','margin-left','0',0,'5140'),(343462,109755,'120979','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(343463,109756,'120980','furniture','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(343464,109756,'120980','furniture','text-align','center',0,''),(343465,109756,'120980','furniture','font-size','14',0,''),(343466,109756,'120980','furniture','color','$fade-color-1',0,''),(343467,109756,'120980','furniture','padding-top','10',0,''),(343468,109757,'120981','furniture','margin-bottom','10',0,''),(343469,109759,'120983','furniture','hide_continue_button','1',0,''),(343470,109760,'116699','furniture','block_type','1',0,''),(343471,109760,'116699','furniture','background-color','$content-bg-2',0,''),(343472,109760,'116699','furniture','padding-top','30',0,''),(343473,109760,'116699','furniture','padding-bottom','30',0,''),(343474,109761,'116700','furniture','block_type','7',0,''),(343475,109761,'116700','furniture','schema','7-2',0,'5140'),(343476,109762,'116701','furniture','block_type','1',0,''),(343477,109762,'116701','furniture','padding-right','0',0,'5140'),(343478,109763,'116703','furniture','block_type','1',0,''),(343479,109763,'116703','furniture','background-color','$content-bg-1',0,''),(343480,109763,'116703','furniture','padding-top','30',0,''),(343481,109763,'116703','furniture','padding-left','30',0,''),(343482,109763,'116703','furniture','padding-right','30',0,''),(343483,109763,'116703','furniture','padding-bottom','30',0,''),(343484,109763,'116703','furniture','margin-bottom','20',0,''),(343485,109763,'116703','furniture','style_class','hiding-box',0,''),(343486,109764,'116704','furniture','margin-bottom','20',0,''),(343487,109765,'116705','furniture','padding-top','10',0,''),(343488,109765,'116705','furniture','padding-left','20',0,''),(343489,109765,'116705','furniture','padding-right','20',0,''),(343490,109765,'116705','furniture','margin-top','20',0,''),(343491,109765,'116705','furniture','background-color','$content-bg-2',0,''),(343492,109765,'116705','furniture','padding-bottom','8',0,''),(343493,109766,'116706','furniture','background-color','$content-bg-1',0,''),(343494,109766,'116706','furniture','block_type','1',0,''),(343495,109766,'116706','furniture','padding-top','30',0,''),(343496,109766,'116706','furniture','padding-left','30',0,''),(343497,109766,'116706','furniture','padding-right','30',0,''),(343498,109766,'116706','furniture','padding-bottom','30',0,''),(343499,109766,'116706','furniture','margin-bottom','20',0,''),(343500,109766,'116706','furniture','style_class','hiding-box',0,''),(343501,109767,'116707','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(343502,109768,'116708','furniture','background-color','$content-bg-2',0,''),(343503,109768,'116708','furniture','padding-top','10',0,''),(343504,109768,'116708','furniture','padding-left','10',0,''),(343505,109768,'116708','furniture','padding-right','10',0,''),(343506,109768,'116708','furniture','padding-bottom','10',0,''),(343507,109768,'116708','furniture','margin-top','10',0,''),(343508,109769,'116709','furniture','block_type','1',0,''),(343509,109769,'116709','furniture','content','\\_',0,'3'),(343510,109769,'116709','furniture','border-top-width','1',0,'3'),(343511,109769,'116709','furniture','border-top-color','$content-border-1',0,'3'),(343512,109769,'116709','furniture','display','block',0,'3'),(343513,109769,'116709','furniture','position','absolute',0,'3'),(343514,109769,'116709','furniture','top','19',0,'3'),(343515,109769,'116709','furniture','left','0',0,'3'),(343516,109769,'116709','furniture','right','0',0,'3'),(343517,109769,'116709','furniture','margin-top','-2',0,'3'),(343518,109769,'116709','furniture','position','relative',0,''),(343519,109770,'116710','furniture','box_align','2',0,''),(343520,109770,'116710','furniture','margin-bottom','10',0,''),(343521,109770,'116710','furniture','background-color','$content-bg-1',0,''),(343522,109770,'116710','furniture','position','relative',0,''),(343523,109771,'116711','furniture','block_type','2',0,''),(343524,109771,'116711','furniture','schema','2-2',0,'5140'),(343525,109772,'116712','furniture','block_type','1',0,''),(343526,109772,'116712','furniture','padding-right','20',0,''),(343527,109772,'116712','furniture','padding-left','0',0,'5140'),(343528,109772,'116712','furniture','margin-bottom','20',0,'5140'),(343529,109772,'116712','furniture','padding-right','0',0,'5140'),(343530,109775,'116715','furniture','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(343531,109776,'116716','furniture','block_type','1',0,''),(343532,109776,'116716','furniture','padding-left','20',0,''),(343533,109776,'116716','furniture','padding-left','0',0,'5140'),(343534,109778,'116718','furniture','border-top-width','1',0,''),(343535,109778,'116718','furniture','border-top-color','$content-border-1',0,''),(343536,109778,'116718','furniture','padding-top','13',0,''),(343537,109778,'116718','furniture','padding-bottom','10',0,''),(343538,109779,'116719','furniture','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(343539,109780,'116720','furniture','block_type','1',0,''),(343540,109780,'116720','furniture','padding-top','30',0,''),(343541,109780,'116720','furniture','padding-left','30',0,''),(343542,109780,'116720','furniture','padding-right','30',0,''),(343543,109780,'116720','furniture','padding-bottom','23',0,''),(343544,109780,'116720','furniture','margin-bottom','20',0,''),(343545,109780,'116720','furniture','background-color','$content-bg-1',0,''),(343546,109780,'116720','furniture','style_class','hiding-box',0,''),(343547,109781,'116721','furniture','block_type','2',0,''),(343548,109781,'116721','furniture','schema','2-2',0,'5140'),(343549,109782,'116722','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343550,109783,'116723','furniture','padding-right','20',0,''),(343551,109783,'116723','furniture','padding-right','0',0,'5140'),(343552,109783,'116723','furniture','padding-bottom','20',0,'5140'),(343553,109784,'116724','furniture','block_type','1',0,''),(343554,109784,'116724','furniture','padding-left','20',0,''),(343555,109784,'116724','furniture','padding-left','0',0,'5140'),(343556,109785,'116725','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343557,109787,'116727','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(343558,109788,'116728','furniture','block_type','1',0,''),(343559,109788,'116728','furniture','background-color','$content-bg-1',0,''),(343560,109788,'116728','furniture','padding-top','30',0,''),(343561,109788,'116728','furniture','padding-left','30',0,''),(343562,109788,'116728','furniture','padding-right','30',0,''),(343563,109788,'116728','furniture','padding-bottom','14',0,''),(343564,109788,'116728','furniture','margin-bottom','20',0,''),(343565,109788,'116728','furniture','style_class','hiding-box closeable-box',0,''),(343566,109789,'116729','furniture','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(343567,109789,'116729','furniture','style_class','closeable-heading closeable-event closed',0,''),(343568,109790,'116730','furniture','style_class','closeable-content',0,''),(343569,109790,'116730','furniture','padding-bottom','20',0,''),(343570,109791,'116731','furniture','block_type','1',0,''),(343571,109791,'116731','furniture','padding-top','30',0,''),(343572,109791,'116731','furniture','padding-left','30',0,''),(343573,109791,'116731','furniture','padding-right','30',0,''),(343574,109791,'116731','furniture','padding-bottom','14',0,''),(343575,109791,'116731','furniture','margin-bottom','20',0,''),(343576,109791,'116731','furniture','background-color','$content-bg-1',0,''),(343577,109791,'116731','furniture','style_class','hiding-box closeable-box',0,''),(343578,109792,'116732','furniture','block_type','2',0,''),(343579,109792,'116732','furniture','style_class','closeable-content',0,''),(343580,109792,'116732','furniture','schema','2-2',0,'5140'),(343581,109793,'116733','furniture','padding-right','20',0,''),(343582,109793,'116733','furniture','padding-bottom','20',0,''),(343583,109793,'116733','furniture','padding-right','0',0,'5140'),(343584,109794,'116734','furniture','padding-left','20',0,''),(343585,109794,'116734','furniture','padding-bottom','20',0,''),(343586,109794,'116734','furniture','padding-left','0',0,'5140'),(343587,109795,'116735','furniture','padding-left','20',0,''),(343588,109795,'116735','furniture','padding-bottom','20',0,''),(343589,109795,'116735','furniture','padding-left','0',0,'5140'),(343590,109796,'116736','furniture','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(343591,109796,'116736','furniture','style_class','closeable-heading closeable-event closed',0,''),(343592,109797,'116737','furniture','block_type','1',0,''),(343593,109797,'116737','furniture','padding-top','20',0,''),(343594,109797,'116737','furniture','padding-left','20',0,''),(343595,109797,'116737','furniture','padding-right','20',0,''),(343596,109797,'116737','furniture','padding-bottom','20',0,''),(343597,109797,'116737','furniture','background-color','$content-bg-1',0,''),(343598,109797,'116737','furniture','style_class','order-summary',0,''),(343599,109797,'116737','furniture','margin-left','25',0,''),(343600,109797,'116737','furniture','padding-left','0',0,'5140'),(343601,109798,'116738','furniture','margin-bottom','10',0,''),(343602,109799,'116739','furniture','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(343603,109799,'116739','furniture','text-align','center',0,''),(343604,109799,'116739','furniture','font-size','14',0,''),(343605,109799,'116739','furniture','color','$fade-color-1',0,''),(343606,109799,'116739','furniture','padding-top','10',0,''),(343607,109800,'116740','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(343608,109802,'120986','furniture','hide_continue_button','1',0,''),(343609,109803,'116742','furniture','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(343610,109808,'116747','furniture','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(343611,109809,'116749','furniture','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(343612,109810,'116750','furniture','style_class','order-summary',0,''),(343613,109810,'116750','furniture','box_align','3',0,''),(343614,109810,'116750','furniture','width','400',0,''),(343615,109812,'116748','furniture','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(343616,109815,'116754','furniture','block_type','1',0,''),(343617,109816,'116755','furniture','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(343618,109817,'116756','furniture','float','right',0,''),(343619,109817,'116756','furniture','position','relative',0,''),(343620,109817,'116756','furniture','z-index','1',0,''),(343621,109817,'116756','furniture','top','30',0,''),(343622,109817,'116756','furniture','margin-bottom','-10',0,''),(343623,109818,'116757','furniture','margin-bottom','30',0,''),(343624,109819,'116758','furniture','block_type','1',0,''),(343625,109820,'116759','furniture','listing_type','CompareProduct',0,''),(343626,109821,'117665.000001','furniture','block_type','1',0,''),(343627,109821,'117665.000001','furniture','style_class','item-holder',0,''),(343628,109821,'117665.000001','furniture','padding-top','25',0,''),(343629,109821,'117665.000001','furniture','padding-left','25',0,''),(343630,109821,'117665.000001','furniture','padding-right','25',0,''),(343631,109821,'117665.000001','furniture','padding-bottom','25',0,''),(343632,109821,'117665.000001','furniture','text-align','left',0,''),(343633,109822,'120921.000001','furniture','block_type','1',0,''),(343634,109822,'120921.000001','furniture','style_class','item-wrapper',0,''),(343635,109823,'120919.000001','furniture','block_type','1',0,''),(343636,109823,'120919.000001','furniture','style_class','item-content',0,''),(343637,109824,'1638872990.9609','furniture','block_type','5',0,''),(343638,109826,'117677.000001','furniture','float','right',0,''),(343639,109827,'117675.000001','furniture','clear','none',0,''),(343640,109828,'117676.000001','furniture','margin-bottom','10',0,''),(343641,109829,'1638873112.0384','furniture','block_type','2',0,''),(343642,109831,'117673.000001','furniture','margin-bottom','7',0,''),(343643,109831,'117673.000001','furniture','text-align','right',0,''),(343644,109832,'116760','furniture','block_type','1',0,''),(343645,109832,'116760','furniture','style_class','item-holder',0,''),(343646,109832,'116760','furniture','padding-top','10',0,''),(343647,109832,'116760','furniture','padding-left','20',0,''),(343648,109832,'116760','furniture','padding-right','20',0,''),(343649,109832,'116760','furniture','padding-bottom','10',0,''),(343650,109832,'116760','furniture','text-align','left',0,''),(343651,109835,'116763','furniture','margin-bottom','10',0,''),(343652,109836,'116764','furniture','block_type','5',0,''),(343653,109838,'116766','furniture','clear','both',0,''),(343654,109839,'116767','furniture','block_type','2',0,''),(343655,109840,'116768','furniture','margin-bottom','7',0,''),(343656,109841,'116769','furniture','text-align','right',0,''),(343657,109841,'116769','furniture','margin-bottom','10',0,''),(343658,109841,'116769','furniture','float','right',0,''),(343659,109842,'116770','furniture','block_type','1',0,''),(343660,109842,'116770','furniture','background-color','$content-bg-2',0,''),(343661,109842,'116770','furniture','padding-bottom','30',0,''),(343662,109842,'116770','furniture','style_class','checkout-order-confirmation',0,''),(343663,109842,'116770','furniture','color','$content-color-2',0,''),(343664,109843,'116771','furniture','block_type','4',0,''),(343665,109843,'116771','furniture','schema','4-2',0,'5140'),(343666,109844,'116772','furniture','block_type','1',0,''),(343667,109844,'116772','furniture','padding-right','40',0,''),(343668,109844,'116772','furniture','padding-right','0',0,'5140'),(343669,109845,'116773','furniture','block_type','1',0,''),(343670,109845,'116773','furniture','padding-right','30',0,''),(343671,109845,'116773','furniture','background-color','$content-bg-1',0,''),(343672,109845,'116773','furniture','padding-top','20',0,''),(343673,109845,'116773','furniture','padding-left','30',0,''),(343674,109845,'116773','furniture','padding-bottom','20',0,''),(343675,109845,'116773','furniture','padding-left','20',0,'5140'),(343676,109845,'116773','furniture','padding-right','20',0,'5140'),(343677,109845,'116773','furniture','color','$content-color-1',0,''),(343678,109846,'116774','furniture','link','products',0,''),(343679,109846,'116774','furniture','float','right',0,''),(343680,109846,'116774','furniture','margin-top','-37',0,''),(343681,109848,'116776','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(343682,109849,'116777','furniture','block_type','1',0,''),(343683,109849,'116777','furniture','background-color','$content-bg-1',0,''),(343684,109849,'116777','furniture','padding-top','20',0,''),(343685,109849,'116777','furniture','padding-bottom','20',0,''),(343686,109849,'116777','furniture','padding-left','30',0,''),(343687,109849,'116777','furniture','padding-right','30',0,''),(343688,109849,'116777','furniture','margin-bottom','20',0,''),(343689,109849,'116777','furniture','color','$content-color-1',0,''),(343690,109850,'116778','furniture','float','right',0,''),(343691,109850,'116778','furniture','margin-top','-37',0,''),(343692,109850,'116778','furniture','link','comments',0,''),(343693,109851,'116779','furniture','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(343694,109852,'116780','furniture','hide_parents','2',0,''),(343695,109853,'116781','furniture','block_type','2',0,''),(343696,109853,'116781','furniture','margin-bottom','20',0,''),(343697,109853,'116781','furniture','schema','2-2',0,'5131'),(343698,109853,'116781','furniture','background-color','$content-bg-1',0,''),(343699,109853,'116781','furniture','color','$content-color-1',0,''),(343700,109854,'116782','furniture','block_type','1',0,''),(343701,109854,'116782','furniture','border-right-width','20',0,''),(343702,109854,'116782','furniture','border-right-color','$content-bg-2',0,''),(343703,109854,'116782','furniture','margin-right','-10',0,''),(343704,109854,'116782','furniture','padding-right','30',0,''),(343705,109854,'116782','furniture','padding-top','20',0,''),(343706,109854,'116782','furniture','padding-left','30',0,''),(343707,109854,'116782','furniture','padding-bottom','20',0,''),(343708,109854,'116782','furniture','border-right-width','0',0,'5140'),(343709,109854,'116782','furniture','margin-right','0',0,'5140'),(343710,109854,'116782','furniture','margin-bottom','20',0,'5140'),(343711,109854,'116782','furniture','padding-left','20',0,'5140'),(343712,109854,'116782','furniture','padding-right','20',0,'5140'),(343713,109855,'116783','furniture','link','shipping_method',0,''),(343714,109855,'116783','furniture','float','right',0,''),(343715,109855,'116783','furniture','margin-top','-31',0,''),(343716,109857,'116785','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(343717,109857,'116785','furniture','padding-top','20',0,''),(343718,109858,'116786','furniture','link','contact_information',0,''),(343719,109858,'116786','furniture','margin-top','-31',0,''),(343720,109858,'116786','furniture','float','right',0,''),(343721,109859,'116787','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(343722,109859,'116787','furniture','clear','none',0,''),(343723,109861,'116789','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(343724,109862,'116790','furniture','link','shipping_address',0,''),(343725,109862,'116790','furniture','float','right',0,''),(343726,109862,'116790','furniture','margin-top','-31',0,''),(343727,109864,'116792','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(343728,109864,'116792','furniture','clear','none',0,''),(343729,109865,'116793','furniture','margin-bottom','20',0,''),(343730,109866,'116794','furniture','block_type','1',0,''),(343731,109866,'116794','furniture','padding-left','30',0,''),(343732,109866,'116794','furniture','border-left-width','20',0,''),(343733,109866,'116794','furniture','border-left-color','$content-bg-2',0,''),(343734,109866,'116794','furniture','margin-left','-10',0,''),(343735,109866,'116794','furniture','padding-right','30',0,''),(343736,109866,'116794','furniture','padding-top','20',0,''),(343737,109866,'116794','furniture','padding-bottom','20',0,''),(343738,109866,'116794','furniture','border-left-width','0',0,'5140'),(343739,109867,'116795','furniture','link','payment_method',0,''),(343740,109867,'116795','furniture','float','right',0,''),(343741,109867,'116795','furniture','margin-top','-31',0,''),(343742,109868,'116796','furniture','link','billing_address',0,''),(343743,109868,'116796','furniture','float','right',0,''),(343744,109868,'116796','furniture','margin-top','-31',0,''),(343745,109870,'116798','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343746,109870,'116798','furniture','clear','none',0,''),(343747,109871,'116799','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(343748,109872,'116800','furniture','margin-bottom','20',0,''),(343749,109873,'116801','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343750,109873,'116801','furniture','clear','none',0,''),(343751,109875,'116803','furniture','block_type','1',0,''),(343752,109875,'116803','furniture','padding-top','20',0,''),(343753,109875,'116803','furniture','padding-left','20',0,''),(343754,109875,'116803','furniture','padding-right','20',0,''),(343755,109875,'116803','furniture','padding-bottom','20',0,''),(343756,109875,'116803','furniture','background-color','$content-bg-1',0,''),(343757,109875,'116803','furniture','style_class','order-summary2 hiding-box',0,''),(343758,109875,'116803','furniture','color','$content-color-1',0,''),(343759,109876,'116804','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(343760,109877,'116805','furniture','margin-bottom','20',0,''),(343761,109877,'116805','furniture','text-align','right',0,''),(343762,109879,'116807','furniture','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(343763,109880,'116808','furniture','block_type','1',0,''),(343764,109880,'116808','furniture','background-color','$content-bg-2',0,''),(343765,109880,'116808','furniture','padding-bottom','30',0,''),(343766,109881,'116809','furniture','block_type','4',0,''),(343767,109881,'116809','furniture','schema','4-2',0,'5140'),(343768,109882,'116810','furniture','block_type','1',0,''),(343769,109882,'116810','furniture','padding-right','40',0,''),(343770,109882,'116810','furniture','padding-right','0',0,'5140'),(343771,109883,'116811','furniture','block_type','1',0,''),(343772,109883,'116811','furniture','background-color','$content-bg-1',0,''),(343773,109883,'116811','furniture','padding-top','20',0,''),(343774,109883,'116811','furniture','padding-bottom','20',0,''),(343775,109883,'116811','furniture','padding-left','30',0,''),(343776,109883,'116811','furniture','padding-right','30',0,''),(343777,109883,'116811','furniture','margin-bottom','20',0,''),(343778,109884,'116812','furniture','hide_parents','2',0,''),(343779,109885,'116813','furniture','float','right',0,''),(343780,109885,'116813','furniture','margin-top','-37',0,''),(343781,109885,'116813','furniture','link','comments',0,''),(343782,109886,'116814','furniture','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(343783,109887,'116815','furniture','block_type','1',0,''),(343784,109887,'116815','furniture','padding-right','30',0,''),(343785,109887,'116815','furniture','background-color','$content-bg-1',0,''),(343786,109887,'116815','furniture','padding-top','20',0,''),(343787,109887,'116815','furniture','padding-left','30',0,''),(343788,109887,'116815','furniture','padding-bottom','20',0,''),(343789,109887,'116815','furniture','padding-left','20',0,'5140'),(343790,109887,'116815','furniture','padding-right','20',0,'5140'),(343791,109888,'116816','furniture','link','products',0,''),(343792,109888,'116816','furniture','float','right',0,''),(343793,109888,'116816','furniture','margin-top','-37',0,''),(343794,109889,'116817','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(343795,109891,'116819','furniture','block_type','2',0,''),(343796,109891,'116819','furniture','margin-bottom','20',0,''),(343797,109891,'116819','furniture','schema','2-2',0,'5131'),(343798,109891,'116819','furniture','background-color','$content-bg-1',0,''),(343799,109892,'116820','furniture','block_type','1',0,''),(343800,109892,'116820','furniture','border-right-width','20',0,''),(343801,109892,'116820','furniture','border-right-color','$content-border-1',0,''),(343802,109892,'116820','furniture','margin-right','-10',0,''),(343803,109892,'116820','furniture','padding-right','30',0,''),(343804,109892,'116820','furniture','padding-top','20',0,''),(343805,109892,'116820','furniture','padding-left','30',0,''),(343806,109892,'116820','furniture','padding-bottom','20',0,''),(343807,109892,'116820','furniture','border-right-width','0',0,'5140'),(343808,109892,'116820','furniture','margin-right','0',0,'5140'),(343809,109892,'116820','furniture','margin-bottom','20',0,'5140'),(343810,109892,'116820','furniture','padding-left','20',0,'5140'),(343811,109892,'116820','furniture','padding-right','20',0,'5140'),(343812,109893,'116821','furniture','link','shipping_address',0,''),(343813,109893,'116821','furniture','float','right',0,''),(343814,109893,'116821','furniture','margin-top','-31',0,''),(343815,109895,'116823','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(343816,109895,'116823','furniture','clear','none',0,''),(343817,109896,'116824','furniture','link','shipping_method',0,''),(343818,109896,'116824','furniture','float','right',0,''),(343819,109896,'116824','furniture','margin-top','-31',0,''),(343820,109897,'116825','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(343821,109897,'116825','furniture','clear','none',0,''),(343822,109898,'116826','furniture','margin-bottom','20',0,''),(343823,109899,'116827','furniture','block_type','1',0,''),(343824,109899,'116827','furniture','padding-left','30',0,''),(343825,109899,'116827','furniture','border-left-width','20',0,''),(343826,109899,'116827','furniture','border-left-color','$content-border-1',0,''),(343827,109899,'116827','furniture','margin-left','-10',0,''),(343828,109899,'116827','furniture','padding-right','30',0,''),(343829,109899,'116827','furniture','padding-top','20',0,''),(343830,109899,'116827','furniture','padding-bottom','20',0,''),(343831,109899,'116827','furniture','border-left-width','0',0,'5140'),(343832,109902,'116830','furniture','link','contact_information',0,''),(343833,109902,'116830','furniture','margin-top','-31',0,''),(343834,109902,'116830','furniture','float','right',0,''),(343835,109903,'116831','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(343836,109904,'116832','furniture','block_type','1',0,''),(343837,109904,'116832','furniture','padding-top','20',0,''),(343838,109904,'116832','furniture','padding-left','20',0,''),(343839,109904,'116832','furniture','padding-right','20',0,''),(343840,109904,'116832','furniture','padding-bottom','20',0,''),(343841,109904,'116832','furniture','background-color','$content-bg-1',0,''),(343842,109904,'116832','furniture','style_class','order-summary',0,''),(343843,109905,'116833','furniture','margin-bottom','20',0,''),(343844,109905,'116833','furniture','text-align','right',0,''),(343845,109906,'116834','furniture','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(343846,109907,'116835','furniture','block_type','1',0,''),(343847,109907,'116835','furniture','background-color','$content-bg-2',0,''),(343848,109907,'116835','furniture','padding-bottom','30',0,''),(343849,109907,'116835','furniture','color','$content-color-2',0,''),(343850,109908,'116836','furniture','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(343851,109909,'116837','furniture','block_type','4',0,''),(343852,109910,'116838','furniture','block_type','1',0,''),(343853,109910,'116838','furniture','padding-right','40',0,''),(343854,109911,'116839','furniture','block_type','2',0,''),(343855,109911,'116839','furniture','margin-bottom','20',0,''),(343856,109911,'116839','furniture','schema','2-2',0,'5131'),(343857,109911,'116839','furniture','background-color','$content-bg-1',0,''),(343858,109911,'116839','furniture','color','$content-color-1',0,''),(343859,109912,'116840','furniture','block_type','1',0,''),(343860,109912,'116840','furniture','padding-right','0',0,'5131'),(343861,109912,'116840','furniture','border-right-width','20',0,''),(343862,109912,'116840','furniture','border-right-color','$content-bg-2',0,''),(343863,109912,'116840','furniture','margin-right','-10',0,''),(343864,109912,'116840','furniture','padding-right','30',0,''),(343865,109912,'116840','furniture','padding-top','20',0,''),(343866,109912,'116840','furniture','padding-left','30',0,''),(343867,109912,'116840','furniture','padding-bottom','20',0,''),(343868,109913,'116841','furniture','link','contact_information',0,''),(343869,109913,'116841','furniture','float','right',0,''),(343870,109914,'116842','furniture','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(343871,109916,'116844','furniture','block_type','1',0,''),(343872,109916,'116844','furniture','padding-left','30',0,''),(343873,109916,'116844','furniture','padding-left','0',0,'5131'),(343874,109916,'116844','furniture','border-left-width','20',0,''),(343875,109916,'116844','furniture','border-left-color','$content-bg-2',0,''),(343876,109916,'116844','furniture','margin-left','-10',0,''),(343877,109916,'116844','furniture','padding-right','30',0,''),(343878,109916,'116844','furniture','padding-top','20',0,''),(343879,109916,'116844','furniture','padding-bottom','20',0,''),(343880,109918,'116846','furniture','link','payment_method',0,''),(343881,109918,'116846','furniture','float','right',0,''),(343882,109918,'116846','furniture','margin-top','-31',0,''),(343883,109919,'116847','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343884,109919,'116847','furniture','clear','none',0,''),(343885,109920,'116848','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(343886,109921,'116849','furniture','link','billing_address',0,''),(343887,109921,'116849','furniture','float','right',0,''),(343888,109921,'116849','furniture','margin-top','-31',0,''),(343889,109922,'116850','furniture','margin-bottom','20',0,''),(343890,109923,'116851','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343891,109923,'116851','furniture','clear','none',0,''),(343892,109924,'116852','furniture','block_type','1',0,''),(343893,109924,'116852','furniture','background-color','$content-bg-1',0,''),(343894,109924,'116852','furniture','padding-top','20',0,''),(343895,109924,'116852','furniture','padding-bottom','20',0,''),(343896,109924,'116852','furniture','padding-left','30',0,''),(343897,109924,'116852','furniture','padding-right','30',0,''),(343898,109924,'116852','furniture','margin-bottom','20',0,''),(343899,109924,'116852','furniture','color','$content-color-1',0,''),(343900,109925,'116853','furniture','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(343901,109926,'116854','furniture','hide_parents','2',0,''),(343902,109927,'116855','furniture','float','right',0,''),(343903,109927,'116855','furniture','margin-top','-37',0,''),(343904,109927,'116855','furniture','link','comments',0,''),(343905,109928,'116856','furniture','block_type','1',0,''),(343906,109928,'116856','furniture','padding-right','30',0,''),(343907,109928,'116856','furniture','padding-right','0',0,'5131'),(343908,109928,'116856','furniture','background-color','$content-bg-1',0,''),(343909,109928,'116856','furniture','padding-top','20',0,''),(343910,109928,'116856','furniture','padding-left','30',0,''),(343911,109928,'116856','furniture','padding-bottom','20',0,''),(343912,109928,'116856','furniture','color','$content-color-1',0,''),(343913,109929,'116857','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(343914,109930,'116858','furniture','link','products',0,''),(343915,109930,'116858','furniture','float','right',0,''),(343916,109930,'116858','furniture','margin-top','-37',0,''),(343917,109932,'116860','furniture','block_type','1',0,''),(343918,109932,'116860','furniture','padding-top','20',0,''),(343919,109932,'116860','furniture','padding-left','20',0,''),(343920,109932,'116860','furniture','padding-right','20',0,''),(343921,109932,'116860','furniture','padding-bottom','20',0,''),(343922,109932,'116860','furniture','background-color','$content-bg-1',0,''),(343923,109932,'116860','furniture','style_class','order-summary2 hiding-box',0,''),(343924,109932,'116860','furniture','color','$content-color-1',0,''),(343925,109933,'116861','furniture','margin-bottom','20',0,''),(343926,109933,'116861','furniture','text-align','right',0,''),(343927,109934,'116862','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(343928,109936,'116864','furniture','block_type','1',0,''),(343929,109936,'116864','furniture','background-color','$content-bg-2',0,''),(343930,109936,'116864','furniture','padding-bottom','30',0,''),(343931,109937,'116865','furniture','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(343932,109938,'116866','furniture','block_type','4',0,''),(343933,109938,'116866','furniture','schema','4-2',0,'5140'),(343934,109939,'116867','furniture','block_type','1',0,''),(343935,109939,'116867','furniture','padding-right','40',0,''),(343936,109939,'116867','furniture','padding-right','0',0,'5140'),(343937,109940,'116868','furniture','block_type','1',0,''),(343938,109940,'116868','furniture','background-color','$content-bg-1',0,''),(343939,109940,'116868','furniture','padding-top','20',0,''),(343940,109940,'116868','furniture','padding-bottom','20',0,''),(343941,109940,'116868','furniture','padding-left','30',0,''),(343942,109940,'116868','furniture','padding-right','30',0,''),(343943,109940,'116868','furniture','margin-bottom','20',0,''),(343944,109941,'116869','furniture','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(343945,109942,'116870','furniture','hide_parents','2',0,''),(343946,109943,'116871','furniture','float','right',0,''),(343947,109943,'116871','furniture','margin-top','-37',0,''),(343948,109943,'116871','furniture','link','comments',0,''),(343949,109944,'116872','furniture','block_type','2',0,''),(343950,109944,'116872','furniture','margin-bottom','20',0,''),(343951,109944,'116872','furniture','schema','2-2',0,'5131'),(343952,109944,'116872','furniture','background-color','$content-bg-1',0,''),(343953,109945,'116873','furniture','block_type','1',0,''),(343954,109945,'116873','furniture','border-right-width','20',0,''),(343955,109945,'116873','furniture','border-right-color','$content-border-1',0,''),(343956,109945,'116873','furniture','margin-right','-10',0,''),(343957,109945,'116873','furniture','padding-right','30',0,''),(343958,109945,'116873','furniture','padding-top','20',0,''),(343959,109945,'116873','furniture','padding-left','30',0,''),(343960,109945,'116873','furniture','padding-bottom','20',0,''),(343961,109945,'116873','furniture','border-right-width','0',0,'5140'),(343962,109945,'116873','furniture','margin-right','0',0,'5140'),(343963,109945,'116873','furniture','margin-bottom','20',0,'5140'),(343964,109945,'116873','furniture','padding-left','20',0,'5140'),(343965,109945,'116873','furniture','padding-right','20',0,'5140'),(343966,109946,'116874','furniture','link','contact_information',0,''),(343967,109946,'116874','furniture','margin-top','-31',0,''),(343968,109946,'116874','furniture','float','right',0,''),(343969,109949,'116877','furniture','link','payment_method',0,''),(343970,109949,'116877','furniture','float','right',0,''),(343971,109949,'116877','furniture','margin-top','-31',0,''),(343972,109950,'116878','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(343973,109950,'116878','furniture','padding-top','20',0,''),(343974,109951,'116879','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(343975,109951,'116879','furniture','clear','none',0,''),(343976,109952,'116880','furniture','block_type','1',0,''),(343977,109952,'116880','furniture','padding-left','30',0,''),(343978,109952,'116880','furniture','border-left-width','20',0,''),(343979,109952,'116880','furniture','border-left-color','$content-border-1',0,''),(343980,109952,'116880','furniture','margin-left','-10',0,''),(343981,109952,'116880','furniture','padding-right','30',0,''),(343982,109952,'116880','furniture','padding-top','20',0,''),(343983,109952,'116880','furniture','padding-bottom','20',0,''),(343984,109952,'116880','furniture','border-left-width','0',0,'5140'),(343985,109953,'116881','furniture','margin-bottom','20',0,''),(343986,109954,'116882','furniture','link','billing_address',0,''),(343987,109954,'116882','furniture','float','right',0,''),(343988,109954,'116882','furniture','margin-top','-31',0,''),(343989,109955,'116883','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(343990,109955,'116883','furniture','clear','none',0,''),(343991,109956,'116884','furniture','block_type','1',0,''),(343992,109956,'116884','furniture','padding-right','30',0,''),(343993,109956,'116884','furniture','background-color','$content-bg-1',0,''),(343994,109956,'116884','furniture','padding-top','20',0,''),(343995,109956,'116884','furniture','padding-left','30',0,''),(343996,109956,'116884','furniture','padding-bottom','20',0,''),(343997,109956,'116884','furniture','padding-left','20',0,'5140'),(343998,109956,'116884','furniture','padding-right','20',0,'5140'),(343999,109957,'116885','furniture','link','products',0,''),(344000,109957,'116885','furniture','float','right',0,''),(344001,109957,'116885','furniture','margin-top','-37',0,''),(344002,109958,'116886','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(344003,109959,'116887','furniture','margin-bottom','20',0,''),(344004,109960,'116888','furniture','block_type','1',0,''),(344005,109960,'116888','furniture','padding-top','20',0,''),(344006,109960,'116888','furniture','padding-left','20',0,''),(344007,109960,'116888','furniture','padding-right','20',0,''),(344008,109960,'116888','furniture','padding-bottom','20',0,''),(344009,109960,'116888','furniture','background-color','$content-bg-1',0,''),(344010,109960,'116888','furniture','style_class','order-summary',0,''),(344011,109961,'116889','furniture','margin-bottom','20',0,''),(344012,109961,'116889','furniture','text-align','right',0,''),(344013,109963,'116891','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(344014,109964,'116892','furniture','block_type','1',0,''),(344015,109964,'116892','furniture','background-color','$content-bg-2',0,''),(344016,109964,'116892','furniture','padding-bottom','30',0,''),(344017,109965,'116893','furniture','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(344018,109966,'116894','furniture','block_type','4',0,''),(344019,109966,'116894','furniture','schema','4-2',0,'5140'),(344020,109967,'116895','furniture','block_type','1',0,''),(344021,109967,'116895','furniture','padding-right','40',0,''),(344022,109967,'116895','furniture','padding-right','0',0,'5140'),(344023,109968,'116896','furniture','block_type','1',0,''),(344024,109968,'116896','furniture','padding-right','30',0,''),(344025,109968,'116896','furniture','background-color','$content-bg-1',0,''),(344026,109968,'116896','furniture','padding-top','20',0,''),(344027,109968,'116896','furniture','padding-left','30',0,''),(344028,109968,'116896','furniture','padding-bottom','20',0,''),(344029,109968,'116896','furniture','padding-left','20',0,'5140'),(344030,109968,'116896','furniture','padding-right','20',0,'5140'),(344031,109970,'116898','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(344032,109971,'116899','furniture','link','products',0,''),(344033,109971,'116899','furniture','float','right',0,''),(344034,109971,'116899','furniture','margin-top','-37',0,''),(344035,109972,'116900','furniture','block_type','2',0,''),(344036,109972,'116900','furniture','margin-bottom','20',0,''),(344037,109972,'116900','furniture','schema','2-2',0,'5131'),(344038,109972,'116900','furniture','background-color','$content-bg-1',0,''),(344039,109973,'116901','furniture','block_type','1',0,''),(344040,109973,'116901','furniture','border-right-width','20',0,''),(344041,109973,'116901','furniture','border-right-color','$content-border-1',0,''),(344042,109973,'116901','furniture','margin-right','-10',0,''),(344043,109973,'116901','furniture','padding-right','30',0,''),(344044,109973,'116901','furniture','padding-top','20',0,''),(344045,109973,'116901','furniture','padding-left','30',0,''),(344046,109973,'116901','furniture','padding-bottom','20',0,''),(344047,109973,'116901','furniture','border-right-width','0',0,'5140'),(344048,109973,'116901','furniture','margin-right','0',0,'5140'),(344049,109973,'116901','furniture','margin-bottom','20',0,'5140'),(344050,109973,'116901','furniture','padding-left','20',0,'5140'),(344051,109973,'116901','furniture','padding-right','20',0,'5140'),(344052,109974,'116902','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(344053,109975,'116903','furniture','link','contact_information',0,''),(344054,109975,'116903','furniture','margin-top','-31',0,''),(344055,109975,'116903','furniture','float','right',0,''),(344056,109976,'116904','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(344057,109976,'116904','furniture','clear','none',0,''),(344058,109978,'116906','furniture','margin-bottom','20',0,''),(344059,109980,'116908','furniture','link','shipping_address',0,''),(344060,109980,'116908','furniture','float','right',0,''),(344061,109980,'116908','furniture','margin-top','-31',0,''),(344062,109982,'116910','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(344063,109982,'116910','furniture','padding-top','20',0,''),(344064,109983,'116911','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(344065,109983,'116911','furniture','clear','none',0,''),(344066,109984,'116912','furniture','link','shipping_method',0,''),(344067,109984,'116912','furniture','float','right',0,''),(344068,109984,'116912','furniture','margin-top','-31',0,''),(344069,109985,'116913','furniture','block_type','1',0,''),(344070,109985,'116913','furniture','padding-left','30',0,''),(344071,109985,'116913','furniture','border-left-width','20',0,''),(344072,109985,'116913','furniture','border-left-color','$content-border-1',0,''),(344073,109985,'116913','furniture','margin-left','-10',0,''),(344074,109985,'116913','furniture','padding-right','30',0,''),(344075,109985,'116913','furniture','padding-top','20',0,''),(344076,109985,'116913','furniture','padding-bottom','20',0,''),(344077,109985,'116913','furniture','border-left-width','0',0,'5140'),(344078,109986,'116914','furniture','link','billing_address',0,''),(344079,109986,'116914','furniture','float','right',0,''),(344080,109986,'116914','furniture','margin-top','-31',0,''),(344081,109987,'116915','furniture','margin-bottom','20',0,''),(344082,109989,'116917','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(344083,109990,'116918','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(344084,109990,'116918','furniture','clear','none',0,''),(344085,109991,'116919','furniture','link','payment_method',0,''),(344086,109991,'116919','furniture','float','right',0,''),(344087,109991,'116919','furniture','margin-top','-31',0,''),(344088,109992,'116920','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(344089,109992,'116920','furniture','clear','none',0,''),(344090,109993,'116921','furniture','block_type','1',0,''),(344091,109993,'116921','furniture','background-color','$content-bg-1',0,''),(344092,109993,'116921','furniture','padding-top','20',0,''),(344093,109993,'116921','furniture','padding-bottom','20',0,''),(344094,109993,'116921','furniture','padding-left','30',0,''),(344095,109993,'116921','furniture','padding-right','30',0,''),(344096,109993,'116921','furniture','margin-bottom','20',0,''),(344097,109994,'116922','furniture','hide_parents','2',0,''),(344098,109995,'116923','furniture','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(344099,109996,'116924','furniture','float','right',0,''),(344100,109996,'116924','furniture','margin-top','-37',0,''),(344101,109996,'116924','furniture','link','comments',0,''),(344102,109997,'116925','furniture','block_type','1',0,''),(344103,109997,'116925','furniture','padding-top','20',0,''),(344104,109997,'116925','furniture','padding-left','20',0,''),(344105,109997,'116925','furniture','padding-right','20',0,''),(344106,109997,'116925','furniture','padding-bottom','20',0,''),(344107,109997,'116925','furniture','background-color','$content-bg-1',0,''),(344108,109997,'116925','furniture','style_class','order-summary',0,''),(344109,109998,'116926','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(344110,110000,'116928','furniture','margin-bottom','20',0,''),(344111,110000,'116928','furniture','text-align','right',0,''),(344112,110001,'116929','furniture','block_type','1',0,''),(344113,110001,'116929','furniture','background-color','$content-bg-2',0,''),(344114,110001,'116929','furniture','padding-bottom','30',0,''),(344115,110002,'116930','furniture','block_type','4',0,''),(344116,110002,'116930','furniture','schema','4-2',0,'5140'),(344117,110003,'116931','furniture','block_type','1',0,''),(344118,110003,'116931','furniture','padding-right','40',0,''),(344119,110003,'116931','furniture','padding-right','0',0,'5140'),(344120,110004,'116932','furniture','block_type','2',0,''),(344121,110004,'116932','furniture','margin-bottom','20',0,''),(344122,110004,'116932','furniture','schema','2-2',0,'5131'),(344123,110004,'116932','furniture','background-color','$content-bg-1',0,''),(344124,110005,'116933','furniture','block_type','1',0,''),(344125,110005,'116933','furniture','border-right-width','20',0,''),(344126,110005,'116933','furniture','border-right-color','$content-border-1',0,''),(344127,110005,'116933','furniture','margin-right','-10',0,''),(344128,110005,'116933','furniture','padding-right','30',0,''),(344129,110005,'116933','furniture','padding-top','20',0,''),(344130,110005,'116933','furniture','padding-left','30',0,''),(344131,110005,'116933','furniture','padding-bottom','20',0,''),(344132,110005,'116933','furniture','border-right-width','0',0,'5140'),(344133,110005,'116933','furniture','margin-right','0',0,'5140'),(344134,110005,'116933','furniture','margin-bottom','20',0,'5140'),(344135,110005,'116933','furniture','padding-left','20',0,'5140'),(344136,110005,'116933','furniture','padding-right','20',0,'5140'),(344137,110006,'116934','furniture','margin-bottom','20',0,''),(344138,110007,'116935','furniture','link','shipping_address',0,''),(344139,110007,'116935','furniture','float','right',0,''),(344140,110007,'116935','furniture','margin-top','-31',0,''),(344141,110008,'116936','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(344142,110008,'116936','furniture','clear','none',0,''),(344143,110011,'116939','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(344144,110012,'116940','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(344145,110012,'116940','furniture','clear','none',0,''),(344146,110013,'116941','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(344147,110013,'116941','furniture','padding-top','20',0,''),(344148,110015,'116943','furniture','link','shipping_method',0,''),(344149,110015,'116943','furniture','float','right',0,''),(344150,110015,'116943','furniture','margin-top','-31',0,''),(344151,110016,'116944','furniture','link','contact_information',0,''),(344152,110016,'116944','furniture','margin-top','-31',0,''),(344153,110016,'116944','furniture','float','right',0,''),(344154,110017,'116945','furniture','block_type','1',0,''),(344155,110017,'116945','furniture','padding-left','30',0,''),(344156,110017,'116945','furniture','border-left-width','20',0,''),(344157,110017,'116945','furniture','border-left-color','$content-border-1',0,''),(344158,110017,'116945','furniture','margin-left','-10',0,''),(344159,110017,'116945','furniture','padding-right','30',0,''),(344160,110017,'116945','furniture','padding-top','20',0,''),(344161,110017,'116945','furniture','padding-bottom','20',0,''),(344162,110017,'116945','furniture','border-left-width','0',0,'5140'),(344163,110018,'116946','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(344164,110018,'116946','furniture','clear','none',0,''),(344165,110019,'116947','furniture','margin-bottom','20',0,''),(344166,110020,'116948','furniture','link','billing_address',0,''),(344167,110020,'116948','furniture','float','right',0,''),(344168,110020,'116948','furniture','margin-top','-31',0,''),(344169,110022,'116950','furniture','link','payment_method',0,''),(344170,110022,'116950','furniture','float','right',0,''),(344171,110022,'116950','furniture','margin-top','-31',0,''),(344172,110023,'116951','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(344173,110024,'116952','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(344174,110024,'116952','furniture','clear','none',0,''),(344175,110025,'116953','furniture','block_type','1',0,''),(344176,110025,'116953','furniture','padding-right','30',0,''),(344177,110025,'116953','furniture','background-color','$content-bg-1',0,''),(344178,110025,'116953','furniture','padding-top','20',0,''),(344179,110025,'116953','furniture','padding-left','30',0,''),(344180,110025,'116953','furniture','padding-bottom','20',0,''),(344181,110025,'116953','furniture','padding-left','20',0,'5140'),(344182,110025,'116953','furniture','padding-right','20',0,'5140'),(344183,110026,'116954','furniture','link','products',0,''),(344184,110026,'116954','furniture','float','right',0,''),(344185,110026,'116954','furniture','margin-top','-37',0,''),(344186,110027,'116955','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(344187,110029,'116957','furniture','block_type','1',0,''),(344188,110029,'116957','furniture','background-color','$content-bg-1',0,''),(344189,110029,'116957','furniture','padding-top','20',0,''),(344190,110029,'116957','furniture','padding-bottom','20',0,''),(344191,110029,'116957','furniture','padding-left','30',0,''),(344192,110029,'116957','furniture','padding-right','30',0,''),(344193,110029,'116957','furniture','margin-bottom','20',0,''),(344194,110030,'116958','furniture','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(344195,110031,'116959','furniture','float','right',0,''),(344196,110031,'116959','furniture','margin-top','-37',0,''),(344197,110031,'116959','furniture','link','comments',0,''),(344198,110032,'116960','furniture','hide_parents','2',0,''),(344199,110033,'116961','furniture','block_type','1',0,''),(344200,110033,'116961','furniture','padding-top','20',0,''),(344201,110033,'116961','furniture','padding-left','20',0,''),(344202,110033,'116961','furniture','padding-right','20',0,''),(344203,110033,'116961','furniture','padding-bottom','20',0,''),(344204,110033,'116961','furniture','background-color','$content-bg-1',0,''),(344205,110033,'116961','furniture','style_class','order-summary',0,''),(344206,110035,'116963','furniture','margin-bottom','20',0,''),(344207,110035,'116963','furniture','text-align','right',0,''),(344208,110036,'116964','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(344209,110037,'116965','furniture','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(344210,110038,'116966','furniture','block_type','1',0,''),(344211,110040,'116968','furniture','block_type','2',0,''),(344212,110040,'116968','furniture','font-weight','400',0,''),(344213,110040,'116968','furniture','padding-bottom','20',0,''),(344214,110040,'116968','furniture','schema','2-2',0,'5140'),(344215,110041,'116969','furniture','show_captcha','on',0,''),(344216,110042,'116970','furniture','font-weight','400',0,''),(344217,110042,'116970','furniture','padding-left','40',0,''),(344218,110042,'116970','furniture','time_format','24',0,''),(344219,110042,'116970','furniture','show_icons','on',0,''),(344220,110042,'116970','furniture','padding-left','0',0,'5140'),(344221,110043,'116971','furniture','block_type','1',0,''),(344222,110044,'116972','furniture','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(344223,110045,'116973','furniture','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(344224,110045,'116973','furniture','margin-bottom','40',0,''),(344225,110046,'116102.000001','furniture','block_type','1',0,''),(344226,110047,'116103.000001','furniture','block_type','6',0,''),(344227,110047,'116103.000001','furniture','schema','6-3',0,'5140'),(344228,110048,'116104.000001','furniture','aria_name','account-menu',0,''),(344286,110068,'116109.000001','furniture','text','<h1>##CREDIT_AMOUNT_HISTORY##</h1>',0,''),(344287,110069,'1638895944.9672','furniture','margin-bottom','20',0,''),(344288,110070,'116974','furniture','width','680',0,''),(344289,110070,'116974','furniture','font-weight','normal',0,''),(344290,110070,'116974','furniture','font-size','12',0,''),(344291,110070,'116974','furniture','padding-top','20',0,''),(344292,110070,'116974','furniture','padding-bottom','20',0,''),(344293,110070,'116974','furniture','color','$content-color-1',0,''),(344294,110071,'116975','furniture','block_type','3',0,''),(344295,110071,'116975','furniture','font-weight','normal',0,''),(344296,110071,'116975','furniture','padding-top','20',0,''),(344297,110072,'116976','furniture','font-size','12',0,''),(344298,110073,'116977','furniture','text','<p>If undelivered please return to:</p>',1,''),(344299,110073,'116977','furniture','font-size','12',0,''),(344300,110073,'116977','furniture','font-weight','bold',0,''),(344301,110073,'116977','furniture','text','<p>If undelivered please return to:</p>',2,''),(344302,110073,'116977','furniture','text','<p>If undelivered please return to:</p>',3,''),(344303,110073,'116977','furniture','text','<p>If undelivered please return to:</p>',4,''),(344304,110074,'116978','furniture','text','<p>Thank you for your order</p>',1,''),(344305,110074,'116978','furniture','color','$content-color-1',0,''),(344306,110074,'116978','furniture','font-size','13',0,''),(344307,110074,'116978','furniture','font-weight','bold',0,''),(344308,110074,'116978','furniture','padding-top','5',0,''),(344309,110074,'116978','furniture','text-align','center',0,''),(344310,110074,'116978','furniture','text','<p>Thank you for your order</p>',2,''),(344311,110074,'116978','furniture','text','<p>Thank you for your order</p>',3,''),(344312,110074,'116978','furniture','text','<p>Thank you for your order</p>',4,''),(344313,110075,'116979','furniture','font-weight','400',0,''),(344314,110075,'116979','furniture','text-align','center',0,''),(344315,110075,'116979','furniture','padding-top','0',0,''),(344317,110075,'116979','furniture','padding-left','20',0,''),(344318,110075,'116979','furniture','padding-right','20',0,''),(344322,110076,'116980','furniture','text','<p>If something has gone wrong please contact us at:</p>',1,''),(344323,110076,'116980','furniture','font-size','12',0,''),(344324,110076,'116980','furniture','font-weight','bold',0,''),(344325,110076,'116980','furniture','text-align','right',0,''),(344326,110076,'116980','furniture','text','<p>If something has gone wrong please contact us at:</p>',2,''),(344327,110076,'116980','furniture','text','<p>If something has gone wrong please contact us at:</p>',3,''),(344328,110076,'116980','furniture','text','<p>If something has gone wrong please contact us at:</p>',4,''),(344329,110077,'116981','furniture','block_type','6',0,''),(344330,110077,'116981','furniture','font-weight','normal',0,''),(344331,110077,'116981','furniture','font-size','16',0,''),(344332,110078,'116982','furniture','text','<p>Email:</p>',1,''),(344333,110078,'116982','furniture','font-weight','normal',0,''),(344334,110078,'116982','furniture','text-align','right',0,''),(344335,110078,'116982','furniture','font-size','12',0,''),(344336,110078,'116982','furniture','text','<p>Email:</p>',2,''),(344337,110078,'116982','furniture','text','<p>Email:</p>',3,''),(344338,110078,'116982','furniture','text','<p>Email:</p>',4,''),(344339,110079,'116983','furniture','font-weight','normal',0,''),(344340,110079,'116983','furniture','text-align','right',0,''),(344341,110079,'116983','furniture','font-size','12',0,''),(344342,110080,'116984','furniture','block_type','6',0,''),(344343,110080,'116984','furniture','font-weight','normal',0,''),(344344,110080,'116984','furniture','font-size','16',0,''),(344345,110081,'116985','furniture','text','<p>Phone:</p>',1,''),(344346,110081,'116985','furniture','font-weight','normal',0,''),(344347,110081,'116985','furniture','text-align','right',0,''),(344348,110081,'116985','furniture','font-size','12',0,''),(344349,110081,'116985','furniture','text','<p>Phone:</p>',2,''),(344350,110081,'116985','furniture','text','<p>Phone:</p>',3,''),(344351,110081,'116985','furniture','text','<p>Phone:</p>',4,''),(344352,110082,'116986','furniture','font-weight','normal',0,''),(344353,110082,'116986','furniture','text-align','right',0,''),(344354,110082,'116986','furniture','font-size','12',0,''),(344355,110083,'116987','furniture','font-weight','400',0,''),(344356,110083,'116987','furniture','padding-top','20',0,''),(344357,110083,'116987','furniture','padding-bottom','0',0,''),(344358,110083,'116987','furniture','font-size','12',0,''),(344359,110084,'116988','furniture','block_type','2',0,''),(344360,110084,'116988','furniture','font-weight','normal',0,''),(344361,110084,'116988','furniture','padding-bottom','20',0,''),(344362,110085,'116989','furniture','font-weight','400',0,''),(344363,110085,'116989','furniture','padding-top','20',0,''),(344368,110086,'116990','furniture','block_type','11',0,''),(344369,110086,'116990','furniture','font-weight','normal',0,''),(344370,110087,'116991','furniture','text','<p>Web:</p>',1,''),(344371,110087,'116991','furniture','font-weight','normal',0,''),(344372,110087,'116991','furniture','text-align','right',0,''),(344373,110087,'116991','furniture','text','<p>Web:</p>',2,''),(344374,110087,'116991','furniture','text','<p>Web:</p>',3,''),(344375,110087,'116991','furniture','text','<p>Web:</p>',4,''),(344376,110088,'116992','furniture','font-weight','normal',0,''),(344377,110088,'116992','furniture','text-align','right',0,''),(344378,110089,'116993','furniture','block_type','11',0,''),(344379,110089,'116993','furniture','font-weight','normal',0,''),(344380,110090,'116994','furniture','text','<p>Phone:</p>',1,''),(344381,110090,'116994','furniture','font-weight','normal',0,''),(344382,110090,'116994','furniture','text-align','right',0,''),(344383,110090,'116994','furniture','text','<p>Phone:</p>',2,''),(344384,110090,'116994','furniture','text','<p>Phone:</p>',3,''),(344385,110090,'116994','furniture','text','<p>Phone:</p>',4,''),(344386,110091,'116995','furniture','font-weight','normal',0,''),(344387,110091,'116995','furniture','text-align','right',0,''),(344388,110092,'116996','furniture','block_type','11',0,''),(344389,110092,'116996','furniture','font-weight','normal',0,''),(344390,110093,'116997','furniture','text','<p>Email:</p>',1,''),(344391,110093,'116997','furniture','font-weight','normal',0,''),(344392,110093,'116997','furniture','text-align','right',0,''),(344393,110093,'116997','furniture','text','<p>Email:</p>',2,''),(344394,110093,'116997','furniture','text','<p>Email:</p>',3,''),(344395,110093,'116997','furniture','text','<p>Email:</p>',4,''),(344396,110094,'116998','furniture','font-weight','normal',0,''),(344397,110094,'116998','furniture','text-align','right',0,''),(344398,110095,'116999','furniture','block_type','1',0,''),(344399,110096,'117000','furniture','font-weight','normal',0,''),(344400,110096,'117000','furniture','text-align','right',0,''),(344401,110096,'117000','furniture','padding-bottom','10',0,''),(344402,110096,'117000','furniture','address_spacer',',',0,''),(344403,110096,'117000','furniture','font-size','12',0,''),(344404,110097,'117001','furniture','block_type','5',0,''),(344405,110097,'117001','furniture','font-weight','normal',0,''),(344406,110097,'117001','furniture','border-bottom-width','1',0,''),(344407,110097,'117001','furniture','border-bottom-color','$content-border-1',0,''),(344408,110097,'117001','furniture','border-top-width','1',0,''),(344409,110097,'117001','furniture','border-top-color','$content-border-1',0,''),(344410,110097,'117001','furniture','border-left-color','$content-border-1',0,''),(344411,110097,'117001','furniture','border-left-width','1',0,''),(344412,110098,'117002','furniture','block_type','1',0,''),(344413,110098,'117002','furniture','font-weight','normal',0,''),(344414,110098,'117002','furniture','padding-top','10',0,''),(344415,110098,'117002','furniture','padding-left','10',0,''),(344416,110098,'117002','furniture','padding-right','10',0,''),(344417,110099,'117003','furniture','font-weight','400',0,''),(344418,110099,'117003','furniture','line-height','120',0,''),(344419,110099,'117003','furniture','line_height_measure','%',0,''),(344420,110099,'117003','furniture','font-size','12',0,''),(344421,110100,'117004','furniture','text','<p>SHIPPING ADDRESS:</p>',1,''),(344422,110100,'117004','furniture','font-size','14',0,''),(344423,110100,'117004','furniture','font-weight','bold',0,''),(344424,110100,'117004','furniture','padding-bottom','10',0,''),(344425,110100,'117004','furniture','text','<p>SHIPPING ADDRESS:</p>',2,''),(344426,110100,'117004','furniture','text','<p>SHIPPING ADDRESS:</p>',3,''),(344427,110100,'117004','furniture','text','<p>SHIPPING ADDRESS:</p>',4,''),(344428,110101,'117005','furniture','block_type','1',0,''),(344429,110101,'117005','furniture','background-color','$content-bg-2',0,''),(344430,110101,'117005','furniture','padding-top','20',0,''),(344431,110101,'117005','furniture','padding-left','10',0,''),(344432,110101,'117005','furniture','padding-right','10',0,''),(344433,110101,'117005','furniture','padding-bottom','20',0,''),(344434,110101,'117005','furniture','font-size','14',0,''),(344435,110102,'117006','furniture','block_type','4',0,''),(344436,110102,'117006','furniture','font-weight','normal',0,''),(344437,110102,'117006','furniture','border-top-width','1',0,''),(344438,110102,'117006','furniture','border-top-color','$content-border-1',0,''),(344439,110102,'117006','furniture','border-left-width','1',0,''),(344440,110102,'117006','furniture','border-left-color','$content-border-1',0,''),(344441,110102,'117006','furniture','border-right-width','1',0,''),(344442,110102,'117006','furniture','border-right-color','$content-border-1',0,''),(344443,110102,'117006','furniture','border-bottom-width','1',0,''),(344444,110102,'117006','furniture','border-bottom-color','$content-border-1',0,''),(344445,110103,'117007','furniture','block_type','2',0,''),(344446,110103,'117007','furniture','font-weight','normal',0,''),(344447,110103,'117007','furniture','border-right-width','1',0,''),(344448,110103,'117007','furniture','border-right-color','$content-border-1',0,''),(344449,110104,'117008','furniture','block_type','1',0,''),(344450,110104,'117008','furniture','font-weight','400',0,''),(344451,110104,'117008','furniture','background-color','$content-bg-2',0,''),(344452,110104,'117008','furniture','padding-top','10',0,''),(344453,110104,'117008','furniture','padding-left','10',0,''),(344454,110104,'117008','furniture','padding-right','10',0,''),(344455,110104,'117008','furniture','padding-bottom','30',0,''),(344456,110105,'117009','furniture','text','<p>INVOICE ADDRESS:</p>',1,''),(344457,110105,'117009','furniture','font-size','14',0,''),(344458,110105,'117009','furniture','font-weight','bold',0,''),(344459,110105,'117009','furniture','text','<p>INVOICE ADDRESS:</p>',2,''),(344460,110105,'117009','furniture','text','<p>INVOICE ADDRESS:</p>',3,''),(344461,110105,'117009','furniture','text','<p>INVOICE ADDRESS:</p>',4,''),(344462,110106,'117010','furniture','font-size','12',0,''),(344463,110107,'117011','furniture','block_type','1',0,''),(344464,110107,'117011','furniture','font-weight','normal',0,''),(344465,110107,'117011','furniture','padding-top','10',0,''),(344466,110107,'117011','furniture','padding-left','10',0,''),(344467,110107,'117011','furniture','padding-right','10',0,''),(344468,110107,'117011','furniture','padding-bottom','10',0,''),(344469,110108,'117012','furniture','font-weight','normal',0,''),(344470,110109,'117013','furniture','text','<p>CUSTOMER:</p>',1,''),(344471,110109,'117013','furniture','font-size','13',0,''),(344472,110109,'117013','furniture','font-weight','bold',0,''),(344473,110109,'117013','furniture','text','<p>CUSTOMER:</p>',2,''),(344474,110109,'117013','furniture','text','<p>CUSTOMER:</p>',3,''),(344475,110109,'117013','furniture','text','<p>CUSTOMER:</p>',4,''),(344476,110110,'117014','furniture','text','<p>PHONE NUMBER:</p>',1,''),(344477,110110,'117014','furniture','font-size','14',0,''),(344478,110110,'117014','furniture','font-weight','bold',0,''),(344479,110110,'117014','furniture','padding-top','10',0,''),(344480,110110,'117014','furniture','text','<p>PHONE NUMBER:</p>',2,''),(344481,110110,'117014','furniture','text','<p>PHONE NUMBER:</p>',3,''),(344482,110110,'117014','furniture','text','<p>PHONE NUMBER:</p>',4,''),(344483,110111,'117015','furniture','font-weight','normal',0,''),(344484,110113,'117017','furniture','text','<p>E-MAIL ADDRESS:</p>',1,''),(344485,110113,'117017','furniture','font-weight','bold',0,''),(344486,110113,'117017','furniture','font-size','14',0,''),(344487,110113,'117017','furniture','padding-top','10',0,''),(344488,110113,'117017','furniture','text','<p>E-MAIL ADDRESS:</p>',2,''),(344489,110113,'117017','furniture','text','<p>E-MAIL ADDRESS:</p>',3,''),(344490,110113,'117017','furniture','text','<p>E-MAIL ADDRESS:</p>',4,''),(344491,110114,'117018','furniture','block_type','2',0,''),(344492,110114,'117018','furniture','font-weight','normal',0,''),(344493,110114,'117018','furniture','border-top-width','1',0,''),(344494,110114,'117018','furniture','border-top-color','$content-border-1',0,''),(344495,110114,'117018','furniture','border-right-width','1',0,''),(344496,110114,'117018','furniture','border-right-color','$content-border-1',0,''),(344497,110115,'117019','furniture','block_type','1',0,''),(344498,110115,'117019','furniture','font-weight','normal',0,''),(344499,110115,'117019','furniture','padding-top','10',0,''),(344500,110115,'117019','furniture','padding-left','10',0,''),(344501,110115,'117019','furniture','padding-right','10',0,''),(344502,110115,'117019','furniture','padding-bottom','10',0,''),(344503,110115,'117019','furniture','border-right-width','1',0,''),(344504,110115,'117019','furniture','border-right-color','$content-border-1',0,''),(344505,110117,'117021','furniture','text','<p>Shipping via</p>',1,''),(344506,110117,'117021','furniture','font-weight','bold',0,''),(344507,110117,'117021','furniture','font-size','14',0,''),(344508,110117,'117021','furniture','text','<p>Shipping via</p>',2,''),(344509,110117,'117021','furniture','text','<p>Shipping via</p>',3,''),(344510,110117,'117021','furniture','text','<p>Shipping via</p>',4,''),(344511,110118,'117022','furniture','block_type','1',0,''),(344512,110118,'117022','furniture','font-weight','normal',0,''),(344513,110118,'117022','furniture','padding-top','10',0,''),(344514,110118,'117022','furniture','padding-left','10',0,''),(344515,110118,'117022','furniture','padding-right','10',0,''),(344516,110118,'117022','furniture','padding-bottom','10',0,''),(344517,110119,'117023','furniture','text','<p>Shipping service</p>',1,''),(344518,110119,'117023','furniture','font-weight','bold',0,''),(344519,110119,'117023','furniture','font-size','14',0,''),(344520,110119,'117023','furniture','text','<p>Shipping service</p>',2,''),(344521,110119,'117023','furniture','text','<p>Shipping service</p>',3,''),(344522,110119,'117023','furniture','text','<p>Shipping service</p>',4,''),(344523,110121,'117025','furniture','font-size','14',0,''),(344524,110121,'117025','furniture','font-weight','bold',0,''),(344525,110121,'117025','furniture','text-align','center',0,''),(344526,110121,'117025','furniture','padding-bottom','10',0,''),(344527,110121,'117025','furniture','padding-top','10',0,''),(344528,110122,'117026','furniture','text','<p>Payment date:</p>',1,''),(344529,110122,'117026','furniture','font-weight','bold',0,''),(344530,110122,'117026','furniture','text-align','center',0,''),(344531,110122,'117026','furniture','font-size','12',0,''),(344532,110122,'117026','furniture','text','<p>Payment date:</p>',2,''),(344533,110122,'117026','furniture','text','<p>Payment date:</p>',3,''),(344534,110122,'117026','furniture','text','<p>Payment date:</p>',4,''),(344535,110123,'117027','furniture','font-weight','normal',0,''),(344536,110123,'117027','furniture','text-align','center',0,''),(344537,110123,'117027','furniture','padding-bottom','10',0,''),(344538,110124,'117034','furniture','text-align','center',0,''),(344539,110124,'117034','furniture','padding-top','10',0,''),(344540,110125,'1639155816.3893','furniture','block_type','1',0,''),(344541,110126,'117028','furniture','padding-top','30',0,''),(344542,110126,'117028','furniture','padding-bottom','30',0,''),(344543,110130,'117032','furniture','col_in_row','4',0,''),(344544,110130,'117032','furniture','listing_type','productListing',0,''),(344545,110130,'117032','furniture','view_as','carousel',0,''),(344546,110130,'117032','furniture','col_in_row','3',0,'5140'),(344547,110130,'117032','furniture','col_in_row','2',0,'5131'),(344548,110130,'117032','furniture','col_in_row','1',0,'5161'),(344549,110132,'1639485067.5512','furniture','padding-top','30',0,''),(344550,110132,'1639485067.5512','furniture','padding-bottom','30',0,''),(344551,110134,'1639154415.2739','furniture','block_type','1',0,''),(344552,110136,'117036','furniture','heading_type','h1',0,''),(344553,110137,'1639419797.9718','furniture','page_id','4',0,''),(344554,110137,'1639419797.9718','furniture','padding-top','30',0,''),(344555,110137,'1639419797.9718','furniture','padding-bottom','30',0,''),(344556,110140,'117039','furniture','text-align','center',0,''),(344557,110140,'117039','furniture','padding-top','10',0,''),(344558,110145,'117044','furniture','block_type','1',0,''),(344559,110146,'117045','furniture','block_type','1',0,''),(344560,110146,'117045','furniture','max-width','800',0,''),(344561,110146,'117045','furniture','margin','0 auto',0,''),(344562,110146,'117045','furniture','background-color','$content-bg-1',0,''),(344563,110147,'117046','furniture','color','$content-color-1',0,''),(344564,110147,'117046','furniture','font-size','12',0,''),(344565,110147,'117046','furniture','padding-top','20',0,''),(344566,110147,'117046','furniture','padding-bottom','20',0,''),(344567,110147,'117046','furniture','border-top-width','1',0,''),(344568,110147,'117046','furniture','border-top-color','$content-border-1',0,''),(344569,110148,'117047','furniture','font-weight','normal',0,''),(344570,110148,'117047','furniture','padding-top','20',0,''),(344571,110148,'117047','furniture','padding-left','10',0,''),(344572,110148,'117047','furniture','padding-right','10',0,''),(344573,110148,'117047','furniture','padding-bottom','20',0,''),(344574,110148,'117047','furniture','color','$content-color-1',0,''),(344575,110148,'117047','furniture','font-size','14',0,''),(344576,110149,'117048','furniture','block_type','7',0,''),(344577,110149,'117048','furniture','font-weight','normal',0,''),(344578,110149,'117048','furniture','background-color','$header-menu-bg-1',0,''),(344579,110149,'117048','furniture','padding-top','5',0,''),(344580,110149,'117048','furniture','padding-left','10',0,''),(344581,110149,'117048','furniture','padding-right','10',0,''),(344582,110149,'117048','furniture','padding-bottom','5',0,''),(344583,110150,'117049','furniture','color','$highlight-box-color-2',0,''),(344584,110150,'117049','furniture','font-size','14',0,''),(344585,110150,'117049','furniture','font-weight','normal',0,''),(344586,110151,'117050','furniture','font-weight','normal',0,''),(344587,110151,'117050','furniture','text-align','right',0,''),(344588,110151,'117050','furniture','color','$highlight-box-color-2',0,''),(344589,110151,'117050','furniture','font-size','12',0,''),(344590,110152,'117051','furniture','font-weight','normal',0,''),(344591,110152,'117051','furniture','padding-bottom','10',0,''),(344592,110152,'117051','furniture','padding-top','10',0,''),(344593,110152,'117051','furniture','logo_from','theme',0,''),(344594,110152,'117051','furniture','padding-left','20',0,''),(344595,110152,'117051','furniture','background-color','$header-bg-1',0,''),(344596,110153,'117052','furniture','block_type','1',0,''),(344597,110154,'117053','furniture','block_type','1',0,''),(344598,110154,'117053','furniture','max-width','800',0,''),(344599,110154,'117053','furniture','margin','0 auto',0,''),(344600,110154,'117053','furniture','background-color','$content-bg-1',0,''),(344601,110155,'117054','furniture','color','$content-color-1',0,''),(344602,110155,'117054','furniture','font-size','12',0,''),(344603,110155,'117054','furniture','padding-top','20',0,''),(344604,110155,'117054','furniture','padding-bottom','20',0,''),(344605,110155,'117054','furniture','border-top-width','1',0,''),(344606,110155,'117054','furniture','border-top-color','$content-border-1',0,''),(344607,110156,'117055','furniture','font-weight','normal',0,''),(344608,110156,'117055','furniture','padding-bottom','10',0,''),(344609,110156,'117055','furniture','background-color','$highlight-box-bg-2',0,''),(344611,110156,'117055','furniture','padding-left','20',0,''),(344612,110156,'117055','furniture','padding-top','10',0,''),(344616,110157,'117056','furniture','font-weight','normal',0,''),(344617,110157,'117056','furniture','padding-top','20',0,''),(344618,110157,'117056','furniture','padding-left','10',0,''),(344619,110157,'117056','furniture','padding-right','10',0,''),(344620,110157,'117056','furniture','padding-bottom','20',0,''),(344621,110157,'117056','furniture','color','$content-color-1',0,''),(344622,110157,'117056','furniture','font-size','14',0,''),(344623,110158,'117057','furniture','block_type','7',0,''),(344624,110158,'117057','furniture','font-weight','normal',0,''),(344625,110158,'117057','furniture','background-color','$highlight-box-bg-2',0,''),(344626,110158,'117057','furniture','padding-top','5',0,''),(344627,110158,'117057','furniture','padding-left','10',0,''),(344628,110158,'117057','furniture','padding-right','10',0,''),(344629,110158,'117057','furniture','padding-bottom','5',0,''),(344630,110159,'117058','furniture','color','$highlight-box-color-2',0,''),(344631,110159,'117058','furniture','font-size','15',0,''),(344632,110159,'117058','furniture','font-weight','700',0,''),(344633,110160,'117059','furniture','font-weight','normal',0,''),(344634,110160,'117059','furniture','text-align','right',0,''),(344635,110160,'117059','furniture','color','$fade-color-1',0,''),(344636,110160,'117059','furniture','font-size','12',0,''),(344637,110161,'117060','furniture','block_type','1',0,''),(344638,110161,'117060','furniture','background-color','$content-bg-2',0,''),(344639,110162,'117061','furniture','block_type','1',0,''),(344640,110162,'117061','furniture','max-width','800',0,''),(344641,110162,'117061','furniture','margin','0 auto',0,''),(344642,110163,'117062','furniture','block_type','1',0,''),(344643,110163,'117062','furniture','background-color','$content-bg-1',0,''),(344644,110163,'117062','furniture','padding-top','20',0,''),(344645,110163,'117062','furniture','padding-left','20',0,''),(344646,110163,'117062','furniture','padding-right','20',0,''),(344647,110163,'117062','furniture','padding-bottom','20',0,''),(344648,110164,'117063','furniture','font-weight','normal',0,''),(344649,110164,'117063','furniture','padding-top','20',0,''),(344650,110164,'117063','furniture','padding-bottom','20',0,''),(344651,110164,'117063','furniture','color','$content-color-1',0,''),(344652,110164,'117063','furniture','font-size','14',0,''),(344653,110165,'117064','furniture','block_type','7',0,''),(344654,110165,'117064','furniture','font-weight','normal',0,''),(344655,110165,'117064','furniture','padding-left','10',0,''),(344656,110165,'117064','furniture','padding-right','10',0,''),(344657,110165,'117064','furniture','padding-bottom','15',0,''),(344658,110165,'117064','furniture','border-bottom-width','1',0,''),(344659,110165,'117064','furniture','border-bottom-color','$content-border-1',0,''),(344660,110166,'117065','furniture','color','$content-color-1',0,''),(344661,110166,'117065','furniture','font-size','14',0,''),(344662,110166,'117065','furniture','font-weight','700',0,''),(344663,110167,'117066','furniture','font-weight','normal',0,''),(344664,110167,'117066','furniture','text-align','right',0,''),(344665,110167,'117066','furniture','color','$fade-color-1',0,''),(344666,110167,'117066','furniture','font-size','11',0,''),(344667,110167,'117066','furniture','text-transform','uppercase',0,''),(344668,110168,'117067','furniture','color','$fade-color-1',0,''),(344669,110168,'117067','furniture','font-size','12',0,''),(344670,110168,'117067','furniture','padding-top','20',0,''),(344671,110168,'117067','furniture','padding-bottom','20',0,''),(344672,110168,'117067','furniture','text-align','center',0,''),(344673,110169,'117068','furniture','font-weight','normal',0,''),(344674,110169,'117068','furniture','padding-bottom','10',0,''),(344675,110169,'117068','furniture','padding-top','10',0,''),(344676,110169,'117068','furniture','text-align','center',0,''),(344677,110169,'117068','furniture','logo_from','theme',0,''),(344678,110170,'117069','furniture','block_type','1',0,''),(344679,110170,'117069','furniture','background-color','$content-bg-2',0,''),(344680,110170,'117069','furniture','padding-top','20',0,''),(344681,110170,'117069','furniture','padding-bottom','20',0,''),(344682,110171,'117070','furniture','block_type','1',0,''),(344683,110171,'117070','furniture','max-width','800',0,''),(344684,110171,'117070','furniture','margin','0 auto',0,''),(344685,110172,'117071','furniture','color','$fade-color-1',0,''),(344686,110172,'117071','furniture','font-size','12',0,''),(344687,110172,'117071','furniture','padding-top','20',0,''),(344688,110172,'117071','furniture','padding-bottom','20',0,''),(344689,110172,'117071','furniture','text-align','left',0,''),(344690,110173,'117072','furniture','block_type','1',0,''),(344691,110173,'117072','furniture','background-color','$content-bg-1',0,''),(344692,110173,'117072','furniture','padding-top','20',0,''),(344693,110173,'117072','furniture','padding-left','20',0,''),(344694,110173,'117072','furniture','padding-right','20',0,''),(344695,110173,'117072','furniture','padding-bottom','20',0,''),(344696,110173,'117072','furniture','border-top-width','1',0,''),(344697,110173,'117072','furniture','border-left-width','1',0,''),(344698,110173,'117072','furniture','border-right-width','1',0,''),(344699,110173,'117072','furniture','border-bottom-width','1',0,''),(344700,110173,'117072','furniture','border-top-color','$content-border-1',0,''),(344701,110173,'117072','furniture','border-left-color','$content-border-1',0,''),(344702,110173,'117072','furniture','border-bottom-color','$content-border-1',0,''),(344703,110173,'117072','furniture','border-right-color','$content-border-1',0,''),(344704,110174,'117073','furniture','block_type','2',0,''),(344705,110175,'117074','furniture','font-weight','normal',0,''),(344706,110175,'117074','furniture','padding-bottom','10',0,''),(344707,110175,'117074','furniture','padding-top','10',0,''),(344708,110175,'117074','furniture','logo_from','theme',0,''),(344709,110176,'117075','furniture','font-weight','normal',0,''),(344710,110176,'117075','furniture','text-align','right',0,''),(344711,110176,'117075','furniture','color','$fade-color-1',0,''),(344712,110176,'117075','furniture','font-size','11',0,''),(344713,110176,'117075','furniture','text-transform','uppercase',0,''),(344714,110177,'117076','furniture','color','$content-color-1',0,''),(344715,110177,'117076','furniture','font-size','14',0,''),(344716,110177,'117076','furniture','font-weight','700',0,''),(344717,110177,'117076','furniture','text-align','right',0,''),(344718,110178,'117077','furniture','font-weight','normal',0,''),(344719,110178,'117077','furniture','padding-top','20',0,''),(344720,110178,'117077','furniture','padding-bottom','20',0,''),(344721,110178,'117077','furniture','color','$content-color-1',0,''),(344722,110178,'117077','furniture','font-size','14',0,''),(344723,110179,'121029','furniture','block_type','1',0,''),(344724,110182,'121032','furniture','margin-bottom','30',0,''),(344725,110183,'121025','furniture','block_type','1',0,''),(344726,110184,'121026','furniture','text','<h1>CATALOGUE</h1>',0,''),(344727,110186,'117078','furniture','block_type','1',0,''),(344728,110186,'117078','furniture','font-weight','normal',0,''),(344729,110186,'117078','furniture','padding-top','20',0,''),(344730,110186,'117078','furniture','background-color','$footer-bg-1',0,''),(344731,110186,'117078','furniture','style_class','preFooter',0,''),(344732,110186,'117078','furniture','padding-bottom','25',0,''),(344733,110186,'117078','furniture','color','$footer-color-1',0,''),(344734,110187,'120866','furniture','block_type','6',0,''),(344735,110187,'120866','furniture','schema','6-3',0,'5131'),(344736,110188,'117091','furniture','view_item','address',0,''),(344737,110188,'117091','furniture','address_spacer',',<br>',0,''),(344738,110188,'117091','furniture','data_format_content','<div>##TITLE##</div><div>Location: ##POST_ADDRESS##</div><div>Phone number: ##TELEPHONE##</div>\n',0,''),(344739,110188,'117091','furniture','margin-top','20',0,'5131'),(344740,110189,'120868','furniture','logo_from','theme',0,''),(344741,110189,'120868','furniture','margin-bottom','25',0,''),(344742,110189,'120868','furniture','padding-right','20',0,''),(344743,110189,'120868','furniture','display_none','1',0,'5131'),(344744,110190,'120871','furniture','block_type','1',0,''),(344745,110190,'120871','furniture','padding-left','15',0,''),(344746,110190,'120871','furniture','padding-right','15',0,''),(344747,110190,'120871','furniture','border-left-width','1',0,''),(344748,110190,'120871','furniture','border-right-width','1',0,''),(344749,110190,'120871','furniture','border-left-color','$footer-border-1',0,''),(344750,110190,'120871','furniture','border-right-color','$footer-border-1',0,''),(344751,110190,'120871','furniture','padding-left','0',0,'5131'),(344752,110190,'120871','furniture','padding-right','0',0,'5131'),(344753,110190,'120871','furniture','border-left-width','0',0,'5131'),(344754,110190,'120871','furniture','border-right-width','0',0,'5131'),(344755,110191,'117085','furniture','class','menu-style-2',0,''),(344756,110191,'117085','furniture','type','builder',0,''),(344757,110191,'117085','furniture','lev2_vis','click',0,'5140'),(344758,110191,'117085','furniture','style_class','footer-menu',0,''),(344759,110191,'117085','furniture','style','3',0,''),(344760,110192,'120869','furniture','block_type','1',0,''),(344761,110192,'120869','furniture','padding-top','30',0,''),(344762,110192,'120869','furniture','margin-top','24',0,''),(344763,110192,'120869','furniture','border-top-width','1',0,''),(344764,110192,'120869','furniture','border-top-color','$footer-border-1',0,''),(344765,110192,'120869','furniture','border-top-width','0',0,'5140'),(344766,110192,'120869','furniture','padding-top','0',0,'5140'),(344767,110193,'120870','furniture','logo','themes/furniture/img/geotrust.png',1,''),(344768,110193,'120870','furniture','float','left',0,''),(344769,110193,'120870','furniture','clear','none',0,''),(344773,110194,'120872','furniture','banners_group','payment',0,''),(344774,110194,'120872','furniture','float','right',0,''),(344775,110194,'120872','furniture','padding-top','15',0,''),(344776,110194,'120872','furniture','clear','none',0,''),(344777,110194,'120872','furniture','margin-bottom','20',0,''),(344778,110194,'120872','furniture','template','1',0,''),(344779,110195,'120873','furniture','text','<span>Payment types we accept</span>',0,''),(344780,110195,'120873','furniture','style_class','payment-text',0,''),(344781,110195,'120873','furniture','font-size','24',0,''),(344782,110195,'120873','furniture','font-weight','bold',0,''),(344783,110195,'120873','furniture','float','right',0,''),(344784,110195,'120873','furniture','padding-top','15',0,''),(344785,110195,'120873','furniture','clear','none',0,''),(344786,110195,'120873','furniture','padding-right','20',0,''),(344787,110195,'120873','furniture','font-size','18',0,'5145'),(344788,110195,'120873','furniture','display_none','1',0,'5140'),(344789,110196,'117093','furniture','block_type','1',0,''),(344790,110196,'117093','furniture','font-weight','400',0,''),(344791,110196,'117093','furniture','padding-top','20',0,''),(344792,110196,'117093','furniture','padding-bottom','20',0,''),(344793,110196,'117093','furniture','schema','2-2',0,''),(344794,110196,'117093','furniture','schema','2-3',0,'5140'),(344795,110196,'117093','furniture','background-color','$footer-bg-1',0,''),(344796,110196,'117093','furniture','color','$footer-color-1',0,''),(344797,110197,'117094','furniture','text-align','center',0,''),(344798,110197,'117094','furniture','font-size','14',0,''),(344799,110198,'117096','furniture','block_type','5',0,''),(344800,110199,'117097','furniture','text','##TEXT_LANGUAGE##',0,''),(344801,110201,'117099','furniture','block_type','5',0,''),(344802,110202,'117100','furniture','text','##TEXT_CURRENCY##',0,''),(344803,110204,'117102','furniture','block_type','1',0,''),(344804,110204,'117102','furniture','font-weight','normal',0,''),(344805,110205,'117103','furniture','block_type','2',0,''),(344806,110205,'117103','furniture','font-weight','normal',0,''),(344807,110205,'117103','furniture','padding-bottom','20',0,''),(344808,110206,'117104','furniture','block_type','1',0,''),(344809,110206,'117104','furniture','margin-right','20',0,''),(344810,110209,'117107','furniture','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(344811,110209,'117107','furniture','font-weight','normal',0,''),(344812,110209,'117107','furniture','padding-bottom','20',0,''),(344813,110209,'117107','furniture','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(344814,110209,'117107','furniture','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(344815,110209,'117107','furniture','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(344816,110211,'117109','furniture','block_type','1',0,''),(344817,110211,'117109','furniture','font-weight','normal',0,''),(344818,110211,'117109','furniture','style_class','gift-card-view',0,''),(344819,110211,'117109','furniture','text-align','center',0,''),(344820,110211,'117109','furniture','padding-bottom','20',0,''),(344821,110211,'117109','furniture','background-color','$highlight-box-bg-2',0,''),(344822,110211,'117109','furniture','padding-left','20',0,''),(344823,110211,'117109','furniture','padding-right','20',0,''),(344824,110211,'117109','furniture','color','$fade-color-1',0,''),(344825,110212,'117110','furniture','block_type','1',0,''),(344826,110212,'117110','furniture','font-weight','normal',0,''),(344827,110212,'117110','furniture','padding-top','10',0,''),(344828,110213,'117111','furniture','font-size','12',0,''),(344829,110213,'117111','furniture','font-weight','bold',0,''),(344830,110213,'117111','furniture','text-align','center',0,''),(344831,110213,'117111','furniture','style_class','email',0,''),(344832,110214,'117112','furniture','text','<p>If you require further assistance please contact us</p>',1,''),(344833,110214,'117112','furniture','font-weight','normal',0,''),(344834,110214,'117112','furniture','text-align','center',0,''),(344835,110214,'117112','furniture','font-size','12',0,''),(344836,110214,'117112','furniture','padding-top','10',0,''),(344837,110214,'117112','furniture','padding-bottom','5',0,''),(344838,110214,'117112','furniture','border-top-width','1',0,''),(344839,110214,'117112','furniture','border-top-color','$highlight-box-border-1',0,''),(344840,110214,'117112','furniture','text','<p>If you require further assistance please contact us</p>',2,''),(344841,110214,'117112','furniture','text','<p>If you require further assistance please contact us</p>',3,''),(344842,110214,'117112','furniture','text','<p>If you require further assistance please contact us</p>',4,''),(344843,110215,'117113','furniture','font-size','12',0,''),(344844,110215,'117113','furniture','font-weight','bold',0,''),(344845,110215,'117113','furniture','text-align','center',0,''),(344846,110215,'117113','furniture','style_class','phone',0,''),(344847,110215,'117113','furniture','padding-bottom','5',0,''),(344848,110216,'117114','furniture','text','<p>WHAT TO DO NEXT:</p>',1,''),(344849,110216,'117114','furniture','font-weight','normal',0,''),(344850,110216,'117114','furniture','text-align','center',0,''),(344851,110216,'117114','furniture','padding-top','20',0,''),(344852,110216,'117114','furniture','padding-bottom','10',0,''),(344853,110216,'117114','furniture','style_class','question-ico',0,''),(344854,110216,'117114','furniture','border-top-width','1',0,''),(344855,110216,'117114','furniture','border-top-color','$highlight-box-border-1',0,''),(344856,110216,'117114','furniture','font-size','18',0,''),(344857,110216,'117114','furniture','text','<p>WHAT TO DO NEXT:</p>',2,''),(344858,110216,'117114','furniture','text','<p>WHAT TO DO NEXT:</p>',3,''),(344859,110216,'117114','furniture','text','<p>WHAT TO DO NEXT:</p>',4,''),(344860,110217,'117115','furniture','text','<p>osCommerce</p>\n',1,''),(344861,110217,'117115','furniture','font-family','$font-1',0,''),(344862,110217,'117115','furniture','font-size','24',0,''),(344863,110217,'117115','furniture','font-weight','normal',0,''),(344864,110217,'117115','furniture','text-align','center',0,''),(344865,110217,'117115','furniture','padding-top','10',0,''),(344866,110217,'117115','furniture','padding-bottom','20',0,''),(344867,110217,'117115','furniture','text','<p>osCommerce</p>\n',2,''),(344868,110217,'117115','furniture','text','<p>osCommerce</p>\n',3,''),(344869,110217,'117115','furniture','text','<p>osCommerce</p>\n',4,''),(344870,110218,'117116','furniture','block_type','4',0,''),(344871,110218,'117116','furniture','color','$highlight-box-color-1',0,''),(344872,110218,'117116','furniture','font-size','30',0,''),(344873,110218,'117116','furniture','font-weight','normal',0,''),(344874,110218,'117116','furniture','background-color','$highlight-box-bg-1',0,''),(344875,110218,'117116','furniture','padding-top','5',0,''),(344876,110218,'117116','furniture','padding-left','10',0,''),(344877,110218,'117116','furniture','padding-right','10',0,''),(344878,110218,'117116','furniture','padding-bottom','5',0,''),(344879,110219,'117117','furniture','text','<p>Your code is:</p>',1,''),(344880,110219,'117117','furniture','font-weight','normal',0,''),(344881,110219,'117117','furniture','text','<p>Your code is:</p>',2,''),(344882,110219,'117117','furniture','text','<p>Your code is:</p>',3,''),(344883,110219,'117117','furniture','text','<p>Your code is:</p>',4,''),(344884,110221,'117119','furniture','font-weight','normal',0,''),(344885,110221,'117119','furniture','text-align','center',0,''),(344886,110221,'117119','furniture','padding-bottom','20',0,''),(344887,110222,'117120','furniture','font-size','60',0,''),(344888,110222,'117120','furniture','font-weight','bold',0,''),(344889,110222,'117120','furniture','text-align','center',0,''),(344890,110222,'117120','furniture','line-height','100',0,''),(344891,110222,'117120','furniture','padding-bottom','20',0,''),(344892,110222,'117120','furniture','line_height_measure','px',0,''),(344893,110223,'117121','furniture','text','<p>PERSONAL MESSAGE</p>',1,''),(344894,110223,'117121','furniture','font-size','18',0,''),(344895,110223,'117121','furniture','font-weight','normal',0,''),(344896,110223,'117121','furniture','text-align','center',0,''),(344897,110223,'117121','furniture','padding-top','20',0,''),(344898,110223,'117121','furniture','padding-bottom','10',0,''),(344899,110223,'117121','furniture','border-top-width','1',0,''),(344900,110223,'117121','furniture','border-top-color','$highlight-box-border-1',0,''),(344901,110223,'117121','furniture','text','<p>PERSONAL MESSAGE</p>',2,''),(344902,110223,'117121','furniture','text','<p>PERSONAL MESSAGE</p>',3,''),(344903,110223,'117121','furniture','text','<p>PERSONAL MESSAGE</p>',4,''),(344905,110224,'117123','furniture','logo_from','theme',0,''),(344906,110224,'117123','furniture','padding-top','20',0,''),(344907,110224,'117123','furniture','text-align','center',0,''),(344911,110225,'117124','furniture','text','<p>GIFT CARD</p>',1,''),(344912,110225,'117124','furniture','font-size','30',0,''),(344913,110225,'117124','furniture','font-weight','normal',0,''),(344914,110225,'117124','furniture','border-top-width','1',0,''),(344915,110225,'117124','furniture','border-top-color','$highlight-box-border-1',0,''),(344916,110225,'117124','furniture','style_class','gift-ico',0,''),(344917,110225,'117124','furniture','text-align','center',0,''),(344918,110225,'117124','furniture','padding-top','15',0,''),(344919,110225,'117124','furniture','text','<p>GIFT CARD</p>',2,''),(344920,110225,'117124','furniture','text','<p>GIFT CARD</p>',3,''),(344921,110225,'117124','furniture','text','<p>GIFT CARD</p>',4,''),(344922,110226,'117125','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(344923,110226,'117125','furniture','font-weight','normal',0,''),(344924,110226,'117125','furniture','text-align','center',0,''),(344925,110226,'117125','furniture','padding-bottom','10',0,''),(344926,110226,'117125','furniture','font-size','14',0,''),(344927,110226,'117125','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(344928,110226,'117125','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(344929,110226,'117125','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(344930,110227,'117126','furniture','block_type','1',0,''),(344931,110227,'117126','furniture','font-weight','normal',0,''),(344932,110227,'117126','furniture','style_class','gift-card-view',0,''),(344933,110227,'117126','furniture','text-align','center',0,''),(344934,110227,'117126','furniture','padding-bottom','20',0,''),(344935,110227,'117126','furniture','background-color','$content-bg-2',0,''),(344936,110227,'117126','furniture','padding-left','20',0,''),(344937,110227,'117126','furniture','padding-right','20',0,''),(344938,110227,'117126','furniture','color','$fade-color-1',0,''),(344939,110228,'117127','furniture','font-size','60',0,''),(344940,110228,'117127','furniture','font-weight','bold',0,''),(344941,110228,'117127','furniture','text-align','center',0,''),(344942,110228,'117127','furniture','line-height','100',0,''),(344943,110228,'117127','furniture','padding-bottom','20',0,''),(344944,110228,'117127','furniture','line_height_measure','px',0,''),(344945,110229,'117128','furniture','block_type','4',0,''),(344946,110229,'117128','furniture','color','$highlight-box-color-2',0,''),(344947,110229,'117128','furniture','font-size','30',0,''),(344948,110229,'117128','furniture','font-weight','normal',0,''),(344949,110229,'117128','furniture','background-color','$highlight-box-bg-4',0,''),(344950,110229,'117128','furniture','padding-top','5',0,''),(344951,110229,'117128','furniture','padding-left','10',0,''),(344952,110229,'117128','furniture','padding-right','10',0,''),(344953,110229,'117128','furniture','padding-bottom','5',0,''),(344954,110230,'117129','furniture','text','<p>Your code is:</p>',1,''),(344955,110230,'117129','furniture','font-weight','normal',0,''),(344956,110230,'117129','furniture','text','<p>Your code is:</p>',2,''),(344957,110230,'117129','furniture','text','<p>Your code is:</p>',3,''),(344958,110230,'117129','furniture','text','<p>Your code is:</p>',4,''),(344959,110232,'117131','furniture','block_type','1',0,''),(344960,110232,'117131','furniture','font-weight','normal',0,''),(344961,110232,'117131','furniture','padding-top','10',0,''),(344962,110233,'117132','furniture','font-size','12',0,''),(344963,110233,'117132','furniture','font-weight','bold',0,''),(344964,110233,'117132','furniture','text-align','center',0,''),(344965,110233,'117132','furniture','style_class','email',0,''),(344966,110234,'117133','furniture','text','<p>If you require further assistance please contact us</p>',1,''),(344967,110234,'117133','furniture','font-weight','normal',0,''),(344968,110234,'117133','furniture','text-align','center',0,''),(344969,110234,'117133','furniture','font-size','12',0,''),(344970,110234,'117133','furniture','padding-top','10',0,''),(344971,110234,'117133','furniture','padding-bottom','5',0,''),(344972,110234,'117133','furniture','border-top-width','1',0,''),(344973,110234,'117133','furniture','border-top-color','$highlight-box-border-1',0,''),(344974,110234,'117133','furniture','text','<p>If you require further assistance please contact us</p>',2,''),(344975,110234,'117133','furniture','text','<p>If you require further assistance please contact us</p>',3,''),(344976,110234,'117133','furniture','text','<p>If you require further assistance please contact us</p>',4,''),(344977,110235,'117134','furniture','font-size','12',0,''),(344978,110235,'117134','furniture','font-weight','bold',0,''),(344979,110235,'117134','furniture','text-align','center',0,''),(344980,110235,'117134','furniture','style_class','phone',0,''),(344981,110235,'117134','furniture','padding-bottom','5',0,''),(344982,110236,'117135','furniture','font-weight','normal',0,''),(344983,110236,'117135','furniture','text-align','center',0,''),(344984,110236,'117135','furniture','padding-bottom','20',0,''),(344985,110237,'117136','furniture','text','<p>PERSONAL MESSAGE</p>',1,''),(344986,110237,'117136','furniture','font-size','18',0,''),(344987,110237,'117136','furniture','font-weight','normal',0,''),(344988,110237,'117136','furniture','text-align','center',0,''),(344989,110237,'117136','furniture','padding-top','20',0,''),(344990,110237,'117136','furniture','padding-bottom','10',0,''),(344991,110237,'117136','furniture','border-top-width','1',0,''),(344992,110237,'117136','furniture','border-top-color','$highlight-box-border-1',0,''),(344993,110237,'117136','furniture','text','<p>PERSONAL MESSAGE</p>',2,''),(344994,110237,'117136','furniture','text','<p>PERSONAL MESSAGE</p>',3,''),(344995,110237,'117136','furniture','text','<p>PERSONAL MESSAGE</p>',4,''),(344996,110238,'117137','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(344997,110238,'117137','furniture','font-weight','normal',0,''),(344998,110238,'117137','furniture','text-align','center',0,''),(344999,110238,'117137','furniture','padding-bottom','10',0,''),(345000,110238,'117137','furniture','font-size','14',0,''),(345001,110238,'117137','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(345002,110238,'117137','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(345003,110238,'117137','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(345004,110239,'117138','furniture','text','<p>GIFT CARD</p>',1,''),(345005,110239,'117138','furniture','font-size','30',0,''),(345006,110239,'117138','furniture','font-weight','normal',0,''),(345007,110239,'117138','furniture','border-top-width','1',0,''),(345008,110239,'117138','furniture','border-top-color','$highlight-box-border-1',0,''),(345009,110239,'117138','furniture','style_class','gift-ico',0,''),(345010,110239,'117138','furniture','text-align','center',0,''),(345011,110239,'117138','furniture','padding-top','15',0,''),(345012,110239,'117138','furniture','text','<p>GIFT CARD</p>',2,''),(345013,110239,'117138','furniture','text','<p>GIFT CARD</p>',3,''),(345014,110239,'117138','furniture','text','<p>GIFT CARD</p>',4,''),(345015,110240,'117139','furniture','text','<p>WHAT TO DO NEXT:</p>',1,''),(345016,110240,'117139','furniture','font-weight','normal',0,''),(345017,110240,'117139','furniture','text-align','center',0,''),(345018,110240,'117139','furniture','padding-top','20',0,''),(345019,110240,'117139','furniture','padding-bottom','10',0,''),(345020,110240,'117139','furniture','style_class','question-ico',0,''),(345021,110240,'117139','furniture','border-top-width','1',0,''),(345022,110240,'117139','furniture','border-top-color','$highlight-box-border-1',0,''),(345023,110240,'117139','furniture','font-size','18',0,''),(345024,110240,'117139','furniture','text','<p>WHAT TO DO NEXT:</p>',2,''),(345025,110240,'117139','furniture','text','<p>WHAT TO DO NEXT:</p>',3,''),(345026,110240,'117139','furniture','text','<p>WHAT TO DO NEXT:</p>',4,''),(345027,110241,'1638804282.8587','furniture','logo_from','theme',0,''),(345028,110241,'1638804282.8587','furniture','padding-top','20',0,''),(345029,110241,'1638804282.8587','furniture','text-align','center',0,''),(345030,110241,'1638804282.8587','furniture','padding-bottom','20',0,''),(345031,110242,'117141','furniture','block_type','1',0,''),(345032,110242,'117141','furniture','font-weight','normal',0,''),(345033,110242,'117141','furniture','style_class','gift-card-view',0,''),(345034,110242,'117141','furniture','text-align','center',0,''),(345035,110242,'117141','furniture','padding-bottom','20',0,''),(345036,110242,'117141','furniture','background-color','$content-bg-2',0,''),(345037,110242,'117141','furniture','padding-left','20',0,''),(345038,110242,'117141','furniture','padding-right','20',0,''),(345039,110242,'117141','furniture','color','$fade-color-1',0,''),(345040,110243,'117142','furniture','block_type','1',0,''),(345041,110243,'117142','furniture','font-weight','normal',0,''),(345042,110243,'117142','furniture','padding-top','10',0,''),(345043,110244,'117143','furniture','font-size','12',0,''),(345044,110244,'117143','furniture','font-weight','bold',0,''),(345045,110244,'117143','furniture','text-align','center',0,''),(345046,110244,'117143','furniture','style_class','email',0,''),(345047,110244,'117143','furniture','color','$highlight-box-color-2',0,''),(345048,110245,'117144','furniture','font-size','12',0,''),(345049,110245,'117144','furniture','font-weight','bold',0,''),(345050,110245,'117144','furniture','text-align','center',0,''),(345051,110245,'117144','furniture','style_class','phone',0,''),(345052,110245,'117144','furniture','padding-bottom','5',0,''),(345053,110245,'117144','furniture','color','$highlight-box-color-2',0,''),(345054,110246,'117145','furniture','text','If you require further assistance please contact us',0,''),(345055,110246,'117145','furniture','font-size','12',0,''),(345056,110246,'117145','furniture','color','$highlight-box-color-2',0,''),(345057,110246,'117145','furniture','text-align','center',0,''),(345058,110246,'117145','furniture','padding-top','10',0,''),(345059,110247,'117146','furniture','block_type','4',0,''),(345060,110247,'117146','furniture','color','$highlight-box-color-2',0,''),(345061,110247,'117146','furniture','font-size','30',0,''),(345062,110247,'117146','furniture','font-weight','normal',0,''),(345063,110247,'117146','furniture','background-color','$highlight-box-bg-4',0,''),(345064,110247,'117146','furniture','padding-top','5',0,''),(345065,110247,'117146','furniture','padding-left','10',0,''),(345066,110247,'117146','furniture','padding-right','10',0,''),(345067,110247,'117146','furniture','padding-bottom','5',0,''),(345068,110248,'117147','furniture','text','Your code is:',0,''),(345069,110248,'117147','furniture','font-size','30',0,''),(345070,110248,'117147','furniture','color','$highlight-box-color-2',0,''),(345071,110249,'117148','furniture','color','$highlight-box-color-2',0,''),(345072,110249,'117148','furniture','font-size','30',0,''),(345073,110250,'117149','furniture','block_type','1',0,''),(345074,110251,'117150','furniture','text','<p>PERSONAL MESSAGE</p>',1,''),(345075,110251,'117150','furniture','font-size','18',0,''),(345076,110251,'117150','furniture','font-weight','normal',0,''),(345077,110251,'117150','furniture','text-align','center',0,''),(345078,110251,'117150','furniture','padding-top','20',0,''),(345079,110251,'117150','furniture','padding-bottom','10',0,''),(345080,110251,'117150','furniture','border-top-width','1',0,''),(345081,110251,'117150','furniture','border-top-color','$highlight-box-border-1',0,''),(345082,110251,'117150','furniture','text','<p>PERSONAL MESSAGE</p>',2,''),(345083,110251,'117150','furniture','text','<p>PERSONAL MESSAGE</p>',3,''),(345084,110251,'117150','furniture','text','<p>PERSONAL MESSAGE</p>',4,''),(345085,110252,'117151','furniture','text','HOLBI',0,''),(345086,110252,'117151','furniture','color','$highlight-box-color-2',0,''),(345087,110252,'117151','furniture','font-size','24',0,''),(345088,110252,'117151','furniture','padding-top','20',0,''),(345089,110252,'117151','furniture','text-align','center',0,''),(345090,110252,'117151','furniture','padding-bottom','20',0,''),(345091,110253,'117152','furniture','border-top-color','$highlight-box-border-1',0,''),(345092,110253,'117152','furniture','border-top-width','1',0,''),(345093,110253,'117152','furniture','padding-top','20',0,''),(345094,110253,'117152','furniture','font-size','30',0,''),(345095,110253,'117152','furniture','text-align','center',0,''),(345096,110253,'117152','furniture','color','$highlight-box-color-2',0,''),(345097,110253,'117152','furniture','text','GIFT CARD',0,''),(345098,110254,'117153','furniture','text-align','center',0,''),(345099,110254,'117153','furniture','font-weight','bold',0,''),(345100,110254,'117153','furniture','font-size','60',0,''),(345101,110254,'117153','furniture','color','$highlight-box-color-2',0,''),(345102,110255,'117154','furniture','font-size','20',0,''),(345103,110255,'117154','furniture','text-align','center',0,''),(345104,110255,'117154','furniture','color','$highlight-box-color-2',0,''),(345105,110255,'117154','furniture','padding-top','20',0,''),(345106,110255,'117154','furniture','padding-bottom','20',0,''),(345107,110256,'117155','furniture','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(345108,110256,'117155','furniture','text-align','center',0,''),(345109,110256,'117155','furniture','color','$highlight-box-color-2',0,''),(345110,110256,'117155','furniture','font-size','14',0,''),(345111,110256,'117155','furniture','padding-bottom','20',0,''),(345112,110257,'117156','furniture','text','WHAT TO DO NEXT:',0,''),(345113,110257,'117156','furniture','font-size','18',0,''),(345114,110257,'117156','furniture','text-align','center',0,''),(345115,110257,'117156','furniture','color','$highlight-box-color-2',0,''),(345116,110257,'117156','furniture','padding-top','20',0,''),(345117,110257,'117156','furniture','padding-bottom','10',0,''),(345118,110257,'117156','furniture','border-top-width','1',0,''),(345119,110257,'117156','furniture','border-top-color','$highlight-box-border-1',0,''),(345120,110259,'117158','furniture','block_type','1',0,''),(345121,110259,'117158','furniture','font-weight','normal',0,''),(345122,110259,'117158','furniture','style_class','gift-card-view',0,''),(345123,110259,'117158','furniture','text-align','center',0,''),(345124,110259,'117158','furniture','padding-bottom','20',0,''),(345125,110259,'117158','furniture','background-color','$highlight-box-bg-2',0,''),(345126,110259,'117158','furniture','padding-left','20',0,''),(345127,110259,'117158','furniture','padding-right','20',0,''),(345128,110259,'117158','furniture','color','$fade-color-1',0,''),(345129,110260,'117159','furniture','block_type','1',0,''),(345130,110260,'117159','furniture','font-weight','normal',0,''),(345131,110260,'117159','furniture','padding-top','10',0,''),(345132,110261,'117160','furniture','font-size','12',0,''),(345133,110261,'117160','furniture','font-weight','bold',0,''),(345134,110261,'117160','furniture','text-align','center',0,''),(345135,110261,'117160','furniture','style_class','email',0,''),(345136,110261,'117160','furniture','color','$highlight-box-color-2',0,''),(345137,110262,'117161','furniture','font-size','12',0,''),(345138,110262,'117161','furniture','font-weight','bold',0,''),(345139,110262,'117161','furniture','text-align','center',0,''),(345140,110262,'117161','furniture','style_class','phone',0,''),(345141,110262,'117161','furniture','padding-bottom','5',0,''),(345142,110262,'117161','furniture','color','$highlight-box-color-2',0,''),(345143,110263,'117162','furniture','text','If you require further assistance please contact us',0,''),(345144,110263,'117162','furniture','font-size','12',0,''),(345145,110263,'117162','furniture','color','$highlight-box-color-2',0,''),(345146,110263,'117162','furniture','text-align','center',0,''),(345147,110263,'117162','furniture','padding-top','10',0,''),(345148,110264,'117163','furniture','block_type','2',0,''),(345149,110264,'117163','furniture','color','$highlight-box-color-2',0,''),(345150,110264,'117163','furniture','font-size','30',0,''),(345151,110264,'117163','furniture','font-weight','normal',0,''),(345152,110264,'117163','furniture','background-color','$highlight-box-bg-4',0,''),(345153,110264,'117163','furniture','padding-top','5',0,''),(345154,110264,'117163','furniture','padding-left','10',0,''),(345155,110264,'117163','furniture','padding-right','10',0,''),(345156,110264,'117163','furniture','padding-bottom','5',0,''),(345157,110265,'117164','furniture','text','Your code is:',0,''),(345158,110265,'117164','furniture','font-size','30',0,''),(345159,110265,'117164','furniture','color','$highlight-box-color-2',0,''),(345160,110266,'117165','furniture','color','$highlight-box-color-2',0,''),(345161,110266,'117165','furniture','font-size','30',0,''),(345162,110267,'117166','furniture','block_type','1',0,''),(345163,110268,'117167','furniture','text','<p>PERSONAL MESSAGE</p>',1,''),(345164,110268,'117167','furniture','font-size','18',0,''),(345165,110268,'117167','furniture','font-weight','normal',0,''),(345166,110268,'117167','furniture','text-align','center',0,''),(345167,110268,'117167','furniture','padding-top','20',0,''),(345168,110268,'117167','furniture','padding-bottom','10',0,''),(345169,110268,'117167','furniture','border-top-width','1',0,''),(345170,110268,'117167','furniture','border-top-color','$highlight-box-border-1',0,''),(345171,110268,'117167','furniture','text','<p>PERSONAL MESSAGE</p>',2,''),(345172,110268,'117167','furniture','text','<p>PERSONAL MESSAGE</p>',3,''),(345173,110268,'117167','furniture','text','<p>PERSONAL MESSAGE</p>',4,''),(345174,110269,'117169','furniture','border-top-color','$highlight-box-border-1',0,''),(345175,110269,'117169','furniture','border-top-width','1',0,''),(345176,110269,'117169','furniture','padding-top','20',0,''),(345177,110269,'117169','furniture','font-size','30',0,''),(345178,110269,'117169','furniture','text-align','center',0,''),(345179,110269,'117169','furniture','color','$highlight-box-color-2',0,''),(345180,110269,'117169','furniture','text','GIFT CARD',0,''),(345181,110270,'117170','furniture','text-align','center',0,''),(345182,110270,'117170','furniture','font-weight','bold',0,''),(345183,110270,'117170','furniture','font-size','60',0,''),(345184,110270,'117170','furniture','color','$highlight-box-color-2',0,''),(345185,110271,'117171','furniture','font-size','20',0,''),(345186,110271,'117171','furniture','text-align','center',0,''),(345187,110271,'117171','furniture','color','$highlight-box-color-2',0,''),(345188,110271,'117171','furniture','padding-top','20',0,''),(345189,110271,'117171','furniture','padding-bottom','20',0,''),(345190,110272,'117172','furniture','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(345191,110272,'117172','furniture','text-align','center',0,''),(345192,110272,'117172','furniture','color','$highlight-box-color-2',0,''),(345193,110272,'117172','furniture','font-size','14',0,''),(345194,110272,'117172','furniture','padding-bottom','20',0,''),(345195,110273,'117173','furniture','text','WHAT TO DO NEXT:',0,''),(345196,110273,'117173','furniture','font-size','18',0,''),(345197,110273,'117173','furniture','text-align','center',0,''),(345198,110273,'117173','furniture','color','$highlight-box-color-2',0,''),(345199,110273,'117173','furniture','padding-top','20',0,''),(345200,110273,'117173','furniture','padding-bottom','10',0,''),(345201,110273,'117173','furniture','border-top-width','1',0,''),(345202,110273,'117173','furniture','border-top-color','$highlight-box-border-1',0,''),(345203,110274,'1638978695.8384','furniture','logo_from','theme',0,''),(345204,110274,'1638978695.8384','furniture','text-align','center',0,''),(345205,110274,'1638978695.8384','furniture','padding-top','20',0,''),(345206,110274,'1638978695.8384','furniture','padding-bottom','20',0,''),(345207,110275,'117175','furniture','block_type','1',0,''),(345208,110275,'117175','furniture','padding-left','20',0,''),(345209,110275,'117175','furniture','padding-right','20',0,''),(345210,110275,'117175','furniture','padding-bottom','20',0,''),(345211,110277,'117177','furniture','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(345212,110277,'117177','furniture','text-align','center',0,''),(345213,110278,'117178','furniture','block_type','1',0,''),(345214,110278,'117178','furniture','font-weight','normal',0,''),(345215,110278,'117178','furniture','style_class','gift-card-view',0,''),(345216,110278,'117178','furniture','text-align','center',0,''),(345217,110278,'117178','furniture','padding-bottom','20',0,''),(345218,110278,'117178','furniture','background-color','$highlight-box-bg-3',0,''),(345219,110278,'117178','furniture','padding-left','20',0,''),(345220,110278,'117178','furniture','padding-right','20',0,''),(345221,110278,'117178','furniture','color','$fade-color-1',0,''),(345222,110279,'117179','furniture','block_type','4',0,''),(345223,110279,'117179','furniture','color','$highlight-box-color-2',0,''),(345224,110279,'117179','furniture','font-size','30',0,''),(345225,110279,'117179','furniture','font-weight','normal',0,''),(345226,110279,'117179','furniture','background-color','$highlight-box-bg-4',0,''),(345227,110279,'117179','furniture','padding-top','5',0,''),(345228,110279,'117179','furniture','padding-left','10',0,''),(345229,110279,'117179','furniture','padding-right','10',0,''),(345230,110279,'117179','furniture','padding-bottom','5',0,''),(345231,110280,'117180','furniture','text','<p>Your code is:</p>',1,''),(345232,110280,'117180','furniture','font-weight','normal',0,''),(345233,110280,'117180','furniture','text','<p>Your code is:</p>',2,''),(345234,110280,'117180','furniture','text','<p>Your code is:</p>',3,''),(345235,110280,'117180','furniture','text','<p>Your code is:</p>',4,''),(345236,110282,'117182','furniture','text','<p>WHAT TO DO NEXT:</p>',1,''),(345237,110282,'117182','furniture','font-weight','normal',0,''),(345238,110282,'117182','furniture','text-align','center',0,''),(345239,110282,'117182','furniture','padding-top','20',0,''),(345240,110282,'117182','furniture','padding-bottom','10',0,''),(345241,110282,'117182','furniture','style_class','question-ico',0,''),(345242,110282,'117182','furniture','border-top-width','1',0,''),(345243,110282,'117182','furniture','border-top-color','$highlight-box-border-1',0,''),(345244,110282,'117182','furniture','font-size','18',0,''),(345245,110282,'117182','furniture','text','<p>WHAT TO DO NEXT:</p>',2,''),(345246,110282,'117182','furniture','text','<p>WHAT TO DO NEXT:</p>',3,''),(345247,110282,'117182','furniture','text','<p>WHAT TO DO NEXT:</p>',4,''),(345248,110283,'117184','furniture','block_type','1',0,''),(345249,110283,'117184','furniture','font-weight','normal',0,''),(345250,110283,'117184','furniture','padding-top','10',0,''),(345251,110284,'117185','furniture','text','<p>If you require further assistance please contact us</p>',1,''),(345252,110284,'117185','furniture','font-weight','normal',0,''),(345253,110284,'117185','furniture','text-align','center',0,''),(345254,110284,'117185','furniture','font-size','12',0,''),(345255,110284,'117185','furniture','padding-top','10',0,''),(345256,110284,'117185','furniture','padding-bottom','5',0,''),(345257,110284,'117185','furniture','border-top-width','1',0,''),(345258,110284,'117185','furniture','border-top-color','$highlight-box-border-1',0,''),(345259,110284,'117185','furniture','text','<p>If you require further assistance please contact us</p>',2,''),(345260,110284,'117185','furniture','text','<p>If you require further assistance please contact us</p>',3,''),(345261,110284,'117185','furniture','text','<p>If you require further assistance please contact us</p>',4,''),(345262,110285,'117186','furniture','font-size','12',0,''),(345263,110285,'117186','furniture','font-weight','bold',0,''),(345264,110285,'117186','furniture','text-align','center',0,''),(345265,110285,'117186','furniture','style_class','email',0,''),(345266,110286,'117187','furniture','font-size','12',0,''),(345267,110286,'117187','furniture','font-weight','bold',0,''),(345268,110286,'117187','furniture','text-align','center',0,''),(345269,110286,'117187','furniture','style_class','phone',0,''),(345270,110286,'117187','furniture','padding-bottom','5',0,''),(345271,110287,'117188','furniture','font-weight','normal',0,''),(345272,110287,'117188','furniture','text-align','center',0,''),(345273,110287,'117188','furniture','padding-bottom','20',0,''),(345274,110288,'117189','furniture','text','<p>GIFT CARD</p>',1,''),(345275,110288,'117189','furniture','font-size','30',0,''),(345276,110288,'117189','furniture','font-weight','normal',0,''),(345277,110288,'117189','furniture','border-top-width','1',0,''),(345278,110288,'117189','furniture','border-top-color','$highlight-box-border-1',0,''),(345279,110288,'117189','furniture','style_class','gift-ico',0,''),(345280,110288,'117189','furniture','text-align','center',0,''),(345281,110288,'117189','furniture','padding-top','15',0,''),(345282,110288,'117189','furniture','text','<p>GIFT CARD</p>',2,''),(345283,110288,'117189','furniture','text','<p>GIFT CARD</p>',3,''),(345284,110288,'117189','furniture','text','<p>GIFT CARD</p>',4,''),(345285,110289,'117190','furniture','text','<p>PERSONAL MESSAGE</p>',1,''),(345286,110289,'117190','furniture','font-size','18',0,''),(345287,110289,'117190','furniture','font-weight','normal',0,''),(345288,110289,'117190','furniture','text-align','center',0,''),(345289,110289,'117190','furniture','padding-top','20',0,''),(345290,110289,'117190','furniture','padding-bottom','10',0,''),(345291,110289,'117190','furniture','border-top-width','1',0,''),(345292,110289,'117190','furniture','border-top-color','$highlight-box-border-1',0,''),(345293,110289,'117190','furniture','text','<p>PERSONAL MESSAGE</p>',2,''),(345294,110289,'117190','furniture','text','<p>PERSONAL MESSAGE</p>',3,''),(345295,110289,'117190','furniture','text','<p>PERSONAL MESSAGE</p>',4,''),(345296,110290,'117191','furniture','font-size','60',0,''),(345297,110290,'117191','furniture','font-weight','bold',0,''),(345298,110290,'117191','furniture','text-align','center',0,''),(345299,110290,'117191','furniture','line-height','100',0,''),(345300,110290,'117191','furniture','padding-bottom','20',0,''),(345301,110290,'117191','furniture','line_height_measure','px',0,''),(345302,110291,'117192','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(345303,110291,'117192','furniture','font-weight','normal',0,''),(345304,110291,'117192','furniture','text-align','center',0,''),(345305,110291,'117192','furniture','padding-bottom','10',0,''),(345306,110291,'117192','furniture','font-size','14',0,''),(345307,110291,'117192','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(345308,110291,'117192','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(345309,110291,'117192','furniture','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(345310,110292,'1638804328.7281','furniture','logo_from','theme',0,''),(345311,110292,'1638804328.7281','furniture','padding-top','20',0,''),(345312,110292,'1638804328.7281','furniture','text-align','center',0,''),(345313,110292,'1638804328.7281','furniture','padding-bottom','20',0,''),(345314,110293,'117193','furniture','block_type','1',0,''),(345315,110293,'117193','furniture','font-weight','normal',0,''),(345316,110293,'117193','furniture','style_class','gift-card-view',0,''),(345317,110293,'117193','furniture','text-align','center',0,''),(345318,110293,'117193','furniture','padding-bottom','20',0,''),(345319,110293,'117193','furniture','background-color','$highlight-box-bg-3',0,''),(345320,110293,'117193','furniture','padding-left','20',0,''),(345321,110293,'117193','furniture','padding-right','20',0,''),(345322,110293,'117193','furniture','color','$fade-color-1',0,''),(345323,110294,'117194','furniture','block_type','1',0,''),(345324,110294,'117194','furniture','font-weight','normal',0,''),(345325,110294,'117194','furniture','padding-top','10',0,''),(345326,110295,'117195','furniture','font-size','12',0,''),(345327,110295,'117195','furniture','font-weight','bold',0,''),(345328,110295,'117195','furniture','text-align','center',0,''),(345329,110295,'117195','furniture','style_class','email',0,''),(345330,110295,'117195','furniture','color','$highlight-box-color-2',0,''),(345331,110296,'117196','furniture','font-size','12',0,''),(345332,110296,'117196','furniture','font-weight','bold',0,''),(345333,110296,'117196','furniture','text-align','center',0,''),(345334,110296,'117196','furniture','style_class','phone',0,''),(345335,110296,'117196','furniture','padding-bottom','5',0,''),(345336,110296,'117196','furniture','color','$highlight-box-color-2',0,''),(345337,110297,'117197','furniture','text','If you require further assistance please contact us',0,''),(345338,110297,'117197','furniture','font-size','12',0,''),(345339,110297,'117197','furniture','color','$highlight-box-color-2',0,''),(345340,110297,'117197','furniture','text-align','center',0,''),(345341,110297,'117197','furniture','padding-top','10',0,''),(345342,110298,'117198','furniture','block_type','4',0,''),(345343,110298,'117198','furniture','color','$highlight-box-color-2',0,''),(345344,110298,'117198','furniture','font-size','30',0,''),(345345,110298,'117198','furniture','font-weight','normal',0,''),(345346,110298,'117198','furniture','background-color','$highlight-box-bg-4',0,''),(345347,110298,'117198','furniture','padding-top','5',0,''),(345348,110298,'117198','furniture','padding-left','10',0,''),(345349,110298,'117198','furniture','padding-right','10',0,''),(345350,110298,'117198','furniture','padding-bottom','5',0,''),(345351,110299,'117199','furniture','text','Your code is:',0,''),(345352,110299,'117199','furniture','font-size','30',0,''),(345353,110299,'117199','furniture','color','$highlight-box-color-2',0,''),(345354,110300,'117200','furniture','color','$highlight-box-color-2',0,''),(345355,110300,'117200','furniture','font-size','30',0,''),(345356,110301,'117201','furniture','block_type','1',0,''),(345357,110302,'117202','furniture','text','<p>PERSONAL MESSAGE</p>',1,''),(345358,110302,'117202','furniture','font-size','18',0,''),(345359,110302,'117202','furniture','font-weight','normal',0,''),(345360,110302,'117202','furniture','text-align','center',0,''),(345361,110302,'117202','furniture','padding-top','20',0,''),(345362,110302,'117202','furniture','padding-bottom','10',0,''),(345363,110302,'117202','furniture','border-top-width','1',0,''),(345364,110302,'117202','furniture','border-top-color','$highlight-box-border-1',0,''),(345365,110302,'117202','furniture','text','<p>PERSONAL MESSAGE</p>',2,''),(345366,110302,'117202','furniture','text','<p>PERSONAL MESSAGE</p>',3,''),(345367,110302,'117202','furniture','text','<p>PERSONAL MESSAGE</p>',4,''),(345368,110303,'117203','furniture','text','HOLBI',0,''),(345369,110303,'117203','furniture','color','$highlight-box-color-2',0,''),(345370,110303,'117203','furniture','font-size','24',0,''),(345371,110303,'117203','furniture','padding-top','20',0,''),(345372,110303,'117203','furniture','text-align','center',0,''),(345373,110303,'117203','furniture','padding-bottom','20',0,''),(345374,110304,'117204','furniture','border-top-color','$highlight-box-border-1',0,''),(345375,110304,'117204','furniture','border-top-width','1',0,''),(345376,110304,'117204','furniture','padding-top','20',0,''),(345377,110304,'117204','furniture','font-size','30',0,''),(345378,110304,'117204','furniture','text-align','center',0,''),(345379,110304,'117204','furniture','color','$highlight-box-color-2',0,''),(345380,110304,'117204','furniture','text','GIFT CARD',0,''),(345381,110305,'117205','furniture','text-align','center',0,''),(345382,110305,'117205','furniture','font-weight','bold',0,''),(345383,110305,'117205','furniture','font-size','60',0,''),(345384,110305,'117205','furniture','color','$highlight-box-color-2',0,''),(345385,110306,'117206','furniture','font-size','20',0,''),(345386,110306,'117206','furniture','text-align','center',0,''),(345387,110306,'117206','furniture','color','$highlight-box-color-2',0,''),(345388,110306,'117206','furniture','padding-top','20',0,''),(345389,110306,'117206','furniture','padding-bottom','20',0,''),(345390,110307,'117207','furniture','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(345391,110307,'117207','furniture','text-align','center',0,''),(345392,110307,'117207','furniture','color','$highlight-box-color-2',0,''),(345393,110307,'117207','furniture','font-size','14',0,''),(345394,110307,'117207','furniture','padding-bottom','20',0,''),(345395,110308,'117208','furniture','text','WHAT TO DO NEXT:',0,''),(345396,110308,'117208','furniture','font-size','18',0,''),(345397,110308,'117208','furniture','text-align','center',0,''),(345398,110308,'117208','furniture','color','$highlight-box-color-2',0,''),(345399,110308,'117208','furniture','padding-top','20',0,''),(345400,110308,'117208','furniture','padding-bottom','10',0,''),(345401,110308,'117208','furniture','border-top-width','1',0,''),(345402,110308,'117208','furniture','border-top-color','$highlight-box-border-1',0,''),(345530,110328,'117224','furniture','block_type','1',0,''),(345531,110334,'117229','furniture','width','680',0,''),(345532,110334,'117229','furniture','font-weight','normal',0,''),(345533,110334,'117229','furniture','font-size','12',0,''),(345534,110334,'117229','furniture','padding-top','20',0,''),(345535,110334,'117229','furniture','padding-bottom','20',0,''),(345536,110334,'117229','furniture','color','$content-color-1',0,''),(345537,110335,'117230','furniture','block_type','4',0,''),(345538,110335,'117230','furniture','font-weight','normal',0,''),(345539,110335,'117230','furniture','border-top-width','1',0,''),(345540,110335,'117230','furniture','border-top-color','$content-border-1',0,''),(345541,110335,'117230','furniture','border-left-width','1',0,''),(345542,110335,'117230','furniture','border-left-color','$content-border-1',0,''),(345543,110335,'117230','furniture','border-right-width','1',0,''),(345544,110335,'117230','furniture','border-right-color','$content-border-1',0,''),(345545,110335,'117230','furniture','border-bottom-width','1',0,''),(345546,110335,'117230','furniture','border-bottom-color','$content-border-1',0,''),(345547,110336,'117231','furniture','block_type','2',0,''),(345548,110336,'117231','furniture','font-weight','normal',0,''),(345549,110336,'117231','furniture','border-top-width','1',0,''),(345550,110336,'117231','furniture','border-top-color','$content-border-1',0,''),(345551,110336,'117231','furniture','border-right-width','1',0,''),(345552,110336,'117231','furniture','border-right-color','$content-border-1',0,''),(345553,110337,'117232','furniture','block_type','1',0,''),(345554,110337,'117232','furniture','font-weight','normal',0,''),(345555,110337,'117232','furniture','padding-top','10',0,''),(345556,110337,'117232','furniture','padding-left','10',0,''),(345557,110337,'117232','furniture','padding-right','10',0,''),(345558,110337,'117232','furniture','padding-bottom','10',0,''),(345559,110337,'117232','furniture','border-right-width','1',0,''),(345560,110337,'117232','furniture','border-right-color','$content-border-1',0,''),(345561,110339,'117234','furniture','text','<p>Shipping via</p>',1,''),(345562,110339,'117234','furniture','font-weight','bold',0,''),(345563,110339,'117234','furniture','font-size','14',0,''),(345564,110339,'117234','furniture','text','<p>Shipping via</p>',2,''),(345565,110339,'117234','furniture','text','<p>Shipping via</p>',3,''),(345566,110339,'117234','furniture','text','<p>Shipping via</p>',4,''),(345567,110340,'117235','furniture','block_type','1',0,''),(345568,110340,'117235','furniture','font-weight','normal',0,''),(345569,110340,'117235','furniture','padding-top','10',0,''),(345570,110340,'117235','furniture','padding-left','10',0,''),(345571,110340,'117235','furniture','padding-right','10',0,''),(345572,110340,'117235','furniture','padding-bottom','10',0,''),(345573,110341,'117236','furniture','text','<p>Shipping service</p>',1,''),(345574,110341,'117236','furniture','font-weight','bold',0,''),(345575,110341,'117236','furniture','font-size','14',0,''),(345576,110341,'117236','furniture','text','<p>Shipping service</p>',2,''),(345577,110341,'117236','furniture','text','<p>Shipping service</p>',3,''),(345578,110341,'117236','furniture','text','<p>Shipping service</p>',4,''),(345579,110343,'117238','furniture','block_type','2',0,''),(345580,110343,'117238','furniture','font-weight','normal',0,''),(345581,110343,'117238','furniture','border-right-width','1',0,''),(345582,110343,'117238','furniture','border-right-color','$content-border-1',0,''),(345583,110344,'117239','furniture','block_type','1',0,''),(345584,110344,'117239','furniture','font-weight','400',0,''),(345585,110344,'117239','furniture','background-color','$content-bg-2',0,''),(345586,110344,'117239','furniture','padding-top','10',0,''),(345587,110344,'117239','furniture','padding-left','10',0,''),(345588,110344,'117239','furniture','padding-right','10',0,''),(345589,110344,'117239','furniture','padding-bottom','30',0,''),(345590,110345,'117240','furniture','text','<p>INVOICE ADDRESS:</p>',1,''),(345591,110345,'117240','furniture','font-size','14',0,''),(345592,110345,'117240','furniture','font-weight','bold',0,''),(345593,110345,'117240','furniture','text','<p>INVOICE ADDRESS:</p>',2,''),(345594,110345,'117240','furniture','text','<p>INVOICE ADDRESS:</p>',3,''),(345595,110345,'117240','furniture','text','<p>INVOICE ADDRESS:</p>',4,''),(345596,110346,'117241','furniture','font-size','12',0,''),(345597,110348,'117242','furniture','block_type','1',0,''),(345598,110348,'117242','furniture','font-weight','normal',0,''),(345599,110348,'117242','furniture','padding-top','10',0,''),(345600,110348,'117242','furniture','padding-left','10',0,''),(345601,110348,'117242','furniture','padding-right','10',0,''),(345602,110348,'117242','furniture','padding-bottom','10',0,''),(345603,110349,'117243','furniture','text','<p>E-MAIL ADDRESS:</p>',1,''),(345604,110349,'117243','furniture','font-weight','bold',0,''),(345605,110349,'117243','furniture','font-size','14',0,''),(345606,110349,'117243','furniture','padding-top','10',0,''),(345607,110349,'117243','furniture','text','<p>E-MAIL ADDRESS:</p>',2,''),(345608,110349,'117243','furniture','text','<p>E-MAIL ADDRESS:</p>',3,''),(345609,110349,'117243','furniture','text','<p>E-MAIL ADDRESS:</p>',4,''),(345610,110350,'117244','furniture','font-weight','normal',0,''),(345611,110351,'117245','furniture','font-weight','normal',0,''),(345612,110352,'117246','furniture','text','<p>CUSTOMER:</p>',1,''),(345613,110352,'117246','furniture','font-size','13',0,''),(345614,110352,'117246','furniture','font-weight','bold',0,''),(345615,110352,'117246','furniture','text','<p>CUSTOMER:</p>',2,''),(345616,110352,'117246','furniture','text','<p>CUSTOMER:</p>',3,''),(345617,110352,'117246','furniture','text','<p>CUSTOMER:</p>',4,''),(345618,110353,'117247','furniture','text','<p>PHONE NUMBER:</p>',1,''),(345619,110353,'117247','furniture','font-size','14',0,''),(345620,110353,'117247','furniture','font-weight','bold',0,''),(345621,110353,'117247','furniture','padding-top','10',0,''),(345622,110353,'117247','furniture','text','<p>PHONE NUMBER:</p>',2,''),(345623,110353,'117247','furniture','text','<p>PHONE NUMBER:</p>',3,''),(345624,110353,'117247','furniture','text','<p>PHONE NUMBER:</p>',4,''),(345625,110355,'117249','furniture','font-weight','normal',0,''),(345626,110355,'117249','furniture','text-align','center',0,''),(345627,110355,'117249','furniture','padding-bottom','20',0,''),(345628,110356,'117250','furniture','text','<p>Payment Method:</p>',1,''),(345629,110356,'117250','furniture','font-weight','bold',0,''),(345630,110356,'117250','furniture','text-align','center',0,''),(345631,110356,'117250','furniture','text','<p>Payment Method:</p>',2,''),(345632,110356,'117250','furniture','text','<p>Payment Method:</p>',3,''),(345633,110356,'117250','furniture','text','<p>Payment Method:</p>',4,''),(345634,110357,'117251','furniture','text','<p>Payment date:</p>',1,''),(345635,110357,'117251','furniture','font-weight','bold',0,''),(345636,110357,'117251','furniture','text-align','center',0,''),(345637,110357,'117251','furniture','font-size','12',0,''),(345638,110357,'117251','furniture','text','<p>Payment date:</p>',2,''),(345639,110357,'117251','furniture','text','<p>Payment date:</p>',3,''),(345640,110357,'117251','furniture','text','<p>Payment date:</p>',4,''),(345641,110358,'117252','furniture','font-size','14',0,''),(345642,110358,'117252','furniture','font-weight','bold',0,''),(345643,110358,'117252','furniture','text-align','center',0,''),(345644,110358,'117252','furniture','padding-bottom','10',0,''),(345645,110358,'117252','furniture','padding-top','10',0,''),(345646,110359,'117253','furniture','font-weight','normal',0,''),(345647,110359,'117253','furniture','text-align','center',0,''),(345648,110359,'117253','furniture','padding-bottom','10',0,''),(345649,110360,'117254','furniture','font-weight','normal',0,''),(345650,110360,'117254','furniture','text-align','center',0,''),(345651,110361,'117255','furniture','block_type','3',0,''),(345652,110361,'117255','furniture','font-weight','normal',0,''),(345653,110361,'117255','furniture','padding-top','20',0,''),(345654,110362,'117256','furniture','font-size','12',0,''),(345655,110363,'117257','furniture','text','<p>If undelivered please return to:</p>',1,''),(345656,110363,'117257','furniture','font-size','12',0,''),(345657,110363,'117257','furniture','font-weight','bold',0,''),(345658,110363,'117257','furniture','text','<p>If undelivered please return to:</p>',2,''),(345659,110363,'117257','furniture','text','<p>If undelivered please return to:</p>',3,''),(345660,110363,'117257','furniture','text','<p>If undelivered please return to:</p>',4,''),(345661,110364,'117258','furniture','text','<p>Thank you for your order</p>',1,''),(345662,110364,'117258','furniture','color','$content-color-1',0,''),(345663,110364,'117258','furniture','font-size','13',0,''),(345664,110364,'117258','furniture','font-weight','bold',0,''),(345665,110364,'117258','furniture','padding-top','5',0,''),(345666,110364,'117258','furniture','text-align','center',0,''),(345667,110364,'117258','furniture','text','<p>Thank you for your order</p>',2,''),(345668,110364,'117258','furniture','text','<p>Thank you for your order</p>',3,''),(345669,110364,'117258','furniture','text','<p>Thank you for your order</p>',4,''),(345670,110365,'117260','furniture','block_type','6',0,''),(345671,110365,'117260','furniture','font-weight','normal',0,''),(345672,110365,'117260','furniture','font-size','16',0,''),(345673,110366,'117261','furniture','text','<p>Email:</p>',1,''),(345674,110366,'117261','furniture','font-weight','normal',0,''),(345675,110366,'117261','furniture','text-align','right',0,''),(345676,110366,'117261','furniture','font-size','12',0,''),(345677,110366,'117261','furniture','text','<p>Email:</p>',2,''),(345678,110366,'117261','furniture','text','<p>Email:</p>',3,''),(345679,110366,'117261','furniture','text','<p>Email:</p>',4,''),(345680,110367,'117262','furniture','font-weight','normal',0,''),(345681,110367,'117262','furniture','text-align','right',0,''),(345682,110367,'117262','furniture','font-size','12',0,''),(345683,110368,'117263','furniture','block_type','6',0,''),(345684,110368,'117263','furniture','font-weight','normal',0,''),(345685,110368,'117263','furniture','font-size','16',0,''),(345686,110369,'117264','furniture','text','<p>Phone:</p>',1,''),(345687,110369,'117264','furniture','font-weight','normal',0,''),(345688,110369,'117264','furniture','text-align','right',0,''),(345689,110369,'117264','furniture','font-size','12',0,''),(345690,110369,'117264','furniture','text','<p>Phone:</p>',2,''),(345691,110369,'117264','furniture','text','<p>Phone:</p>',3,''),(345692,110369,'117264','furniture','text','<p>Phone:</p>',4,''),(345693,110370,'117265','furniture','font-weight','normal',0,''),(345694,110370,'117265','furniture','text-align','right',0,''),(345695,110370,'117265','furniture','font-size','12',0,''),(345696,110371,'117266','furniture','text','<p>If something has gone wrong please contact us at:</p>',1,''),(345697,110371,'117266','furniture','font-size','12',0,''),(345698,110371,'117266','furniture','font-weight','bold',0,''),(345699,110371,'117266','furniture','text-align','right',0,''),(345700,110371,'117266','furniture','text','<p>If something has gone wrong please contact us at:</p>',2,''),(345701,110371,'117266','furniture','text','<p>If something has gone wrong please contact us at:</p>',3,''),(345702,110371,'117266','furniture','text','<p>If something has gone wrong please contact us at:</p>',4,''),(345703,110372,'117267','furniture','font-weight','400',0,''),(345704,110372,'117267','furniture','padding-top','20',0,''),(345705,110372,'117267','furniture','padding-bottom','0',0,''),(345706,110372,'117267','furniture','font-size','12',0,''),(345707,110373,'117268','furniture','block_type','5',0,''),(345708,110373,'117268','furniture','font-weight','normal',0,''),(345709,110373,'117268','furniture','border-bottom-width','1',0,''),(345710,110373,'117268','furniture','border-bottom-color','$content-border-1',0,''),(345711,110373,'117268','furniture','border-top-width','1',0,''),(345712,110373,'117268','furniture','border-top-color','$content-border-1',0,''),(345713,110373,'117268','furniture','border-left-color','$content-border-1',0,''),(345714,110373,'117268','furniture','border-left-width','1',0,''),(345715,110374,'117269','furniture','block_type','1',0,''),(345716,110374,'117269','furniture','font-weight','normal',0,''),(345717,110374,'117269','furniture','padding-top','10',0,''),(345718,110374,'117269','furniture','padding-left','10',0,''),(345719,110374,'117269','furniture','padding-right','10',0,''),(345720,110375,'117270','furniture','font-weight','400',0,''),(345721,110375,'117270','furniture','line-height','120',0,''),(345722,110375,'117270','furniture','line_height_measure','%',0,''),(345723,110375,'117270','furniture','font-size','12',0,''),(345724,110376,'117271','furniture','text','<p>SHIPPING ADDRESS:</p>',1,''),(345725,110376,'117271','furniture','font-size','14',0,''),(345726,110376,'117271','furniture','font-weight','bold',0,''),(345727,110376,'117271','furniture','padding-bottom','10',0,''),(345728,110376,'117271','furniture','text','<p>SHIPPING ADDRESS:</p>',2,''),(345729,110376,'117271','furniture','text','<p>SHIPPING ADDRESS:</p>',3,''),(345730,110376,'117271','furniture','text','<p>SHIPPING ADDRESS:</p>',4,''),(345731,110377,'117272','furniture','block_type','1',0,''),(345732,110377,'117272','furniture','background-color','$content-bg-2',0,''),(345733,110377,'117272','furniture','padding-top','20',0,''),(345734,110377,'117272','furniture','padding-left','10',0,''),(345735,110377,'117272','furniture','padding-right','10',0,''),(345736,110377,'117272','furniture','padding-bottom','20',0,''),(345737,110377,'117272','furniture','font-size','14',0,''),(345738,110378,'117273','furniture','font-weight','normal',0,''),(345739,110378,'117273','furniture','text-align','right',0,''),(345740,110378,'117273','furniture','font-size','14',0,''),(345741,110378,'117273','furniture','box_align','3',0,''),(345742,110379,'117274','furniture','block_type','2',0,''),(345743,110379,'117274','furniture','font-weight','normal',0,''),(345744,110379,'117274','furniture','padding-bottom','20',0,''),(345745,110380,'117275','furniture','font-weight','400',0,''),(345746,110380,'117275','furniture','padding-top','10',0,''),(345748,110380,'117275','furniture','padding-bottom','10',0,''),(345752,110381,'117276','furniture','block_type','11',0,''),(345753,110381,'117276','furniture','font-weight','normal',0,''),(345754,110382,'117277','furniture','text','<p>Web:</p>',1,''),(345755,110382,'117277','furniture','font-weight','normal',0,''),(345756,110382,'117277','furniture','text-align','right',0,''),(345757,110382,'117277','furniture','text','<p>Web:</p>',2,''),(345758,110382,'117277','furniture','text','<p>Web:</p>',3,''),(345759,110382,'117277','furniture','text','<p>Web:</p>',4,''),(345760,110383,'117278','furniture','font-weight','normal',0,''),(345761,110383,'117278','furniture','text-align','right',0,''),(345762,110384,'117279','furniture','block_type','11',0,''),(345763,110384,'117279','furniture','font-weight','normal',0,''),(345764,110385,'117280','furniture','text','<p>Email:</p>',1,''),(345765,110385,'117280','furniture','font-weight','normal',0,''),(345766,110385,'117280','furniture','text-align','right',0,''),(345767,110385,'117280','furniture','text','<p>Email:</p>',2,''),(345768,110385,'117280','furniture','text','<p>Email:</p>',3,''),(345769,110385,'117280','furniture','text','<p>Email:</p>',4,''),(345770,110386,'117281','furniture','font-weight','normal',0,''),(345771,110386,'117281','furniture','text-align','right',0,''),(345772,110387,'117282','furniture','block_type','1',0,''),(345773,110388,'117283','furniture','font-weight','normal',0,''),(345774,110388,'117283','furniture','text-align','right',0,''),(345775,110388,'117283','furniture','padding-bottom','10',0,''),(345776,110388,'117283','furniture','address_spacer',',',0,''),(345777,110388,'117283','furniture','font-size','12',0,''),(345778,110389,'117284','furniture','block_type','11',0,''),(345779,110389,'117284','furniture','font-weight','normal',0,''),(345780,110390,'117285','furniture','text','<p>Phone:</p>',1,''),(345781,110390,'117285','furniture','font-weight','normal',0,''),(345782,110390,'117285','furniture','text-align','right',0,''),(345783,110390,'117285','furniture','text','<p>Phone:</p>',2,''),(345784,110390,'117285','furniture','text','<p>Phone:</p>',3,''),(345785,110390,'117285','furniture','text','<p>Phone:</p>',4,''),(345786,110391,'117286','furniture','font-weight','normal',0,''),(345787,110391,'117286','furniture','text-align','right',0,''),(345788,110392,'1640103567.8175','furniture','column_qty','1',0,''),(345789,110392,'1640103567.8175','furniture','column_name','1',0,''),(345790,110392,'1640103567.8175','furniture','column_model','1',0,''),(345791,110393,'117287','furniture','block_type','1',0,''),(345792,110393,'117287','furniture','padding-top','20',0,''),(345793,110394,'117288','furniture','tab_1','RETURNING CUSTOMER',1,''),(345794,110394,'117288','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(345795,110394,'117288','furniture','tab_1','RETURNING CUSTOMER',2,''),(345796,110394,'117288','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(345797,110394,'117288','furniture','tab_1','RETURNING CUSTOMER',3,''),(345798,110394,'117288','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(345799,110394,'117288','furniture','tab_1','RETURNING CUSTOMER',4,''),(345800,110394,'117288','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(345801,110395,'117289','furniture','max-width','600',0,''),(345802,110395,'117289','furniture','margin_left_measure','auto',0,''),(345803,110395,'117289','furniture','margin_right_measure','auto',0,''),(345804,110396,'117290','furniture','block_type','8',0,''),(345805,110396,'117290','furniture','schema','8-6',0,'5140'),(345806,110397,'117291','furniture','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(345807,110398,'117292','furniture','block_type','1',0,''),(345808,110398,'117292','furniture','padding-left','20',0,''),(345809,110398,'117292','furniture','padding-right','20',0,''),(345810,110399,'117293','furniture','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(345811,110401,'117295','furniture','block_type','1',0,''),(345812,110402,'117296','furniture','text','##TEXT_OR##',0,''),(345813,110402,'117296','furniture','font-size','18',0,''),(345814,110402,'117296','furniture','font-weight','700',0,''),(345815,110402,'117296','furniture','padding-top','15',0,''),(345816,110402,'117296','furniture','text-align','center',0,''),(345817,110402,'117296','furniture','content','\\_',0,'3'),(345818,110402,'117296','furniture','height','5',0,'3'),(345819,110402,'117296','furniture','width','70',0,'3'),(345820,110402,'117296','furniture','display','inline-block',0,'3'),(345821,110402,'117296','furniture','border-top-width','1',0,'3'),(345822,110402,'117296','furniture','border-top-color','$content-border-1',0,'3'),(345823,110402,'117296','furniture','margin-left','10',0,'3'),(345824,110402,'117296','furniture','margin-right','10',0,'3'),(345825,110402,'117296','furniture','content','\\_',0,'4'),(345826,110402,'117296','furniture','display','inline-block',0,'4'),(345827,110402,'117296','furniture','width','70',0,'4'),(345828,110402,'117296','furniture','height','5',0,'4'),(345829,110402,'117296','furniture','border-top-width','1',0,'4'),(345830,110402,'117296','furniture','border-top-color','$content-border-1',0,'4'),(345831,110402,'117296','furniture','margin-left','10',0,'4'),(345832,110402,'117296','furniture','margin-right','10',0,'4'),(345833,110402,'117296','furniture','position','relative',0,''),(345834,110402,'117296','furniture','top','-10',0,''),(345835,110403,'117297','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(345836,110403,'117297','furniture','font-size','26',0,''),(345837,110403,'117297','furniture','font-family','$font-1',0,''),(345838,110403,'117297','furniture','padding-top','15',0,''),(345839,110403,'117297','furniture','padding-bottom','15',0,''),(345840,110403,'117297','furniture','text-align','center',0,''),(345841,110404,'117298','furniture','text-align','center',0,''),(345842,110404,'117298','furniture','hide_parents','2',0,''),(345843,110405,'117299','furniture','block_type','1',0,''),(345844,110405,'117299','furniture','padding-top','40',0,''),(345845,110405,'117299','furniture','background-color','$content-bg-2',0,''),(345846,110405,'117299','furniture','padding-bottom','40',0,''),(345847,110405,'117299','furniture','style_class','checkout-login-wrap',0,''),(345848,110405,'117299','furniture','color','$content-color-2',0,''),(345849,110406,'117300','furniture','block_type','2',0,''),(345850,110406,'117300','furniture','background-color','$content-bg-1',0,''),(345851,110406,'117300','furniture','max-width','830',0,''),(345852,110406,'117300','furniture','margin_left_measure','auto',0,''),(345853,110406,'117300','furniture','margin_right_measure','auto',0,''),(345854,110406,'117300','furniture','padding-top','40',0,''),(345855,110406,'117300','furniture','padding-bottom','40',0,''),(345856,110406,'117300','furniture','schema','2-3',0,'5140'),(345857,110406,'117300','furniture','color','$content-color-1',0,''),(345858,110407,'117301','furniture','text-align','center',0,''),(345859,110407,'117301','furniture','margin-bottom','40',0,''),(345860,110408,'117302','furniture','text-align','center',0,''),(345861,110409,'117303','furniture','text','##TEXT_OR##',0,''),(345862,110409,'117303','furniture','font-size','18',0,''),(345863,110409,'117303','furniture','font-weight','700',0,''),(345864,110409,'117303','furniture','text-align','center',0,''),(345865,110409,'117303','furniture','content','\\_',0,'3'),(345866,110409,'117303','furniture','height','5',0,'3'),(345867,110409,'117303','furniture','width','70',0,'3'),(345868,110409,'117303','furniture','display','inline-block',0,'3'),(345869,110409,'117303','furniture','border-top-width','1',0,'3'),(345870,110409,'117303','furniture','border-top-color','$content-border-1',0,'3'),(345871,110409,'117303','furniture','margin-left','10',0,'3'),(345872,110409,'117303','furniture','margin-right','10',0,'3'),(345873,110409,'117303','furniture','content','\\_',0,'4'),(345874,110409,'117303','furniture','display','inline-block',0,'4'),(345875,110409,'117303','furniture','width','70',0,'4'),(345876,110409,'117303','furniture','height','5',0,'4'),(345877,110409,'117303','furniture','border-top-width','1',0,'4'),(345878,110409,'117303','furniture','border-top-color','$content-border-1',0,'4'),(345879,110409,'117303','furniture','margin-left','10',0,'4'),(345880,110409,'117303','furniture','margin-right','10',0,'4'),(345881,110409,'117303','furniture','position','relative',0,''),(345882,110409,'117303','furniture','padding-top','10',0,''),(345883,110409,'117303','furniture','padding-bottom','10',0,''),(345884,110410,'117304','furniture','block_type','1',0,''),(345885,110411,'117305','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(345886,110411,'117305','furniture','font-size','18',0,''),(345887,110411,'117305','furniture','font-family','$font-1',0,''),(345888,110411,'117305','furniture','padding-top','15',0,''),(345889,110411,'117305','furniture','padding-bottom','15',0,''),(345890,110411,'117305','furniture','text-align','center',0,''),(345891,110411,'117305','furniture','text-transform','uppercase',0,''),(345892,110412,'117306','furniture','text-align','center',0,''),(345893,110412,'117306','furniture','hide_parents','2',0,''),(345894,110413,'117307','furniture','text','##NEW_CUSTOMER##',0,''),(345895,110413,'117307','furniture','font-size','18',0,''),(345896,110413,'117307','furniture','font-family','$font-1',0,''),(345897,110413,'117307','furniture','text-align','center',0,''),(345898,110413,'117307','furniture','text-transform','uppercase',0,''),(345899,110413,'117307','furniture','margin-bottom','10',0,''),(345900,110414,'117308','furniture','max-width','230',0,''),(345901,110414,'117308','furniture','margin_left_measure','auto',0,''),(345902,110414,'117308','furniture','margin_right_measure','auto',0,''),(345903,110415,'117309','furniture','text','##RETURNING_CUSTOMER##',0,''),(345904,110415,'117309','furniture','font-size','18',0,''),(345905,110415,'117309','furniture','font-family','$font-1',0,''),(345906,110415,'117309','furniture','text-transform','uppercase',0,''),(345907,110415,'117309','furniture','text-align','center',0,''),(345908,110416,'117310','furniture','block_type','1',0,''),(345909,110416,'117310','furniture','padding-top','20',0,''),(345910,110417,'117311','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(345911,110417,'117311','furniture','tab_2','RETURNING CUSTOMER',1,''),(345912,110417,'117311','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(345913,110417,'117311','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(345914,110417,'117311','furniture','tab_2','RETURNING CUSTOMER',2,''),(345915,110417,'117311','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(345916,110417,'117311','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(345917,110417,'117311','furniture','tab_2','RETURNING CUSTOMER',3,''),(345918,110417,'117311','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(345919,110417,'117311','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(345920,110417,'117311','furniture','tab_2','RETURNING CUSTOMER',4,''),(345921,110417,'117311','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(345922,110418,'117312','furniture','block_type','8',0,''),(345923,110419,'117313','furniture','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(345924,110420,'117314','furniture','block_type','1',0,''),(345925,110420,'117314','furniture','padding-left','20',0,''),(345926,110420,'117314','furniture','padding-right','20',0,''),(345927,110422,'117316','furniture','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(345928,110422,'117316','furniture','border-top-width','1',0,''),(345929,110422,'117316','furniture','border-top-color','$content-border-1',0,''),(345930,110424,'117318','furniture','block_type','8',0,''),(345931,110425,'117319','furniture','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(345932,110426,'117320','furniture','block_type','1',0,''),(345933,110426,'117320','furniture','padding-left','20',0,''),(345934,110426,'117320','furniture','padding-right','20',0,''),(345935,110427,'117321','furniture','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(345936,110429,'117323','furniture','text-align','center',0,''),(345937,110430,'117324','furniture','text','##TEXT_OR##',0,''),(345938,110430,'117324','furniture','font-size','18',0,''),(345939,110430,'117324','furniture','font-weight','700',0,''),(345940,110430,'117324','furniture','padding-top','15',0,''),(345941,110430,'117324','furniture','text-align','center',0,''),(345942,110430,'117324','furniture','content','\\_',0,'3'),(345943,110430,'117324','furniture','height','5',0,'3'),(345944,110430,'117324','furniture','width','70',0,'3'),(345945,110430,'117324','furniture','display','inline-block',0,'3'),(345946,110430,'117324','furniture','border-top-width','1',0,'3'),(345947,110430,'117324','furniture','border-top-color','$content-border-1',0,'3'),(345948,110430,'117324','furniture','margin-left','10',0,'3'),(345949,110430,'117324','furniture','margin-right','10',0,'3'),(345950,110430,'117324','furniture','content','\\_',0,'4'),(345951,110430,'117324','furniture','display','inline-block',0,'4'),(345952,110430,'117324','furniture','width','70',0,'4'),(345953,110430,'117324','furniture','height','5',0,'4'),(345954,110430,'117324','furniture','border-top-width','1',0,'4'),(345955,110430,'117324','furniture','border-top-color','$content-border-1',0,'4'),(345956,110430,'117324','furniture','margin-left','10',0,'4'),(345957,110430,'117324','furniture','margin-right','10',0,'4'),(345958,110430,'117324','furniture','position','relative',0,''),(345959,110430,'117324','furniture','top','-10',0,''),(345960,110431,'117325','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(345961,110431,'117325','furniture','font-size','26',0,''),(345962,110431,'117325','furniture','font-family','$font-1',0,''),(345963,110431,'117325','furniture','padding-top','15',0,''),(345964,110431,'117325','furniture','padding-bottom','15',0,''),(345965,110431,'117325','furniture','text-align','center',0,''),(345966,110432,'117326','furniture','block_type','1',0,''),(345967,110432,'117326','furniture','padding-top','20',0,''),(345968,110433,'117327','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(345969,110433,'117327','furniture','tab_2','RETURNING CUSTOMER',1,''),(345970,110433,'117327','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(345971,110433,'117327','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(345972,110433,'117327','furniture','tab_2','RETURNING CUSTOMER',2,''),(345973,110433,'117327','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(345974,110433,'117327','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(345975,110433,'117327','furniture','tab_2','RETURNING CUSTOMER',3,''),(345976,110433,'117327','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(345977,110433,'117327','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(345978,110433,'117327','furniture','tab_2','RETURNING CUSTOMER',4,''),(345979,110433,'117327','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(345980,110434,'117328','furniture','block_type','8',0,''),(345981,110435,'117329','furniture','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(345982,110438,'117332','furniture','block_type','8',0,''),(345983,110439,'117333','furniture','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(345984,110441,'117335','furniture','block_type','1',0,''),(345985,110441,'117335','furniture','padding-left','20',0,''),(345986,110441,'117335','furniture','padding-right','20',0,''),(345987,110443,'117337','furniture','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(345988,110444,'117338','furniture','text','##TEXT_OR##',0,''),(345989,110444,'117338','furniture','font-size','18',0,''),(345990,110444,'117338','furniture','font-weight','700',0,''),(345991,110444,'117338','furniture','padding-top','15',0,''),(345992,110444,'117338','furniture','text-align','center',0,''),(345993,110444,'117338','furniture','content','\\_',0,'3'),(345994,110444,'117338','furniture','height','5',0,'3'),(345995,110444,'117338','furniture','width','70',0,'3'),(345996,110444,'117338','furniture','display','inline-block',0,'3'),(345997,110444,'117338','furniture','border-top-width','1',0,'3'),(345998,110444,'117338','furniture','border-top-color','$content-border-1',0,'3'),(345999,110444,'117338','furniture','margin-left','10',0,'3'),(346000,110444,'117338','furniture','margin-right','10',0,'3'),(346001,110444,'117338','furniture','content','\\_',0,'4'),(346002,110444,'117338','furniture','display','inline-block',0,'4'),(346003,110444,'117338','furniture','width','70',0,'4'),(346004,110444,'117338','furniture','height','5',0,'4'),(346005,110444,'117338','furniture','border-top-width','1',0,'4'),(346006,110444,'117338','furniture','border-top-color','$content-border-1',0,'4'),(346007,110444,'117338','furniture','margin-left','10',0,'4'),(346008,110444,'117338','furniture','margin-right','10',0,'4'),(346009,110444,'117338','furniture','position','relative',0,''),(346010,110444,'117338','furniture','top','-10',0,''),(346011,110445,'117339','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(346012,110445,'117339','furniture','font-size','26',0,''),(346013,110445,'117339','furniture','font-family','$font-1',0,''),(346014,110445,'117339','furniture','padding-top','15',0,''),(346015,110445,'117339','furniture','padding-bottom','15',0,''),(346016,110445,'117339','furniture','text-align','center',0,''),(346017,110446,'117340','furniture','text-align','center',0,''),(346018,110447,'117341','furniture','block_type','1',0,''),(346019,110447,'117341','furniture','padding-top','20',0,''),(346020,110448,'117342','furniture','text-align','center',0,''),(346021,110449,'117343','furniture','text','##TEXT_OR##',0,''),(346022,110449,'117343','furniture','font-size','18',0,''),(346023,110449,'117343','furniture','font-weight','700',0,''),(346024,110449,'117343','furniture','padding-top','15',0,''),(346025,110449,'117343','furniture','text-align','center',0,''),(346026,110449,'117343','furniture','content','\\_',0,'3'),(346027,110449,'117343','furniture','height','5',0,'3'),(346028,110449,'117343','furniture','width','70',0,'3'),(346029,110449,'117343','furniture','display','inline-block',0,'3'),(346030,110449,'117343','furniture','border-top-width','1',0,'3'),(346031,110449,'117343','furniture','border-top-color','$content-border-1',0,'3'),(346032,110449,'117343','furniture','margin-left','10',0,'3'),(346033,110449,'117343','furniture','margin-right','10',0,'3'),(346034,110449,'117343','furniture','content','\\_',0,'4'),(346035,110449,'117343','furniture','display','inline-block',0,'4'),(346036,110449,'117343','furniture','width','70',0,'4'),(346037,110449,'117343','furniture','height','5',0,'4'),(346038,110449,'117343','furniture','border-top-width','1',0,'4'),(346039,110449,'117343','furniture','border-top-color','$content-border-1',0,'4'),(346040,110449,'117343','furniture','margin-left','10',0,'4'),(346041,110449,'117343','furniture','margin-right','10',0,'4'),(346042,110449,'117343','furniture','position','relative',0,''),(346043,110449,'117343','furniture','top','-10',0,''),(346044,110450,'117344','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(346045,110450,'117344','furniture','tab_2','RETURNING CUSTOMER',1,''),(346046,110450,'117344','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(346047,110450,'117344','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(346048,110450,'117344','furniture','tab_2','RETURNING CUSTOMER',2,''),(346049,110450,'117344','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(346050,110450,'117344','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(346051,110450,'117344','furniture','tab_2','RETURNING CUSTOMER',3,''),(346052,110450,'117344','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(346053,110450,'117344','furniture','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(346054,110450,'117344','furniture','tab_2','RETURNING CUSTOMER',4,''),(346055,110450,'117344','furniture','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(346056,110451,'117345','furniture','block_type','8',0,''),(346057,110452,'117346','furniture','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(346058,110455,'117349','furniture','block_type','8',0,''),(346059,110456,'117350','furniture','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(346060,110457,'117351','furniture','block_type','1',0,''),(346061,110457,'117351','furniture','padding-left','20',0,''),(346062,110457,'117351','furniture','padding-right','20',0,''),(346063,110459,'117353','furniture','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(346064,110460,'117354','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(346065,110460,'117354','furniture','font-size','26',0,''),(346066,110460,'117354','furniture','font-family','$font-1',0,''),(346067,110460,'117354','furniture','padding-top','15',0,''),(346068,110460,'117354','furniture','padding-bottom','15',0,''),(346069,110460,'117354','furniture','text-align','center',0,''),(346070,110461,'117355','furniture','block_type','1',0,''),(346071,110461,'117355','furniture','padding-top','40',0,''),(346072,110461,'117355','furniture','background-color','$content-bg-2',0,''),(346073,110461,'117355','furniture','padding-bottom','40',0,''),(346074,110462,'117356','furniture','block_type','2',0,''),(346075,110462,'117356','furniture','background-color','$content-bg-1',0,''),(346076,110462,'117356','furniture','max-width','830',0,''),(346077,110462,'117356','furniture','margin_left_measure','auto',0,''),(346078,110462,'117356','furniture','margin_right_measure','auto',0,''),(346079,110462,'117356','furniture','padding-top','40',0,''),(346080,110462,'117356','furniture','padding-bottom','40',0,''),(346081,110462,'117356','furniture','schema','2-3',0,'5140'),(346082,110463,'117357','furniture','block_type','1',0,''),(346083,110464,'117358','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(346084,110464,'117358','furniture','font-size','18',0,''),(346085,110464,'117358','furniture','font-family','$font-1',0,''),(346086,110464,'117358','furniture','padding-top','15',0,''),(346087,110464,'117358','furniture','padding-bottom','15',0,''),(346088,110464,'117358','furniture','text-align','center',0,''),(346089,110464,'117358','furniture','text-transform','uppercase',0,''),(346090,110465,'117359','furniture','text-align','center',0,''),(346091,110465,'117359','furniture','hide_parents','2',0,''),(346092,110466,'117360','furniture','text-align','center',0,''),(346093,110467,'117361','furniture','text-align','center',0,''),(346094,110467,'117361','furniture','margin-bottom','40',0,''),(346095,110468,'117362','furniture','text','##TEXT_OR##',0,''),(346096,110468,'117362','furniture','font-size','18',0,''),(346097,110468,'117362','furniture','font-weight','700',0,''),(346098,110468,'117362','furniture','text-align','center',0,''),(346099,110468,'117362','furniture','content','\\_',0,'3'),(346100,110468,'117362','furniture','height','5',0,'3'),(346101,110468,'117362','furniture','width','70',0,'3'),(346102,110468,'117362','furniture','display','inline-block',0,'3'),(346103,110468,'117362','furniture','border-top-width','1',0,'3'),(346104,110468,'117362','furniture','border-top-color','$content-border-1',0,'3'),(346105,110468,'117362','furniture','margin-left','10',0,'3'),(346106,110468,'117362','furniture','margin-right','10',0,'3'),(346107,110468,'117362','furniture','content','\\_',0,'4'),(346108,110468,'117362','furniture','display','inline-block',0,'4'),(346109,110468,'117362','furniture','width','70',0,'4'),(346110,110468,'117362','furniture','height','5',0,'4'),(346111,110468,'117362','furniture','border-top-width','1',0,'4'),(346112,110468,'117362','furniture','border-top-color','$content-border-1',0,'4'),(346113,110468,'117362','furniture','margin-left','10',0,'4'),(346114,110468,'117362','furniture','margin-right','10',0,'4'),(346115,110468,'117362','furniture','position','relative',0,''),(346116,110468,'117362','furniture','padding-top','10',0,''),(346117,110468,'117362','furniture','padding-bottom','10',0,''),(346118,110469,'117363','furniture','text','##NEW_CUSTOMER##',0,''),(346119,110469,'117363','furniture','font-size','18',0,''),(346120,110469,'117363','furniture','font-family','$font-1',0,''),(346121,110469,'117363','furniture','text-align','center',0,''),(346122,110469,'117363','furniture','text-transform','uppercase',0,''),(346123,110469,'117363','furniture','margin-bottom','10',0,''),(346124,110470,'117364','furniture','text','##RETURNING_CUSTOMER##',0,''),(346125,110470,'117364','furniture','font-size','18',0,''),(346126,110470,'117364','furniture','font-family','$font-1',0,''),(346127,110470,'117364','furniture','text-transform','uppercase',0,''),(346128,110470,'117364','furniture','text-align','center',0,''),(346129,110471,'117365','furniture','max-width','230',0,''),(346130,110471,'117365','furniture','margin_left_measure','auto',0,''),(346131,110471,'117365','furniture','margin_right_measure','auto',0,''),(346132,110472,'117366','furniture','block_type','1',0,''),(346133,110472,'117366','furniture','padding-top','40',0,''),(346134,110472,'117366','furniture','background-color','$content-bg-2',0,''),(346135,110472,'117366','furniture','padding-bottom','40',0,''),(346136,110473,'117367','furniture','block_type','2',0,''),(346137,110473,'117367','furniture','background-color','$content-bg-1',0,''),(346138,110473,'117367','furniture','max-width','830',0,''),(346139,110473,'117367','furniture','margin_left_measure','auto',0,''),(346140,110473,'117367','furniture','margin_right_measure','auto',0,''),(346141,110473,'117367','furniture','padding-top','40',0,''),(346142,110473,'117367','furniture','padding-bottom','40',0,''),(346143,110473,'117367','furniture','schema','2-3',0,'5140'),(346144,110474,'117368','furniture','text','##NEW_CUSTOMER##',0,''),(346145,110474,'117368','furniture','font-size','18',0,''),(346146,110474,'117368','furniture','font-family','$font-1',0,''),(346147,110474,'117368','furniture','text-align','center',0,''),(346148,110474,'117368','furniture','text-transform','uppercase',0,''),(346149,110474,'117368','furniture','margin-bottom','10',0,''),(346150,110475,'117369','furniture','text-align','center',0,''),(346151,110476,'117370','furniture','text-align','center',0,''),(346152,110476,'117370','furniture','margin-bottom','40',0,''),(346153,110477,'117371','furniture','text','##TEXT_OR##',0,''),(346154,110477,'117371','furniture','font-size','18',0,''),(346155,110477,'117371','furniture','font-weight','700',0,''),(346156,110477,'117371','furniture','text-align','center',0,''),(346157,110477,'117371','furniture','content','\\_',0,'3'),(346158,110477,'117371','furniture','height','5',0,'3'),(346159,110477,'117371','furniture','width','70',0,'3'),(346160,110477,'117371','furniture','display','inline-block',0,'3'),(346161,110477,'117371','furniture','border-top-width','1',0,'3'),(346162,110477,'117371','furniture','border-top-color','$content-border-1',0,'3'),(346163,110477,'117371','furniture','margin-left','10',0,'3'),(346164,110477,'117371','furniture','margin-right','10',0,'3'),(346165,110477,'117371','furniture','content','\\_',0,'4'),(346166,110477,'117371','furniture','display','inline-block',0,'4'),(346167,110477,'117371','furniture','width','70',0,'4'),(346168,110477,'117371','furniture','height','5',0,'4'),(346169,110477,'117371','furniture','border-top-width','1',0,'4'),(346170,110477,'117371','furniture','border-top-color','$content-border-1',0,'4'),(346171,110477,'117371','furniture','margin-left','10',0,'4'),(346172,110477,'117371','furniture','margin-right','10',0,'4'),(346173,110477,'117371','furniture','position','relative',0,''),(346174,110477,'117371','furniture','padding-top','10',0,''),(346175,110477,'117371','furniture','padding-bottom','10',0,''),(346176,110478,'117372','furniture','block_type','1',0,''),(346177,110479,'117373','furniture','text','##LOGIN_WITH_SOCIAL##',0,''),(346178,110479,'117373','furniture','font-size','18',0,''),(346179,110479,'117373','furniture','font-family','$font-1',0,''),(346180,110479,'117373','furniture','padding-top','15',0,''),(346181,110479,'117373','furniture','padding-bottom','15',0,''),(346182,110479,'117373','furniture','text-align','center',0,''),(346183,110479,'117373','furniture','text-transform','uppercase',0,''),(346184,110480,'117374','furniture','text-align','center',0,''),(346185,110480,'117374','furniture','hide_parents','2',0,''),(346186,110481,'117375','furniture','text','##RETURNING_CUSTOMER##',0,''),(346187,110481,'117375','furniture','font-size','18',0,''),(346188,110481,'117375','furniture','font-family','$font-1',0,''),(346189,110481,'117375','furniture','text-transform','uppercase',0,''),(346190,110481,'117375','furniture','text-align','center',0,''),(346191,110482,'117376','furniture','max-width','230',0,''),(346192,110482,'117376','furniture','margin_left_measure','auto',0,''),(346193,110482,'117376','furniture','margin_right_measure','auto',0,''),(346194,110483,'117377','furniture','block_type','1',0,''),(346195,110484,'117378','furniture','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(346196,110484,'117378','furniture','margin-bottom','30',0,''),(346197,110485,'117379','furniture','block_type','1',0,''),(346198,110486,'117380','furniture','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(346199,110486,'117380','furniture','margin-bottom','30',0,''),(346200,110487,'1683019393.8433','furniture','block_type','1',0,''),(346201,110487,'1683019393.8433','furniture','style_class','mainBanner',0,''),(346202,110488,'1683018455.4659','furniture','banners_type','single',0,''),(346203,110488,'1683018455.4659','furniture','banners_group','3',0,''),(346204,110488,'1683018455.4659','furniture','ban_id','136',0,''),(346205,110490,'1705058746.79624','furniture','block_type','1',0,''),(346206,110490,'1705058746.79624','furniture','font-weight','normal',0,''),(346207,110491,'1705058746.808883','furniture','block_type','1',0,''),(346208,110491,'1705058746.808883','furniture','style_class','lowestPricedBox',0,''),(346209,110492,'1705058746.898727','furniture','banners_group','21',0,''),(346210,110492,'1705058746.898727','furniture','banners_type','banner',0,''),(346211,110492,'1705058746.898727','furniture','template','1',0,''),(346212,110493,'1705058747.047682','furniture','block_type','3',0,''),(346213,110493,'1705058747.047682','furniture','style_class','tripleBanner',0,''),(346214,110494,'1705058747.07661','furniture','text','<div>Returns and Exchanges</div>\n<div>30 Day Satisfaction Guarantee</div>\n',0,''),(346215,110494,'1705058747.07661','furniture','style_class','returns',0,''),(346216,110495,'1705058747.089734','furniture','text','<div>Warranty</div>\n<div>Min 12 months manufacturer’s warranty</div>',0,''),(346217,110495,'1705058747.089734','furniture','style_class','warranty',0,''),(346218,110496,'1705058747.092420','furniture','text','<div>Track your order</div>\n<div>Check the current status of your order</div>',0,''),(346219,110496,'1705058747.092420','furniture','style_class','track',0,''),(346220,110497,'1705058747.094689','furniture','block_type','1',0,''),(346221,110498,'1705058747.096170','furniture','col_in_row','4',0,''),(346222,110498,'1705058747.096170','furniture','view_as','carousel',0,''),(346223,110498,'1705058747.096170','furniture','show_attributes','1',0,''),(346224,110498,'1705058747.096170','furniture','col_in_row','3',0,'5140'),(346225,110498,'1705058747.096170','furniture','col_in_row','2',0,'5131'),(346226,110498,'1705058747.096170','furniture','col_in_row','1',0,'5161'),(346227,110498,'1705058747.096170','furniture','listing_type','productListing',0,''),(346228,110498,'1705058747.096170','furniture','show_qty_input','1',0,''),(346229,110498,'1705058747.096170','furniture','show_compare','1',0,''),(346230,110498,'1705058747.096170','furniture','lazy_load','1',0,''),(346231,110498,'1705058747.096170','furniture','show_model','1',0,''),(346232,110498,'1705058747.096170','furniture','show_properties','1',0,''),(346233,110498,'1705058747.096170','furniture','show_bonus_points','1',0,''),(346234,110498,'1705058747.096170','furniture','show_buy_button','1',0,''),(346235,110498,'1705058747.096170','furniture','show_view_button','1',0,''),(346236,110498,'1705058747.096170','furniture','show_wishlist_button','1',0,''),(346237,110498,'1705058747.096170','furniture','hide_parents','2',0,''),(346238,110499,'1705058747.101394','furniture','text','<h2>Furniture deals</h2>',0,''),(346239,110500,'1705058747.103997','furniture','block_type','1',0,''),(346240,110500,'1705058747.103997','furniture','style_class','shopByCollectionBox',0,''),(346241,110500,'1705058747.103997','furniture','padding-bottom','30',0,''),(346242,110501,'1705058747.131252','furniture','banners_group','11',0,''),(346243,110501,'1705058747.131252','furniture','banners_type','banner',0,''),(346244,110501,'1705058747.131252','furniture','template','1',0,''),(346245,110502,'1705058747.202374','furniture','text','<h2>Shop by collection</h2> ',0,''),(346246,110504,'117394','furniture','block_type','1',0,''),(346247,110505,'117395','furniture','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(346248,110507,'117397','furniture','block_type','1',0,''),(346249,110507,'117397','furniture','padding-top','40',0,''),(346250,110507,'117397','furniture','padding-bottom','80',0,''),(346251,110508,'117398','furniture','block_type','6',0,''),(346252,110509,'117399','furniture','block_type','1',0,''),(346253,110509,'117399','furniture','padding-top','20',0,''),(346254,110509,'117399','furniture','padding-left','20',0,''),(346255,110509,'117399','furniture','padding-right','20',0,''),(346256,110509,'117399','furniture','padding-bottom','20',0,''),(346257,110509,'117399','furniture','border-top-width','1',0,''),(346258,110509,'117399','furniture','border-left-width','1',0,''),(346259,110509,'117399','furniture','border-right-width','1',0,''),(346260,110509,'117399','furniture','border-bottom-width','1',0,''),(346261,110509,'117399','furniture','border-top-color','$content-border-1',0,''),(346262,110509,'117399','furniture','border-left-color','$content-border-1',0,''),(346263,110509,'117399','furniture','border-right-color','$content-border-1',0,''),(346264,110509,'117399','furniture','border-bottom-color','$content-border-1',0,''),(346265,110509,'117399','furniture','margin-right','20',0,''),(346266,110512,'117402','furniture','block_type','1',0,''),(346267,110512,'117402','furniture','padding-top','20',0,''),(346268,110513,'117403','furniture','block_type','6',0,''),(346269,110514,'117404','furniture','padding-right','20',0,''),(346270,110516,'117406','furniture','block_type','1',0,''),(346271,110516,'117406','furniture','padding-top','20',0,''),(346272,110517,'117407','furniture','block_type','6',0,''),(346273,110518,'117408','furniture','padding-right','20',0,''),(346274,110520,'117410','furniture','block_type','1',0,''),(346275,110520,'117410','furniture','style_class','account-password-wrap',0,''),(346276,110521,'117411','furniture','block_type','6',0,''),(346277,110521,'117411','furniture','schema','6-3',0,'5140'),(346278,110522,'117412','furniture','aria_name','account-menu',0,''),(346336,110543,'117414','furniture','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(346337,110544,'117415','furniture','block_type','1',0,''),(346338,110544,'117415','furniture','padding-top','20',0,''),(346339,110545,'117416','furniture','tab_1','RETURNING CUSTOMER',1,''),(346340,110545,'117416','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(346341,110545,'117416','furniture','tab_1','RETURNING CUSTOMER',2,''),(346342,110545,'117416','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(346343,110545,'117416','furniture','tab_1','RETURNING CUSTOMER',3,''),(346344,110545,'117416','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(346345,110545,'117416','furniture','tab_1','RETURNING CUSTOMER',4,''),(346346,110545,'117416','furniture','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(346347,110546,'117417','furniture','max-width','800',0,''),(346348,110546,'117417','furniture','margin_left_measure','auto',0,''),(346349,110546,'117417','furniture','margin_right_measure','auto',0,''),(346350,110547,'117418','furniture','block_type','8',0,''),(346351,110548,'117419','furniture','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(346352,110549,'117420','furniture','block_type','1',0,''),(346353,110549,'117420','furniture','padding-left','20',0,''),(346354,110549,'117420','furniture','padding-right','20',0,''),(346355,110551,'117422','furniture','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(346356,110552,'117423','furniture','block_type','1',0,''),(346357,110553,'117424','furniture','block_type','1',0,''),(346358,110554,'117425','furniture','margin-left','0',0,''),(346359,110554,'117425','furniture','margin-right','0',0,''),(346360,110554,'117425','furniture','margin-bottom','20',0,''),(346361,110555,'117426','furniture','margin-bottom','30',0,''),(346362,110556,'117427','furniture','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(346363,110557,'117428','furniture','block_type','1',0,''),(346364,110559,'117430','furniture','block_type','6',0,''),(346365,110559,'117430','furniture','font-weight','400',0,''),(346366,110559,'117430','furniture','schema','6-2',0,'5161'),(346367,110559,'117430','furniture','schema','6-2',0,'5140'),(346368,110560,'117431','furniture','font-weight','400',0,''),(346369,110560,'117431','furniture','padding-right','40',0,''),(346370,110560,'117431','furniture','padding-right','0',0,'5161'),(346371,110560,'117431','furniture','padding-right','0',0,'5140'),(346372,110561,'117432','furniture','col_in_row','3',0,''),(346373,110561,'117432','furniture','products_align','left',0,''),(346374,110561,'117432','furniture','font-weight','400',0,''),(346375,110561,'117432','furniture','show_qty_input','0',0,''),(346376,110561,'117432','furniture','listing_type','productListing',0,''),(346377,110561,'117432','furniture','listing_type_rows','no',0,''),(346378,110561,'117432','furniture','show_buy_button_b2b','on',0,''),(346379,110561,'117432','furniture','show_wishlist_button_b2b','1',0,''),(346380,110561,'117432','furniture','show_compare_b2b','1',0,''),(346381,110561,'117432','furniture','show_stock','0',0,''),(346382,110561,'117432','furniture','show_description','0',0,''),(346383,110561,'117432','furniture','show_model','0',0,''),(346384,110561,'117432','furniture','show_properties','0',0,''),(346385,110561,'117432','furniture','show_rating','0',0,''),(346386,110561,'117432','furniture','show_rating_counts','0',0,''),(346387,110561,'117432','furniture','show_price','0',0,''),(346388,110561,'117432','furniture','show_buy_button','0',0,''),(346389,110561,'117432','furniture','show_view_button','0',0,''),(346390,110561,'117432','furniture','show_wishlist_button','0',0,''),(346391,110561,'117432','furniture','show_compare','0',0,''),(346392,110561,'117432','furniture','show_name_rows','0',0,''),(346393,110561,'117432','furniture','show_image_rows','0',0,''),(346394,110561,'117432','furniture','show_stock_rows','0',0,''),(346395,110561,'117432','furniture','show_description_rows','0',0,''),(346396,110561,'117432','furniture','show_model_rows','0',0,''),(346397,110561,'117432','furniture','show_properties_rows','0',0,''),(346398,110561,'117432','furniture','show_rating_rows','0',0,''),(346399,110561,'117432','furniture','show_rating_counts_rows','0',0,''),(346400,110561,'117432','furniture','show_price_rows','0',0,''),(346401,110561,'117432','furniture','show_buy_button_rows','0',0,''),(346402,110561,'117432','furniture','show_qty_input_rows','0',0,''),(346403,110561,'117432','furniture','show_view_button_rows','0',0,''),(346404,110561,'117432','furniture','show_wishlist_button_rows','0',0,''),(346405,110561,'117432','furniture','show_compare_rows','0',0,''),(346406,110561,'117432','furniture','show_name_b2b','0',0,''),(346407,110561,'117432','furniture','show_image_b2b','0',0,''),(346408,110561,'117432','furniture','show_stock_b2b','0',0,''),(346409,110561,'117432','furniture','show_description_b2b','0',0,''),(346410,110561,'117432','furniture','show_model_b2b','0',0,''),(346411,110561,'117432','furniture','show_properties_b2b','0',0,''),(346412,110561,'117432','furniture','show_rating_b2b','0',0,''),(346413,110561,'117432','furniture','show_rating_counts_b2b','0',0,''),(346414,110561,'117432','furniture','show_price_b2b','0',0,''),(346415,110561,'117432','furniture','show_qty_input_b2b','0',0,''),(346416,110561,'117432','furniture','show_view_button_b2b','0',0,''),(346417,110561,'117432','furniture','show_attributes_b2b','0',0,''),(346418,110561,'117432','furniture','items_on_page','9',0,''),(346419,110561,'117432','furniture','col_in_row','2',0,'5140'),(346420,110561,'117432','furniture','col_in_row','1',0,'5161'),(346421,110561,'117432','furniture','product_names_teg','h2',0,''),(346422,110563,'117434','furniture','block_type','5',0,''),(346423,110563,'117434','furniture','padding-top','10',0,''),(346424,110563,'117434','furniture','padding-bottom','10',0,''),(346425,110563,'117434','furniture','schema','5-2',0,'5161'),(346426,110563,'117434','furniture','border-top-color','$content-border-1',0,''),(346427,110563,'117434','furniture','border-top-width','1',0,''),(346428,110565,'117436','furniture','float','right',0,''),(346429,110566,'117437','furniture','listing_type','productListing',0,''),(346430,110568,'117439','furniture','block_type','1',0,''),(346431,110568,'117439','furniture','padding-top','10',0,''),(346432,110568,'117439','furniture','padding-bottom','10',0,''),(346433,110568,'117439','furniture','border-bottom-width','1',0,''),(346434,110568,'117439','furniture','border-bottom-color','$content-border-1',0,''),(346435,110568,'117439','furniture','margin-left','0',0,''),(346436,110568,'117439','furniture','margin-right','0',0,''),(346437,110569,'117440','furniture','float','right',0,''),(346438,110569,'117440','furniture','display','none',0,'5161'),(346439,110570,'117441','furniture','float','left',0,''),(346440,110570,'117441','furniture','clear','none',0,''),(346441,110570,'117441','furniture','margin-left','20',0,''),(346442,110570,'117441','furniture','display','none',0,'5161'),(346443,110571,'117442','furniture','margin-right','20',0,''),(346444,110571,'117442','furniture','float','right',0,''),(346445,110571,'117442','furniture','clear','none',0,''),(346446,110571,'117442','furniture','display','none',0,'5140'),(346447,110572,'117443','furniture','float','left',0,''),(346448,110572,'117443','furniture','clear','none',0,''),(346449,110572,'117443','furniture','sort_pos_3','1',0,''),(346450,110572,'117443','furniture','sort_pos_4','2',0,''),(346451,110572,'117443','furniture','sort_pos_10','3',0,''),(346452,110572,'117443','furniture','sort_pos_9','4',0,''),(346453,110572,'117443','furniture','sort_pos_11','5',0,''),(346454,110572,'117443','furniture','sort_pos_12','6',0,''),(346455,110572,'117443','furniture','sort_pos_14','7',0,''),(346456,110572,'117443','furniture','sort_pos_13','8',0,''),(346457,110572,'117443','furniture','sort_pos_8','9',0,''),(346458,110572,'117443','furniture','sort_pos_7','10',0,''),(346459,110572,'117443','furniture','sort_pos_2','11',0,''),(346460,110572,'117443','furniture','sort_pos_1','12',0,''),(346461,110572,'117443','furniture','sort_pos_6','13',0,''),(346462,110572,'117443','furniture','sort_pos_5','14',0,''),(346463,110572,'117443','furniture','sort_pos_0','15',0,''),(346464,110572,'117443','furniture','sort_hide_10','1',0,''),(346465,110572,'117443','furniture','sort_hide_9','1',0,''),(346466,110572,'117443','furniture','hide_icons','1',0,''),(346467,110572,'117443','furniture','sort_hide_16','1',0,''),(346468,110572,'117443','furniture','sort_hide_15','1',0,''),(346469,110572,'117443','furniture','sort_hide_3','0',0,''),(346470,110572,'117443','furniture','sort_hide_4','0',0,''),(346471,110572,'117443','furniture','sort_hide_11','1',0,''),(346472,110572,'117443','furniture','sort_hide_12','1',0,''),(346473,110572,'117443','furniture','sort_hide_14','1',0,''),(346474,110572,'117443','furniture','sort_hide_13','1',0,''),(346475,110572,'117443','furniture','sort_hide_8','0',0,''),(346476,110572,'117443','furniture','sort_hide_7','0',0,''),(346477,110572,'117443','furniture','sort_hide_2','1',0,''),(346478,110572,'117443','furniture','sort_hide_1','1',0,''),(346479,110572,'117443','furniture','sort_hide_6','1',0,''),(346480,110572,'117443','furniture','sort_hide_5','1',0,''),(346481,110572,'117443','furniture','sort_hide_0','1',0,''),(346482,110573,'117444','furniture','block_type','1',0,''),(346483,110574,'117445','furniture','margin-bottom','30',0,''),(346484,110575,'117446','furniture','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(346485,110576,'117447','furniture','block_type','1',0,''),(346486,110577,'117448','furniture','block_type','5',0,''),(346487,110577,'117448','furniture','padding-top','10',0,''),(346488,110577,'117448','furniture','padding-bottom','10',0,''),(346489,110577,'117448','furniture','schema','5-2',0,'5161'),(346490,110577,'117448','furniture','border-top-color','$content-border-1',0,''),(346491,110577,'117448','furniture','border-top-width','1',0,''),(346492,110578,'117449','furniture','padding-top','3',0,''),(346493,110579,'117450','furniture','float','right',0,''),(346494,110579,'117450','furniture','height','31',0,''),(346495,110580,'117451','furniture','col_in_row','4',0,''),(346496,110580,'117451','furniture','products_align','left',0,''),(346497,110580,'117451','furniture','font-weight','400',0,''),(346498,110580,'117451','furniture','listing_type','productListing',0,''),(346499,110580,'117451','furniture','listing_type_rows','Rows',0,''),(346500,110580,'117451','furniture','show_buy_button_b2b','on',0,''),(346501,110580,'117451','furniture','show_wishlist_button_b2b','1',0,''),(346502,110580,'117451','furniture','show_compare_b2b','1',0,''),(346503,110580,'117451','furniture','listing_type_b2b','b2b',0,''),(346504,110580,'117451','furniture','show_image','0',0,''),(346505,110580,'117451','furniture','show_stock','0',0,''),(346506,110580,'117451','furniture','show_description','0',0,''),(346507,110580,'117451','furniture','show_model','0',0,''),(346508,110580,'117451','furniture','show_properties','0',0,''),(346509,110580,'117451','furniture','show_rating','0',0,''),(346510,110580,'117451','furniture','show_rating_counts','0',0,''),(346511,110580,'117451','furniture','show_price','0',0,''),(346512,110580,'117451','furniture','show_buy_button','0',0,''),(346513,110580,'117451','furniture','show_view_button','0',0,''),(346514,110580,'117451','furniture','show_wishlist_button','0',0,''),(346515,110580,'117451','furniture','show_compare','0',0,''),(346516,110580,'117451','furniture','show_name_rows','0',0,''),(346517,110580,'117451','furniture','show_image_rows','0',0,''),(346518,110580,'117451','furniture','show_stock_rows','0',0,''),(346519,110580,'117451','furniture','show_description_rows','0',0,''),(346520,110580,'117451','furniture','show_model_rows','0',0,''),(346521,110580,'117451','furniture','show_properties_rows','0',0,''),(346522,110580,'117451','furniture','show_rating_rows','0',0,''),(346523,110580,'117451','furniture','show_rating_counts_rows','0',0,''),(346524,110580,'117451','furniture','show_price_rows','0',0,''),(346525,110580,'117451','furniture','show_buy_button_rows','0',0,''),(346526,110580,'117451','furniture','show_qty_input_rows','0',0,''),(346527,110580,'117451','furniture','show_view_button_rows','0',0,''),(346528,110580,'117451','furniture','show_wishlist_button_rows','0',0,''),(346529,110580,'117451','furniture','show_compare_rows','0',0,''),(346530,110580,'117451','furniture','show_name_b2b','0',0,''),(346531,110580,'117451','furniture','show_image_b2b','0',0,''),(346532,110580,'117451','furniture','show_stock_b2b','0',0,''),(346533,110580,'117451','furniture','show_description_b2b','0',0,''),(346534,110580,'117451','furniture','show_model_b2b','0',0,''),(346535,110580,'117451','furniture','show_properties_b2b','0',0,''),(346536,110580,'117451','furniture','show_rating_b2b','0',0,''),(346537,110580,'117451','furniture','show_rating_counts_b2b','0',0,''),(346538,110580,'117451','furniture','show_price_b2b','0',0,''),(346539,110580,'117451','furniture','show_qty_input_b2b','0',0,''),(346540,110580,'117451','furniture','show_view_button_b2b','0',0,''),(346541,110580,'117451','furniture','show_attributes_b2b','0',0,''),(346542,110580,'117451','furniture','items_on_page','12',0,''),(346543,110580,'117451','furniture','col_in_row','2',0,'5140'),(346544,110580,'117451','furniture','col_in_row','1',0,'5161'),(346545,110580,'117451','furniture','product_names_teg','h2',0,''),(346546,110583,'117454','furniture','block_type','1',0,''),(346547,110584,'117455','furniture','block_type','1',0,''),(346548,110584,'117455','furniture','padding-top','10',0,''),(346549,110584,'117455','furniture','padding-bottom','10',0,''),(346550,110584,'117455','furniture','border-bottom-width','1',0,''),(346551,110584,'117455','furniture','border-bottom-color','$content-border-1',0,''),(346552,110584,'117455','furniture','margin-left','0',0,''),(346553,110584,'117455','furniture','margin-right','0',0,''),(346554,110585,'117456','furniture','clear','none',0,''),(346555,110585,'117456','furniture','float','left',0,''),(346556,110585,'117456','furniture','padding-top','3',0,''),(346557,110585,'117456','furniture','margin-left','20',0,''),(346558,110586,'117457','furniture','float','right',0,''),(346559,110586,'117457','furniture','display','none',0,'5161'),(346560,110587,'117458','furniture','margin-right','20',0,''),(346561,110587,'117458','furniture','float','right',0,''),(346562,110587,'117458','furniture','clear','none',0,''),(346563,110587,'117458','furniture','display','none',0,'5140'),(346564,110588,'117459','furniture','float','left',0,''),(346565,110588,'117459','furniture','clear','none',0,''),(346566,110588,'117459','furniture','margin-left','20',0,''),(346567,110588,'117459','furniture','display','none',0,'5161'),(346568,110589,'117460','furniture','float','left',0,''),(346569,110589,'117460','furniture','clear','none',0,''),(346570,110589,'117460','furniture','sort_pos_3','2',0,''),(346571,110589,'117460','furniture','sort_pos_4','3',0,''),(346572,110589,'117460','furniture','sort_pos_10','11',0,''),(346573,110589,'117460','furniture','sort_pos_9','10',0,''),(346574,110589,'117460','furniture','sort_pos_11','12',0,''),(346575,110589,'117460','furniture','sort_pos_12','13',0,''),(346576,110589,'117460','furniture','sort_pos_14','15',0,''),(346577,110589,'117460','furniture','sort_pos_13','14',0,''),(346578,110589,'117460','furniture','sort_pos_8','4',0,''),(346579,110589,'117460','furniture','sort_pos_7','5',0,''),(346580,110589,'117460','furniture','sort_pos_2','7',0,''),(346581,110589,'117460','furniture','sort_pos_1','6',0,''),(346582,110589,'117460','furniture','sort_pos_6','9',0,''),(346583,110589,'117460','furniture','sort_pos_5','8',0,''),(346584,110589,'117460','furniture','sort_pos_0','1',0,''),(346585,110589,'117460','furniture','sort_hide_10','1',0,''),(346586,110589,'117460','furniture','sort_hide_9','1',0,''),(346587,110589,'117460','furniture','sort_pos_15','16',0,''),(346588,110589,'117460','furniture','sort_pos_16','17',0,''),(346589,110589,'117460','furniture','sort_hide_4','0',0,''),(346590,110589,'117460','furniture','sort_hide_3','0',0,''),(346591,110589,'117460','furniture','sort_hide_16','1',0,''),(346592,110589,'117460','furniture','sort_hide_15','1',0,''),(346593,110589,'117460','furniture','sort_hide_11','1',0,''),(346594,110589,'117460','furniture','sort_hide_12','1',0,''),(346595,110589,'117460','furniture','sort_hide_14','1',0,''),(346596,110589,'117460','furniture','sort_hide_13','1',0,''),(346597,110589,'117460','furniture','sort_hide_8','0',0,''),(346598,110589,'117460','furniture','sort_hide_7','0',0,''),(346599,110589,'117460','furniture','sort_hide_2','1',0,''),(346600,110589,'117460','furniture','sort_hide_1','1',0,''),(346601,110589,'117460','furniture','sort_hide_6','1',0,''),(346602,110589,'117460','furniture','sort_hide_5','1',0,''),(346603,110589,'117460','furniture','sort_hide_0','0',0,''),(346604,110589,'117460','furniture','hide_icons','1',0,''),(346605,110590,'117461','furniture','margin-bottom','20',0,''),(346606,110591,'117462','furniture','block_type','1',0,''),(346607,110591,'117462','furniture','style_class','account-order-history',0,''),(346674,110615,'117467','furniture','block_type','1',0,''),(346675,110615,'117467','furniture','style_class','account-order-history-info',0,''),(346806,110674,'117507','furniture','block_type','1',0,''),(346807,110674,'117507','furniture','style_class','account-order-pay',0,''),(346808,110675,'117508','furniture','block_type','6',0,''),(346809,110675,'117508','furniture','schema','6-3',0,'5140'),(346810,110676,'117509','furniture','aria_name','account-menu',0,''),(346868,110697,'117511','furniture','block_type','3',0,''),(346869,110698,'117512','furniture','block_type','1',0,''),(346870,110698,'117512','furniture','padding-right','20',0,''),(346871,110698,'117512','furniture','padding-bottom','20',0,''),(346872,110699,'117513','furniture','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(346873,110700,'117514','furniture','orders_data','name',0,''),(346874,110700,'117514','furniture','padding-left','30',0,''),(346875,110701,'117515','furniture','block_type','1',0,''),(346876,110702,'117516','furniture','padding-left','30',0,''),(346877,110703,'117517','furniture','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(346878,110704,'117518','furniture','block_type','1',0,''),(346879,110704,'117518','furniture','padding-right','20',0,''),(346880,110704,'117518','furniture','padding-bottom','20',0,''),(346881,110705,'117519','furniture','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(346882,110706,'117520','furniture','orders_data','delivery_address',0,''),(346883,110706,'117520','furniture','padding-left','30',0,''),(346884,110707,'117521','furniture','block_type','1',0,''),(346885,110707,'117521','furniture','padding-right','20',0,''),(346886,110708,'117522','furniture','orders_data','shipping_method',0,''),(346887,110708,'117522','furniture','padding-left','30',0,''),(346888,110709,'117523','furniture','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(346889,110710,'117524','furniture','block_type','1',0,''),(346890,110711,'117525','furniture','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(346891,110712,'117526','furniture','orders_data','payment_method',0,''),(346892,110712,'117526','furniture','padding-left','30',0,''),(346893,110713,'117527','furniture','block_type','1',0,''),(346894,110713,'117527','furniture','padding-bottom','20',0,''),(346895,110714,'117528','furniture','orders_data','billing_address',0,''),(346896,110714,'117528','furniture','padding-left','30',0,''),(346897,110715,'117529','furniture','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(346898,110716,'117530','furniture','margin-bottom','20',0,''),(346899,110716,'117530','furniture','orders_data','name',0,''),(346900,110717,'117531','furniture','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(346901,110720,'117534','furniture','width','680',0,''),(346902,110720,'117534','furniture','font-weight','400',0,''),(346903,110720,'117534','furniture','font-size','12',0,''),(346904,110720,'117534','furniture','padding-top','20',0,''),(346905,110720,'117534','furniture','padding-bottom','20',0,''),(346906,110721,'117535','furniture','block_type','2',0,''),(346907,110721,'117535','furniture','font-weight','normal',0,''),(346908,110721,'117535','furniture','padding-bottom','20',0,''),(346909,110722,'117536','furniture','font-weight','400',0,''),(346910,110722,'117536','furniture','text-align','center',0,''),(346911,110722,'117536','furniture','padding-top','10',0,''),(346916,110723,'117537','furniture','block_type','11',0,''),(346917,110723,'117537','furniture','font-weight','normal',0,''),(346918,110724,'117538','furniture','text','<p>Email:</p>',1,''),(346919,110724,'117538','furniture','font-weight','normal',0,''),(346920,110724,'117538','furniture','text-align','right',0,''),(346921,110724,'117538','furniture','text','<p>Email:</p>',2,''),(346922,110724,'117538','furniture','text','<p>Email:</p>',3,''),(346923,110724,'117538','furniture','text','<p>Email:</p>',4,''),(346924,110725,'117539','furniture','font-weight','normal',0,''),(346925,110725,'117539','furniture','text-align','right',0,''),(346926,110726,'117540','furniture','block_type','11',0,''),(346927,110726,'117540','furniture','font-weight','normal',0,''),(346928,110727,'117541','furniture','text','<p>Phone:</p>',1,''),(346929,110727,'117541','furniture','font-weight','normal',0,''),(346930,110727,'117541','furniture','text-align','right',0,''),(346931,110727,'117541','furniture','text','<p>Phone:</p>',2,''),(346932,110727,'117541','furniture','text','<p>Phone:</p>',3,''),(346933,110727,'117541','furniture','text','<p>Phone:</p>',4,''),(346934,110728,'117542','furniture','font-weight','normal',0,''),(346935,110728,'117542','furniture','text-align','right',0,''),(346936,110729,'117543','furniture','block_type','1',0,''),(346937,110730,'117544','furniture','font-weight','400',0,''),(346938,110730,'117544','furniture','text-align','right',0,''),(346939,110730,'117544','furniture','padding-bottom','10',0,''),(346940,110730,'117544','furniture','address_spacer',',',0,''),(346941,110730,'117544','furniture','font-size','12',0,''),(346942,110731,'117545','furniture','block_type','11',0,''),(346943,110731,'117545','furniture','font-weight','400',0,''),(346944,110732,'117546','furniture','text','<p>Web:</p>',1,''),(346945,110732,'117546','furniture','font-weight','400',0,''),(346946,110732,'117546','furniture','text-align','right',0,''),(346947,110732,'117546','furniture','text','<p>Web:</p>',2,''),(346948,110732,'117546','furniture','text','<p>Web:</p>',3,''),(346949,110732,'117546','furniture','text','<p>Web:</p>',4,''),(346950,110733,'117547','furniture','font-weight','normal',0,''),(346951,110733,'117547','furniture','text-align','right',0,''),(346952,110734,'117548','furniture','font-weight','normal',0,''),(346953,110734,'117548','furniture','padding-top','20',0,''),(346954,110734,'117548','furniture','font-size','12',0,''),(346955,110735,'117549','furniture','block_type','1',0,''),(346956,110735,'117549','furniture','font-weight','normal',0,''),(346957,110735,'117549','furniture','padding-top','10',0,''),(346958,110735,'117549','furniture','padding-bottom','10',0,''),(346959,110737,'117551','furniture','text','<p>If undelivered please return to:</p>',1,''),(346960,110737,'117551','furniture','font-weight','bold',0,''),(346961,110737,'117551','furniture','text','<p>If undelivered please return to:</p>',2,''),(346962,110737,'117551','furniture','text','<p>If undelivered please return to:</p>',3,''),(346963,110737,'117551','furniture','text','<p>If undelivered please return to:</p>',4,''),(346964,110738,'117552','furniture','block_type','4',0,''),(346965,110738,'117552','furniture','font-weight','400',0,''),(346966,110738,'117552','furniture','border-top-width','1',0,''),(346967,110738,'117552','furniture','border-top-color','$content-border-1',0,''),(346968,110738,'117552','furniture','border-left-width','1',0,''),(346969,110738,'117552','furniture','border-left-color','$content-border-1',0,''),(346970,110738,'117552','furniture','border-right-width','1',0,''),(346971,110738,'117552','furniture','border-right-color','$content-border-1',0,''),(346972,110738,'117552','furniture','border-bottom-width','1',0,''),(346973,110738,'117552','furniture','border-bottom-color','$content-border-1',0,''),(346974,110739,'117553','furniture','block_type','2',0,''),(346975,110739,'117553','furniture','font-weight','normal',0,''),(346976,110739,'117553','furniture','border-right-width','1',0,''),(346977,110739,'117553','furniture','border-right-color','$content-border-1',0,''),(346978,110740,'117554','furniture','block_type','1',0,''),(346979,110740,'117554','furniture','font-weight','normal',0,''),(346980,110740,'117554','furniture','border-right-width','1',0,''),(346981,110740,'117554','furniture','border-right-color','$content-border-1',0,''),(346982,110740,'117554','furniture','background-color','$content-bg-2',0,''),(346983,110740,'117554','furniture','padding-top','10',0,''),(346984,110740,'117554','furniture','padding-left','10',0,''),(346985,110740,'117554','furniture','padding-right','10',0,''),(346986,110740,'117554','furniture','padding-bottom','10',0,''),(346987,110741,'117555','furniture','font-size','12',0,''),(346988,110741,'117555','furniture','font-weight','normal',0,''),(346989,110742,'117556','furniture','text','<p>SHIPPING ADDRESS:</p>',1,''),(346990,110742,'117556','furniture','font-size','13',0,''),(346991,110742,'117556','furniture','font-weight','bold',0,''),(346992,110742,'117556','furniture','padding-bottom','10',0,''),(346993,110742,'117556','furniture','text','<p>SHIPPING ADDRESS:</p>',2,''),(346994,110742,'117556','furniture','text','<p>SHIPPING ADDRESS:</p>',3,''),(346995,110742,'117556','furniture','text','<p>SHIPPING ADDRESS:</p>',4,''),(346996,110743,'117557','furniture','block_type','1',0,''),(346997,110743,'117557','furniture','font-weight','normal',0,''),(346998,110743,'117557','furniture','padding-top','10',0,''),(346999,110743,'117557','furniture','padding-left','10',0,''),(347000,110743,'117557','furniture','padding-right','10',0,''),(347001,110743,'117557','furniture','padding-bottom','10',0,''),(347002,110744,'117558','furniture','text','<p>CUSTOMER:</p>',1,''),(347003,110744,'117558','furniture','font-size','13',0,''),(347004,110744,'117558','furniture','font-weight','bold',0,''),(347005,110744,'117558','furniture','text','<p>CUSTOMER:</p>',2,''),(347006,110744,'117558','furniture','text','<p>CUSTOMER:</p>',3,''),(347007,110744,'117558','furniture','text','<p>CUSTOMER:</p>',4,''),(347008,110745,'117559','furniture','font-size','12',0,''),(347009,110747,'117561','furniture','text','<p>PHONE NUMBER:</p>',1,''),(347010,110747,'117561','furniture','font-size','13',0,''),(347011,110747,'117561','furniture','font-weight','bold',0,''),(347012,110747,'117561','furniture','padding-top','10',0,''),(347013,110747,'117561','furniture','text','<p>PHONE NUMBER:</p>',2,''),(347014,110747,'117561','furniture','text','<p>PHONE NUMBER:</p>',3,''),(347015,110747,'117561','furniture','text','<p>PHONE NUMBER:</p>',4,''),(347016,110748,'117562','furniture','font-size','12',0,''),(347017,110749,'117563','furniture','text','<p>E-MAIL ADDRESS:</p>',1,''),(347018,110749,'117563','furniture','font-size','13',0,''),(347019,110749,'117563','furniture','font-weight','bold',0,''),(347020,110749,'117563','furniture','padding-top','10',0,''),(347021,110749,'117563','furniture','text','<p>E-MAIL ADDRESS:</p>',2,''),(347022,110749,'117563','furniture','text','<p>E-MAIL ADDRESS:</p>',3,''),(347023,110749,'117563','furniture','text','<p>E-MAIL ADDRESS:</p>',4,''),(347024,110750,'117564','furniture','block_type','2',0,''),(347025,110750,'117564','furniture','font-weight','normal',0,''),(347026,110750,'117564','furniture','border-right-width','1',0,''),(347027,110750,'117564','furniture','border-right-color','$content-border-1',0,''),(347028,110750,'117564','furniture','border-top-width','1',0,''),(347029,110750,'117564','furniture','border-top-color','$content-border-1',0,''),(347030,110751,'117565','furniture','block_type','1',0,''),(347031,110751,'117565','furniture','font-weight','normal',0,''),(347032,110751,'117565','furniture','padding-top','10',0,''),(347033,110751,'117565','furniture','padding-left','10',0,''),(347034,110751,'117565','furniture','padding-right','10',0,''),(347035,110751,'117565','furniture','padding-bottom','10',0,''),(347036,110751,'117565','furniture','border-right-width','1',0,''),(347037,110751,'117565','furniture','border-right-color','$content-border-1',0,''),(347038,110753,'117567','furniture','text','<p>Shipping via</p>',1,''),(347039,110753,'117567','furniture','font-weight','bold',0,''),(347040,110753,'117567','furniture','text','<p>Shipping via</p>',2,''),(347041,110753,'117567','furniture','text','<p>Shipping via</p>',3,''),(347042,110753,'117567','furniture','text','<p>Shipping via</p>',4,''),(347043,110754,'117568','furniture','block_type','1',0,''),(347044,110754,'117568','furniture','font-weight','normal',0,''),(347045,110754,'117568','furniture','padding-top','10',0,''),(347046,110754,'117568','furniture','padding-left','10',0,''),(347047,110754,'117568','furniture','padding-right','10',0,''),(347048,110754,'117568','furniture','padding-bottom','10',0,''),(347049,110756,'117570','furniture','text','<p>Shipping service</p>',1,''),(347050,110756,'117570','furniture','font-weight','bold',0,''),(347051,110756,'117570','furniture','text','<p>Shipping service</p>',2,''),(347052,110756,'117570','furniture','text','<p>Shipping service</p>',3,''),(347053,110756,'117570','furniture','text','<p>Shipping service</p>',4,''),(347054,110757,'117571','furniture','font-weight','normal',0,''),(347055,110757,'117571','furniture','text-align','center',0,''),(347056,110757,'117571','furniture','padding-top','40',0,''),(347057,110759,'1639661081.5616','furniture','padding-top','15',0,''),(347058,110760,'117572','furniture','block_type','1',0,''),(347059,110761,'117573','furniture','block_type','8',0,''),(347060,110762,'1638807246.6206','furniture','text','<span></span>',0,''),(347061,110763,'117574','furniture','text','##TEXT_MAIN##',0,''),(347062,110763,'117574','furniture','margin-bottom','20',0,''),(347063,110763,'117574','furniture','text-align','center',0,''),(347064,110764,'117575','furniture','margin-bottom','20',0,''),(347065,110765,'117576','furniture','text','<h1>##HEADING_TITLE##</h1>',0,''),(347066,110767,'117578','furniture','block_type','2',0,''),(347067,110768,'117579','furniture','block_type','1',0,''),(347068,110768,'117579','furniture','style_class','product',0,''),(347069,110768,'117579','furniture','padding-right','10',0,''),(347070,110768,'117579','furniture','padding-bottom','20',0,''),(347071,110769,'117580','furniture','block_type','1',0,''),(347072,110770,'117581','furniture','product_element','products_name',0,''),(347073,110770,'117581','furniture','font-family','$font-1',0,''),(347074,110770,'117581','furniture','padding-bottom','10',0,''),(347075,110770,'117581','furniture','font-size','16',0,''),(347076,110771,'117582','furniture','block_type','2',0,''),(347077,110772,'117583','furniture','product_element','image',0,''),(347078,110772,'117583','furniture','padding-right','10',0,''),(347079,110773,'117584','furniture','product_element','products_price_old',0,''),(347080,110773,'117584','furniture','font-family','$font-1',0,''),(347081,110773,'117584','furniture','font-size','14',0,''),(347082,110773,'117584','furniture','text-decoration','line-through',0,''),(347083,110774,'117585','furniture','product_element','products_price',0,''),(347084,110774,'117585','furniture','font-family','$font-1',0,''),(347085,110774,'117585','furniture','font-size','20',0,''),(347086,110774,'117585','furniture','padding-top','20',0,''),(347087,110775,'117586','furniture','block_type','1',0,''),(347088,110775,'117586','furniture','style_class','product',0,''),(347089,110775,'117586','furniture','padding-left','10',0,''),(347090,110775,'117586','furniture','padding-bottom','20',0,''),(347091,110776,'117587','furniture','block_type','2',0,''),(347092,110777,'117588','furniture','product_element','image',0,''),(347093,110777,'117588','furniture','padding-right','10',0,''),(347094,110778,'117589','furniture','font-size','14',0,''),(347095,110778,'117589','furniture','font-family','$font-1',0,''),(347096,110778,'117589','furniture','text-decoration','line-through',0,''),(347097,110778,'117589','furniture','product_element','products_price_old',0,''),(347098,110779,'117590','furniture','product_element','products_price',0,''),(347099,110779,'117590','furniture','font-family','$font-1',0,''),(347100,110779,'117590','furniture','font-size','20',0,''),(347101,110779,'117590','furniture','padding-top','20',0,''),(347102,110780,'117591','furniture','block_type','1',0,''),(347103,110781,'117592','furniture','product_element','products_name',0,''),(347104,110781,'117592','furniture','font-family','$font-1',0,''),(347105,110781,'117592','furniture','font-size','16',0,''),(347106,110781,'117592','furniture','padding-bottom','10',0,''),(347107,110782,'117593','furniture','font-size','30',0,''),(347108,110782,'117593','furniture','font-family','$font-1',0,''),(347109,110782,'117593','furniture','text-align','center',0,''),(347110,110782,'117593','furniture','padding-bottom','50',0,''),(347111,110783,'117594','furniture','padding-bottom','20',0,''),(347112,110783,'117594','furniture','text-align','center',0,''),(347113,110784,'117595','furniture','width','680',0,''),(347114,110785,'117596','furniture','padding-top','200',0,''),(347115,110785,'117596','furniture','padding-left','200',0,''),(347120,110786,'117597','furniture','text','osCommerce 4',1,''),(347121,110786,'117597','furniture','font-family','$font-1',0,''),(347122,110786,'117597','furniture','font-size','40',0,''),(347123,110786,'117597','furniture','padding-top','50',0,''),(347124,110786,'117597','furniture','text-align','center',0,''),(347125,110786,'117597','furniture','text','osCommerce 4',2,''),(347126,110786,'117597','furniture','text','osCommerce 4',3,''),(347127,110786,'117597','furniture','text','osCommerce 4',4,''),(347128,110787,'117598','furniture','block_type','2',0,''),(347129,110787,'117598','furniture','border-top-width','1',0,''),(347130,110787,'117598','furniture','border-top-color','$content-border-1',0,''),(347131,110788,'117599','furniture','text-align','right',0,''),(347132,110788,'117599','furniture','padding-top','15',0,''),(347133,110788,'117599','furniture','padding-bottom','15',0,''),(347134,110788,'117599','furniture','font-size','14',0,''),(347135,110789,'117600','furniture','font-family','$font-1',0,''),(347136,110789,'117600','furniture','text-align','center',0,''),(347137,110789,'117600','furniture','font-size','20',0,''),(347138,110789,'117600','furniture','color','$content-color-1',0,''),(347139,110789,'117600','furniture','border-bottom-width','1',0,''),(347140,110789,'117600','furniture','border-bottom-color','$content-border-1',0,''),(347141,110789,'117600','furniture','padding-top','10',0,''),(347142,110789,'117600','furniture','padding-bottom','10',0,''),(347143,110790,'117601','furniture','block_type','1',0,''),(347144,110791,'117602','furniture','block_type','6',0,''),(347145,110791,'117602','furniture','schema','6-3',0,'5140'),(347146,110792,'117603','furniture','aria_name','account-menu',0,''),(347204,110812,'117604','furniture','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(347205,110813,'117606','furniture','max_items','10',0,''),(347206,110813,'117606','furniture','padding-bottom','20',0,''),(347207,110814,'117607','furniture','block_type','1',0,''),(347208,110814,'117607','furniture','padding-top','20',0,''),(347209,110814,'117607','furniture','padding-left','20',0,''),(347210,110814,'117607','furniture','padding-right','20',0,''),(347211,110814,'117607','furniture','padding-bottom','20',0,''),(347212,110815,'117608','furniture','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(347213,110817,'117610','furniture','block_type','1',0,''),(347214,110818,'117611','furniture','margin_left_measure','auto',0,''),(347215,110818,'117611','furniture','margin_right_measure','auto',0,''),(347216,110818,'117611','furniture','max-width','560',0,''),(347217,110819,'117612','furniture','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(347218,110820,'117613','furniture','margin-bottom','30',0,''),(347219,110821,'1683109599.245213','furniture','block_type','1',0,''),(347220,110822,'1683109599.255978','furniture','block_type','2',0,''),(347221,110822,'1683109599.255978','furniture','font-weight','400',0,''),(347222,110822,'1683109599.255978','furniture','padding-bottom','20',0,''),(347223,110822,'1683109599.255978','furniture','schema','2-2',0,'5161'),(347224,110822,'1683109599.255978','furniture','schema','2-2',0,'5140'),(347225,110823,'1683109599.25889','furniture','block_type','1',0,''),(347226,110824,'1683109599.25915','furniture','font-weight','400',0,''),(347227,110824,'1683109599.25915','furniture','padding-top','20',0,''),(347228,110824,'1683109599.25915','furniture','box_align','4',0,''),(347229,110824,'1683109599.25915','furniture','margin-bottom','50',0,''),(347230,110824,'1683109599.25915','furniture','align_position','horizontal',0,''),(347231,110824,'1683109599.25915','furniture','padding-right','0',0,'5140'),(347232,110824,'1683109599.25915','furniture','padding-right','20',0,''),(347233,110826,'1683109599.261153','furniture','padding-bottom','20',0,''),(347234,110830,'1683109599.263173','furniture','block_type','2',0,''),(347235,110830,'1683109599.263173','furniture','schema','2-2',0,'5145'),(347236,110831,'1683109599.264430','furniture','block_type','1',0,''),(347237,110831,'1683109599.264430','furniture','padding-right','9',0,''),(347238,110831,'1683109599.264430','furniture','padding-right','0',0,'5145'),(347239,110832,'1683109599.26556','furniture','cat_description','on',0,''),(347240,110832,'1683109599.26556','furniture','length_description','250',0,''),(347241,110832,'1683109599.26556','furniture','padding-bottom','7',0,''),(347242,110832,'1683109599.26556','furniture','link_description','1',0,''),(347243,110832,'1683109599.26556','furniture','border-bottom-width','1',0,''),(347244,110832,'1683109599.26556','furniture','border-bottom-color','$content-border-1',0,''),(347245,110833,'1683109599.26782','furniture','margin-bottom','7',0,''),(347246,110833,'1683109599.26782','furniture','border-bottom-width','1',0,''),(347247,110833,'1683109599.26782','furniture','border-bottom-color','$content-border-1',0,''),(347248,110834,'1683109599.267742','furniture','text','<div class=\"warranty\">\n <div class=\"title\">##TITLE_WARRANTY_PRODUCT##</div>\n <div class=\"seeDetails\"><a href=\"warranty\">##TITLE_SEE_DETAILS_PRODUCT##</a></div>\n</div>\n<div class=\"delivery\">\n <div class=\"title\">##TITLE_DELIVERY_PRODUCT##</div>\n <div class=\"seeDetails\"><a href=\"shipping\">##TITLE_SEE_DETAILS_PRODUCT##</a></div>\n</div>',0,''),(347249,110834,'1683109599.267742','furniture','style_class','warrantyProduct',0,''),(347250,110834,'1683109599.267742','furniture','margin-bottom','20',0,''),(347251,110835,'1683109599.27259','furniture','show_prices','1',0,''),(347252,110835,'1683109599.27259','furniture','show_images','swatches',0,''),(347253,110836,'1683109599.272734','furniture','block_type','1',0,''),(347254,110838,'1683109599.292170','furniture','block_type','1',0,''),(347255,110838,'1683109599.292170','furniture','padding-left','9',0,''),(347256,110838,'1683109599.292170','furniture','margin-top','20',0,'5145'),(347257,110838,'1683109599.292170','furniture','padding-left','0',0,'5145'),(347258,110839,'1683109599.294458','furniture','block_type','1',0,''),(347259,110839,'1683109599.294458','furniture','style_class','productNavigation',0,''),(347260,110839,'1683109599.294458','furniture','border-top-width','1',0,''),(347261,110839,'1683109599.294458','furniture','border-left-width','1',0,''),(347262,110839,'1683109599.294458','furniture','border-right-width','1',0,''),(347263,110839,'1683109599.294458','furniture','border-bottom-width','1',0,''),(347264,110839,'1683109599.294458','furniture','border-top-color','$content-border-1',0,''),(347265,110839,'1683109599.294458','furniture','border-left-color','$content-border-1',0,''),(347266,110839,'1683109599.294458','furniture','border-right-color','$content-border-1',0,''),(347267,110839,'1683109599.294458','furniture','border-bottom-color','$content-border-1',0,''),(347268,110840,'1683109599.297231','furniture','padding-top','15',0,''),(347269,110840,'1683109599.297231','furniture','padding-left','20',0,''),(347270,110840,'1683109599.297231','furniture','padding-right','20',0,''),(347271,110840,'1683109599.297231','furniture','padding-bottom','20',0,''),(347272,110840,'1683109599.297231','furniture','border-bottom-width','1',0,''),(347273,110840,'1683109599.297231','furniture','border-bottom-color','$content-border-1',0,''),(347274,110841,'1683109599.30758','furniture','block_type','1',0,''),(347275,110841,'1683109599.30758','furniture','padding-top','20',0,''),(347276,110841,'1683109599.30758','furniture','padding-left','20',0,''),(347277,110841,'1683109599.30758','furniture','padding-right','20',0,''),(347278,110841,'1683109599.30758','furniture','padding-bottom','20',0,''),(347279,110842,'1683109599.30990','furniture','margin-bottom','20',0,''),(347280,110843,'1683109599.310437','furniture','text-align','center',0,''),(347281,110843,'1683109599.310437','furniture','padding-bottom','10',0,''),(347282,110843,'1683109599.310437','furniture','border-bottom-color','$content-border-1',0,''),(347283,110843,'1683109599.310437','furniture','border-bottom-width','1',0,''),(347284,110843,'1683109599.310437','furniture','margin-bottom','10',0,''),(347285,110843,'1683109599.310437','furniture','padding-top','10',0,''),(347286,110843,'1683109599.310437','furniture','margin-top','10',0,''),(347287,110843,'1683109599.310437','furniture','border-top-color','$content-border-1',0,''),(347288,110843,'1683109599.310437','furniture','border-top-width','1',0,''),(347289,110844,'1683109599.313121','furniture','font-size','38',0,''),(347290,110844,'1683109599.313121','furniture','font-weight','400',0,''),(347291,110844,'1683109599.313121','furniture','line-height','35',0,''),(347292,110844,'1683109599.313121','furniture','font-family','$font-1',0,''),(347293,110844,'1683109599.313121','furniture','line_height_measure','px',0,''),(347294,110844,'1683109599.313121','furniture','padding-top','5',0,''),(347295,110844,'1683109599.313121','furniture','text-align','center',0,''),(347296,110844,'1683109599.313121','furniture','padding-bottom','15',0,''),(347297,110845,'1683109599.315738','furniture','box_align','2',0,''),(347298,110845,'1683109599.315738','furniture','margin-bottom','15',0,'5140'),(347299,110845,'1683109599.315738','furniture','text-align','right',0,'5140'),(347300,110845,'1683109599.315738','furniture','padding-top','5',0,''),(347301,110845,'1683109599.315738','furniture','text-align','center',0,''),(347302,110845,'1683109599.315738','furniture','margin-bottom','25',0,''),(347303,110846,'1683109599.322597','furniture','text-align','center',0,''),(347304,110846,'1683109599.322597','furniture','width','100',0,'5131'),(347305,110846,'1683109599.322597','furniture','width_measure','%',0,'5131'),(347306,110846,'1683109599.322597','furniture','float','none',0,'5131'),(347307,110846,'1683109599.322597','furniture','hide_additional_buttons','1',0,''),(347308,110846,'1683109599.322597','furniture','margin-bottom','15',0,''),(347309,110847,'1683109599.325422','furniture','text-align','center',0,''),(347310,110848,'1683109599.326754','furniture','text-align','center',0,''),(347311,110849,'1683109599.329949','furniture','text-align','center',0,''),(347312,110850,'1683109599.331551','furniture','margin-bottom','10',0,''),(347313,110851,'1683109599.334184','furniture','block_type','2',0,''),(347314,110852,'1683109599.335484','furniture','margin-bottom','15',0,''),(347315,110852,'1683109599.335484','furniture','padding-top','15',0,''),(347316,110853,'1683109599.33824','furniture','font-weight','400',0,''),(347317,110854,'1683109599.338931','furniture','font-weight','normal',0,''),(347318,110854,'1683109599.338931','furniture','padding-top','10',0,''),(347319,110854,'1683109599.338931','furniture','padding-bottom','10',0,''),(347320,110854,'1683109599.338931','furniture','box_align','4',0,''),(347321,110855,'1683109599.343489','furniture','block_type','1',0,''),(347322,110855,'1683109599.343489','furniture','padding-bottom','30',0,''),(347323,110856,'1683109599.345520','furniture','reviews_count','right',0,''),(347324,110856,'1683109599.345520','furniture','display','inline-block',0,''),(347325,110856,'1683109599.345520','furniture','padding-right','12',0,''),(347326,110856,'1683109599.345520','furniture','border-right-width','1',0,''),(347327,110856,'1683109599.345520','furniture','border-right-color','$content-border-2',0,''),(347328,110856,'1683109599.345520','furniture','line-height','1',0,''),(347329,110857,'1683109599.348715','furniture','text','##TEXT_WRITE_REVIEW##',0,''),(347330,110857,'1683109599.348715','furniture','style_class','writeReview',0,''),(347331,110857,'1683109599.348715','furniture','display','inline-block',0,''),(347332,110857,'1683109599.348715','furniture','padding-left','12',0,''),(347333,110857,'1683109599.348715','furniture','line-height','1',0,''),(347334,110857,'1683109599.348715','furniture','font-size','14',0,''),(347335,110858,'1683109648.23241','furniture','block_type','1',0,''),(347336,110859,'1683109648.239129','furniture','font-weight','normal',0,''),(347337,110859,'1683109648.239129','furniture','padding-bottom','20',0,''),(347338,110861,'1683109666.978945','furniture','block_type','1',0,''),(347339,110861,'1683109666.978945','furniture','padding-top','25',0,''),(347340,110861,'1683109666.978945','furniture','padding-bottom','25',0,''),(347341,110861,'1683109666.978945','furniture','style_class','catalog-product-wrap',0,''),(347342,110862,'1683109666.985380','furniture','block_type','1',0,''),(347343,110863,'1683109666.986680','furniture','tab_1','##TEXT_PRODUCT_OVERVIEW##',1,''),(347344,110863,'1683109666.986680','furniture','tab_2','##TEXT_DELIVERY_AND_RETURNS##',1,''),(347345,110863,'1683109666.986680','furniture','font-weight','400',0,''),(347346,110863,'1683109666.986680','furniture','tab_3','##TEXT_ASSEMBLY##',1,''),(347347,110863,'1683109666.986680','furniture','tab_1','##TEXT_PRODUCT_OVERVIEW##',2,''),(347348,110863,'1683109666.986680','furniture','tab_2','##TEXT_DELIVERY_AND_RETURNS##',2,''),(347349,110863,'1683109666.986680','furniture','tab_3','##TEXT_ASSEMBLY##',2,''),(347350,110863,'1683109666.986680','furniture','tab_1','##TEXT_PRODUCT_OVERVIEW##',3,''),(347351,110863,'1683109666.986680','furniture','tab_2','##TEXT_DELIVERY_AND_RETURNS##',3,''),(347352,110863,'1683109666.986680','furniture','tab_3','##TEXT_ASSEMBLY##',3,''),(347353,110863,'1683109666.986680','furniture','tab_1','##TEXT_PRODUCT_OVERVIEW##',4,''),(347354,110863,'1683109666.986680','furniture','tab_2','##TEXT_DELIVERY_AND_RETURNS##',4,''),(347355,110863,'1683109666.986680','furniture','tab_3','##TEXT_ASSEMBLY##',4,''),(347356,110864,'1683109666.994221','furniture','hTagsInline','block',0,''),(347357,110865,'1683109666.99570','furniture','margin-bottom','20',0,''),(347358,110865,'1683109666.99570','furniture','max-width','500',0,''),(347359,110866,'1683109666.999888','furniture','info_page','42',0,''),(347360,110867,'1683109667.001793','furniture','tab_1','##TEXT_CUSTOMER_ALSO_BOUGHT##',0,''),(347361,110867,'1683109667.001793','furniture','tab_2','##TEXT_YOU_RECENTLY_VIEWED##',0,''),(347362,110867,'1683109667.001793','furniture','margin-bottom','20',0,''),(347363,110868,'1683109667.003150','furniture','font-weight','400',0,''),(347364,110868,'1683109667.003150','furniture','padding-bottom','20',0,''),(347365,110868,'1683109667.003150','furniture','show_qty_input','1',0,''),(347366,110868,'1683109667.003150','furniture','show_compare','1',0,''),(347367,110868,'1683109667.003150','furniture','listing_type','productListing',0,''),(347368,110868,'1683109667.003150','furniture','view_as','carousel',0,''),(347369,110868,'1683109667.003150','furniture','show_name','0',0,''),(347370,110868,'1683109667.003150','furniture','show_image','0',0,''),(347371,110868,'1683109667.003150','furniture','show_stock','0',0,''),(347372,110868,'1683109667.003150','furniture','show_description','0',0,''),(347373,110868,'1683109667.003150','furniture','show_model','1',0,''),(347374,110868,'1683109667.003150','furniture','show_properties','1',0,''),(347375,110868,'1683109667.003150','furniture','show_rating','0',0,''),(347376,110868,'1683109667.003150','furniture','show_rating_counts','0',0,''),(347377,110868,'1683109667.003150','furniture','show_price','0',0,''),(347378,110868,'1683109667.003150','furniture','show_buy_button','1',0,''),(347379,110868,'1683109667.003150','furniture','show_view_button','1',0,''),(347380,110868,'1683109667.003150','furniture','show_wishlist_button','1',0,''),(347381,110868,'1683109667.003150','furniture','display','none',0,'5140'),(347382,110868,'1683109667.003150','furniture','product_names_teg','h2',0,''),(347383,110868,'1683109667.003150','furniture','show_attributes','1',0,''),(347384,110868,'1683109667.003150','furniture','col_in_row','4',0,''),(347385,110868,'1683109667.003150','furniture','show_bonus_points','1',0,''),(347386,110869,'1683109667.007130','furniture','font-weight','400',0,''),(347387,110869,'1683109667.007130','furniture','padding-bottom','20',0,''),(347388,110869,'1683109667.007130','furniture','show_compare','1',0,''),(347389,110869,'1683109667.007130','furniture','show_name','0',0,''),(347390,110869,'1683109667.007130','furniture','show_image','0',0,''),(347391,110869,'1683109667.007130','furniture','show_stock','0',0,''),(347392,110869,'1683109667.007130','furniture','show_description','0',0,''),(347393,110869,'1683109667.007130','furniture','show_model','1',0,''),(347394,110869,'1683109667.007130','furniture','show_properties','1',0,''),(347395,110869,'1683109667.007130','furniture','show_rating','0',0,''),(347396,110869,'1683109667.007130','furniture','show_rating_counts','0',0,''),(347397,110869,'1683109667.007130','furniture','show_price','0',0,''),(347398,110869,'1683109667.007130','furniture','show_buy_button','1',0,''),(347399,110869,'1683109667.007130','furniture','show_view_button','1',0,''),(347400,110869,'1683109667.007130','furniture','show_wishlist_button','1',0,''),(347401,110869,'1683109667.007130','furniture','listing_type','productListing',0,''),(347402,110869,'1683109667.007130','furniture','col_in_row','2',0,'5140'),(347403,110869,'1683109667.007130','furniture','col_in_row','1',0,'5161'),(347404,110869,'1683109667.007130','furniture','col_in_row','4',0,''),(347405,110869,'1683109667.007130','furniture','view_as','carousel',0,''),(347406,110869,'1683109667.007130','furniture','show_bonus_points','1',0,''),(347407,110869,'1683109667.007130','furniture','show_qty_input','1',0,''),(347408,110869,'1683109667.007130','furniture','show_attributes','1',0,''),(347409,110870,'1683109667.010748','furniture','block_type','3',0,''),(347410,110870,'1683109667.010748','furniture','style_class','tripleBanner',0,''),(347411,110871,'1683109667.01353','furniture','text','<div>##TEXT_RETURN_AND_EXCHANGES##</div>\n<div>##TEXT_SATISFACTION_GUARANTEE##</div>\n',0,''),(347412,110871,'1683109667.01353','furniture','style_class','returns',0,''),(347413,110872,'1683109667.014986','furniture','text','<div>##TEXT_WARRANTY##</div>\n<div>##TEXT_PERIOD_MANUFACTURER_WARRANTY##</div>',0,''),(347414,110872,'1683109667.014986','furniture','style_class','warranty',0,''),(347415,110873,'1683109667.016871','furniture','text','<div>##TEXT_TRACK_YOUR_ORDER##</div>\n<div>##TEXT_CHECK_CURRENT_STATUS##</div>',0,''),(347416,110873,'1683109667.016871','furniture','style_class','track',0,''),(347417,110874,'1683109667.01857','furniture','block_type','1',0,''),(347418,110875,'1683109667.019642','furniture','padding-bottom','10',0,''),(347419,110875,'1683109667.019642','furniture','padding-top','5',0,''),(347420,110876,'1707919218.1062','furniture','listing_type','b2b',0,''),(347421,110876,'1707919218.1062','furniture','platform','8',0,''),(347422,110876,'1707919218.1062','furniture','xsell_type_id','1',0,''),(347423,110887,'117665','furniture','block_type','1',0,''),(347424,110887,'117665','furniture','style_class','item-holder',0,''),(347425,110887,'117665','furniture','padding-top','25',0,''),(347426,110887,'117665','furniture','padding-left','25',0,''),(347427,110887,'117665','furniture','padding-right','25',0,''),(347428,110887,'117665','furniture','padding-bottom','25',0,''),(347429,110887,'117665','furniture','text-align','left',0,''),(347430,110888,'120921','furniture','block_type','1',0,''),(347431,110888,'120921','furniture','style_class','item-wrapper',0,''),(347432,110889,'120896','furniture','block_type','1',0,''),(347433,110889,'120896','furniture','style_class','item-nav',0,''),(347434,110893,'120919','furniture','block_type','1',0,''),(347435,110893,'120919','furniture','style_class','item-content',0,''),(347436,110895,'117668','furniture','description_characters','90',0,''),(347437,110898,'117673','furniture','margin-bottom','7',0,''),(347438,110899,'117675','furniture','clear','both',0,''),(347439,110900,'117676','furniture','margin-bottom','10',0,''),(347440,110903,'117678','furniture','block_type','1',0,''),(347441,110903,'117678','furniture','padding-bottom','30',0,''),(347442,110904,'117679','furniture','block_type','6',0,''),(347443,110904,'117679','furniture','font-weight','400',0,''),(347444,110904,'117679','furniture','schema','6-2',0,'5161'),(347445,110904,'117679','furniture','schema','6-2',0,'5140'),(347446,110905,'117680','furniture','font-weight','400',0,''),(347447,110905,'117680','furniture','padding-right','40',0,''),(347448,110905,'117680','furniture','padding-right','0',0,'5161'),(347449,110905,'117680','furniture','padding-right','0',0,'5140'),(347450,110905,'117680','furniture','margin-bottom','20',0,''),(347451,110906,'117681','furniture','margin-bottom','20',0,''),(347452,110907,'120916','furniture','block_type','1',0,''),(347453,110907,'120916','furniture','padding-right','40',0,''),(347454,110907,'120916','furniture','style_class','leftCategories',0,''),(347455,110907,'120916','furniture','padding-bottom','25',0,''),(347456,110907,'120916','furniture','padding-right','0',0,'5140'),(347457,110908,'120918','furniture','block_type','1',0,''),(347458,110908,'120918','furniture','background-color','$content-bg-2',0,''),(347459,110909,'120884','furniture','type','default',0,''),(347460,110909,'120884','furniture','class','menu-simple',0,''),(347461,110909,'120884','furniture','style_class','LeftCategories',0,''),(347462,110910,'120917','furniture','text','##TEXT_CATEGORIES##',0,''),(347463,110910,'120917','furniture','padding-top','22',0,''),(347464,110910,'120917','furniture','padding-left','25',0,''),(347465,110910,'120917','furniture','padding-right','25',0,''),(347466,110910,'120917','furniture','padding-bottom','10',0,''),(347467,110910,'120917','furniture','color','$content-color-1',0,''),(347468,110910,'120917','furniture','font-size','24',0,''),(347469,110910,'120917','furniture','font-weight','bold',0,''),(347470,110912,'117683','furniture','block_type','1',0,''),(347471,110912,'117683','furniture','padding-top','10',0,''),(347472,110912,'117683','furniture','padding-bottom','10',0,''),(347473,110912,'117683','furniture','border-bottom-width','1',0,''),(347474,110912,'117683','furniture','border-bottom-color','$content-border-1',0,''),(347475,110912,'117683','furniture','margin-left','0',0,''),(347476,110912,'117683','furniture','margin-right','0',0,''),(347477,110913,'117684','furniture','float','left',0,''),(347478,110913,'117684','furniture','clear','none',0,''),(347479,110913,'117684','furniture','sort_pos_3','2',0,''),(347480,110913,'117684','furniture','sort_pos_4','3',0,''),(347481,110913,'117684','furniture','sort_pos_10','11',0,''),(347482,110913,'117684','furniture','sort_pos_9','10',0,''),(347483,110913,'117684','furniture','sort_pos_11','12',0,''),(347484,110913,'117684','furniture','sort_pos_12','13',0,''),(347485,110913,'117684','furniture','sort_pos_14','15',0,''),(347486,110913,'117684','furniture','sort_pos_13','14',0,''),(347487,110913,'117684','furniture','sort_pos_8','4',0,''),(347488,110913,'117684','furniture','sort_pos_7','5',0,''),(347489,110913,'117684','furniture','sort_pos_2','7',0,''),(347490,110913,'117684','furniture','sort_pos_1','6',0,''),(347491,110913,'117684','furniture','sort_pos_6','9',0,''),(347492,110913,'117684','furniture','sort_pos_5','8',0,''),(347493,110913,'117684','furniture','sort_pos_0','1',0,''),(347494,110913,'117684','furniture','sort_hide_10','1',0,''),(347495,110913,'117684','furniture','sort_hide_9','1',0,''),(347496,110913,'117684','furniture','sort_pos_15','16',0,''),(347497,110913,'117684','furniture','sort_pos_16','17',0,''),(347498,110913,'117684','furniture','sort_hide_4','0',0,''),(347499,110913,'117684','furniture','sort_hide_3','0',0,''),(347500,110913,'117684','furniture','sort_hide_16','1',0,''),(347501,110913,'117684','furniture','sort_hide_15','1',0,''),(347502,110913,'117684','furniture','sort_hide_11','1',0,''),(347503,110913,'117684','furniture','sort_hide_12','1',0,''),(347504,110913,'117684','furniture','sort_hide_14','1',0,''),(347505,110913,'117684','furniture','sort_hide_13','1',0,''),(347506,110913,'117684','furniture','sort_hide_8','0',0,''),(347507,110913,'117684','furniture','sort_hide_7','0',0,''),(347508,110913,'117684','furniture','sort_hide_2','1',0,''),(347509,110913,'117684','furniture','sort_hide_1','1',0,''),(347510,110913,'117684','furniture','sort_hide_6','1',0,''),(347511,110913,'117684','furniture','sort_hide_5','1',0,''),(347512,110913,'117684','furniture','sort_hide_0','0',0,''),(347513,110913,'117684','furniture','hide_icons','1',0,''),(347514,110914,'117685','furniture','float','right',0,''),(347515,110914,'117685','furniture','display','none',0,'5161'),(347516,110915,'117686','furniture','float','left',0,''),(347517,110915,'117686','furniture','clear','none',0,''),(347518,110915,'117686','furniture','margin-left','20',0,''),(347519,110915,'117686','furniture','display','none',0,'5161'),(347520,110915,'117686','furniture','display','none',0,'5145'),(347521,110916,'117687','furniture','margin-right','20',0,''),(347522,110916,'117687','furniture','float','right',0,''),(347523,110916,'117687','furniture','clear','none',0,''),(347524,110916,'117687','furniture','display','none',0,'5140'),(347525,110917,'117688','furniture','block_type','5',0,''),(347526,110917,'117688','furniture','padding-top','10',0,''),(347527,110917,'117688','furniture','padding-bottom','10',0,''),(347528,110917,'117688','furniture','schema','5-2',0,'5161'),(347529,110917,'117688','furniture','border-top-color','$content-border-1',0,''),(347530,110917,'117688','furniture','border-top-width','1',0,''),(347531,110918,'117689','furniture','padding-top','3',0,''),(347532,110919,'117690','furniture','float','right',0,''),(347533,110919,'117690','furniture','height','31',0,''),(347534,110920,'117691','furniture','col_in_row','3',0,''),(347535,110920,'117691','furniture','products_align','left',0,''),(347536,110920,'117691','furniture','font-weight','400',0,''),(347537,110920,'117691','furniture','listing_type','productListing',0,''),(347538,110920,'117691','furniture','listing_type_rows','Rows',0,''),(347539,110920,'117691','furniture','show_buy_button_b2b','on',0,''),(347540,110920,'117691','furniture','show_wishlist_button_b2b','1',0,''),(347541,110920,'117691','furniture','show_compare_b2b','1',0,''),(347542,110920,'117691','furniture','show_image','0',0,''),(347543,110920,'117691','furniture','show_stock','0',0,''),(347544,110920,'117691','furniture','show_description','0',0,''),(347545,110920,'117691','furniture','show_rating','0',0,''),(347546,110920,'117691','furniture','show_rating_counts','0',0,''),(347547,110920,'117691','furniture','show_price','0',0,''),(347548,110920,'117691','furniture','show_view_button','0',0,''),(347549,110920,'117691','furniture','show_wishlist_button','0',0,''),(347550,110920,'117691','furniture','show_compare','0',0,''),(347551,110920,'117691','furniture','show_name_rows','0',0,''),(347552,110920,'117691','furniture','show_image_rows','0',0,''),(347553,110920,'117691','furniture','show_stock_rows','0',0,''),(347554,110920,'117691','furniture','show_description_rows','0',0,''),(347555,110920,'117691','furniture','show_model_rows','0',0,''),(347556,110920,'117691','furniture','show_properties_rows','0',0,''),(347557,110920,'117691','furniture','show_rating_rows','0',0,''),(347558,110920,'117691','furniture','show_rating_counts_rows','0',0,''),(347559,110920,'117691','furniture','show_price_rows','0',0,''),(347560,110920,'117691','furniture','show_buy_button_rows','0',0,''),(347561,110920,'117691','furniture','show_qty_input_rows','0',0,''),(347562,110920,'117691','furniture','show_view_button_rows','0',0,''),(347563,110920,'117691','furniture','show_wishlist_button_rows','0',0,''),(347564,110920,'117691','furniture','show_compare_rows','0',0,''),(347565,110920,'117691','furniture','show_name_b2b','0',0,''),(347566,110920,'117691','furniture','show_image_b2b','0',0,''),(347567,110920,'117691','furniture','show_stock_b2b','0',0,''),(347568,110920,'117691','furniture','show_description_b2b','0',0,''),(347569,110920,'117691','furniture','show_model_b2b','0',0,''),(347570,110920,'117691','furniture','show_properties_b2b','0',0,''),(347571,110920,'117691','furniture','show_rating_b2b','0',0,''),(347572,110920,'117691','furniture','show_rating_counts_b2b','0',0,''),(347573,110920,'117691','furniture','show_price_b2b','0',0,''),(347574,110920,'117691','furniture','show_qty_input_b2b','0',0,''),(347575,110920,'117691','furniture','show_view_button_b2b','0',0,''),(347576,110920,'117691','furniture','show_attributes_b2b','0',0,''),(347577,110920,'117691','furniture','items_on_page','9',0,''),(347578,110920,'117691','furniture','col_in_row','2',0,'5140'),(347579,110920,'117691','furniture','col_in_row','1',0,'5161'),(347580,110920,'117691','furniture','product_names_teg','h2',0,''),(347581,110920,'117691','furniture','padding-top','20',0,''),(347582,110920,'117691','furniture','padding-bottom','20',0,''),(347583,110920,'117691','furniture','col_in_row','2',0,'5145'),(347584,110921,'120912','furniture','block_type','5',0,''),(347585,110921,'120912','furniture','padding-top','10',0,''),(347586,110921,'120912','furniture','schema','5-2',0,'5161'),(347587,110922,'120913','furniture','padding-top','3',0,''),(347588,110923,'120914','furniture','float','right',0,''),(347589,110923,'120914','furniture','height','31',0,''),(347590,110924,'1639760443.0645','furniture','carousel','1',0,''),(347591,110924,'1639760443.0645','furniture','col_in_row','4',0,''),(347592,110924,'1639760443.0645','furniture','fancibox','1',0,''),(347593,110926,'117693','furniture','block_type','1',0,''),(347594,110927,'117694','furniture','margin-bottom','20',0,''),(347595,110931,'117696','furniture','block_type','1',0,''),(347596,110933,'117698','furniture','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(347597,110934,'117699','furniture','width','680',0,''),(347598,110934,'117699','furniture','font-weight','normal',0,''),(347599,110934,'117699','furniture','font-size','12',0,''),(347600,110934,'117699','furniture','padding-top','20',0,''),(347601,110934,'117699','furniture','padding-bottom','20',0,''),(347602,110934,'117699','furniture','color','$content-color-1',0,''),(347603,110935,'117700','furniture','font-weight','400',0,''),(347604,110935,'117700','furniture','padding-top','20',0,''),(347605,110935,'117700','furniture','padding-bottom','0',0,''),(347606,110935,'117700','furniture','font-size','12',0,''),(347607,110936,'117701','furniture','block_type','3',0,''),(347608,110936,'117701','furniture','font-weight','normal',0,''),(347609,110936,'117701','furniture','padding-top','20',0,''),(347610,110937,'117702','furniture','text','<p>If undelivered please return to:</p>',1,''),(347611,110937,'117702','furniture','font-size','12',0,''),(347612,110937,'117702','furniture','font-weight','bold',0,''),(347613,110937,'117702','furniture','text','<p>If undelivered please return to:</p>',2,''),(347614,110937,'117702','furniture','text','<p>If undelivered please return to:</p>',3,''),(347615,110937,'117702','furniture','text','<p>If undelivered please return to:</p>',4,''),(347616,110938,'117703','furniture','font-size','12',0,''),(347617,110939,'117704','furniture','text','<p>Thank you for your order</p>',1,''),(347618,110939,'117704','furniture','color','$content-color-1',0,''),(347619,110939,'117704','furniture','font-size','13',0,''),(347620,110939,'117704','furniture','font-weight','bold',0,''),(347621,110939,'117704','furniture','padding-top','5',0,''),(347622,110939,'117704','furniture','text-align','center',0,''),(347623,110939,'117704','furniture','text','<p>Thank you for your order</p>',2,''),(347624,110939,'117704','furniture','text','<p>Thank you for your order</p>',3,''),(347625,110939,'117704','furniture','text','<p>Thank you for your order</p>',4,''),(347626,110940,'117705','furniture','font-weight','400',0,''),(347627,110940,'117705','furniture','text-align','center',0,''),(347628,110940,'117705','furniture','padding-top','0',0,''),(347630,110940,'117705','furniture','padding-left','20',0,''),(347631,110940,'117705','furniture','padding-right','20',0,''),(347635,110941,'117706','furniture','block_type','6',0,''),(347636,110941,'117706','furniture','font-weight','normal',0,''),(347637,110941,'117706','furniture','font-size','16',0,''),(347638,110942,'117707','furniture','text','<p>Email:</p>',1,''),(347639,110942,'117707','furniture','font-weight','normal',0,''),(347640,110942,'117707','furniture','text-align','right',0,''),(347641,110942,'117707','furniture','font-size','12',0,''),(347642,110942,'117707','furniture','text','<p>Email:</p>',2,''),(347643,110942,'117707','furniture','text','<p>Email:</p>',3,''),(347644,110942,'117707','furniture','text','<p>Email:</p>',4,''),(347645,110943,'117708','furniture','font-weight','normal',0,''),(347646,110943,'117708','furniture','text-align','right',0,''),(347647,110943,'117708','furniture','font-size','12',0,''),(347648,110944,'117709','furniture','text','<p>If something has gone wrong please contact us at:</p>',1,''),(347649,110944,'117709','furniture','font-size','12',0,''),(347650,110944,'117709','furniture','font-weight','bold',0,''),(347651,110944,'117709','furniture','text-align','right',0,''),(347652,110944,'117709','furniture','text','<p>If something has gone wrong please contact us at:</p>',2,''),(347653,110944,'117709','furniture','text','<p>If something has gone wrong please contact us at:</p>',3,''),(347654,110944,'117709','furniture','text','<p>If something has gone wrong please contact us at:</p>',4,''),(347655,110945,'117710','furniture','block_type','6',0,''),(347656,110945,'117710','furniture','font-weight','normal',0,''),(347657,110945,'117710','furniture','font-size','16',0,''),(347658,110946,'117711','furniture','text','<p>Phone:</p>',1,''),(347659,110946,'117711','furniture','font-weight','normal',0,''),(347660,110946,'117711','furniture','text-align','right',0,''),(347661,110946,'117711','furniture','font-size','12',0,''),(347662,110946,'117711','furniture','text','<p>Phone:</p>',2,''),(347663,110946,'117711','furniture','text','<p>Phone:</p>',3,''),(347664,110946,'117711','furniture','text','<p>Phone:</p>',4,''),(347665,110947,'117712','furniture','font-weight','normal',0,''),(347666,110947,'117712','furniture','text-align','right',0,''),(347667,110947,'117712','furniture','font-size','12',0,''),(347668,110948,'117713','furniture','block_type','2',0,''),(347669,110948,'117713','furniture','font-weight','normal',0,''),(347670,110948,'117713','furniture','padding-bottom','20',0,''),(347671,110949,'117714','furniture','font-weight','400',0,''),(347672,110949,'117714','furniture','padding-top','20',0,''),(347677,110950,'117715','furniture','block_type','11',0,''),(347678,110950,'117715','furniture','font-weight','normal',0,''),(347679,110951,'117716','furniture','text','<p>Phone:</p>',1,''),(347680,110951,'117716','furniture','font-weight','normal',0,''),(347681,110951,'117716','furniture','text-align','right',0,''),(347682,110951,'117716','furniture','text','<p>Phone:</p>',2,''),(347683,110951,'117716','furniture','text','<p>Phone:</p>',3,''),(347684,110951,'117716','furniture','text','<p>Phone:</p>',4,''),(347685,110952,'117717','furniture','font-weight','normal',0,''),(347686,110952,'117717','furniture','text-align','right',0,''),(347687,110953,'117718','furniture','block_type','11',0,''),(347688,110953,'117718','furniture','font-weight','normal',0,''),(347689,110954,'117719','furniture','text','<p>Web:</p>',1,''),(347690,110954,'117719','furniture','font-weight','normal',0,''),(347691,110954,'117719','furniture','text-align','right',0,''),(347692,110954,'117719','furniture','text','<p>Web:</p>',2,''),(347693,110954,'117719','furniture','text','<p>Web:</p>',3,''),(347694,110954,'117719','furniture','text','<p>Web:</p>',4,''),(347695,110955,'117720','furniture','font-weight','normal',0,''),(347696,110955,'117720','furniture','text-align','right',0,''),(347697,110956,'117721','furniture','block_type','1',0,''),(347698,110957,'117722','furniture','font-weight','normal',0,''),(347699,110957,'117722','furniture','text-align','right',0,''),(347700,110957,'117722','furniture','padding-bottom','10',0,''),(347701,110957,'117722','furniture','address_spacer',',',0,''),(347702,110957,'117722','furniture','font-size','12',0,''),(347703,110958,'117723','furniture','block_type','11',0,''),(347704,110958,'117723','furniture','font-weight','normal',0,''),(347705,110959,'117724','furniture','text','<p>Email:</p>',1,''),(347706,110959,'117724','furniture','font-weight','normal',0,''),(347707,110959,'117724','furniture','text-align','right',0,''),(347708,110959,'117724','furniture','text','<p>Email:</p>',2,''),(347709,110959,'117724','furniture','text','<p>Email:</p>',3,''),(347710,110959,'117724','furniture','text','<p>Email:</p>',4,''),(347711,110960,'117725','furniture','font-weight','normal',0,''),(347712,110960,'117725','furniture','text-align','right',0,''),(347713,110961,'117726','furniture','block_type','4',0,''),(347714,110961,'117726','furniture','font-weight','normal',0,''),(347715,110961,'117726','furniture','border-top-width','1',0,''),(347716,110961,'117726','furniture','border-top-color','$content-border-1',0,''),(347717,110961,'117726','furniture','border-left-width','1',0,''),(347718,110961,'117726','furniture','border-left-color','$content-border-1',0,''),(347719,110961,'117726','furniture','border-right-width','1',0,''),(347720,110961,'117726','furniture','border-right-color','$content-border-1',0,''),(347721,110961,'117726','furniture','border-bottom-width','1',0,''),(347722,110961,'117726','furniture','border-bottom-color','$content-border-1',0,''),(347723,110962,'117727','furniture','block_type','2',0,''),(347724,110962,'117727','furniture','font-weight','normal',0,''),(347725,110962,'117727','furniture','border-right-width','1',0,''),(347726,110962,'117727','furniture','border-right-color','$content-border-1',0,''),(347727,110963,'117728','furniture','block_type','1',0,''),(347728,110963,'117728','furniture','font-weight','400',0,''),(347729,110963,'117728','furniture','background-color','$content-bg-2',0,''),(347730,110963,'117728','furniture','padding-top','10',0,''),(347731,110963,'117728','furniture','padding-left','10',0,''),(347732,110963,'117728','furniture','padding-right','10',0,''),(347733,110963,'117728','furniture','padding-bottom','30',0,''),(347734,110964,'117729','furniture','font-size','12',0,''),(347735,110965,'117730','furniture','text','<p>ADDRESS:</p>\n',1,''),(347736,110965,'117730','furniture','font-size','14',0,''),(347737,110965,'117730','furniture','font-weight','bold',0,''),(347738,110965,'117730','furniture','text','<p>ADDRESS:</p>\n',2,''),(347739,110965,'117730','furniture','text','<p>ADDRESS:</p>\n',3,''),(347740,110965,'117730','furniture','text','<p>ADDRESS:</p>\n',4,''),(347741,110966,'117731','furniture','block_type','1',0,''),(347742,110966,'117731','furniture','font-weight','normal',0,''),(347743,110966,'117731','furniture','padding-top','10',0,''),(347744,110966,'117731','furniture','padding-left','10',0,''),(347745,110966,'117731','furniture','padding-right','10',0,''),(347746,110966,'117731','furniture','padding-bottom','10',0,''),(347747,110968,'117733','furniture','text','<p>E-MAIL ADDRESS:</p>',1,''),(347748,110968,'117733','furniture','font-weight','bold',0,''),(347749,110968,'117733','furniture','font-size','14',0,''),(347750,110968,'117733','furniture','padding-top','10',0,''),(347751,110968,'117733','furniture','text','<p>E-MAIL ADDRESS:</p>',2,''),(347752,110968,'117733','furniture','text','<p>E-MAIL ADDRESS:</p>',3,''),(347753,110968,'117733','furniture','text','<p>E-MAIL ADDRESS:</p>',4,''),(347754,110969,'117734','furniture','font-weight','normal',0,''),(347755,110970,'117735','furniture','font-weight','normal',0,''),(347756,110971,'117736','furniture','text','<p>PHONE NUMBER:</p>',1,''),(347757,110971,'117736','furniture','font-size','14',0,''),(347758,110971,'117736','furniture','font-weight','bold',0,''),(347759,110971,'117736','furniture','padding-top','10',0,''),(347760,110971,'117736','furniture','text','<p>PHONE NUMBER:</p>',2,''),(347761,110971,'117736','furniture','text','<p>PHONE NUMBER:</p>',3,''),(347762,110971,'117736','furniture','text','<p>PHONE NUMBER:</p>',4,''),(347763,110972,'117737','furniture','text','<p>CUSTOMER:</p>',1,''),(347764,110972,'117737','furniture','font-size','13',0,''),(347765,110972,'117737','furniture','font-weight','bold',0,''),(347766,110972,'117737','furniture','text','<p>CUSTOMER:</p>',2,''),(347767,110972,'117737','furniture','text','<p>CUSTOMER:</p>',3,''),(347768,110972,'117737','furniture','text','<p>CUSTOMER:</p>',4,''),(347769,110973,'117738','furniture','font-size','14',0,''),(347770,110973,'117738','furniture','font-weight','bold',0,''),(347771,110973,'117738','furniture','text-align','center',0,''),(347772,110973,'117738','furniture','padding-bottom','10',0,''),(347773,110973,'117738','furniture','padding-top','10',0,''),(347774,110974,'117739','furniture','text','<p>Order date:</p>\n',1,''),(347775,110974,'117739','furniture','font-weight','bold',0,''),(347776,110974,'117739','furniture','text-align','center',0,''),(347777,110974,'117739','furniture','font-size','12',0,''),(347778,110974,'117739','furniture','text','<p>Order date:</p>\n',2,''),(347779,110974,'117739','furniture','text','<p>Order date:</p>\n',3,''),(347780,110974,'117739','furniture','text','<p>Order date:</p>\n',4,''),(347781,110975,'117740','furniture','font-weight','normal',0,''),(347782,110975,'117740','furniture','text-align','center',0,''),(347783,110975,'117740','furniture','padding-bottom','10',0,''),(347784,110976,'117741','furniture','block_type','5',0,''),(347785,110976,'117741','furniture','font-weight','normal',0,''),(347786,110976,'117741','furniture','border-bottom-width','1',0,''),(347787,110976,'117741','furniture','border-bottom-color','$content-border-1',0,''),(347788,110976,'117741','furniture','border-top-width','1',0,''),(347789,110976,'117741','furniture','border-top-color','$content-border-1',0,''),(347790,110976,'117741','furniture','border-left-color','$content-border-1',0,''),(347791,110976,'117741','furniture','border-left-width','1',0,''),(347792,110977,'117742','furniture','block_type','1',0,''),(347793,110977,'117742','furniture','font-weight','normal',0,''),(347794,110977,'117742','furniture','padding-top','10',0,''),(347795,110977,'117742','furniture','padding-left','10',0,''),(347796,110977,'117742','furniture','padding-right','10',0,''),(347797,110978,'117743','furniture','font-weight','400',0,''),(347798,110978,'117743','furniture','line-height','120',0,''),(347799,110978,'117743','furniture','line_height_measure','%',0,''),(347800,110978,'117743','furniture','font-size','12',0,''),(347801,110979,'117744','furniture','text','<p>SHIPPING ADDRESS:</p>',1,''),(347802,110979,'117744','furniture','font-size','14',0,''),(347803,110979,'117744','furniture','font-weight','bold',0,''),(347804,110979,'117744','furniture','padding-bottom','10',0,''),(347805,110979,'117744','furniture','text','<p>SHIPPING ADDRESS:</p>',2,''),(347806,110979,'117744','furniture','text','<p>SHIPPING ADDRESS:</p>',3,''),(347807,110979,'117744','furniture','text','<p>SHIPPING ADDRESS:</p>',4,''),(347810,110983,'117745','furniture','block_type','1',0,''),(347811,110984,'117746','furniture','block_type','6',0,''),(347812,110984,'117746','furniture','schema','6-3',0,'5140'),(347813,110985,'117747','furniture','aria_name','account-menu',0,''),(347871,111005,'117748','furniture','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(347872,111006,'117749','furniture','link','Quotation Info',0,''),(347873,111006,'117749','furniture','margin-bottom','20',0,''),(347874,111007,'117750','furniture','block_type','1',0,''),(347875,111008,'117751','furniture','block_type','6',0,''),(347876,111008,'117751','furniture','schema','6-3',0,'5140'),(347877,111009,'117752','furniture','aria_name','account-menu',0,''),(347935,111029,'117753','furniture','block_type','3',0,''),(347936,111030,'117754','furniture','block_type','1',0,''),(347937,111030,'117754','furniture','padding-right','20',0,''),(347938,111030,'117754','furniture','padding-bottom','20',0,''),(347939,111031,'117755','furniture','orders_data','name',0,''),(347940,111032,'117756','furniture','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(347941,111033,'117757','furniture','block_type','1',0,''),(347942,111033,'117757','furniture','padding-right','20',0,''),(347943,111033,'117757','furniture','padding-bottom','20',0,''),(347944,111034,'117758','furniture','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(347945,111035,'117759','furniture','orders_data','telephone',0,''),(347946,111036,'117760','furniture','block_type','1',0,''),(347947,111036,'117760','furniture','padding-right','20',0,''),(347948,111037,'117761','furniture','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(347949,111038,'117762','furniture','orders_data','shipping_method',0,''),(347950,111039,'117763','furniture','block_type','1',0,''),(347951,111039,'117763','furniture','padding-right','20',0,''),(347952,111039,'117763','furniture','padding-bottom','20',0,''),(347953,111040,'117764','furniture','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(347954,111041,'117765','furniture','orders_data','delivery_address',0,''),(347955,111042,'117766','furniture','block_type','1',0,''),(347956,111042,'117766','furniture','padding-bottom','20',0,''),(347957,111043,'117767','furniture','orders_data','billing_address',0,''),(347958,111044,'117768','furniture','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(347959,111045,'117769','furniture','block_type','1',0,''),(347960,111046,'117770','furniture','orders_data','payment_method',0,''),(347961,111047,'117771','furniture','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(347962,111048,'117772','furniture','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(347963,111050,'117774','furniture','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(347964,111053,'117777','furniture','block_type','2',0,''),(347965,111053,'117777','furniture','padding-top','20',0,''),(347966,111053,'117777','furniture','margin-bottom','20',0,''),(347967,111054,'117778','furniture','like_button','1',0,''),(347968,111054,'117778','furniture','text','IMAGE_BUTTON_BACK',0,''),(347969,111054,'117778','furniture','link','Quotations',0,''),(347970,111055,'117779','furniture','text','<h1>##HEADING_TITLE##</h1>',0,''),(347971,111056,'117780','furniture','padding-top','20',0,''),(347972,111056,'117780','furniture','padding-bottom','20',0,''),(347973,111056,'117780','furniture','block_type','1',0,''),(347974,111056,'117780','furniture','background-color','$content-bg-2',0,''),(347975,111058,'117782','furniture','block_type','4',0,''),(347976,111058,'117782','furniture','schema','4-2',0,'5140'),(347977,111058,'117782','furniture','schema','4-2',0,'5131'),(347978,111059,'117783','furniture','background-color','$content-bg-1',0,''),(347979,111060,'117784','furniture','block_type','1',0,''),(347980,111060,'117784','furniture','style_class','order-summary',0,''),(347981,111060,'117784','furniture','margin-left','30',0,''),(347982,111060,'117784','furniture','margin-left','0',0,'5140'),(347983,111061,'117785','furniture','block_type','1',0,''),(347984,111061,'117785','furniture','padding-left','20',0,''),(347985,111061,'117785','furniture','padding-right','20',0,''),(347986,111061,'117785','furniture','padding-bottom','30',0,''),(347987,111062,'117786','furniture','max-width','300',0,'5140'),(347988,111062,'117786','furniture','margin_left_measure','auto',0,'5140'),(347989,111062,'117786','furniture','margin_right_measure','auto',0,'5140'),(347990,111062,'117786','furniture','margin-bottom','0',0,''),(347991,111064,'117788','furniture','block_type','1',0,''),(348054,111088,'117793','furniture','block_type','1',0,''),(348055,111090,'117795','furniture','pagination','bottom',0,''),(348056,111091,'117796','furniture','width','800',0,''),(348057,111092,'117797','furniture','block_type','11',0,''),(348058,111092,'117797','furniture','border-top-width','1',0,''),(348059,111092,'117797','furniture','border-left-width','1',0,''),(348060,111092,'117797','furniture','border-right-width','1',0,''),(348061,111092,'117797','furniture','border-bottom-width','1',0,''),(348062,111092,'117797','furniture','border-top-color','$content-border-2',0,''),(348063,111092,'117797','furniture','border-left-color','$content-border-2',0,''),(348064,111092,'117797','furniture','border-right-color','$content-border-2',0,''),(348065,111092,'117797','furniture','border-bottom-color','$content-border-2',0,''),(348066,111093,'117798','furniture','block_type','1',0,''),(348067,111093,'117798','furniture','border-right-width','1',0,''),(348068,111093,'117798','furniture','border-right-color','$content-border-2',0,''),(348069,111093,'117798','furniture','padding-top','10',0,''),(348070,111093,'117798','furniture','padding-right','10',0,''),(348071,111093,'117798','furniture','padding-bottom','10',0,''),(348072,111094,'117799','furniture','block_type','9',0,''),(348073,111095,'117800','furniture','text','1.',0,''),(348074,111095,'117800','furniture','font-size','12',0,''),(348075,111095,'117800','furniture','text-align','right',0,''),(348076,111095,'117800','furniture','padding-right','5',0,''),(348077,111096,'117801','furniture','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(348078,111096,'117801','furniture','font-size','12',0,''),(348079,111096,'117801','furniture','padding-bottom','5',0,''),(348080,111097,'117802','furniture','block_type','9',0,''),(348081,111098,'117803','furniture','text','4.',0,''),(348082,111098,'117803','furniture','font-size','12',0,''),(348083,111098,'117803','furniture','text-align','right',0,''),(348084,111098,'117803','furniture','margin-right','5',0,''),(348085,111099,'117804','furniture','text','Our Replacement Department will process your request.',0,''),(348086,111099,'117804','furniture','font-size','12',0,''),(348087,111099,'117804','furniture','padding-bottom','5',0,''),(348088,111100,'117805','furniture','block_type','9',0,''),(348089,111101,'117806','furniture','text','3.',0,''),(348090,111101,'117806','furniture','font-size','12',0,''),(348091,111101,'117806','furniture','text-align','right',0,''),(348092,111101,'117806','furniture','margin-right','5',0,''),(348093,111102,'117807','furniture','text','Return the authorized item(s) per shipping instructions.',0,''),(348094,111102,'117807','furniture','font-size','12',0,''),(348095,111102,'117807','furniture','padding-bottom','5',0,''),(348096,111103,'117808','furniture','block_type','9',0,''),(348097,111104,'117809','furniture','text','2.',0,''),(348098,111104,'117809','furniture','font-size','12',0,''),(348099,111104,'117809','furniture','text-align','right',0,''),(348100,111104,'117809','furniture','margin-right','5',0,''),(348101,111105,'117810','furniture','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(348102,111105,'117810','furniture','font-size','12',0,''),(348103,111105,'117810','furniture','padding-bottom','5',0,''),(348104,111106,'117811','furniture','block_type','1',0,''),(348105,111106,'117811','furniture','padding-left','15',0,''),(348106,111107,'117812','furniture','text','Replacement Policy:',0,''),(348107,111107,'117812','furniture','font-size','14',0,''),(348108,111107,'117812','furniture','padding-bottom','5',0,''),(348109,111107,'117812','furniture','font-weight','bold',0,''),(348110,111108,'117813','furniture','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(348111,111108,'117813','furniture','font-size','11',0,''),(348112,111108,'117813','furniture','font-style','italic',0,''),(348113,111108,'117813','furniture','padding-bottom','5',0,''),(348114,111109,'117814','furniture','block_type','1',0,''),(348115,111109,'117814','furniture','border-bottom-width','1',0,''),(348116,111109,'117814','furniture','border-bottom-color','$content-border-2',0,''),(348117,111110,'117815','furniture','text','Return Material Authorization (RMA) Form',0,''),(348118,111110,'117815','furniture','text-align','center',0,''),(348119,111110,'117815','furniture','font-size','16',0,''),(348120,111110,'117815','furniture','font-weight','bold',0,''),(348121,111111,'117816','furniture','text-align','center',0,''),(348123,111111,'117816','furniture','padding-top','10',0,''),(348124,111111,'117816','furniture','padding-bottom','10',0,''),(348128,111112,'117817','furniture','block_type','1',0,''),(348129,111112,'117817','furniture','padding-top','10',0,''),(348130,111112,'117817','furniture','padding-left','10',0,''),(348131,111112,'117817','furniture','padding-right','10',0,''),(348132,111112,'117817','furniture','padding-bottom','20',0,''),(348133,111113,'117818','furniture','block_type','2',0,''),(348134,111113,'117818','furniture','padding-top','5',0,''),(348135,111114,'117819','furniture','block_type','11',0,''),(348136,111115,'117820','furniture','text','Email:',0,''),(348137,111115,'117820','furniture','font-size','12',0,''),(348138,111116,'117821','furniture','data','rrDelivery_email_address',0,''),(348139,111116,'117821','furniture','font-size','12',0,''),(348140,111117,'117822','furniture','block_type','11',0,''),(348141,111118,'117823','furniture','text','Phone:',0,''),(348142,111118,'117823','furniture','font-size','12',0,''),(348143,111119,'117824','furniture','data','rrDelivery_telephone',0,''),(348144,111119,'117824','furniture','font-size','12',0,''),(348145,111120,'117825','furniture','block_type','2',0,''),(348146,111120,'117825','furniture','padding-top','5',0,''),(348147,111121,'117826','furniture','block_type','11',0,''),(348148,111122,'117827','furniture','text','Country:',0,''),(348149,111122,'117827','furniture','font-size','12',0,''),(348150,111123,'117828','furniture','data','rrDelivery_country',0,''),(348151,111123,'117828','furniture','font-size','12',0,''),(348152,111124,'117829','furniture','block_type','11',0,''),(348153,111125,'117830','furniture','text','Postcode:',0,''),(348154,111125,'117830','furniture','font-size','12',0,''),(348155,111126,'117831','furniture','data','rrDelivery_postcode',0,''),(348156,111126,'117831','furniture','font-size','12',0,''),(348157,111127,'117832','furniture','block_type','2',0,''),(348158,111127,'117832','furniture','padding-top','5',0,''),(348159,111128,'117833','furniture','block_type','11',0,''),(348160,111129,'117834','furniture','text','City:',0,''),(348161,111129,'117834','furniture','font-size','12',0,''),(348162,111130,'117835','furniture','data','rrDelivery_city',0,''),(348163,111130,'117835','furniture','font-size','12',0,''),(348164,111131,'117836','furniture','block_type','11',0,''),(348165,111132,'117837','furniture','text','State:',0,''),(348166,111132,'117837','furniture','font-size','12',0,''),(348167,111133,'117838','furniture','data','rrDelivery_state',0,''),(348168,111133,'117838','furniture','font-size','12',0,''),(348169,111134,'117839','furniture','block_type','9',0,''),(348170,111134,'117839','furniture','padding-top','5',0,''),(348171,111135,'117840','furniture','text','Address:',0,''),(348172,111135,'117840','furniture','font-size','12',0,''),(348173,111136,'117841','furniture','data','rrDelivery_street_address',0,''),(348174,111136,'117841','furniture','font-size','12',0,''),(348175,111137,'117842','furniture','block_type','2',0,''),(348176,111138,'117843','furniture','block_type','11',0,''),(348177,111139,'117844','furniture','text','Company:',0,''),(348178,111139,'117844','furniture','font-size','12',0,''),(348179,111140,'117845','furniture','data','rrDelivery_company',0,''),(348180,111140,'117845','furniture','font-size','12',0,''),(348181,111141,'117846','furniture','block_type','2',0,''),(348182,111142,'117847','furniture','text','Contact Name:',0,''),(348183,111142,'117847','furniture','font-size','12',0,''),(348184,111143,'117848','furniture','data','rrDelivery_name',0,''),(348185,111143,'117848','furniture','font-size','12',0,''),(348186,111144,'117849','furniture','block_type','2',0,''),(348187,111144,'117849','furniture','padding-left','10',0,''),(348188,111144,'117849','furniture','padding-top','20',0,''),(348189,111144,'117849','furniture','padding-right','10',0,''),(348190,111145,'117850','furniture','block_type','5',0,''),(348191,111146,'117851','furniture','text','RMA No:',0,''),(348192,111146,'117851','furniture','font-size','12',0,''),(348193,111146,'117851','furniture','font-weight','bold',0,''),(348194,111147,'117852','furniture','data','rrNumber',0,''),(348195,111147,'117852','furniture','font-size','12',0,''),(348196,111147,'117852','furniture','font-weight','bold',0,''),(348197,111148,'117853','furniture','block_type','2',0,''),(348198,111149,'117854','furniture','text','Date Issued:',0,''),(348199,111149,'117854','furniture','font-size','12',0,''),(348200,111149,'117854','furniture','font-weight','bold',0,''),(348201,111150,'117855','furniture','data','rrDateCreate',0,''),(348202,111150,'117855','furniture','font-size','12',0,''),(348203,111150,'117855','furniture','font-weight','bold',0,''),(348204,111151,'117856','furniture','block_type','1',0,''),(348205,111152,'117857','furniture','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(348206,111152,'117857','furniture','font-size','12',0,''),(348207,111152,'117857','furniture','font-style','italic',0,''),(348208,111152,'117857','furniture','padding-bottom','20',0,''),(348209,111154,'117859','furniture','block_type','1',0,''),(348210,111154,'117859','furniture','border-top-width','1',0,''),(348211,111154,'117859','furniture','border-left-width','1',0,''),(348212,111154,'117859','furniture','border-right-width','1',0,''),(348213,111154,'117859','furniture','border-bottom-width','1',0,''),(348214,111154,'117859','furniture','border-top-color','$content-border-2',0,''),(348215,111154,'117859','furniture','border-left-color','$content-border-2',0,''),(348216,111154,'117859','furniture','border-right-color','$content-border-2',0,''),(348217,111154,'117859','furniture','border-bottom-color','$content-border-2',0,''),(348218,111155,'117860','furniture','block_type','11',0,''),(348219,111156,'117861','furniture','block_type','1',0,''),(348220,111156,'117861','furniture','padding-top','10',0,''),(348221,111156,'117861','furniture','padding-right','10',0,''),(348222,111156,'117861','furniture','padding-bottom','10',0,''),(348223,111156,'117861','furniture','border-right-width','1',0,''),(348224,111156,'117861','furniture','border-right-color','$content-border-2',0,''),(348225,111157,'117862','furniture','block_type','9',0,''),(348226,111158,'117863','furniture','text','4.',0,''),(348227,111158,'117863','furniture','font-size','12',0,''),(348228,111158,'117863','furniture','text-align','right',0,''),(348229,111158,'117863','furniture','padding-right','5',0,''),(348230,111159,'117864','furniture','font-size','11',0,''),(348231,111159,'117864','furniture','font-style','italic',0,''),(348232,111159,'117864','furniture','padding-bottom','5',0,''),(348233,111160,'117865','furniture','text','Ship returned items to:',0,''),(348234,111160,'117865','furniture','font-size','12',0,''),(348235,111160,'117865','furniture','padding-bottom','5',0,''),(348236,111161,'117866','furniture','block_type','9',0,''),(348237,111162,'117867','furniture','text','3.',0,''),(348238,111162,'117867','furniture','font-size','12',0,''),(348239,111162,'117867','furniture','text-align','right',0,''),(348240,111162,'117867','furniture','padding-right','5',0,''),(348241,111163,'117868','furniture','text','Ship only the items that are authorized.',0,''),(348242,111163,'117868','furniture','font-size','12',0,''),(348243,111163,'117868','furniture','padding-bottom','10',0,''),(348244,111164,'117869','furniture','block_type','9',0,''),(348245,111165,'117870','furniture','text','1.',0,''),(348246,111165,'117870','furniture','font-size','12',0,''),(348247,111165,'117870','furniture','text-align','right',0,''),(348248,111165,'117870','furniture','padding-right','5',0,''),(348249,111166,'117871','furniture','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(348250,111166,'117871','furniture','font-size','12',0,''),(348251,111166,'117871','furniture','padding-bottom','10',0,''),(348252,111167,'117872','furniture','block_type','1',0,''),(348253,111168,'117873','furniture','text','Shipping Instructions:',0,''),(348254,111168,'117873','furniture','font-weight','bold',0,''),(348255,111168,'117873','furniture','font-size','14',0,''),(348256,111168,'117873','furniture','padding-bottom','5',0,''),(348257,111168,'117873','furniture','padding-left','10',0,''),(348258,111169,'117874','furniture','block_type','9',0,''),(348259,111170,'117875','furniture','text','2.',0,''),(348260,111170,'117875','furniture','font-size','12',0,''),(348261,111170,'117875','furniture','text-align','right',0,''),(348262,111170,'117875','furniture','padding-right','5',0,''),(348263,111171,'117876','furniture','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(348264,111171,'117876','furniture','font-size','12',0,''),(348265,111171,'117876','furniture','padding-bottom','10',0,''),(348266,111172,'117877','furniture','block_type','1',0,''),(348267,111172,'117877','furniture','padding-left','10',0,''),(348268,111172,'117877','furniture','padding-right','10',0,''),(348269,111172,'117877','furniture','padding-bottom','10',0,''),(348270,111173,'117878','furniture','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(348271,111173,'117878','furniture','font-size','11',0,''),(348272,111173,'117878','furniture','font-style','italic',0,''),(348273,111174,'117879','furniture','block_type','1',0,''),(348274,111174,'117879','furniture','padding-top','10',0,''),(348275,111174,'117879','furniture','padding-left','40',0,''),(348276,111174,'117879','furniture','padding-right','40',0,''),(348277,111174,'117879','furniture','padding-bottom','10',0,''),(348278,111175,'117880','furniture','block_type','1',0,''),(348279,111175,'117880','furniture','padding-top','10',0,''),(348280,111175,'117880','furniture','padding-left','10',0,''),(348281,111175,'117880','furniture','padding-right','10',0,''),(348282,111175,'117880','furniture','padding-bottom','10',0,''),(348283,111175,'117880','furniture','border-top-width','1',0,''),(348284,111175,'117880','furniture','border-left-width','1',0,''),(348285,111175,'117880','furniture','border-right-width','1',0,''),(348286,111175,'117880','furniture','border-bottom-width','1',0,''),(348287,111175,'117880','furniture','border-top-color','$content-border-2',0,''),(348288,111175,'117880','furniture','border-left-color','$content-border-2',0,''),(348289,111175,'117880','furniture','border-right-color','$content-border-2',0,''),(348290,111175,'117880','furniture','border-bottom-color','$content-border-2',0,''),(348291,111176,'117881','furniture','block_type','3',0,''),(348292,111177,'117882','furniture','data','rrDelivery_name',0,''),(348293,111177,'117882','furniture','font-size','9',0,''),(348294,111178,'117883','furniture','block_type','2',0,''),(348295,111179,'117884','furniture','text','RMA#:',0,''),(348296,111179,'117884','furniture','font-size','10',0,''),(348297,111180,'117885','furniture','data','rrNumber',0,''),(348298,111180,'117885','furniture','font-size','9',0,''),(348299,111181,'117886','furniture','block_type','5',0,''),(348300,111182,'117887','furniture','font-size','9',0,''),(348301,111183,'117888','furniture','block_type','1',0,''),(348302,111183,'117888','furniture','padding-left','10',0,''),(348303,111183,'117888','furniture','padding-right','10',0,''),(348304,111183,'117888','furniture','padding-bottom','10',0,''),(348305,111184,'117889','furniture','text','Use this space for additional Comments:',0,''),(348306,111184,'117889','furniture','font-size','11',0,''),(348307,111184,'117889','furniture','font-style','italic',0,''),(348308,111185,'117890','furniture','text','&nbsp;',0,''),(348309,111185,'117890','furniture','border-bottom-width','1',0,''),(348310,111185,'117890','furniture','border-bottom-color','$content-border-2',0,''),(348311,111186,'117891','furniture','text','&nbsp;',0,''),(348312,111186,'117891','furniture','border-bottom-width','1',0,''),(348313,111186,'117891','furniture','border-bottom-color','$content-border-2',0,''),(348314,111186,'117891','furniture','padding-top','5',0,''),(348315,111187,'117892','furniture','text','&nbsp;',0,''),(348316,111187,'117892','furniture','border-bottom-width','1',0,''),(348317,111187,'117892','furniture','border-bottom-color','$content-border-2',0,''),(348318,111187,'117892','furniture','padding-top','5',0,''),(348319,111188,'117893','furniture','text','&nbsp;',0,''),(348320,111188,'117893','furniture','border-bottom-width','1',0,''),(348321,111188,'117893','furniture','border-bottom-color','$content-border-2',0,''),(348322,111188,'117893','furniture','padding-top','5',0,''),(348323,111189,'117894','furniture','block_type','3',0,''),(348324,111189,'117894','furniture','padding-top','10',0,''),(348325,111189,'117894','furniture','padding-bottom','10',0,''),(348326,111189,'117894','furniture','padding-right','10',0,''),(348327,111190,'117895','furniture','font-size','11',0,''),(348328,111190,'117895','furniture','font-weight','bold',0,''),(348329,111190,'117895','furniture','text','Return Approval:',0,''),(348330,111190,'117895','furniture','padding-top','5',0,''),(348331,111190,'117895','furniture','padding-left','10',0,''),(348332,111191,'117896','furniture','border-bottom-width','1',0,''),(348333,111191,'117896','furniture','border-bottom-color','$content-border-2',0,''),(348334,111191,'117896','furniture','text','&nbsp;',0,''),(348335,111192,'117897','furniture','block_type','5',0,''),(348336,111193,'117898','furniture','text','Date:',0,''),(348337,111193,'117898','furniture','padding-top','5',0,''),(348338,111193,'117898','furniture','font-size','11',0,''),(348339,111193,'117898','furniture','font-weight','bold',0,''),(348340,111193,'117898','furniture','padding-left','5',0,''),(348341,111194,'117899','furniture','text','&nbsp;',0,''),(348342,111194,'117899','furniture','border-bottom-width','1',0,''),(348343,111194,'117899','furniture','border-bottom-color','$content-border-2',0,''),(348344,111195,'117900','furniture','block_type','3',0,''),(348345,111195,'117900','furniture','padding-right','10',0,''),(348346,111196,'117901','furniture','text','Customer Signature:',0,''),(348347,111196,'117901','furniture','font-weight','bold',0,''),(348348,111196,'117901','furniture','font-size','11',0,''),(348349,111196,'117901','furniture','padding-top','5',0,''),(348350,111196,'117901','furniture','padding-left','10',0,''),(348351,111197,'117902','furniture','text','&nbsp;',0,''),(348352,111197,'117902','furniture','border-bottom-width','1',0,''),(348353,111197,'117902','furniture','border-bottom-color','$content-border-2',0,''),(348354,111198,'117903','furniture','block_type','5',0,''),(348355,111199,'117904','furniture','text','Date:',0,''),(348356,111199,'117904','furniture','padding-top','5',0,''),(348357,111199,'117904','furniture','font-size','11',0,''),(348358,111199,'117904','furniture','font-weight','bold',0,''),(348359,111199,'117904','furniture','padding-left','5',0,''),(348360,111200,'117905','furniture','text','&nbsp;',0,''),(348361,111200,'117905','furniture','border-bottom-width','1',0,''),(348362,111200,'117905','furniture','border-bottom-color','$content-border-2',0,''),(348363,111201,'117906','furniture','block_type','1',0,''),(348364,111201,'117906','furniture','style_class','item-holder',0,''),(348365,111201,'117906','furniture','padding-top','25',0,''),(348366,111201,'117906','furniture','padding-bottom','25',0,''),(348367,111201,'117906','furniture','text-align','left',0,''),(348368,111201,'117906','furniture','border-top-width','1',0,''),(348369,111201,'117906','furniture','border-top-color','$content-border-1',0,''),(348370,111202,'117907','furniture','block_type','7',0,''),(348371,111202,'117907','furniture','schema','7-2',0,'5140'),(348372,111203,'117908','furniture','block_type','5',0,''),(348373,111203,'117908','furniture','schema','5-2',0,'5140'),(348374,111204,'117909','furniture','clear','none',0,''),(348375,111204,'117909','furniture','padding-right','20',0,''),(348376,111205,'117910','furniture','padding-right','20',0,''),(348377,111205,'117910','furniture','max-width','300',0,'5140'),(348378,111205,'117910','furniture','margin_left_measure','auto',0,'5140'),(348379,111205,'117910','furniture','margin_right_measure','auto',0,'5140'),(348380,111206,'117914','furniture','padding-right','20',0,''),(348381,111207,'117915','furniture','description_characters','200',0,''),(348382,111207,'117915','furniture','clear','none',0,''),(348383,111207,'117915','furniture','padding-right','20',0,''),(348384,111208,'117916','furniture','clear','none',0,''),(348385,111209,'117917','furniture','margin-bottom','20',0,''),(348386,111212,'117918','furniture','block_type','1',0,''),(348387,111212,'117918','furniture','padding-left','40',0,''),(348388,111212,'117918','furniture','style_class','right-aria',0,''),(348389,111212,'117918','furniture','padding-left','0',0,'5140'),(348390,111213,'117911','furniture','block_type','1',0,''),(348391,111213,'117911','furniture','text-align','center',0,''),(348392,111214,'117912','furniture','margin-top','4',0,''),(348393,111214,'117912','furniture','margin-bottom','7',0,''),(348394,111215,'117913','furniture','padding-top','6',0,''),(348395,111215,'117913','furniture','padding-left','5',0,''),(348396,111216,'117919','furniture','margin-bottom','15',0,''),(348397,111216,'117919','furniture','text-align','right',0,''),(348398,111217,'117920','furniture','margin-bottom','10',0,''),(348399,111217,'117920','furniture','text-align','center',0,''),(348400,111218,'117922','furniture','text-align','right',0,''),(348401,111218,'117922','furniture','margin-bottom','15',0,''),(348402,111219,'117924','furniture','text-align','center',0,''),(348403,111219,'117924','furniture','margin-bottom','10',0,''),(348404,111220,'120924','furniture','block_type','1',0,''),(348405,111220,'120924','furniture','style_class','item-nav',0,''),(348406,111224,'117925','furniture','block_type','1',0,''),(348407,111224,'117925','furniture','padding-top','20',0,''),(348408,111224,'117925','furniture','padding-bottom','20',0,''),(348409,111224,'117925','furniture','background-color','$content-bg-2',0,''),(348410,111226,'117927','furniture','block_type','7',0,''),(348411,111226,'117927','furniture','schema','4-2',0,'5140'),(348412,111227,'117928','furniture','padding-bottom','20',0,''),(348413,111227,'117928','furniture','background-color','$content-bg-1',0,''),(348414,111228,'117929','furniture','style_class','order-summary',0,''),(348415,111228,'117929','furniture','padding-left','25',0,''),(348416,111228,'117929','furniture','block_type','1',0,''),(348417,111228,'117929','furniture','padding-left','0',0,'5140'),(348418,111228,'117929','furniture','margin-top','30',0,'5140'),(348419,111229,'117930','furniture','block_type','1',0,''),(348420,111229,'117930','furniture','padding-left','20',0,''),(348421,111229,'117930','furniture','padding-right','20',0,''),(348422,111229,'117930','furniture','padding-bottom','20',0,''),(348423,111229,'117930','furniture','padding-top','20',0,''),(348424,111230,'117931','furniture','max-width','300',0,'5140'),(348425,111230,'117931','furniture','margin_left_measure','auto',0,'5140'),(348426,111230,'117931','furniture','margin_right_measure','auto',0,'5140'),(348427,111231,'117932','furniture','block_type','1',0,''),(348428,111231,'117932','furniture','style_class','account-samples',0,''),(348429,111232,'117933','furniture','block_type','6',0,''),(348430,111232,'117933','furniture','schema','6-3',0,'5140'),(348431,111233,'117934','furniture','aria_name','account-menu',0,''),(348489,111253,'117935','furniture','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(348490,111254,'117936','furniture','show_pagenation','1',0,''),(348491,111254,'117936','furniture','link','Sample Info',0,''),(348492,111254,'117936','furniture','margin-bottom','20',0,''),(348493,111255,'117937','furniture','block_type','1',0,''),(348494,111255,'117937','furniture','style_class','account-sample-info',0,''),(348495,111256,'117938','furniture','block_type','6',0,''),(348496,111256,'117938','furniture','schema','6-3',0,'5140'),(348497,111257,'117939','furniture','aria_name','account-menu',0,''),(348555,111277,'117940','furniture','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(348556,111278,'117941','furniture','block_type','2',0,''),(348557,111278,'117941','furniture','padding-top','20',0,''),(348558,111278,'117941','furniture','margin-bottom','20',0,''),(348559,111279,'117942','furniture','like_button','1',0,''),(348560,111279,'117942','furniture','text','IMAGE_BUTTON_BACK',0,''),(348561,111279,'117942','furniture','link','Samples',0,''),(348562,111281,'117944','furniture','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(348563,111284,'117947','furniture','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(348564,111285,'117948','furniture','block_type','3',0,''),(348565,111286,'117949','furniture','block_type','1',0,''),(348566,111286,'117949','furniture','padding-right','20',0,''),(348567,111286,'117949','furniture','padding-bottom','20',0,''),(348568,111287,'117950','furniture','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(348569,111288,'117951','furniture','orders_data','telephone',0,''),(348570,111289,'117952','furniture','block_type','1',0,''),(348571,111289,'117952','furniture','padding-right','20',0,''),(348572,111289,'117952','furniture','padding-bottom','20',0,''),(348573,111290,'117953','furniture','orders_data','name',0,''),(348574,111291,'117954','furniture','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(348575,111292,'117955','furniture','block_type','1',0,''),(348576,111292,'117955','furniture','padding-right','20',0,''),(348577,111293,'117956','furniture','orders_data','shipping_method',0,''),(348578,111294,'117957','furniture','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(348579,111295,'117958','furniture','block_type','1',0,''),(348580,111295,'117958','furniture','padding-right','20',0,''),(348581,111295,'117958','furniture','padding-bottom','20',0,''),(348582,111296,'117959','furniture','orders_data','delivery_address',0,''),(348583,111297,'117960','furniture','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(348584,111298,'117961','furniture','block_type','1',0,''),(348585,111299,'117962','furniture','orders_data','payment_method',0,''),(348586,111300,'117963','furniture','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(348587,111301,'117964','furniture','block_type','1',0,''),(348588,111301,'117964','furniture','padding-bottom','20',0,''),(348589,111302,'117965','furniture','orders_data','billing_address',0,''),(348590,111303,'117966','furniture','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(348591,111304,'117967','furniture','block_type','1',0,''),(348592,111305,'117968','furniture','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(348593,111306,'117969','furniture','block_type','6',0,''),(348594,111307,'117970','furniture','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(348595,111308,'117971','furniture','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(348596,111309,'117972','furniture','text','<div class=\"heading-4\">Categories</div>',0,''),(348597,111312,'117975','furniture','class','menu-simple',0,''),(348598,111314,'117977','furniture','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(348599,111315,'120878','furniture','float','left',0,''),(348600,111315,'120878','furniture','margin-right','10',0,''),(348601,111316,'117978','furniture','block_type','1',0,''),(348602,111317,'117979','furniture','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(348603,111317,'117979','furniture','style_class','middle-form',0,''),(348604,111318,'117980','furniture','style_class','middle-form',0,''),(348605,111319,'117981','furniture','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(348606,111320,'117982','furniture','style_class','middle-form',0,''),(348607,111320,'117982','furniture','margin-bottom','30',0,''),(348608,111321,'117983','furniture','block_type','1',0,''),(348609,111322,'117984','furniture','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(348610,111322,'117984','furniture','padding-top','100',0,''),(348611,111322,'117984','furniture','margin-bottom','100',0,''),(348612,111322,'117984','furniture','text-align','center',0,''),(348613,111322,'117984','furniture','font-size','20',0,''),(348614,111323,'117985','furniture','block_type','1',0,''),(348615,111324,'117986','furniture','block_type','6',0,''),(348616,111324,'117986','furniture','schema','6-3',0,'5140'),(348617,111325,'117987','furniture','aria_name','account-menu',0,''),(348675,111345,'117988','furniture','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(348676,111346,'117989','furniture','text','##SUBSCRIPTION_TEXT##',0,''),(348677,111348,'1695216662.204376','furniture','block_type','1',0,''),(348678,111348,'1695216662.204376','furniture','background-color','$content-bg-2',0,''),(348679,111348,'1695216662.204376','furniture','padding-bottom','30',0,''),(348680,111348,'1695216662.204376','furniture','style_class','success-page',0,''),(348681,111348,'1695216662.204376','furniture','color','$content-color-2',0,''),(348682,111349,'1695216662.283842','furniture','block_type','12',0,''),(348683,111349,'1695216662.283842','furniture','schema','4-2',0,'5140'),(348684,111350,'1695216662.28679','furniture','block_type','1',0,''),(348685,111350,'1695216662.28679','furniture','padding-right','40',0,''),(348686,111350,'1695216662.28679','furniture','padding-right','0',0,'5140'),(348687,111351,'1695216662.287367','furniture','block_type','2',0,''),(348688,111351,'1695216662.287367','furniture','margin-bottom','20',0,''),(348689,111351,'1695216662.287367','furniture','schema','2-2',0,'5131'),(348690,111351,'1695216662.287367','furniture','background-color','$content-bg-1',0,''),(348691,111351,'1695216662.287367','furniture','color','$content-color-1',0,''),(348692,111352,'1695216662.28994','furniture','block_type','1',0,''),(348693,111352,'1695216662.28994','furniture','border-right-width','20',0,''),(348694,111352,'1695216662.28994','furniture','border-right-color','$content-bg-2',0,''),(348695,111352,'1695216662.28994','furniture','margin-right','-10',0,''),(348696,111352,'1695216662.28994','furniture','padding-right','30',0,''),(348697,111352,'1695216662.28994','furniture','padding-top','20',0,''),(348698,111352,'1695216662.28994','furniture','padding-left','30',0,''),(348699,111352,'1695216662.28994','furniture','padding-bottom','20',0,''),(348700,111352,'1695216662.28994','furniture','border-right-width','0',0,'5140'),(348701,111352,'1695216662.28994','furniture','margin-right','0',0,'5140'),(348702,111352,'1695216662.28994','furniture','margin-bottom','20',0,'5140'),(348703,111352,'1695216662.28994','furniture','padding-left','20',0,'5140'),(348704,111352,'1695216662.28994','furniture','padding-right','20',0,'5140'),(348705,111352,'1695216662.28994','furniture','border-top-color','$content-bg-2',0,''),(348706,111354,'1695216662.293199','furniture','margin-bottom','20',0,''),(348707,111355,'1695216662.294382','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(348708,111355,'1695216662.294382','furniture','padding-top','20',0,''),(348709,111356,'1695216662.301223','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(348710,111356,'1695216662.301223','furniture','clear','none',0,''),(348711,111357,'1695216662.303717','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(348712,111359,'1695216662.306549','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(348713,111359,'1695216662.306549','furniture','clear','none',0,''),(348714,111360,'1695216662.308881','furniture','block_type','1',0,''),(348715,111360,'1695216662.308881','furniture','padding-left','30',0,''),(348716,111360,'1695216662.308881','furniture','border-left-width','20',0,''),(348717,111360,'1695216662.308881','furniture','border-left-color','$content-bg-2',0,''),(348718,111360,'1695216662.308881','furniture','margin-left','-10',0,''),(348719,111360,'1695216662.308881','furniture','padding-right','30',0,''),(348720,111360,'1695216662.308881','furniture','padding-top','20',0,''),(348721,111360,'1695216662.308881','furniture','padding-bottom','20',0,''),(348722,111360,'1695216662.308881','furniture','border-left-width','0',0,'5140'),(348723,111362,'1695216662.311766','furniture','margin-bottom','20',0,''),(348724,111363,'1695216662.312915','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(348725,111363,'1695216662.312915','furniture','clear','none',0,''),(348726,111364,'1695216662.314711','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(348727,111365,'1695216662.316646','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(348728,111365,'1695216662.316646','furniture','clear','none',0,''),(348729,111366,'1695216662.31980','furniture','text','<div class=\"page-success\">\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>',0,''),(348730,111366,'1695216662.31980','furniture','background-color','$content-bg-1',0,''),(348731,111366,'1695216662.31980','furniture','margin-bottom','30',0,''),(348732,111366,'1695216662.31980','furniture','padding-top','30',0,''),(348733,111366,'1695216662.31980','furniture','padding-bottom','30',0,''),(348734,111366,'1695216662.31980','furniture','padding-left','30',0,''),(348735,111366,'1695216662.31980','furniture','padding-right','30',0,''),(348736,111366,'1695216662.31980','furniture','color','$content-color-1',0,''),(348737,111367,'1695216662.322253','furniture','block_type','1',0,''),(348738,111367,'1695216662.322253','furniture','style_class','order-summary2 hiding-box',0,''),(348739,111368,'1695216662.323587','furniture','text-align','center',0,''),(348740,111368,'1695216662.323587','furniture','margin-bottom','20',0,''),(348741,111369,'1695216662.325129','furniture','text-align','center',0,''),(348742,111372,'1695216662.335222','furniture','block_type','12',0,''),(348743,111373,'1695216662.336556','furniture','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n</div>\n',0,''),(348744,111373,'1695216662.336556','furniture','margin-bottom','20',0,''),(348745,111374,'1695216662.338898','furniture','text-align','center',0,''),(348746,111374,'1695216662.338898','furniture','padding-top','40',0,''),(348747,111375,'117997','furniture','block_type','1',0,''),(348748,111376,'117998','furniture','block_type','1',0,''),(348749,111376,'117998','furniture','font-weight','normal',0,''),(348750,111377,'117999','furniture','block_type','1',0,''),(348751,111377,'117999','furniture','text-align','center',0,''),(348752,111377,'117999','furniture','padding-top','30',0,''),(348753,111377,'117999','furniture','margin-bottom','200',0,''),(348754,111378,'118000','furniture','display','inline-block',0,''),(348755,111378,'118000','furniture','clear','none',0,''),(348756,111378,'118000','furniture','margin-left','20',0,''),(348757,111379,'118001','furniture','display','inline-block',0,''),(348758,111380,'118002','furniture','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(348763,111385,'118007','furniture','width','680',0,''),(348764,111385,'118007','furniture','font-weight','normal',0,''),(348765,111385,'118007','furniture','font-size','12',0,''),(348766,111385,'118007','furniture','padding-top','20',0,''),(348767,111385,'118007','furniture','padding-bottom','20',0,''),(348768,111385,'118007','furniture','color','$content-color-1',0,''),(348769,111386,'118008','furniture','block_type','5',0,''),(348770,111386,'118008','furniture','font-weight','normal',0,''),(348771,111386,'118008','furniture','border-bottom-width','1',0,''),(348772,111386,'118008','furniture','border-bottom-color','$content-border-1',0,''),(348773,111386,'118008','furniture','border-top-width','1',0,''),(348774,111386,'118008','furniture','border-top-color','$content-border-1',0,''),(348775,111386,'118008','furniture','border-left-color','$content-border-1',0,''),(348776,111386,'118008','furniture','border-left-width','1',0,''),(348777,111387,'118009','furniture','block_type','1',0,''),(348778,111387,'118009','furniture','font-weight','normal',0,''),(348779,111387,'118009','furniture','padding-top','10',0,''),(348780,111387,'118009','furniture','padding-left','10',0,''),(348781,111387,'118009','furniture','padding-right','10',0,''),(348782,111388,'118010','furniture','font-weight','400',0,''),(348783,111388,'118010','furniture','line-height','120',0,''),(348784,111388,'118010','furniture','line_height_measure','%',0,''),(348785,111388,'118010','furniture','font-size','12',0,''),(348786,111389,'118011','furniture','text','<p>SHIPPING ADDRESS:</p>',1,''),(348787,111389,'118011','furniture','font-size','14',0,''),(348788,111389,'118011','furniture','font-weight','bold',0,''),(348789,111389,'118011','furniture','padding-bottom','10',0,''),(348790,111389,'118011','furniture','text','<p>SHIPPING ADDRESS:</p>',2,''),(348791,111389,'118011','furniture','text','<p>SHIPPING ADDRESS:</p>',3,''),(348792,111389,'118011','furniture','text','<p>SHIPPING ADDRESS:</p>',4,''),(348793,111390,'118012','furniture','block_type','1',0,''),(348794,111390,'118012','furniture','background-color','$content-bg-2',0,''),(348795,111390,'118012','furniture','padding-top','20',0,''),(348796,111390,'118012','furniture','padding-left','10',0,''),(348797,111390,'118012','furniture','padding-right','10',0,''),(348798,111390,'118012','furniture','padding-bottom','20',0,''),(348799,111390,'118012','furniture','font-size','14',0,''),(348800,111391,'118013','furniture','font-weight','normal',0,''),(348801,111391,'118013','furniture','text-align','right',0,''),(348802,111391,'118013','furniture','font-size','14',0,''),(348803,111391,'118013','furniture','box_align','3',0,''),(348804,111392,'118014','furniture','block_type','3',0,''),(348805,111392,'118014','furniture','font-weight','normal',0,''),(348806,111392,'118014','furniture','padding-top','20',0,''),(348807,111393,'118015','furniture','text','<p>If undelivered please return to:</p>',1,''),(348808,111393,'118015','furniture','font-size','12',0,''),(348809,111393,'118015','furniture','font-weight','bold',0,''),(348810,111393,'118015','furniture','text','<p>If undelivered please return to:</p>',2,''),(348811,111393,'118015','furniture','text','<p>If undelivered please return to:</p>',3,''),(348812,111393,'118015','furniture','text','<p>If undelivered please return to:</p>',4,''),(348813,111394,'118016','furniture','font-size','12',0,''),(348814,111395,'118018','furniture','text','<p>Thank you for your order</p>',1,''),(348815,111395,'118018','furniture','color','$content-color-1',0,''),(348816,111395,'118018','furniture','font-size','13',0,''),(348817,111395,'118018','furniture','font-weight','bold',0,''),(348818,111395,'118018','furniture','padding-top','5',0,''),(348819,111395,'118018','furniture','text-align','center',0,''),(348820,111395,'118018','furniture','text','<p>Thank you for your order</p>',2,''),(348821,111395,'118018','furniture','text','<p>Thank you for your order</p>',3,''),(348822,111395,'118018','furniture','text','<p>Thank you for your order</p>',4,''),(348823,111396,'118019','furniture','text','<p>If something has gone wrong please contact us at:</p>',1,''),(348824,111396,'118019','furniture','font-size','12',0,''),(348825,111396,'118019','furniture','font-weight','bold',0,''),(348826,111396,'118019','furniture','text-align','right',0,''),(348827,111396,'118019','furniture','text','<p>If something has gone wrong please contact us at:</p>',2,''),(348828,111396,'118019','furniture','text','<p>If something has gone wrong please contact us at:</p>',3,''),(348829,111396,'118019','furniture','text','<p>If something has gone wrong please contact us at:</p>',4,''),(348830,111397,'118020','furniture','block_type','6',0,''),(348831,111397,'118020','furniture','font-weight','normal',0,''),(348832,111397,'118020','furniture','font-size','16',0,''),(348833,111398,'118021','furniture','text','<p>Email:</p>',1,''),(348834,111398,'118021','furniture','font-weight','normal',0,''),(348835,111398,'118021','furniture','text-align','right',0,''),(348836,111398,'118021','furniture','font-size','12',0,''),(348837,111398,'118021','furniture','text','<p>Email:</p>',2,''),(348838,111398,'118021','furniture','text','<p>Email:</p>',3,''),(348839,111398,'118021','furniture','text','<p>Email:</p>',4,''),(348840,111399,'118022','furniture','font-weight','normal',0,''),(348841,111399,'118022','furniture','text-align','right',0,''),(348842,111399,'118022','furniture','font-size','12',0,''),(348843,111400,'118023','furniture','block_type','6',0,''),(348844,111400,'118023','furniture','font-weight','normal',0,''),(348845,111400,'118023','furniture','font-size','16',0,''),(348846,111401,'118024','furniture','text','<p>Phone:</p>',1,''),(348847,111401,'118024','furniture','font-weight','normal',0,''),(348848,111401,'118024','furniture','text-align','right',0,''),(348849,111401,'118024','furniture','font-size','12',0,''),(348850,111401,'118024','furniture','text','<p>Phone:</p>',2,''),(348851,111401,'118024','furniture','text','<p>Phone:</p>',3,''),(348852,111401,'118024','furniture','text','<p>Phone:</p>',4,''),(348853,111402,'118025','furniture','font-weight','normal',0,''),(348854,111402,'118025','furniture','text-align','right',0,''),(348855,111402,'118025','furniture','font-size','12',0,''),(348856,111403,'118026','furniture','font-weight','400',0,''),(348857,111403,'118026','furniture','padding-top','20',0,''),(348858,111403,'118026','furniture','padding-bottom','0',0,''),(348859,111403,'118026','furniture','font-size','12',0,''),(348860,111404,'118027','furniture','block_type','2',0,''),(348861,111404,'118027','furniture','font-weight','normal',0,''),(348862,111404,'118027','furniture','padding-bottom','20',0,''),(348863,111405,'118028','furniture','block_type','11',0,''),(348864,111405,'118028','furniture','font-weight','normal',0,''),(348865,111406,'118029','furniture','text','<p>Email:</p>',1,''),(348866,111406,'118029','furniture','font-weight','normal',0,''),(348867,111406,'118029','furniture','text-align','right',0,''),(348868,111406,'118029','furniture','text','<p>Email:</p>',2,''),(348869,111406,'118029','furniture','text','<p>Email:</p>',3,''),(348870,111406,'118029','furniture','text','<p>Email:</p>',4,''),(348871,111407,'118030','furniture','font-weight','normal',0,''),(348872,111407,'118030','furniture','text-align','right',0,''),(348873,111408,'118031','furniture','block_type','11',0,''),(348874,111408,'118031','furniture','font-weight','normal',0,''),(348875,111409,'118032','furniture','text','<p>Web:</p>',1,''),(348876,111409,'118032','furniture','font-weight','normal',0,''),(348877,111409,'118032','furniture','text-align','right',0,''),(348878,111409,'118032','furniture','text','<p>Web:</p>',2,''),(348879,111409,'118032','furniture','text','<p>Web:</p>',3,''),(348880,111409,'118032','furniture','text','<p>Web:</p>',4,''),(348881,111410,'118033','furniture','font-weight','normal',0,''),(348882,111410,'118033','furniture','text-align','right',0,''),(348883,111411,'118034','furniture','block_type','1',0,''),(348884,111412,'118035','furniture','font-weight','normal',0,''),(348885,111412,'118035','furniture','text-align','right',0,''),(348886,111412,'118035','furniture','padding-bottom','10',0,''),(348887,111412,'118035','furniture','address_spacer',',',0,''),(348888,111412,'118035','furniture','font-size','12',0,''),(348889,111413,'118036','furniture','block_type','11',0,''),(348890,111413,'118036','furniture','font-weight','normal',0,''),(348891,111414,'118037','furniture','text','<p>Phone:</p>',1,''),(348892,111414,'118037','furniture','font-weight','normal',0,''),(348893,111414,'118037','furniture','text-align','right',0,''),(348894,111414,'118037','furniture','text','<p>Phone:</p>',2,''),(348895,111414,'118037','furniture','text','<p>Phone:</p>',3,''),(348896,111414,'118037','furniture','text','<p>Phone:</p>',4,''),(348897,111415,'118038','furniture','font-weight','normal',0,''),(348898,111415,'118038','furniture','text-align','right',0,''),(348899,111416,'118039','furniture','block_type','4',0,''),(348900,111416,'118039','furniture','font-weight','normal',0,''),(348901,111416,'118039','furniture','border-top-width','1',0,''),(348902,111416,'118039','furniture','border-top-color','$content-border-1',0,''),(348903,111416,'118039','furniture','border-left-width','1',0,''),(348904,111416,'118039','furniture','border-left-color','$content-border-1',0,''),(348905,111416,'118039','furniture','border-right-width','1',0,''),(348906,111416,'118039','furniture','border-right-color','$content-border-1',0,''),(348907,111416,'118039','furniture','border-bottom-width','1',0,''),(348908,111416,'118039','furniture','border-bottom-color','$content-border-1',0,''),(348909,111417,'118040','furniture','block_type','2',0,''),(348910,111417,'118040','furniture','font-weight','normal',0,''),(348911,111417,'118040','furniture','border-top-width','1',0,''),(348912,111417,'118040','furniture','border-top-color','$content-border-1',0,''),(348913,111417,'118040','furniture','border-right-width','1',0,''),(348914,111417,'118040','furniture','border-right-color','$content-border-1',0,''),(348915,111418,'118041','furniture','block_type','1',0,''),(348916,111418,'118041','furniture','font-weight','normal',0,''),(348917,111418,'118041','furniture','padding-top','10',0,''),(348918,111418,'118041','furniture','padding-left','10',0,''),(348919,111418,'118041','furniture','padding-right','10',0,''),(348920,111418,'118041','furniture','padding-bottom','10',0,''),(348921,111418,'118041','furniture','border-right-width','1',0,''),(348922,111418,'118041','furniture','border-right-color','$content-border-1',0,''),(348923,111419,'118042','furniture','text','<p>Shipping via</p>',1,''),(348924,111419,'118042','furniture','font-weight','bold',0,''),(348925,111419,'118042','furniture','font-size','14',0,''),(348926,111419,'118042','furniture','text','<p>Shipping via</p>',2,''),(348927,111419,'118042','furniture','text','<p>Shipping via</p>',3,''),(348928,111419,'118042','furniture','text','<p>Shipping via</p>',4,''),(348929,111421,'118044','furniture','block_type','1',0,''),(348930,111421,'118044','furniture','font-weight','normal',0,''),(348931,111421,'118044','furniture','padding-top','10',0,''),(348932,111421,'118044','furniture','padding-left','10',0,''),(348933,111421,'118044','furniture','padding-right','10',0,''),(348934,111421,'118044','furniture','padding-bottom','10',0,''),(348935,111422,'118045','furniture','text','<p>Shipping service</p>',1,''),(348936,111422,'118045','furniture','font-weight','bold',0,''),(348937,111422,'118045','furniture','font-size','14',0,''),(348938,111422,'118045','furniture','text','<p>Shipping service</p>',2,''),(348939,111422,'118045','furniture','text','<p>Shipping service</p>',3,''),(348940,111422,'118045','furniture','text','<p>Shipping service</p>',4,''),(348941,111424,'118047','furniture','block_type','2',0,''),(348942,111424,'118047','furniture','font-weight','normal',0,''),(348943,111424,'118047','furniture','border-right-width','1',0,''),(348944,111424,'118047','furniture','border-right-color','$content-border-1',0,''),(348945,111425,'118048','furniture','block_type','1',0,''),(348946,111425,'118048','furniture','font-weight','400',0,''),(348947,111425,'118048','furniture','background-color','$content-bg-2',0,''),(348948,111425,'118048','furniture','padding-top','10',0,''),(348949,111425,'118048','furniture','padding-left','10',0,''),(348950,111425,'118048','furniture','padding-right','10',0,''),(348951,111425,'118048','furniture','padding-bottom','30',0,''),(348952,111426,'118049','furniture','font-size','12',0,''),(348953,111427,'118050','furniture','text','<p>INVOICE ADDRESS:</p>',1,''),(348954,111427,'118050','furniture','font-size','14',0,''),(348955,111427,'118050','furniture','font-weight','bold',0,''),(348956,111427,'118050','furniture','text','<p>INVOICE ADDRESS:</p>',2,''),(348957,111427,'118050','furniture','text','<p>INVOICE ADDRESS:</p>',3,''),(348958,111427,'118050','furniture','text','<p>INVOICE ADDRESS:</p>',4,''),(348959,111428,'118051','furniture','block_type','1',0,''),(348960,111428,'118051','furniture','font-weight','normal',0,''),(348961,111428,'118051','furniture','padding-top','10',0,''),(348962,111428,'118051','furniture','padding-left','10',0,''),(348963,111428,'118051','furniture','padding-right','10',0,''),(348964,111428,'118051','furniture','padding-bottom','10',0,''),(348965,111429,'118052','furniture','font-weight','normal',0,''),(348966,111430,'118053','furniture','text','<p>PHONE NUMBER:</p>',1,''),(348967,111430,'118053','furniture','font-size','14',0,''),(348968,111430,'118053','furniture','font-weight','bold',0,''),(348969,111430,'118053','furniture','padding-top','10',0,''),(348970,111430,'118053','furniture','text','<p>PHONE NUMBER:</p>',2,''),(348971,111430,'118053','furniture','text','<p>PHONE NUMBER:</p>',3,''),(348972,111430,'118053','furniture','text','<p>PHONE NUMBER:</p>',4,''),(348973,111432,'118055','furniture','font-weight','normal',0,''),(348974,111433,'118056','furniture','text','<p>E-MAIL ADDRESS:</p>',1,''),(348975,111433,'118056','furniture','font-weight','bold',0,''),(348976,111433,'118056','furniture','font-size','14',0,''),(348977,111433,'118056','furniture','padding-top','10',0,''),(348978,111433,'118056','furniture','text','<p>E-MAIL ADDRESS:</p>',2,''),(348979,111433,'118056','furniture','text','<p>E-MAIL ADDRESS:</p>',3,''),(348980,111433,'118056','furniture','text','<p>E-MAIL ADDRESS:</p>',4,''),(348981,111434,'118057','furniture','text','<p>CUSTOMER:</p>',1,''),(348982,111434,'118057','furniture','font-size','13',0,''),(348983,111434,'118057','furniture','font-weight','bold',0,''),(348984,111434,'118057','furniture','text','<p>CUSTOMER:</p>',2,''),(348985,111434,'118057','furniture','text','<p>CUSTOMER:</p>',3,''),(348986,111434,'118057','furniture','text','<p>CUSTOMER:</p>',4,''),(348987,111435,'118058','furniture','font-weight','normal',0,''),(348988,111435,'118058','furniture','text-align','center',0,''),(348989,111435,'118058','furniture','padding-bottom','10',0,''),(348990,111436,'118059','furniture','text','<p>Payment date:</p>',1,''),(348991,111436,'118059','furniture','font-weight','bold',0,''),(348992,111436,'118059','furniture','text-align','center',0,''),(348993,111436,'118059','furniture','font-size','12',0,''),(348994,111436,'118059','furniture','text','<p>Payment date:</p>',2,''),(348995,111436,'118059','furniture','text','<p>Payment date:</p>',3,''),(348996,111436,'118059','furniture','text','<p>Payment date:</p>',4,''),(348997,111437,'118060','furniture','text','<p>Payment Method:</p>',1,''),(348998,111437,'118060','furniture','font-weight','bold',0,''),(348999,111437,'118060','furniture','text-align','center',0,''),(349000,111437,'118060','furniture','text','<p>Payment Method:</p>',2,''),(349001,111437,'118060','furniture','text','<p>Payment Method:</p>',3,''),(349002,111437,'118060','furniture','text','<p>Payment Method:</p>',4,''),(349003,111438,'118061','furniture','font-size','14',0,''),(349004,111438,'118061','furniture','font-weight','bold',0,''),(349005,111438,'118061','furniture','text-align','center',0,''),(349006,111438,'118061','furniture','padding-bottom','10',0,''),(349007,111438,'118061','furniture','padding-top','10',0,''),(349008,111439,'118062','furniture','font-weight','normal',0,''),(349009,111439,'118062','furniture','text-align','center',0,''),(349010,111439,'118062','furniture','padding-bottom','20',0,''),(349011,111440,'118063','furniture','font-weight','normal',0,''),(349012,111440,'118063','furniture','text-align','center',0,''),(349013,111441,'118094','furniture','block_type','1',0,''),(349014,111442,'118095','furniture','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(349015,111444,'118318','furniture','block_type','1',0,''),(349016,111445,'118319','furniture','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(349017,111445,'118319','furniture','padding-top','100',0,''),(349018,111445,'118319','furniture','margin-bottom','100',0,''),(349019,111445,'118319','furniture','text-align','center',0,''),(349020,111445,'118319','furniture','font-size','20',0,''),(349021,111446,'118320','furniture','block_type','1',0,''),(349022,111446,'118320','furniture','background-color','$content-bg-2',0,''),(349023,111446,'118320','furniture','padding-bottom','30',0,''),(349024,111447,'118321','furniture','block_type','4',0,''),(349025,111447,'118321','furniture','schema','4-2',0,'5140'),(349026,111448,'118322','furniture','block_type','1',0,''),(349027,111448,'118322','furniture','padding-right','40',0,''),(349028,111448,'118322','furniture','padding-right','0',0,'5140'),(349029,111449,'118323','furniture','block_type','2',0,''),(349030,111449,'118323','furniture','margin-bottom','20',0,''),(349031,111449,'118323','furniture','schema','2-2',0,'5131'),(349032,111449,'118323','furniture','background-color','$content-bg-1',0,''),(349033,111450,'118324','furniture','block_type','1',0,''),(349034,111450,'118324','furniture','border-right-width','20',0,''),(349035,111450,'118324','furniture','border-right-color','$content-border-1',0,''),(349036,111450,'118324','furniture','margin-right','-10',0,''),(349037,111450,'118324','furniture','padding-right','30',0,''),(349038,111450,'118324','furniture','padding-top','20',0,''),(349039,111450,'118324','furniture','padding-left','30',0,''),(349040,111450,'118324','furniture','padding-bottom','20',0,''),(349041,111450,'118324','furniture','border-right-width','0',0,'5140'),(349042,111450,'118324','furniture','margin-right','0',0,'5140'),(349043,111450,'118324','furniture','margin-bottom','20',0,'5140'),(349044,111450,'118324','furniture','padding-left','20',0,'5140'),(349045,111450,'118324','furniture','padding-right','20',0,'5140'),(349046,111452,'118326','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(349047,111452,'118326','furniture','clear','none',0,''),(349048,111453,'118327','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(349049,111453,'118327','furniture','clear','none',0,''),(349050,111454,'118328','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(349051,111456,'118330','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(349052,111456,'118330','furniture','padding-top','20',0,''),(349053,111459,'118333','furniture','margin-bottom','20',0,''),(349054,111460,'118334','furniture','block_type','1',0,''),(349055,111460,'118334','furniture','padding-left','30',0,''),(349056,111460,'118334','furniture','border-left-width','20',0,''),(349057,111460,'118334','furniture','border-left-color','$content-border-1',0,''),(349058,111460,'118334','furniture','margin-left','-10',0,''),(349059,111460,'118334','furniture','padding-right','30',0,''),(349060,111460,'118334','furniture','padding-top','20',0,''),(349061,111460,'118334','furniture','padding-bottom','20',0,''),(349062,111460,'118334','furniture','border-left-width','0',0,'5140'),(349063,111461,'118335','furniture','margin-bottom','20',0,''),(349064,111463,'118337','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(349065,111464,'118338','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(349066,111464,'118338','furniture','clear','none',0,''),(349067,111465,'118339','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(349068,111465,'118339','furniture','clear','none',0,''),(349069,111466,'118340','furniture','block_type','1',0,''),(349070,111466,'118340','furniture','padding-right','30',0,''),(349071,111466,'118340','furniture','background-color','$content-bg-1',0,''),(349072,111466,'118340','furniture','padding-top','20',0,''),(349073,111466,'118340','furniture','padding-left','30',0,''),(349074,111466,'118340','furniture','padding-bottom','20',0,''),(349075,111466,'118340','furniture','padding-left','20',0,'5140'),(349076,111466,'118340','furniture','padding-right','20',0,'5140'),(349077,111468,'118342','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(349078,111469,'118343','furniture','block_type','1',0,''),(349079,111469,'118343','furniture','padding-top','20',0,''),(349080,111469,'118343','furniture','padding-left','20',0,''),(349081,111469,'118343','furniture','padding-right','20',0,''),(349082,111469,'118343','furniture','padding-bottom','20',0,''),(349083,111469,'118343','furniture','background-color','$content-bg-1',0,''),(349084,111469,'118343','furniture','style_class','order-summary',0,''),(349085,111470,'118344','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(349086,111474,'118348','furniture','block_type','1',0,''),(349087,111474,'118348','furniture','background-color','$content-bg-2',0,''),(349088,111474,'118348','furniture','padding-bottom','30',0,''),(349089,111475,'118349','furniture','block_type','4',0,''),(349090,111475,'118349','furniture','schema','4-2',0,'5140'),(349091,111476,'118350','furniture','block_type','1',0,''),(349092,111476,'118350','furniture','padding-right','40',0,''),(349093,111476,'118350','furniture','padding-right','0',0,'5140'),(349094,111477,'118351','furniture','block_type','2',0,''),(349095,111477,'118351','furniture','margin-bottom','20',0,''),(349096,111477,'118351','furniture','schema','2-2',0,'5131'),(349097,111477,'118351','furniture','background-color','$content-bg-1',0,''),(349098,111478,'118352','furniture','block_type','1',0,''),(349099,111478,'118352','furniture','border-right-width','20',0,''),(349100,111478,'118352','furniture','border-right-color','$content-border-1',0,''),(349101,111478,'118352','furniture','margin-right','-10',0,''),(349102,111478,'118352','furniture','padding-right','30',0,''),(349103,111478,'118352','furniture','padding-top','20',0,''),(349104,111478,'118352','furniture','padding-left','30',0,''),(349105,111478,'118352','furniture','padding-bottom','20',0,''),(349106,111478,'118352','furniture','border-right-width','0',0,'5140'),(349107,111478,'118352','furniture','margin-right','0',0,'5140'),(349108,111478,'118352','furniture','margin-bottom','20',0,'5140'),(349109,111478,'118352','furniture','padding-left','20',0,'5140'),(349110,111478,'118352','furniture','padding-right','20',0,'5140'),(349111,111479,'118353','furniture','margin-bottom','20',0,''),(349112,111482,'118356','furniture','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(349113,111482,'118356','furniture','padding-top','20',0,''),(349114,111484,'118358','furniture','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(349115,111484,'118358','furniture','clear','none',0,''),(349116,111486,'118360','furniture','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(349117,111487,'118361','furniture','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(349118,111487,'118361','furniture','clear','none',0,''),(349119,111489,'118362','furniture','block_type','1',0,''),(349120,111489,'118362','furniture','padding-left','30',0,''),(349121,111489,'118362','furniture','border-left-width','20',0,''),(349122,111489,'118362','furniture','border-left-color','$content-border-1',0,''),(349123,111489,'118362','furniture','margin-left','-10',0,''),(349124,111489,'118362','furniture','padding-right','30',0,''),(349125,111489,'118362','furniture','padding-top','20',0,''),(349126,111489,'118362','furniture','padding-bottom','20',0,''),(349127,111489,'118362','furniture','border-left-width','0',0,'5140'),(349128,111490,'118363','furniture','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(349129,111491,'118364','furniture','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(349130,111491,'118364','furniture','clear','none',0,''),(349131,111492,'118365','furniture','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(349132,111492,'118365','furniture','clear','none',0,''),(349133,111493,'118366','furniture','margin-bottom','20',0,''),(349134,111494,'118367','furniture','orders_data','name',0,''),(349135,111495,'118368','furniture','block_type','1',0,''),(349136,111495,'118368','furniture','padding-right','30',0,''),(349137,111495,'118368','furniture','background-color','$content-bg-1',0,''),(349138,111495,'118368','furniture','padding-top','20',0,''),(349139,111495,'118368','furniture','padding-left','30',0,''),(349140,111495,'118368','furniture','padding-bottom','20',0,''),(349141,111495,'118368','furniture','padding-left','20',0,'5140'),(349142,111495,'118368','furniture','padding-right','20',0,'5140'),(349143,111496,'118369','furniture','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(349144,111498,'118371','furniture','block_type','1',0,''),(349145,111498,'118371','furniture','padding-top','20',0,''),(349146,111498,'118371','furniture','padding-left','20',0,''),(349147,111498,'118371','furniture','padding-right','20',0,''),(349148,111498,'118371','furniture','padding-bottom','20',0,''),(349149,111498,'118371','furniture','background-color','$content-bg-1',0,''),(349150,111498,'118371','furniture','style_class','order-summary',0,''),(349151,111501,'118374','furniture','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(349152,111503,'118440','furniture','block_type','1',0,''),(349153,111504,'118441','furniture','block_type','6',0,''),(349154,111504,'118441','furniture','schema','6-3',0,'5140'),(349155,111505,'118442','furniture','aria_name','account-menu',0,''),(349156,111506,'116126','furniture','block_type','1',0,''),(349157,111506,'116126','furniture','padding-top','70',0,''),(349158,111506,'116126','furniture','padding-right','30',0,''),(349159,111506,'116126','furniture','padding-bottom','30',0,''),(349160,111506,'116126','furniture','padding-top','0',0,'5140'),(349161,111506,'116126','furniture','padding-left','0',0,'5140'),(349162,111506,'116126','furniture','padding-right','0',0,'5140'),(349163,111506,'116126','furniture','padding-bottom','0',0,'5140'),(349213,111525,'118443','furniture','margin-bottom','20',0,''),(349214,111526,'118444','furniture','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(349215,111527,'118445','furniture','block_type','1',0,''),(349216,111527,'118445','furniture','padding-top','20',0,''),(349217,111527,'118445','furniture','padding-bottom','20',0,''),(349218,111529,'118447','furniture','padding-top','20',0,''),(349219,111529,'118447','furniture','padding-bottom','20',0,''),(349220,111530,'73349','watch','text','##TEXT_PAGE_NOT_FOUND##',0,''),(349221,111530,'73349','watch','text-align','center',0,''),(349222,111530,'73349','watch','padding-top','100',0,''),(349223,111530,'73349','watch','padding-bottom','100',0,''),(349224,111531,'75904','watch','block_type','1',0,''),(349343,111547,'75920','watch','block_type','1',0,''),(349462,111563,'75936','watch','block_type','1',0,''),(349581,111579,'75952','watch','block_type','1',0,''),(349700,111595,'75968','watch','block_type','1',0,''),(349819,111611,'75984','watch','block_type','1',0,''),(349938,111627,'73350','watch','block_type','1',0,''),(349939,111627,'73350','watch','style_class','account-index',0,''),(350177,111691,'73393','watch','block_type','1',0,''),(350178,111691,'73393','watch','style_class','account-edit-wrap',0,''),(350240,111715,'73398','watch','block_type','1',0,''),(350241,111715,'73398','watch','style_class','account-address-book',0,''),(350311,111740,'73404','watch','block_type','1',0,''),(350312,111740,'73404','watch','style_class','account-address-book-process',0,''),(350374,111764,'73409','watch','block_type','1',0,''),(350375,111764,'73409','watch','style_class','item-holder',0,''),(350376,111764,'73409','watch','padding-top','25',0,''),(350377,111764,'73409','watch','padding-bottom','25',0,''),(350378,111764,'73409','watch','text-align','left',0,''),(350379,111764,'73409','watch','border-top-color','$content-border-1',0,''),(350380,111764,'73409','watch','border-top-width','1',0,''),(350381,111765,'73410','watch','block_type','6',0,''),(350382,111766,'73411','watch','padding-right','20',0,''),(350383,111767,'73412','watch','description_characters','200',0,''),(350384,111767,'73412','watch','clear','none',0,''),(350385,111767,'73412','watch','padding-right','20',0,''),(350386,111768,'73413','watch','clear','none',0,''),(350387,111770,'73415','watch','block_type','4',0,''),(350388,111771,'73416','watch','block_type','2',0,''),(350389,111772,'73417','watch','margin-bottom','7',0,''),(350390,111773,'73418','watch','clear','none',0,''),(350391,111774,'73419','watch','margin-bottom','20',0,''),(350392,111774,'73419','watch','text-align','right',0,''),(350393,111775,'73420','watch','padding-right','20',0,''),(350394,111776,'73421','watch','block_type','2',0,''),(350395,111777,'73422','watch','clear','none',0,''),(350396,111779,'76000','watch','block_type','1',0,''),(350397,111779,'76000','watch','style_class','item-holder',0,''),(350398,111779,'76000','watch','padding-top','25',0,''),(350399,111779,'76000','watch','padding-left','25',0,''),(350400,111779,'76000','watch','padding-right','25',0,''),(350401,111779,'76000','watch','padding-bottom','25',0,''),(350402,111779,'76000','watch','text-align','left',0,''),(350403,111781,'76002','watch','margin-bottom','7',0,''),(350404,111782,'76003','watch','clear','both',0,''),(350405,111785,'76006','watch','block_type','1',0,''),(350406,111785,'76006','watch','style_class','item-holder',0,''),(350407,111785,'76006','watch','padding-top','25',0,''),(350408,111785,'76006','watch','padding-left','25',0,''),(350409,111785,'76006','watch','padding-right','25',0,''),(350410,111785,'76006','watch','padding-bottom','25',0,''),(350411,111785,'76006','watch','text-align','left',0,''),(350412,111786,'76007','watch','block_type','5',0,''),(350413,111789,'76010','watch','margin-bottom','7',0,''),(350414,111790,'76011','watch','clear','both',0,''),(350415,111791,'76012','watch','block_type','1',0,''),(350416,111792,'76013','watch','block_type','6',0,''),(350417,111792,'76013','watch','font-weight','400',0,''),(350418,111792,'76013','watch','schema','6-2',0,'5261'),(350419,111792,'76013','watch','schema','6-2',0,'5240'),(350420,111793,'76014','watch','font-weight','400',0,''),(350421,111793,'76014','watch','padding-right','40',0,''),(350422,111793,'76014','watch','padding-right','0',0,'5261'),(350423,111793,'76014','watch','padding-right','0',0,'5240'),(350424,111794,'76015','watch','block_type','5',0,''),(350425,111794,'76015','watch','padding-top','10',0,''),(350426,111794,'76015','watch','padding-bottom','10',0,''),(350427,111794,'76015','watch','schema','5-2',0,'5261'),(350428,111794,'76015','watch','border-top-color','$content-border-1',0,''),(350429,111794,'76015','watch','border-top-width','1',0,''),(350430,111796,'76017','watch','float','right',0,''),(350431,111798,'76019','watch','col_in_row','3',0,''),(350432,111798,'76019','watch','products_align','left',0,''),(350433,111798,'76019','watch','font-weight','400',0,''),(350434,111798,'76019','watch','show_qty_input','0',0,''),(350435,111798,'76019','watch','listing_type','productListing',0,''),(350436,111798,'76019','watch','listing_type_rows','no',0,''),(350437,111798,'76019','watch','show_buy_button_b2b','on',0,''),(350438,111798,'76019','watch','show_wishlist_button_b2b','1',0,''),(350439,111798,'76019','watch','show_compare_b2b','1',0,''),(350440,111798,'76019','watch','show_stock','0',0,''),(350441,111798,'76019','watch','show_description','0',0,''),(350442,111798,'76019','watch','show_model','0',0,''),(350443,111798,'76019','watch','show_properties','0',0,''),(350444,111798,'76019','watch','show_rating','0',0,''),(350445,111798,'76019','watch','show_rating_counts','0',0,''),(350446,111798,'76019','watch','show_price','0',0,''),(350447,111798,'76019','watch','show_buy_button','0',0,''),(350448,111798,'76019','watch','show_view_button','0',0,''),(350449,111798,'76019','watch','show_wishlist_button','0',0,''),(350450,111798,'76019','watch','show_compare','0',0,''),(350451,111798,'76019','watch','show_name_rows','0',0,''),(350452,111798,'76019','watch','show_image_rows','0',0,''),(350453,111798,'76019','watch','show_stock_rows','0',0,''),(350454,111798,'76019','watch','show_description_rows','0',0,''),(350455,111798,'76019','watch','show_model_rows','0',0,''),(350456,111798,'76019','watch','show_properties_rows','0',0,''),(350457,111798,'76019','watch','show_rating_rows','0',0,''),(350458,111798,'76019','watch','show_rating_counts_rows','0',0,''),(350459,111798,'76019','watch','show_price_rows','0',0,''),(350460,111798,'76019','watch','show_buy_button_rows','0',0,''),(350461,111798,'76019','watch','show_qty_input_rows','0',0,''),(350462,111798,'76019','watch','show_view_button_rows','0',0,''),(350463,111798,'76019','watch','show_wishlist_button_rows','0',0,''),(350464,111798,'76019','watch','show_compare_rows','0',0,''),(350465,111798,'76019','watch','show_name_b2b','0',0,''),(350466,111798,'76019','watch','show_image_b2b','0',0,''),(350467,111798,'76019','watch','show_stock_b2b','0',0,''),(350468,111798,'76019','watch','show_description_b2b','0',0,''),(350469,111798,'76019','watch','show_model_b2b','0',0,''),(350470,111798,'76019','watch','show_properties_b2b','0',0,''),(350471,111798,'76019','watch','show_rating_b2b','0',0,''),(350472,111798,'76019','watch','show_rating_counts_b2b','0',0,''),(350473,111798,'76019','watch','show_price_b2b','0',0,''),(350474,111798,'76019','watch','show_qty_input_b2b','0',0,''),(350475,111798,'76019','watch','show_view_button_b2b','0',0,''),(350476,111798,'76019','watch','show_attributes_b2b','0',0,''),(350477,111798,'76019','watch','items_on_page','9',0,''),(350478,111798,'76019','watch','col_in_row','2',0,'5240'),(350479,111798,'76019','watch','col_in_row','1',0,'5261'),(350480,111798,'76019','watch','product_names_teg','h2',0,''),(350481,111799,'76020','watch','listing_type','productListing',0,''),(350482,111800,'76021','watch','block_type','1',0,''),(350483,111800,'76021','watch','padding-top','10',0,''),(350484,111800,'76021','watch','padding-bottom','10',0,''),(350485,111800,'76021','watch','border-bottom-width','1',0,''),(350486,111800,'76021','watch','border-bottom-color','$content-border-1',0,''),(350487,111800,'76021','watch','margin-left','0',0,''),(350488,111800,'76021','watch','margin-right','0',0,''),(350489,111801,'76022','watch','float','right',0,''),(350490,111801,'76022','watch','display','none',0,'5261'),(350491,111802,'76023','watch','margin-right','20',0,''),(350492,111802,'76023','watch','float','right',0,''),(350493,111802,'76023','watch','clear','none',0,''),(350494,111802,'76023','watch','display','none',0,'5240'),(350495,111803,'76024','watch','float','left',0,''),(350496,111803,'76024','watch','clear','none',0,''),(350497,111803,'76024','watch','margin-left','20',0,''),(350498,111803,'76024','watch','display','none',0,'5261'),(350499,111804,'76025','watch','float','left',0,''),(350500,111804,'76025','watch','clear','none',0,''),(350501,111804,'76025','watch','sort_pos_3','1',0,''),(350502,111804,'76025','watch','sort_pos_4','2',0,''),(350503,111804,'76025','watch','sort_pos_10','3',0,''),(350504,111804,'76025','watch','sort_pos_9','4',0,''),(350505,111804,'76025','watch','sort_pos_11','5',0,''),(350506,111804,'76025','watch','sort_pos_12','6',0,''),(350507,111804,'76025','watch','sort_pos_14','7',0,''),(350508,111804,'76025','watch','sort_pos_13','8',0,''),(350509,111804,'76025','watch','sort_pos_8','9',0,''),(350510,111804,'76025','watch','sort_pos_7','10',0,''),(350511,111804,'76025','watch','sort_pos_2','11',0,''),(350512,111804,'76025','watch','sort_pos_1','12',0,''),(350513,111804,'76025','watch','sort_pos_6','13',0,''),(350514,111804,'76025','watch','sort_pos_5','14',0,''),(350515,111804,'76025','watch','sort_pos_0','15',0,''),(350516,111804,'76025','watch','sort_hide_10','1',0,''),(350517,111804,'76025','watch','sort_hide_9','1',0,''),(350518,111804,'76025','watch','hide_icons','1',0,''),(350519,111804,'76025','watch','sort_hide_16','1',0,''),(350520,111804,'76025','watch','sort_hide_15','1',0,''),(350521,111804,'76025','watch','sort_hide_3','0',0,''),(350522,111804,'76025','watch','sort_hide_4','0',0,''),(350523,111804,'76025','watch','sort_hide_11','1',0,''),(350524,111804,'76025','watch','sort_hide_12','1',0,''),(350525,111804,'76025','watch','sort_hide_14','1',0,''),(350526,111804,'76025','watch','sort_hide_13','1',0,''),(350527,111804,'76025','watch','sort_hide_8','0',0,''),(350528,111804,'76025','watch','sort_hide_7','0',0,''),(350529,111804,'76025','watch','sort_hide_2','1',0,''),(350530,111804,'76025','watch','sort_hide_1','1',0,''),(350531,111804,'76025','watch','sort_hide_6','1',0,''),(350532,111804,'76025','watch','sort_hide_5','1',0,''),(350533,111804,'76025','watch','sort_hide_0','1',0,''),(350534,111807,'1683124632.767746','watch','block_type','1',0,''),(350535,111807,'1683124632.767746','watch','font-weight','normal',0,''),(350536,111807,'1683124632.767746','watch','padding-top','20',0,''),(350537,111807,'1683124632.767746','watch','background-color','$content-bg-2',0,''),(350538,111807,'1683124632.767746','watch','style_class','shopping-cart-index',0,''),(350539,111807,'1683124632.767746','watch','color','$content-color-2',0,''),(350540,111808,'1683124632.80670','watch','block_type','4',0,''),(350541,111808,'1683124632.80670','watch','schema','4-1',0,'5245'),(350542,111808,'1683124632.80670','watch','schema','4-2',0,'5240'),(350543,111809,'1683124632.809680','watch','block_type','1',0,''),(350544,111809,'1683124632.809680','watch','background-color','$content-bg-1',0,''),(350545,111809,'1683124632.809680','watch','padding-top','20',0,''),(350546,111809,'1683124632.809680','watch','padding-bottom','20',0,''),(350547,111809,'1683124632.809680','watch','padding-left','25',0,''),(350548,111809,'1683124632.809680','watch','padding-right','25',0,''),(350549,111809,'1683124632.809680','watch','margin-bottom','30',0,''),(350550,111809,'1683124632.809680','watch','color','$content-color-1',0,''),(350551,111810,'1683124632.816335','watch','block_type','1',0,''),(350552,111810,'1683124632.816335','watch','background-color','$content-bg-1',0,''),(350553,111810,'1683124632.816335','watch','margin-bottom','30',0,''),(350554,111810,'1683124632.816335','watch','color','$content-color-1',0,''),(350555,111811,'1683124632.817623','watch','padding-top','20',0,''),(350556,111811,'1683124632.817623','watch','padding-left','25',0,''),(350557,111811,'1683124632.817623','watch','padding-right','25',0,''),(350558,111811,'1683124632.817623','watch','padding-bottom','20',0,''),(350559,111812,'1683124632.818551','watch','block_type','2',0,''),(350560,111812,'1683124632.818551','watch','padding-bottom','20',0,''),(350561,111812,'1683124632.818551','watch','padding-top','20',0,''),(350562,111812,'1683124632.818551','watch','padding-left','25',0,''),(350563,111812,'1683124632.818551','watch','padding-right','25',0,''),(350564,111812,'1683124632.818551','watch','border-bottom-color','#e0e0e0',0,''),(350565,111812,'1683124632.818551','watch','border-bottom-width','1',0,''),(350566,111812,'1683124632.818551','watch','schema','2-2',0,'5240'),(350567,111813,'1683124632.820317','watch','float','left',0,''),(350568,111814,'1683124632.820914','watch','text-align','right',0,''),(350569,111814,'1683124632.820914','watch','clear','none',0,''),(350570,111814,'1683124632.820914','watch','float','right',0,''),(350571,111814,'1683124632.820914','watch','padding-top','22',0,''),(350572,111815,'1683124632.822588','watch','float','right',0,''),(350573,111815,'1683124632.822588','watch','padding-top','26',0,''),(350574,111816,'1683124632.823175','watch','block_type','3',0,''),(350575,111816,'1683124632.823175','watch','font-weight','400',0,''),(350576,111816,'1683124632.823175','watch','schema','2-2',0,'5232'),(350577,111816,'1683124632.823175','watch','style_class','closeable-content',0,''),(350578,111816,'1683124632.823175','watch','padding-top','10',0,''),(350579,111816,'1683124632.823175','watch','padding-left','25',0,''),(350580,111816,'1683124632.823175','watch','padding-right','25',0,''),(350581,111816,'1683124632.823175','watch','padding-bottom','20',0,''),(350582,111819,'1683124632.82683','watch','block_type','1',0,''),(350583,111819,'1683124632.82683','watch','padding-top','20',0,''),(350584,111819,'1683124632.82683','watch','padding-bottom','20',0,''),(350585,111819,'1683124632.82683','watch','padding-left','25',0,''),(350586,111819,'1683124632.82683','watch','padding-right','25',0,''),(350587,111819,'1683124632.82683','watch','background-color','$content-bg-1',0,''),(350588,111819,'1683124632.82683','watch','margin-bottom','30',0,''),(350589,111819,'1683124632.82683','watch','color','$content-color-1',0,''),(350590,111820,'1683124632.827413','watch','hide_parents','2',0,''),(350591,111821,'1683124632.828374','watch','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(350592,111822,'1683124632.829840','watch','block_type','1',0,''),(350593,111822,'1683124632.829840','watch','background-color','$content-bg-1',0,''),(350594,111822,'1683124632.829840','watch','padding-top','20',0,''),(350595,111822,'1683124632.829840','watch','padding-left','25',0,''),(350596,111822,'1683124632.829840','watch','padding-right','25',0,''),(350597,111822,'1683124632.829840','watch','padding-bottom','20',0,''),(350598,111822,'1683124632.829840','watch','margin-bottom','30',0,''),(350599,111822,'1683124632.829840','watch','style_class','closeable-box',0,''),(350600,111822,'1683124632.829840','watch','display','none',0,'5240'),(350601,111823,'1683124632.831459','watch','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(350602,111823,'1683124632.831459','watch','style_class','shipping-ico closeable-heading closeable-event',0,''),(350603,111824,'1683124632.832592','watch','font-weight','normal',0,''),(350604,111824,'1683124632.832592','watch','style_class','closeable-content',0,''),(350605,111824,'1683124632.832592','watch','padding-top','10',0,''),(350606,111824,'1683124632.832592','watch','hide_parents','2',0,''),(350607,111825,'1683124632.833353','watch','style_class','order-summary',0,''),(350608,111825,'1683124632.833353','watch','block_type','1',0,''),(350609,111825,'1683124632.833353','watch','margin-left','30',0,''),(350610,111825,'1683124632.833353','watch','margin-left','0',0,'5240'),(350611,111825,'1683124632.833353','watch','margin-bottom','30',0,'5240'),(350612,111826,'1683124632.834715','watch','block_type','1',0,''),(350613,111826,'1683124632.834715','watch','padding-left','20',0,''),(350614,111826,'1683124632.834715','watch','padding-right','20',0,''),(350615,111826,'1683124632.834715','watch','padding-bottom','20',0,''),(350616,111827,'1683124632.835884','watch','font-weight','400',0,''),(350617,111827,'1683124632.835884','watch','padding-top','12',0,'5232'),(350618,111827,'1683124632.835884','watch','padding-left','0',0,'5232'),(350619,111828,'1683124632.836532','watch','font-weight','400',0,''),(350620,111828,'1683124632.836532','watch','logo','themes/watch/img/payment.png',1,''),(350621,111828,'1683124632.836532','watch','padding-top','20',0,''),(350622,111828,'1683124632.836532','watch','padding-bottom','10',0,''),(350623,111828,'1683124632.836532','watch','logo','themes/watch/img/payment.png',2,''),(350624,111828,'1683124632.836532','watch','logo','themes/watch/img/payment.png',3,''),(350625,111828,'1683124632.836532','watch','logo','themes/watch/img/payment.png',4,''),(350626,111829,'1683124632.844829','watch','font-weight','400',0,''),(350627,111829,'1683124632.844829','watch','box_align','4',0,''),(350628,111829,'1683124632.844829','watch','text-align','center',0,'5232'),(350629,111829,'1683124632.844829','watch','float','none',0,'5232'),(350630,111829,'1683124632.844829','watch','width','100',0,'5232'),(350631,111829,'1683124632.844829','watch','width_measure','%',0,'5232'),(350632,111830,'1683124632.84681','watch','style_class','bottom-totals',0,''),(350633,111831,'1683124632.846538','watch','style_class','top-totals',0,''),(350634,111832,'1683124632.84726','watch','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(350635,111833,'94658','watch','block_type','1',0,''),(350636,111833,'94658','watch','font-weight','normal',0,''),(350637,111833,'94658','watch','padding-top','20',0,''),(350638,111833,'94658','watch','background-color','$content-bg-2',0,''),(350639,111835,'94660','watch','block_type','4',0,''),(350640,111835,'94660','watch','schema','4-1',0,'5245'),(350641,111835,'94660','watch','schema','4-2',0,'5240'),(350642,111836,'94661','watch','block_type','1',0,''),(350643,111836,'94661','watch','background-color','$content-bg-1',0,''),(350644,111836,'94661','watch','padding-top','20',0,''),(350645,111836,'94661','watch','padding-bottom','20',0,''),(350646,111836,'94661','watch','padding-left','25',0,''),(350647,111836,'94661','watch','padding-right','25',0,''),(350648,111836,'94661','watch','margin-bottom','30',0,''),(350649,111837,'94662','watch','col_in_row','3',0,''),(350650,111837,'94662','watch','show_description','1',0,''),(350651,111837,'94662','watch','show_model','1',0,''),(350652,111837,'94662','watch','show_properties','1',0,''),(350653,111837,'94662','watch','show_rating','1',0,''),(350654,111837,'94662','watch','show_rating_counts','1',0,''),(350655,111837,'94662','watch','show_qty_input','1',0,''),(350656,111837,'94662','watch','show_view_button','1',0,''),(350657,111837,'94662','watch','show_wishlist_button','1',0,''),(350658,111837,'94662','watch','show_compare','1',0,''),(350659,111837,'94662','watch','view_as','carousel',0,''),(350660,111837,'94662','watch','hide_parents','2',0,''),(350661,111838,'94663','watch','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(350662,111838,'94663','watch','style_class','bell-ico',0,''),(350663,111839,'94664','watch','block_type','1',0,''),(350664,111839,'94664','watch','background-color','$content-bg-1',0,''),(350665,111839,'94664','watch','margin-bottom','30',0,''),(350666,111840,'94665','watch','padding-top','20',0,''),(350667,111840,'94665','watch','padding-left','25',0,''),(350668,111840,'94665','watch','padding-right','25',0,''),(350669,111840,'94665','watch','padding-bottom','20',0,''),(350670,111841,'94666','watch','block_type','2',0,''),(350671,111841,'94666','watch','padding-bottom','20',0,''),(350672,111841,'94666','watch','padding-top','20',0,''),(350673,111841,'94666','watch','padding-left','25',0,''),(350674,111841,'94666','watch','padding-right','25',0,''),(350675,111841,'94666','watch','border-bottom-color','$content-border-1',0,''),(350676,111841,'94666','watch','border-bottom-width','1',0,''),(350677,111841,'94666','watch','schema','2-2',0,'5240'),(350678,111842,'94667','watch','float','left',0,''),(350679,111843,'94668','watch','text-align','right',0,''),(350680,111843,'94668','watch','clear','none',0,''),(350681,111843,'94668','watch','float','right',0,''),(350682,111843,'94668','watch','padding-top','22',0,''),(350683,111844,'94669','watch','float','right',0,''),(350684,111844,'94669','watch','padding-top','26',0,''),(350685,111845,'94670','watch','block_type','1',0,''),(350686,111845,'94670','watch','padding-top','20',0,''),(350687,111845,'94670','watch','padding-bottom','20',0,''),(350688,111845,'94670','watch','padding-left','25',0,''),(350689,111845,'94670','watch','padding-right','25',0,''),(350690,111845,'94670','watch','background-color','$content-bg-1',0,''),(350691,111845,'94670','watch','margin-bottom','30',0,''),(350692,111846,'94671','watch','hide_parents','2',0,''),(350693,111847,'94672','watch','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(350694,111848,'94673','watch','block_type','1',0,''),(350695,111848,'94673','watch','background-color','$content-bg-1',0,''),(350696,111848,'94673','watch','padding-top','20',0,''),(350697,111848,'94673','watch','padding-bottom','20',0,''),(350698,111848,'94673','watch','padding-left','25',0,''),(350699,111848,'94673','watch','padding-right','25',0,''),(350700,111848,'94673','watch','margin-bottom','30',0,''),(350701,111848,'94673','watch','style_class','closeable-box',0,''),(350702,111849,'94674','watch','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(350703,111849,'94674','watch','style_class','savings-ico closeable-heading closeable-event',0,''),(350704,111850,'94675','watch','block_type','3',0,''),(350705,111850,'94675','watch','font-weight','400',0,''),(350706,111850,'94675','watch','schema','2-2',0,'5232'),(350707,111850,'94675','watch','style_class','closeable-content',0,''),(350708,111850,'94675','watch','padding-top','10',0,''),(350709,111851,'94676','watch','font-weight','400',0,''),(350710,111851,'94676','watch','padding-top','12',0,'5232'),(350711,111851,'94676','watch','padding-left','0',0,'5232'),(350712,111854,'94679','watch','block_type','1',0,''),(350713,111854,'94679','watch','background-color','$content-bg-1',0,''),(350714,111854,'94679','watch','padding-top','20',0,''),(350715,111854,'94679','watch','padding-left','25',0,''),(350716,111854,'94679','watch','padding-right','25',0,''),(350717,111854,'94679','watch','padding-bottom','20',0,''),(350718,111854,'94679','watch','margin-bottom','30',0,''),(350719,111854,'94679','watch','style_class','closeable-box',0,''),(350720,111854,'94679','watch','display','none',0,'5240'),(350721,111855,'94680','watch','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(350722,111855,'94680','watch','style_class','shipping-ico closeable-heading closeable-event',0,''),(350723,111856,'94681','watch','font-weight','normal',0,''),(350724,111856,'94681','watch','style_class','closeable-content',0,''),(350725,111856,'94681','watch','padding-top','10',0,''),(350726,111856,'94681','watch','hide_parents','2',0,''),(350727,111857,'94682','watch','style_class','order-summary',0,''),(350728,111857,'94682','watch','block_type','1',0,''),(350729,111857,'94682','watch','margin-left','30',0,''),(350730,111857,'94682','watch','margin-left','0',0,'5240'),(350731,111857,'94682','watch','margin-bottom','30',0,'5240'),(350732,111858,'94683','watch','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(350733,111859,'94684','watch','block_type','1',0,''),(350734,111859,'94684','watch','padding-left','20',0,''),(350735,111859,'94684','watch','padding-right','20',0,''),(350736,111859,'94684','watch','padding-bottom','20',0,''),(350737,111860,'94685','watch','font-weight','400',0,''),(350738,111860,'94685','watch','logo','themes/watch/img/payicons.png',1,''),(350739,111860,'94685','watch','padding-top','20',0,''),(350740,111860,'94685','watch','padding-bottom','10',0,''),(350741,111860,'94685','watch','logo','themes/watch/img/payicons.png',2,''),(350742,111860,'94685','watch','logo','themes/watch/img/payicons.png',3,''),(350743,111860,'94685','watch','logo','themes/watch/img/payicons.png',4,''),(350744,111861,'94686','watch','font-weight','400',0,''),(350745,111861,'94686','watch','box_align','4',0,''),(350746,111861,'94686','watch','text-align','center',0,'5232'),(350747,111861,'94686','watch','float','none',0,'5232'),(350748,111861,'94686','watch','width','100',0,'5232'),(350749,111861,'94686','watch','width_measure','%',0,'5232'),(350750,111863,'73462','watch','block_type','1',0,''),(350751,111864,'73463','watch','block_type','6',0,''),(350752,111864,'73463','watch','font-weight','400',0,''),(350753,111864,'73463','watch','schema','6-2',0,'5261'),(350754,111864,'73463','watch','schema','6-2',0,'5240'),(350755,111865,'73464','watch','font-weight','400',0,''),(350756,111865,'73464','watch','padding-right','40',0,''),(350757,111865,'73464','watch','padding-right','0',0,'5261'),(350758,111865,'73464','watch','padding-right','0',0,'5240'),(350759,111866,'73465','watch','col_in_row','3',0,''),(350760,111866,'73465','watch','products_align','left',0,''),(350761,111866,'73465','watch','font-weight','400',0,''),(350762,111866,'73465','watch','show_qty_input','0',0,''),(350763,111866,'73465','watch','listing_type','productListing',0,''),(350764,111866,'73465','watch','listing_type_rows','Rows',0,''),(350765,111866,'73465','watch','show_buy_button_b2b','on',0,''),(350766,111866,'73465','watch','show_wishlist_button_b2b','1',0,''),(350767,111866,'73465','watch','show_compare_b2b','1',0,''),(350768,111866,'73465','watch','show_stock','0',0,''),(350769,111866,'73465','watch','show_description','0',0,''),(350770,111866,'73465','watch','show_model','0',0,''),(350771,111866,'73465','watch','show_properties','0',0,''),(350772,111866,'73465','watch','show_rating','0',0,''),(350773,111866,'73465','watch','show_rating_counts','0',0,''),(350774,111866,'73465','watch','show_price','0',0,''),(350775,111866,'73465','watch','show_buy_button','0',0,''),(350776,111866,'73465','watch','show_view_button','0',0,''),(350777,111866,'73465','watch','show_wishlist_button','0',0,''),(350778,111866,'73465','watch','show_compare','0',0,''),(350779,111866,'73465','watch','show_name_rows','0',0,''),(350780,111866,'73465','watch','show_image_rows','0',0,''),(350781,111866,'73465','watch','show_stock_rows','0',0,''),(350782,111866,'73465','watch','show_description_rows','0',0,''),(350783,111866,'73465','watch','show_model_rows','0',0,''),(350784,111866,'73465','watch','show_properties_rows','0',0,''),(350785,111866,'73465','watch','show_rating_rows','0',0,''),(350786,111866,'73465','watch','show_rating_counts_rows','0',0,''),(350787,111866,'73465','watch','show_price_rows','0',0,''),(350788,111866,'73465','watch','show_buy_button_rows','0',0,''),(350789,111866,'73465','watch','show_qty_input_rows','0',0,''),(350790,111866,'73465','watch','show_view_button_rows','0',0,''),(350791,111866,'73465','watch','show_wishlist_button_rows','0',0,''),(350792,111866,'73465','watch','show_compare_rows','0',0,''),(350793,111866,'73465','watch','show_name_b2b','0',0,''),(350794,111866,'73465','watch','show_image_b2b','0',0,''),(350795,111866,'73465','watch','show_stock_b2b','0',0,''),(350796,111866,'73465','watch','show_description_b2b','0',0,''),(350797,111866,'73465','watch','show_model_b2b','0',0,''),(350798,111866,'73465','watch','show_properties_b2b','0',0,''),(350799,111866,'73465','watch','show_rating_b2b','0',0,''),(350800,111866,'73465','watch','show_rating_counts_b2b','0',0,''),(350801,111866,'73465','watch','show_price_b2b','0',0,''),(350802,111866,'73465','watch','show_qty_input_b2b','0',0,''),(350803,111866,'73465','watch','show_view_button_b2b','0',0,''),(350804,111866,'73465','watch','show_attributes_b2b','0',0,''),(350805,111866,'73465','watch','items_on_page','9',0,''),(350806,111866,'73465','watch','col_in_row','2',0,'5240'),(350807,111866,'73465','watch','col_in_row','1',0,'5261'),(350808,111866,'73465','watch','product_names_teg','h2',0,''),(350809,111868,'73467','watch','block_type','5',0,''),(350810,111868,'73467','watch','padding-top','10',0,''),(350811,111868,'73467','watch','padding-bottom','10',0,''),(350812,111868,'73467','watch','schema','5-2',0,'5261'),(350813,111868,'73467','watch','border-top-color','$content-border-1',0,''),(350814,111868,'73467','watch','border-top-width','1',0,''),(350815,111870,'73469','watch','float','right',0,''),(350816,111871,'73470','watch','listing_type','productListing',0,''),(350817,111873,'73472','watch','block_type','1',0,''),(350818,111873,'73472','watch','padding-top','10',0,''),(350819,111873,'73472','watch','padding-bottom','10',0,''),(350820,111873,'73472','watch','border-bottom-width','1',0,''),(350821,111873,'73472','watch','border-bottom-color','$content-border-1',0,''),(350822,111873,'73472','watch','margin-left','0',0,''),(350823,111873,'73472','watch','margin-right','0',0,''),(350824,111874,'73473','watch','float','right',0,''),(350825,111874,'73473','watch','display','none',0,'5261'),(350826,111875,'73474','watch','margin-right','20',0,''),(350827,111875,'73474','watch','float','right',0,''),(350828,111875,'73474','watch','clear','none',0,''),(350829,111875,'73474','watch','display','none',0,'5240'),(350830,111876,'73475','watch','float','left',0,''),(350831,111876,'73475','watch','clear','none',0,''),(350832,111876,'73475','watch','margin-left','20',0,''),(350833,111876,'73475','watch','display','none',0,'5261'),(350834,111877,'73476','watch','float','left',0,''),(350835,111877,'73476','watch','clear','none',0,''),(350836,111877,'73476','watch','sort_pos_3','2',0,''),(350837,111877,'73476','watch','sort_pos_4','3',0,''),(350838,111877,'73476','watch','sort_pos_10','11',0,''),(350839,111877,'73476','watch','sort_pos_9','10',0,''),(350840,111877,'73476','watch','sort_pos_11','12',0,''),(350841,111877,'73476','watch','sort_pos_12','13',0,''),(350842,111877,'73476','watch','sort_pos_14','15',0,''),(350843,111877,'73476','watch','sort_pos_13','14',0,''),(350844,111877,'73476','watch','sort_pos_8','4',0,''),(350845,111877,'73476','watch','sort_pos_7','5',0,''),(350846,111877,'73476','watch','sort_pos_2','7',0,''),(350847,111877,'73476','watch','sort_pos_1','6',0,''),(350848,111877,'73476','watch','sort_pos_6','9',0,''),(350849,111877,'73476','watch','sort_pos_5','8',0,''),(350850,111877,'73476','watch','sort_pos_0','1',0,''),(350851,111877,'73476','watch','sort_hide_10','1',0,''),(350852,111877,'73476','watch','sort_hide_9','1',0,''),(350853,111877,'73476','watch','hide_icons','1',0,''),(350854,111877,'73476','watch','sort_hide_16','1',0,''),(350855,111877,'73476','watch','sort_hide_15','1',0,''),(350856,111877,'73476','watch','sort_hide_3','0',0,''),(350857,111877,'73476','watch','sort_hide_4','0',0,''),(350858,111877,'73476','watch','sort_hide_11','1',0,''),(350859,111877,'73476','watch','sort_hide_12','1',0,''),(350860,111877,'73476','watch','sort_hide_14','1',0,''),(350861,111877,'73476','watch','sort_hide_13','1',0,''),(350862,111877,'73476','watch','sort_hide_8','0',0,''),(350863,111877,'73476','watch','sort_hide_7','0',0,''),(350864,111877,'73476','watch','sort_hide_2','1',0,''),(350865,111877,'73476','watch','sort_hide_1','1',0,''),(350866,111877,'73476','watch','sort_hide_6','1',0,''),(350867,111877,'73476','watch','sort_hide_5','1',0,''),(350868,111877,'73476','watch','sort_hide_0','0',0,''),(350869,111877,'73476','watch','sort_pos_15','16',0,''),(350870,111877,'73476','watch','sort_pos_16','17',0,''),(350871,111884,'94688','watch','block_type','1',0,''),(350872,111886,'94690','watch','block_type','6',0,''),(350873,111886,'94690','watch','font-weight','400',0,''),(350874,111886,'94690','watch','schema','6-2',0,'5261'),(350875,111886,'94690','watch','schema','6-2',0,'5240'),(350876,111887,'94691','watch','font-weight','400',0,''),(350877,111887,'94691','watch','padding-right','40',0,''),(350878,111887,'94691','watch','padding-right','0',0,'5261'),(350879,111887,'94691','watch','padding-right','0',0,'5240'),(350880,111889,'94693','watch','col_in_row','3',0,''),(350881,111889,'94693','watch','products_align','left',0,''),(350882,111889,'94693','watch','font-weight','400',0,''),(350883,111889,'94693','watch','show_qty_input','0',0,''),(350884,111889,'94693','watch','listing_type','productListing',0,''),(350885,111889,'94693','watch','listing_type_rows','no',0,''),(350886,111889,'94693','watch','show_buy_button_b2b','on',0,''),(350887,111889,'94693','watch','show_wishlist_button_b2b','1',0,''),(350888,111889,'94693','watch','show_compare_b2b','1',0,''),(350889,111889,'94693','watch','show_stock','0',0,''),(350890,111889,'94693','watch','show_description','0',0,''),(350891,111889,'94693','watch','show_model','0',0,''),(350892,111889,'94693','watch','show_properties','0',0,''),(350893,111889,'94693','watch','show_rating','0',0,''),(350894,111889,'94693','watch','show_rating_counts','0',0,''),(350895,111889,'94693','watch','show_price','0',0,''),(350896,111889,'94693','watch','show_buy_button','0',0,''),(350897,111889,'94693','watch','show_view_button','0',0,''),(350898,111889,'94693','watch','show_wishlist_button','0',0,''),(350899,111889,'94693','watch','show_compare','0',0,''),(350900,111889,'94693','watch','show_name_rows','0',0,''),(350901,111889,'94693','watch','show_image_rows','0',0,''),(350902,111889,'94693','watch','show_stock_rows','0',0,''),(350903,111889,'94693','watch','show_description_rows','0',0,''),(350904,111889,'94693','watch','show_model_rows','0',0,''),(350905,111889,'94693','watch','show_properties_rows','0',0,''),(350906,111889,'94693','watch','show_rating_rows','0',0,''),(350907,111889,'94693','watch','show_rating_counts_rows','0',0,''),(350908,111889,'94693','watch','show_price_rows','0',0,''),(350909,111889,'94693','watch','show_buy_button_rows','0',0,''),(350910,111889,'94693','watch','show_qty_input_rows','0',0,''),(350911,111889,'94693','watch','show_view_button_rows','0',0,''),(350912,111889,'94693','watch','show_wishlist_button_rows','0',0,''),(350913,111889,'94693','watch','show_compare_rows','0',0,''),(350914,111889,'94693','watch','show_name_b2b','0',0,''),(350915,111889,'94693','watch','show_image_b2b','0',0,''),(350916,111889,'94693','watch','show_stock_b2b','0',0,''),(350917,111889,'94693','watch','show_description_b2b','0',0,''),(350918,111889,'94693','watch','show_model_b2b','0',0,''),(350919,111889,'94693','watch','show_properties_b2b','0',0,''),(350920,111889,'94693','watch','show_rating_b2b','0',0,''),(350921,111889,'94693','watch','show_rating_counts_b2b','0',0,''),(350922,111889,'94693','watch','show_price_b2b','0',0,''),(350923,111889,'94693','watch','show_qty_input_b2b','0',0,''),(350924,111889,'94693','watch','show_view_button_b2b','0',0,''),(350925,111889,'94693','watch','show_attributes_b2b','0',0,''),(350926,111889,'94693','watch','items_on_page','9',0,''),(350927,111889,'94693','watch','col_in_row','2',0,'5240'),(350928,111889,'94693','watch','col_in_row','1',0,'5261'),(350929,111889,'94693','watch','product_names_teg','h2',0,''),(350930,111890,'94694','watch','block_type','1',0,''),(350931,111890,'94694','watch','padding-top','10',0,''),(350932,111890,'94694','watch','padding-bottom','10',0,''),(350933,111890,'94694','watch','border-bottom-width','1',0,''),(350934,111890,'94694','watch','border-bottom-color','$content-border-1',0,''),(350935,111890,'94694','watch','margin-left','0',0,''),(350936,111890,'94694','watch','margin-right','0',0,''),(350937,111891,'94695','watch','float','left',0,''),(350938,111891,'94695','watch','clear','none',0,''),(350939,111891,'94695','watch','sort_pos_3','1',0,''),(350940,111891,'94695','watch','sort_pos_4','2',0,''),(350941,111891,'94695','watch','sort_pos_10','3',0,''),(350942,111891,'94695','watch','sort_pos_9','4',0,''),(350943,111891,'94695','watch','sort_pos_11','5',0,''),(350944,111891,'94695','watch','sort_pos_12','6',0,''),(350945,111891,'94695','watch','sort_pos_14','7',0,''),(350946,111891,'94695','watch','sort_pos_13','8',0,''),(350947,111891,'94695','watch','sort_pos_8','9',0,''),(350948,111891,'94695','watch','sort_pos_7','10',0,''),(350949,111891,'94695','watch','sort_pos_2','11',0,''),(350950,111891,'94695','watch','sort_pos_1','12',0,''),(350951,111891,'94695','watch','sort_pos_6','13',0,''),(350952,111891,'94695','watch','sort_pos_5','14',0,''),(350953,111891,'94695','watch','sort_pos_0','15',0,''),(350954,111891,'94695','watch','sort_hide_10','1',0,''),(350955,111891,'94695','watch','sort_hide_9','1',0,''),(350956,111891,'94695','watch','hide_icons','1',0,''),(350957,111891,'94695','watch','sort_hide_16','1',0,''),(350958,111891,'94695','watch','sort_hide_15','1',0,''),(350959,111891,'94695','watch','sort_hide_3','0',0,''),(350960,111891,'94695','watch','sort_hide_4','0',0,''),(350961,111891,'94695','watch','sort_hide_11','1',0,''),(350962,111891,'94695','watch','sort_hide_12','1',0,''),(350963,111891,'94695','watch','sort_hide_14','1',0,''),(350964,111891,'94695','watch','sort_hide_13','1',0,''),(350965,111891,'94695','watch','sort_hide_8','0',0,''),(350966,111891,'94695','watch','sort_hide_7','0',0,''),(350967,111891,'94695','watch','sort_hide_2','1',0,''),(350968,111891,'94695','watch','sort_hide_1','1',0,''),(350969,111891,'94695','watch','sort_hide_6','1',0,''),(350970,111891,'94695','watch','sort_hide_5','1',0,''),(350971,111891,'94695','watch','sort_hide_0','1',0,''),(350972,111892,'94696','watch','float','left',0,''),(350973,111892,'94696','watch','clear','none',0,''),(350974,111892,'94696','watch','margin-left','20',0,''),(350975,111892,'94696','watch','display','none',0,'5261'),(350976,111893,'94697','watch','margin-right','20',0,''),(350977,111893,'94697','watch','float','right',0,''),(350978,111893,'94697','watch','clear','none',0,''),(350979,111893,'94697','watch','display','none',0,'5240'),(350980,111894,'94698','watch','float','right',0,''),(350981,111894,'94698','watch','display','none',0,'5261'),(350982,111895,'94699','watch','listing_type','productListing',0,''),(350983,111897,'94701','watch','block_type','5',0,''),(350984,111897,'94701','watch','padding-top','10',0,''),(350985,111897,'94701','watch','padding-bottom','10',0,''),(350986,111897,'94701','watch','schema','5-2',0,'5261'),(350987,111897,'94701','watch','border-top-color','$content-border-1',0,''),(350988,111897,'94701','watch','border-top-width','1',0,''),(350989,111899,'94703','watch','float','right',0,''),(350990,111900,'73483','watch','block_type','1',0,''),(350991,111903,'73486','watch','block_type','1',0,''),(350992,111903,'73486','watch','padding-top','10',0,''),(350993,111903,'73486','watch','padding-bottom','10',0,''),(350994,111903,'73486','watch','border-bottom-width','1',0,''),(350995,111903,'73486','watch','border-bottom-color','$content-border-1',0,''),(350996,111903,'73486','watch','margin-left','0',0,''),(350997,111903,'73486','watch','margin-right','0',0,''),(350998,111904,'73487','watch','float','left',0,''),(350999,111904,'73487','watch','clear','none',0,''),(351000,111904,'73487','watch','margin-left','20',0,''),(351001,111904,'73487','watch','display','none',0,'5261'),(351002,111905,'73488','watch','float','left',0,''),(351003,111905,'73488','watch','clear','none',0,''),(351004,111905,'73488','watch','sort_pos_3','2',0,''),(351005,111905,'73488','watch','sort_pos_4','3',0,''),(351006,111905,'73488','watch','sort_pos_10','11',0,''),(351007,111905,'73488','watch','sort_pos_9','10',0,''),(351008,111905,'73488','watch','sort_pos_11','12',0,''),(351009,111905,'73488','watch','sort_pos_12','13',0,''),(351010,111905,'73488','watch','sort_pos_14','15',0,''),(351011,111905,'73488','watch','sort_pos_13','14',0,''),(351012,111905,'73488','watch','sort_pos_8','4',0,''),(351013,111905,'73488','watch','sort_pos_7','5',0,''),(351014,111905,'73488','watch','sort_pos_2','7',0,''),(351015,111905,'73488','watch','sort_pos_1','6',0,''),(351016,111905,'73488','watch','sort_pos_6','9',0,''),(351017,111905,'73488','watch','sort_pos_5','8',0,''),(351018,111905,'73488','watch','sort_pos_0','1',0,''),(351019,111905,'73488','watch','sort_hide_10','1',0,''),(351020,111905,'73488','watch','sort_hide_9','1',0,''),(351021,111905,'73488','watch','hide_icons','1',0,''),(351022,111905,'73488','watch','sort_hide_16','1',0,''),(351023,111905,'73488','watch','sort_hide_15','1',0,''),(351024,111905,'73488','watch','sort_hide_3','0',0,''),(351025,111905,'73488','watch','sort_hide_4','0',0,''),(351026,111905,'73488','watch','sort_hide_11','1',0,''),(351027,111905,'73488','watch','sort_hide_12','1',0,''),(351028,111905,'73488','watch','sort_hide_14','1',0,''),(351029,111905,'73488','watch','sort_hide_13','1',0,''),(351030,111905,'73488','watch','sort_hide_8','0',0,''),(351031,111905,'73488','watch','sort_hide_7','0',0,''),(351032,111905,'73488','watch','sort_hide_2','1',0,''),(351033,111905,'73488','watch','sort_hide_1','1',0,''),(351034,111905,'73488','watch','sort_hide_6','1',0,''),(351035,111905,'73488','watch','sort_hide_5','1',0,''),(351036,111905,'73488','watch','sort_hide_0','0',0,''),(351037,111905,'73488','watch','sort_pos_15','16',0,''),(351038,111905,'73488','watch','sort_pos_16','17',0,''),(351039,111906,'73489','watch','margin-right','20',0,''),(351040,111906,'73489','watch','float','right',0,''),(351041,111906,'73489','watch','clear','none',0,''),(351042,111906,'73489','watch','display','none',0,'5240'),(351043,111907,'73490','watch','float','right',0,''),(351044,111907,'73490','watch','display','none',0,'5261'),(351045,111908,'73491','watch','clear','none',0,''),(351046,111908,'73491','watch','float','left',0,''),(351047,111908,'73491','watch','padding-top','3',0,''),(351048,111908,'73491','watch','padding-left','20',0,''),(351049,111909,'73492','watch','block_type','5',0,''),(351050,111909,'73492','watch','padding-top','10',0,''),(351051,111909,'73492','watch','padding-bottom','10',0,''),(351052,111909,'73492','watch','schema','5-2',0,'5261'),(351053,111909,'73492','watch','border-top-color','$content-border-1',0,''),(351054,111909,'73492','watch','border-top-width','1',0,''),(351055,111911,'73494','watch','float','right',0,''),(351056,111912,'73495','watch','col_in_row','4',0,''),(351057,111912,'73495','watch','products_align','left',0,''),(351058,111912,'73495','watch','font-weight','400',0,''),(351059,111912,'73495','watch','show_qty_input','0',0,''),(351060,111912,'73495','watch','listing_type','productListing',0,''),(351061,111912,'73495','watch','listing_type_rows','Rows',0,''),(351062,111912,'73495','watch','show_buy_button_b2b','on',0,''),(351063,111912,'73495','watch','show_wishlist_button_b2b','1',0,''),(351064,111912,'73495','watch','show_compare_b2b','1',0,''),(351065,111912,'73495','watch','show_image','0',0,''),(351066,111912,'73495','watch','show_stock','0',0,''),(351067,111912,'73495','watch','show_description','0',0,''),(351068,111912,'73495','watch','show_model','0',0,''),(351069,111912,'73495','watch','show_properties','0',0,''),(351070,111912,'73495','watch','show_rating','0',0,''),(351071,111912,'73495','watch','show_rating_counts','0',0,''),(351072,111912,'73495','watch','show_price','0',0,''),(351073,111912,'73495','watch','show_buy_button','0',0,''),(351074,111912,'73495','watch','show_view_button','0',0,''),(351075,111912,'73495','watch','show_wishlist_button','0',0,''),(351076,111912,'73495','watch','show_compare','0',0,''),(351077,111912,'73495','watch','show_name_rows','0',0,''),(351078,111912,'73495','watch','show_image_rows','0',0,''),(351079,111912,'73495','watch','show_stock_rows','0',0,''),(351080,111912,'73495','watch','show_description_rows','0',0,''),(351081,111912,'73495','watch','show_model_rows','0',0,''),(351082,111912,'73495','watch','show_properties_rows','0',0,''),(351083,111912,'73495','watch','show_rating_rows','0',0,''),(351084,111912,'73495','watch','show_rating_counts_rows','0',0,''),(351085,111912,'73495','watch','show_price_rows','0',0,''),(351086,111912,'73495','watch','show_buy_button_rows','0',0,''),(351087,111912,'73495','watch','show_qty_input_rows','0',0,''),(351088,111912,'73495','watch','show_view_button_rows','0',0,''),(351089,111912,'73495','watch','show_wishlist_button_rows','0',0,''),(351090,111912,'73495','watch','show_compare_rows','0',0,''),(351091,111912,'73495','watch','show_name_b2b','0',0,''),(351092,111912,'73495','watch','show_image_b2b','0',0,''),(351093,111912,'73495','watch','show_stock_b2b','0',0,''),(351094,111912,'73495','watch','show_description_b2b','0',0,''),(351095,111912,'73495','watch','show_model_b2b','0',0,''),(351096,111912,'73495','watch','show_properties_b2b','0',0,''),(351097,111912,'73495','watch','show_rating_b2b','0',0,''),(351098,111912,'73495','watch','show_rating_counts_b2b','0',0,''),(351099,111912,'73495','watch','show_price_b2b','0',0,''),(351100,111912,'73495','watch','show_qty_input_b2b','0',0,''),(351101,111912,'73495','watch','show_view_button_b2b','0',0,''),(351102,111912,'73495','watch','show_attributes_b2b','0',0,''),(351103,111912,'73495','watch','items_on_page','12',0,''),(351104,111912,'73495','watch','col_in_row','2',0,'5240'),(351105,111912,'73495','watch','col_in_row','1',0,'5261'),(351106,111912,'73495','watch','product_names_teg','h2',0,''),(351107,111915,'1683125852.345798','watch','block_type','1',0,''),(351108,111915,'1683125852.345798','watch','background-color','$content-bg-2',0,''),(351109,111915,'1683125852.345798','watch','padding-top','30',0,''),(351110,111915,'1683125852.345798','watch','padding-bottom','30',0,''),(351111,111915,'1683125852.345798','watch','style_class','checkout-index-wrap',0,''),(351112,111915,'1683125852.345798','watch','color','$content-color-2',0,''),(351113,111916,'1683125852.356555','watch','block_type','4',0,''),(351114,111916,'1683125852.356555','watch','schema','4-2',0,'5240'),(351115,111916,'1683125852.356555','watch','style_class','checkoutDoubleBox',0,''),(351116,111917,'1683125852.358412','watch','block_type','1',0,''),(351117,111917,'1683125852.358412','watch','padding-right','40',0,''),(351118,111917,'1683125852.358412','watch','padding-right','0',0,'5240'),(351119,111918,'1683125852.35982','watch','block_type','1',0,''),(351120,111918,'1683125852.35982','watch','background-color','$content-bg-1',0,''),(351121,111918,'1683125852.35982','watch','padding-top','30',0,''),(351122,111918,'1683125852.35982','watch','padding-left','30',0,''),(351123,111918,'1683125852.35982','watch','padding-right','30',0,''),(351124,111918,'1683125852.35982','watch','padding-bottom','30',0,''),(351125,111918,'1683125852.35982','watch','margin-bottom','20',0,''),(351126,111918,'1683125852.35982','watch','style_class','hiding-box closeable-box',0,''),(351127,111918,'1683125852.35982','watch','color','$content-color-1',0,''),(351128,111919,'1683125852.361569','watch','style_class','closeable-content',0,''),(351129,111919,'1683125852.361569','watch','padding-bottom','20',0,''),(351130,111920,'1683125852.362847','watch','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(351131,111920,'1683125852.362847','watch','style_class','closeable-heading closeable-event closed',0,''),(351132,111921,'1683125852.36485','watch','block_type','1',0,''),(351133,111921,'1683125852.36485','watch','padding-top','30',0,''),(351134,111921,'1683125852.36485','watch','padding-left','30',0,''),(351135,111921,'1683125852.36485','watch','padding-right','30',0,''),(351136,111921,'1683125852.36485','watch','padding-bottom','30',0,''),(351137,111921,'1683125852.36485','watch','margin-bottom','20',0,''),(351138,111921,'1683125852.36485','watch','background-color','$content-bg-1',0,''),(351139,111921,'1683125852.36485','watch','style_class','hiding-box closeable-box',0,''),(351140,111921,'1683125852.36485','watch','color','$content-color-1',0,''),(351141,111922,'1683125852.366422','watch','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(351142,111922,'1683125852.366422','watch','style_class','closeable-heading closeable-event closed',0,''),(351143,111923,'1683125852.367732','watch','block_type','2',0,''),(351144,111923,'1683125852.367732','watch','style_class','closeable-content',0,''),(351145,111923,'1683125852.367732','watch','schema','2-2',0,'5240'),(351146,111924,'1683125852.36968','watch','padding-right','20',0,''),(351147,111924,'1683125852.36968','watch','padding-bottom','20',0,''),(351148,111924,'1683125852.36968','watch','padding-right','0',0,'5240'),(351149,111925,'1683125852.369745','watch','padding-left','20',0,''),(351150,111925,'1683125852.369745','watch','padding-bottom','20',0,''),(351151,111925,'1683125852.369745','watch','padding-left','0',0,'5240'),(351152,111926,'1683125852.37045','watch','padding-left','20',0,''),(351153,111926,'1683125852.37045','watch','padding-bottom','20',0,''),(351154,111926,'1683125852.37045','watch','padding-left','0',0,'5240'),(351155,111927,'1683125852.371233','watch','background-color','$content-bg-1',0,''),(351156,111927,'1683125852.371233','watch','block_type','1',0,''),(351157,111927,'1683125852.371233','watch','padding-top','30',0,''),(351158,111927,'1683125852.371233','watch','padding-left','30',0,''),(351159,111927,'1683125852.371233','watch','padding-right','30',0,''),(351160,111927,'1683125852.371233','watch','padding-bottom','30',0,''),(351161,111927,'1683125852.371233','watch','margin-bottom','20',0,''),(351162,111927,'1683125852.371233','watch','style_class','hiding-box',0,''),(351163,111927,'1683125852.371233','watch','color','$content-color-1',0,''),(351164,111928,'1683125852.37350','watch','block_type','1',0,''),(351165,111928,'1683125852.37350','watch','content','\\_',0,'3'),(351166,111928,'1683125852.37350','watch','border-top-width','1',0,'3'),(351167,111928,'1683125852.37350','watch','border-top-color','#e0e0e0',0,'3'),(351168,111928,'1683125852.37350','watch','display','block',0,'3'),(351169,111928,'1683125852.37350','watch','position','absolute',0,'3'),(351170,111928,'1683125852.37350','watch','top','19',0,'3'),(351171,111928,'1683125852.37350','watch','left','0',0,'3'),(351172,111928,'1683125852.37350','watch','right','0',0,'3'),(351173,111928,'1683125852.37350','watch','margin-top','-2',0,'3'),(351174,111928,'1683125852.37350','watch','position','relative',0,''),(351175,111929,'1683125852.374899','watch','box_align','2',0,''),(351176,111929,'1683125852.374899','watch','margin-bottom','10',0,''),(351177,111929,'1683125852.374899','watch','background-color','$content-bg-1',0,''),(351178,111929,'1683125852.374899','watch','position','relative',0,''),(351179,111930,'1683125852.375685','watch','background-color','$content-bg-2',0,''),(351180,111930,'1683125852.375685','watch','padding-top','10',0,''),(351181,111930,'1683125852.375685','watch','padding-left','10',0,''),(351182,111930,'1683125852.375685','watch','padding-right','10',0,''),(351183,111930,'1683125852.375685','watch','padding-bottom','10',0,''),(351184,111930,'1683125852.375685','watch','margin-top','10',0,''),(351185,111931,'1683125852.376557','watch','block_type','2',0,''),(351186,111931,'1683125852.376557','watch','schema','2-2',0,'5240'),(351187,111932,'1683125852.377637','watch','block_type','1',0,''),(351188,111932,'1683125852.377637','watch','padding-right','20',0,''),(351189,111932,'1683125852.377637','watch','padding-left','0',0,'5240'),(351190,111932,'1683125852.377637','watch','margin-bottom','20',0,'5240'),(351191,111932,'1683125852.377637','watch','padding-right','0',0,'5240'),(351192,111933,'1683125852.378829','watch','address_in','popup',0,''),(351193,111934,'1683125852.379375','watch','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(351194,111937,'1683125852.381183','watch','block_type','1',0,''),(351195,111937,'1683125852.381183','watch','padding-left','20',0,''),(351196,111937,'1683125852.381183','watch','padding-left','0',0,'5240'),(351197,111939,'1683125852.382635','watch','border-top-width','1',0,''),(351198,111939,'1683125852.382635','watch','border-top-color','#e0e0e0',0,''),(351199,111939,'1683125852.382635','watch','padding-top','13',0,''),(351200,111939,'1683125852.382635','watch','padding-bottom','10',0,''),(351201,111940,'1683125852.383516','watch','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(351202,111941,'1683125852.385278','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(351203,111942,'1683125852.386397','watch','margin-bottom','20',0,''),(351204,111942,'1683125852.386397','watch','style_class','hiding-box',0,''),(351205,111943,'1683125852.386970','watch','padding-top','30',0,''),(351206,111943,'1683125852.386970','watch','padding-left','30',0,''),(351207,111943,'1683125852.386970','watch','padding-right','30',0,''),(351208,111943,'1683125852.386970','watch','margin-top','20',0,''),(351209,111943,'1683125852.386970','watch','background-color','$content-bg-1',0,''),(351210,111943,'1683125852.386970','watch','padding-bottom','30',0,''),(351211,111943,'1683125852.386970','watch','margin-bottom','20',0,''),(351212,111943,'1683125852.386970','watch','color','$content-color-1',0,''),(351213,111944,'1683125852.38820','watch','block_type','1',0,''),(351214,111944,'1683125852.38820','watch','padding-top','30',0,''),(351215,111944,'1683125852.38820','watch','padding-left','30',0,''),(351216,111944,'1683125852.38820','watch','padding-right','30',0,''),(351217,111944,'1683125852.38820','watch','padding-bottom','23',0,''),(351218,111944,'1683125852.38820','watch','margin-bottom','20',0,''),(351219,111944,'1683125852.38820','watch','background-color','$content-bg-1',0,''),(351220,111944,'1683125852.38820','watch','style_class','hiding-box',0,''),(351221,111944,'1683125852.38820','watch','color','$content-color-1',0,''),(351222,111945,'1683125852.390244','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(351223,111946,'1683125852.391810','watch','block_type','2',0,''),(351224,111946,'1683125852.391810','watch','schema','2-2',0,'5240'),(351225,111947,'1683125852.393320','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351226,111948,'1683125852.394747','watch','padding-right','20',0,''),(351227,111948,'1683125852.394747','watch','padding-right','0',0,'5240'),(351228,111948,'1683125852.394747','watch','padding-bottom','20',0,'5240'),(351229,111948,'1683125852.394747','watch','address_in','popup',0,''),(351230,111949,'1683125852.395767','watch','block_type','1',0,''),(351231,111949,'1683125852.395767','watch','padding-left','20',0,''),(351232,111949,'1683125852.395767','watch','padding-left','0',0,'5240'),(351233,111951,'1683125852.398588','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351234,111952,'1683125852.400291','watch','block_type','1',0,''),(351235,111952,'1683125852.400291','watch','padding-top','30',0,''),(351236,111952,'1683125852.400291','watch','padding-left','30',0,''),(351237,111952,'1683125852.400291','watch','padding-right','30',0,''),(351238,111952,'1683125852.400291','watch','padding-bottom','30',0,''),(351239,111952,'1683125852.400291','watch','margin-bottom','20',0,''),(351240,111952,'1683125852.400291','watch','background-color','$content-bg-1',0,''),(351241,111952,'1683125852.400291','watch','color','$content-color-1',0,''),(351242,111955,'1683125852.403563','watch','block_type','1',0,''),(351243,111955,'1683125852.403563','watch','padding-top','20',0,''),(351244,111955,'1683125852.403563','watch','padding-left','20',0,''),(351245,111955,'1683125852.403563','watch','padding-right','20',0,''),(351246,111955,'1683125852.403563','watch','padding-bottom','20',0,''),(351247,111955,'1683125852.403563','watch','background-color','$content-bg-1',0,''),(351248,111955,'1683125852.403563','watch','style_class','order-summary',0,''),(351249,111955,'1683125852.403563','watch','color','$content-color-1',0,''),(351250,111956,'1683125852.405625','watch','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(351251,111956,'1683125852.405625','watch','text-align','center',0,''),(351252,111956,'1683125852.405625','watch','font-size','14',0,''),(351253,111956,'1683125852.405625','watch','color','$fade-color-1',0,''),(351254,111956,'1683125852.405625','watch','padding-top','10',0,''),(351255,111957,'1683125852.407666','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(351256,111958,'1683125852.40885','watch','hide_page','1',0,''),(351257,111958,'1683125852.40885','watch','hide_continue_button','1',0,''),(351258,111959,'1683125852.409688','watch','margin-bottom','10',0,''),(351259,111962,'73542','watch','block_type','1',0,''),(351260,111963,'73543','watch','margin-top','20',0,''),(351261,111964,'73544','watch','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(351262,111965,'73545','watch','link','products',0,''),(351263,111965,'73545','watch','margin-top','-33',0,''),(351264,111965,'73545','watch','float','right',0,''),(351265,111966,'73546','watch','block_type','2',0,''),(351266,111966,'73546','watch','margin-bottom','20',0,''),(351267,111966,'73546','watch','schema','2-2',0,'5232'),(351268,111967,'73547','watch','block_type','1',0,''),(351269,111967,'73547','watch','padding-right','20',0,''),(351270,111967,'73547','watch','padding-right','0',0,'5232'),(351271,111968,'73548','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(351272,111968,'73548','watch','clear','none',0,''),(351273,111970,'73550','watch','padding-left','20',0,''),(351274,111970,'73550','watch','block_type','1',0,''),(351275,111970,'73550','watch','padding-left','0',0,'5232'),(351276,111972,'73552','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351277,111972,'73552','watch','clear','none',0,''),(351278,111973,'73553','watch','text-align','right',0,''),(351279,111973,'73553','watch','margin-bottom','20',0,''),(351280,111973,'73553','watch','margin-top','20',0,''),(351281,111974,'73554','watch','block_type','2',0,''),(351282,111974,'73554','watch','margin-bottom','20',0,''),(351283,111974,'73554','watch','schema','2-2',0,'5232'),(351284,111975,'73555','watch','block_type','1',0,''),(351285,111975,'73555','watch','padding-right','20',0,''),(351286,111975,'73555','watch','padding-right','0',0,'5232'),(351287,111977,'73557','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(351288,111977,'73557','watch','clear','none',0,''),(351289,111978,'73558','watch','block_type','1',0,''),(351290,111978,'73558','watch','padding-left','20',0,''),(351291,111978,'73558','watch','padding-left','0',0,'5232'),(351292,111979,'73559','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351293,111979,'73559','watch','clear','none',0,''),(351294,111981,'73561','watch','margin-bottom','20',0,''),(351295,111981,'73561','watch','text-align','right',0,''),(351296,111983,'73576','watch','block_type','1',0,''),(351297,111984,'73577','watch','text-align','right',0,''),(351298,111984,'73577','watch','margin-bottom','20',0,''),(351299,111985,'73578','watch','block_type','2',0,''),(351300,111985,'73578','watch','margin-bottom','20',0,''),(351301,111985,'73578','watch','schema','2-2',0,'5232'),(351302,111986,'73579','watch','block_type','1',0,''),(351303,111986,'73579','watch','padding-right','20',0,''),(351304,111986,'73579','watch','padding-right','0',0,'5232'),(351305,111987,'73580','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351306,111987,'73580','watch','clear','none',0,''),(351307,111989,'73582','watch','block_type','1',0,''),(351308,111989,'73582','watch','padding-left','20',0,''),(351309,111989,'73582','watch','padding-left','0',0,'5232'),(351310,111990,'73583','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351311,111990,'73583','watch','clear','none',0,''),(351312,111992,'73585','watch','margin-bottom','20',0,''),(351313,111992,'73585','watch','text-align','right',0,''),(351314,111995,'73588','watch','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(351315,111996,'73563','watch','block_type','1',0,''),(351316,111997,'73564','watch','margin-bottom','20',0,''),(351317,111998,'73565','watch','margin-bottom','20',0,''),(351318,111998,'73565','watch','text-align','right',0,''),(351319,111999,'73566','watch','text-align','right',0,''),(351320,111999,'73566','watch','margin-bottom','20',0,''),(351321,112000,'73567','watch','block_type','2',0,''),(351322,112000,'73567','watch','margin-bottom','20',0,''),(351323,112000,'73567','watch','schema','2-2',0,'5232'),(351324,112001,'73568','watch','block_type','1',0,''),(351325,112001,'73568','watch','padding-right','20',0,''),(351326,112001,'73568','watch','padding-right','0',0,'5232'),(351327,112003,'73570','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351328,112003,'73570','watch','clear','none',0,''),(351329,112004,'73571','watch','block_type','1',0,''),(351330,112004,'73571','watch','padding-left','20',0,''),(351331,112004,'73571','watch','padding-left','0',0,'5232'),(351332,112006,'73573','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351333,112006,'73573','watch','clear','none',0,''),(351334,112007,'73574','watch','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(351335,112008,'73575','watch','margin-bottom','20',0,''),(351336,112009,'73589','watch','block_type','1',0,''),(351337,112010,'73590','watch','block_type','2',0,''),(351338,112010,'73590','watch','margin-bottom','20',0,''),(351339,112010,'73590','watch','schema','2-2',0,'5232'),(351340,112011,'73591','watch','block_type','1',0,''),(351341,112011,'73591','watch','padding-right','20',0,''),(351342,112011,'73591','watch','padding-right','0',0,'5232'),(351343,112013,'73593','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(351344,112013,'73593','watch','clear','none',0,''),(351345,112014,'73594','watch','block_type','1',0,''),(351346,112014,'73594','watch','padding-left','20',0,''),(351347,112014,'73594','watch','padding-left','0',0,'5232'),(351348,112016,'73596','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351349,112016,'73596','watch','clear','none',0,''),(351350,112017,'73597','watch','margin-bottom','20',0,''),(351351,112018,'73598','watch','margin-bottom','20',0,''),(351352,112019,'73599','watch','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(351353,112020,'73600','watch','link','products',0,''),(351354,112020,'73600','watch','margin-top','-33',0,''),(351355,112020,'73600','watch','float','right',0,''),(351356,112021,'73601','watch','text-align','right',0,''),(351357,112021,'73601','watch','margin-bottom','20',0,''),(351358,112022,'73602','watch','margin-bottom','20',0,''),(351359,112022,'73602','watch','text-align','right',0,''),(351360,112023,'73603','watch','block_type','2',0,''),(351361,112023,'73603','watch','margin-bottom','20',0,''),(351362,112023,'73603','watch','schema','2-2',0,'5232'),(351363,112024,'73604','watch','block_type','1',0,''),(351364,112024,'73604','watch','padding-right','20',0,''),(351365,112024,'73604','watch','padding-right','0',0,'5232'),(351366,112025,'73605','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(351367,112025,'73605','watch','clear','none',0,''),(351368,112027,'73607','watch','padding-left','20',0,''),(351369,112027,'73607','watch','block_type','1',0,''),(351370,112027,'73607','watch','padding-left','0',0,'5232'),(351371,112028,'73608','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351372,112028,'73608','watch','clear','none',0,''),(351373,112030,'73610','watch','text','##TEXT_CONFIRMATION##',0,''),(351374,112031,'73611','watch','text','##TEXT_CONFIRMATION##',0,''),(351375,112032,'73613','watch','text','##TEXT_CONFIRMATION##',0,''),(351376,112033,'73612','watch','text','##TEXT_CONFIRMATION##',0,''),(351377,112034,'73614','watch','text','##TEXT_CONFIRMATION##',0,''),(351378,112035,'73615','watch','text','##TEXT_CONFIRMATION##',0,''),(351379,112036,'73616','watch','block_type','2',0,''),(351380,112037,'73617','watch','block_type','1',0,''),(351381,112037,'73617','watch','padding-right','20',0,''),(351382,112038,'73618','watch','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(351383,112040,'73620','watch','block_type','1',0,''),(351384,112040,'73620','watch','padding-left','20',0,''),(351385,112040,'73620','watch','padding-left','0',0,'5240'),(351386,112041,'73621','watch','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(351387,112043,'73623','watch','block_type','4',0,''),(351388,112043,'73623','watch','schema','4-2',0,'5261'),(351389,112043,'73623','watch','padding-top','20',0,''),(351390,112044,'73624','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351391,112044,'73624','watch','text-align','right',0,''),(351392,112044,'73624','watch','padding-top','10',0,''),(351393,112044,'73624','watch','font_size_measure','em',0,''),(351394,112044,'73624','watch','font-size','1.2',0,''),(351395,112045,'73625','watch','text-align','right',0,''),(351396,112046,'73626','watch','block_type','2',0,''),(351397,112047,'73627','watch','block_type','1',0,''),(351398,112047,'73627','watch','padding-right','20',0,''),(351399,112047,'73627','watch','padding-right','0',0,'5240'),(351400,112048,'73628','watch','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(351401,112050,'73630','watch','block_type','1',0,''),(351402,112050,'73630','watch','padding-right','0',0,'5240'),(351403,112050,'73630','watch','padding-left','20',0,''),(351404,112053,'73633','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(351405,112055,'73635','watch','block_type','2',0,''),(351406,112056,'73636','watch','block_type','1',0,''),(351407,112056,'73636','watch','padding-right','20',0,''),(351408,112058,'73638','watch','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(351409,112059,'73639','watch','block_type','1',0,''),(351410,112059,'73639','watch','padding-left','20',0,''),(351411,112059,'73639','watch','padding-left','0',0,'5240'),(351412,112060,'73640','watch','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(351413,112062,'73642','watch','block_type','4',0,''),(351414,112062,'73642','watch','schema','4-2',0,'5261'),(351415,112063,'73643','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351416,112063,'73643','watch','text-align','right',0,''),(351417,112063,'73643','watch','padding-top','10',0,''),(351418,112063,'73643','watch','font_size_measure','em',0,''),(351419,112063,'73643','watch','font-size','1.2',0,''),(351420,112064,'73644','watch','text-align','right',0,''),(351421,112065,'73645','watch','block_type','2',0,''),(351422,112066,'73646','watch','block_type','1',0,''),(351423,112066,'73646','watch','padding-right','20',0,''),(351424,112066,'73646','watch','padding-right','0',0,'5240'),(351425,112068,'73648','watch','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(351426,112069,'73649','watch','block_type','1',0,''),(351427,112069,'73649','watch','padding-right','0',0,'5240'),(351428,112069,'73649','watch','padding-left','20',0,''),(351429,112071,'73651','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(351430,112074,'73654','watch','block_type','4',0,''),(351431,112074,'73654','watch','schema','4-2',0,'5261'),(351432,112075,'73655','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351433,112075,'73655','watch','text-align','right',0,''),(351434,112075,'73655','watch','padding-top','10',0,''),(351435,112075,'73655','watch','font_size_measure','em',0,''),(351436,112075,'73655','watch','font-size','1.2',0,''),(351437,112076,'73656','watch','text-align','right',0,''),(351438,112077,'73657','watch','block_type','2',0,''),(351439,112078,'73658','watch','block_type','1',0,''),(351440,112078,'73658','watch','padding-right','20',0,''),(351441,112080,'73660','watch','block_type','1',0,''),(351442,112080,'73660','watch','padding-left','20',0,''),(351443,112080,'73660','watch','padding-left','0',0,'5240'),(351444,112081,'73661','watch','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(351445,112083,'73663','watch','block_type','4',0,''),(351446,112083,'73663','watch','schema','4-2',0,'5261'),(351447,112084,'73664','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351448,112084,'73664','watch','text-align','right',0,''),(351449,112084,'73664','watch','padding-top','10',0,''),(351450,112084,'73664','watch','font_size_measure','em',0,''),(351451,112084,'73664','watch','font-size','1.2',0,''),(351452,112085,'73665','watch','text-align','right',0,''),(351453,112086,'73666','watch','block_type','2',0,''),(351454,112087,'73667','watch','block_type','1',0,''),(351455,112087,'73667','watch','padding-right','20',0,''),(351456,112089,'73669','watch','block_type','1',0,''),(351457,112089,'73669','watch','padding-left','20',0,''),(351458,112089,'73669','watch','padding-left','0',0,'5240'),(351459,112091,'73671','watch','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(351460,112092,'73672','watch','text','##DELIVERY_DETAILS##',0,''),(351461,112093,'73673','watch','text','##DELIVERY_DETAILS##',0,''),(351462,112094,'73675','watch','text','##CONTACT_INFORMATION##',0,''),(351463,112095,'73674','watch','text','##CONTACT_INFORMATION##',0,''),(351464,112096,'73676','watch','text','##DELIVERY_DETAILS##',0,''),(351465,112097,'73677','watch','text','##DELIVERY_DETAILS##',0,''),(351466,112098,'73678','watch','block_type','1',0,''),(351467,112098,'73678','watch','background-color','$content-bg-2',0,''),(351468,112098,'73678','watch','padding-top','30',0,''),(351469,112098,'73678','watch','padding-bottom','30',0,''),(351470,112099,'73679','watch','block_type','4',0,''),(351471,112099,'73679','watch','schema','4-2',0,'5240'),(351472,112100,'73680','watch','block_type','1',0,''),(351473,112100,'73680','watch','padding-right','40',0,''),(351474,112100,'73680','watch','padding-right','0',0,'5240'),(351475,112101,'73682','watch','block_type','1',0,''),(351476,112101,'73682','watch','background-color','$content-bg-1',0,''),(351477,112101,'73682','watch','padding-top','30',0,''),(351478,112101,'73682','watch','padding-left','30',0,''),(351479,112101,'73682','watch','padding-right','30',0,''),(351480,112101,'73682','watch','padding-bottom','30',0,''),(351481,112101,'73682','watch','margin-bottom','20',0,''),(351482,112101,'73682','watch','style_class','hiding-box',0,''),(351483,112102,'73683','watch','margin-bottom','20',0,''),(351484,112103,'73684','watch','padding-top','10',0,''),(351485,112103,'73684','watch','padding-left','20',0,''),(351486,112103,'73684','watch','padding-right','20',0,''),(351487,112103,'73684','watch','margin-top','20',0,''),(351488,112103,'73684','watch','background-color','$content-bg-2',0,''),(351489,112103,'73684','watch','padding-bottom','8',0,''),(351490,112104,'73685','watch','block_type','1',0,''),(351491,112104,'73685','watch','background-color','$content-bg-1',0,''),(351492,112104,'73685','watch','padding-top','30',0,''),(351493,112104,'73685','watch','padding-left','30',0,''),(351494,112104,'73685','watch','padding-right','30',0,''),(351495,112104,'73685','watch','padding-bottom','14',0,''),(351496,112104,'73685','watch','margin-bottom','20',0,''),(351497,112104,'73685','watch','style_class','hiding-box closeable-box',0,''),(351498,112105,'73686','watch','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(351499,112105,'73686','watch','style_class','closeable-heading closeable-event closed',0,''),(351500,112106,'73687','watch','style_class','closeable-content',0,''),(351501,112106,'73687','watch','padding-bottom','20',0,''),(351502,112107,'73688','watch','background-color','$content-bg-1',0,''),(351503,112107,'73688','watch','block_type','1',0,''),(351504,112107,'73688','watch','padding-top','30',0,''),(351505,112107,'73688','watch','padding-left','30',0,''),(351506,112107,'73688','watch','padding-right','30',0,''),(351507,112107,'73688','watch','padding-bottom','30',0,''),(351508,112107,'73688','watch','margin-bottom','20',0,''),(351509,112107,'73688','watch','style_class','hiding-box',0,''),(351510,112108,'73689','watch','block_type','1',0,''),(351511,112108,'73689','watch','content','\\_',0,'3'),(351512,112108,'73689','watch','border-top-width','1',0,'3'),(351513,112108,'73689','watch','border-top-color','$content-border-1',0,'3'),(351514,112108,'73689','watch','display','block',0,'3'),(351515,112108,'73689','watch','position','absolute',0,'3'),(351516,112108,'73689','watch','top','19',0,'3'),(351517,112108,'73689','watch','left','0',0,'3'),(351518,112108,'73689','watch','right','0',0,'3'),(351519,112108,'73689','watch','margin-top','-2',0,'3'),(351520,112108,'73689','watch','position','relative',0,''),(351521,112109,'73690','watch','box_align','2',0,''),(351522,112109,'73690','watch','margin-bottom','10',0,''),(351523,112109,'73690','watch','background-color','$content-bg-1',0,''),(351524,112109,'73690','watch','position','relative',0,''),(351525,112110,'73691','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(351526,112111,'73692','watch','block_type','2',0,''),(351527,112111,'73692','watch','schema','2-2',0,'5240'),(351528,112112,'73693','watch','block_type','1',0,''),(351529,112112,'73693','watch','padding-right','20',0,''),(351530,112112,'73693','watch','padding-left','0',0,'5240'),(351531,112112,'73693','watch','margin-bottom','20',0,'5240'),(351532,112115,'73696','watch','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(351533,112116,'73697','watch','block_type','1',0,''),(351534,112116,'73697','watch','padding-left','20',0,''),(351535,112116,'73697','watch','padding-left','0',0,'5240'),(351536,112117,'73698','watch','border-top-width','1',0,''),(351537,112117,'73698','watch','border-top-color','$content-border-1',0,''),(351538,112117,'73698','watch','padding-top','13',0,''),(351539,112117,'73698','watch','padding-bottom','10',0,''),(351540,112118,'73699','watch','background-color','$content-bg-2',0,''),(351541,112118,'73699','watch','padding-top','10',0,''),(351542,112118,'73699','watch','padding-left','10',0,''),(351543,112118,'73699','watch','padding-right','10',0,''),(351544,112118,'73699','watch','padding-bottom','10',0,''),(351545,112118,'73699','watch','margin-top','10',0,''),(351546,112119,'73700','watch','block_type','1',0,''),(351547,112119,'73700','watch','padding-top','20',0,''),(351548,112119,'73700','watch','padding-left','20',0,''),(351549,112119,'73700','watch','padding-right','20',0,''),(351550,112119,'73700','watch','padding-bottom','20',0,''),(351551,112119,'73700','watch','background-color','$content-bg-1',0,''),(351552,112119,'73700','watch','style_class','order-summary',0,''),(351553,112120,'73701','watch','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(351554,112120,'73701','watch','text-align','center',0,''),(351555,112120,'73701','watch','font-size','14',0,''),(351556,112120,'73701','watch','color','$fade-color-1',0,''),(351557,112120,'73701','watch','padding-top','10',0,''),(351558,112122,'115999','watch','hide_continue_button','1',0,''),(351559,112123,'73703','watch','block_type','1',0,''),(351560,112123,'73703','watch','background-color','$content-bg-2',0,''),(351561,112123,'73703','watch','padding-top','30',0,''),(351562,112123,'73703','watch','padding-bottom','30',0,''),(351563,112123,'73703','watch','color','$content-color-2',0,''),(351564,112124,'73704','watch','block_type','4',0,''),(351565,112125,'73705','watch','block_type','1',0,''),(351566,112125,'73705','watch','padding-right','40',0,''),(351567,112126,'73706','watch','block_type','1',0,''),(351568,112126,'73706','watch','background-color','$content-bg-1',0,''),(351569,112126,'73706','watch','padding-top','30',0,''),(351570,112126,'73706','watch','padding-left','30',0,''),(351571,112126,'73706','watch','padding-right','30',0,''),(351572,112126,'73706','watch','padding-bottom','30',0,''),(351573,112126,'73706','watch','margin-bottom','20',0,''),(351574,112126,'73706','watch','style_class','hiding-box',0,''),(351575,112126,'73706','watch','color','$content-color-1',0,''),(351576,112127,'73707','watch','padding-top','10',0,''),(351577,112127,'73707','watch','padding-left','20',0,''),(351578,112127,'73707','watch','padding-right','20',0,''),(351579,112127,'73707','watch','margin-top','20',0,''),(351580,112127,'73707','watch','background-color','$content-bg-2',0,''),(351581,112127,'73707','watch','padding-bottom','8',0,''),(351582,112127,'73707','watch','color','$content-color-2',0,''),(351583,112128,'73708','watch','margin-bottom','20',0,''),(351584,112129,'73709','watch','block_type','1',0,''),(351585,112129,'73709','watch','padding-top','30',0,''),(351586,112129,'73709','watch','padding-left','30',0,''),(351587,112129,'73709','watch','padding-right','30',0,''),(351588,112129,'73709','watch','padding-bottom','23',0,''),(351589,112129,'73709','watch','margin-bottom','20',0,''),(351590,112129,'73709','watch','background-color','$content-bg-1',0,''),(351591,112129,'73709','watch','style_class','hiding-box',0,''),(351592,112129,'73709','watch','color','$content-color-1',0,''),(351593,112130,'73710','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(351594,112131,'73711','watch','block_type','2',0,''),(351595,112132,'73712','watch','padding-right','20',0,''),(351596,112133,'73713','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351597,112134,'73714','watch','block_type','1',0,''),(351598,112134,'73714','watch','padding-left','20',0,''),(351599,112135,'73715','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351600,112137,'73717','watch','block_type','1',0,''),(351601,112137,'73717','watch','padding-top','30',0,''),(351602,112137,'73717','watch','padding-left','30',0,''),(351603,112137,'73717','watch','padding-right','30',0,''),(351604,112137,'73717','watch','padding-bottom','14',0,''),(351605,112137,'73717','watch','margin-bottom','20',0,''),(351606,112137,'73717','watch','background-color','$content-bg-1',0,''),(351607,112137,'73717','watch','style_class','hiding-box closeable-box',0,''),(351608,112137,'73717','watch','color','$content-color-1',0,''),(351609,112138,'73718','watch','block_type','2',0,''),(351610,112138,'73718','watch','style_class','closeable-content',0,''),(351611,112139,'73719','watch','padding-right','20',0,''),(351612,112139,'73719','watch','padding-bottom','20',0,''),(351613,112140,'73720','watch','padding-left','20',0,''),(351614,112140,'73720','watch','padding-bottom','20',0,''),(351615,112141,'73721','watch','padding-left','20',0,''),(351616,112141,'73721','watch','padding-bottom','20',0,''),(351617,112142,'73722','watch','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(351618,112142,'73722','watch','style_class','closeable-heading closeable-event closed',0,''),(351619,112143,'73723','watch','block_type','1',0,''),(351620,112143,'73723','watch','background-color','$content-bg-1',0,''),(351621,112143,'73723','watch','padding-top','30',0,''),(351622,112143,'73723','watch','padding-left','30',0,''),(351623,112143,'73723','watch','padding-right','30',0,''),(351624,112143,'73723','watch','padding-bottom','14',0,''),(351625,112143,'73723','watch','margin-bottom','20',0,''),(351626,112143,'73723','watch','style_class','hiding-box closeable-box',0,''),(351627,112143,'73723','watch','color','$content-color-1',0,''),(351628,112144,'73724','watch','style_class','closeable-content',0,''),(351629,112144,'73724','watch','padding-bottom','20',0,''),(351630,112145,'73725','watch','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(351631,112145,'73725','watch','style_class','closeable-heading closeable-event closed',0,''),(351632,112146,'73726','watch','block_type','1',0,''),(351633,112146,'73726','watch','padding-top','20',0,''),(351634,112146,'73726','watch','padding-left','20',0,''),(351635,112146,'73726','watch','padding-right','20',0,''),(351636,112146,'73726','watch','padding-bottom','20',0,''),(351637,112146,'73726','watch','background-color','$content-bg-1',0,''),(351638,112146,'73726','watch','style_class','order-summary hiding-box',0,''),(351639,112146,'73726','watch','color','$content-color-1',0,''),(351640,112147,'73727','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(351641,112148,'73728','watch','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(351642,112148,'73728','watch','text-align','center',0,''),(351643,112148,'73728','watch','font-size','14',0,''),(351644,112148,'73728','watch','color','$fade-color-1',0,''),(351645,112148,'73728','watch','padding-top','10',0,''),(351646,112149,'73729','watch','margin-bottom','10',0,''),(351647,112151,'73731','watch','hide_page','1',0,''),(351648,112151,'73731','watch','hide_continue_button','1',0,''),(351649,112152,'73732','watch','block_type','1',0,''),(351650,112154,'73734','watch','block_type','4',0,''),(351651,112154,'73734','watch','schema','4-2',0,'5261'),(351652,112155,'73735','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351653,112155,'73735','watch','text-align','right',0,''),(351654,112155,'73735','watch','padding-top','10',0,''),(351655,112155,'73735','watch','font_size_measure','em',0,''),(351656,112155,'73735','watch','font-size','1.2',0,''),(351657,112156,'73736','watch','text-align','right',0,''),(351658,112157,'73737','watch','block_type','2',0,''),(351659,112157,'73737','watch','schema','2-2',0,'5240'),(351660,112158,'73738','watch','block_type','1',0,''),(351661,112158,'73738','watch','padding-right','20',0,''),(351662,112158,'73738','watch','padding-right','0',0,'5240'),(351663,112160,'73740','watch','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(351664,112161,'73741','watch','block_type','1',0,''),(351665,112161,'73741','watch','padding-left','20',0,''),(351666,112161,'73741','watch','padding-left','0',0,'5240'),(351667,112163,'73743','watch','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(351668,112164,'73744','watch','block_type','2',0,''),(351669,112164,'73744','watch','schema','2-2',0,'5240'),(351670,112165,'73745','watch','block_type','1',0,''),(351671,112165,'73745','watch','padding-right','20',0,''),(351672,112165,'73745','watch','padding-right','0',0,'5240'),(351673,112166,'73746','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351674,112168,'73748','watch','block_type','1',0,''),(351675,112168,'73748','watch','padding-left','20',0,''),(351676,112168,'73748','watch','padding-left','0',0,'5240'),(351677,112173,'73753','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351678,112174,'73754','watch','margin-bottom','20',0,''),(351679,112175,'73755','watch','block_type','1',0,''),(351680,112175,'73755','watch','background-color','$content-bg-2',0,''),(351681,112175,'73755','watch','padding-top','30',0,''),(351682,112175,'73755','watch','padding-bottom','30',0,''),(351683,112176,'73756','watch','block_type','4',0,''),(351684,112176,'73756','watch','schema','4-2',0,'5240'),(351685,112177,'73757','watch','block_type','1',0,''),(351686,112177,'73757','watch','padding-right','40',0,''),(351687,112177,'73757','watch','padding-right','0',0,'5240'),(351688,112178,'73758','watch','background-color','$content-bg-1',0,''),(351689,112178,'73758','watch','padding-top','30',0,''),(351690,112178,'73758','watch','padding-left','30',0,''),(351691,112178,'73758','watch','padding-right','30',0,''),(351692,112178,'73758','watch','padding-bottom','30',0,''),(351693,112178,'73758','watch','margin-bottom','20',0,''),(351694,112179,'73759','watch','block_type','1',0,''),(351695,112179,'73759','watch','background-color','$content-bg-1',0,''),(351696,112179,'73759','watch','padding-top','30',0,''),(351697,112179,'73759','watch','padding-left','30',0,''),(351698,112179,'73759','watch','padding-right','30',0,''),(351699,112179,'73759','watch','padding-bottom','14',0,''),(351700,112179,'73759','watch','margin-bottom','20',0,''),(351701,112179,'73759','watch','style_class','hiding-box closeable-box',0,''),(351702,112180,'73760','watch','style_class','closeable-content',0,''),(351703,112180,'73760','watch','padding-bottom','20',0,''),(351704,112181,'73761','watch','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(351705,112181,'73761','watch','style_class','closeable-heading closeable-event closed',0,''),(351706,112182,'73762','watch','block_type','1',0,''),(351707,112182,'73762','watch','background-color','$content-bg-1',0,''),(351708,112182,'73762','watch','padding-top','30',0,''),(351709,112182,'73762','watch','padding-left','30',0,''),(351710,112182,'73762','watch','padding-right','30',0,''),(351711,112182,'73762','watch','padding-bottom','30',0,''),(351712,112182,'73762','watch','margin-bottom','20',0,''),(351713,112182,'73762','watch','style_class','hiding-box',0,''),(351714,112183,'73763','watch','padding-top','10',0,''),(351715,112183,'73763','watch','padding-left','20',0,''),(351716,112183,'73763','watch','padding-right','20',0,''),(351717,112183,'73763','watch','margin-top','20',0,''),(351718,112183,'73763','watch','background-color','$content-bg-2',0,''),(351719,112183,'73763','watch','padding-bottom','8',0,''),(351720,112184,'73764','watch','margin-bottom','20',0,''),(351721,112185,'73765','watch','block_type','1',0,''),(351722,112185,'73765','watch','padding-top','30',0,''),(351723,112185,'73765','watch','padding-left','30',0,''),(351724,112185,'73765','watch','padding-right','30',0,''),(351725,112185,'73765','watch','padding-bottom','23',0,''),(351726,112185,'73765','watch','margin-bottom','20',0,''),(351727,112185,'73765','watch','background-color','$content-bg-1',0,''),(351728,112185,'73765','watch','style_class','hiding-box',0,''),(351729,112186,'73766','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(351730,112187,'73767','watch','block_type','2',0,''),(351731,112187,'73767','watch','schema','2-2',0,'5240'),(351732,112188,'73768','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351733,112189,'73769','watch','padding-right','20',0,''),(351734,112189,'73769','watch','padding-right','0',0,'5240'),(351735,112189,'73769','watch','padding-bottom','20',0,'5240'),(351736,112190,'73770','watch','block_type','1',0,''),(351737,112190,'73770','watch','padding-left','20',0,''),(351738,112190,'73770','watch','padding-left','0',0,'5240'),(351739,112192,'73772','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351740,112193,'73773','watch','block_type','1',0,''),(351741,112193,'73773','watch','padding-top','20',0,''),(351742,112193,'73773','watch','padding-left','20',0,''),(351743,112193,'73773','watch','padding-right','20',0,''),(351744,112193,'73773','watch','padding-bottom','20',0,''),(351745,112193,'73773','watch','background-color','$content-bg-1',0,''),(351746,112193,'73773','watch','style_class','order-summary',0,''),(351747,112195,'73775','watch','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(351748,112195,'73775','watch','text-align','center',0,''),(351749,112195,'73775','watch','font-size','14',0,''),(351750,112195,'73775','watch','color','$fade-color-1',0,''),(351751,112195,'73775','watch','padding-top','10',0,''),(351752,112196,'73776','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(351753,112197,'73777','watch','margin-bottom','10',0,''),(351754,112198,'73778','watch','block_type','2',0,''),(351755,112199,'73779','watch','block_type','1',0,''),(351756,112199,'73779','watch','padding-left','0',0,'5240'),(351757,112199,'73779','watch','padding-right','20',0,''),(351758,112201,'73781','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351759,112202,'73782','watch','block_type','1',0,''),(351760,112202,'73782','watch','padding-left','20',0,''),(351761,112202,'73782','watch','padding-left','0',0,'5240'),(351762,112207,'73787','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351763,112208,'73788','watch','block_type','4',0,''),(351764,112208,'73788','watch','schema','4-2',0,'5261'),(351765,112208,'73788','watch','padding-top','20',0,''),(351766,112209,'73789','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351767,112209,'73789','watch','text-align','right',0,''),(351768,112209,'73789','watch','padding-top','10',0,''),(351769,112209,'73789','watch','font_size_measure','em',0,''),(351770,112209,'73789','watch','font-size','1.2',0,''),(351771,112210,'73790','watch','text-align','right',0,''),(351772,112211,'73791','watch','block_type','2',0,''),(351773,112212,'73792','watch','block_type','1',0,''),(351774,112212,'73792','watch','padding-left','0',0,'5240'),(351775,112212,'73792','watch','padding-right','20',0,''),(351776,112214,'73794','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351777,112215,'73795','watch','block_type','1',0,''),(351778,112215,'73795','watch','padding-left','20',0,''),(351779,112215,'73795','watch','padding-left','0',0,'5240'),(351780,112217,'73797','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351781,112221,'73801','watch','block_type','4',0,''),(351782,112221,'73801','watch','schema','4-2',0,'5261'),(351783,112222,'73802','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351784,112222,'73802','watch','text-align','right',0,''),(351785,112222,'73802','watch','padding-top','10',0,''),(351786,112222,'73802','watch','font_size_measure','em',0,''),(351787,112222,'73802','watch','font-size','1.2',0,''),(351788,112223,'73803','watch','text-align','right',0,''),(351789,112224,'73804','watch','block_type','4',0,''),(351790,112224,'73804','watch','schema','4-2',0,'5261'),(351791,112225,'73805','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351792,112225,'73805','watch','text-align','right',0,''),(351793,112225,'73805','watch','padding-top','10',0,''),(351794,112225,'73805','watch','font_size_measure','em',0,''),(351795,112225,'73805','watch','font-size','1.2',0,''),(351796,112226,'73806','watch','text-align','right',0,''),(351797,112227,'73807','watch','block_type','2',0,''),(351798,112228,'73808','watch','block_type','1',0,''),(351799,112228,'73808','watch','padding-left','0',0,'5240'),(351800,112228,'73808','watch','padding-right','20',0,''),(351801,112229,'73809','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351802,112231,'73811','watch','block_type','1',0,''),(351803,112231,'73811','watch','padding-left','20',0,''),(351804,112231,'73811','watch','padding-left','0',0,'5240'),(351805,112236,'73816','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351806,112237,'73817','watch','block_type','4',0,''),(351807,112237,'73817','watch','schema','4-2',0,'5261'),(351808,112238,'73818','watch','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(351809,112238,'73818','watch','text-align','right',0,''),(351810,112238,'73818','watch','padding-top','10',0,''),(351811,112238,'73818','watch','font_size_measure','em',0,''),(351812,112238,'73818','watch','font-size','1.2',0,''),(351813,112239,'73819','watch','text-align','right',0,''),(351814,112240,'73820','watch','block_type','2',0,''),(351815,112241,'73821','watch','block_type','1',0,''),(351816,112241,'73821','watch','padding-left','0',0,'5240'),(351817,112241,'73821','watch','padding-right','20',0,''),(351818,112243,'73823','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351819,112244,'73824','watch','block_type','1',0,''),(351820,112244,'73824','watch','padding-left','20',0,''),(351821,112244,'73824','watch','padding-left','0',0,'5240'),(351822,112248,'73828','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351823,112250,'73830','watch','text','##PAYMENT_DETAILS##',0,''),(351824,112251,'73831','watch','text','##PAYMENT_DETAILS##',0,''),(351825,112252,'73832','watch','text','##PAYMENT_DETAILS##',0,''),(351826,112253,'73833','watch','text','##PAYMENT_DETAILS##',0,''),(351827,112254,'73834','watch','text','##PAYMENT_DETAILS##',0,''),(351828,112255,'73835','watch','text','##PAYMENT_DETAILS##',0,''),(351829,112256,'73836','watch','block_type','1',0,''),(351830,112256,'73836','watch','background-color','$content-bg-2',0,''),(351831,112256,'73836','watch','padding-top','30',0,''),(351832,112256,'73836','watch','padding-bottom','30',0,''),(351833,112257,'73837','watch','block_type','4',0,''),(351834,112257,'73837','watch','schema','4-2',0,'5240'),(351835,112258,'73838','watch','block_type','1',0,''),(351836,112258,'73838','watch','padding-right','40',0,''),(351837,112258,'73838','watch','padding-right','0',0,'5240'),(351838,112259,'73839','watch','block_type','1',0,''),(351839,112259,'73839','watch','background-color','$content-bg-1',0,''),(351840,112259,'73839','watch','padding-top','30',0,''),(351841,112259,'73839','watch','padding-left','30',0,''),(351842,112259,'73839','watch','padding-right','30',0,''),(351843,112259,'73839','watch','padding-bottom','30',0,''),(351844,112259,'73839','watch','margin-bottom','20',0,''),(351845,112259,'73839','watch','style_class','hiding-box',0,''),(351846,112260,'73840','watch','padding-top','10',0,''),(351847,112260,'73840','watch','padding-left','20',0,''),(351848,112260,'73840','watch','padding-right','20',0,''),(351849,112260,'73840','watch','margin-top','20',0,''),(351850,112260,'73840','watch','background-color','$content-bg-2',0,''),(351851,112260,'73840','watch','padding-bottom','8',0,''),(351852,112261,'73841','watch','margin-bottom','20',0,''),(351853,112262,'73842','watch','background-color','$content-bg-1',0,''),(351854,112262,'73842','watch','block_type','1',0,''),(351855,112262,'73842','watch','padding-top','30',0,''),(351856,112262,'73842','watch','padding-left','30',0,''),(351857,112262,'73842','watch','padding-right','30',0,''),(351858,112262,'73842','watch','padding-bottom','30',0,''),(351859,112262,'73842','watch','margin-bottom','20',0,''),(351860,112262,'73842','watch','style_class','hiding-box',0,''),(351861,112263,'73843','watch','block_type','1',0,''),(351862,112263,'73843','watch','content','\\_',0,'3'),(351863,112263,'73843','watch','border-top-width','1',0,'3'),(351864,112263,'73843','watch','border-top-color','$content-border-1',0,'3'),(351865,112263,'73843','watch','display','block',0,'3'),(351866,112263,'73843','watch','position','absolute',0,'3'),(351867,112263,'73843','watch','top','19',0,'3'),(351868,112263,'73843','watch','left','0',0,'3'),(351869,112263,'73843','watch','right','0',0,'3'),(351870,112263,'73843','watch','margin-top','-2',0,'3'),(351871,112263,'73843','watch','position','relative',0,''),(351872,112264,'73844','watch','box_align','2',0,''),(351873,112264,'73844','watch','margin-bottom','10',0,''),(351874,112264,'73844','watch','background-color','$content-bg-1',0,''),(351875,112264,'73844','watch','position','relative',0,''),(351876,112265,'73845','watch','background-color','$content-bg-2',0,''),(351877,112265,'73845','watch','padding-top','10',0,''),(351878,112265,'73845','watch','padding-left','10',0,''),(351879,112265,'73845','watch','padding-right','10',0,''),(351880,112265,'73845','watch','padding-bottom','10',0,''),(351881,112265,'73845','watch','margin-top','10',0,''),(351882,112266,'73846','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(351883,112267,'73847','watch','block_type','2',0,''),(351884,112267,'73847','watch','schema','2-2',0,'5240'),(351885,112268,'73848','watch','block_type','1',0,''),(351886,112268,'73848','watch','padding-right','20',0,''),(351887,112268,'73848','watch','padding-left','0',0,'5240'),(351888,112268,'73848','watch','margin-bottom','20',0,'5240'),(351889,112271,'73851','watch','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(351890,112272,'73852','watch','block_type','1',0,''),(351891,112272,'73852','watch','padding-left','20',0,''),(351892,112272,'73852','watch','padding-left','0',0,'5240'),(351893,112274,'73854','watch','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(351894,112275,'73855','watch','border-top-width','1',0,''),(351895,112275,'73855','watch','border-top-color','$content-border-1',0,''),(351896,112275,'73855','watch','padding-top','13',0,''),(351897,112275,'73855','watch','padding-bottom','10',0,''),(351898,112276,'73856','watch','block_type','1',0,''),(351899,112276,'73856','watch','background-color','$content-bg-1',0,''),(351900,112276,'73856','watch','padding-top','30',0,''),(351901,112276,'73856','watch','padding-left','30',0,''),(351902,112276,'73856','watch','padding-right','30',0,''),(351903,112276,'73856','watch','padding-bottom','14',0,''),(351904,112276,'73856','watch','margin-bottom','20',0,''),(351905,112276,'73856','watch','style_class','hiding-box closeable-box',0,''),(351906,112277,'73857','watch','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(351907,112277,'73857','watch','style_class','closeable-heading closeable-event closed',0,''),(351908,112278,'73858','watch','style_class','closeable-content',0,''),(351909,112278,'73858','watch','padding-bottom','20',0,''),(351910,112279,'73860','watch','block_type','1',0,''),(351911,112279,'73860','watch','padding-top','30',0,''),(351912,112279,'73860','watch','padding-left','30',0,''),(351913,112279,'73860','watch','padding-right','30',0,''),(351914,112279,'73860','watch','padding-bottom','23',0,''),(351915,112279,'73860','watch','margin-bottom','20',0,''),(351916,112279,'73860','watch','background-color','$content-bg-1',0,''),(351917,112279,'73860','watch','style_class','hiding-box',0,''),(351918,112280,'73861','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(351919,112281,'73862','watch','block_type','2',0,''),(351920,112281,'73862','watch','schema','2-2',0,'5240'),(351921,112282,'73863','watch','padding-right','20',0,''),(351922,112282,'73863','watch','padding-right','0',0,'5240'),(351923,112282,'73863','watch','padding-bottom','20',0,'5240'),(351924,112283,'73864','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(351925,112284,'73865','watch','block_type','1',0,''),(351926,112284,'73865','watch','padding-left','20',0,''),(351927,112284,'73865','watch','padding-left','0',0,'5240'),(351928,112286,'73867','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(351929,112287,'73868','watch','block_type','1',0,''),(351930,112287,'73868','watch','padding-top','20',0,''),(351931,112287,'73868','watch','padding-left','20',0,''),(351932,112287,'73868','watch','padding-right','20',0,''),(351933,112287,'73868','watch','padding-bottom','20',0,''),(351934,112287,'73868','watch','background-color','$content-bg-1',0,''),(351935,112287,'73868','watch','style_class','order-summary',0,''),(351936,112288,'73869','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(351937,112289,'73870','watch','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(351938,112289,'73870','watch','text-align','center',0,''),(351939,112289,'73870','watch','font-size','14',0,''),(351940,112289,'73870','watch','color','$fade-color-1',0,''),(351941,112289,'73870','watch','padding-top','10',0,''),(351942,112290,'73871','watch','margin-bottom','10',0,''),(351943,112292,'115996','watch','hide_continue_button','1',0,''),(351944,112293,'73873','watch','block_type','1',0,''),(351945,112293,'73873','watch','background-color','$content-bg-2',0,''),(351946,112293,'73873','watch','padding-top','30',0,''),(351947,112293,'73873','watch','padding-bottom','30',0,''),(351948,112294,'73874','watch','block_type','4',0,''),(351949,112294,'73874','watch','schema','4-2',0,'5240'),(351950,112295,'73875','watch','block_type','1',0,''),(351951,112295,'73875','watch','padding-right','40',0,''),(351952,112295,'73875','watch','padding-right','0',0,'5240'),(351953,112296,'73876','watch','background-color','$content-bg-1',0,''),(351954,112296,'73876','watch','padding-top','30',0,''),(351955,112296,'73876','watch','padding-left','30',0,''),(351956,112296,'73876','watch','padding-right','30',0,''),(351957,112296,'73876','watch','padding-bottom','30',0,''),(351958,112296,'73876','watch','margin-bottom','20',0,''),(351959,112297,'73877','watch','block_type','1',0,''),(351960,112297,'73877','watch','background-color','$content-bg-1',0,''),(351961,112297,'73877','watch','padding-top','30',0,''),(351962,112297,'73877','watch','padding-left','30',0,''),(351963,112297,'73877','watch','padding-right','30',0,''),(351964,112297,'73877','watch','padding-bottom','30',0,''),(351965,112297,'73877','watch','margin-bottom','20',0,''),(351966,112297,'73877','watch','style_class','hiding-box',0,''),(351967,112298,'73878','watch','margin-bottom','20',0,''),(351968,112299,'73879','watch','padding-top','10',0,''),(351969,112299,'73879','watch','padding-left','20',0,''),(351970,112299,'73879','watch','padding-right','20',0,''),(351971,112299,'73879','watch','margin-top','20',0,''),(351972,112299,'73879','watch','background-color','$content-bg-2',0,''),(351973,112299,'73879','watch','padding-bottom','8',0,''),(351974,112300,'73880','watch','background-color','$content-bg-1',0,''),(351975,112300,'73880','watch','block_type','1',0,''),(351976,112300,'73880','watch','padding-top','30',0,''),(351977,112300,'73880','watch','padding-left','30',0,''),(351978,112300,'73880','watch','padding-right','30',0,''),(351979,112300,'73880','watch','padding-bottom','30',0,''),(351980,112300,'73880','watch','margin-bottom','20',0,''),(351981,112300,'73880','watch','style_class','hiding-box',0,''),(351982,112301,'73881','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(351983,112302,'73882','watch','background-color','$content-bg-2',0,''),(351984,112302,'73882','watch','padding-top','10',0,''),(351985,112302,'73882','watch','padding-left','10',0,''),(351986,112302,'73882','watch','padding-right','10',0,''),(351987,112302,'73882','watch','padding-bottom','10',0,''),(351988,112302,'73882','watch','margin-top','10',0,''),(351989,112303,'73883','watch','block_type','1',0,''),(351990,112303,'73883','watch','content','\\_',0,'3'),(351991,112303,'73883','watch','border-top-width','1',0,'3'),(351992,112303,'73883','watch','border-top-color','$content-border-1',0,'3'),(351993,112303,'73883','watch','display','block',0,'3'),(351994,112303,'73883','watch','position','absolute',0,'3'),(351995,112303,'73883','watch','top','19',0,'3'),(351996,112303,'73883','watch','left','0',0,'3'),(351997,112303,'73883','watch','right','0',0,'3'),(351998,112303,'73883','watch','margin-top','-2',0,'3'),(351999,112303,'73883','watch','position','relative',0,''),(352000,112304,'73884','watch','box_align','2',0,''),(352001,112304,'73884','watch','margin-bottom','10',0,''),(352002,112304,'73884','watch','background-color','$content-bg-1',0,''),(352003,112304,'73884','watch','position','relative',0,''),(352004,112305,'73885','watch','block_type','2',0,''),(352005,112305,'73885','watch','schema','2-2',0,'5240'),(352006,112306,'73886','watch','block_type','1',0,''),(352007,112306,'73886','watch','padding-right','20',0,''),(352008,112306,'73886','watch','padding-left','0',0,'5240'),(352009,112306,'73886','watch','margin-bottom','20',0,'5240'),(352010,112309,'73889','watch','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(352011,112310,'73890','watch','block_type','1',0,''),(352012,112310,'73890','watch','padding-left','20',0,''),(352013,112310,'73890','watch','padding-left','0',0,'5240'),(352014,112312,'73892','watch','border-top-width','1',0,''),(352015,112312,'73892','watch','border-top-color','$content-border-1',0,''),(352016,112312,'73892','watch','padding-top','13',0,''),(352017,112312,'73892','watch','padding-bottom','10',0,''),(352018,112313,'73893','watch','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(352019,112314,'73894','watch','block_type','1',0,''),(352020,112314,'73894','watch','padding-top','30',0,''),(352021,112314,'73894','watch','padding-left','30',0,''),(352022,112314,'73894','watch','padding-right','30',0,''),(352023,112314,'73894','watch','padding-bottom','23',0,''),(352024,112314,'73894','watch','margin-bottom','20',0,''),(352025,112314,'73894','watch','background-color','$content-bg-1',0,''),(352026,112314,'73894','watch','style_class','hiding-box',0,''),(352027,112315,'73895','watch','block_type','2',0,''),(352028,112315,'73895','watch','schema','2-2',0,'5240'),(352029,112316,'73896','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(352030,112317,'73897','watch','padding-right','20',0,''),(352031,112317,'73897','watch','padding-right','0',0,'5240'),(352032,112317,'73897','watch','padding-bottom','20',0,'5240'),(352033,112318,'73898','watch','block_type','1',0,''),(352034,112318,'73898','watch','padding-left','20',0,''),(352035,112318,'73898','watch','padding-left','0',0,'5240'),(352036,112319,'73899','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(352037,112321,'73901','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(352038,112322,'73902','watch','block_type','1',0,''),(352039,112322,'73902','watch','background-color','$content-bg-1',0,''),(352040,112322,'73902','watch','padding-top','30',0,''),(352041,112322,'73902','watch','padding-left','30',0,''),(352042,112322,'73902','watch','padding-right','30',0,''),(352043,112322,'73902','watch','padding-bottom','14',0,''),(352044,112322,'73902','watch','margin-bottom','20',0,''),(352045,112322,'73902','watch','style_class','hiding-box closeable-box',0,''),(352046,112323,'73903','watch','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(352047,112323,'73903','watch','style_class','closeable-heading closeable-event closed',0,''),(352048,112324,'73904','watch','style_class','closeable-content',0,''),(352049,112324,'73904','watch','padding-bottom','20',0,''),(352050,112325,'73905','watch','block_type','1',0,''),(352051,112325,'73905','watch','padding-top','30',0,''),(352052,112325,'73905','watch','padding-left','30',0,''),(352053,112325,'73905','watch','padding-right','30',0,''),(352054,112325,'73905','watch','padding-bottom','14',0,''),(352055,112325,'73905','watch','margin-bottom','20',0,''),(352056,112325,'73905','watch','background-color','$content-bg-1',0,''),(352057,112325,'73905','watch','style_class','hiding-box closeable-box',0,''),(352058,112326,'73906','watch','block_type','2',0,''),(352059,112326,'73906','watch','style_class','closeable-content',0,''),(352060,112326,'73906','watch','schema','2-2',0,'5240'),(352061,112327,'73907','watch','padding-right','20',0,''),(352062,112327,'73907','watch','padding-bottom','20',0,''),(352063,112327,'73907','watch','padding-right','0',0,'5240'),(352064,112328,'73908','watch','padding-left','20',0,''),(352065,112328,'73908','watch','padding-bottom','20',0,''),(352066,112328,'73908','watch','padding-left','0',0,'5240'),(352067,112329,'73909','watch','padding-left','20',0,''),(352068,112329,'73909','watch','padding-bottom','20',0,''),(352069,112329,'73909','watch','padding-left','0',0,'5240'),(352070,112330,'73910','watch','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(352071,112330,'73910','watch','style_class','closeable-heading closeable-event closed',0,''),(352072,112331,'73911','watch','block_type','1',0,''),(352073,112331,'73911','watch','padding-top','20',0,''),(352074,112331,'73911','watch','padding-left','20',0,''),(352075,112331,'73911','watch','padding-right','20',0,''),(352076,112331,'73911','watch','padding-bottom','20',0,''),(352077,112331,'73911','watch','background-color','$content-bg-1',0,''),(352078,112331,'73911','watch','style_class','order-summary',0,''),(352079,112332,'73912','watch','margin-bottom','10',0,''),(352080,112333,'73913','watch','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(352081,112333,'73913','watch','text-align','center',0,''),(352082,112333,'73913','watch','font-size','14',0,''),(352083,112333,'73913','watch','color','$fade-color-1',0,''),(352084,112333,'73913','watch','padding-top','10',0,''),(352085,112334,'73914','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(352086,112336,'115998','watch','hide_continue_button','1',0,''),(352087,112337,'73916','watch','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(352088,112342,'73921','watch','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(352089,112343,'73923','watch','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(352090,112344,'73924','watch','style_class','order-summary',0,''),(352091,112344,'73924','watch','box_align','3',0,''),(352092,112344,'73924','watch','width','400',0,''),(352093,112346,'73922','watch','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(352094,112349,'73928','watch','block_type','1',0,''),(352095,112350,'73929','watch','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(352096,112351,'73930','watch','float','right',0,''),(352097,112351,'73930','watch','position','relative',0,''),(352098,112351,'73930','watch','z-index','1',0,''),(352099,112351,'73930','watch','top','30',0,''),(352100,112351,'73930','watch','margin-bottom','-20',0,''),(352101,112352,'73931','watch','margin-bottom','30',0,''),(352102,112353,'94704','watch','block_type','1',0,''),(352103,112354,'94705','watch','listing_type','Compare Products',0,''),(352104,112355,'94706','watch','block_type','1',0,''),(352105,112355,'94706','watch','style_class','item-holder',0,''),(352106,112355,'94706','watch','padding-top','10',0,''),(352107,112355,'94706','watch','padding-left','20',0,''),(352108,112355,'94706','watch','padding-right','20',0,''),(352109,112355,'94706','watch','padding-bottom','10',0,''),(352110,112355,'94706','watch','text-align','left',0,''),(352111,112358,'94709','watch','margin-bottom','10',0,''),(352112,112359,'94710','watch','block_type','5',0,''),(352113,112361,'94712','watch','clear','both',0,''),(352114,112362,'94713','watch','block_type','2',0,''),(352115,112363,'94714','watch','margin-bottom','7',0,''),(352116,112364,'94715','watch','text-align','right',0,''),(352117,112364,'94715','watch','margin-bottom','10',0,''),(352118,112364,'94715','watch','float','right',0,''),(352119,112365,'73932','watch','block_type','1',0,''),(352120,112365,'73932','watch','background-color','$content-bg-2',0,''),(352121,112365,'73932','watch','padding-bottom','30',0,''),(352122,112365,'73932','watch','color','$content-color-2',0,''),(352123,112366,'73933','watch','block_type','4',0,''),(352124,112366,'73933','watch','schema','4-2',0,'5240'),(352125,112367,'73934','watch','block_type','1',0,''),(352126,112367,'73934','watch','padding-right','40',0,''),(352127,112367,'73934','watch','padding-right','0',0,'5240'),(352128,112368,'73935','watch','block_type','1',0,''),(352129,112368,'73935','watch','padding-right','30',0,''),(352130,112368,'73935','watch','background-color','$content-bg-1',0,''),(352131,112368,'73935','watch','padding-top','20',0,''),(352132,112368,'73935','watch','padding-left','30',0,''),(352133,112368,'73935','watch','padding-bottom','20',0,''),(352134,112368,'73935','watch','padding-left','20',0,'5240'),(352135,112368,'73935','watch','padding-right','20',0,'5240'),(352136,112368,'73935','watch','color','$content-color-1',0,''),(352137,112369,'73936','watch','link','products',0,''),(352138,112369,'73936','watch','float','right',0,''),(352139,112369,'73936','watch','margin-top','-37',0,''),(352140,112371,'73938','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(352141,112372,'73939','watch','block_type','1',0,''),(352142,112372,'73939','watch','background-color','$content-bg-1',0,''),(352143,112372,'73939','watch','padding-top','20',0,''),(352144,112372,'73939','watch','padding-bottom','20',0,''),(352145,112372,'73939','watch','padding-left','30',0,''),(352146,112372,'73939','watch','padding-right','30',0,''),(352147,112372,'73939','watch','margin-bottom','20',0,''),(352148,112372,'73939','watch','color','$content-color-1',0,''),(352149,112373,'73940','watch','float','right',0,''),(352150,112373,'73940','watch','margin-top','-37',0,''),(352151,112373,'73940','watch','link','comments',0,''),(352152,112374,'73941','watch','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(352153,112375,'73942','watch','hide_parents','2',0,''),(352154,112376,'73943','watch','block_type','2',0,''),(352155,112376,'73943','watch','margin-bottom','20',0,''),(352156,112376,'73943','watch','schema','2-2',0,'5232'),(352157,112376,'73943','watch','background-color','$content-bg-1',0,''),(352158,112376,'73943','watch','color','$content-color-1',0,''),(352159,112377,'73944','watch','block_type','1',0,''),(352160,112377,'73944','watch','border-right-width','20',0,''),(352161,112377,'73944','watch','border-right-color','$content-bg-2',0,''),(352162,112377,'73944','watch','margin-right','-10',0,''),(352163,112377,'73944','watch','padding-right','30',0,''),(352164,112377,'73944','watch','padding-top','20',0,''),(352165,112377,'73944','watch','padding-left','30',0,''),(352166,112377,'73944','watch','padding-bottom','20',0,''),(352167,112377,'73944','watch','border-right-width','0',0,'5240'),(352168,112377,'73944','watch','margin-right','0',0,'5240'),(352169,112377,'73944','watch','margin-bottom','20',0,'5240'),(352170,112377,'73944','watch','padding-left','20',0,'5240'),(352171,112377,'73944','watch','padding-right','20',0,'5240'),(352172,112378,'73945','watch','link','shipping_method',0,''),(352173,112378,'73945','watch','float','right',0,''),(352174,112378,'73945','watch','margin-top','-31',0,''),(352175,112380,'73947','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(352176,112380,'73947','watch','padding-top','20',0,''),(352177,112381,'73948','watch','link','contact_information',0,''),(352178,112381,'73948','watch','margin-top','-31',0,''),(352179,112381,'73948','watch','float','right',0,''),(352180,112382,'73949','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(352181,112382,'73949','watch','clear','none',0,''),(352182,112384,'73951','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(352183,112385,'73952','watch','link','shipping_address',0,''),(352184,112385,'73952','watch','float','right',0,''),(352185,112385,'73952','watch','margin-top','-31',0,''),(352186,112387,'73954','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(352187,112387,'73954','watch','clear','none',0,''),(352188,112388,'73955','watch','margin-bottom','20',0,''),(352189,112389,'73956','watch','block_type','1',0,''),(352190,112389,'73956','watch','padding-left','30',0,''),(352191,112389,'73956','watch','border-left-width','20',0,''),(352192,112389,'73956','watch','border-left-color','$content-bg-2',0,''),(352193,112389,'73956','watch','margin-left','-10',0,''),(352194,112389,'73956','watch','padding-right','30',0,''),(352195,112389,'73956','watch','padding-top','20',0,''),(352196,112389,'73956','watch','padding-bottom','20',0,''),(352197,112389,'73956','watch','border-left-width','0',0,'5240'),(352198,112390,'73957','watch','link','payment_method',0,''),(352199,112390,'73957','watch','float','right',0,''),(352200,112390,'73957','watch','margin-top','-31',0,''),(352201,112391,'73958','watch','link','billing_address',0,''),(352202,112391,'73958','watch','float','right',0,''),(352203,112391,'73958','watch','margin-top','-31',0,''),(352204,112393,'73960','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(352205,112393,'73960','watch','clear','none',0,''),(352206,112394,'73961','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(352207,112395,'73962','watch','margin-bottom','20',0,''),(352208,112396,'73963','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(352209,112396,'73963','watch','clear','none',0,''),(352210,112398,'73965','watch','block_type','1',0,''),(352211,112398,'73965','watch','padding-top','20',0,''),(352212,112398,'73965','watch','padding-left','20',0,''),(352213,112398,'73965','watch','padding-right','20',0,''),(352214,112398,'73965','watch','padding-bottom','20',0,''),(352215,112398,'73965','watch','background-color','$content-bg-1',0,''),(352216,112398,'73965','watch','style_class','order-summary2 hiding-box',0,''),(352217,112398,'73965','watch','color','$content-color-1',0,''),(352218,112399,'73966','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(352219,112400,'73967','watch','margin-bottom','20',0,''),(352220,112400,'73967','watch','text-align','right',0,''),(352221,112402,'73969','watch','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(352222,112403,'73970','watch','block_type','1',0,''),(352223,112403,'73970','watch','background-color','$content-bg-2',0,''),(352224,112403,'73970','watch','padding-bottom','30',0,''),(352225,112404,'73971','watch','block_type','4',0,''),(352226,112404,'73971','watch','schema','4-2',0,'5240'),(352227,112405,'73972','watch','block_type','1',0,''),(352228,112405,'73972','watch','padding-right','40',0,''),(352229,112405,'73972','watch','padding-right','0',0,'5240'),(352230,112406,'73973','watch','block_type','1',0,''),(352231,112406,'73973','watch','background-color','$content-bg-1',0,''),(352232,112406,'73973','watch','padding-top','20',0,''),(352233,112406,'73973','watch','padding-bottom','20',0,''),(352234,112406,'73973','watch','padding-left','30',0,''),(352235,112406,'73973','watch','padding-right','30',0,''),(352236,112406,'73973','watch','margin-bottom','20',0,''),(352237,112407,'73974','watch','hide_parents','2',0,''),(352238,112408,'73975','watch','float','right',0,''),(352239,112408,'73975','watch','margin-top','-37',0,''),(352240,112408,'73975','watch','link','comments',0,''),(352241,112409,'73976','watch','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(352242,112410,'73977','watch','block_type','1',0,''),(352243,112410,'73977','watch','padding-right','30',0,''),(352244,112410,'73977','watch','background-color','$content-bg-1',0,''),(352245,112410,'73977','watch','padding-top','20',0,''),(352246,112410,'73977','watch','padding-left','30',0,''),(352247,112410,'73977','watch','padding-bottom','20',0,''),(352248,112410,'73977','watch','padding-left','20',0,'5240'),(352249,112410,'73977','watch','padding-right','20',0,'5240'),(352250,112411,'73978','watch','link','products',0,''),(352251,112411,'73978','watch','float','right',0,''),(352252,112411,'73978','watch','margin-top','-37',0,''),(352253,112412,'73979','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(352254,112414,'73981','watch','block_type','2',0,''),(352255,112414,'73981','watch','margin-bottom','20',0,''),(352256,112414,'73981','watch','schema','2-2',0,'5232'),(352257,112414,'73981','watch','background-color','$content-bg-1',0,''),(352258,112415,'73982','watch','block_type','1',0,''),(352259,112415,'73982','watch','border-right-width','20',0,''),(352260,112415,'73982','watch','border-right-color','$content-border-1',0,''),(352261,112415,'73982','watch','margin-right','-10',0,''),(352262,112415,'73982','watch','padding-right','30',0,''),(352263,112415,'73982','watch','padding-top','20',0,''),(352264,112415,'73982','watch','padding-left','30',0,''),(352265,112415,'73982','watch','padding-bottom','20',0,''),(352266,112415,'73982','watch','border-right-width','0',0,'5240'),(352267,112415,'73982','watch','margin-right','0',0,'5240'),(352268,112415,'73982','watch','margin-bottom','20',0,'5240'),(352269,112415,'73982','watch','padding-left','20',0,'5240'),(352270,112415,'73982','watch','padding-right','20',0,'5240'),(352271,112416,'73983','watch','link','shipping_address',0,''),(352272,112416,'73983','watch','float','right',0,''),(352273,112416,'73983','watch','margin-top','-31',0,''),(352274,112418,'73985','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(352275,112418,'73985','watch','clear','none',0,''),(352276,112419,'73986','watch','link','shipping_method',0,''),(352277,112419,'73986','watch','float','right',0,''),(352278,112419,'73986','watch','margin-top','-31',0,''),(352279,112420,'73987','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(352280,112420,'73987','watch','clear','none',0,''),(352281,112421,'73988','watch','margin-bottom','20',0,''),(352282,112422,'73989','watch','block_type','1',0,''),(352283,112422,'73989','watch','padding-left','30',0,''),(352284,112422,'73989','watch','border-left-width','20',0,''),(352285,112422,'73989','watch','border-left-color','$content-border-1',0,''),(352286,112422,'73989','watch','margin-left','-10',0,''),(352287,112422,'73989','watch','padding-right','30',0,''),(352288,112422,'73989','watch','padding-top','20',0,''),(352289,112422,'73989','watch','padding-bottom','20',0,''),(352290,112422,'73989','watch','border-left-width','0',0,'5240'),(352291,112425,'73992','watch','link','contact_information',0,''),(352292,112425,'73992','watch','margin-top','-31',0,''),(352293,112425,'73992','watch','float','right',0,''),(352294,112426,'73993','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(352295,112427,'73994','watch','block_type','1',0,''),(352296,112427,'73994','watch','padding-top','20',0,''),(352297,112427,'73994','watch','padding-left','20',0,''),(352298,112427,'73994','watch','padding-right','20',0,''),(352299,112427,'73994','watch','padding-bottom','20',0,''),(352300,112427,'73994','watch','background-color','$content-bg-1',0,''),(352301,112427,'73994','watch','style_class','order-summary',0,''),(352302,112428,'73995','watch','margin-bottom','20',0,''),(352303,112428,'73995','watch','text-align','right',0,''),(352304,112429,'73996','watch','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(352305,112430,'73997','watch','block_type','1',0,''),(352306,112430,'73997','watch','background-color','$content-bg-2',0,''),(352307,112430,'73997','watch','padding-bottom','30',0,''),(352308,112430,'73997','watch','color','$content-color-2',0,''),(352309,112431,'73998','watch','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(352310,112432,'73999','watch','block_type','4',0,''),(352311,112433,'74000','watch','block_type','1',0,''),(352312,112433,'74000','watch','padding-right','40',0,''),(352313,112434,'74001','watch','block_type','2',0,''),(352314,112434,'74001','watch','margin-bottom','20',0,''),(352315,112434,'74001','watch','schema','2-2',0,'5232'),(352316,112434,'74001','watch','background-color','$content-bg-1',0,''),(352317,112434,'74001','watch','color','$content-color-1',0,''),(352318,112435,'74002','watch','block_type','1',0,''),(352319,112435,'74002','watch','padding-right','0',0,'5232'),(352320,112435,'74002','watch','border-right-width','20',0,''),(352321,112435,'74002','watch','border-right-color','$content-bg-2',0,''),(352322,112435,'74002','watch','margin-right','-10',0,''),(352323,112435,'74002','watch','padding-right','30',0,''),(352324,112435,'74002','watch','padding-top','20',0,''),(352325,112435,'74002','watch','padding-left','30',0,''),(352326,112435,'74002','watch','padding-bottom','20',0,''),(352327,112436,'74003','watch','link','contact_information',0,''),(352328,112436,'74003','watch','margin-top','-37',0,''),(352329,112436,'74003','watch','float','right',0,''),(352330,112437,'74004','watch','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(352331,112437,'74004','watch','padding-top','20',0,''),(352332,112439,'74006','watch','block_type','1',0,''),(352333,112439,'74006','watch','padding-left','30',0,''),(352334,112439,'74006','watch','padding-left','0',0,'5232'),(352335,112439,'74006','watch','border-left-width','20',0,''),(352336,112439,'74006','watch','border-left-color','$content-bg-2',0,''),(352337,112439,'74006','watch','margin-left','-10',0,''),(352338,112439,'74006','watch','padding-right','30',0,''),(352339,112439,'74006','watch','padding-top','20',0,''),(352340,112439,'74006','watch','padding-bottom','20',0,''),(352341,112441,'74008','watch','link','payment_method',0,''),(352342,112441,'74008','watch','float','right',0,''),(352343,112441,'74008','watch','margin-top','-31',0,''),(352344,112442,'74009','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(352345,112442,'74009','watch','clear','none',0,''),(352346,112443,'74010','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(352347,112444,'74011','watch','link','billing_address',0,''),(352348,112444,'74011','watch','float','right',0,''),(352349,112444,'74011','watch','margin-top','-31',0,''),(352350,112445,'74012','watch','margin-bottom','20',0,''),(352351,112446,'74013','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(352352,112446,'74013','watch','clear','none',0,''),(352353,112447,'74014','watch','block_type','1',0,''),(352354,112447,'74014','watch','background-color','$content-bg-1',0,''),(352355,112447,'74014','watch','padding-top','20',0,''),(352356,112447,'74014','watch','padding-bottom','20',0,''),(352357,112447,'74014','watch','padding-left','30',0,''),(352358,112447,'74014','watch','padding-right','30',0,''),(352359,112447,'74014','watch','margin-bottom','20',0,''),(352360,112447,'74014','watch','color','$content-color-1',0,''),(352361,112448,'74015','watch','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(352362,112449,'74016','watch','hide_parents','2',0,''),(352363,112450,'74017','watch','float','right',0,''),(352364,112450,'74017','watch','margin-top','-37',0,''),(352365,112450,'74017','watch','link','comments',0,''),(352366,112451,'74018','watch','block_type','1',0,''),(352367,112451,'74018','watch','padding-right','30',0,''),(352368,112451,'74018','watch','padding-right','0',0,'5232'),(352369,112451,'74018','watch','background-color','$content-bg-1',0,''),(352370,112451,'74018','watch','padding-top','20',0,''),(352371,112451,'74018','watch','padding-left','30',0,''),(352372,112451,'74018','watch','padding-bottom','20',0,''),(352373,112451,'74018','watch','color','$content-color-1',0,''),(352374,112452,'74019','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(352375,112453,'74020','watch','link','products',0,''),(352376,112453,'74020','watch','float','right',0,''),(352377,112453,'74020','watch','margin-top','-37',0,''),(352378,112455,'74022','watch','block_type','1',0,''),(352379,112455,'74022','watch','padding-top','20',0,''),(352380,112455,'74022','watch','padding-left','20',0,''),(352381,112455,'74022','watch','padding-right','20',0,''),(352382,112455,'74022','watch','padding-bottom','20',0,''),(352383,112455,'74022','watch','background-color','$content-bg-1',0,''),(352384,112455,'74022','watch','style_class','order-summary2 hiding-box',0,''),(352385,112455,'74022','watch','color','$content-color-1',0,''),(352386,112456,'74023','watch','margin-bottom','20',0,''),(352387,112456,'74023','watch','text-align','right',0,''),(352388,112457,'74024','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(352389,112459,'74026','watch','block_type','1',0,''),(352390,112459,'74026','watch','background-color','$content-bg-2',0,''),(352391,112459,'74026','watch','padding-bottom','30',0,''),(352392,112460,'74027','watch','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(352393,112461,'74028','watch','block_type','4',0,''),(352394,112461,'74028','watch','schema','4-2',0,'5240'),(352395,112462,'74029','watch','block_type','1',0,''),(352396,112462,'74029','watch','padding-right','40',0,''),(352397,112462,'74029','watch','padding-right','0',0,'5240'),(352398,112463,'74030','watch','block_type','1',0,''),(352399,112463,'74030','watch','background-color','$content-bg-1',0,''),(352400,112463,'74030','watch','padding-top','20',0,''),(352401,112463,'74030','watch','padding-bottom','20',0,''),(352402,112463,'74030','watch','padding-left','30',0,''),(352403,112463,'74030','watch','padding-right','30',0,''),(352404,112463,'74030','watch','margin-bottom','20',0,''),(352405,112464,'74031','watch','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(352406,112465,'74032','watch','hide_parents','2',0,''),(352407,112466,'74033','watch','float','right',0,''),(352408,112466,'74033','watch','margin-top','-37',0,''),(352409,112466,'74033','watch','link','comments',0,''),(352410,112467,'74034','watch','block_type','2',0,''),(352411,112467,'74034','watch','margin-bottom','20',0,''),(352412,112467,'74034','watch','schema','2-2',0,'5232'),(352413,112467,'74034','watch','background-color','$content-bg-1',0,''),(352414,112468,'74035','watch','block_type','1',0,''),(352415,112468,'74035','watch','border-right-width','20',0,''),(352416,112468,'74035','watch','border-right-color','$content-border-1',0,''),(352417,112468,'74035','watch','margin-right','-10',0,''),(352418,112468,'74035','watch','padding-right','30',0,''),(352419,112468,'74035','watch','padding-top','20',0,''),(352420,112468,'74035','watch','padding-left','30',0,''),(352421,112468,'74035','watch','padding-bottom','20',0,''),(352422,112468,'74035','watch','border-right-width','0',0,'5240'),(352423,112468,'74035','watch','margin-right','0',0,'5240'),(352424,112468,'74035','watch','margin-bottom','20',0,'5240'),(352425,112468,'74035','watch','padding-left','20',0,'5240'),(352426,112468,'74035','watch','padding-right','20',0,'5240'),(352427,112469,'74036','watch','link','contact_information',0,''),(352428,112469,'74036','watch','margin-top','-31',0,''),(352429,112469,'74036','watch','float','right',0,''),(352430,112472,'74039','watch','link','payment_method',0,''),(352431,112472,'74039','watch','float','right',0,''),(352432,112472,'74039','watch','margin-top','-31',0,''),(352433,112473,'74040','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(352434,112473,'74040','watch','padding-top','20',0,''),(352435,112474,'74041','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(352436,112474,'74041','watch','clear','none',0,''),(352437,112475,'74042','watch','block_type','1',0,''),(352438,112475,'74042','watch','padding-left','30',0,''),(352439,112475,'74042','watch','border-left-width','20',0,''),(352440,112475,'74042','watch','border-left-color','$content-border-1',0,''),(352441,112475,'74042','watch','margin-left','-10',0,''),(352442,112475,'74042','watch','padding-right','30',0,''),(352443,112475,'74042','watch','padding-top','20',0,''),(352444,112475,'74042','watch','padding-bottom','20',0,''),(352445,112475,'74042','watch','border-left-width','0',0,'5240'),(352446,112476,'74043','watch','margin-bottom','20',0,''),(352447,112477,'74044','watch','link','billing_address',0,''),(352448,112477,'74044','watch','float','right',0,''),(352449,112477,'74044','watch','margin-top','-31',0,''),(352450,112478,'74045','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(352451,112478,'74045','watch','clear','none',0,''),(352452,112479,'74046','watch','block_type','1',0,''),(352453,112479,'74046','watch','padding-right','30',0,''),(352454,112479,'74046','watch','background-color','$content-bg-1',0,''),(352455,112479,'74046','watch','padding-top','20',0,''),(352456,112479,'74046','watch','padding-left','30',0,''),(352457,112479,'74046','watch','padding-bottom','20',0,''),(352458,112479,'74046','watch','padding-left','20',0,'5240'),(352459,112479,'74046','watch','padding-right','20',0,'5240'),(352460,112480,'74047','watch','link','products',0,''),(352461,112480,'74047','watch','float','right',0,''),(352462,112480,'74047','watch','margin-top','-37',0,''),(352463,112481,'74048','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(352464,112482,'74049','watch','margin-bottom','20',0,''),(352465,112483,'74050','watch','block_type','1',0,''),(352466,112483,'74050','watch','padding-top','20',0,''),(352467,112483,'74050','watch','padding-left','20',0,''),(352468,112483,'74050','watch','padding-right','20',0,''),(352469,112483,'74050','watch','padding-bottom','20',0,''),(352470,112483,'74050','watch','background-color','$content-bg-1',0,''),(352471,112483,'74050','watch','style_class','order-summary',0,''),(352472,112484,'74051','watch','margin-bottom','20',0,''),(352473,112484,'74051','watch','text-align','right',0,''),(352474,112486,'74053','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(352475,112487,'74054','watch','block_type','1',0,''),(352476,112487,'74054','watch','background-color','$content-bg-2',0,''),(352477,112487,'74054','watch','padding-bottom','30',0,''),(352478,112488,'74055','watch','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(352479,112489,'74056','watch','block_type','4',0,''),(352480,112489,'74056','watch','schema','4-2',0,'5240'),(352481,112490,'74057','watch','block_type','1',0,''),(352482,112490,'74057','watch','padding-right','40',0,''),(352483,112490,'74057','watch','padding-right','0',0,'5240'),(352484,112491,'74058','watch','block_type','1',0,''),(352485,112491,'74058','watch','padding-right','30',0,''),(352486,112491,'74058','watch','background-color','$content-bg-1',0,''),(352487,112491,'74058','watch','padding-top','20',0,''),(352488,112491,'74058','watch','padding-left','30',0,''),(352489,112491,'74058','watch','padding-bottom','20',0,''),(352490,112491,'74058','watch','padding-left','20',0,'5240'),(352491,112491,'74058','watch','padding-right','20',0,'5240'),(352492,112493,'74060','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(352493,112494,'74061','watch','link','products',0,''),(352494,112494,'74061','watch','float','right',0,''),(352495,112494,'74061','watch','margin-top','-37',0,''),(352496,112495,'74062','watch','block_type','2',0,''),(352497,112495,'74062','watch','margin-bottom','20',0,''),(352498,112495,'74062','watch','schema','2-2',0,'5232'),(352499,112495,'74062','watch','background-color','$content-bg-1',0,''),(352500,112496,'74063','watch','block_type','1',0,''),(352501,112496,'74063','watch','border-right-width','20',0,''),(352502,112496,'74063','watch','border-right-color','$content-border-1',0,''),(352503,112496,'74063','watch','margin-right','-10',0,''),(352504,112496,'74063','watch','padding-right','30',0,''),(352505,112496,'74063','watch','padding-top','20',0,''),(352506,112496,'74063','watch','padding-left','30',0,''),(352507,112496,'74063','watch','padding-bottom','20',0,''),(352508,112496,'74063','watch','border-right-width','0',0,'5240'),(352509,112496,'74063','watch','margin-right','0',0,'5240'),(352510,112496,'74063','watch','margin-bottom','20',0,'5240'),(352511,112496,'74063','watch','padding-left','20',0,'5240'),(352512,112496,'74063','watch','padding-right','20',0,'5240'),(352513,112497,'74064','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(352514,112498,'74065','watch','link','contact_information',0,''),(352515,112498,'74065','watch','margin-top','-31',0,''),(352516,112498,'74065','watch','float','right',0,''),(352517,112499,'74066','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(352518,112499,'74066','watch','clear','none',0,''),(352519,112501,'74068','watch','margin-bottom','20',0,''),(352520,112503,'74070','watch','link','shipping_address',0,''),(352521,112503,'74070','watch','float','right',0,''),(352522,112503,'74070','watch','margin-top','-31',0,''),(352523,112505,'74072','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(352524,112505,'74072','watch','padding-top','20',0,''),(352525,112506,'74073','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(352526,112506,'74073','watch','clear','none',0,''),(352527,112507,'74074','watch','link','shipping_method',0,''),(352528,112507,'74074','watch','float','right',0,''),(352529,112507,'74074','watch','margin-top','-31',0,''),(352530,112508,'74075','watch','block_type','1',0,''),(352531,112508,'74075','watch','padding-left','30',0,''),(352532,112508,'74075','watch','border-left-width','20',0,''),(352533,112508,'74075','watch','border-left-color','$content-border-1',0,''),(352534,112508,'74075','watch','margin-left','-10',0,''),(352535,112508,'74075','watch','padding-right','30',0,''),(352536,112508,'74075','watch','padding-top','20',0,''),(352537,112508,'74075','watch','padding-bottom','20',0,''),(352538,112508,'74075','watch','border-left-width','0',0,'5240'),(352539,112509,'74076','watch','link','billing_address',0,''),(352540,112509,'74076','watch','float','right',0,''),(352541,112509,'74076','watch','margin-top','-31',0,''),(352542,112510,'74077','watch','margin-bottom','20',0,''),(352543,112512,'74079','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(352544,112513,'74080','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(352545,112513,'74080','watch','clear','none',0,''),(352546,112514,'74081','watch','link','payment_method',0,''),(352547,112514,'74081','watch','float','right',0,''),(352548,112514,'74081','watch','margin-top','-31',0,''),(352549,112515,'74082','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(352550,112515,'74082','watch','clear','none',0,''),(352551,112516,'74083','watch','block_type','1',0,''),(352552,112516,'74083','watch','background-color','$content-bg-1',0,''),(352553,112516,'74083','watch','padding-top','20',0,''),(352554,112516,'74083','watch','padding-bottom','20',0,''),(352555,112516,'74083','watch','padding-left','30',0,''),(352556,112516,'74083','watch','padding-right','30',0,''),(352557,112516,'74083','watch','margin-bottom','20',0,''),(352558,112517,'74084','watch','hide_parents','2',0,''),(352559,112518,'74085','watch','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(352560,112519,'74086','watch','float','right',0,''),(352561,112519,'74086','watch','margin-top','-37',0,''),(352562,112519,'74086','watch','link','comments',0,''),(352563,112520,'74087','watch','block_type','1',0,''),(352564,112520,'74087','watch','padding-top','20',0,''),(352565,112520,'74087','watch','padding-left','20',0,''),(352566,112520,'74087','watch','padding-right','20',0,''),(352567,112520,'74087','watch','padding-bottom','20',0,''),(352568,112520,'74087','watch','background-color','$content-bg-1',0,''),(352569,112520,'74087','watch','style_class','order-summary',0,''),(352570,112521,'74088','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(352571,112523,'74090','watch','margin-bottom','20',0,''),(352572,112523,'74090','watch','text-align','right',0,''),(352573,112524,'74091','watch','block_type','1',0,''),(352574,112524,'74091','watch','background-color','$content-bg-2',0,''),(352575,112524,'74091','watch','padding-bottom','30',0,''),(352576,112525,'74092','watch','block_type','4',0,''),(352577,112525,'74092','watch','schema','4-2',0,'5240'),(352578,112526,'74093','watch','block_type','1',0,''),(352579,112526,'74093','watch','padding-right','40',0,''),(352580,112526,'74093','watch','padding-right','0',0,'5240'),(352581,112527,'74094','watch','block_type','2',0,''),(352582,112527,'74094','watch','margin-bottom','20',0,''),(352583,112527,'74094','watch','schema','2-2',0,'5232'),(352584,112527,'74094','watch','background-color','$content-bg-1',0,''),(352585,112528,'74095','watch','block_type','1',0,''),(352586,112528,'74095','watch','border-right-width','20',0,''),(352587,112528,'74095','watch','border-right-color','$content-border-1',0,''),(352588,112528,'74095','watch','margin-right','-10',0,''),(352589,112528,'74095','watch','padding-right','30',0,''),(352590,112528,'74095','watch','padding-top','20',0,''),(352591,112528,'74095','watch','padding-left','30',0,''),(352592,112528,'74095','watch','padding-bottom','20',0,''),(352593,112528,'74095','watch','border-right-width','0',0,'5240'),(352594,112528,'74095','watch','margin-right','0',0,'5240'),(352595,112528,'74095','watch','margin-bottom','20',0,'5240'),(352596,112528,'74095','watch','padding-left','20',0,'5240'),(352597,112528,'74095','watch','padding-right','20',0,'5240'),(352598,112529,'74096','watch','margin-bottom','20',0,''),(352599,112530,'74097','watch','link','shipping_address',0,''),(352600,112530,'74097','watch','float','right',0,''),(352601,112530,'74097','watch','margin-top','-31',0,''),(352602,112531,'74098','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(352603,112531,'74098','watch','clear','none',0,''),(352604,112534,'74101','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(352605,112535,'74102','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(352606,112535,'74102','watch','clear','none',0,''),(352607,112536,'74103','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(352608,112536,'74103','watch','padding-top','20',0,''),(352609,112538,'74105','watch','link','shipping_method',0,''),(352610,112538,'74105','watch','float','right',0,''),(352611,112538,'74105','watch','margin-top','-31',0,''),(352612,112539,'74106','watch','link','contact_information',0,''),(352613,112539,'74106','watch','margin-top','-31',0,''),(352614,112539,'74106','watch','float','right',0,''),(352615,112540,'74107','watch','block_type','1',0,''),(352616,112540,'74107','watch','padding-left','30',0,''),(352617,112540,'74107','watch','border-left-width','20',0,''),(352618,112540,'74107','watch','border-left-color','$content-border-1',0,''),(352619,112540,'74107','watch','margin-left','-10',0,''),(352620,112540,'74107','watch','padding-right','30',0,''),(352621,112540,'74107','watch','padding-top','20',0,''),(352622,112540,'74107','watch','padding-bottom','20',0,''),(352623,112540,'74107','watch','border-left-width','0',0,'5240'),(352624,112541,'74108','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(352625,112541,'74108','watch','clear','none',0,''),(352626,112542,'74109','watch','margin-bottom','20',0,''),(352627,112543,'74110','watch','link','billing_address',0,''),(352628,112543,'74110','watch','float','right',0,''),(352629,112543,'74110','watch','margin-top','-31',0,''),(352630,112545,'74112','watch','link','payment_method',0,''),(352631,112545,'74112','watch','float','right',0,''),(352632,112545,'74112','watch','margin-top','-31',0,''),(352633,112546,'74113','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(352634,112547,'74114','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(352635,112547,'74114','watch','clear','none',0,''),(352636,112548,'74115','watch','block_type','1',0,''),(352637,112548,'74115','watch','padding-right','30',0,''),(352638,112548,'74115','watch','background-color','$content-bg-1',0,''),(352639,112548,'74115','watch','padding-top','20',0,''),(352640,112548,'74115','watch','padding-left','30',0,''),(352641,112548,'74115','watch','padding-bottom','20',0,''),(352642,112548,'74115','watch','padding-left','20',0,'5240'),(352643,112548,'74115','watch','padding-right','20',0,'5240'),(352644,112549,'74116','watch','link','products',0,''),(352645,112549,'74116','watch','float','right',0,''),(352646,112549,'74116','watch','margin-top','-37',0,''),(352647,112550,'74117','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(352648,112552,'74119','watch','block_type','1',0,''),(352649,112552,'74119','watch','background-color','$content-bg-1',0,''),(352650,112552,'74119','watch','padding-top','20',0,''),(352651,112552,'74119','watch','padding-bottom','20',0,''),(352652,112552,'74119','watch','padding-left','30',0,''),(352653,112552,'74119','watch','padding-right','30',0,''),(352654,112552,'74119','watch','margin-bottom','20',0,''),(352655,112553,'74120','watch','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(352656,112554,'74121','watch','float','right',0,''),(352657,112554,'74121','watch','margin-top','-37',0,''),(352658,112554,'74121','watch','link','comments',0,''),(352659,112555,'74122','watch','hide_parents','2',0,''),(352660,112556,'74123','watch','block_type','1',0,''),(352661,112556,'74123','watch','padding-top','20',0,''),(352662,112556,'74123','watch','padding-left','20',0,''),(352663,112556,'74123','watch','padding-right','20',0,''),(352664,112556,'74123','watch','padding-bottom','20',0,''),(352665,112556,'74123','watch','background-color','$content-bg-1',0,''),(352666,112556,'74123','watch','style_class','order-summary',0,''),(352667,112558,'74125','watch','margin-bottom','20',0,''),(352668,112558,'74125','watch','text-align','right',0,''),(352669,112559,'74126','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(352670,112560,'74127','watch','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(352671,112561,'74128','watch','block_type','1',0,''),(352672,112563,'74133','watch','block_type','2',0,''),(352673,112563,'74133','watch','font-weight','400',0,''),(352674,112563,'74133','watch','padding-bottom','20',0,''),(352675,112563,'74133','watch','schema','2-2',0,'5240'),(352676,112564,'74134','watch','show_captcha','on',0,''),(352677,112565,'74135','watch','font-weight','400',0,''),(352678,112565,'74135','watch','padding-left','40',0,''),(352679,112565,'74135','watch','time_format','24',0,''),(352680,112565,'74135','watch','show_icons','on',0,''),(352681,112565,'74135','watch','padding-left','0',0,'5240'),(352682,112566,'74136','watch','block_type','1',0,''),(352683,112567,'74137','watch','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(352684,112568,'74138','watch','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(352685,112568,'74138','watch','margin-bottom','40',0,''),(352686,112569,'74139','watch','width','680',0,''),(352687,112569,'74139','watch','font-weight','normal',0,''),(352688,112569,'74139','watch','font-size','12',0,''),(352689,112569,'74139','watch','padding-top','20',0,''),(352690,112569,'74139','watch','padding-bottom','20',0,''),(352691,112569,'74139','watch','color','$content-color-1',0,''),(352692,112570,'74140','watch','block_type','3',0,''),(352693,112570,'74140','watch','font-weight','normal',0,''),(352694,112570,'74140','watch','padding-top','20',0,''),(352695,112571,'74141','watch','font-size','12',0,''),(352696,112572,'74142','watch','text','<p>If undelivered please return to:</p>',1,''),(352697,112572,'74142','watch','font-size','12',0,''),(352698,112572,'74142','watch','font-weight','bold',0,''),(352699,112572,'74142','watch','text','<p>If undelivered please return to:</p>',2,''),(352700,112572,'74142','watch','text','<p>If undelivered please return to:</p>',3,''),(352701,112572,'74142','watch','text','<p>If undelivered please return to:</p>',4,''),(352702,112573,'74143','watch','text','<p>Thank you for your order</p>',1,''),(352703,112573,'74143','watch','color','$color-8',0,''),(352704,112573,'74143','watch','font-size','13',0,''),(352705,112573,'74143','watch','font-weight','bold',0,''),(352706,112573,'74143','watch','padding-top','5',0,''),(352707,112573,'74143','watch','text-align','center',0,''),(352708,112573,'74143','watch','text','<p>Thank you for your order</p>',2,''),(352709,112573,'74143','watch','text','<p>Thank you for your order</p>',3,''),(352710,112573,'74143','watch','text','<p>Thank you for your order</p>',4,''),(352711,112574,'74144','watch','font-weight','400',0,''),(352712,112574,'74144','watch','text-align','center',0,''),(352713,112574,'74144','watch','padding-top','0',0,''),(352715,112574,'74144','watch','padding-left','20',0,''),(352716,112574,'74144','watch','padding-right','20',0,''),(352720,112575,'74145','watch','text','<p>If something has gone wrong please contact us at:</p>',1,''),(352721,112575,'74145','watch','font-size','12',0,''),(352722,112575,'74145','watch','font-weight','bold',0,''),(352723,112575,'74145','watch','text-align','right',0,''),(352724,112575,'74145','watch','text','<p>If something has gone wrong please contact us at:</p>',2,''),(352725,112575,'74145','watch','text','<p>If something has gone wrong please contact us at:</p>',3,''),(352726,112575,'74145','watch','text','<p>If something has gone wrong please contact us at:</p>',4,''),(352727,112576,'74146','watch','block_type','6',0,''),(352728,112576,'74146','watch','font-weight','normal',0,''),(352729,112576,'74146','watch','font-size','16',0,''),(352730,112577,'74147','watch','text','<p>Email:</p>',1,''),(352731,112577,'74147','watch','font-weight','normal',0,''),(352732,112577,'74147','watch','text-align','right',0,''),(352733,112577,'74147','watch','font-size','12',0,''),(352734,112577,'74147','watch','text','<p>Email:</p>',2,''),(352735,112577,'74147','watch','text','<p>Email:</p>',3,''),(352736,112577,'74147','watch','text','<p>Email:</p>',4,''),(352737,112578,'74148','watch','font-weight','normal',0,''),(352738,112578,'74148','watch','text-align','right',0,''),(352739,112578,'74148','watch','font-size','12',0,''),(352740,112579,'74149','watch','block_type','6',0,''),(352741,112579,'74149','watch','font-weight','normal',0,''),(352742,112579,'74149','watch','font-size','16',0,''),(352743,112580,'74150','watch','text','<p>Phone:</p>',1,''),(352744,112580,'74150','watch','font-weight','normal',0,''),(352745,112580,'74150','watch','text-align','right',0,''),(352746,112580,'74150','watch','font-size','12',0,''),(352747,112580,'74150','watch','text','<p>Phone:</p>',2,''),(352748,112580,'74150','watch','text','<p>Phone:</p>',3,''),(352749,112580,'74150','watch','text','<p>Phone:</p>',4,''),(352750,112581,'74151','watch','font-weight','normal',0,''),(352751,112581,'74151','watch','text-align','right',0,''),(352752,112581,'74151','watch','font-size','12',0,''),(352753,112582,'74152','watch','font-weight','400',0,''),(352754,112582,'74152','watch','padding-top','20',0,''),(352755,112582,'74152','watch','padding-bottom','0',0,''),(352756,112582,'74152','watch','font-size','12',0,''),(352757,112583,'74153','watch','block_type','2',0,''),(352758,112583,'74153','watch','font-weight','normal',0,''),(352759,112583,'74153','watch','padding-bottom','20',0,''),(352760,112584,'74154','watch','font-weight','400',0,''),(352761,112584,'74154','watch','padding-top','20',0,''),(352766,112585,'74155','watch','block_type','11',0,''),(352767,112585,'74155','watch','font-weight','normal',0,''),(352768,112586,'74156','watch','text','<p>Web:</p>',1,''),(352769,112586,'74156','watch','font-weight','normal',0,''),(352770,112586,'74156','watch','text-align','right',0,''),(352771,112586,'74156','watch','text','<p>Web:</p>',2,''),(352772,112586,'74156','watch','text','<p>Web:</p>',3,''),(352773,112586,'74156','watch','text','<p>Web:</p>',4,''),(352774,112587,'74157','watch','font-weight','normal',0,''),(352775,112587,'74157','watch','text-align','right',0,''),(352776,112588,'74158','watch','block_type','11',0,''),(352777,112588,'74158','watch','font-weight','normal',0,''),(352778,112589,'74159','watch','text','<p>Phone:</p>',1,''),(352779,112589,'74159','watch','font-weight','normal',0,''),(352780,112589,'74159','watch','text-align','right',0,''),(352781,112589,'74159','watch','text','<p>Phone:</p>',2,''),(352782,112589,'74159','watch','text','<p>Phone:</p>',3,''),(352783,112589,'74159','watch','text','<p>Phone:</p>',4,''),(352784,112590,'74160','watch','font-weight','normal',0,''),(352785,112590,'74160','watch','text-align','right',0,''),(352786,112591,'74161','watch','block_type','11',0,''),(352787,112591,'74161','watch','font-weight','normal',0,''),(352788,112592,'74162','watch','text','<p>Email:</p>',1,''),(352789,112592,'74162','watch','font-weight','normal',0,''),(352790,112592,'74162','watch','text-align','right',0,''),(352791,112592,'74162','watch','text','<p>Email:</p>',2,''),(352792,112592,'74162','watch','text','<p>Email:</p>',3,''),(352793,112592,'74162','watch','text','<p>Email:</p>',4,''),(352794,112593,'74163','watch','font-weight','normal',0,''),(352795,112593,'74163','watch','text-align','right',0,''),(352796,112594,'74164','watch','block_type','1',0,''),(352797,112595,'74165','watch','font-weight','normal',0,''),(352798,112595,'74165','watch','text-align','right',0,''),(352799,112595,'74165','watch','padding-bottom','10',0,''),(352800,112595,'74165','watch','address_spacer',',',0,''),(352801,112595,'74165','watch','font-size','12',0,''),(352802,112596,'74166','watch','block_type','5',0,''),(352803,112596,'74166','watch','font-weight','normal',0,''),(352804,112596,'74166','watch','border-bottom-width','1',0,''),(352805,112596,'74166','watch','border-bottom-color','$content-border-1',0,''),(352806,112596,'74166','watch','border-top-width','1',0,''),(352807,112596,'74166','watch','border-top-color','$content-border-1',0,''),(352808,112596,'74166','watch','border-left-color','$content-border-1',0,''),(352809,112596,'74166','watch','border-left-width','1',0,''),(352810,112597,'74167','watch','block_type','1',0,''),(352811,112597,'74167','watch','font-weight','normal',0,''),(352812,112597,'74167','watch','padding-top','10',0,''),(352813,112597,'74167','watch','padding-left','10',0,''),(352814,112597,'74167','watch','padding-right','10',0,''),(352815,112598,'74168','watch','font-weight','400',0,''),(352816,112598,'74168','watch','line-height','120',0,''),(352817,112598,'74168','watch','line_height_measure','%',0,''),(352818,112598,'74168','watch','font-size','12',0,''),(352819,112599,'74169','watch','text','<p>SHIPPING ADDRESS:</p>',1,''),(352820,112599,'74169','watch','font-size','14',0,''),(352821,112599,'74169','watch','font-weight','bold',0,''),(352822,112599,'74169','watch','padding-bottom','10',0,''),(352823,112599,'74169','watch','text','<p>SHIPPING ADDRESS:</p>',2,''),(352824,112599,'74169','watch','text','<p>SHIPPING ADDRESS:</p>',3,''),(352825,112599,'74169','watch','text','<p>SHIPPING ADDRESS:</p>',4,''),(352826,112600,'74170','watch','block_type','1',0,''),(352827,112600,'74170','watch','background-color','$content-bg-2',0,''),(352828,112600,'74170','watch','padding-top','20',0,''),(352829,112600,'74170','watch','padding-left','10',0,''),(352830,112600,'74170','watch','padding-right','10',0,''),(352831,112600,'74170','watch','padding-bottom','20',0,''),(352832,112600,'74170','watch','font-size','14',0,''),(352833,112601,'74171','watch','block_type','4',0,''),(352834,112601,'74171','watch','font-weight','normal',0,''),(352835,112601,'74171','watch','border-top-width','1',0,''),(352836,112601,'74171','watch','border-top-color','$content-border-1',0,''),(352837,112601,'74171','watch','border-left-width','1',0,''),(352838,112601,'74171','watch','border-left-color','$content-border-1',0,''),(352839,112601,'74171','watch','border-right-width','1',0,''),(352840,112601,'74171','watch','border-right-color','$content-border-1',0,''),(352841,112601,'74171','watch','border-bottom-width','1',0,''),(352842,112601,'74171','watch','border-bottom-color','$content-border-1',0,''),(352843,112602,'74172','watch','block_type','2',0,''),(352844,112602,'74172','watch','font-weight','normal',0,''),(352845,112602,'74172','watch','border-right-width','1',0,''),(352846,112602,'74172','watch','border-right-color','$content-border-1',0,''),(352847,112603,'74173','watch','block_type','1',0,''),(352848,112603,'74173','watch','font-weight','400',0,''),(352849,112603,'74173','watch','background-color','$content-bg-2',0,''),(352850,112603,'74173','watch','padding-top','10',0,''),(352851,112603,'74173','watch','padding-left','10',0,''),(352852,112603,'74173','watch','padding-right','10',0,''),(352853,112603,'74173','watch','padding-bottom','30',0,''),(352854,112604,'74174','watch','text','<p>INVOICE ADDRESS:</p>',1,''),(352855,112604,'74174','watch','font-size','14',0,''),(352856,112604,'74174','watch','font-weight','bold',0,''),(352857,112604,'74174','watch','text','<p>INVOICE ADDRESS:</p>',2,''),(352858,112604,'74174','watch','text','<p>INVOICE ADDRESS:</p>',3,''),(352859,112604,'74174','watch','text','<p>INVOICE ADDRESS:</p>',4,''),(352860,112605,'74175','watch','font-size','12',0,''),(352861,112606,'74176','watch','block_type','1',0,''),(352862,112606,'74176','watch','font-weight','normal',0,''),(352863,112606,'74176','watch','padding-top','10',0,''),(352864,112606,'74176','watch','padding-left','10',0,''),(352865,112606,'74176','watch','padding-right','10',0,''),(352866,112606,'74176','watch','padding-bottom','10',0,''),(352867,112607,'74177','watch','font-weight','normal',0,''),(352868,112608,'74178','watch','text','<p>CUSTOMER:</p>',1,''),(352869,112608,'74178','watch','font-size','13',0,''),(352870,112608,'74178','watch','font-weight','bold',0,''),(352871,112608,'74178','watch','text','<p>CUSTOMER:</p>',2,''),(352872,112608,'74178','watch','text','<p>CUSTOMER:</p>',3,''),(352873,112608,'74178','watch','text','<p>CUSTOMER:</p>',4,''),(352874,112609,'74179','watch','text','<p>PHONE NUMBER:</p>',1,''),(352875,112609,'74179','watch','font-size','14',0,''),(352876,112609,'74179','watch','font-weight','bold',0,''),(352877,112609,'74179','watch','padding-top','10',0,''),(352878,112609,'74179','watch','text','<p>PHONE NUMBER:</p>',2,''),(352879,112609,'74179','watch','text','<p>PHONE NUMBER:</p>',3,''),(352880,112609,'74179','watch','text','<p>PHONE NUMBER:</p>',4,''),(352881,112610,'74180','watch','font-weight','normal',0,''),(352882,112612,'74182','watch','text','<p>E-MAIL ADDRESS:</p>',1,''),(352883,112612,'74182','watch','font-weight','bold',0,''),(352884,112612,'74182','watch','font-size','14',0,''),(352885,112612,'74182','watch','padding-top','10',0,''),(352886,112612,'74182','watch','text','<p>E-MAIL ADDRESS:</p>',2,''),(352887,112612,'74182','watch','text','<p>E-MAIL ADDRESS:</p>',3,''),(352888,112612,'74182','watch','text','<p>E-MAIL ADDRESS:</p>',4,''),(352889,112613,'74183','watch','block_type','2',0,''),(352890,112613,'74183','watch','font-weight','normal',0,''),(352891,112613,'74183','watch','border-top-width','1',0,''),(352892,112613,'74183','watch','border-top-color','$content-border-1',0,''),(352893,112613,'74183','watch','border-right-width','1',0,''),(352894,112613,'74183','watch','border-right-color','$content-border-1',0,''),(352895,112614,'74184','watch','block_type','1',0,''),(352896,112614,'74184','watch','font-weight','normal',0,''),(352897,112614,'74184','watch','padding-top','10',0,''),(352898,112614,'74184','watch','padding-left','10',0,''),(352899,112614,'74184','watch','padding-right','10',0,''),(352900,112614,'74184','watch','padding-bottom','10',0,''),(352901,112614,'74184','watch','border-right-width','1',0,''),(352902,112614,'74184','watch','border-right-color','$content-border-1',0,''),(352903,112616,'74186','watch','text','<p>Shipping via</p>',1,''),(352904,112616,'74186','watch','font-weight','bold',0,''),(352905,112616,'74186','watch','font-size','14',0,''),(352906,112616,'74186','watch','text','<p>Shipping via</p>',2,''),(352907,112616,'74186','watch','text','<p>Shipping via</p>',3,''),(352908,112616,'74186','watch','text','<p>Shipping via</p>',4,''),(352909,112617,'74187','watch','block_type','1',0,''),(352910,112617,'74187','watch','font-weight','normal',0,''),(352911,112617,'74187','watch','padding-top','10',0,''),(352912,112617,'74187','watch','padding-left','10',0,''),(352913,112617,'74187','watch','padding-right','10',0,''),(352914,112617,'74187','watch','padding-bottom','10',0,''),(352915,112618,'74188','watch','text','<p>Shipping service</p>',1,''),(352916,112618,'74188','watch','font-weight','bold',0,''),(352917,112618,'74188','watch','font-size','14',0,''),(352918,112618,'74188','watch','text','<p>Shipping service</p>',2,''),(352919,112618,'74188','watch','text','<p>Shipping service</p>',3,''),(352920,112618,'74188','watch','text','<p>Shipping service</p>',4,''),(352921,112620,'74190','watch','font-size','14',0,''),(352922,112620,'74190','watch','font-weight','bold',0,''),(352923,112620,'74190','watch','text-align','center',0,''),(352924,112620,'74190','watch','padding-bottom','10',0,''),(352925,112620,'74190','watch','padding-top','10',0,''),(352926,112621,'74191','watch','text','<p>Payment date:</p>',1,''),(352927,112621,'74191','watch','font-weight','bold',0,''),(352928,112621,'74191','watch','text-align','center',0,''),(352929,112621,'74191','watch','font-size','12',0,''),(352930,112621,'74191','watch','text','<p>Payment date:</p>',2,''),(352931,112621,'74191','watch','text','<p>Payment date:</p>',3,''),(352932,112621,'74191','watch','text','<p>Payment date:</p>',4,''),(352933,112622,'74192','watch','font-weight','normal',0,''),(352934,112622,'74192','watch','text-align','center',0,''),(352935,112622,'74192','watch','padding-bottom','10',0,''),(352936,112629,'74199','watch','text-align','center',0,''),(352937,112629,'74199','watch','padding-top','10',0,''),(352938,112631,'74201','watch','heading_type','h1',0,''),(352939,112634,'94718','watch','text-align','center',0,''),(352940,112634,'94718','watch','padding-top','10',0,''),(352941,112639,'74202','watch','block_type','1',0,''),(352942,112640,'74203','watch','block_type','1',0,''),(352943,112640,'74203','watch','max-width','800',0,''),(352944,112640,'74203','watch','margin','0 auto',0,''),(352945,112640,'74203','watch','background-color','$content-bg-1',0,''),(352946,112641,'74204','watch','color','$content-color-1',0,''),(352947,112641,'74204','watch','font-size','12',0,''),(352948,112641,'74204','watch','padding-top','20',0,''),(352949,112641,'74204','watch','padding-bottom','20',0,''),(352950,112641,'74204','watch','border-top-width','1',0,''),(352951,112641,'74204','watch','border-top-color','$content-border-1',0,''),(352952,112642,'74205','watch','font-weight','normal',0,''),(352953,112642,'74205','watch','padding-top','20',0,''),(352954,112642,'74205','watch','padding-left','10',0,''),(352955,112642,'74205','watch','padding-right','10',0,''),(352956,112642,'74205','watch','padding-bottom','20',0,''),(352957,112642,'74205','watch','color','$content-color-1',0,''),(352958,112642,'74205','watch','font-size','14',0,''),(352959,112643,'74206','watch','block_type','7',0,''),(352960,112643,'74206','watch','font-weight','normal',0,''),(352961,112643,'74206','watch','background-color','$highlight-box-bg-1',0,''),(352962,112643,'74206','watch','padding-top','5',0,''),(352963,112643,'74206','watch','padding-left','10',0,''),(352964,112643,'74206','watch','padding-right','10',0,''),(352965,112643,'74206','watch','padding-bottom','5',0,''),(352966,112644,'74207','watch','color','$highlight-box-color-1',0,''),(352967,112644,'74207','watch','font-size','14',0,''),(352968,112644,'74207','watch','font-weight','normal',0,''),(352969,112645,'74208','watch','font-weight','normal',0,''),(352970,112645,'74208','watch','text-align','right',0,''),(352971,112645,'74208','watch','color','$highlight-box-color-1',0,''),(352972,112645,'74208','watch','font-size','12',0,''),(352973,112646,'74209','watch','font-weight','normal',0,''),(352974,112646,'74209','watch','padding-bottom','10',0,''),(352975,112646,'74209','watch','padding-top','10',0,''),(352976,112646,'74209','watch','logo_from','theme',0,''),(352977,112647,'74210','watch','block_type','1',0,''),(352978,112648,'74211','watch','block_type','1',0,''),(352979,112648,'74211','watch','max-width','800',0,''),(352980,112648,'74211','watch','margin','0 auto',0,''),(352981,112648,'74211','watch','background-color','$content-bg-1',0,''),(352982,112649,'74212','watch','color','$content-color-1',0,''),(352983,112649,'74212','watch','font-size','12',0,''),(352984,112649,'74212','watch','padding-top','20',0,''),(352985,112649,'74212','watch','padding-bottom','20',0,''),(352986,112649,'74212','watch','border-top-width','1',0,''),(352987,112649,'74212','watch','border-top-color','$content-border-1',0,''),(352988,112650,'74213','watch','font-weight','normal',0,''),(352989,112650,'74213','watch','padding-bottom','10',0,''),(352990,112650,'74213','watch','background-color','$highlight-box-bg-1',0,''),(352992,112650,'74213','watch','padding-left','20',0,''),(352993,112650,'74213','watch','padding-top','10',0,''),(352997,112651,'74214','watch','font-weight','normal',0,''),(352998,112651,'74214','watch','padding-top','20',0,''),(352999,112651,'74214','watch','padding-left','10',0,''),(353000,112651,'74214','watch','padding-right','10',0,''),(353001,112651,'74214','watch','padding-bottom','20',0,''),(353002,112651,'74214','watch','color','$content-color-1',0,''),(353003,112651,'74214','watch','font-size','14',0,''),(353004,112652,'74215','watch','block_type','7',0,''),(353005,112652,'74215','watch','font-weight','normal',0,''),(353006,112652,'74215','watch','background-color','$highlight-box-bg-1',0,''),(353007,112652,'74215','watch','padding-top','5',0,''),(353008,112652,'74215','watch','padding-left','10',0,''),(353009,112652,'74215','watch','padding-right','10',0,''),(353010,112652,'74215','watch','padding-bottom','5',0,''),(353011,112653,'74216','watch','color','$highlight-box-color-1',0,''),(353012,112653,'74216','watch','font-size','15',0,''),(353013,112653,'74216','watch','font-weight','700',0,''),(353014,112654,'74217','watch','font-weight','normal',0,''),(353015,112654,'74217','watch','text-align','right',0,''),(353016,112654,'74217','watch','color','$highlight-box-color-1',0,''),(353017,112654,'74217','watch','font-size','12',0,''),(353018,112655,'74218','watch','block_type','1',0,''),(353019,112655,'74218','watch','background-color','$content-bg-2',0,''),(353020,112656,'74219','watch','block_type','1',0,''),(353021,112656,'74219','watch','max-width','800',0,''),(353022,112656,'74219','watch','margin','0 auto',0,''),(353023,112657,'74220','watch','block_type','1',0,''),(353024,112657,'74220','watch','background-color','$content-bg-1',0,''),(353025,112657,'74220','watch','padding-top','20',0,''),(353026,112657,'74220','watch','padding-left','20',0,''),(353027,112657,'74220','watch','padding-right','20',0,''),(353028,112657,'74220','watch','padding-bottom','20',0,''),(353029,112658,'74221','watch','font-weight','normal',0,''),(353030,112658,'74221','watch','padding-top','20',0,''),(353031,112658,'74221','watch','padding-bottom','20',0,''),(353032,112658,'74221','watch','color','$content-color-1',0,''),(353033,112658,'74221','watch','font-size','14',0,''),(353034,112659,'74222','watch','block_type','7',0,''),(353035,112659,'74222','watch','font-weight','normal',0,''),(353036,112659,'74222','watch','padding-left','10',0,''),(353037,112659,'74222','watch','padding-right','10',0,''),(353038,112659,'74222','watch','padding-bottom','15',0,''),(353039,112659,'74222','watch','border-bottom-width','1',0,''),(353040,112659,'74222','watch','border-bottom-color','$content-border-1',0,''),(353041,112660,'74223','watch','color','$content-color-1',0,''),(353042,112660,'74223','watch','font-size','14',0,''),(353043,112660,'74223','watch','font-weight','700',0,''),(353044,112661,'74224','watch','font-weight','normal',0,''),(353045,112661,'74224','watch','text-align','right',0,''),(353046,112661,'74224','watch','color','$fade-color-1',0,''),(353047,112661,'74224','watch','font-size','11',0,''),(353048,112661,'74224','watch','text-transform','uppercase',0,''),(353049,112662,'74225','watch','color','$fade-color-1',0,''),(353050,112662,'74225','watch','font-size','12',0,''),(353051,112662,'74225','watch','padding-top','20',0,''),(353052,112662,'74225','watch','padding-bottom','20',0,''),(353053,112662,'74225','watch','text-align','center',0,''),(353054,112663,'74226','watch','font-weight','normal',0,''),(353055,112663,'74226','watch','padding-bottom','10',0,''),(353056,112663,'74226','watch','padding-top','10',0,''),(353057,112663,'74226','watch','text-align','center',0,''),(353058,112663,'74226','watch','logo_from','theme',0,''),(353059,112664,'74227','watch','block_type','1',0,''),(353060,112664,'74227','watch','background-color','$content-bg-2',0,''),(353061,112664,'74227','watch','padding-top','20',0,''),(353062,112664,'74227','watch','padding-bottom','20',0,''),(353063,112665,'74228','watch','block_type','1',0,''),(353064,112665,'74228','watch','max-width','800',0,''),(353065,112665,'74228','watch','margin','0 auto',0,''),(353066,112666,'74229','watch','color','$fade-color-1',0,''),(353067,112666,'74229','watch','font-size','12',0,''),(353068,112666,'74229','watch','padding-top','20',0,''),(353069,112666,'74229','watch','padding-bottom','20',0,''),(353070,112666,'74229','watch','text-align','left',0,''),(353071,112667,'74230','watch','block_type','1',0,''),(353072,112667,'74230','watch','background-color','$content-bg-1',0,''),(353073,112667,'74230','watch','padding-top','20',0,''),(353074,112667,'74230','watch','padding-left','20',0,''),(353075,112667,'74230','watch','padding-right','20',0,''),(353076,112667,'74230','watch','padding-bottom','20',0,''),(353077,112667,'74230','watch','border-top-width','1',0,''),(353078,112667,'74230','watch','border-left-width','1',0,''),(353079,112667,'74230','watch','border-right-width','1',0,''),(353080,112667,'74230','watch','border-bottom-width','1',0,''),(353081,112667,'74230','watch','border-top-color','$content-border-1',0,''),(353082,112667,'74230','watch','border-left-color','$content-border-1',0,''),(353083,112667,'74230','watch','border-bottom-color','$content-border-1',0,''),(353084,112667,'74230','watch','border-right-color','$content-border-1',0,''),(353085,112668,'74231','watch','block_type','2',0,''),(353086,112669,'74232','watch','font-weight','normal',0,''),(353087,112669,'74232','watch','padding-bottom','10',0,''),(353088,112669,'74232','watch','padding-top','10',0,''),(353089,112669,'74232','watch','logo_from','theme',0,''),(353090,112670,'74233','watch','font-weight','normal',0,''),(353091,112670,'74233','watch','text-align','right',0,''),(353092,112670,'74233','watch','color','$fade-color-1',0,''),(353093,112670,'74233','watch','font-size','11',0,''),(353094,112670,'74233','watch','text-transform','uppercase',0,''),(353095,112671,'74234','watch','color','$content-color-1',0,''),(353096,112671,'74234','watch','font-size','14',0,''),(353097,112671,'74234','watch','font-weight','700',0,''),(353098,112671,'74234','watch','text-align','right',0,''),(353099,112672,'74235','watch','font-weight','normal',0,''),(353100,112672,'74235','watch','padding-top','20',0,''),(353101,112672,'74235','watch','padding-bottom','20',0,''),(353102,112672,'74235','watch','color','$content-color-1',0,''),(353103,112672,'74235','watch','font-size','14',0,''),(353104,112673,'74236','watch','block_type','1',0,''),(353105,112673,'74236','watch','font-weight','normal',0,''),(353106,112673,'74236','watch','padding-top','20',0,''),(353107,112673,'74236','watch','background-color','$footer-bg-1',0,''),(353108,112673,'74236','watch','color','$footer-color-1',0,''),(353109,112674,'74237','watch','block_type','14',0,''),(353110,112674,'74237','watch','margin-bottom','15',0,''),(353111,112674,'74237','watch','schema','14-2',0,'5240'),(353112,112674,'74237','watch','schema','14-3',0,'5232'),(353113,112674,'74237','watch','style_class','preFooter',0,''),(353114,112674,'74237','watch','visibility_checkout','1',0,''),(353115,112675,'74238','watch','block_type','1',0,''),(353116,112676,'74239','watch','class','menu-style-2',0,''),(353117,112677,'1695906739.5696','watch','text','##NAVBAR_TITLE_ACCOUNT##',0,''),(353118,112677,'1695906739.5696','watch','style_class','footerTitle',0,''),(353119,112677,'1695906739.5696','watch','font-family','$font-1',0,''),(353120,112677,'1695906739.5696','watch','font-size','20',0,''),(353121,112677,'1695906739.5696','watch','text-transform','uppercase',0,''),(353122,112678,'74241','watch','block_type','1',0,''),(353123,112679,'74243','watch','class','menu-style-2',0,''),(353124,112680,'1695906751.0591','watch','text','##TEXT_PRODUCTS##',0,''),(353125,112680,'1695906751.0591','watch','font-family','$font-1',0,''),(353126,112680,'1695906751.0591','watch','font-size','20',0,''),(353127,112680,'1695906751.0591','watch','text-transform','uppercase',0,''),(353128,112680,'1695906751.0591','watch','style_class','footerTitle',0,''),(353129,112681,'74244','watch','block_type','1',0,''),(353130,112682,'74246','watch','class','menu-style-2',0,''),(353131,112683,'1695906756.0887','watch','text','##TEXT_SHOP##',0,''),(353132,112683,'1695906756.0887','watch','style_class','footerTitle',0,''),(353133,112683,'1695906756.0887','watch','font-family','$font-1',0,''),(353134,112683,'1695906756.0887','watch','font-size','20',0,''),(353135,112683,'1695906756.0887','watch','text-transform','uppercase',0,''),(353136,112684,'74247','watch','block_type','1',0,''),(353137,112685,'74248','watch','view_item','phone_number',0,''),(353138,112686,'74249','watch','view_item','address',0,''),(353139,112686,'74249','watch','address_spacer',',<span> </span>',0,''),(353140,112687,'1695906761.6568','watch','text','##TEXT_CONTACT##',0,''),(353141,112687,'1695906761.6568','watch','font-family','$font-1',0,''),(353142,112687,'1695906761.6568','watch','font-size','20',0,''),(353143,112687,'1695906761.6568','watch','text-transform','uppercase',0,''),(353144,112687,'1695906761.6568','watch','style_class','footerTitle',0,''),(353145,112688,'74256','watch','block_type','2',0,''),(353146,112688,'74256','watch','font-weight','400',0,''),(353147,112688,'74256','watch','padding-top','20',0,''),(353148,112688,'74256','watch','padding-bottom','20',0,''),(353149,112688,'74256','watch','schema','2-2',0,''),(353150,112688,'74256','watch','schema','2-3',0,'5240'),(353151,112690,'74258','watch','address_spacer',', ',0,''),(353152,112690,'74258','watch','font-weight','400',0,''),(353153,112690,'74258','watch','padding-bottom','10',0,'5240'),(353154,112690,'74258','watch','margin-bottom','10',0,'5240'),(353155,112690,'74258','watch','border-bottom-width','1',0,'5240'),(353156,112690,'74258','watch','border-bottom-color','$content-border-1',0,'5240'),(353157,112691,'94723','watch','block_type','5',0,''),(353158,112692,'94724','watch','text','##TEXT_LANGUAGE##',0,''),(353159,112694,'94726','watch','block_type','5',0,''),(353160,112695,'94727','watch','text','##TEXT_CURRENCY##',0,''),(353161,112697,'74263','watch','block_type','1',0,''),(353162,112697,'74263','watch','font-weight','normal',0,''),(353163,112698,'74264','watch','block_type','2',0,''),(353164,112698,'74264','watch','font-weight','normal',0,''),(353165,112698,'74264','watch','padding-bottom','20',0,''),(353166,112699,'74265','watch','block_type','1',0,''),(353167,112699,'74265','watch','margin-right','20',0,''),(353168,112702,'74268','watch','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(353169,112702,'74268','watch','font-weight','normal',0,''),(353170,112702,'74268','watch','padding-bottom','20',0,''),(353171,112702,'74268','watch','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(353172,112702,'74268','watch','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(353173,112702,'74268','watch','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(353174,112704,'74270','watch','block_type','1',0,''),(353175,112704,'74270','watch','font-weight','normal',0,''),(353176,112704,'74270','watch','style_class','gift-card-view',0,''),(353177,112704,'74270','watch','text-align','center',0,''),(353178,112704,'74270','watch','padding-bottom','20',0,''),(353179,112704,'74270','watch','background-color','$highlight-box-bg-1',0,''),(353180,112704,'74270','watch','padding-left','20',0,''),(353181,112704,'74270','watch','padding-right','20',0,''),(353182,112704,'74270','watch','color','$highlight-box-color-1',0,''),(353183,112705,'74271','watch','block_type','1',0,''),(353184,112705,'74271','watch','font-weight','normal',0,''),(353185,112705,'74271','watch','padding-top','10',0,''),(353186,112706,'74272','watch','font-size','12',0,''),(353187,112706,'74272','watch','font-weight','bold',0,''),(353188,112706,'74272','watch','text-align','center',0,''),(353189,112706,'74272','watch','style_class','email',0,''),(353190,112707,'74273','watch','text','<p>If you require further assistance please contact us</p>',1,''),(353191,112707,'74273','watch','font-weight','normal',0,''),(353192,112707,'74273','watch','text-align','center',0,''),(353193,112707,'74273','watch','font-size','12',0,''),(353194,112707,'74273','watch','padding-top','10',0,''),(353195,112707,'74273','watch','padding-bottom','5',0,''),(353196,112707,'74273','watch','border-top-width','1',0,''),(353197,112707,'74273','watch','border-top-color','$content-border-3',0,''),(353198,112707,'74273','watch','text','<p>If you require further assistance please contact us</p>',2,''),(353199,112707,'74273','watch','text','<p>If you require further assistance please contact us</p>',3,''),(353200,112707,'74273','watch','text','<p>If you require further assistance please contact us</p>',4,''),(353201,112708,'74274','watch','font-size','12',0,''),(353202,112708,'74274','watch','font-weight','bold',0,''),(353203,112708,'74274','watch','text-align','center',0,''),(353204,112708,'74274','watch','style_class','phone',0,''),(353205,112708,'74274','watch','padding-bottom','5',0,''),(353206,112709,'74275','watch','text','<p>WHAT TO DO NEXT:</p>',1,''),(353207,112709,'74275','watch','font-weight','normal',0,''),(353208,112709,'74275','watch','text-align','center',0,''),(353209,112709,'74275','watch','padding-top','20',0,''),(353210,112709,'74275','watch','padding-bottom','10',0,''),(353211,112709,'74275','watch','style_class','question-ico',0,''),(353212,112709,'74275','watch','border-top-width','1',0,''),(353213,112709,'74275','watch','border-top-color','$content-border-3',0,''),(353214,112709,'74275','watch','font-size','18',0,''),(353215,112709,'74275','watch','text','<p>WHAT TO DO NEXT:</p>',2,''),(353216,112709,'74275','watch','text','<p>WHAT TO DO NEXT:</p>',3,''),(353217,112709,'74275','watch','text','<p>WHAT TO DO NEXT:</p>',4,''),(353218,112710,'74276','watch','text','<p>osCommerce</p>\n',1,''),(353219,112710,'74276','watch','font-family','$font-1',0,''),(353220,112710,'74276','watch','font-size','24',0,''),(353221,112710,'74276','watch','font-weight','normal',0,''),(353222,112710,'74276','watch','text-align','center',0,''),(353223,112710,'74276','watch','padding-top','10',0,''),(353224,112710,'74276','watch','padding-bottom','20',0,''),(353225,112710,'74276','watch','text','<p>osCommerce</p>\n',2,''),(353226,112710,'74276','watch','text','<p>osCommerce</p>\n',3,''),(353227,112710,'74276','watch','text','<p>osCommerce</p>\n',4,''),(353228,112711,'74277','watch','block_type','4',0,''),(353229,112711,'74277','watch','color','$highlight-box-color-2',0,''),(353230,112711,'74277','watch','font-size','30',0,''),(353231,112711,'74277','watch','font-weight','normal',0,''),(353232,112711,'74277','watch','background-color','$highlight-box-bg-2',0,''),(353233,112711,'74277','watch','padding-top','5',0,''),(353234,112711,'74277','watch','padding-left','10',0,''),(353235,112711,'74277','watch','padding-right','10',0,''),(353236,112711,'74277','watch','padding-bottom','5',0,''),(353237,112712,'74278','watch','text','<p>Your code is:</p>',1,''),(353238,112712,'74278','watch','font-weight','normal',0,''),(353239,112712,'74278','watch','text','<p>Your code is:</p>',2,''),(353240,112712,'74278','watch','text','<p>Your code is:</p>',3,''),(353241,112712,'74278','watch','text','<p>Your code is:</p>',4,''),(353242,112714,'74280','watch','font-weight','normal',0,''),(353243,112714,'74280','watch','text-align','center',0,''),(353244,112714,'74280','watch','padding-bottom','20',0,''),(353245,112715,'74281','watch','font-size','60',0,''),(353246,112715,'74281','watch','font-weight','bold',0,''),(353247,112715,'74281','watch','text-align','center',0,''),(353248,112715,'74281','watch','line-height','100',0,''),(353249,112715,'74281','watch','padding-bottom','20',0,''),(353250,112715,'74281','watch','line_height_measure','px',0,''),(353251,112716,'74282','watch','text','<p>PERSONAL MESSAGE</p>',1,''),(353252,112716,'74282','watch','font-size','18',0,''),(353253,112716,'74282','watch','font-weight','normal',0,''),(353254,112716,'74282','watch','text-align','center',0,''),(353255,112716,'74282','watch','padding-top','20',0,''),(353256,112716,'74282','watch','padding-bottom','10',0,''),(353257,112716,'74282','watch','border-top-width','1',0,''),(353258,112716,'74282','watch','border-top-color','$content-border-3',0,''),(353259,112716,'74282','watch','text','<p>PERSONAL MESSAGE</p>',2,''),(353260,112716,'74282','watch','text','<p>PERSONAL MESSAGE</p>',3,''),(353261,112716,'74282','watch','text','<p>PERSONAL MESSAGE</p>',4,''),(353266,112717,'74284','watch','text-align','center',0,''),(353267,112717,'74284','watch','padding-top','20',0,''),(353268,112717,'74284','watch','logo_from','theme',0,''),(353269,112718,'74285','watch','text','<p>GIFT CARD</p>',1,''),(353270,112718,'74285','watch','font-size','30',0,''),(353271,112718,'74285','watch','font-weight','normal',0,''),(353272,112718,'74285','watch','border-top-width','1',0,''),(353273,112718,'74285','watch','border-top-color','$content-border-3',0,''),(353274,112718,'74285','watch','style_class','gift-ico',0,''),(353275,112718,'74285','watch','text-align','center',0,''),(353276,112718,'74285','watch','padding-top','15',0,''),(353277,112718,'74285','watch','text','<p>GIFT CARD</p>',2,''),(353278,112718,'74285','watch','text','<p>GIFT CARD</p>',3,''),(353279,112718,'74285','watch','text','<p>GIFT CARD</p>',4,''),(353280,112719,'74286','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(353281,112719,'74286','watch','font-weight','normal',0,''),(353282,112719,'74286','watch','text-align','center',0,''),(353283,112719,'74286','watch','padding-bottom','10',0,''),(353284,112719,'74286','watch','font-size','14',0,''),(353285,112719,'74286','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(353286,112719,'74286','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(353287,112719,'74286','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(353288,112720,'74287','watch','block_type','1',0,''),(353289,112720,'74287','watch','font-weight','normal',0,''),(353290,112720,'74287','watch','style_class','gift-card-view',0,''),(353291,112720,'74287','watch','text-align','center',0,''),(353292,112720,'74287','watch','padding-bottom','20',0,''),(353293,112720,'74287','watch','background-color','$content-bg-2',0,''),(353294,112720,'74287','watch','padding-left','20',0,''),(353295,112720,'74287','watch','padding-right','20',0,''),(353296,112720,'74287','watch','color','$fade-color-2',0,''),(353297,112721,'74288','watch','font-size','60',0,''),(353298,112721,'74288','watch','font-weight','bold',0,''),(353299,112721,'74288','watch','text-align','center',0,''),(353300,112721,'74288','watch','line-height','100',0,''),(353301,112721,'74288','watch','padding-bottom','20',0,''),(353302,112721,'74288','watch','line_height_measure','px',0,''),(353303,112722,'74289','watch','block_type','4',0,''),(353304,112722,'74289','watch','color','$highlight-box-color-2',0,''),(353305,112722,'74289','watch','font-size','30',0,''),(353306,112722,'74289','watch','font-weight','normal',0,''),(353307,112722,'74289','watch','background-color','$highlight-box-bg-2',0,''),(353308,112722,'74289','watch','padding-top','5',0,''),(353309,112722,'74289','watch','padding-left','10',0,''),(353310,112722,'74289','watch','padding-right','10',0,''),(353311,112722,'74289','watch','padding-bottom','5',0,''),(353312,112723,'74290','watch','text','<p>Your code is:</p>',1,''),(353313,112723,'74290','watch','font-weight','normal',0,''),(353314,112723,'74290','watch','text','<p>Your code is:</p>',2,''),(353315,112723,'74290','watch','text','<p>Your code is:</p>',3,''),(353316,112723,'74290','watch','text','<p>Your code is:</p>',4,''),(353317,112725,'74292','watch','block_type','1',0,''),(353318,112725,'74292','watch','font-weight','normal',0,''),(353319,112725,'74292','watch','padding-top','10',0,''),(353320,112726,'74293','watch','font-size','12',0,''),(353321,112726,'74293','watch','font-weight','bold',0,''),(353322,112726,'74293','watch','text-align','center',0,''),(353323,112726,'74293','watch','style_class','email',0,''),(353324,112727,'74294','watch','text','<p>If you require further assistance please contact us</p>',1,''),(353325,112727,'74294','watch','font-weight','normal',0,''),(353326,112727,'74294','watch','text-align','center',0,''),(353327,112727,'74294','watch','font-size','12',0,''),(353328,112727,'74294','watch','padding-top','10',0,''),(353329,112727,'74294','watch','padding-bottom','5',0,''),(353330,112727,'74294','watch','border-top-width','1',0,''),(353331,112727,'74294','watch','border-top-color','$content-border-3',0,''),(353332,112727,'74294','watch','text','<p>If you require further assistance please contact us</p>',2,''),(353333,112727,'74294','watch','text','<p>If you require further assistance please contact us</p>',3,''),(353334,112727,'74294','watch','text','<p>If you require further assistance please contact us</p>',4,''),(353335,112728,'74295','watch','font-size','12',0,''),(353336,112728,'74295','watch','font-weight','bold',0,''),(353337,112728,'74295','watch','text-align','center',0,''),(353338,112728,'74295','watch','style_class','phone',0,''),(353339,112728,'74295','watch','padding-bottom','5',0,''),(353340,112729,'74296','watch','font-weight','normal',0,''),(353341,112729,'74296','watch','text-align','center',0,''),(353342,112729,'74296','watch','padding-bottom','20',0,''),(353343,112730,'74297','watch','text','<p>PERSONAL MESSAGE</p>',1,''),(353344,112730,'74297','watch','font-size','18',0,''),(353345,112730,'74297','watch','font-weight','normal',0,''),(353346,112730,'74297','watch','text-align','center',0,''),(353347,112730,'74297','watch','padding-top','20',0,''),(353348,112730,'74297','watch','padding-bottom','10',0,''),(353349,112730,'74297','watch','border-top-width','1',0,''),(353350,112730,'74297','watch','border-top-color','$content-border-3',0,''),(353351,112730,'74297','watch','text','<p>PERSONAL MESSAGE</p>',2,''),(353352,112730,'74297','watch','text','<p>PERSONAL MESSAGE</p>',3,''),(353353,112730,'74297','watch','text','<p>PERSONAL MESSAGE</p>',4,''),(353354,112731,'74298','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(353355,112731,'74298','watch','font-weight','normal',0,''),(353356,112731,'74298','watch','text-align','center',0,''),(353357,112731,'74298','watch','padding-bottom','10',0,''),(353358,112731,'74298','watch','font-size','14',0,''),(353359,112731,'74298','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(353360,112731,'74298','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(353361,112731,'74298','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(353362,112732,'74299','watch','text','<p>GIFT CARD</p>',1,''),(353363,112732,'74299','watch','font-size','30',0,''),(353364,112732,'74299','watch','font-weight','normal',0,''),(353365,112732,'74299','watch','border-top-width','1',0,''),(353366,112732,'74299','watch','border-top-color','$content-border-3',0,''),(353367,112732,'74299','watch','style_class','gift-ico',0,''),(353368,112732,'74299','watch','text-align','center',0,''),(353369,112732,'74299','watch','padding-top','15',0,''),(353370,112732,'74299','watch','text','<p>GIFT CARD</p>',2,''),(353371,112732,'74299','watch','text','<p>GIFT CARD</p>',3,''),(353372,112732,'74299','watch','text','<p>GIFT CARD</p>',4,''),(353373,112733,'74300','watch','text','<p>WHAT TO DO NEXT:</p>',1,''),(353374,112733,'74300','watch','font-weight','normal',0,''),(353375,112733,'74300','watch','text-align','center',0,''),(353376,112733,'74300','watch','padding-top','20',0,''),(353377,112733,'74300','watch','padding-bottom','10',0,''),(353378,112733,'74300','watch','style_class','question-ico',0,''),(353379,112733,'74300','watch','border-top-width','1',0,''),(353380,112733,'74300','watch','border-top-color','$content-border-3',0,''),(353381,112733,'74300','watch','font-size','18',0,''),(353382,112733,'74300','watch','text','<p>WHAT TO DO NEXT:</p>',2,''),(353383,112733,'74300','watch','text','<p>WHAT TO DO NEXT:</p>',3,''),(353384,112733,'74300','watch','text','<p>WHAT TO DO NEXT:</p>',4,''),(353385,112734,'74301','watch','text','<p>HOLBI</p>',1,''),(353386,112734,'74301','watch','font-family','$font-1',0,''),(353387,112734,'74301','watch','font-size','24',0,''),(353388,112734,'74301','watch','font-weight','normal',0,''),(353389,112734,'74301','watch','text-align','center',0,''),(353390,112734,'74301','watch','padding-top','10',0,''),(353391,112734,'74301','watch','padding-bottom','20',0,''),(353392,112734,'74301','watch','text','<p>HOLBI</p>',2,''),(353393,112734,'74301','watch','text','<p>HOLBI</p>',3,''),(353394,112734,'74301','watch','text','<p>HOLBI</p>',4,''),(353395,112735,'94729','watch','block_type','1',0,''),(353396,112735,'94729','watch','font-weight','normal',0,''),(353397,112735,'94729','watch','style_class','gift-card-view',0,''),(353398,112735,'94729','watch','text-align','center',0,''),(353399,112735,'94729','watch','padding-bottom','20',0,''),(353400,112735,'94729','watch','background-color','$content-bg-2',0,''),(353401,112735,'94729','watch','padding-left','20',0,''),(353402,112735,'94729','watch','padding-right','20',0,''),(353403,112736,'94730','watch','block_type','1',0,''),(353404,112736,'94730','watch','font-weight','normal',0,''),(353405,112736,'94730','watch','padding-top','10',0,''),(353406,112737,'94731','watch','font-size','12',0,''),(353407,112737,'94731','watch','font-weight','bold',0,''),(353408,112737,'94731','watch','text-align','center',0,''),(353409,112737,'94731','watch','style_class','email',0,''),(353410,112738,'94732','watch','font-size','12',0,''),(353411,112738,'94732','watch','font-weight','bold',0,''),(353412,112738,'94732','watch','text-align','center',0,''),(353413,112738,'94732','watch','style_class','phone',0,''),(353414,112738,'94732','watch','padding-bottom','5',0,''),(353415,112739,'94733','watch','text','If you require further assistance please contact us',0,''),(353416,112739,'94733','watch','font-size','12',0,''),(353417,112739,'94733','watch','text-align','center',0,''),(353418,112739,'94733','watch','padding-top','10',0,''),(353419,112740,'94734','watch','block_type','4',0,''),(353420,112740,'94734','watch','color','$highlight-box-color-2',0,''),(353421,112740,'94734','watch','font-size','30',0,''),(353422,112740,'94734','watch','font-weight','normal',0,''),(353423,112740,'94734','watch','background-color','$highlight-box-bg-2',0,''),(353424,112740,'94734','watch','padding-top','5',0,''),(353425,112740,'94734','watch','padding-left','10',0,''),(353426,112740,'94734','watch','padding-right','10',0,''),(353427,112740,'94734','watch','padding-bottom','5',0,''),(353428,112741,'94735','watch','text','Your code is:',0,''),(353429,112741,'94735','watch','font-size','30',0,''),(353430,112741,'94735','watch','color','$highlight-box-color-2',0,''),(353431,112742,'94736','watch','color','$highlight-box-color-2',0,''),(353432,112742,'94736','watch','font-size','30',0,''),(353433,112743,'94737','watch','block_type','1',0,''),(353434,112744,'94738','watch','text','<p>PERSONAL MESSAGE</p>',1,''),(353435,112744,'94738','watch','font-size','18',0,''),(353436,112744,'94738','watch','font-weight','normal',0,''),(353437,112744,'94738','watch','text-align','center',0,''),(353438,112744,'94738','watch','padding-top','20',0,''),(353439,112744,'94738','watch','padding-bottom','10',0,''),(353440,112744,'94738','watch','border-top-width','1',0,''),(353441,112744,'94738','watch','border-top-color','$content-border-3',0,''),(353442,112744,'94738','watch','text','<p>PERSONAL MESSAGE</p>',2,''),(353443,112744,'94738','watch','text','<p>PERSONAL MESSAGE</p>',3,''),(353444,112744,'94738','watch','text','<p>PERSONAL MESSAGE</p>',4,''),(353445,112745,'94739','watch','text','HOLBI',0,''),(353446,112745,'94739','watch','font-size','24',0,''),(353447,112745,'94739','watch','padding-top','20',0,''),(353448,112745,'94739','watch','text-align','center',0,''),(353449,112745,'94739','watch','padding-bottom','20',0,''),(353450,112746,'94740','watch','border-top-color','$content-border-3',0,''),(353451,112746,'94740','watch','border-top-width','1',0,''),(353452,112746,'94740','watch','padding-top','20',0,''),(353453,112746,'94740','watch','font-size','30',0,''),(353454,112746,'94740','watch','text-align','center',0,''),(353455,112746,'94740','watch','text','GIFT CARD',0,''),(353456,112747,'94741','watch','text-align','center',0,''),(353457,112747,'94741','watch','font-weight','bold',0,''),(353458,112747,'94741','watch','font-size','60',0,''),(353459,112748,'94742','watch','font-size','20',0,''),(353460,112748,'94742','watch','text-align','center',0,''),(353461,112748,'94742','watch','padding-top','20',0,''),(353462,112748,'94742','watch','padding-bottom','20',0,''),(353463,112749,'94743','watch','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(353464,112749,'94743','watch','text-align','center',0,''),(353465,112749,'94743','watch','font-size','14',0,''),(353466,112749,'94743','watch','padding-bottom','20',0,''),(353467,112750,'94744','watch','text','WHAT TO DO NEXT:',0,''),(353468,112750,'94744','watch','font-size','18',0,''),(353469,112750,'94744','watch','text-align','center',0,''),(353470,112750,'94744','watch','padding-top','20',0,''),(353471,112750,'94744','watch','padding-bottom','10',0,''),(353472,112750,'94744','watch','border-top-width','1',0,''),(353473,112750,'94744','watch','border-top-color','$content-border-3',0,''),(353474,112751,'94746','watch','block_type','1',0,''),(353475,112751,'94746','watch','font-weight','normal',0,''),(353476,112751,'94746','watch','style_class','gift-card-view',0,''),(353477,112751,'94746','watch','text-align','center',0,''),(353478,112751,'94746','watch','padding-bottom','20',0,''),(353479,112751,'94746','watch','background-color','$highlight-box-bg-1',0,''),(353480,112751,'94746','watch','padding-left','20',0,''),(353481,112751,'94746','watch','padding-right','20',0,''),(353482,112751,'94746','watch','color','$highlight-box-color-1',0,''),(353483,112752,'94747','watch','block_type','1',0,''),(353484,112752,'94747','watch','font-weight','normal',0,''),(353485,112752,'94747','watch','padding-top','10',0,''),(353486,112753,'94748','watch','font-size','12',0,''),(353487,112753,'94748','watch','font-weight','bold',0,''),(353488,112753,'94748','watch','text-align','center',0,''),(353489,112753,'94748','watch','style_class','email',0,''),(353490,112753,'94748','watch','color','$highlight-box-color-1',0,''),(353491,112754,'94749','watch','font-size','12',0,''),(353492,112754,'94749','watch','font-weight','bold',0,''),(353493,112754,'94749','watch','text-align','center',0,''),(353494,112754,'94749','watch','style_class','phone',0,''),(353495,112754,'94749','watch','padding-bottom','5',0,''),(353496,112754,'94749','watch','color','$highlight-box-color-1',0,''),(353497,112755,'94750','watch','text','If you require further assistance please contact us',0,''),(353498,112755,'94750','watch','font-size','12',0,''),(353499,112755,'94750','watch','color','$highlight-box-color-1',0,''),(353500,112755,'94750','watch','text-align','center',0,''),(353501,112755,'94750','watch','padding-top','10',0,''),(353502,112756,'94751','watch','block_type','4',0,''),(353503,112756,'94751','watch','color','$highlight-box-color-2',0,''),(353504,112756,'94751','watch','font-size','30',0,''),(353505,112756,'94751','watch','font-weight','normal',0,''),(353506,112756,'94751','watch','background-color','$highlight-box-bg-2',0,''),(353507,112756,'94751','watch','padding-top','5',0,''),(353508,112756,'94751','watch','padding-left','10',0,''),(353509,112756,'94751','watch','padding-right','10',0,''),(353510,112756,'94751','watch','padding-bottom','5',0,''),(353511,112757,'94752','watch','text','Your code is:',0,''),(353512,112757,'94752','watch','font-size','30',0,''),(353513,112757,'94752','watch','color','$highlight-box-color-2',0,''),(353514,112758,'94753','watch','color','$highlight-box-color-2',0,''),(353515,112758,'94753','watch','font-size','30',0,''),(353516,112759,'94754','watch','block_type','1',0,''),(353517,112760,'94755','watch','text','<p>PERSONAL MESSAGE</p>',1,''),(353518,112760,'94755','watch','font-size','18',0,''),(353519,112760,'94755','watch','font-weight','normal',0,''),(353520,112760,'94755','watch','text-align','center',0,''),(353521,112760,'94755','watch','padding-top','20',0,''),(353522,112760,'94755','watch','padding-bottom','10',0,''),(353523,112760,'94755','watch','border-top-width','1',0,''),(353524,112760,'94755','watch','border-top-color','$content-border-3',0,''),(353525,112760,'94755','watch','text','<p>PERSONAL MESSAGE</p>',2,''),(353526,112760,'94755','watch','text','<p>PERSONAL MESSAGE</p>',3,''),(353527,112760,'94755','watch','text','<p>PERSONAL MESSAGE</p>',4,''),(353528,112761,'94757','watch','border-top-color','$content-border-3',0,''),(353529,112761,'94757','watch','border-top-width','1',0,''),(353530,112761,'94757','watch','padding-top','20',0,''),(353531,112761,'94757','watch','font-size','30',0,''),(353532,112761,'94757','watch','text-align','center',0,''),(353533,112761,'94757','watch','color','$highlight-box-color-1',0,''),(353534,112761,'94757','watch','text','GIFT CARD',0,''),(353535,112762,'94758','watch','text-align','center',0,''),(353536,112762,'94758','watch','font-weight','bold',0,''),(353537,112762,'94758','watch','font-size','60',0,''),(353538,112762,'94758','watch','color','$highlight-box-color-1',0,''),(353539,112763,'94759','watch','font-size','20',0,''),(353540,112763,'94759','watch','text-align','center',0,''),(353541,112763,'94759','watch','color','$highlight-box-color-1',0,''),(353542,112763,'94759','watch','padding-top','20',0,''),(353543,112763,'94759','watch','padding-bottom','20',0,''),(353544,112764,'94760','watch','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(353545,112764,'94760','watch','text-align','center',0,''),(353546,112764,'94760','watch','color','$highlight-box-color-1',0,''),(353547,112764,'94760','watch','font-size','14',0,''),(353548,112764,'94760','watch','padding-bottom','20',0,''),(353549,112765,'94761','watch','text','WHAT TO DO NEXT:',0,''),(353550,112765,'94761','watch','font-size','18',0,''),(353551,112765,'94761','watch','text-align','center',0,''),(353552,112765,'94761','watch','padding-top','20',0,''),(353553,112765,'94761','watch','padding-bottom','10',0,''),(353554,112765,'94761','watch','border-top-width','1',0,''),(353555,112765,'94761','watch','border-top-color','$content-border-3',0,''),(353556,112766,'1707902674.2595','watch','logo_from','theme',0,''),(353557,112766,'1707902674.2595','watch','text-align','center',0,''),(353558,112766,'1707902674.2595','watch','padding-top','20',0,''),(353559,112768,'74302','watch','block_type','1',0,''),(353560,112770,'74304','watch','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(353561,112770,'74304','watch','text-align','center',0,''),(353562,112771,'74305','watch','block_type','1',0,''),(353563,112771,'74305','watch','font-weight','normal',0,''),(353564,112771,'74305','watch','style_class','gift-card-view',0,''),(353565,112771,'74305','watch','text-align','center',0,''),(353566,112771,'74305','watch','padding-bottom','20',0,''),(353567,112771,'74305','watch','background-color','$highlight-box-bg-3',0,''),(353568,112771,'74305','watch','padding-left','20',0,''),(353569,112771,'74305','watch','padding-right','20',0,''),(353570,112771,'74305','watch','color','$highlight-box-color-3',0,''),(353571,112772,'74306','watch','block_type','4',0,''),(353572,112772,'74306','watch','color','$highlight-box-color-2',0,''),(353573,112772,'74306','watch','font-size','30',0,''),(353574,112772,'74306','watch','font-weight','normal',0,''),(353575,112772,'74306','watch','background-color','$highlight-box-bg-2',0,''),(353576,112772,'74306','watch','padding-top','5',0,''),(353577,112772,'74306','watch','padding-left','10',0,''),(353578,112772,'74306','watch','padding-right','10',0,''),(353579,112772,'74306','watch','padding-bottom','5',0,''),(353580,112773,'74307','watch','text','<p>Your code is:</p>',1,''),(353581,112773,'74307','watch','font-weight','normal',0,''),(353582,112773,'74307','watch','text','<p>Your code is:</p>',2,''),(353583,112773,'74307','watch','text','<p>Your code is:</p>',3,''),(353584,112773,'74307','watch','text','<p>Your code is:</p>',4,''),(353585,112775,'74309','watch','text','<p>WHAT TO DO NEXT:</p>',1,''),(353586,112775,'74309','watch','font-weight','normal',0,''),(353587,112775,'74309','watch','text-align','center',0,''),(353588,112775,'74309','watch','padding-top','20',0,''),(353589,112775,'74309','watch','padding-bottom','10',0,''),(353590,112775,'74309','watch','style_class','question-ico',0,''),(353591,112775,'74309','watch','border-top-width','1',0,''),(353592,112775,'74309','watch','border-top-color','$content-border-3',0,''),(353593,112775,'74309','watch','font-size','18',0,''),(353594,112775,'74309','watch','text','<p>WHAT TO DO NEXT:</p>',2,''),(353595,112775,'74309','watch','text','<p>WHAT TO DO NEXT:</p>',3,''),(353596,112775,'74309','watch','text','<p>WHAT TO DO NEXT:</p>',4,''),(353597,112776,'74310','watch','text','<p>osCommerce</p>\n',1,''),(353598,112776,'74310','watch','font-family','$font-1',0,''),(353599,112776,'74310','watch','font-size','24',0,''),(353600,112776,'74310','watch','font-weight','normal',0,''),(353601,112776,'74310','watch','text-align','center',0,''),(353602,112776,'74310','watch','padding-top','10',0,''),(353603,112776,'74310','watch','padding-bottom','20',0,''),(353604,112776,'74310','watch','text','<p>osCommerce</p>\n',2,''),(353605,112776,'74310','watch','text','<p>osCommerce</p>\n',3,''),(353606,112776,'74310','watch','text','<p>osCommerce</p>\n',4,''),(353607,112777,'74311','watch','block_type','1',0,''),(353608,112777,'74311','watch','font-weight','normal',0,''),(353609,112777,'74311','watch','padding-top','10',0,''),(353610,112778,'74312','watch','text','<p>If you require further assistance please contact us</p>',1,''),(353611,112778,'74312','watch','font-weight','normal',0,''),(353612,112778,'74312','watch','text-align','center',0,''),(353613,112778,'74312','watch','font-size','12',0,''),(353614,112778,'74312','watch','padding-top','10',0,''),(353615,112778,'74312','watch','padding-bottom','5',0,''),(353616,112778,'74312','watch','border-top-width','1',0,''),(353617,112778,'74312','watch','border-top-color','$content-border-3',0,''),(353618,112778,'74312','watch','text','<p>If you require further assistance please contact us</p>',2,''),(353619,112778,'74312','watch','text','<p>If you require further assistance please contact us</p>',3,''),(353620,112778,'74312','watch','text','<p>If you require further assistance please contact us</p>',4,''),(353621,112779,'74313','watch','font-size','12',0,''),(353622,112779,'74313','watch','font-weight','bold',0,''),(353623,112779,'74313','watch','text-align','center',0,''),(353624,112779,'74313','watch','style_class','email',0,''),(353625,112780,'74314','watch','font-size','12',0,''),(353626,112780,'74314','watch','font-weight','bold',0,''),(353627,112780,'74314','watch','text-align','center',0,''),(353628,112780,'74314','watch','style_class','phone',0,''),(353629,112780,'74314','watch','padding-bottom','5',0,''),(353630,112781,'74315','watch','font-weight','normal',0,''),(353631,112781,'74315','watch','text-align','center',0,''),(353632,112781,'74315','watch','padding-bottom','20',0,''),(353633,112782,'74316','watch','text','<p>GIFT CARD</p>',1,''),(353634,112782,'74316','watch','font-size','30',0,''),(353635,112782,'74316','watch','font-weight','normal',0,''),(353636,112782,'74316','watch','border-top-width','1',0,''),(353637,112782,'74316','watch','border-top-color','$content-border-3',0,''),(353638,112782,'74316','watch','style_class','gift-ico',0,''),(353639,112782,'74316','watch','text-align','center',0,''),(353640,112782,'74316','watch','padding-top','15',0,''),(353641,112782,'74316','watch','text','<p>GIFT CARD</p>',2,''),(353642,112782,'74316','watch','text','<p>GIFT CARD</p>',3,''),(353643,112782,'74316','watch','text','<p>GIFT CARD</p>',4,''),(353644,112783,'74317','watch','text','<p>PERSONAL MESSAGE</p>',1,''),(353645,112783,'74317','watch','font-size','18',0,''),(353646,112783,'74317','watch','font-weight','normal',0,''),(353647,112783,'74317','watch','text-align','center',0,''),(353648,112783,'74317','watch','padding-top','20',0,''),(353649,112783,'74317','watch','padding-bottom','10',0,''),(353650,112783,'74317','watch','border-top-width','1',0,''),(353651,112783,'74317','watch','border-top-color','$content-border-3',0,''),(353652,112783,'74317','watch','text','<p>PERSONAL MESSAGE</p>',2,''),(353653,112783,'74317','watch','text','<p>PERSONAL MESSAGE</p>',3,''),(353654,112783,'74317','watch','text','<p>PERSONAL MESSAGE</p>',4,''),(353655,112784,'74318','watch','font-size','60',0,''),(353656,112784,'74318','watch','font-weight','bold',0,''),(353657,112784,'74318','watch','text-align','center',0,''),(353658,112784,'74318','watch','line-height','100',0,''),(353659,112784,'74318','watch','padding-bottom','20',0,''),(353660,112784,'74318','watch','line_height_measure','px',0,''),(353661,112785,'74319','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(353662,112785,'74319','watch','font-weight','normal',0,''),(353663,112785,'74319','watch','text-align','center',0,''),(353664,112785,'74319','watch','padding-bottom','10',0,''),(353665,112785,'74319','watch','font-size','14',0,''),(353666,112785,'74319','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(353667,112785,'74319','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(353668,112785,'74319','watch','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(353669,112786,'94763','watch','block_type','1',0,''),(353670,112786,'94763','watch','font-weight','normal',0,''),(353671,112786,'94763','watch','style_class','gift-card-view',0,''),(353672,112786,'94763','watch','text-align','center',0,''),(353673,112786,'94763','watch','padding-bottom','20',0,''),(353674,112786,'94763','watch','background-color','$highlight-box-bg-3',0,''),(353675,112786,'94763','watch','padding-left','20',0,''),(353676,112786,'94763','watch','padding-right','20',0,''),(353677,112786,'94763','watch','color','$highlight-box-color-3',0,''),(353678,112787,'94764','watch','block_type','1',0,''),(353679,112787,'94764','watch','font-weight','normal',0,''),(353680,112787,'94764','watch','padding-top','10',0,''),(353681,112788,'94765','watch','font-size','12',0,''),(353682,112788,'94765','watch','font-weight','bold',0,''),(353683,112788,'94765','watch','text-align','center',0,''),(353684,112788,'94765','watch','style_class','email',0,''),(353685,112789,'94766','watch','font-size','12',0,''),(353686,112789,'94766','watch','font-weight','bold',0,''),(353687,112789,'94766','watch','text-align','center',0,''),(353688,112789,'94766','watch','style_class','phone',0,''),(353689,112789,'94766','watch','padding-bottom','5',0,''),(353690,112790,'94767','watch','text','If you require further assistance please contact us',0,''),(353691,112790,'94767','watch','font-size','12',0,''),(353692,112790,'94767','watch','text-align','center',0,''),(353693,112790,'94767','watch','padding-top','10',0,''),(353694,112791,'94768','watch','block_type','4',0,''),(353695,112791,'94768','watch','color','$highlight-box-color-2',0,''),(353696,112791,'94768','watch','font-size','30',0,''),(353697,112791,'94768','watch','font-weight','normal',0,''),(353698,112791,'94768','watch','background-color','$highlight-box-bg-2',0,''),(353699,112791,'94768','watch','padding-top','5',0,''),(353700,112791,'94768','watch','padding-left','10',0,''),(353701,112791,'94768','watch','padding-right','10',0,''),(353702,112791,'94768','watch','padding-bottom','5',0,''),(353703,112792,'94769','watch','text','Your code is:',0,''),(353704,112792,'94769','watch','font-size','30',0,''),(353705,112792,'94769','watch','color','$highlight-box-color-2',0,''),(353706,112793,'94770','watch','color','$highlight-box-color-2',0,''),(353707,112793,'94770','watch','font-size','30',0,''),(353708,112794,'94771','watch','block_type','1',0,''),(353709,112795,'94772','watch','text','<p>PERSONAL MESSAGE</p>',1,''),(353710,112795,'94772','watch','font-size','18',0,''),(353711,112795,'94772','watch','font-weight','normal',0,''),(353712,112795,'94772','watch','text-align','center',0,''),(353713,112795,'94772','watch','padding-top','20',0,''),(353714,112795,'94772','watch','padding-bottom','10',0,''),(353715,112795,'94772','watch','border-top-width','1',0,''),(353716,112795,'94772','watch','border-top-color','$content-border-3',0,''),(353717,112795,'94772','watch','text','<p>PERSONAL MESSAGE</p>',2,''),(353718,112795,'94772','watch','text','<p>PERSONAL MESSAGE</p>',3,''),(353719,112795,'94772','watch','text','<p>PERSONAL MESSAGE</p>',4,''),(353720,112796,'94773','watch','text','HOLBI',0,''),(353721,112796,'94773','watch','color','$highlight-box-color-3',0,''),(353722,112796,'94773','watch','font-size','24',0,''),(353723,112796,'94773','watch','padding-top','20',0,''),(353724,112796,'94773','watch','text-align','center',0,''),(353725,112796,'94773','watch','padding-bottom','20',0,''),(353726,112797,'94774','watch','border-top-color','$content-border-3',0,''),(353727,112797,'94774','watch','border-top-width','1',0,''),(353728,112797,'94774','watch','padding-top','20',0,''),(353729,112797,'94774','watch','font-size','30',0,''),(353730,112797,'94774','watch','text-align','center',0,''),(353731,112797,'94774','watch','color','$highlight-box-color-3',0,''),(353732,112797,'94774','watch','text','GIFT CARD',0,''),(353733,112798,'94775','watch','text-align','center',0,''),(353734,112798,'94775','watch','font-weight','bold',0,''),(353735,112798,'94775','watch','font-size','60',0,''),(353736,112798,'94775','watch','color','$highlight-box-color-3',0,''),(353737,112799,'94776','watch','font-size','20',0,''),(353738,112799,'94776','watch','text-align','center',0,''),(353739,112799,'94776','watch','padding-top','20',0,''),(353740,112799,'94776','watch','padding-bottom','20',0,''),(353741,112800,'94777','watch','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(353742,112800,'94777','watch','text-align','center',0,''),(353743,112800,'94777','watch','font-size','14',0,''),(353744,112800,'94777','watch','padding-bottom','20',0,''),(353745,112801,'94778','watch','text','WHAT TO DO NEXT:',0,''),(353746,112801,'94778','watch','font-size','18',0,''),(353747,112801,'94778','watch','text-align','center',0,''),(353748,112801,'94778','watch','padding-top','20',0,''),(353749,112801,'94778','watch','padding-bottom','10',0,''),(353750,112801,'94778','watch','border-top-width','1',0,''),(353751,112801,'94778','watch','border-top-color','$content-border-3',0,''),(353752,112802,'74328','watch','block_type','1',0,''),(353753,112802,'74328','watch','font-weight','400',0,''),(353754,112802,'74328','watch','background-color','$header-menu-bg-1',0,''),(353755,112802,'74328','watch','visibility_checkout','1',0,''),(353756,112802,'74328','watch','color','$header-menu-color-1',0,''),(353765,112805,'74331','watch','block_type','1',0,''),(353766,112805,'74331','watch','padding-top','20',0,''),(353767,112805,'74331','watch','padding-bottom','20',0,''),(353768,112805,'74331','watch','style_class','header-content',0,''),(353769,112805,'74331','watch','color','$header-color-1',0,''),(353770,112805,'74331','watch','background-color','$header-bg-1',0,''),(353802,112813,'74338','watch','block_type','1',0,''),(353803,112813,'74338','watch','border-bottom-width','1',0,''),(353804,112813,'74338','watch','border-bottom-color','$header-border-1',0,''),(353805,112813,'74338','watch','font-weight','normal',0,''),(353806,112813,'74338','watch','visibility_checkout','1',0,''),(353807,112813,'74338','watch','background-color','$header-bg-1',0,''),(353808,112813,'74338','watch','color','$header-color-1',0,''),(353847,112821,'74346','watch','block_type','1',0,''),(353848,112826,'74351','watch','width','680',0,''),(353849,112826,'74351','watch','font-weight','normal',0,''),(353850,112826,'74351','watch','font-size','12',0,''),(353851,112826,'74351','watch','padding-top','20',0,''),(353852,112826,'74351','watch','padding-bottom','20',0,''),(353853,112826,'74351','watch','color','$content-color-1',0,''),(353854,112827,'74352','watch','block_type','4',0,''),(353855,112827,'74352','watch','font-weight','normal',0,''),(353856,112827,'74352','watch','border-top-width','1',0,''),(353857,112827,'74352','watch','border-top-color','$content-border-1',0,''),(353858,112827,'74352','watch','border-left-width','1',0,''),(353859,112827,'74352','watch','border-left-color','$content-border-1',0,''),(353860,112827,'74352','watch','border-right-width','1',0,''),(353861,112827,'74352','watch','border-right-color','$content-border-1',0,''),(353862,112827,'74352','watch','border-bottom-width','1',0,''),(353863,112827,'74352','watch','border-bottom-color','$content-border-1',0,''),(353864,112828,'74353','watch','block_type','2',0,''),(353865,112828,'74353','watch','font-weight','normal',0,''),(353866,112828,'74353','watch','border-top-width','1',0,''),(353867,112828,'74353','watch','border-top-color','$content-border-1',0,''),(353868,112828,'74353','watch','border-right-width','1',0,''),(353869,112828,'74353','watch','border-right-color','$content-border-1',0,''),(353870,112829,'74354','watch','block_type','1',0,''),(353871,112829,'74354','watch','font-weight','normal',0,''),(353872,112829,'74354','watch','padding-top','10',0,''),(353873,112829,'74354','watch','padding-left','10',0,''),(353874,112829,'74354','watch','padding-right','10',0,''),(353875,112829,'74354','watch','padding-bottom','10',0,''),(353876,112829,'74354','watch','border-right-width','1',0,''),(353877,112829,'74354','watch','border-right-color','$content-border-1',0,''),(353878,112831,'74356','watch','text','<p>Shipping via</p>',1,''),(353879,112831,'74356','watch','font-weight','bold',0,''),(353880,112831,'74356','watch','font-size','14',0,''),(353881,112831,'74356','watch','text','<p>Shipping via</p>',2,''),(353882,112831,'74356','watch','text','<p>Shipping via</p>',3,''),(353883,112831,'74356','watch','text','<p>Shipping via</p>',4,''),(353884,112832,'74357','watch','block_type','1',0,''),(353885,112832,'74357','watch','font-weight','normal',0,''),(353886,112832,'74357','watch','padding-top','10',0,''),(353887,112832,'74357','watch','padding-left','10',0,''),(353888,112832,'74357','watch','padding-right','10',0,''),(353889,112832,'74357','watch','padding-bottom','10',0,''),(353890,112833,'74358','watch','text','<p>Shipping service</p>',1,''),(353891,112833,'74358','watch','font-weight','bold',0,''),(353892,112833,'74358','watch','font-size','14',0,''),(353893,112833,'74358','watch','text','<p>Shipping service</p>',2,''),(353894,112833,'74358','watch','text','<p>Shipping service</p>',3,''),(353895,112833,'74358','watch','text','<p>Shipping service</p>',4,''),(353896,112835,'74360','watch','block_type','2',0,''),(353897,112835,'74360','watch','font-weight','normal',0,''),(353898,112835,'74360','watch','border-right-width','1',0,''),(353899,112835,'74360','watch','border-right-color','$content-border-1',0,''),(353900,112836,'74361','watch','block_type','1',0,''),(353901,112836,'74361','watch','font-weight','400',0,''),(353902,112836,'74361','watch','background-color','$content-bg-2',0,''),(353903,112836,'74361','watch','padding-top','10',0,''),(353904,112836,'74361','watch','padding-left','10',0,''),(353905,112836,'74361','watch','padding-right','10',0,''),(353906,112836,'74361','watch','padding-bottom','30',0,''),(353907,112837,'74362','watch','text','<p>INVOICE ADDRESS:</p>',1,''),(353908,112837,'74362','watch','font-size','14',0,''),(353909,112837,'74362','watch','font-weight','bold',0,''),(353910,112837,'74362','watch','text','<p>INVOICE ADDRESS:</p>',2,''),(353911,112837,'74362','watch','text','<p>INVOICE ADDRESS:</p>',3,''),(353912,112837,'74362','watch','text','<p>INVOICE ADDRESS:</p>',4,''),(353913,112838,'74363','watch','font-size','12',0,''),(353914,112839,'74364','watch','block_type','1',0,''),(353915,112839,'74364','watch','font-weight','normal',0,''),(353916,112839,'74364','watch','padding-top','10',0,''),(353917,112839,'74364','watch','padding-left','10',0,''),(353918,112839,'74364','watch','padding-right','10',0,''),(353919,112839,'74364','watch','padding-bottom','10',0,''),(353920,112840,'74365','watch','text','<p>E-MAIL ADDRESS:</p>',1,''),(353921,112840,'74365','watch','font-weight','bold',0,''),(353922,112840,'74365','watch','font-size','14',0,''),(353923,112840,'74365','watch','padding-top','10',0,''),(353924,112840,'74365','watch','text','<p>E-MAIL ADDRESS:</p>',2,''),(353925,112840,'74365','watch','text','<p>E-MAIL ADDRESS:</p>',3,''),(353926,112840,'74365','watch','text','<p>E-MAIL ADDRESS:</p>',4,''),(353927,112841,'74366','watch','font-weight','normal',0,''),(353928,112842,'74367','watch','font-weight','normal',0,''),(353929,112843,'74368','watch','text','<p>CUSTOMER:</p>',1,''),(353930,112843,'74368','watch','font-size','13',0,''),(353931,112843,'74368','watch','font-weight','bold',0,''),(353932,112843,'74368','watch','text','<p>CUSTOMER:</p>',2,''),(353933,112843,'74368','watch','text','<p>CUSTOMER:</p>',3,''),(353934,112843,'74368','watch','text','<p>CUSTOMER:</p>',4,''),(353935,112844,'74369','watch','text','<p>PHONE NUMBER:</p>',1,''),(353936,112844,'74369','watch','font-size','14',0,''),(353937,112844,'74369','watch','font-weight','bold',0,''),(353938,112844,'74369','watch','padding-top','10',0,''),(353939,112844,'74369','watch','text','<p>PHONE NUMBER:</p>',2,''),(353940,112844,'74369','watch','text','<p>PHONE NUMBER:</p>',3,''),(353941,112844,'74369','watch','text','<p>PHONE NUMBER:</p>',4,''),(353942,112846,'74371','watch','font-weight','normal',0,''),(353943,112846,'74371','watch','text-align','center',0,''),(353944,112846,'74371','watch','padding-bottom','20',0,''),(353945,112847,'74372','watch','text','<p>Payment Method:</p>',1,''),(353946,112847,'74372','watch','font-weight','bold',0,''),(353947,112847,'74372','watch','text-align','center',0,''),(353948,112847,'74372','watch','text','<p>Payment Method:</p>',2,''),(353949,112847,'74372','watch','text','<p>Payment Method:</p>',3,''),(353950,112847,'74372','watch','text','<p>Payment Method:</p>',4,''),(353951,112848,'74373','watch','text','<p>Payment date:</p>',1,''),(353952,112848,'74373','watch','font-weight','bold',0,''),(353953,112848,'74373','watch','text-align','center',0,''),(353954,112848,'74373','watch','font-size','12',0,''),(353955,112848,'74373','watch','text','<p>Payment date:</p>',2,''),(353956,112848,'74373','watch','text','<p>Payment date:</p>',3,''),(353957,112848,'74373','watch','text','<p>Payment date:</p>',4,''),(353958,112849,'74374','watch','font-size','14',0,''),(353959,112849,'74374','watch','font-weight','bold',0,''),(353960,112849,'74374','watch','text-align','center',0,''),(353961,112849,'74374','watch','padding-bottom','10',0,''),(353962,112849,'74374','watch','padding-top','10',0,''),(353963,112850,'74375','watch','font-weight','normal',0,''),(353964,112850,'74375','watch','text-align','center',0,''),(353965,112850,'74375','watch','padding-bottom','10',0,''),(353966,112851,'74376','watch','font-weight','normal',0,''),(353967,112851,'74376','watch','text-align','center',0,''),(353968,112852,'74377','watch','block_type','3',0,''),(353969,112852,'74377','watch','font-weight','normal',0,''),(353970,112852,'74377','watch','padding-top','20',0,''),(353971,112853,'74378','watch','font-size','12',0,''),(353972,112854,'74379','watch','text','<p>If undelivered please return to:</p>',1,''),(353973,112854,'74379','watch','font-size','12',0,''),(353974,112854,'74379','watch','font-weight','bold',0,''),(353975,112854,'74379','watch','text','<p>If undelivered please return to:</p>',2,''),(353976,112854,'74379','watch','text','<p>If undelivered please return to:</p>',3,''),(353977,112854,'74379','watch','text','<p>If undelivered please return to:</p>',4,''),(353978,112855,'74380','watch','text','<p>Thank you for your order</p>',1,''),(353979,112855,'74380','watch','color','$color-8',0,''),(353980,112855,'74380','watch','font-size','13',0,''),(353981,112855,'74380','watch','font-weight','bold',0,''),(353982,112855,'74380','watch','padding-top','5',0,''),(353983,112855,'74380','watch','text-align','center',0,''),(353984,112855,'74380','watch','text','<p>Thank you for your order</p>',2,''),(353985,112855,'74380','watch','text','<p>Thank you for your order</p>',3,''),(353986,112855,'74380','watch','text','<p>Thank you for your order</p>',4,''),(353987,112856,'74381','watch','font-weight','400',0,''),(353988,112856,'74381','watch','text-align','center',0,''),(353989,112856,'74381','watch','padding-top','0',0,''),(353991,112856,'74381','watch','padding-left','20',0,''),(353992,112856,'74381','watch','padding-right','20',0,''),(353993,112856,'74381','watch','logo_from','theme',0,''),(353997,112857,'74382','watch','block_type','6',0,''),(353998,112857,'74382','watch','font-weight','normal',0,''),(353999,112857,'74382','watch','font-size','16',0,''),(354000,112858,'74383','watch','text','<p>Email:</p>',1,''),(354001,112858,'74383','watch','font-weight','normal',0,''),(354002,112858,'74383','watch','text-align','right',0,''),(354003,112858,'74383','watch','font-size','12',0,''),(354004,112858,'74383','watch','text','<p>Email:</p>',2,''),(354005,112858,'74383','watch','text','<p>Email:</p>',3,''),(354006,112858,'74383','watch','text','<p>Email:</p>',4,''),(354007,112859,'74384','watch','font-weight','normal',0,''),(354008,112859,'74384','watch','text-align','right',0,''),(354009,112859,'74384','watch','font-size','12',0,''),(354010,112860,'74385','watch','block_type','6',0,''),(354011,112860,'74385','watch','font-weight','normal',0,''),(354012,112860,'74385','watch','font-size','16',0,''),(354013,112861,'74386','watch','text','<p>Phone:</p>',1,''),(354014,112861,'74386','watch','font-weight','normal',0,''),(354015,112861,'74386','watch','text-align','right',0,''),(354016,112861,'74386','watch','font-size','12',0,''),(354017,112861,'74386','watch','text','<p>Phone:</p>',2,''),(354018,112861,'74386','watch','text','<p>Phone:</p>',3,''),(354019,112861,'74386','watch','text','<p>Phone:</p>',4,''),(354020,112862,'74387','watch','font-weight','normal',0,''),(354021,112862,'74387','watch','text-align','right',0,''),(354022,112862,'74387','watch','font-size','12',0,''),(354023,112863,'74388','watch','text','<p>If something has gone wrong please contact us at:</p>',1,''),(354024,112863,'74388','watch','font-size','12',0,''),(354025,112863,'74388','watch','font-weight','bold',0,''),(354026,112863,'74388','watch','text-align','right',0,''),(354027,112863,'74388','watch','text','<p>If something has gone wrong please contact us at:</p>',2,''),(354028,112863,'74388','watch','text','<p>If something has gone wrong please contact us at:</p>',3,''),(354029,112863,'74388','watch','text','<p>If something has gone wrong please contact us at:</p>',4,''),(354030,112864,'74389','watch','font-weight','400',0,''),(354031,112864,'74389','watch','padding-top','20',0,''),(354032,112864,'74389','watch','padding-bottom','0',0,''),(354033,112864,'74389','watch','font-size','12',0,''),(354034,112865,'74390','watch','block_type','5',0,''),(354035,112865,'74390','watch','font-weight','normal',0,''),(354036,112865,'74390','watch','border-bottom-width','1',0,''),(354037,112865,'74390','watch','border-bottom-color','$content-border-1',0,''),(354038,112865,'74390','watch','border-top-width','1',0,''),(354039,112865,'74390','watch','border-top-color','$content-border-1',0,''),(354040,112865,'74390','watch','border-left-color','$content-border-1',0,''),(354041,112865,'74390','watch','border-left-width','1',0,''),(354042,112866,'74391','watch','block_type','1',0,''),(354043,112866,'74391','watch','font-weight','normal',0,''),(354044,112866,'74391','watch','padding-top','10',0,''),(354045,112866,'74391','watch','padding-left','10',0,''),(354046,112866,'74391','watch','padding-right','10',0,''),(354047,112867,'74392','watch','font-weight','400',0,''),(354048,112867,'74392','watch','line-height','120',0,''),(354049,112867,'74392','watch','line_height_measure','%',0,''),(354050,112867,'74392','watch','font-size','12',0,''),(354051,112868,'74393','watch','text','<p>SHIPPING ADDRESS:</p>',1,''),(354052,112868,'74393','watch','font-size','14',0,''),(354053,112868,'74393','watch','font-weight','bold',0,''),(354054,112868,'74393','watch','padding-bottom','10',0,''),(354055,112868,'74393','watch','text','<p>SHIPPING ADDRESS:</p>',2,''),(354056,112868,'74393','watch','text','<p>SHIPPING ADDRESS:</p>',3,''),(354057,112868,'74393','watch','text','<p>SHIPPING ADDRESS:</p>',4,''),(354058,112869,'74394','watch','block_type','1',0,''),(354059,112869,'74394','watch','background-color','$content-bg-2',0,''),(354060,112869,'74394','watch','padding-top','20',0,''),(354061,112869,'74394','watch','padding-left','10',0,''),(354062,112869,'74394','watch','padding-right','10',0,''),(354063,112869,'74394','watch','padding-bottom','20',0,''),(354064,112869,'74394','watch','font-size','14',0,''),(354065,112870,'74395','watch','font-weight','normal',0,''),(354066,112870,'74395','watch','text-align','right',0,''),(354067,112870,'74395','watch','font-size','14',0,''),(354068,112870,'74395','watch','box_align','3',0,''),(354069,112871,'74396','watch','block_type','2',0,''),(354070,112871,'74396','watch','font-weight','normal',0,''),(354071,112871,'74396','watch','padding-bottom','20',0,''),(354072,112872,'74397','watch','font-weight','400',0,''),(354073,112872,'74397','watch','padding-top','20',0,''),(354075,112872,'74397','watch','logo_from','theme',0,''),(354079,112873,'74398','watch','block_type','11',0,''),(354080,112873,'74398','watch','font-weight','normal',0,''),(354081,112874,'74399','watch','text','<p>Web:</p>',1,''),(354082,112874,'74399','watch','font-weight','normal',0,''),(354083,112874,'74399','watch','text-align','right',0,''),(354084,112874,'74399','watch','text','<p>Web:</p>',2,''),(354085,112874,'74399','watch','text','<p>Web:</p>',3,''),(354086,112874,'74399','watch','text','<p>Web:</p>',4,''),(354087,112875,'74400','watch','font-weight','normal',0,''),(354088,112875,'74400','watch','text-align','right',0,''),(354089,112876,'74401','watch','block_type','11',0,''),(354090,112876,'74401','watch','font-weight','normal',0,''),(354091,112877,'74402','watch','text','<p>Email:</p>',1,''),(354092,112877,'74402','watch','font-weight','normal',0,''),(354093,112877,'74402','watch','text-align','right',0,''),(354094,112877,'74402','watch','text','<p>Email:</p>',2,''),(354095,112877,'74402','watch','text','<p>Email:</p>',3,''),(354096,112877,'74402','watch','text','<p>Email:</p>',4,''),(354097,112878,'74403','watch','font-weight','normal',0,''),(354098,112878,'74403','watch','text-align','right',0,''),(354099,112879,'74404','watch','block_type','1',0,''),(354100,112880,'74405','watch','font-weight','normal',0,''),(354101,112880,'74405','watch','text-align','right',0,''),(354102,112880,'74405','watch','padding-bottom','10',0,''),(354103,112880,'74405','watch','address_spacer',',',0,''),(354104,112880,'74405','watch','font-size','12',0,''),(354105,112881,'74406','watch','block_type','11',0,''),(354106,112881,'74406','watch','font-weight','normal',0,''),(354107,112882,'74407','watch','text','<p>Phone:</p>',1,''),(354108,112882,'74407','watch','font-weight','normal',0,''),(354109,112882,'74407','watch','text-align','right',0,''),(354110,112882,'74407','watch','text','<p>Phone:</p>',2,''),(354111,112882,'74407','watch','text','<p>Phone:</p>',3,''),(354112,112882,'74407','watch','text','<p>Phone:</p>',4,''),(354113,112883,'74408','watch','font-weight','normal',0,''),(354114,112883,'74408','watch','text-align','right',0,''),(354115,112884,'74409','watch','block_type','1',0,''),(354116,112884,'74409','watch','padding-top','20',0,''),(354117,112885,'74410','watch','tab_1','RETURNING CUSTOMER',1,''),(354118,112885,'74410','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(354119,112885,'74410','watch','tab_1','RETURNING CUSTOMER',2,''),(354120,112885,'74410','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(354121,112885,'74410','watch','tab_1','RETURNING CUSTOMER',3,''),(354122,112885,'74410','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(354123,112885,'74410','watch','tab_1','RETURNING CUSTOMER',4,''),(354124,112885,'74410','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(354125,112887,'74412','watch','block_type','8',0,''),(354126,112888,'74413','watch','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(354127,112889,'74414','watch','block_type','1',0,''),(354128,112889,'74414','watch','padding-left','20',0,''),(354129,112889,'74414','watch','padding-right','20',0,''),(354130,112890,'74415','watch','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(354131,112892,'74417','watch','block_type','1',0,''),(354132,112893,'74418','watch','text','##TEXT_OR##',0,''),(354133,112893,'74418','watch','font-size','18',0,''),(354134,112893,'74418','watch','font-weight','700',0,''),(354135,112893,'74418','watch','padding-top','15',0,''),(354136,112893,'74418','watch','text-align','center',0,''),(354137,112893,'74418','watch','content','\\_',0,'3'),(354138,112893,'74418','watch','height','5',0,'3'),(354139,112893,'74418','watch','width','70',0,'3'),(354140,112893,'74418','watch','display','inline-block',0,'3'),(354141,112893,'74418','watch','border-top-width','1',0,'3'),(354142,112893,'74418','watch','border-top-color','$content-border-1',0,'3'),(354143,112893,'74418','watch','margin-left','10',0,'3'),(354144,112893,'74418','watch','margin-right','10',0,'3'),(354145,112893,'74418','watch','content','\\_',0,'4'),(354146,112893,'74418','watch','display','inline-block',0,'4'),(354147,112893,'74418','watch','width','70',0,'4'),(354148,112893,'74418','watch','height','5',0,'4'),(354149,112893,'74418','watch','border-top-width','1',0,'4'),(354150,112893,'74418','watch','border-top-color','$content-border-1',0,'4'),(354151,112893,'74418','watch','margin-left','10',0,'4'),(354152,112893,'74418','watch','margin-right','10',0,'4'),(354153,112893,'74418','watch','position','relative',0,''),(354154,112893,'74418','watch','top','-10',0,''),(354155,112894,'74419','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354156,112894,'74419','watch','font-size','26',0,''),(354157,112894,'74419','watch','font-family','$font-1',0,''),(354158,112894,'74419','watch','padding-top','15',0,''),(354159,112894,'74419','watch','padding-bottom','15',0,''),(354160,112894,'74419','watch','text-align','center',0,''),(354161,112895,'74420','watch','text-align','center',0,''),(354162,112895,'74420','watch','hide_parents','2',0,''),(354163,112896,'74421','watch','block_type','1',0,''),(354164,112896,'74421','watch','padding-top','40',0,''),(354165,112896,'74421','watch','background-color','$content-bg-2',0,''),(354166,112896,'74421','watch','padding-bottom','40',0,''),(354167,112896,'74421','watch','style_class','checkout-login-wrap',0,''),(354168,112896,'74421','watch','color','$content-color-2',0,''),(354169,112897,'74422','watch','block_type','2',0,''),(354170,112897,'74422','watch','background-color','$content-bg-1',0,''),(354171,112897,'74422','watch','max-width','830',0,''),(354172,112897,'74422','watch','margin_left_measure','auto',0,''),(354173,112897,'74422','watch','margin_right_measure','auto',0,''),(354174,112897,'74422','watch','padding-top','40',0,''),(354175,112897,'74422','watch','padding-bottom','40',0,''),(354176,112897,'74422','watch','schema','2-3',0,'5240'),(354177,112897,'74422','watch','color','$content-color-1',0,''),(354178,112898,'74423','watch','text-align','center',0,''),(354179,112898,'74423','watch','margin-bottom','40',0,''),(354180,112899,'74424','watch','text-align','center',0,''),(354181,112900,'74425','watch','text','##TEXT_OR##',0,''),(354182,112900,'74425','watch','font-size','18',0,''),(354183,112900,'74425','watch','font-weight','700',0,''),(354184,112900,'74425','watch','text-align','center',0,''),(354185,112900,'74425','watch','content','\\_',0,'3'),(354186,112900,'74425','watch','height','5',0,'3'),(354187,112900,'74425','watch','width','70',0,'3'),(354188,112900,'74425','watch','display','inline-block',0,'3'),(354189,112900,'74425','watch','border-top-width','1',0,'3'),(354190,112900,'74425','watch','border-top-color','$content-border-1',0,'3'),(354191,112900,'74425','watch','margin-left','10',0,'3'),(354192,112900,'74425','watch','margin-right','10',0,'3'),(354193,112900,'74425','watch','content','\\_',0,'4'),(354194,112900,'74425','watch','display','inline-block',0,'4'),(354195,112900,'74425','watch','width','70',0,'4'),(354196,112900,'74425','watch','height','5',0,'4'),(354197,112900,'74425','watch','border-top-width','1',0,'4'),(354198,112900,'74425','watch','border-top-color','$content-border-1',0,'4'),(354199,112900,'74425','watch','margin-left','10',0,'4'),(354200,112900,'74425','watch','margin-right','10',0,'4'),(354201,112900,'74425','watch','position','relative',0,''),(354202,112900,'74425','watch','padding-top','10',0,''),(354203,112900,'74425','watch','padding-bottom','10',0,''),(354204,112901,'74426','watch','block_type','1',0,''),(354205,112902,'74427','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354206,112902,'74427','watch','font-size','18',0,''),(354207,112902,'74427','watch','font-family','$font-1',0,''),(354208,112902,'74427','watch','padding-top','15',0,''),(354209,112902,'74427','watch','padding-bottom','15',0,''),(354210,112902,'74427','watch','text-align','center',0,''),(354211,112902,'74427','watch','text-transform','uppercase',0,''),(354212,112903,'74428','watch','text-align','center',0,''),(354213,112903,'74428','watch','hide_parents','2',0,''),(354214,112904,'74429','watch','text','##NEW_CUSTOMER##',0,''),(354215,112904,'74429','watch','font-size','18',0,''),(354216,112904,'74429','watch','font-family','$font-1',0,''),(354217,112904,'74429','watch','text-align','center',0,''),(354218,112904,'74429','watch','text-transform','uppercase',0,''),(354219,112904,'74429','watch','margin-bottom','10',0,''),(354220,112905,'74430','watch','max-width','230',0,''),(354221,112905,'74430','watch','margin_left_measure','auto',0,''),(354222,112905,'74430','watch','margin_right_measure','auto',0,''),(354223,112906,'74431','watch','text','##RETURNING_CUSTOMER##',0,''),(354224,112906,'74431','watch','font-size','18',0,''),(354225,112906,'74431','watch','font-family','$font-1',0,''),(354226,112906,'74431','watch','text-transform','uppercase',0,''),(354227,112906,'74431','watch','text-align','center',0,''),(354228,112907,'74432','watch','block_type','1',0,''),(354229,112907,'74432','watch','padding-top','20',0,''),(354230,112908,'74433','watch','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(354231,112908,'74433','watch','tab_2','RETURNING CUSTOMER',1,''),(354232,112908,'74433','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(354233,112908,'74433','watch','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(354234,112908,'74433','watch','tab_2','RETURNING CUSTOMER',2,''),(354235,112908,'74433','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(354236,112908,'74433','watch','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(354237,112908,'74433','watch','tab_2','RETURNING CUSTOMER',3,''),(354238,112908,'74433','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(354239,112908,'74433','watch','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(354240,112908,'74433','watch','tab_2','RETURNING CUSTOMER',4,''),(354241,112908,'74433','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(354242,112909,'74434','watch','block_type','8',0,''),(354243,112910,'74435','watch','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(354244,112911,'74436','watch','block_type','1',0,''),(354245,112911,'74436','watch','padding-left','20',0,''),(354246,112911,'74436','watch','padding-right','20',0,''),(354247,112913,'74438','watch','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(354248,112913,'74438','watch','border-top-width','1',0,''),(354249,112913,'74438','watch','border-top-color','$content-border-1',0,''),(354250,112915,'74440','watch','block_type','8',0,''),(354251,112916,'74441','watch','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(354252,112917,'74442','watch','block_type','1',0,''),(354253,112917,'74442','watch','padding-left','20',0,''),(354254,112917,'74442','watch','padding-right','20',0,''),(354255,112918,'74443','watch','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(354256,112920,'74445','watch','text-align','center',0,''),(354257,112921,'74446','watch','text','##TEXT_OR##',0,''),(354258,112921,'74446','watch','font-size','18',0,''),(354259,112921,'74446','watch','font-weight','700',0,''),(354260,112921,'74446','watch','padding-top','15',0,''),(354261,112921,'74446','watch','text-align','center',0,''),(354262,112921,'74446','watch','content','\\_',0,'3'),(354263,112921,'74446','watch','height','5',0,'3'),(354264,112921,'74446','watch','width','70',0,'3'),(354265,112921,'74446','watch','display','inline-block',0,'3'),(354266,112921,'74446','watch','border-top-width','1',0,'3'),(354267,112921,'74446','watch','border-top-color','$content-border-1',0,'3'),(354268,112921,'74446','watch','margin-left','10',0,'3'),(354269,112921,'74446','watch','margin-right','10',0,'3'),(354270,112921,'74446','watch','content','\\_',0,'4'),(354271,112921,'74446','watch','display','inline-block',0,'4'),(354272,112921,'74446','watch','width','70',0,'4'),(354273,112921,'74446','watch','height','5',0,'4'),(354274,112921,'74446','watch','border-top-width','1',0,'4'),(354275,112921,'74446','watch','border-top-color','$content-border-1',0,'4'),(354276,112921,'74446','watch','margin-left','10',0,'4'),(354277,112921,'74446','watch','margin-right','10',0,'4'),(354278,112921,'74446','watch','position','relative',0,''),(354279,112921,'74446','watch','top','-10',0,''),(354280,112922,'74447','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354281,112922,'74447','watch','font-size','26',0,''),(354282,112922,'74447','watch','font-family','$font-1',0,''),(354283,112922,'74447','watch','padding-top','15',0,''),(354284,112922,'74447','watch','padding-bottom','15',0,''),(354285,112922,'74447','watch','text-align','center',0,''),(354286,112923,'74448','watch','block_type','1',0,''),(354287,112923,'74448','watch','padding-top','20',0,''),(354288,112924,'74449','watch','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(354289,112924,'74449','watch','tab_2','RETURNING CUSTOMER',1,''),(354290,112924,'74449','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(354291,112924,'74449','watch','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(354292,112924,'74449','watch','tab_2','RETURNING CUSTOMER',2,''),(354293,112924,'74449','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(354294,112924,'74449','watch','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(354295,112924,'74449','watch','tab_2','RETURNING CUSTOMER',3,''),(354296,112924,'74449','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(354297,112924,'74449','watch','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(354298,112924,'74449','watch','tab_2','RETURNING CUSTOMER',4,''),(354299,112924,'74449','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(354300,112925,'74450','watch','block_type','8',0,''),(354301,112926,'74451','watch','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(354302,112929,'74454','watch','block_type','8',0,''),(354303,112930,'74455','watch','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(354304,112932,'74457','watch','block_type','1',0,''),(354305,112932,'74457','watch','padding-left','20',0,''),(354306,112932,'74457','watch','padding-right','20',0,''),(354307,112934,'74459','watch','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(354308,112935,'74460','watch','text','##TEXT_OR##',0,''),(354309,112935,'74460','watch','font-size','18',0,''),(354310,112935,'74460','watch','font-weight','700',0,''),(354311,112935,'74460','watch','padding-top','15',0,''),(354312,112935,'74460','watch','text-align','center',0,''),(354313,112935,'74460','watch','content','\\_',0,'3'),(354314,112935,'74460','watch','height','5',0,'3'),(354315,112935,'74460','watch','width','70',0,'3'),(354316,112935,'74460','watch','display','inline-block',0,'3'),(354317,112935,'74460','watch','border-top-width','1',0,'3'),(354318,112935,'74460','watch','border-top-color','$content-border-1',0,'3'),(354319,112935,'74460','watch','margin-left','10',0,'3'),(354320,112935,'74460','watch','margin-right','10',0,'3'),(354321,112935,'74460','watch','content','\\_',0,'4'),(354322,112935,'74460','watch','display','inline-block',0,'4'),(354323,112935,'74460','watch','width','70',0,'4'),(354324,112935,'74460','watch','height','5',0,'4'),(354325,112935,'74460','watch','border-top-width','1',0,'4'),(354326,112935,'74460','watch','border-top-color','$content-border-1',0,'4'),(354327,112935,'74460','watch','margin-left','10',0,'4'),(354328,112935,'74460','watch','margin-right','10',0,'4'),(354329,112935,'74460','watch','position','relative',0,''),(354330,112935,'74460','watch','top','-10',0,''),(354331,112936,'74461','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354332,112936,'74461','watch','font-size','26',0,''),(354333,112936,'74461','watch','font-family','$font-1',0,''),(354334,112936,'74461','watch','padding-top','15',0,''),(354335,112936,'74461','watch','padding-bottom','15',0,''),(354336,112936,'74461','watch','text-align','center',0,''),(354337,112937,'74462','watch','text-align','center',0,''),(354338,112938,'74463','watch','block_type','1',0,''),(354339,112938,'74463','watch','padding-top','20',0,''),(354340,112939,'74464','watch','text-align','center',0,''),(354341,112940,'74465','watch','text','##TEXT_OR##',0,''),(354342,112940,'74465','watch','font-size','18',0,''),(354343,112940,'74465','watch','font-weight','700',0,''),(354344,112940,'74465','watch','padding-top','15',0,''),(354345,112940,'74465','watch','text-align','center',0,''),(354346,112940,'74465','watch','content','\\_',0,'3'),(354347,112940,'74465','watch','height','5',0,'3'),(354348,112940,'74465','watch','width','70',0,'3'),(354349,112940,'74465','watch','display','inline-block',0,'3'),(354350,112940,'74465','watch','border-top-width','1',0,'3'),(354351,112940,'74465','watch','border-top-color','$content-border-1',0,'3'),(354352,112940,'74465','watch','margin-left','10',0,'3'),(354353,112940,'74465','watch','margin-right','10',0,'3'),(354354,112940,'74465','watch','content','\\_',0,'4'),(354355,112940,'74465','watch','display','inline-block',0,'4'),(354356,112940,'74465','watch','width','70',0,'4'),(354357,112940,'74465','watch','height','5',0,'4'),(354358,112940,'74465','watch','border-top-width','1',0,'4'),(354359,112940,'74465','watch','border-top-color','$content-border-1',0,'4'),(354360,112940,'74465','watch','margin-left','10',0,'4'),(354361,112940,'74465','watch','margin-right','10',0,'4'),(354362,112940,'74465','watch','position','relative',0,''),(354363,112940,'74465','watch','top','-10',0,''),(354364,112941,'74466','watch','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(354365,112941,'74466','watch','tab_2','RETURNING CUSTOMER',1,''),(354366,112941,'74466','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(354367,112941,'74466','watch','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(354368,112941,'74466','watch','tab_2','RETURNING CUSTOMER',2,''),(354369,112941,'74466','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(354370,112941,'74466','watch','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(354371,112941,'74466','watch','tab_2','RETURNING CUSTOMER',3,''),(354372,112941,'74466','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(354373,112941,'74466','watch','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(354374,112941,'74466','watch','tab_2','RETURNING CUSTOMER',4,''),(354375,112941,'74466','watch','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(354376,112942,'74467','watch','block_type','8',0,''),(354377,112943,'74468','watch','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(354378,112946,'74471','watch','block_type','8',0,''),(354379,112947,'74472','watch','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(354380,112948,'74473','watch','block_type','1',0,''),(354381,112948,'74473','watch','padding-left','20',0,''),(354382,112948,'74473','watch','padding-right','20',0,''),(354383,112950,'74475','watch','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(354384,112951,'74476','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354385,112951,'74476','watch','font-size','26',0,''),(354386,112951,'74476','watch','font-family','$font-1',0,''),(354387,112951,'74476','watch','padding-top','15',0,''),(354388,112951,'74476','watch','padding-bottom','15',0,''),(354389,112951,'74476','watch','text-align','center',0,''),(354390,112952,'74477','watch','block_type','1',0,''),(354391,112952,'74477','watch','padding-top','40',0,''),(354392,112952,'74477','watch','background-color','$content-bg-2',0,''),(354393,112952,'74477','watch','padding-bottom','40',0,''),(354394,112953,'74478','watch','block_type','2',0,''),(354395,112953,'74478','watch','background-color','$content-bg-1',0,''),(354396,112953,'74478','watch','max-width','830',0,''),(354397,112953,'74478','watch','margin_left_measure','auto',0,''),(354398,112953,'74478','watch','margin_right_measure','auto',0,''),(354399,112953,'74478','watch','padding-top','40',0,''),(354400,112953,'74478','watch','padding-bottom','40',0,''),(354401,112954,'74479','watch','block_type','1',0,''),(354402,112955,'74480','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354403,112955,'74480','watch','font-size','18',0,''),(354404,112955,'74480','watch','font-family','$font-1',0,''),(354405,112955,'74480','watch','padding-top','15',0,''),(354406,112955,'74480','watch','padding-bottom','15',0,''),(354407,112955,'74480','watch','text-align','center',0,''),(354408,112955,'74480','watch','text-transform','uppercase',0,''),(354409,112956,'74481','watch','text-align','center',0,''),(354410,112956,'74481','watch','hide_parents','2',0,''),(354411,112957,'74482','watch','text-align','center',0,''),(354412,112958,'74483','watch','text-align','center',0,''),(354413,112958,'74483','watch','margin-bottom','40',0,''),(354414,112959,'74484','watch','text','##TEXT_OR##',0,''),(354415,112959,'74484','watch','font-size','18',0,''),(354416,112959,'74484','watch','font-weight','700',0,''),(354417,112959,'74484','watch','text-align','center',0,''),(354418,112959,'74484','watch','content','\\_',0,'3'),(354419,112959,'74484','watch','height','5',0,'3'),(354420,112959,'74484','watch','width','70',0,'3'),(354421,112959,'74484','watch','display','inline-block',0,'3'),(354422,112959,'74484','watch','border-top-width','1',0,'3'),(354423,112959,'74484','watch','border-top-color','$content-border-1',0,'3'),(354424,112959,'74484','watch','margin-left','10',0,'3'),(354425,112959,'74484','watch','margin-right','10',0,'3'),(354426,112959,'74484','watch','content','\\_',0,'4'),(354427,112959,'74484','watch','display','inline-block',0,'4'),(354428,112959,'74484','watch','width','70',0,'4'),(354429,112959,'74484','watch','height','5',0,'4'),(354430,112959,'74484','watch','border-top-width','1',0,'4'),(354431,112959,'74484','watch','border-top-color','$content-border-1',0,'4'),(354432,112959,'74484','watch','margin-left','10',0,'4'),(354433,112959,'74484','watch','margin-right','10',0,'4'),(354434,112959,'74484','watch','position','relative',0,''),(354435,112959,'74484','watch','padding-top','10',0,''),(354436,112959,'74484','watch','padding-bottom','10',0,''),(354437,112960,'74485','watch','text','##NEW_CUSTOMER##',0,''),(354438,112960,'74485','watch','font-size','18',0,''),(354439,112960,'74485','watch','font-family','$font-1',0,''),(354440,112960,'74485','watch','text-align','center',0,''),(354441,112960,'74485','watch','text-transform','uppercase',0,''),(354442,112960,'74485','watch','margin-bottom','10',0,''),(354443,112961,'74486','watch','text','##RETURNING_CUSTOMER##',0,''),(354444,112961,'74486','watch','font-size','18',0,''),(354445,112961,'74486','watch','font-family','$font-1',0,''),(354446,112961,'74486','watch','text-transform','uppercase',0,''),(354447,112961,'74486','watch','text-align','center',0,''),(354448,112962,'74487','watch','max-width','230',0,''),(354449,112962,'74487','watch','margin_left_measure','auto',0,''),(354450,112962,'74487','watch','margin_right_measure','auto',0,''),(354451,112963,'74488','watch','block_type','1',0,''),(354452,112963,'74488','watch','padding-top','40',0,''),(354453,112963,'74488','watch','background-color','$content-bg-2',0,''),(354454,112963,'74488','watch','padding-bottom','40',0,''),(354455,112964,'74489','watch','block_type','2',0,''),(354456,112964,'74489','watch','background-color','$content-bg-1',0,''),(354457,112964,'74489','watch','max-width','830',0,''),(354458,112964,'74489','watch','margin_left_measure','auto',0,''),(354459,112964,'74489','watch','margin_right_measure','auto',0,''),(354460,112964,'74489','watch','padding-top','40',0,''),(354461,112964,'74489','watch','padding-bottom','40',0,''),(354462,112965,'74490','watch','text','##NEW_CUSTOMER##',0,''),(354463,112965,'74490','watch','font-size','18',0,''),(354464,112965,'74490','watch','font-family','$font-1',0,''),(354465,112965,'74490','watch','text-align','center',0,''),(354466,112965,'74490','watch','text-transform','uppercase',0,''),(354467,112965,'74490','watch','margin-bottom','10',0,''),(354468,112966,'74491','watch','text-align','center',0,''),(354469,112967,'74492','watch','text-align','center',0,''),(354470,112967,'74492','watch','margin-bottom','40',0,''),(354471,112968,'74493','watch','text','##TEXT_OR##',0,''),(354472,112968,'74493','watch','font-size','18',0,''),(354473,112968,'74493','watch','font-weight','700',0,''),(354474,112968,'74493','watch','text-align','center',0,''),(354475,112968,'74493','watch','content','\\_',0,'3'),(354476,112968,'74493','watch','height','5',0,'3'),(354477,112968,'74493','watch','width','70',0,'3'),(354478,112968,'74493','watch','display','inline-block',0,'3'),(354479,112968,'74493','watch','border-top-width','1',0,'3'),(354480,112968,'74493','watch','border-top-color','$content-border-1',0,'3'),(354481,112968,'74493','watch','margin-left','10',0,'3'),(354482,112968,'74493','watch','margin-right','10',0,'3'),(354483,112968,'74493','watch','content','\\_',0,'4'),(354484,112968,'74493','watch','display','inline-block',0,'4'),(354485,112968,'74493','watch','width','70',0,'4'),(354486,112968,'74493','watch','height','5',0,'4'),(354487,112968,'74493','watch','border-top-width','1',0,'4'),(354488,112968,'74493','watch','border-top-color','$content-border-1',0,'4'),(354489,112968,'74493','watch','margin-left','10',0,'4'),(354490,112968,'74493','watch','margin-right','10',0,'4'),(354491,112968,'74493','watch','position','relative',0,''),(354492,112968,'74493','watch','padding-top','10',0,''),(354493,112968,'74493','watch','padding-bottom','10',0,''),(354494,112969,'74494','watch','block_type','1',0,''),(354495,112970,'74495','watch','text','##LOGIN_WITH_SOCIAL##',0,''),(354496,112970,'74495','watch','font-size','18',0,''),(354497,112970,'74495','watch','font-family','$font-1',0,''),(354498,112970,'74495','watch','padding-top','15',0,''),(354499,112970,'74495','watch','padding-bottom','15',0,''),(354500,112970,'74495','watch','text-align','center',0,''),(354501,112970,'74495','watch','text-transform','uppercase',0,''),(354502,112971,'74496','watch','text-align','center',0,''),(354503,112971,'74496','watch','hide_parents','2',0,''),(354504,112972,'74497','watch','text','##RETURNING_CUSTOMER##',0,''),(354505,112972,'74497','watch','font-size','18',0,''),(354506,112972,'74497','watch','font-family','$font-1',0,''),(354507,112972,'74497','watch','text-transform','uppercase',0,''),(354508,112972,'74497','watch','text-align','center',0,''),(354509,112973,'74498','watch','max-width','230',0,''),(354510,112973,'74498','watch','margin_left_measure','auto',0,''),(354511,112973,'74498','watch','margin_right_measure','auto',0,''),(354512,112974,'74499','watch','block_type','1',0,''),(354513,112975,'74500','watch','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(354514,112975,'74500','watch','margin-bottom','30',0,''),(354515,112976,'74501','watch','block_type','1',0,''),(354516,112977,'74502','watch','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(354517,112977,'74502','watch','margin-bottom','30',0,''),(354518,112978,'74503','watch','block_type','1',0,''),(354519,112978,'74503','watch','background-color','$best-sellers-bg-1',0,''),(354520,112978,'74503','watch','padding-top','20',0,''),(354521,112978,'74503','watch','padding-bottom','20',0,''),(354522,112978,'74503','watch','font-weight','400',0,''),(354523,112978,'74503','watch','visibility_product','1',0,''),(354524,112978,'74503','watch','visibility_catalog','1',0,''),(354525,112978,'74503','watch','visibility_info','1',0,''),(354526,112978,'74503','watch','visibility_cart','1',0,''),(354527,112978,'74503','watch','visibility_checkout','1',0,''),(354528,112978,'74503','watch','visibility_success','1',0,''),(354529,112978,'74503','watch','visibility_account','1',0,''),(354530,112978,'74503','watch','visibility_login','1',0,''),(354531,112978,'74503','watch','visibility_other','1',0,''),(354532,112978,'74503','watch','margin-bottom','20',0,''),(354533,112978,'74503','watch','display_none','on',0,'5240'),(354534,112979,'74504','watch','block_type','2',0,''),(354535,112979,'74504','watch','font-weight','normal',0,''),(354536,112980,'74505','watch','font-weight','400',0,''),(354537,112980,'74505','watch','visibility_product','1',0,''),(354538,112980,'74505','watch','show_name','0',0,''),(354539,112980,'74505','watch','show_stock','1',0,''),(354540,112980,'74505','watch','show_description','1',0,''),(354541,112980,'74505','watch','show_model','1',0,''),(354542,112980,'74505','watch','show_rating','1',0,''),(354543,112980,'74505','watch','show_rating_counts','1',0,''),(354544,112980,'74505','watch','show_qty_input','1',0,''),(354545,112980,'74505','watch','show_view_button','1',0,''),(354546,112980,'74505','watch','show_wishlist_button','1',0,''),(354547,112980,'74505','watch','show_compare','1',0,''),(354548,112980,'74505','watch','listing_type','productListing',0,''),(354549,112980,'74505','watch','show_properties','1',0,''),(354550,112980,'74505','watch','col_in_row','2',0,''),(354551,112980,'74505','watch','show_bonus_points','1',0,''),(354552,112980,'74505','watch','show_buy_button','1',0,''),(354553,112980,'74505','watch','show_attributes','1',0,''),(354554,112981,'74506','watch','font-weight','normal',0,''),(354555,112981,'74506','watch','visibility_product','1',0,''),(354556,112982,'74507','watch','font-weight','400',0,''),(354557,112982,'74507','watch','visibility_product','1',0,''),(354558,112982,'74507','watch','visibility_catalog','1',0,''),(354559,112982,'74507','watch','visibility_info','1',0,''),(354560,112982,'74507','watch','visibility_cart','1',0,''),(354561,112982,'74507','watch','visibility_checkout','1',0,''),(354562,112982,'74507','watch','visibility_success','1',0,''),(354563,112982,'74507','watch','visibility_account','1',0,''),(354564,112982,'74507','watch','visibility_login','1',0,''),(354565,112982,'74507','watch','visibility_other','1',0,''),(354566,112982,'74507','watch','banners_group','home',0,''),(354567,112982,'74507','watch','banners_type','single',0,''),(354569,112982,'74507','watch','template','1',0,''),(354570,112982,'74507','watch','ban_id','41',0,''),(354571,112983,'74508','watch','block_type','1',0,''),(354572,112983,'74508','watch','font-weight','normal',0,''),(354573,112984,'74510','watch','tab_1','##NEW_PRODUCTS##',0,''),(354574,112984,'74510','watch','tab_2','##SPECIALS_PRODUCTS##',0,''),(354575,112984,'74510','watch','tab_3','##FEATURED_PRODUCTS##',0,''),(354576,112985,'74511','watch','col_in_row','4',0,''),(354577,112985,'74511','watch','view_as','carousel',0,''),(354578,112985,'74511','watch','show_attributes','1',0,''),(354579,112985,'74511','watch','col_in_row','3',0,'5240'),(354580,112985,'74511','watch','col_in_row','2',0,'5232'),(354581,112985,'74511','watch','col_in_row','1',0,'5261'),(354582,112985,'74511','watch','listing_type','productListing',0,''),(354583,112985,'74511','watch','show_qty_input','1',0,''),(354584,112985,'74511','watch','show_compare','1',0,''),(354585,112985,'74511','watch','lazy_load','1',0,''),(354586,112986,'74512','watch','font-weight','400',0,''),(354587,112986,'74512','watch','show_compare','1',0,''),(354588,112986,'74512','watch','listing_type','productListing',0,''),(354589,112986,'74512','watch','show_model','1',0,''),(354590,112986,'74512','watch','show_properties','1',0,''),(354591,112986,'74512','watch','col_in_row','4',0,''),(354592,112986,'74512','watch','show_name','0',0,''),(354593,112986,'74512','watch','show_image','0',0,''),(354594,112986,'74512','watch','show_stock','0',0,''),(354595,112986,'74512','watch','show_description','0',0,''),(354596,112986,'74512','watch','show_rating','0',0,''),(354597,112986,'74512','watch','show_rating_counts','0',0,''),(354598,112986,'74512','watch','show_price','0',0,''),(354599,112986,'74512','watch','show_buy_button','0',0,''),(354600,112986,'74512','watch','show_qty_input','0',0,''),(354601,112986,'74512','watch','show_view_button','0',0,''),(354602,112986,'74512','watch','show_wishlist_button','0',0,''),(354603,112986,'74512','watch','col_in_row','2',0,'5240'),(354604,112986,'74512','watch','col_in_row','1',0,'5261'),(354605,112986,'74512','watch','view_as','carousel',0,''),(354606,112986,'74512','watch','product_names_teg','h2',0,''),(354607,112986,'74512','watch','show_attributes','1',0,''),(354608,112987,'74513','watch','font-weight','400',0,''),(354609,112987,'74513','watch','listing_type','productListing',0,''),(354610,112987,'74513','watch','col_in_row','4',0,''),(354611,112987,'74513','watch','show_image','0',0,''),(354612,112987,'74513','watch','show_stock','0',0,''),(354613,112987,'74513','watch','show_description','0',0,''),(354614,112987,'74513','watch','show_rating','0',0,''),(354615,112987,'74513','watch','show_rating_counts','0',0,''),(354616,112987,'74513','watch','show_price','0',0,''),(354617,112987,'74513','watch','show_buy_button','0',0,''),(354618,112987,'74513','watch','show_qty_input','0',0,''),(354619,112987,'74513','watch','show_view_button','0',0,''),(354620,112987,'74513','watch','show_wishlist_button','0',0,''),(354621,112987,'74513','watch','col_in_row','2',0,'5240'),(354622,112987,'74513','watch','col_in_row','1',0,'5261'),(354623,112987,'74513','watch','view_as','carousel',0,''),(354624,112987,'74513','watch','col_in_row','2',0,'5232'),(354625,112987,'74513','watch','featured_type_id','0',0,''),(354626,112989,'1708695037.0808','watch','form_name','test',0,''),(354627,112990,'74515','watch','heading_type','h1',0,''),(354628,112992,'74516','watch','block_type','1',0,''),(354629,112993,'74517','watch','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(354630,112995,'74519','watch','block_type','1',0,''),(354631,112995,'74519','watch','padding-top','40',0,''),(354632,112995,'74519','watch','padding-bottom','80',0,''),(354633,112996,'74520','watch','block_type','6',0,''),(354634,112997,'74521','watch','block_type','1',0,''),(354635,112997,'74521','watch','padding-top','20',0,''),(354636,112997,'74521','watch','padding-left','20',0,''),(354637,112997,'74521','watch','padding-right','20',0,''),(354638,112997,'74521','watch','padding-bottom','20',0,''),(354639,112997,'74521','watch','border-top-width','1',0,''),(354640,112997,'74521','watch','border-left-width','1',0,''),(354641,112997,'74521','watch','border-right-width','1',0,''),(354642,112997,'74521','watch','border-bottom-width','1',0,''),(354643,112997,'74521','watch','border-top-color','$content-border-1',0,''),(354644,112997,'74521','watch','border-left-color','$content-border-1',0,''),(354645,112997,'74521','watch','border-right-color','$content-border-1',0,''),(354646,112997,'74521','watch','border-bottom-color','$content-border-1',0,''),(354647,112997,'74521','watch','margin-right','20',0,''),(354648,113000,'74524','watch','block_type','1',0,''),(354649,113000,'74524','watch','padding-top','20',0,''),(354650,113001,'74525','watch','block_type','6',0,''),(354651,113002,'74526','watch','padding-right','20',0,''),(354652,113004,'74528','watch','block_type','1',0,''),(354653,113004,'74528','watch','padding-top','20',0,''),(354654,113005,'74529','watch','block_type','6',0,''),(354655,113006,'74530','watch','padding-right','20',0,''),(354656,113008,'74532','watch','block_type','1',0,''),(354657,113008,'74532','watch','style_class','account-password-wrap',0,''),(354658,113009,'74533','watch','block_type','6',0,''),(354659,113009,'74533','watch','schema','6-3',0,'5240'),(354660,113010,'74534','watch','aria_name','account-menu',0,''),(354718,113031,'74536','watch','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(354719,113032,'74537','watch','block_type','1',0,''),(354720,113032,'74537','watch','padding-top','20',0,''),(354721,113033,'74538','watch','tab_1','RETURNING CUSTOMER',1,''),(354722,113033,'74538','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(354723,113033,'74538','watch','tab_1','RETURNING CUSTOMER',2,''),(354724,113033,'74538','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(354725,113033,'74538','watch','tab_1','RETURNING CUSTOMER',3,''),(354726,113033,'74538','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(354727,113033,'74538','watch','tab_1','RETURNING CUSTOMER',4,''),(354728,113033,'74538','watch','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(354729,113035,'74540','watch','block_type','8',0,''),(354730,113036,'74541','watch','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(354731,113037,'74542','watch','block_type','1',0,''),(354732,113037,'74542','watch','padding-left','20',0,''),(354733,113037,'74542','watch','padding-right','20',0,''),(354734,113039,'74544','watch','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(354735,113040,'74545','watch','block_type','1',0,''),(354736,113041,'74546','watch','block_type','1',0,''),(354737,113042,'74547','watch','margin_left_measure','auto',0,''),(354738,113042,'74547','watch','margin_right_measure','auto',0,''),(354739,113042,'74547','watch','max-width','560',0,''),(354740,113043,'74548','watch','margin-bottom','30',0,''),(354741,113044,'74549','watch','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(354742,113045,'94779','watch','block_type','1',0,''),(354743,113047,'94781','watch','block_type','6',0,''),(354744,113047,'94781','watch','font-weight','400',0,''),(354745,113047,'94781','watch','schema','6-2',0,'5261'),(354746,113047,'94781','watch','schema','6-2',0,'5240'),(354747,113048,'94782','watch','font-weight','400',0,''),(354748,113048,'94782','watch','padding-right','40',0,''),(354749,113048,'94782','watch','padding-right','0',0,'5261'),(354750,113048,'94782','watch','padding-right','0',0,'5240'),(354751,113049,'94783','watch','col_in_row','3',0,''),(354752,113049,'94783','watch','products_align','left',0,''),(354753,113049,'94783','watch','font-weight','400',0,''),(354754,113049,'94783','watch','show_qty_input','0',0,''),(354755,113049,'94783','watch','listing_type','productListing',0,''),(354756,113049,'94783','watch','listing_type_rows','no',0,''),(354757,113049,'94783','watch','show_buy_button_b2b','on',0,''),(354758,113049,'94783','watch','show_wishlist_button_b2b','1',0,''),(354759,113049,'94783','watch','show_compare_b2b','1',0,''),(354760,113049,'94783','watch','show_stock','0',0,''),(354761,113049,'94783','watch','show_description','0',0,''),(354762,113049,'94783','watch','show_model','0',0,''),(354763,113049,'94783','watch','show_properties','0',0,''),(354764,113049,'94783','watch','show_rating','0',0,''),(354765,113049,'94783','watch','show_rating_counts','0',0,''),(354766,113049,'94783','watch','show_price','0',0,''),(354767,113049,'94783','watch','show_buy_button','0',0,''),(354768,113049,'94783','watch','show_view_button','0',0,''),(354769,113049,'94783','watch','show_wishlist_button','0',0,''),(354770,113049,'94783','watch','show_compare','0',0,''),(354771,113049,'94783','watch','show_name_rows','0',0,''),(354772,113049,'94783','watch','show_image_rows','0',0,''),(354773,113049,'94783','watch','show_stock_rows','0',0,''),(354774,113049,'94783','watch','show_description_rows','0',0,''),(354775,113049,'94783','watch','show_model_rows','0',0,''),(354776,113049,'94783','watch','show_properties_rows','0',0,''),(354777,113049,'94783','watch','show_rating_rows','0',0,''),(354778,113049,'94783','watch','show_rating_counts_rows','0',0,''),(354779,113049,'94783','watch','show_price_rows','0',0,''),(354780,113049,'94783','watch','show_buy_button_rows','0',0,''),(354781,113049,'94783','watch','show_qty_input_rows','0',0,''),(354782,113049,'94783','watch','show_view_button_rows','0',0,''),(354783,113049,'94783','watch','show_wishlist_button_rows','0',0,''),(354784,113049,'94783','watch','show_compare_rows','0',0,''),(354785,113049,'94783','watch','show_name_b2b','0',0,''),(354786,113049,'94783','watch','show_image_b2b','0',0,''),(354787,113049,'94783','watch','show_stock_b2b','0',0,''),(354788,113049,'94783','watch','show_description_b2b','0',0,''),(354789,113049,'94783','watch','show_model_b2b','0',0,''),(354790,113049,'94783','watch','show_properties_b2b','0',0,''),(354791,113049,'94783','watch','show_rating_b2b','0',0,''),(354792,113049,'94783','watch','show_rating_counts_b2b','0',0,''),(354793,113049,'94783','watch','show_price_b2b','0',0,''),(354794,113049,'94783','watch','show_qty_input_b2b','0',0,''),(354795,113049,'94783','watch','show_view_button_b2b','0',0,''),(354796,113049,'94783','watch','show_attributes_b2b','0',0,''),(354797,113049,'94783','watch','items_on_page','9',0,''),(354798,113049,'94783','watch','col_in_row','2',0,'5240'),(354799,113049,'94783','watch','col_in_row','1',0,'5261'),(354800,113049,'94783','watch','product_names_teg','h2',0,''),(354801,113051,'94785','watch','block_type','5',0,''),(354802,113051,'94785','watch','padding-top','10',0,''),(354803,113051,'94785','watch','padding-bottom','10',0,''),(354804,113051,'94785','watch','schema','5-2',0,'5261'),(354805,113051,'94785','watch','border-top-color','$content-border-1',0,''),(354806,113051,'94785','watch','border-top-width','1',0,''),(354807,113053,'94787','watch','float','right',0,''),(354808,113054,'94788','watch','listing_type','productListing',0,''),(354809,113056,'94790','watch','block_type','1',0,''),(354810,113056,'94790','watch','padding-top','10',0,''),(354811,113056,'94790','watch','padding-bottom','10',0,''),(354812,113056,'94790','watch','border-bottom-width','1',0,''),(354813,113056,'94790','watch','border-bottom-color','$content-border-1',0,''),(354814,113056,'94790','watch','margin-left','0',0,''),(354815,113056,'94790','watch','margin-right','0',0,''),(354816,113057,'94791','watch','float','right',0,''),(354817,113057,'94791','watch','display','none',0,'5261'),(354818,113058,'94792','watch','float','left',0,''),(354819,113058,'94792','watch','clear','none',0,''),(354820,113058,'94792','watch','margin-left','20',0,''),(354821,113058,'94792','watch','display','none',0,'5261'),(354822,113059,'94793','watch','margin-right','20',0,''),(354823,113059,'94793','watch','float','right',0,''),(354824,113059,'94793','watch','clear','none',0,''),(354825,113059,'94793','watch','display','none',0,'5240'),(354826,113060,'94794','watch','float','left',0,''),(354827,113060,'94794','watch','clear','none',0,''),(354828,113060,'94794','watch','sort_pos_3','1',0,''),(354829,113060,'94794','watch','sort_pos_4','2',0,''),(354830,113060,'94794','watch','sort_pos_10','3',0,''),(354831,113060,'94794','watch','sort_pos_9','4',0,''),(354832,113060,'94794','watch','sort_pos_11','5',0,''),(354833,113060,'94794','watch','sort_pos_12','6',0,''),(354834,113060,'94794','watch','sort_pos_14','7',0,''),(354835,113060,'94794','watch','sort_pos_13','8',0,''),(354836,113060,'94794','watch','sort_pos_8','9',0,''),(354837,113060,'94794','watch','sort_pos_7','10',0,''),(354838,113060,'94794','watch','sort_pos_2','11',0,''),(354839,113060,'94794','watch','sort_pos_1','12',0,''),(354840,113060,'94794','watch','sort_pos_6','13',0,''),(354841,113060,'94794','watch','sort_pos_5','14',0,''),(354842,113060,'94794','watch','sort_pos_0','15',0,''),(354843,113060,'94794','watch','sort_hide_10','1',0,''),(354844,113060,'94794','watch','sort_hide_9','1',0,''),(354845,113060,'94794','watch','hide_icons','1',0,''),(354846,113060,'94794','watch','sort_hide_16','1',0,''),(354847,113060,'94794','watch','sort_hide_15','1',0,''),(354848,113060,'94794','watch','sort_hide_3','0',0,''),(354849,113060,'94794','watch','sort_hide_4','0',0,''),(354850,113060,'94794','watch','sort_hide_11','1',0,''),(354851,113060,'94794','watch','sort_hide_12','1',0,''),(354852,113060,'94794','watch','sort_hide_14','1',0,''),(354853,113060,'94794','watch','sort_hide_13','1',0,''),(354854,113060,'94794','watch','sort_hide_8','0',0,''),(354855,113060,'94794','watch','sort_hide_7','0',0,''),(354856,113060,'94794','watch','sort_hide_2','1',0,''),(354857,113060,'94794','watch','sort_hide_1','1',0,''),(354858,113060,'94794','watch','sort_hide_6','1',0,''),(354859,113060,'94794','watch','sort_hide_5','1',0,''),(354860,113060,'94794','watch','sort_hide_0','1',0,''),(354861,113061,'74550','watch','block_type','1',0,''),(354862,113062,'74551','watch','margin-bottom','30',0,''),(354863,113063,'74552','watch','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(354864,113064,'74553','watch','block_type','1',0,''),(354865,113065,'74554','watch','block_type','5',0,''),(354866,113065,'74554','watch','padding-top','10',0,''),(354867,113065,'74554','watch','padding-bottom','10',0,''),(354868,113065,'74554','watch','schema','5-2',0,'5261'),(354869,113065,'74554','watch','border-top-color','$content-border-1',0,''),(354870,113065,'74554','watch','border-top-width','1',0,''),(354871,113066,'74555','watch','padding-top','3',0,''),(354872,113067,'74556','watch','float','right',0,''),(354873,113067,'74556','watch','height','31',0,''),(354874,113068,'74557','watch','col_in_row','4',0,''),(354875,113068,'74557','watch','products_align','left',0,''),(354876,113068,'74557','watch','font-weight','400',0,''),(354877,113068,'74557','watch','listing_type','productListing',0,''),(354878,113068,'74557','watch','listing_type_rows','Rows',0,''),(354879,113068,'74557','watch','show_buy_button_b2b','on',0,''),(354880,113068,'74557','watch','show_wishlist_button_b2b','1',0,''),(354881,113068,'74557','watch','show_compare_b2b','1',0,''),(354882,113068,'74557','watch','show_image','0',0,''),(354883,113068,'74557','watch','show_stock','0',0,''),(354884,113068,'74557','watch','show_description','0',0,''),(354885,113068,'74557','watch','show_model','0',0,''),(354886,113068,'74557','watch','show_properties','0',0,''),(354887,113068,'74557','watch','show_rating','0',0,''),(354888,113068,'74557','watch','show_rating_counts','0',0,''),(354889,113068,'74557','watch','show_price','0',0,''),(354890,113068,'74557','watch','show_buy_button','0',0,''),(354891,113068,'74557','watch','show_view_button','0',0,''),(354892,113068,'74557','watch','show_wishlist_button','0',0,''),(354893,113068,'74557','watch','show_compare','0',0,''),(354894,113068,'74557','watch','show_name_rows','0',0,''),(354895,113068,'74557','watch','show_image_rows','0',0,''),(354896,113068,'74557','watch','show_stock_rows','0',0,''),(354897,113068,'74557','watch','show_description_rows','0',0,''),(354898,113068,'74557','watch','show_model_rows','0',0,''),(354899,113068,'74557','watch','show_properties_rows','0',0,''),(354900,113068,'74557','watch','show_rating_rows','0',0,''),(354901,113068,'74557','watch','show_rating_counts_rows','0',0,''),(354902,113068,'74557','watch','show_price_rows','0',0,''),(354903,113068,'74557','watch','show_buy_button_rows','0',0,''),(354904,113068,'74557','watch','show_qty_input_rows','0',0,''),(354905,113068,'74557','watch','show_view_button_rows','0',0,''),(354906,113068,'74557','watch','show_wishlist_button_rows','0',0,''),(354907,113068,'74557','watch','show_compare_rows','0',0,''),(354908,113068,'74557','watch','show_name_b2b','0',0,''),(354909,113068,'74557','watch','show_image_b2b','0',0,''),(354910,113068,'74557','watch','show_stock_b2b','0',0,''),(354911,113068,'74557','watch','show_description_b2b','0',0,''),(354912,113068,'74557','watch','show_model_b2b','0',0,''),(354913,113068,'74557','watch','show_properties_b2b','0',0,''),(354914,113068,'74557','watch','show_rating_b2b','0',0,''),(354915,113068,'74557','watch','show_rating_counts_b2b','0',0,''),(354916,113068,'74557','watch','show_price_b2b','0',0,''),(354917,113068,'74557','watch','show_qty_input_b2b','0',0,''),(354918,113068,'74557','watch','show_view_button_b2b','0',0,''),(354919,113068,'74557','watch','show_attributes_b2b','0',0,''),(354920,113068,'74557','watch','items_on_page','12',0,''),(354921,113068,'74557','watch','col_in_row','2',0,'5240'),(354922,113068,'74557','watch','col_in_row','1',0,'5261'),(354923,113068,'74557','watch','product_names_teg','h2',0,''),(354924,113071,'74560','watch','block_type','1',0,''),(354925,113072,'74561','watch','block_type','1',0,''),(354926,113072,'74561','watch','padding-top','10',0,''),(354927,113072,'74561','watch','padding-bottom','10',0,''),(354928,113072,'74561','watch','border-bottom-width','1',0,''),(354929,113072,'74561','watch','border-bottom-color','$content-border-1',0,''),(354930,113072,'74561','watch','margin-left','0',0,''),(354931,113072,'74561','watch','margin-right','0',0,''),(354932,113073,'74562','watch','clear','none',0,''),(354933,113073,'74562','watch','float','left',0,''),(354934,113073,'74562','watch','padding-top','3',0,''),(354935,113073,'74562','watch','margin-left','20',0,''),(354936,113074,'74563','watch','float','right',0,''),(354937,113074,'74563','watch','display','none',0,'5261'),(354938,113075,'74564','watch','margin-right','20',0,''),(354939,113075,'74564','watch','float','right',0,''),(354940,113075,'74564','watch','clear','none',0,''),(354941,113075,'74564','watch','display','none',0,'5240'),(354942,113076,'74565','watch','float','left',0,''),(354943,113076,'74565','watch','clear','none',0,''),(354944,113076,'74565','watch','margin-left','20',0,''),(354945,113076,'74565','watch','display','none',0,'5261'),(354946,113077,'74566','watch','float','left',0,''),(354947,113077,'74566','watch','clear','none',0,''),(354948,113077,'74566','watch','sort_pos_3','2',0,''),(354949,113077,'74566','watch','sort_pos_4','3',0,''),(354950,113077,'74566','watch','sort_pos_10','11',0,''),(354951,113077,'74566','watch','sort_pos_9','10',0,''),(354952,113077,'74566','watch','sort_pos_11','12',0,''),(354953,113077,'74566','watch','sort_pos_12','13',0,''),(354954,113077,'74566','watch','sort_pos_14','15',0,''),(354955,113077,'74566','watch','sort_pos_13','14',0,''),(354956,113077,'74566','watch','sort_pos_8','4',0,''),(354957,113077,'74566','watch','sort_pos_7','5',0,''),(354958,113077,'74566','watch','sort_pos_2','7',0,''),(354959,113077,'74566','watch','sort_pos_1','6',0,''),(354960,113077,'74566','watch','sort_pos_6','9',0,''),(354961,113077,'74566','watch','sort_pos_5','8',0,''),(354962,113077,'74566','watch','sort_pos_0','1',0,''),(354963,113077,'74566','watch','sort_hide_10','1',0,''),(354964,113077,'74566','watch','sort_hide_9','1',0,''),(354965,113077,'74566','watch','sort_pos_15','16',0,''),(354966,113077,'74566','watch','sort_pos_16','17',0,''),(354967,113077,'74566','watch','sort_hide_4','0',0,''),(354968,113077,'74566','watch','sort_hide_3','0',0,''),(354969,113077,'74566','watch','sort_hide_16','1',0,''),(354970,113077,'74566','watch','sort_hide_15','1',0,''),(354971,113077,'74566','watch','sort_hide_11','1',0,''),(354972,113077,'74566','watch','sort_hide_12','1',0,''),(354973,113077,'74566','watch','sort_hide_14','1',0,''),(354974,113077,'74566','watch','sort_hide_13','1',0,''),(354975,113077,'74566','watch','sort_hide_8','0',0,''),(354976,113077,'74566','watch','sort_hide_7','0',0,''),(354977,113077,'74566','watch','sort_hide_2','1',0,''),(354978,113077,'74566','watch','sort_hide_1','1',0,''),(354979,113077,'74566','watch','sort_hide_6','1',0,''),(354980,113077,'74566','watch','sort_hide_5','1',0,''),(354981,113077,'74566','watch','sort_hide_0','0',0,''),(354982,113077,'74566','watch','hide_icons','1',0,''),(354983,113078,'74567','watch','margin-bottom','20',0,''),(354984,113079,'74568','watch','block_type','1',0,''),(354985,113079,'74568','watch','style_class','account-order-history',0,''),(355052,113103,'74573','watch','block_type','1',0,''),(355053,113103,'74573','watch','style_class','account-order-history-info',0,''),(355183,113162,'74613','watch','block_type','1',0,''),(355184,113162,'74613','watch','style_class','account-order-pay',0,''),(355185,113163,'74614','watch','block_type','6',0,''),(355186,113163,'74614','watch','schema','6-3',0,'5240'),(355187,113164,'74615','watch','aria_name','account-menu',0,''),(355245,113185,'74617','watch','block_type','3',0,''),(355246,113186,'74618','watch','block_type','1',0,''),(355247,113186,'74618','watch','padding-right','20',0,''),(355248,113186,'74618','watch','padding-bottom','20',0,''),(355249,113187,'74619','watch','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(355250,113188,'74620','watch','orders_data','name',0,''),(355251,113188,'74620','watch','padding-left','30',0,''),(355252,113189,'74621','watch','block_type','1',0,''),(355253,113190,'74622','watch','padding-left','30',0,''),(355254,113191,'74623','watch','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(355255,113192,'74624','watch','block_type','1',0,''),(355256,113192,'74624','watch','padding-right','20',0,''),(355257,113192,'74624','watch','padding-bottom','20',0,''),(355258,113193,'74625','watch','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(355259,113194,'74626','watch','orders_data','delivery_address',0,''),(355260,113194,'74626','watch','padding-left','30',0,''),(355261,113195,'74627','watch','block_type','1',0,''),(355262,113195,'74627','watch','padding-right','20',0,''),(355263,113196,'74628','watch','orders_data','shipping_method',0,''),(355264,113196,'74628','watch','padding-left','30',0,''),(355265,113197,'74629','watch','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(355266,113198,'74630','watch','block_type','1',0,''),(355267,113199,'74631','watch','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(355268,113200,'74632','watch','orders_data','payment_method',0,''),(355269,113200,'74632','watch','padding-left','30',0,''),(355270,113201,'74633','watch','block_type','1',0,''),(355271,113201,'74633','watch','padding-bottom','20',0,''),(355272,113202,'74634','watch','orders_data','billing_address',0,''),(355273,113202,'74634','watch','padding-left','30',0,''),(355274,113203,'74635','watch','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(355275,113204,'74636','watch','margin-bottom','20',0,''),(355276,113205,'74637','watch','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(355277,113208,'74640','watch','width','680',0,''),(355278,113208,'74640','watch','font-weight','400',0,''),(355279,113208,'74640','watch','font-size','12',0,''),(355280,113208,'74640','watch','padding-top','20',0,''),(355281,113208,'74640','watch','padding-bottom','20',0,''),(355282,113209,'74641','watch','block_type','2',0,''),(355283,113209,'74641','watch','font-weight','normal',0,''),(355284,113209,'74641','watch','padding-bottom','20',0,''),(355285,113210,'74642','watch','font-weight','400',0,''),(355286,113210,'74642','watch','text-align','center',0,''),(355287,113210,'74642','watch','padding-top','10',0,''),(355289,113210,'74642','watch','logo_from','theme',0,''),(355293,113211,'74643','watch','block_type','11',0,''),(355294,113211,'74643','watch','font-weight','normal',0,''),(355295,113212,'74644','watch','text','<p>Email:</p>',1,''),(355296,113212,'74644','watch','font-weight','normal',0,''),(355297,113212,'74644','watch','text-align','right',0,''),(355298,113212,'74644','watch','text','<p>Email:</p>',2,''),(355299,113212,'74644','watch','text','<p>Email:</p>',3,''),(355300,113212,'74644','watch','text','<p>Email:</p>',4,''),(355301,113213,'74645','watch','font-weight','normal',0,''),(355302,113213,'74645','watch','text-align','right',0,''),(355303,113214,'74646','watch','block_type','11',0,''),(355304,113214,'74646','watch','font-weight','normal',0,''),(355305,113215,'74647','watch','text','<p>Phone:</p>',1,''),(355306,113215,'74647','watch','font-weight','normal',0,''),(355307,113215,'74647','watch','text-align','right',0,''),(355308,113215,'74647','watch','text','<p>Phone:</p>',2,''),(355309,113215,'74647','watch','text','<p>Phone:</p>',3,''),(355310,113215,'74647','watch','text','<p>Phone:</p>',4,''),(355311,113216,'74648','watch','font-weight','normal',0,''),(355312,113216,'74648','watch','text-align','right',0,''),(355313,113217,'74649','watch','block_type','1',0,''),(355314,113218,'74650','watch','font-weight','400',0,''),(355315,113218,'74650','watch','text-align','right',0,''),(355316,113218,'74650','watch','padding-bottom','10',0,''),(355317,113218,'74650','watch','address_spacer',',',0,''),(355318,113218,'74650','watch','font-size','12',0,''),(355319,113219,'74651','watch','block_type','11',0,''),(355320,113219,'74651','watch','font-weight','400',0,''),(355321,113220,'74652','watch','text','<p>Web:</p>',1,''),(355322,113220,'74652','watch','font-weight','400',0,''),(355323,113220,'74652','watch','text-align','right',0,''),(355324,113220,'74652','watch','text','<p>Web:</p>',2,''),(355325,113220,'74652','watch','text','<p>Web:</p>',3,''),(355326,113220,'74652','watch','text','<p>Web:</p>',4,''),(355327,113221,'74653','watch','font-weight','normal',0,''),(355328,113221,'74653','watch','text-align','right',0,''),(355329,113222,'74654','watch','font-weight','normal',0,''),(355330,113222,'74654','watch','padding-top','20',0,''),(355331,113222,'74654','watch','font-size','12',0,''),(355332,113223,'74655','watch','block_type','1',0,''),(355333,113223,'74655','watch','font-weight','normal',0,''),(355334,113223,'74655','watch','padding-top','10',0,''),(355335,113223,'74655','watch','padding-bottom','10',0,''),(355336,113225,'74657','watch','text','<p>If undelivered please return to:</p>',1,''),(355337,113225,'74657','watch','font-weight','bold',0,''),(355338,113225,'74657','watch','text','<p>If undelivered please return to:</p>',2,''),(355339,113225,'74657','watch','text','<p>If undelivered please return to:</p>',3,''),(355340,113225,'74657','watch','text','<p>If undelivered please return to:</p>',4,''),(355341,113226,'74658','watch','block_type','4',0,''),(355342,113226,'74658','watch','font-weight','400',0,''),(355343,113226,'74658','watch','border-top-width','1',0,''),(355344,113226,'74658','watch','border-top-color','$content-border-1',0,''),(355345,113226,'74658','watch','border-left-width','1',0,''),(355346,113226,'74658','watch','border-left-color','$content-border-1',0,''),(355347,113226,'74658','watch','border-right-width','1',0,''),(355348,113226,'74658','watch','border-right-color','$content-border-1',0,''),(355349,113226,'74658','watch','border-bottom-width','1',0,''),(355350,113226,'74658','watch','border-bottom-color','$content-border-1',0,''),(355351,113227,'74659','watch','block_type','2',0,''),(355352,113227,'74659','watch','font-weight','normal',0,''),(355353,113227,'74659','watch','border-right-width','1',0,''),(355354,113227,'74659','watch','border-right-color','$content-border-1',0,''),(355355,113228,'74660','watch','block_type','1',0,''),(355356,113228,'74660','watch','font-weight','normal',0,''),(355357,113228,'74660','watch','border-right-width','1',0,''),(355358,113228,'74660','watch','border-right-color','$content-border-1',0,''),(355359,113228,'74660','watch','background-color','$content-bg-2',0,''),(355360,113228,'74660','watch','padding-top','10',0,''),(355361,113228,'74660','watch','padding-left','10',0,''),(355362,113228,'74660','watch','padding-right','10',0,''),(355363,113228,'74660','watch','padding-bottom','10',0,''),(355364,113229,'74661','watch','font-size','12',0,''),(355365,113229,'74661','watch','font-weight','normal',0,''),(355366,113230,'74662','watch','text','<p>SHIPPING ADDRESS:</p>',1,''),(355367,113230,'74662','watch','font-size','13',0,''),(355368,113230,'74662','watch','font-weight','bold',0,''),(355369,113230,'74662','watch','padding-bottom','10',0,''),(355370,113230,'74662','watch','text','<p>SHIPPING ADDRESS:</p>',2,''),(355371,113230,'74662','watch','text','<p>SHIPPING ADDRESS:</p>',3,''),(355372,113230,'74662','watch','text','<p>SHIPPING ADDRESS:</p>',4,''),(355373,113231,'74663','watch','block_type','1',0,''),(355374,113231,'74663','watch','font-weight','normal',0,''),(355375,113231,'74663','watch','padding-top','10',0,''),(355376,113231,'74663','watch','padding-left','10',0,''),(355377,113231,'74663','watch','padding-right','10',0,''),(355378,113231,'74663','watch','padding-bottom','10',0,''),(355379,113232,'74664','watch','text','<p>CUSTOMER:</p>',1,''),(355380,113232,'74664','watch','font-size','13',0,''),(355381,113232,'74664','watch','font-weight','bold',0,''),(355382,113232,'74664','watch','text','<p>CUSTOMER:</p>',2,''),(355383,113232,'74664','watch','text','<p>CUSTOMER:</p>',3,''),(355384,113232,'74664','watch','text','<p>CUSTOMER:</p>',4,''),(355385,113233,'74665','watch','font-size','12',0,''),(355386,113235,'74667','watch','text','<p>PHONE NUMBER:</p>',1,''),(355387,113235,'74667','watch','font-size','13',0,''),(355388,113235,'74667','watch','font-weight','bold',0,''),(355389,113235,'74667','watch','padding-top','10',0,''),(355390,113235,'74667','watch','text','<p>PHONE NUMBER:</p>',2,''),(355391,113235,'74667','watch','text','<p>PHONE NUMBER:</p>',3,''),(355392,113235,'74667','watch','text','<p>PHONE NUMBER:</p>',4,''),(355393,113236,'74668','watch','font-size','12',0,''),(355394,113237,'74669','watch','text','<p>E-MAIL ADDRESS:</p>',1,''),(355395,113237,'74669','watch','font-size','13',0,''),(355396,113237,'74669','watch','font-weight','bold',0,''),(355397,113237,'74669','watch','padding-top','10',0,''),(355398,113237,'74669','watch','text','<p>E-MAIL ADDRESS:</p>',2,''),(355399,113237,'74669','watch','text','<p>E-MAIL ADDRESS:</p>',3,''),(355400,113237,'74669','watch','text','<p>E-MAIL ADDRESS:</p>',4,''),(355401,113238,'74670','watch','block_type','2',0,''),(355402,113238,'74670','watch','font-weight','normal',0,''),(355403,113238,'74670','watch','border-right-width','1',0,''),(355404,113238,'74670','watch','border-right-color','$content-border-1',0,''),(355405,113238,'74670','watch','border-top-width','1',0,''),(355406,113238,'74670','watch','border-top-color','$content-border-1',0,''),(355407,113239,'74671','watch','block_type','1',0,''),(355408,113239,'74671','watch','font-weight','normal',0,''),(355409,113239,'74671','watch','padding-top','10',0,''),(355410,113239,'74671','watch','padding-left','10',0,''),(355411,113239,'74671','watch','padding-right','10',0,''),(355412,113239,'74671','watch','padding-bottom','10',0,''),(355413,113239,'74671','watch','border-right-width','1',0,''),(355414,113239,'74671','watch','border-right-color','$content-border-1',0,''),(355415,113241,'74673','watch','text','<p>Shipping via</p>',1,''),(355416,113241,'74673','watch','font-weight','bold',0,''),(355417,113241,'74673','watch','text','<p>Shipping via</p>',2,''),(355418,113241,'74673','watch','text','<p>Shipping via</p>',3,''),(355419,113241,'74673','watch','text','<p>Shipping via</p>',4,''),(355420,113242,'74674','watch','block_type','1',0,''),(355421,113242,'74674','watch','font-weight','normal',0,''),(355422,113242,'74674','watch','padding-top','10',0,''),(355423,113242,'74674','watch','padding-left','10',0,''),(355424,113242,'74674','watch','padding-right','10',0,''),(355425,113242,'74674','watch','padding-bottom','10',0,''),(355426,113244,'74676','watch','text','<p>Shipping service</p>',1,''),(355427,113244,'74676','watch','font-weight','bold',0,''),(355428,113244,'74676','watch','text','<p>Shipping service</p>',2,''),(355429,113244,'74676','watch','text','<p>Shipping service</p>',3,''),(355430,113244,'74676','watch','text','<p>Shipping service</p>',4,''),(355431,113245,'74677','watch','font-weight','normal',0,''),(355432,113245,'74677','watch','text-align','center',0,''),(355433,113245,'74677','watch','padding-top','40',0,''),(355434,113246,'74678','watch','block_type','1',0,''),(355435,113247,'74679','watch','block_type','8',0,''),(355436,113248,'74680','watch','text','##TEXT_MAIN##',0,''),(355437,113248,'74680','watch','margin-bottom','20',0,''),(355438,113248,'74680','watch','text-align','center',0,''),(355439,113249,'74681','watch','margin-bottom','20',0,''),(355440,113250,'74682','watch','text','<h1>##HEADING_TITLE##</h1>',0,''),(355441,113252,'74684','watch','block_type','2',0,''),(355442,113253,'74685','watch','block_type','1',0,''),(355443,113253,'74685','watch','style_class','product',0,''),(355444,113253,'74685','watch','padding-right','10',0,''),(355445,113253,'74685','watch','padding-bottom','20',0,''),(355446,113254,'74686','watch','block_type','1',0,''),(355447,113255,'74687','watch','product_element','products_name',0,''),(355448,113255,'74687','watch','font-family','$font-1',0,''),(355449,113255,'74687','watch','padding-bottom','10',0,''),(355450,113255,'74687','watch','font-size','16',0,''),(355451,113256,'74688','watch','block_type','2',0,''),(355452,113257,'74689','watch','product_element','image',0,''),(355453,113257,'74689','watch','padding-right','10',0,''),(355454,113258,'74690','watch','product_element','products_price_old',0,''),(355455,113258,'74690','watch','font-family','$font-1',0,''),(355456,113258,'74690','watch','font-size','14',0,''),(355457,113258,'74690','watch','text-decoration','line-through',0,''),(355458,113259,'74691','watch','product_element','products_price',0,''),(355459,113259,'74691','watch','font-family','$font-1',0,''),(355460,113259,'74691','watch','font-size','20',0,''),(355461,113259,'74691','watch','padding-top','20',0,''),(355462,113260,'74692','watch','block_type','1',0,''),(355463,113260,'74692','watch','style_class','product',0,''),(355464,113260,'74692','watch','padding-left','10',0,''),(355465,113260,'74692','watch','padding-bottom','20',0,''),(355466,113261,'74693','watch','block_type','2',0,''),(355467,113262,'74694','watch','product_element','image',0,''),(355468,113262,'74694','watch','padding-right','10',0,''),(355469,113263,'74695','watch','font-size','14',0,''),(355470,113263,'74695','watch','font-family','$font-1',0,''),(355471,113263,'74695','watch','text-decoration','line-through',0,''),(355472,113263,'74695','watch','product_element','products_price_old',0,''),(355473,113264,'74696','watch','product_element','products_price',0,''),(355474,113264,'74696','watch','font-family','$font-1',0,''),(355475,113264,'74696','watch','font-size','20',0,''),(355476,113264,'74696','watch','padding-top','20',0,''),(355477,113265,'74697','watch','block_type','1',0,''),(355478,113266,'74698','watch','product_element','products_name',0,''),(355479,113266,'74698','watch','font-family','$font-1',0,''),(355480,113266,'74698','watch','font-size','16',0,''),(355481,113266,'74698','watch','padding-bottom','10',0,''),(355482,113267,'74699','watch','font-size','30',0,''),(355483,113267,'74699','watch','font-family','$font-1',0,''),(355484,113267,'74699','watch','text-align','center',0,''),(355485,113267,'74699','watch','padding-bottom','50',0,''),(355486,113268,'74700','watch','padding-bottom','20',0,''),(355487,113268,'74700','watch','text-align','center',0,''),(355488,113269,'74701','watch','width','680',0,''),(355489,113270,'74702','watch','padding-top','200',0,''),(355490,113270,'74702','watch','padding-left','200',0,''),(355495,113271,'74703','watch','text','osCommerce 4',1,''),(355496,113271,'74703','watch','font-family','$font-1',0,''),(355497,113271,'74703','watch','font-size','40',0,''),(355498,113271,'74703','watch','padding-top','50',0,''),(355499,113271,'74703','watch','text-align','center',0,''),(355500,113271,'74703','watch','text','osCommerce 4',2,''),(355501,113271,'74703','watch','text','osCommerce 4',3,''),(355502,113271,'74703','watch','text','osCommerce 4',4,''),(355503,113272,'74704','watch','block_type','2',0,''),(355504,113272,'74704','watch','border-top-width','1',0,''),(355505,113272,'74704','watch','border-top-color','$content-border-1',0,''),(355506,113273,'74705','watch','text-align','right',0,''),(355507,113273,'74705','watch','padding-top','15',0,''),(355508,113273,'74705','watch','padding-bottom','15',0,''),(355509,113273,'74705','watch','font-size','14',0,''),(355510,113274,'74706','watch','font-family','$font-1',0,''),(355511,113274,'74706','watch','text-align','center',0,''),(355512,113274,'74706','watch','font-size','20',0,''),(355513,113274,'74706','watch','color','$highlight-color-1',0,''),(355514,113274,'74706','watch','border-bottom-width','1',0,''),(355515,113274,'74706','watch','border-bottom-color','$content-border-1',0,''),(355516,113274,'74706','watch','padding-top','10',0,''),(355517,113274,'74706','watch','padding-bottom','10',0,''),(355518,113275,'74707','watch','block_type','1',0,''),(355519,113276,'74708','watch','block_type','6',0,''),(355520,113276,'74708','watch','schema','6-3',0,'5240'),(355521,113277,'74709','watch','aria_name','account-menu',0,''),(355579,113297,'74710','watch','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(355580,113298,'74711','watch','like_button','1',0,''),(355581,113298,'74711','watch','link','personal_catalog',0,''),(355582,113298,'74711','watch','text','BOX_INFORMATION_ALLPRODS',0,''),(355583,113298,'74711','watch','text-align','center',0,''),(355584,113298,'74711','watch','padding-top','20',0,''),(355585,113298,'74711','watch','padding-bottom','20',0,''),(355586,113299,'74712','watch','max_items','10',0,''),(355587,113300,'74713','watch','block_type','1',0,''),(355588,113300,'74713','watch','padding-top','20',0,''),(355589,113300,'74713','watch','padding-left','20',0,''),(355590,113300,'74713','watch','padding-right','20',0,''),(355591,113300,'74713','watch','padding-bottom','20',0,''),(355592,113301,'74714','watch','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(355593,113303,'74716','watch','block_type','1',0,''),(355594,113304,'74717','watch','margin_left_measure','auto',0,''),(355595,113304,'74717','watch','margin_right_measure','auto',0,''),(355596,113304,'74717','watch','max-width','560',0,''),(355597,113305,'74718','watch','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(355598,113306,'74719','watch','margin-bottom','30',0,''),(355599,113307,'74720','watch','block_type','1',0,''),(355600,113307,'74720','watch','style_class','catalog-product-wrap',0,''),(355601,113309,'74722','watch','block_type','2',0,''),(355602,113309,'74722','watch','font-weight','400',0,''),(355603,113309,'74722','watch','padding-bottom','20',0,''),(355604,113309,'74722','watch','schema','2-2',0,'5261'),(355605,113310,'74724','watch','font-weight','400',0,''),(355606,113310,'74724','watch','padding-top','20',0,''),(355607,113310,'74724','watch','padding-right','20',0,''),(355608,113310,'74724','watch','box_align','4',0,''),(355609,113310,'74724','watch','margin-bottom','50',0,''),(355610,113310,'74724','watch','align_position','horizontal',0,''),(355611,113313,'74727','watch','block_type','12',0,''),(355612,113313,'74727','watch','padding-top','15',0,''),(355613,113313,'74727','watch','padding-bottom','5',0,''),(355614,113313,'74727','watch','border-top-width','1',0,''),(355615,113313,'74727','watch','border-top-color','$content-border-1',0,''),(355616,113313,'74727','watch','schema','2-2',0,'5232'),(355617,113313,'74727','watch','margin-bottom','15',0,''),(355618,113313,'74727','watch','border-bottom-width','1',0,''),(355619,113313,'74727','watch','border-bottom-color','$content-border-1',0,''),(355620,113313,'74727','watch','schema','12-2',0,'5240'),(355621,113314,'74728','watch','padding-top','10',0,''),(355622,113314,'74728','watch','padding-bottom','10',0,''),(355623,113315,'74729','watch','block_type','2',0,''),(355624,113315,'74729','watch','schema','2-1',0,'5240'),(355625,113316,'74730','watch','font-size','30',0,''),(355626,113316,'74730','watch','font-weight','400',0,''),(355627,113316,'74730','watch','line-height','35',0,''),(355628,113316,'74730','watch','font-family','$font-1',0,''),(355629,113316,'74730','watch','line_height_measure','px',0,''),(355630,113316,'74730','watch','padding-top','5',0,''),(355631,113317,'74731','watch','box_align','4',0,''),(355632,113317,'74731','watch','margin-bottom','15',0,'5240'),(355633,113317,'74731','watch','text-align','right',0,'5240'),(355634,113317,'74731','watch','padding-top','5',0,''),(355635,113317,'74731','watch','text-align','left',0,''),(355636,113318,'74732','watch','margin-bottom','15',0,''),(355637,113318,'74732','watch','padding-top','15',0,''),(355638,113319,'1694165842.4776','watch','padding-top','10',0,''),(355639,113320,'74733','watch','text-align','right',0,''),(355640,113320,'74733','watch','width','100',0,'5232'),(355641,113320,'74733','watch','width_measure','%',0,'5232'),(355642,113320,'74733','watch','float','none',0,'5232'),(355643,113320,'74733','watch','hide_additional_buttons','1',0,''),(355644,113321,'74734','watch','text-align','right',0,''),(355645,113322,'74735','watch','cat_description','on',0,''),(355646,113322,'74735','watch','length_description','250',0,''),(355647,113322,'74735','watch','padding-bottom','20',0,''),(355648,113323,'74737','watch','document_types_id','4',0,''),(355649,113324,'74738','watch','show_address','1',0,''),(355650,113324,'74738','watch','show_time','1',0,''),(355651,113324,'74738','watch','show_qty','1',0,''),(355652,113324,'74738','watch','show_qty_level1','500',0,''),(355653,113324,'74738','watch','show_qty_level2','2000',0,''),(355654,113324,'74738','watch','text-align','right',0,''),(355655,113324,'74738','watch','margin-bottom','10',0,''),(355656,113325,'74739','watch','block_type','2',0,''),(355657,113329,'74745','watch','font-weight','400',0,''),(355658,113333,'74750','watch','font-weight','normal',0,''),(355659,113333,'74750','watch','padding-top','10',0,''),(355660,113333,'74750','watch','padding-bottom','10',0,''),(355661,113333,'74750','watch','box_align','4',0,''),(355662,113334,'74752','watch','tab_1','Description',1,''),(355663,113334,'74752','watch','tab_2','Reviews',1,''),(355664,113334,'74752','watch','font-weight','400',0,''),(355665,113334,'74752','watch','tab_1','Description',2,''),(355666,113334,'74752','watch','tab_2','Reviews',2,''),(355667,113334,'74752','watch','tab_1','Description',3,''),(355668,113334,'74752','watch','tab_2','Reviews',3,''),(355669,113334,'74752','watch','tab_1','Description',4,''),(355670,113334,'74752','watch','tab_2','Reviews',4,''),(355671,113335,'74753','watch','hTagsInline','block',0,''),(355672,113336,'74754','watch','margin-bottom','20',0,''),(355673,113336,'74754','watch','max-width','500',0,''),(355674,113337,'74755','watch','padding-bottom','10',0,''),(355675,113337,'74755','watch','padding-top','5',0,''),(355676,113338,'74757','watch','font-weight','normal',0,''),(355677,113338,'74757','watch','padding-bottom','20',0,''),(355678,113339,'74758','watch','font-weight','normal',0,''),(355679,113339,'74758','watch','padding-bottom','20',0,''),(355680,113340,'1694166186.2638','watch','block_type','1',0,''),(355681,113341,'74751','watch','font-weight','400',0,''),(355682,113341,'74751','watch','padding-bottom','20',0,''),(355683,113341,'74751','watch','show_qty_input','1',0,''),(355684,113341,'74751','watch','show_compare','1',0,''),(355685,113341,'74751','watch','listing_type','productListing',0,''),(355686,113341,'74751','watch','view_as','carousel',0,''),(355687,113341,'74751','watch','show_name','0',0,''),(355688,113341,'74751','watch','show_image','0',0,''),(355689,113341,'74751','watch','show_stock','0',0,''),(355690,113341,'74751','watch','show_description','0',0,''),(355691,113341,'74751','watch','show_model','0',0,''),(355692,113341,'74751','watch','show_properties','0',0,''),(355693,113341,'74751','watch','show_rating','0',0,''),(355694,113341,'74751','watch','show_rating_counts','0',0,''),(355695,113341,'74751','watch','show_price','0',0,''),(355696,113341,'74751','watch','show_buy_button','0',0,''),(355697,113341,'74751','watch','show_view_button','0',0,''),(355698,113341,'74751','watch','show_wishlist_button','0',0,''),(355699,113341,'74751','watch','display','none',0,'5240'),(355700,113341,'74751','watch','product_names_teg','h2',0,''),(355701,113341,'74751','watch','show_attributes','1',0,''),(355702,113341,'74751','watch','col_in_row','4',0,''),(355703,113341,'74751','watch','hide_parents','2',0,''),(355704,113342,'1694166209.3278','watch','text','<div class=\"heading-3\">##PRODUCT_ALSO_PURCHASED##</div>',0,''),(355705,113343,'1694166191.5684','watch','block_type','1',0,''),(355706,113344,'74747','watch','font-weight','400',0,''),(355707,113344,'74747','watch','padding-bottom','20',0,''),(355708,113344,'74747','watch','show_compare','1',0,''),(355709,113344,'74747','watch','show_name','0',0,''),(355710,113344,'74747','watch','show_image','0',0,''),(355711,113344,'74747','watch','show_stock','0',0,''),(355712,113344,'74747','watch','show_description','0',0,''),(355713,113344,'74747','watch','show_model','0',0,''),(355714,113344,'74747','watch','show_properties','0',0,''),(355715,113344,'74747','watch','show_rating','0',0,''),(355716,113344,'74747','watch','show_rating_counts','0',0,''),(355717,113344,'74747','watch','show_price','0',0,''),(355718,113344,'74747','watch','show_buy_button','0',0,''),(355719,113344,'74747','watch','show_view_button','0',0,''),(355720,113344,'74747','watch','show_wishlist_button','0',0,''),(355721,113344,'74747','watch','listing_type','productListing',0,''),(355722,113344,'74747','watch','col_in_row','2',0,'5240'),(355723,113344,'74747','watch','col_in_row','1',0,'5261'),(355724,113344,'74747','watch','col_in_row','4',0,''),(355725,113344,'74747','watch','hide_parents','2',0,''),(355726,113345,'1694166222.3382','watch','text','<div class=\"heading-3\">##VIEWED_PRODUCTS##</div>',0,''),(355727,113356,'74771','watch','block_type','1',0,''),(355728,113356,'74771','watch','style_class','item-holder',0,''),(355729,113356,'74771','watch','padding-top','25',0,''),(355730,113356,'74771','watch','padding-left','25',0,''),(355731,113356,'74771','watch','padding-right','25',0,''),(355732,113356,'74771','watch','padding-bottom','25',0,''),(355733,113356,'74771','watch','text-align','left',0,''),(355734,113359,'74775','watch','description_characters','90',0,''),(355735,113360,'74776','watch','text-align','right',0,''),(355736,113360,'74776','watch','margin-bottom','10',0,''),(355737,113361,'74777','watch','text-align','right',0,''),(355738,113361,'74777','watch','clear','none',0,''),(355739,113361,'74777','watch','float','left',0,''),(355740,113363,'74779','watch','block_type','2',0,''),(355741,113364,'74780','watch','margin-bottom','7',0,''),(355742,113365,'74781','watch','margin-bottom','10',0,''),(355743,113365,'74781','watch','text-align','right',0,''),(355744,113365,'74781','watch','float','right',0,''),(355745,113366,'74782','watch','clear','both',0,''),(355746,113367,'74783','watch','float','left',0,''),(355747,113367,'74783','watch','margin-right','20',0,''),(355748,113367,'74783','watch','margin-bottom','5',0,''),(355749,113369,'74785','watch','block_type','1',0,''),(355750,113370,'74786','watch','block_type','6',0,''),(355751,113370,'74786','watch','font-weight','400',0,''),(355752,113370,'74786','watch','schema','6-2',0,'5261'),(355753,113370,'74786','watch','schema','6-2',0,'5240'),(355754,113371,'74787','watch','font-weight','400',0,''),(355755,113371,'74787','watch','padding-right','40',0,''),(355756,113371,'74787','watch','padding-right','0',0,'5261'),(355757,113371,'74787','watch','padding-right','0',0,'5240'),(355758,113371,'74787','watch','margin-bottom','20',0,''),(355759,113372,'74788','watch','margin-bottom','20',0,''),(355760,113374,'74790','watch','block_type','1',0,''),(355761,113374,'74790','watch','padding-top','10',0,''),(355762,113374,'74790','watch','padding-bottom','10',0,''),(355763,113374,'74790','watch','border-bottom-width','1',0,''),(355764,113374,'74790','watch','border-bottom-color','$content-border-1',0,''),(355765,113374,'74790','watch','margin-left','0',0,''),(355766,113374,'74790','watch','margin-right','0',0,''),(355767,113375,'74791','watch','float','left',0,''),(355768,113375,'74791','watch','clear','none',0,''),(355769,113375,'74791','watch','sort_pos_3','2',0,''),(355770,113375,'74791','watch','sort_pos_4','3',0,''),(355771,113375,'74791','watch','sort_pos_10','11',0,''),(355772,113375,'74791','watch','sort_pos_9','10',0,''),(355773,113375,'74791','watch','sort_pos_11','12',0,''),(355774,113375,'74791','watch','sort_pos_12','13',0,''),(355775,113375,'74791','watch','sort_pos_14','15',0,''),(355776,113375,'74791','watch','sort_pos_13','14',0,''),(355777,113375,'74791','watch','sort_pos_8','4',0,''),(355778,113375,'74791','watch','sort_pos_7','5',0,''),(355779,113375,'74791','watch','sort_pos_2','7',0,''),(355780,113375,'74791','watch','sort_pos_1','6',0,''),(355781,113375,'74791','watch','sort_pos_6','9',0,''),(355782,113375,'74791','watch','sort_pos_5','8',0,''),(355783,113375,'74791','watch','sort_pos_0','1',0,''),(355784,113375,'74791','watch','sort_hide_10','1',0,''),(355785,113375,'74791','watch','sort_hide_9','1',0,''),(355786,113375,'74791','watch','sort_pos_15','16',0,''),(355787,113375,'74791','watch','sort_pos_16','17',0,''),(355788,113375,'74791','watch','sort_hide_4','0',0,''),(355789,113375,'74791','watch','sort_hide_3','0',0,''),(355790,113375,'74791','watch','sort_hide_16','1',0,''),(355791,113375,'74791','watch','sort_hide_15','1',0,''),(355792,113375,'74791','watch','sort_hide_11','1',0,''),(355793,113375,'74791','watch','sort_hide_12','1',0,''),(355794,113375,'74791','watch','sort_hide_14','1',0,''),(355795,113375,'74791','watch','sort_hide_13','1',0,''),(355796,113375,'74791','watch','sort_hide_8','0',0,''),(355797,113375,'74791','watch','sort_hide_7','0',0,''),(355798,113375,'74791','watch','sort_hide_2','1',0,''),(355799,113375,'74791','watch','sort_hide_1','1',0,''),(355800,113375,'74791','watch','sort_hide_6','1',0,''),(355801,113375,'74791','watch','sort_hide_5','1',0,''),(355802,113375,'74791','watch','sort_hide_0','0',0,''),(355803,113375,'74791','watch','hide_icons','1',0,''),(355804,113376,'74792','watch','float','right',0,''),(355805,113376,'74792','watch','display','none',0,'5261'),(355806,113377,'74793','watch','float','left',0,''),(355807,113377,'74793','watch','clear','none',0,''),(355808,113377,'74793','watch','margin-left','20',0,''),(355809,113377,'74793','watch','display','none',0,'5261'),(355810,113378,'74794','watch','margin-right','20',0,''),(355811,113378,'74794','watch','float','right',0,''),(355812,113378,'74794','watch','clear','none',0,''),(355813,113378,'74794','watch','display','none',0,'5240'),(355814,113379,'74795','watch','block_type','5',0,''),(355815,113379,'74795','watch','padding-top','10',0,''),(355816,113379,'74795','watch','padding-bottom','10',0,''),(355817,113379,'74795','watch','schema','5-2',0,'5261'),(355818,113379,'74795','watch','border-top-color','$content-border-1',0,''),(355819,113379,'74795','watch','border-top-width','1',0,''),(355820,113380,'74796','watch','padding-top','3',0,''),(355821,113381,'74797','watch','float','right',0,''),(355822,113381,'74797','watch','height','31',0,''),(355823,113382,'74798','watch','col_in_row','3',0,''),(355824,113382,'74798','watch','products_align','left',0,''),(355825,113382,'74798','watch','font-weight','400',0,''),(355826,113382,'74798','watch','listing_type','productListing',0,''),(355827,113382,'74798','watch','listing_type_rows','Rows',0,''),(355828,113382,'74798','watch','show_buy_button_b2b','on',0,''),(355829,113382,'74798','watch','show_wishlist_button_b2b','1',0,''),(355830,113382,'74798','watch','show_compare_b2b','1',0,''),(355831,113382,'74798','watch','show_image','0',0,''),(355832,113382,'74798','watch','show_stock','0',0,''),(355833,113382,'74798','watch','show_description','0',0,''),(355834,113382,'74798','watch','show_model','0',0,''),(355835,113382,'74798','watch','show_properties','0',0,''),(355836,113382,'74798','watch','show_rating','0',0,''),(355837,113382,'74798','watch','show_rating_counts','0',0,''),(355838,113382,'74798','watch','show_price','0',0,''),(355839,113382,'74798','watch','show_buy_button','0',0,''),(355840,113382,'74798','watch','show_view_button','0',0,''),(355841,113382,'74798','watch','show_wishlist_button','0',0,''),(355842,113382,'74798','watch','show_compare','0',0,''),(355843,113382,'74798','watch','show_name_rows','0',0,''),(355844,113382,'74798','watch','show_image_rows','0',0,''),(355845,113382,'74798','watch','show_stock_rows','0',0,''),(355846,113382,'74798','watch','show_description_rows','0',0,''),(355847,113382,'74798','watch','show_model_rows','0',0,''),(355848,113382,'74798','watch','show_properties_rows','0',0,''),(355849,113382,'74798','watch','show_rating_rows','0',0,''),(355850,113382,'74798','watch','show_rating_counts_rows','0',0,''),(355851,113382,'74798','watch','show_price_rows','0',0,''),(355852,113382,'74798','watch','show_buy_button_rows','0',0,''),(355853,113382,'74798','watch','show_qty_input_rows','0',0,''),(355854,113382,'74798','watch','show_view_button_rows','0',0,''),(355855,113382,'74798','watch','show_wishlist_button_rows','0',0,''),(355856,113382,'74798','watch','show_compare_rows','0',0,''),(355857,113382,'74798','watch','show_name_b2b','0',0,''),(355858,113382,'74798','watch','show_image_b2b','0',0,''),(355859,113382,'74798','watch','show_stock_b2b','0',0,''),(355860,113382,'74798','watch','show_description_b2b','0',0,''),(355861,113382,'74798','watch','show_model_b2b','0',0,''),(355862,113382,'74798','watch','show_properties_b2b','0',0,''),(355863,113382,'74798','watch','show_rating_b2b','0',0,''),(355864,113382,'74798','watch','show_rating_counts_b2b','0',0,''),(355865,113382,'74798','watch','show_price_b2b','0',0,''),(355866,113382,'74798','watch','show_qty_input_b2b','0',0,''),(355867,113382,'74798','watch','show_view_button_b2b','0',0,''),(355868,113382,'74798','watch','show_attributes_b2b','0',0,''),(355869,113382,'74798','watch','items_on_page','9',0,''),(355870,113382,'74798','watch','col_in_row','2',0,'5240'),(355871,113382,'74798','watch','col_in_row','1',0,'5261'),(355872,113382,'74798','watch','product_names_teg','h2',0,''),(355873,113384,'74800','watch','block_type','1',0,''),(355874,113385,'74801','watch','margin-bottom','20',0,''),(355875,113387,'74802','watch','block_type','1',0,''),(355876,113389,'74804','watch','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(355877,113390,'74805','watch','width','680',0,''),(355878,113390,'74805','watch','font-weight','normal',0,''),(355879,113390,'74805','watch','font-size','12',0,''),(355880,113390,'74805','watch','padding-top','20',0,''),(355881,113390,'74805','watch','padding-bottom','20',0,''),(355882,113390,'74805','watch','color','$content-color-1',0,''),(355883,113391,'74806','watch','font-weight','400',0,''),(355884,113391,'74806','watch','padding-top','20',0,''),(355885,113391,'74806','watch','padding-bottom','0',0,''),(355886,113391,'74806','watch','font-size','12',0,''),(355887,113392,'74807','watch','block_type','3',0,''),(355888,113392,'74807','watch','font-weight','normal',0,''),(355889,113392,'74807','watch','padding-top','20',0,''),(355890,113393,'74808','watch','text','<p>If undelivered please return to:</p>',1,''),(355891,113393,'74808','watch','font-size','12',0,''),(355892,113393,'74808','watch','font-weight','bold',0,''),(355893,113393,'74808','watch','text','<p>If undelivered please return to:</p>',2,''),(355894,113393,'74808','watch','text','<p>If undelivered please return to:</p>',3,''),(355895,113393,'74808','watch','text','<p>If undelivered please return to:</p>',4,''),(355896,113394,'74809','watch','font-size','12',0,''),(355897,113395,'74810','watch','text','<p>Thank you for your order</p>',1,''),(355898,113395,'74810','watch','color','$color-8',0,''),(355899,113395,'74810','watch','font-size','13',0,''),(355900,113395,'74810','watch','font-weight','bold',0,''),(355901,113395,'74810','watch','padding-top','5',0,''),(355902,113395,'74810','watch','text-align','center',0,''),(355903,113395,'74810','watch','text','<p>Thank you for your order</p>',2,''),(355904,113395,'74810','watch','text','<p>Thank you for your order</p>',3,''),(355905,113395,'74810','watch','text','<p>Thank you for your order</p>',4,''),(355906,113396,'74811','watch','font-weight','400',0,''),(355907,113396,'74811','watch','text-align','center',0,''),(355908,113396,'74811','watch','padding-top','0',0,''),(355910,113396,'74811','watch','padding-left','20',0,''),(355911,113396,'74811','watch','padding-right','20',0,''),(355915,113397,'74812','watch','block_type','6',0,''),(355916,113397,'74812','watch','font-weight','normal',0,''),(355917,113397,'74812','watch','font-size','16',0,''),(355918,113398,'74813','watch','text','<p>Email:</p>',1,''),(355919,113398,'74813','watch','font-weight','normal',0,''),(355920,113398,'74813','watch','text-align','right',0,''),(355921,113398,'74813','watch','font-size','12',0,''),(355922,113398,'74813','watch','text','<p>Email:</p>',2,''),(355923,113398,'74813','watch','text','<p>Email:</p>',3,''),(355924,113398,'74813','watch','text','<p>Email:</p>',4,''),(355925,113399,'74814','watch','font-weight','normal',0,''),(355926,113399,'74814','watch','text-align','right',0,''),(355927,113399,'74814','watch','font-size','12',0,''),(355928,113400,'74815','watch','text','<p>If something has gone wrong please contact us at:</p>',1,''),(355929,113400,'74815','watch','font-size','12',0,''),(355930,113400,'74815','watch','font-weight','bold',0,''),(355931,113400,'74815','watch','text-align','right',0,''),(355932,113400,'74815','watch','text','<p>If something has gone wrong please contact us at:</p>',2,''),(355933,113400,'74815','watch','text','<p>If something has gone wrong please contact us at:</p>',3,''),(355934,113400,'74815','watch','text','<p>If something has gone wrong please contact us at:</p>',4,''),(355935,113401,'74816','watch','block_type','6',0,''),(355936,113401,'74816','watch','font-weight','normal',0,''),(355937,113401,'74816','watch','font-size','16',0,''),(355938,113402,'74817','watch','text','<p>Phone:</p>',1,''),(355939,113402,'74817','watch','font-weight','normal',0,''),(355940,113402,'74817','watch','text-align','right',0,''),(355941,113402,'74817','watch','font-size','12',0,''),(355942,113402,'74817','watch','text','<p>Phone:</p>',2,''),(355943,113402,'74817','watch','text','<p>Phone:</p>',3,''),(355944,113402,'74817','watch','text','<p>Phone:</p>',4,''),(355945,113403,'74818','watch','font-weight','normal',0,''),(355946,113403,'74818','watch','text-align','right',0,''),(355947,113403,'74818','watch','font-size','12',0,''),(355948,113404,'74819','watch','block_type','2',0,''),(355949,113404,'74819','watch','font-weight','normal',0,''),(355950,113404,'74819','watch','padding-bottom','20',0,''),(355951,113405,'74820','watch','font-weight','400',0,''),(355952,113405,'74820','watch','padding-top','20',0,''),(355957,113406,'74821','watch','block_type','11',0,''),(355958,113406,'74821','watch','font-weight','normal',0,''),(355959,113407,'74822','watch','text','<p>Phone:</p>',1,''),(355960,113407,'74822','watch','font-weight','normal',0,''),(355961,113407,'74822','watch','text-align','right',0,''),(355962,113407,'74822','watch','text','<p>Phone:</p>',2,''),(355963,113407,'74822','watch','text','<p>Phone:</p>',3,''),(355964,113407,'74822','watch','text','<p>Phone:</p>',4,''),(355965,113408,'74823','watch','font-weight','normal',0,''),(355966,113408,'74823','watch','text-align','right',0,''),(355967,113409,'74824','watch','block_type','11',0,''),(355968,113409,'74824','watch','font-weight','normal',0,''),(355969,113410,'74825','watch','text','<p>Web:</p>',1,''),(355970,113410,'74825','watch','font-weight','normal',0,''),(355971,113410,'74825','watch','text-align','right',0,''),(355972,113410,'74825','watch','text','<p>Web:</p>',2,''),(355973,113410,'74825','watch','text','<p>Web:</p>',3,''),(355974,113410,'74825','watch','text','<p>Web:</p>',4,''),(355975,113411,'74826','watch','font-weight','normal',0,''),(355976,113411,'74826','watch','text-align','right',0,''),(355977,113412,'74827','watch','block_type','1',0,''),(355978,113413,'74828','watch','font-weight','normal',0,''),(355979,113413,'74828','watch','text-align','right',0,''),(355980,113413,'74828','watch','padding-bottom','10',0,''),(355981,113413,'74828','watch','address_spacer',',',0,''),(355982,113413,'74828','watch','font-size','12',0,''),(355983,113414,'74829','watch','block_type','11',0,''),(355984,113414,'74829','watch','font-weight','normal',0,''),(355985,113415,'74830','watch','text','<p>Email:</p>',1,''),(355986,113415,'74830','watch','font-weight','normal',0,''),(355987,113415,'74830','watch','text-align','right',0,''),(355988,113415,'74830','watch','text','<p>Email:</p>',2,''),(355989,113415,'74830','watch','text','<p>Email:</p>',3,''),(355990,113415,'74830','watch','text','<p>Email:</p>',4,''),(355991,113416,'74831','watch','font-weight','normal',0,''),(355992,113416,'74831','watch','text-align','right',0,''),(355993,113417,'74832','watch','block_type','4',0,''),(355994,113417,'74832','watch','font-weight','normal',0,''),(355995,113417,'74832','watch','border-top-width','1',0,''),(355996,113417,'74832','watch','border-top-color','$content-border-1',0,''),(355997,113417,'74832','watch','border-left-width','1',0,''),(355998,113417,'74832','watch','border-left-color','$content-border-1',0,''),(355999,113417,'74832','watch','border-right-width','1',0,''),(356000,113417,'74832','watch','border-right-color','$content-border-1',0,''),(356001,113417,'74832','watch','border-bottom-width','1',0,''),(356002,113417,'74832','watch','border-bottom-color','$content-border-1',0,''),(356003,113418,'74833','watch','block_type','2',0,''),(356004,113418,'74833','watch','font-weight','normal',0,''),(356005,113418,'74833','watch','border-right-width','1',0,''),(356006,113418,'74833','watch','border-right-color','$content-border-1',0,''),(356007,113419,'74834','watch','block_type','1',0,''),(356008,113419,'74834','watch','font-weight','400',0,''),(356009,113419,'74834','watch','background-color','$content-bg-2',0,''),(356010,113419,'74834','watch','padding-top','10',0,''),(356011,113419,'74834','watch','padding-left','10',0,''),(356012,113419,'74834','watch','padding-right','10',0,''),(356013,113419,'74834','watch','padding-bottom','30',0,''),(356014,113420,'74835','watch','font-size','12',0,''),(356015,113421,'74836','watch','text','<p>ADDRESS:</p>\n',1,''),(356016,113421,'74836','watch','font-size','14',0,''),(356017,113421,'74836','watch','font-weight','bold',0,''),(356018,113421,'74836','watch','text','<p>ADDRESS:</p>\n',2,''),(356019,113421,'74836','watch','text','<p>ADDRESS:</p>\n',3,''),(356020,113421,'74836','watch','text','<p>ADDRESS:</p>\n',4,''),(356021,113422,'74837','watch','block_type','1',0,''),(356022,113422,'74837','watch','font-weight','normal',0,''),(356023,113422,'74837','watch','padding-top','10',0,''),(356024,113422,'74837','watch','padding-left','10',0,''),(356025,113422,'74837','watch','padding-right','10',0,''),(356026,113422,'74837','watch','padding-bottom','10',0,''),(356027,113424,'74839','watch','text','<p>E-MAIL ADDRESS:</p>',1,''),(356028,113424,'74839','watch','font-weight','bold',0,''),(356029,113424,'74839','watch','font-size','14',0,''),(356030,113424,'74839','watch','padding-top','10',0,''),(356031,113424,'74839','watch','text','<p>E-MAIL ADDRESS:</p>',2,''),(356032,113424,'74839','watch','text','<p>E-MAIL ADDRESS:</p>',3,''),(356033,113424,'74839','watch','text','<p>E-MAIL ADDRESS:</p>',4,''),(356034,113425,'74840','watch','font-weight','normal',0,''),(356035,113426,'74841','watch','font-weight','normal',0,''),(356036,113427,'74842','watch','text','<p>PHONE NUMBER:</p>',1,''),(356037,113427,'74842','watch','font-size','14',0,''),(356038,113427,'74842','watch','font-weight','bold',0,''),(356039,113427,'74842','watch','padding-top','10',0,''),(356040,113427,'74842','watch','text','<p>PHONE NUMBER:</p>',2,''),(356041,113427,'74842','watch','text','<p>PHONE NUMBER:</p>',3,''),(356042,113427,'74842','watch','text','<p>PHONE NUMBER:</p>',4,''),(356043,113428,'74843','watch','text','<p>CUSTOMER:</p>',1,''),(356044,113428,'74843','watch','font-size','13',0,''),(356045,113428,'74843','watch','font-weight','bold',0,''),(356046,113428,'74843','watch','text','<p>CUSTOMER:</p>',2,''),(356047,113428,'74843','watch','text','<p>CUSTOMER:</p>',3,''),(356048,113428,'74843','watch','text','<p>CUSTOMER:</p>',4,''),(356049,113429,'74844','watch','font-size','14',0,''),(356050,113429,'74844','watch','font-weight','bold',0,''),(356051,113429,'74844','watch','text-align','center',0,''),(356052,113429,'74844','watch','padding-bottom','10',0,''),(356053,113429,'74844','watch','padding-top','10',0,''),(356054,113430,'74845','watch','text','<p>Order date:</p>\n',1,''),(356055,113430,'74845','watch','font-weight','bold',0,''),(356056,113430,'74845','watch','text-align','center',0,''),(356057,113430,'74845','watch','font-size','12',0,''),(356058,113430,'74845','watch','text','<p>Order date:</p>\n',2,''),(356059,113430,'74845','watch','text','<p>Order date:</p>\n',3,''),(356060,113430,'74845','watch','text','<p>Order date:</p>\n',4,''),(356061,113431,'74846','watch','font-weight','normal',0,''),(356062,113431,'74846','watch','text-align','center',0,''),(356063,113431,'74846','watch','padding-bottom','10',0,''),(356064,113432,'74847','watch','block_type','5',0,''),(356065,113432,'74847','watch','font-weight','normal',0,''),(356066,113432,'74847','watch','border-bottom-width','1',0,''),(356067,113432,'74847','watch','border-bottom-color','$content-border-1',0,''),(356068,113432,'74847','watch','border-top-width','1',0,''),(356069,113432,'74847','watch','border-top-color','$content-border-1',0,''),(356070,113432,'74847','watch','border-left-color','$content-border-1',0,''),(356071,113432,'74847','watch','border-left-width','1',0,''),(356072,113433,'74848','watch','block_type','1',0,''),(356073,113433,'74848','watch','font-weight','normal',0,''),(356074,113433,'74848','watch','padding-top','10',0,''),(356075,113433,'74848','watch','padding-left','10',0,''),(356076,113433,'74848','watch','padding-right','10',0,''),(356077,113434,'74849','watch','font-weight','400',0,''),(356078,113434,'74849','watch','line-height','120',0,''),(356079,113434,'74849','watch','line_height_measure','%',0,''),(356080,113434,'74849','watch','font-size','12',0,''),(356081,113435,'74850','watch','text','<p>SHIPPING ADDRESS:</p>',1,''),(356082,113435,'74850','watch','font-size','14',0,''),(356083,113435,'74850','watch','font-weight','bold',0,''),(356084,113435,'74850','watch','padding-bottom','10',0,''),(356085,113435,'74850','watch','text','<p>SHIPPING ADDRESS:</p>',2,''),(356086,113435,'74850','watch','text','<p>SHIPPING ADDRESS:</p>',3,''),(356087,113435,'74850','watch','text','<p>SHIPPING ADDRESS:</p>',4,''),(356088,113436,'74851','watch','block_type','1',0,''),(356089,113437,'74852','watch','block_type','6',0,''),(356090,113438,'74853','watch','aria_name','account-menu',0,''),(356148,113458,'74854','watch','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(356149,113459,'74855','watch','link','Quotation Info',0,''),(356150,113459,'74855','watch','margin-bottom','20',0,''),(356151,113460,'74856','watch','block_type','1',0,''),(356152,113461,'74857','watch','block_type','6',0,''),(356153,113461,'74857','watch','schema','6-3',0,'5240'),(356154,113462,'74858','watch','aria_name','account-menu',0,''),(356212,113482,'74859','watch','block_type','3',0,''),(356213,113483,'74860','watch','block_type','1',0,''),(356214,113483,'74860','watch','padding-right','20',0,''),(356215,113483,'74860','watch','padding-bottom','20',0,''),(356216,113484,'74861','watch','orders_data','name',0,''),(356217,113485,'74862','watch','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(356218,113486,'74863','watch','block_type','1',0,''),(356219,113486,'74863','watch','padding-right','20',0,''),(356220,113486,'74863','watch','padding-bottom','20',0,''),(356221,113487,'74864','watch','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(356222,113488,'74865','watch','orders_data','telephone',0,''),(356223,113489,'74866','watch','block_type','1',0,''),(356224,113489,'74866','watch','padding-right','20',0,''),(356225,113490,'74867','watch','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(356226,113491,'74868','watch','orders_data','shipping_method',0,''),(356227,113492,'74869','watch','block_type','1',0,''),(356228,113492,'74869','watch','padding-right','20',0,''),(356229,113492,'74869','watch','padding-bottom','20',0,''),(356230,113493,'74870','watch','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(356231,113494,'74871','watch','orders_data','delivery_address',0,''),(356232,113495,'74872','watch','block_type','1',0,''),(356233,113495,'74872','watch','padding-bottom','20',0,''),(356234,113496,'74873','watch','orders_data','billing_address',0,''),(356235,113497,'74874','watch','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(356236,113498,'74875','watch','block_type','1',0,''),(356237,113499,'74876','watch','orders_data','payment_method',0,''),(356238,113500,'74877','watch','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(356239,113501,'74878','watch','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(356240,113503,'74880','watch','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(356241,113506,'74883','watch','block_type','2',0,''),(356242,113506,'74883','watch','padding-top','20',0,''),(356243,113506,'74883','watch','margin-bottom','20',0,''),(356244,113507,'74884','watch','like_button','1',0,''),(356245,113507,'74884','watch','text','IMAGE_BUTTON_BACK',0,''),(356246,113507,'74884','watch','link','Quotations',0,''),(356247,113508,'74885','watch','text','<h1>##HEADING_TITLE##</h1>',0,''),(356248,113509,'74886','watch','padding-top','20',0,''),(356249,113509,'74886','watch','padding-bottom','20',0,''),(356250,113509,'74886','watch','block_type','1',0,''),(356251,113509,'74886','watch','background-color','$content-bg-2',0,''),(356252,113511,'74888','watch','block_type','4',0,''),(356253,113512,'74889','watch','background-color','$content-bg-1',0,''),(356254,113513,'74890','watch','block_type','1',0,''),(356255,113513,'74890','watch','style_class','order-summary',0,''),(356256,113513,'74890','watch','margin-left','30',0,''),(356257,113514,'74891','watch','block_type','1',0,''),(356258,113514,'74891','watch','padding-left','20',0,''),(356259,113514,'74891','watch','padding-right','20',0,''),(356260,113514,'74891','watch','padding-bottom','30',0,''),(356261,113517,'74894','watch','block_type','1',0,''),(356324,113541,'74899','watch','block_type','1',0,''),(356325,113543,'74901','watch','pagination','bottom',0,''),(356326,113544,'74902','watch','width','800',0,''),(356327,113545,'74903','watch','block_type','11',0,''),(356328,113545,'74903','watch','border-top-width','1',0,''),(356329,113545,'74903','watch','border-left-width','1',0,''),(356330,113545,'74903','watch','border-right-width','1',0,''),(356331,113545,'74903','watch','border-bottom-width','1',0,''),(356332,113545,'74903','watch','border-top-color','$content-border-1',0,''),(356333,113545,'74903','watch','border-left-color','$content-border-1',0,''),(356334,113545,'74903','watch','border-right-color','$content-border-1',0,''),(356335,113545,'74903','watch','border-bottom-color','$content-border-1',0,''),(356336,113546,'74904','watch','block_type','1',0,''),(356337,113546,'74904','watch','border-right-width','1',0,''),(356338,113546,'74904','watch','border-right-color','$content-border-1',0,''),(356339,113546,'74904','watch','padding-top','10',0,''),(356340,113546,'74904','watch','padding-right','10',0,''),(356341,113546,'74904','watch','padding-bottom','10',0,''),(356342,113547,'74905','watch','block_type','9',0,''),(356343,113548,'74906','watch','text','1.',0,''),(356344,113548,'74906','watch','font-size','12',0,''),(356345,113548,'74906','watch','text-align','right',0,''),(356346,113548,'74906','watch','padding-right','5',0,''),(356347,113549,'74907','watch','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(356348,113549,'74907','watch','font-size','12',0,''),(356349,113549,'74907','watch','padding-bottom','5',0,''),(356350,113550,'74908','watch','block_type','9',0,''),(356351,113551,'74909','watch','text','4.',0,''),(356352,113551,'74909','watch','font-size','12',0,''),(356353,113551,'74909','watch','text-align','right',0,''),(356354,113551,'74909','watch','margin-right','5',0,''),(356355,113552,'74910','watch','text','Our Replacement Department will process your request.',0,''),(356356,113552,'74910','watch','font-size','12',0,''),(356357,113552,'74910','watch','padding-bottom','5',0,''),(356358,113553,'74911','watch','block_type','9',0,''),(356359,113554,'74912','watch','text','3.',0,''),(356360,113554,'74912','watch','font-size','12',0,''),(356361,113554,'74912','watch','text-align','right',0,''),(356362,113554,'74912','watch','margin-right','5',0,''),(356363,113555,'74913','watch','text','Return the authorized item(s) per shipping instructions.',0,''),(356364,113555,'74913','watch','font-size','12',0,''),(356365,113555,'74913','watch','padding-bottom','5',0,''),(356366,113556,'74914','watch','block_type','9',0,''),(356367,113557,'74915','watch','text','2.',0,''),(356368,113557,'74915','watch','font-size','12',0,''),(356369,113557,'74915','watch','text-align','right',0,''),(356370,113557,'74915','watch','margin-right','5',0,''),(356371,113558,'74916','watch','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(356372,113558,'74916','watch','font-size','12',0,''),(356373,113558,'74916','watch','padding-bottom','5',0,''),(356374,113559,'74917','watch','block_type','1',0,''),(356375,113559,'74917','watch','padding-left','15',0,''),(356376,113560,'74918','watch','text','Replacement Policy:',0,''),(356377,113560,'74918','watch','font-size','14',0,''),(356378,113560,'74918','watch','padding-bottom','5',0,''),(356379,113560,'74918','watch','font-weight','bold',0,''),(356380,113561,'74919','watch','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(356381,113561,'74919','watch','font-size','11',0,''),(356382,113561,'74919','watch','font-style','italic',0,''),(356383,113561,'74919','watch','padding-bottom','5',0,''),(356384,113562,'74920','watch','block_type','1',0,''),(356385,113562,'74920','watch','border-bottom-width','1',0,''),(356386,113562,'74920','watch','border-bottom-color','$content-border-1',0,''),(356387,113563,'74921','watch','text','Return Material Authorization (RMA) Form',0,''),(356388,113563,'74921','watch','text-align','center',0,''),(356389,113563,'74921','watch','font-size','16',0,''),(356390,113563,'74921','watch','font-weight','bold',0,''),(356391,113564,'74922','watch','text-align','center',0,''),(356393,113564,'74922','watch','padding-top','10',0,''),(356394,113564,'74922','watch','padding-bottom','10',0,''),(356398,113565,'74923','watch','block_type','1',0,''),(356399,113565,'74923','watch','padding-top','10',0,''),(356400,113565,'74923','watch','padding-left','10',0,''),(356401,113565,'74923','watch','padding-right','10',0,''),(356402,113565,'74923','watch','padding-bottom','20',0,''),(356403,113566,'74924','watch','block_type','2',0,''),(356404,113566,'74924','watch','padding-top','5',0,''),(356405,113567,'74925','watch','block_type','11',0,''),(356406,113568,'74926','watch','text','Email:',0,''),(356407,113568,'74926','watch','font-size','12',0,''),(356408,113569,'74927','watch','data','rrDelivery_email_address',0,''),(356409,113569,'74927','watch','font-size','12',0,''),(356410,113570,'74928','watch','block_type','11',0,''),(356411,113571,'74929','watch','text','Phone:',0,''),(356412,113571,'74929','watch','font-size','12',0,''),(356413,113572,'74930','watch','data','rrDelivery_telephone',0,''),(356414,113572,'74930','watch','font-size','12',0,''),(356415,113573,'74931','watch','block_type','2',0,''),(356416,113573,'74931','watch','padding-top','5',0,''),(356417,113574,'74932','watch','block_type','11',0,''),(356418,113575,'74933','watch','text','Country:',0,''),(356419,113575,'74933','watch','font-size','12',0,''),(356420,113576,'74934','watch','data','rrDelivery_country',0,''),(356421,113576,'74934','watch','font-size','12',0,''),(356422,113577,'74935','watch','block_type','11',0,''),(356423,113578,'74936','watch','text','Postcode:',0,''),(356424,113578,'74936','watch','font-size','12',0,''),(356425,113579,'74937','watch','data','rrDelivery_postcode',0,''),(356426,113579,'74937','watch','font-size','12',0,''),(356427,113580,'74938','watch','block_type','2',0,''),(356428,113580,'74938','watch','padding-top','5',0,''),(356429,113581,'74939','watch','block_type','11',0,''),(356430,113582,'74940','watch','text','City:',0,''),(356431,113582,'74940','watch','font-size','12',0,''),(356432,113583,'74941','watch','data','rrDelivery_city',0,''),(356433,113583,'74941','watch','font-size','12',0,''),(356434,113584,'74942','watch','block_type','11',0,''),(356435,113585,'74943','watch','text','State:',0,''),(356436,113585,'74943','watch','font-size','12',0,''),(356437,113586,'74944','watch','data','rrDelivery_state',0,''),(356438,113586,'74944','watch','font-size','12',0,''),(356439,113587,'74945','watch','block_type','9',0,''),(356440,113587,'74945','watch','padding-top','5',0,''),(356441,113588,'74946','watch','text','Address:',0,''),(356442,113588,'74946','watch','font-size','12',0,''),(356443,113589,'74947','watch','data','rrDelivery_street_address',0,''),(356444,113589,'74947','watch','font-size','12',0,''),(356445,113590,'74948','watch','block_type','2',0,''),(356446,113591,'74949','watch','block_type','11',0,''),(356447,113592,'74950','watch','text','Company:',0,''),(356448,113592,'74950','watch','font-size','12',0,''),(356449,113593,'74951','watch','data','rrDelivery_company',0,''),(356450,113593,'74951','watch','font-size','12',0,''),(356451,113594,'74952','watch','block_type','2',0,''),(356452,113595,'74953','watch','text','Contact Name:',0,''),(356453,113595,'74953','watch','font-size','12',0,''),(356454,113596,'74954','watch','data','rrDelivery_name',0,''),(356455,113596,'74954','watch','font-size','12',0,''),(356456,113597,'74955','watch','block_type','2',0,''),(356457,113597,'74955','watch','padding-left','10',0,''),(356458,113597,'74955','watch','padding-top','20',0,''),(356459,113597,'74955','watch','padding-right','10',0,''),(356460,113598,'74956','watch','block_type','5',0,''),(356461,113599,'74957','watch','text','RMA No:',0,''),(356462,113599,'74957','watch','font-size','12',0,''),(356463,113599,'74957','watch','font-weight','bold',0,''),(356464,113600,'74958','watch','data','rrNumber',0,''),(356465,113600,'74958','watch','font-size','12',0,''),(356466,113600,'74958','watch','font-weight','bold',0,''),(356467,113601,'74959','watch','block_type','2',0,''),(356468,113602,'74960','watch','text','Date Issued:',0,''),(356469,113602,'74960','watch','font-size','12',0,''),(356470,113602,'74960','watch','font-weight','bold',0,''),(356471,113603,'74961','watch','data','rrDateCreate',0,''),(356472,113603,'74961','watch','font-size','12',0,''),(356473,113603,'74961','watch','font-weight','bold',0,''),(356474,113604,'74962','watch','block_type','1',0,''),(356475,113605,'74963','watch','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(356476,113605,'74963','watch','font-size','12',0,''),(356477,113605,'74963','watch','font-style','italic',0,''),(356478,113605,'74963','watch','padding-bottom','20',0,''),(356479,113607,'74965','watch','block_type','1',0,''),(356480,113607,'74965','watch','border-top-width','1',0,''),(356481,113607,'74965','watch','border-left-width','1',0,''),(356482,113607,'74965','watch','border-right-width','1',0,''),(356483,113607,'74965','watch','border-bottom-width','1',0,''),(356484,113607,'74965','watch','border-top-color','$content-border-1',0,''),(356485,113607,'74965','watch','border-left-color','$content-border-1',0,''),(356486,113607,'74965','watch','border-right-color','$content-border-1',0,''),(356487,113607,'74965','watch','border-bottom-color','$content-border-1',0,''),(356488,113608,'74966','watch','block_type','11',0,''),(356489,113609,'74967','watch','block_type','1',0,''),(356490,113609,'74967','watch','padding-top','10',0,''),(356491,113609,'74967','watch','padding-right','10',0,''),(356492,113609,'74967','watch','padding-bottom','10',0,''),(356493,113609,'74967','watch','border-right-width','1',0,''),(356494,113609,'74967','watch','border-right-color','$content-border-1',0,''),(356495,113610,'74968','watch','block_type','9',0,''),(356496,113611,'74969','watch','text','4.',0,''),(356497,113611,'74969','watch','font-size','12',0,''),(356498,113611,'74969','watch','text-align','right',0,''),(356499,113611,'74969','watch','padding-right','5',0,''),(356500,113612,'74970','watch','font-size','11',0,''),(356501,113612,'74970','watch','font-style','italic',0,''),(356502,113612,'74970','watch','padding-bottom','5',0,''),(356503,113613,'74971','watch','text','Ship returned items to:',0,''),(356504,113613,'74971','watch','font-size','12',0,''),(356505,113613,'74971','watch','padding-bottom','5',0,''),(356506,113614,'74972','watch','block_type','9',0,''),(356507,113615,'74973','watch','text','3.',0,''),(356508,113615,'74973','watch','font-size','12',0,''),(356509,113615,'74973','watch','text-align','right',0,''),(356510,113615,'74973','watch','padding-right','5',0,''),(356511,113616,'74974','watch','text','Ship only the items that are authorized.',0,''),(356512,113616,'74974','watch','font-size','12',0,''),(356513,113616,'74974','watch','padding-bottom','10',0,''),(356514,113617,'74975','watch','block_type','9',0,''),(356515,113618,'74976','watch','text','1.',0,''),(356516,113618,'74976','watch','font-size','12',0,''),(356517,113618,'74976','watch','text-align','right',0,''),(356518,113618,'74976','watch','padding-right','5',0,''),(356519,113619,'74977','watch','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(356520,113619,'74977','watch','font-size','12',0,''),(356521,113619,'74977','watch','padding-bottom','10',0,''),(356522,113620,'74978','watch','block_type','1',0,''),(356523,113621,'74979','watch','text','Shipping Instructions:',0,''),(356524,113621,'74979','watch','font-weight','bold',0,''),(356525,113621,'74979','watch','font-size','14',0,''),(356526,113621,'74979','watch','padding-bottom','5',0,''),(356527,113621,'74979','watch','padding-left','10',0,''),(356528,113622,'74980','watch','block_type','9',0,''),(356529,113623,'74981','watch','text','2.',0,''),(356530,113623,'74981','watch','font-size','12',0,''),(356531,113623,'74981','watch','text-align','right',0,''),(356532,113623,'74981','watch','padding-right','5',0,''),(356533,113624,'74982','watch','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(356534,113624,'74982','watch','font-size','12',0,''),(356535,113624,'74982','watch','padding-bottom','10',0,''),(356536,113625,'74983','watch','block_type','1',0,''),(356537,113625,'74983','watch','padding-left','10',0,''),(356538,113625,'74983','watch','padding-right','10',0,''),(356539,113625,'74983','watch','padding-bottom','10',0,''),(356540,113626,'74984','watch','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(356541,113626,'74984','watch','font-size','11',0,''),(356542,113626,'74984','watch','font-style','italic',0,''),(356543,113627,'74985','watch','block_type','1',0,''),(356544,113627,'74985','watch','padding-top','10',0,''),(356545,113627,'74985','watch','padding-left','40',0,''),(356546,113627,'74985','watch','padding-right','40',0,''),(356547,113627,'74985','watch','padding-bottom','10',0,''),(356548,113628,'74986','watch','block_type','1',0,''),(356549,113628,'74986','watch','padding-top','10',0,''),(356550,113628,'74986','watch','padding-left','10',0,''),(356551,113628,'74986','watch','padding-right','10',0,''),(356552,113628,'74986','watch','padding-bottom','10',0,''),(356553,113628,'74986','watch','border-top-width','1',0,''),(356554,113628,'74986','watch','border-left-width','1',0,''),(356555,113628,'74986','watch','border-right-width','1',0,''),(356556,113628,'74986','watch','border-bottom-width','1',0,''),(356557,113628,'74986','watch','border-top-color','$content-border-1',0,''),(356558,113628,'74986','watch','border-left-color','$content-border-1',0,''),(356559,113628,'74986','watch','border-right-color','$content-border-1',0,''),(356560,113628,'74986','watch','border-bottom-color','$content-border-1',0,''),(356561,113629,'74987','watch','block_type','3',0,''),(356562,113630,'74988','watch','data','rrDelivery_name',0,''),(356563,113630,'74988','watch','font-size','9',0,''),(356564,113631,'74989','watch','block_type','2',0,''),(356565,113632,'74990','watch','text','RMA#:',0,''),(356566,113632,'74990','watch','font-size','10',0,''),(356567,113633,'74991','watch','data','rrNumber',0,''),(356568,113633,'74991','watch','font-size','9',0,''),(356569,113634,'74992','watch','block_type','5',0,''),(356570,113635,'74993','watch','font-size','9',0,''),(356571,113636,'74994','watch','block_type','1',0,''),(356572,113636,'74994','watch','padding-left','10',0,''),(356573,113636,'74994','watch','padding-right','10',0,''),(356574,113636,'74994','watch','padding-bottom','10',0,''),(356575,113637,'74995','watch','text','Use this space for additional Comments:',0,''),(356576,113637,'74995','watch','font-size','11',0,''),(356577,113637,'74995','watch','font-style','italic',0,''),(356578,113638,'74996','watch','text','&nbsp;',0,''),(356579,113638,'74996','watch','border-bottom-width','1',0,''),(356580,113638,'74996','watch','border-bottom-color','$content-border-1',0,''),(356581,113639,'74997','watch','text','&nbsp;',0,''),(356582,113639,'74997','watch','border-bottom-width','1',0,''),(356583,113639,'74997','watch','border-bottom-color','$content-border-1',0,''),(356584,113639,'74997','watch','padding-top','5',0,''),(356585,113640,'74998','watch','text','&nbsp;',0,''),(356586,113640,'74998','watch','border-bottom-width','1',0,''),(356587,113640,'74998','watch','border-bottom-color','$content-border-1',0,''),(356588,113640,'74998','watch','padding-top','5',0,''),(356589,113641,'74999','watch','text','&nbsp;',0,''),(356590,113641,'74999','watch','border-bottom-width','1',0,''),(356591,113641,'74999','watch','border-bottom-color','$content-border-1',0,''),(356592,113641,'74999','watch','padding-top','5',0,''),(356593,113642,'75000','watch','block_type','3',0,''),(356594,113642,'75000','watch','padding-top','10',0,''),(356595,113642,'75000','watch','padding-bottom','10',0,''),(356596,113642,'75000','watch','padding-right','10',0,''),(356597,113643,'75001','watch','font-size','11',0,''),(356598,113643,'75001','watch','font-weight','bold',0,''),(356599,113643,'75001','watch','text','Return Approval:',0,''),(356600,113643,'75001','watch','padding-top','5',0,''),(356601,113643,'75001','watch','padding-left','10',0,''),(356602,113644,'75002','watch','border-bottom-width','1',0,''),(356603,113644,'75002','watch','border-bottom-color','$content-border-1',0,''),(356604,113644,'75002','watch','text','&nbsp;',0,''),(356605,113645,'75003','watch','block_type','5',0,''),(356606,113646,'75004','watch','text','Date:',0,''),(356607,113646,'75004','watch','padding-top','5',0,''),(356608,113646,'75004','watch','font-size','11',0,''),(356609,113646,'75004','watch','font-weight','bold',0,''),(356610,113646,'75004','watch','padding-left','5',0,''),(356611,113647,'75005','watch','text','&nbsp;',0,''),(356612,113647,'75005','watch','border-bottom-width','1',0,''),(356613,113647,'75005','watch','border-bottom-color','$content-border-1',0,''),(356614,113648,'75006','watch','block_type','3',0,''),(356615,113648,'75006','watch','padding-right','10',0,''),(356616,113649,'75007','watch','text','Customer Signature:',0,''),(356617,113649,'75007','watch','font-weight','bold',0,''),(356618,113649,'75007','watch','font-size','11',0,''),(356619,113649,'75007','watch','padding-top','5',0,''),(356620,113649,'75007','watch','padding-left','10',0,''),(356621,113650,'75008','watch','text','&nbsp;',0,''),(356622,113650,'75008','watch','border-bottom-width','1',0,''),(356623,113650,'75008','watch','border-bottom-color','$content-border-1',0,''),(356624,113651,'75009','watch','block_type','5',0,''),(356625,113652,'75010','watch','text','Date:',0,''),(356626,113652,'75010','watch','padding-top','5',0,''),(356627,113652,'75010','watch','font-size','11',0,''),(356628,113652,'75010','watch','font-weight','bold',0,''),(356629,113652,'75010','watch','padding-left','5',0,''),(356630,113653,'75011','watch','text','&nbsp;',0,''),(356631,113653,'75011','watch','border-bottom-width','1',0,''),(356632,113653,'75011','watch','border-bottom-color','$content-border-1',0,''),(356633,113654,'75012','watch','block_type','1',0,''),(356634,113654,'75012','watch','style_class','item-holder',0,''),(356635,113654,'75012','watch','padding-top','25',0,''),(356636,113654,'75012','watch','padding-bottom','25',0,''),(356637,113654,'75012','watch','text-align','left',0,''),(356638,113654,'75012','watch','border-top-width','1',0,''),(356639,113654,'75012','watch','border-top-color','$content-border-1',0,''),(356640,113655,'75013','watch','block_type','7',0,''),(356641,113655,'75013','watch','schema','7-2',0,'5240'),(356642,113656,'75014','watch','block_type','5',0,''),(356643,113656,'75014','watch','schema','5-2',0,'5240'),(356644,113657,'75015','watch','clear','none',0,''),(356645,113657,'75015','watch','padding-right','20',0,''),(356646,113658,'75016','watch','padding-right','20',0,''),(356647,113658,'75016','watch','max-width','300',0,'5240'),(356648,113658,'75016','watch','margin_left_measure','auto',0,'5240'),(356649,113658,'75016','watch','margin_right_measure','auto',0,'5240'),(356650,113659,'75017','watch','block_type','1',0,''),(356651,113660,'75018','watch','text-align','right',0,''),(356652,113660,'75018','watch','margin-top','4',0,''),(356653,113660,'75018','watch','margin-bottom','7',0,''),(356654,113660,'75018','watch','float','left',0,''),(356655,113661,'75019','watch','padding-top','6',0,''),(356656,113661,'75019','watch','padding-left','5',0,''),(356657,113661,'75019','watch','float','left',0,''),(356658,113661,'75019','watch','clear','none',0,''),(356659,113662,'75020','watch','padding-right','20',0,''),(356660,113663,'75021','watch','description_characters','200',0,''),(356661,113663,'75021','watch','clear','none',0,''),(356662,113663,'75021','watch','padding-right','20',0,''),(356663,113664,'75022','watch','clear','none',0,''),(356664,113665,'75023','watch','margin-bottom','20',0,''),(356665,113666,'75024','watch','block_type','1',0,''),(356666,113666,'75024','watch','padding-left','40',0,''),(356667,113666,'75024','watch','style_class','right-aria',0,''),(356668,113666,'75024','watch','padding-left','0',0,'5240'),(356669,113667,'75025','watch','margin-bottom','15',0,''),(356670,113667,'75025','watch','text-align','right',0,''),(356671,113668,'75026','watch','margin-bottom','10',0,''),(356672,113668,'75026','watch','text-align','right',0,''),(356673,113669,'75027','watch','margin-bottom','10',0,''),(356674,113670,'75028','watch','text-align','right',0,''),(356675,113670,'75028','watch','margin-bottom','15',0,''),(356676,113671,'75030','watch','text-align','right',0,''),(356677,113671,'75030','watch','margin-bottom','10',0,''),(356678,113672,'75031','watch','block_type','1',0,''),(356679,113672,'75031','watch','padding-top','20',0,''),(356680,113672,'75031','watch','padding-bottom','20',0,''),(356681,113672,'75031','watch','background-color','$content-bg-2',0,''),(356682,113674,'75033','watch','block_type','4',0,''),(356683,113675,'75034','watch','padding-bottom','20',0,''),(356684,113675,'75034','watch','background-color','$content-bg-1',0,''),(356685,113676,'75035','watch','style_class','order-summary',0,''),(356686,113676,'75035','watch','padding-left','30',0,''),(356687,113676,'75035','watch','block_type','1',0,''),(356688,113677,'75036','watch','block_type','1',0,''),(356689,113677,'75036','watch','padding-left','20',0,''),(356690,113677,'75036','watch','padding-right','20',0,''),(356691,113677,'75036','watch','padding-bottom','20',0,''),(356692,113677,'75036','watch','padding-top','20',0,''),(356693,113678,'75037','watch','margin-bottom','40',0,''),(356694,113679,'75038','watch','block_type','1',0,''),(356695,113679,'75038','watch','style_class','account-samples',0,''),(356696,113680,'75039','watch','block_type','6',0,''),(356697,113680,'75039','watch','schema','6-3',0,'5240'),(356698,113681,'75040','watch','aria_name','account-menu',0,''),(356756,113701,'75041','watch','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(356757,113702,'75042','watch','show_pagenation','1',0,''),(356758,113702,'75042','watch','link','Sample Info',0,''),(356759,113702,'75042','watch','margin-bottom','20',0,''),(356760,113703,'75043','watch','block_type','1',0,''),(356761,113703,'75043','watch','style_class','account-sample-info',0,''),(356762,113704,'75044','watch','block_type','6',0,''),(356763,113705,'75045','watch','aria_name','account-menu',0,''),(356821,113725,'75046','watch','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(356822,113726,'75047','watch','block_type','2',0,''),(356823,113726,'75047','watch','padding-top','20',0,''),(356824,113726,'75047','watch','margin-bottom','20',0,''),(356825,113727,'75048','watch','like_button','1',0,''),(356826,113727,'75048','watch','text','IMAGE_BUTTON_BACK',0,''),(356827,113727,'75048','watch','link','Samples',0,''),(356828,113729,'75050','watch','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(356829,113732,'75053','watch','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(356830,113733,'75054','watch','block_type','3',0,''),(356831,113734,'75055','watch','block_type','1',0,''),(356832,113734,'75055','watch','padding-right','20',0,''),(356833,113734,'75055','watch','padding-bottom','20',0,''),(356834,113735,'75056','watch','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(356835,113736,'75057','watch','orders_data','telephone',0,''),(356836,113737,'75058','watch','block_type','1',0,''),(356837,113737,'75058','watch','padding-right','20',0,''),(356838,113737,'75058','watch','padding-bottom','20',0,''),(356839,113738,'75059','watch','orders_data','name',0,''),(356840,113739,'75060','watch','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(356841,113740,'75061','watch','block_type','1',0,''),(356842,113740,'75061','watch','padding-right','20',0,''),(356843,113741,'75062','watch','orders_data','shipping_method',0,''),(356844,113742,'75063','watch','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(356845,113743,'75064','watch','block_type','1',0,''),(356846,113743,'75064','watch','padding-right','20',0,''),(356847,113743,'75064','watch','padding-bottom','20',0,''),(356848,113744,'75065','watch','orders_data','delivery_address',0,''),(356849,113745,'75066','watch','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(356850,113746,'75067','watch','block_type','1',0,''),(356851,113747,'75068','watch','orders_data','payment_method',0,''),(356852,113748,'75069','watch','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(356853,113749,'75070','watch','block_type','1',0,''),(356854,113749,'75070','watch','padding-bottom','20',0,''),(356855,113750,'75071','watch','orders_data','billing_address',0,''),(356856,113751,'75072','watch','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(356857,113752,'75073','watch','block_type','1',0,''),(356858,113753,'75074','watch','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(356859,113754,'75075','watch','block_type','6',0,''),(356860,113755,'75076','watch','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(356861,113756,'75077','watch','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(356862,113757,'75078','watch','text','<div class=\"heading-4\">Categories</div>',0,''),(356863,113760,'75081','watch','class','menu-simple',0,''),(356864,113762,'75083','watch','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(356865,113763,'75084','watch','block_type','1',0,''),(356866,113764,'75085','watch','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(356867,113764,'75085','watch','style_class','middle-form',0,''),(356868,113765,'75086','watch','style_class','middle-form',0,''),(356869,113766,'75087','watch','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(356870,113767,'75088','watch','style_class','middle-form',0,''),(356871,113767,'75088','watch','margin-bottom','30',0,''),(356872,113768,'75089','watch','block_type','1',0,''),(356873,113769,'75090','watch','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(356874,113769,'75090','watch','padding-top','100',0,''),(356875,113769,'75090','watch','margin-bottom','100',0,''),(356876,113769,'75090','watch','text-align','center',0,''),(356877,113769,'75090','watch','font-size','20',0,''),(356878,113770,'94795','watch','block_type','1',0,''),(356879,113771,'94796','watch','block_type','6',0,''),(356880,113771,'94796','watch','schema','6-3',0,'5240'),(356881,113772,'94797','watch','aria_name','account-menu',0,''),(356939,113792,'94798','watch','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(356940,113793,'94799','watch','text','##SUBSCRIPTION_TEXT##',0,''),(356941,113795,'1694099590.22143','watch','block_type','1',0,''),(356942,113795,'1694099590.22143','watch','background-color','$content-bg-2',0,''),(356943,113795,'1694099590.22143','watch','padding-bottom','30',0,''),(356944,113795,'1694099590.22143','watch','style_class','success-page',0,''),(356945,113795,'1694099590.22143','watch','color','$content-color-2',0,''),(356946,113796,'1694099590.340695','watch','block_type','12',0,''),(356947,113796,'1694099590.340695','watch','schema','4-2',0,'5240'),(356948,113797,'1694099590.343733','watch','block_type','1',0,''),(356949,113797,'1694099590.343733','watch','padding-right','40',0,''),(356950,113797,'1694099590.343733','watch','padding-right','0',0,'5240'),(356951,113798,'1694099590.345212','watch','block_type','2',0,''),(356952,113798,'1694099590.345212','watch','margin-bottom','20',0,''),(356953,113798,'1694099590.345212','watch','schema','2-2',0,'5232'),(356954,113798,'1694099590.345212','watch','background-color','$content-bg-1',0,''),(356955,113798,'1694099590.345212','watch','color','$content-color-1',0,''),(356956,113799,'1694099590.34749','watch','block_type','1',0,''),(356957,113799,'1694099590.34749','watch','border-right-width','20',0,''),(356958,113799,'1694099590.34749','watch','border-right-color','$content-bg-2',0,''),(356959,113799,'1694099590.34749','watch','margin-right','-10',0,''),(356960,113799,'1694099590.34749','watch','padding-right','30',0,''),(356961,113799,'1694099590.34749','watch','padding-top','20',0,''),(356962,113799,'1694099590.34749','watch','padding-left','30',0,''),(356963,113799,'1694099590.34749','watch','padding-bottom','20',0,''),(356964,113799,'1694099590.34749','watch','border-right-width','0',0,'5240'),(356965,113799,'1694099590.34749','watch','margin-right','0',0,'5240'),(356966,113799,'1694099590.34749','watch','margin-bottom','20',0,'5240'),(356967,113799,'1694099590.34749','watch','padding-left','20',0,'5240'),(356968,113799,'1694099590.34749','watch','padding-right','20',0,'5240'),(356969,113801,'1694099590.351567','watch','margin-bottom','20',0,''),(356970,113802,'1694099590.35337','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(356971,113802,'1694099590.35337','watch','padding-top','20',0,''),(356972,113803,'1694099590.360420','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(356973,113803,'1694099590.360420','watch','clear','none',0,''),(356974,113804,'1694099590.362714','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(356975,113806,'1694099590.365625','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(356976,113806,'1694099590.365625','watch','clear','none',0,''),(356977,113807,'1694099590.367789','watch','block_type','1',0,''),(356978,113807,'1694099590.367789','watch','padding-left','30',0,''),(356979,113807,'1694099590.367789','watch','border-left-width','20',0,''),(356980,113807,'1694099590.367789','watch','border-left-color','$content-bg-2',0,''),(356981,113807,'1694099590.367789','watch','margin-left','-10',0,''),(356982,113807,'1694099590.367789','watch','padding-right','30',0,''),(356983,113807,'1694099590.367789','watch','padding-top','20',0,''),(356984,113807,'1694099590.367789','watch','padding-bottom','20',0,''),(356985,113807,'1694099590.367789','watch','border-left-width','0',0,'5240'),(356986,113809,'1694099590.370690','watch','margin-bottom','20',0,''),(356987,113810,'1694099590.371953','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(356988,113810,'1694099590.371953','watch','clear','none',0,''),(356989,113811,'1694099590.373633','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(356990,113812,'1694099590.37590','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(356991,113812,'1694099590.37590','watch','clear','none',0,''),(356992,113813,'1694099590.376747','watch','text','<div class=\"page-success\">\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>',0,''),(356993,113813,'1694099590.376747','watch','background-color','$content-bg-1',0,''),(356994,113813,'1694099590.376747','watch','margin-bottom','30',0,''),(356995,113813,'1694099590.376747','watch','padding-top','30',0,''),(356996,113813,'1694099590.376747','watch','padding-bottom','30',0,''),(356997,113813,'1694099590.376747','watch','padding-left','30',0,''),(356998,113813,'1694099590.376747','watch','padding-right','30',0,''),(356999,113813,'1694099590.376747','watch','color','$content-color-1',0,''),(357000,113814,'1694099590.38020','watch','block_type','1',0,''),(357001,113814,'1694099590.38020','watch','style_class','order-summary2 hiding-box',0,''),(357002,113815,'1694099590.381373','watch','text-align','center',0,''),(357003,113815,'1694099590.381373','watch','margin-bottom','20',0,''),(357004,113816,'1694099590.382864','watch','text-align','center',0,''),(357005,113819,'1694099590.386683','watch','block_type','12',0,''),(357006,113820,'1694099590.387673','watch','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n</div>\n',0,''),(357007,113820,'1694099590.387673','watch','margin-bottom','20',0,''),(357008,113821,'1694099590.389337','watch','text-align','center',0,''),(357009,113821,'1694099590.389337','watch','padding-top','40',0,''),(357010,113822,'75097','watch','block_type','1',0,''),(357011,113823,'75098','watch','block_type','1',0,''),(357012,113823,'75098','watch','font-weight','normal',0,''),(357013,113824,'75099','watch','block_type','1',0,''),(357014,113824,'75099','watch','text-align','center',0,''),(357015,113824,'75099','watch','padding-top','30',0,''),(357016,113824,'75099','watch','margin-bottom','200',0,''),(357017,113825,'75100','watch','display','inline-block',0,''),(357018,113825,'75100','watch','clear','none',0,''),(357019,113825,'75100','watch','margin-left','20',0,''),(357020,113826,'75101','watch','display','inline-block',0,''),(357021,113827,'75102','watch','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(357026,113832,'75107','watch','width','680',0,''),(357027,113832,'75107','watch','font-weight','normal',0,''),(357028,113832,'75107','watch','font-size','12',0,''),(357029,113832,'75107','watch','padding-top','20',0,''),(357030,113832,'75107','watch','padding-bottom','20',0,''),(357031,113832,'75107','watch','color','$content-color-1',0,''),(357032,113833,'75108','watch','block_type','5',0,''),(357033,113833,'75108','watch','font-weight','normal',0,''),(357034,113833,'75108','watch','border-bottom-width','1',0,''),(357035,113833,'75108','watch','border-bottom-color','$content-border-1',0,''),(357036,113833,'75108','watch','border-top-width','1',0,''),(357037,113833,'75108','watch','border-top-color','$content-border-1',0,''),(357038,113833,'75108','watch','border-left-color','$content-border-1',0,''),(357039,113833,'75108','watch','border-left-width','1',0,''),(357040,113834,'75109','watch','block_type','1',0,''),(357041,113834,'75109','watch','font-weight','normal',0,''),(357042,113834,'75109','watch','padding-top','10',0,''),(357043,113834,'75109','watch','padding-left','10',0,''),(357044,113834,'75109','watch','padding-right','10',0,''),(357045,113835,'75110','watch','font-weight','400',0,''),(357046,113835,'75110','watch','line-height','120',0,''),(357047,113835,'75110','watch','line_height_measure','%',0,''),(357048,113835,'75110','watch','font-size','12',0,''),(357049,113836,'75111','watch','text','<p>SHIPPING ADDRESS:</p>',1,''),(357050,113836,'75111','watch','font-size','14',0,''),(357051,113836,'75111','watch','font-weight','bold',0,''),(357052,113836,'75111','watch','padding-bottom','10',0,''),(357053,113836,'75111','watch','text','<p>SHIPPING ADDRESS:</p>',2,''),(357054,113836,'75111','watch','text','<p>SHIPPING ADDRESS:</p>',3,''),(357055,113836,'75111','watch','text','<p>SHIPPING ADDRESS:</p>',4,''),(357056,113837,'75112','watch','block_type','1',0,''),(357057,113837,'75112','watch','background-color','$content-bg-2',0,''),(357058,113837,'75112','watch','padding-top','20',0,''),(357059,113837,'75112','watch','padding-left','10',0,''),(357060,113837,'75112','watch','padding-right','10',0,''),(357061,113837,'75112','watch','padding-bottom','20',0,''),(357062,113837,'75112','watch','font-size','14',0,''),(357063,113838,'75113','watch','font-weight','normal',0,''),(357064,113838,'75113','watch','text-align','right',0,''),(357065,113838,'75113','watch','font-size','14',0,''),(357066,113838,'75113','watch','box_align','3',0,''),(357067,113839,'75114','watch','block_type','3',0,''),(357068,113839,'75114','watch','font-weight','normal',0,''),(357069,113839,'75114','watch','padding-top','20',0,''),(357070,113840,'75115','watch','text','<p>If undelivered please return to:</p>',1,''),(357071,113840,'75115','watch','font-size','12',0,''),(357072,113840,'75115','watch','font-weight','bold',0,''),(357073,113840,'75115','watch','text','<p>If undelivered please return to:</p>',2,''),(357074,113840,'75115','watch','text','<p>If undelivered please return to:</p>',3,''),(357075,113840,'75115','watch','text','<p>If undelivered please return to:</p>',4,''),(357076,113841,'75116','watch','font-size','12',0,''),(357077,113842,'75117','watch','font-weight','400',0,''),(357078,113842,'75117','watch','text-align','center',0,''),(357079,113842,'75117','watch','padding-top','0',0,''),(357081,113842,'75117','watch','padding-left','20',0,''),(357082,113842,'75117','watch','padding-right','20',0,''),(357086,113843,'75118','watch','text','<p>Thank you for your order</p>',1,''),(357087,113843,'75118','watch','color','$color-8',0,''),(357088,113843,'75118','watch','font-size','13',0,''),(357089,113843,'75118','watch','font-weight','bold',0,''),(357090,113843,'75118','watch','padding-top','5',0,''),(357091,113843,'75118','watch','text-align','center',0,''),(357092,113843,'75118','watch','text','<p>Thank you for your order</p>',2,''),(357093,113843,'75118','watch','text','<p>Thank you for your order</p>',3,''),(357094,113843,'75118','watch','text','<p>Thank you for your order</p>',4,''),(357095,113844,'75119','watch','text','<p>If something has gone wrong please contact us at:</p>',1,''),(357096,113844,'75119','watch','font-size','12',0,''),(357097,113844,'75119','watch','font-weight','bold',0,''),(357098,113844,'75119','watch','text-align','right',0,''),(357099,113844,'75119','watch','text','<p>If something has gone wrong please contact us at:</p>',2,''),(357100,113844,'75119','watch','text','<p>If something has gone wrong please contact us at:</p>',3,''),(357101,113844,'75119','watch','text','<p>If something has gone wrong please contact us at:</p>',4,''),(357102,113845,'75120','watch','block_type','6',0,''),(357103,113845,'75120','watch','font-weight','normal',0,''),(357104,113845,'75120','watch','font-size','16',0,''),(357105,113846,'75121','watch','text','<p>Email:</p>',1,''),(357106,113846,'75121','watch','font-weight','normal',0,''),(357107,113846,'75121','watch','text-align','right',0,''),(357108,113846,'75121','watch','font-size','12',0,''),(357109,113846,'75121','watch','text','<p>Email:</p>',2,''),(357110,113846,'75121','watch','text','<p>Email:</p>',3,''),(357111,113846,'75121','watch','text','<p>Email:</p>',4,''),(357112,113847,'75122','watch','font-weight','normal',0,''),(357113,113847,'75122','watch','text-align','right',0,''),(357114,113847,'75122','watch','font-size','12',0,''),(357115,113848,'75123','watch','block_type','6',0,''),(357116,113848,'75123','watch','font-weight','normal',0,''),(357117,113848,'75123','watch','font-size','16',0,''),(357118,113849,'75124','watch','text','<p>Phone:</p>',1,''),(357119,113849,'75124','watch','font-weight','normal',0,''),(357120,113849,'75124','watch','text-align','right',0,''),(357121,113849,'75124','watch','font-size','12',0,''),(357122,113849,'75124','watch','text','<p>Phone:</p>',2,''),(357123,113849,'75124','watch','text','<p>Phone:</p>',3,''),(357124,113849,'75124','watch','text','<p>Phone:</p>',4,''),(357125,113850,'75125','watch','font-weight','normal',0,''),(357126,113850,'75125','watch','text-align','right',0,''),(357127,113850,'75125','watch','font-size','12',0,''),(357128,113851,'75126','watch','font-weight','400',0,''),(357129,113851,'75126','watch','padding-top','20',0,''),(357130,113851,'75126','watch','padding-bottom','0',0,''),(357131,113851,'75126','watch','font-size','12',0,''),(357132,113852,'75127','watch','block_type','2',0,''),(357133,113852,'75127','watch','font-weight','normal',0,''),(357134,113852,'75127','watch','padding-bottom','20',0,''),(357135,113853,'75128','watch','block_type','11',0,''),(357136,113853,'75128','watch','font-weight','normal',0,''),(357137,113854,'75129','watch','text','<p>Email:</p>',1,''),(357138,113854,'75129','watch','font-weight','normal',0,''),(357139,113854,'75129','watch','text-align','right',0,''),(357140,113854,'75129','watch','text','<p>Email:</p>',2,''),(357141,113854,'75129','watch','text','<p>Email:</p>',3,''),(357142,113854,'75129','watch','text','<p>Email:</p>',4,''),(357143,113855,'75130','watch','font-weight','normal',0,''),(357144,113855,'75130','watch','text-align','right',0,''),(357145,113856,'75131','watch','block_type','11',0,''),(357146,113856,'75131','watch','font-weight','normal',0,''),(357147,113857,'75132','watch','text','<p>Web:</p>',1,''),(357148,113857,'75132','watch','font-weight','normal',0,''),(357149,113857,'75132','watch','text-align','right',0,''),(357150,113857,'75132','watch','text','<p>Web:</p>',2,''),(357151,113857,'75132','watch','text','<p>Web:</p>',3,''),(357152,113857,'75132','watch','text','<p>Web:</p>',4,''),(357153,113858,'75133','watch','font-weight','normal',0,''),(357154,113858,'75133','watch','text-align','right',0,''),(357155,113859,'75134','watch','block_type','1',0,''),(357156,113860,'75135','watch','font-weight','normal',0,''),(357157,113860,'75135','watch','text-align','right',0,''),(357158,113860,'75135','watch','padding-bottom','10',0,''),(357159,113860,'75135','watch','address_spacer',',',0,''),(357160,113860,'75135','watch','font-size','12',0,''),(357161,113861,'75136','watch','block_type','11',0,''),(357162,113861,'75136','watch','font-weight','normal',0,''),(357163,113862,'75137','watch','text','<p>Phone:</p>',1,''),(357164,113862,'75137','watch','font-weight','normal',0,''),(357165,113862,'75137','watch','text-align','right',0,''),(357166,113862,'75137','watch','text','<p>Phone:</p>',2,''),(357167,113862,'75137','watch','text','<p>Phone:</p>',3,''),(357168,113862,'75137','watch','text','<p>Phone:</p>',4,''),(357169,113863,'75138','watch','font-weight','normal',0,''),(357170,113863,'75138','watch','text-align','right',0,''),(357171,113864,'75139','watch','block_type','4',0,''),(357172,113864,'75139','watch','font-weight','normal',0,''),(357173,113864,'75139','watch','border-top-width','1',0,''),(357174,113864,'75139','watch','border-top-color','$content-border-1',0,''),(357175,113864,'75139','watch','border-left-width','1',0,''),(357176,113864,'75139','watch','border-left-color','$content-border-1',0,''),(357177,113864,'75139','watch','border-right-width','1',0,''),(357178,113864,'75139','watch','border-right-color','$content-border-1',0,''),(357179,113864,'75139','watch','border-bottom-width','1',0,''),(357180,113864,'75139','watch','border-bottom-color','$content-border-1',0,''),(357181,113865,'75140','watch','block_type','2',0,''),(357182,113865,'75140','watch','font-weight','normal',0,''),(357183,113865,'75140','watch','border-top-width','1',0,''),(357184,113865,'75140','watch','border-top-color','$content-border-1',0,''),(357185,113865,'75140','watch','border-right-width','1',0,''),(357186,113865,'75140','watch','border-right-color','$content-border-1',0,''),(357187,113866,'75141','watch','block_type','1',0,''),(357188,113866,'75141','watch','font-weight','normal',0,''),(357189,113866,'75141','watch','padding-top','10',0,''),(357190,113866,'75141','watch','padding-left','10',0,''),(357191,113866,'75141','watch','padding-right','10',0,''),(357192,113866,'75141','watch','padding-bottom','10',0,''),(357193,113866,'75141','watch','border-right-width','1',0,''),(357194,113866,'75141','watch','border-right-color','$content-border-1',0,''),(357195,113867,'75142','watch','text','<p>Shipping via</p>',1,''),(357196,113867,'75142','watch','font-weight','bold',0,''),(357197,113867,'75142','watch','font-size','14',0,''),(357198,113867,'75142','watch','text','<p>Shipping via</p>',2,''),(357199,113867,'75142','watch','text','<p>Shipping via</p>',3,''),(357200,113867,'75142','watch','text','<p>Shipping via</p>',4,''),(357201,113869,'75144','watch','block_type','1',0,''),(357202,113869,'75144','watch','font-weight','normal',0,''),(357203,113869,'75144','watch','padding-top','10',0,''),(357204,113869,'75144','watch','padding-left','10',0,''),(357205,113869,'75144','watch','padding-right','10',0,''),(357206,113869,'75144','watch','padding-bottom','10',0,''),(357207,113870,'75145','watch','text','<p>Shipping service</p>',1,''),(357208,113870,'75145','watch','font-weight','bold',0,''),(357209,113870,'75145','watch','font-size','14',0,''),(357210,113870,'75145','watch','text','<p>Shipping service</p>',2,''),(357211,113870,'75145','watch','text','<p>Shipping service</p>',3,''),(357212,113870,'75145','watch','text','<p>Shipping service</p>',4,''),(357213,113872,'75147','watch','block_type','2',0,''),(357214,113872,'75147','watch','font-weight','normal',0,''),(357215,113872,'75147','watch','border-right-width','1',0,''),(357216,113872,'75147','watch','border-right-color','$content-border-1',0,''),(357217,113873,'75148','watch','block_type','1',0,''),(357218,113873,'75148','watch','font-weight','400',0,''),(357219,113873,'75148','watch','background-color','$content-bg-2',0,''),(357220,113873,'75148','watch','padding-top','10',0,''),(357221,113873,'75148','watch','padding-left','10',0,''),(357222,113873,'75148','watch','padding-right','10',0,''),(357223,113873,'75148','watch','padding-bottom','30',0,''),(357224,113874,'75149','watch','font-size','12',0,''),(357225,113875,'75150','watch','text','<p>INVOICE ADDRESS:</p>',1,''),(357226,113875,'75150','watch','font-size','14',0,''),(357227,113875,'75150','watch','font-weight','bold',0,''),(357228,113875,'75150','watch','text','<p>INVOICE ADDRESS:</p>',2,''),(357229,113875,'75150','watch','text','<p>INVOICE ADDRESS:</p>',3,''),(357230,113875,'75150','watch','text','<p>INVOICE ADDRESS:</p>',4,''),(357231,113876,'75151','watch','block_type','1',0,''),(357232,113876,'75151','watch','font-weight','normal',0,''),(357233,113876,'75151','watch','padding-top','10',0,''),(357234,113876,'75151','watch','padding-left','10',0,''),(357235,113876,'75151','watch','padding-right','10',0,''),(357236,113876,'75151','watch','padding-bottom','10',0,''),(357237,113877,'75152','watch','font-weight','normal',0,''),(357238,113878,'75153','watch','text','<p>PHONE NUMBER:</p>',1,''),(357239,113878,'75153','watch','font-size','14',0,''),(357240,113878,'75153','watch','font-weight','bold',0,''),(357241,113878,'75153','watch','padding-top','10',0,''),(357242,113878,'75153','watch','text','<p>PHONE NUMBER:</p>',2,''),(357243,113878,'75153','watch','text','<p>PHONE NUMBER:</p>',3,''),(357244,113878,'75153','watch','text','<p>PHONE NUMBER:</p>',4,''),(357245,113880,'75155','watch','font-weight','normal',0,''),(357246,113881,'75156','watch','text','<p>E-MAIL ADDRESS:</p>',1,''),(357247,113881,'75156','watch','font-weight','bold',0,''),(357248,113881,'75156','watch','font-size','14',0,''),(357249,113881,'75156','watch','padding-top','10',0,''),(357250,113881,'75156','watch','text','<p>E-MAIL ADDRESS:</p>',2,''),(357251,113881,'75156','watch','text','<p>E-MAIL ADDRESS:</p>',3,''),(357252,113881,'75156','watch','text','<p>E-MAIL ADDRESS:</p>',4,''),(357253,113882,'75157','watch','text','<p>CUSTOMER:</p>',1,''),(357254,113882,'75157','watch','font-size','13',0,''),(357255,113882,'75157','watch','font-weight','bold',0,''),(357256,113882,'75157','watch','text','<p>CUSTOMER:</p>',2,''),(357257,113882,'75157','watch','text','<p>CUSTOMER:</p>',3,''),(357258,113882,'75157','watch','text','<p>CUSTOMER:</p>',4,''),(357259,113883,'75158','watch','font-weight','normal',0,''),(357260,113883,'75158','watch','text-align','center',0,''),(357261,113883,'75158','watch','padding-bottom','10',0,''),(357262,113884,'75159','watch','text','<p>Payment date:</p>',1,''),(357263,113884,'75159','watch','font-weight','bold',0,''),(357264,113884,'75159','watch','text-align','center',0,''),(357265,113884,'75159','watch','font-size','12',0,''),(357266,113884,'75159','watch','text','<p>Payment date:</p>',2,''),(357267,113884,'75159','watch','text','<p>Payment date:</p>',3,''),(357268,113884,'75159','watch','text','<p>Payment date:</p>',4,''),(357269,113885,'75160','watch','text','<p>Payment Method:</p>',1,''),(357270,113885,'75160','watch','font-weight','bold',0,''),(357271,113885,'75160','watch','text-align','center',0,''),(357272,113885,'75160','watch','text','<p>Payment Method:</p>',2,''),(357273,113885,'75160','watch','text','<p>Payment Method:</p>',3,''),(357274,113885,'75160','watch','text','<p>Payment Method:</p>',4,''),(357275,113886,'75161','watch','font-size','14',0,''),(357276,113886,'75161','watch','font-weight','bold',0,''),(357277,113886,'75161','watch','text-align','center',0,''),(357278,113886,'75161','watch','padding-bottom','10',0,''),(357279,113886,'75161','watch','padding-top','10',0,''),(357280,113887,'75162','watch','font-weight','normal',0,''),(357281,113887,'75162','watch','text-align','center',0,''),(357282,113887,'75162','watch','padding-bottom','20',0,''),(357283,113888,'75163','watch','font-weight','normal',0,''),(357284,113888,'75163','watch','text-align','center',0,''),(357285,113889,'75194','watch','block_type','1',0,''),(357286,113890,'75195','watch','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(357287,113892,'75418','watch','block_type','1',0,''),(357288,113893,'75419','watch','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(357289,113893,'75419','watch','padding-top','100',0,''),(357290,113893,'75419','watch','margin-bottom','100',0,''),(357291,113893,'75419','watch','text-align','center',0,''),(357292,113893,'75419','watch','font-size','20',0,''),(357293,113894,'75420','watch','block_type','1',0,''),(357294,113894,'75420','watch','background-color','$content-bg-2',0,''),(357295,113894,'75420','watch','padding-bottom','30',0,''),(357296,113895,'75421','watch','block_type','4',0,''),(357297,113895,'75421','watch','schema','4-2',0,'5240'),(357298,113896,'75422','watch','block_type','1',0,''),(357299,113896,'75422','watch','padding-right','40',0,''),(357300,113896,'75422','watch','padding-right','0',0,'5240'),(357301,113897,'75423','watch','block_type','2',0,''),(357302,113897,'75423','watch','margin-bottom','20',0,''),(357303,113897,'75423','watch','schema','2-2',0,'5232'),(357304,113897,'75423','watch','background-color','$content-bg-1',0,''),(357305,113898,'75424','watch','block_type','1',0,''),(357306,113898,'75424','watch','border-right-width','20',0,''),(357307,113898,'75424','watch','border-right-color','$content-border-1',0,''),(357308,113898,'75424','watch','margin-right','-10',0,''),(357309,113898,'75424','watch','padding-right','30',0,''),(357310,113898,'75424','watch','padding-top','20',0,''),(357311,113898,'75424','watch','padding-left','30',0,''),(357312,113898,'75424','watch','padding-bottom','20',0,''),(357313,113898,'75424','watch','border-right-width','0',0,'5240'),(357314,113898,'75424','watch','margin-right','0',0,'5240'),(357315,113898,'75424','watch','margin-bottom','20',0,'5240'),(357316,113898,'75424','watch','padding-left','20',0,'5240'),(357317,113898,'75424','watch','padding-right','20',0,'5240'),(357318,113900,'75426','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(357319,113900,'75426','watch','clear','none',0,''),(357320,113901,'75427','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(357321,113901,'75427','watch','clear','none',0,''),(357322,113902,'75428','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(357323,113904,'75430','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(357324,113904,'75430','watch','padding-top','20',0,''),(357325,113907,'75433','watch','margin-bottom','20',0,''),(357326,113908,'75434','watch','block_type','1',0,''),(357327,113908,'75434','watch','padding-left','30',0,''),(357328,113908,'75434','watch','border-left-width','20',0,''),(357329,113908,'75434','watch','border-left-color','$content-border-1',0,''),(357330,113908,'75434','watch','margin-left','-10',0,''),(357331,113908,'75434','watch','padding-right','30',0,''),(357332,113908,'75434','watch','padding-top','20',0,''),(357333,113908,'75434','watch','padding-bottom','20',0,''),(357334,113908,'75434','watch','border-left-width','0',0,'5240'),(357335,113909,'75435','watch','margin-bottom','20',0,''),(357336,113911,'75437','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(357337,113912,'75438','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(357338,113912,'75438','watch','clear','none',0,''),(357339,113913,'75439','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(357340,113913,'75439','watch','clear','none',0,''),(357341,113914,'75440','watch','block_type','1',0,''),(357342,113914,'75440','watch','padding-right','30',0,''),(357343,113914,'75440','watch','background-color','$content-bg-1',0,''),(357344,113914,'75440','watch','padding-top','20',0,''),(357345,113914,'75440','watch','padding-left','30',0,''),(357346,113914,'75440','watch','padding-bottom','20',0,''),(357347,113914,'75440','watch','padding-left','20',0,'5240'),(357348,113914,'75440','watch','padding-right','20',0,'5240'),(357349,113916,'75442','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(357350,113917,'75443','watch','block_type','1',0,''),(357351,113917,'75443','watch','padding-top','20',0,''),(357352,113917,'75443','watch','padding-left','20',0,''),(357353,113917,'75443','watch','padding-right','20',0,''),(357354,113917,'75443','watch','padding-bottom','20',0,''),(357355,113917,'75443','watch','background-color','$content-bg-1',0,''),(357356,113917,'75443','watch','style_class','order-summary',0,''),(357357,113918,'75444','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(357358,113922,'75448','watch','block_type','1',0,''),(357359,113922,'75448','watch','background-color','$content-bg-2',0,''),(357360,113922,'75448','watch','padding-bottom','30',0,''),(357361,113923,'75449','watch','block_type','4',0,''),(357362,113923,'75449','watch','schema','4-2',0,'5240'),(357363,113924,'75450','watch','block_type','1',0,''),(357364,113924,'75450','watch','padding-right','40',0,''),(357365,113924,'75450','watch','padding-right','0',0,'5240'),(357366,113925,'75451','watch','block_type','2',0,''),(357367,113925,'75451','watch','margin-bottom','20',0,''),(357368,113925,'75451','watch','schema','2-2',0,'5232'),(357369,113925,'75451','watch','background-color','$content-bg-1',0,''),(357370,113926,'75452','watch','block_type','1',0,''),(357371,113926,'75452','watch','border-right-width','20',0,''),(357372,113926,'75452','watch','border-right-color','$content-border-1',0,''),(357373,113926,'75452','watch','margin-right','-10',0,''),(357374,113926,'75452','watch','padding-right','30',0,''),(357375,113926,'75452','watch','padding-top','20',0,''),(357376,113926,'75452','watch','padding-left','30',0,''),(357377,113926,'75452','watch','padding-bottom','20',0,''),(357378,113926,'75452','watch','border-right-width','0',0,'5240'),(357379,113926,'75452','watch','margin-right','0',0,'5240'),(357380,113926,'75452','watch','margin-bottom','20',0,'5240'),(357381,113926,'75452','watch','padding-left','20',0,'5240'),(357382,113926,'75452','watch','padding-right','20',0,'5240'),(357383,113927,'75453','watch','margin-bottom','20',0,''),(357384,113930,'75456','watch','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(357385,113930,'75456','watch','padding-top','20',0,''),(357386,113932,'75458','watch','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(357387,113932,'75458','watch','clear','none',0,''),(357388,113934,'75460','watch','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(357389,113935,'75461','watch','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(357390,113935,'75461','watch','clear','none',0,''),(357391,113936,'75462','watch','block_type','1',0,''),(357392,113936,'75462','watch','padding-left','30',0,''),(357393,113936,'75462','watch','border-left-width','20',0,''),(357394,113936,'75462','watch','border-left-color','$content-border-1',0,''),(357395,113936,'75462','watch','margin-left','-10',0,''),(357396,113936,'75462','watch','padding-right','30',0,''),(357397,113936,'75462','watch','padding-top','20',0,''),(357398,113936,'75462','watch','padding-bottom','20',0,''),(357399,113936,'75462','watch','border-left-width','0',0,'5240'),(357400,113937,'75463','watch','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(357401,113938,'75464','watch','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(357402,113938,'75464','watch','clear','none',0,''),(357403,113939,'75465','watch','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(357404,113939,'75465','watch','clear','none',0,''),(357405,113940,'75466','watch','margin-bottom','20',0,''),(357406,113942,'75468','watch','block_type','1',0,''),(357407,113942,'75468','watch','padding-right','30',0,''),(357408,113942,'75468','watch','background-color','$content-bg-1',0,''),(357409,113942,'75468','watch','padding-top','20',0,''),(357410,113942,'75468','watch','padding-left','30',0,''),(357411,113942,'75468','watch','padding-bottom','20',0,''),(357412,113942,'75468','watch','padding-left','20',0,'5240'),(357413,113942,'75468','watch','padding-right','20',0,'5240'),(357414,113943,'75469','watch','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(357415,113945,'75471','watch','block_type','1',0,''),(357416,113945,'75471','watch','padding-top','20',0,''),(357417,113945,'75471','watch','padding-left','20',0,''),(357418,113945,'75471','watch','padding-right','20',0,''),(357419,113945,'75471','watch','padding-bottom','20',0,''),(357420,113945,'75471','watch','background-color','$content-bg-1',0,''),(357421,113945,'75471','watch','style_class','order-summary',0,''),(357422,113948,'75474','watch','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(357423,113950,'75540','watch','block_type','1',0,''),(357424,113951,'75541','watch','block_type','6',0,''),(357425,113951,'75541','watch','schema','6-3',0,'5240'),(357426,113952,'75542','watch','aria_name','account-menu',0,''),(357427,113953,'73374','watch','block_type','1',0,''),(357428,113953,'73374','watch','padding-top','70',0,''),(357429,113953,'73374','watch','padding-right','30',0,''),(357430,113953,'73374','watch','padding-bottom','30',0,''),(357431,113953,'73374','watch','padding-top','0',0,'5240'),(357432,113953,'73374','watch','padding-left','0',0,'5240'),(357433,113953,'73374','watch','padding-right','0',0,'5240'),(357434,113953,'73374','watch','padding-bottom','0',0,'5240'),(357484,113972,'75543','watch','margin-bottom','20',0,''),(357485,113973,'75544','watch','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(357486,113974,'75545','watch','block_type','1',0,''),(357487,113974,'75545','watch','padding-top','20',0,''),(357488,113974,'75545','watch','padding-bottom','20',0,''),(357489,113976,'75547','watch','padding-top','20',0,''),(357490,113976,'75547','watch','padding-bottom','20',0,''),(357491,113977,'116005','printshop','text','##TEXT_PAGE_NOT_FOUND##',0,''),(357492,113977,'116005','printshop','text-align','center',0,''),(357493,113977,'116005','printshop','padding-top','100',0,''),(357494,113977,'116005','printshop','padding-bottom','100',0,''),(357495,113978,'116006','printshop','block_type','1',0,''),(357614,113994,'116022','printshop','block_type','1',0,''),(357733,114010,'116038','printshop','block_type','1',0,''),(357852,114026,'116054','printshop','block_type','1',0,''),(357971,114042,'116070','printshop','block_type','1',0,''),(358090,114058,'116086','printshop','block_type','1',0,''),(358209,114074,'116102','printshop','block_type','1',0,''),(358210,114074,'116102','printshop','style_class','account-index',0,''),(358445,114132,'116145','printshop','block_type','1',0,''),(358446,114132,'116145','printshop','style_class','account-edit-wrap',0,''),(358513,114156,'116150','printshop','block_type','1',0,''),(358514,114156,'116150','printshop','style_class','account-address-book',0,''),(358590,114181,'116156','printshop','block_type','1',0,''),(358591,114181,'116156','printshop','style_class','account-address-book-process',0,''),(358658,114205,'117906.000001','printshop','block_type','1',0,''),(358659,114205,'117906.000001','printshop','style_class','item-holder',0,''),(358660,114205,'117906.000001','printshop','padding-top','25',0,''),(358661,114205,'117906.000001','printshop','padding-bottom','25',0,''),(358662,114205,'117906.000001','printshop','text-align','left',0,''),(358663,114205,'117906.000001','printshop','border-top-width','1',0,''),(358664,114205,'117906.000001','printshop','border-top-color','$content-border-3',0,''),(358665,114206,'117907.000001','printshop','block_type','7',0,''),(358666,114206,'117907.000001','printshop','schema','7-2',0,'5342'),(358667,114207,'117908.000001','printshop','block_type','5',0,''),(358668,114207,'117908.000001','printshop','schema','5-2',0,'5342'),(358669,114208,'117909.000001','printshop','clear','none',0,''),(358670,114208,'117909.000001','printshop','padding-right','20',0,''),(358671,114209,'117910.000001','printshop','padding-right','20',0,''),(358672,114209,'117910.000001','printshop','max-width','300',0,'5342'),(358673,114209,'117910.000001','printshop','margin_left_measure','auto',0,'5342'),(358674,114209,'117910.000001','printshop','margin_right_measure','auto',0,'5342'),(358675,114210,'117914.000001','printshop','padding-right','20',0,''),(358676,114211,'117915.000001','printshop','description_characters','200',0,''),(358677,114211,'117915.000001','printshop','clear','none',0,''),(358678,114211,'117915.000001','printshop','padding-right','20',0,''),(358679,114212,'117916.000001','printshop','clear','none',0,''),(358680,114213,'117917.000001','printshop','margin-bottom','20',0,''),(358681,114215,'117918.000001','printshop','block_type','1',0,''),(358682,114215,'117918.000001','printshop','padding-left','40',0,''),(358683,114215,'117918.000001','printshop','style_class','right-aria',0,''),(358684,114215,'117918.000001','printshop','padding-left','0',0,'5342'),(358685,114216,'117911.000001','printshop','block_type','1',0,''),(358686,114216,'117911.000001','printshop','text-align','center',0,''),(358687,114217,'117912.000001','printshop','margin-top','4',0,''),(358688,114217,'117912.000001','printshop','margin-bottom','7',0,''),(358689,114218,'117913.000001','printshop','padding-top','6',0,''),(358690,114218,'117913.000001','printshop','padding-left','5',0,''),(358691,114219,'117919.000001','printshop','margin-bottom','15',0,''),(358692,114219,'117919.000001','printshop','text-align','center',0,''),(358693,114220,'117920.000001','printshop','margin-bottom','10',0,''),(358694,114220,'117920.000001','printshop','text-align','center',0,''),(358695,114221,'117922.000001','printshop','text-align','center',0,''),(358696,114221,'117922.000001','printshop','margin-bottom','15',0,''),(358697,114222,'117924.000001','printshop','text-align','center',0,''),(358698,114222,'117924.000001','printshop','margin-bottom','10',0,''),(358699,114224,'120926.000001','printshop','text-align','center',0,''),(358700,114224,'120926.000001','printshop','margin-bottom','15',0,''),(358701,114225,'120927.000001','printshop','text-align','center',0,''),(358702,114225,'120927.000001','printshop','margin-bottom','15',0,''),(358703,114226,'116176','printshop','block_type','1',0,''),(358704,114226,'116176','printshop','style_class','item-holder',0,''),(358705,114226,'116176','printshop','padding-top','25',0,''),(358706,114226,'116176','printshop','padding-left','25',0,''),(358707,114226,'116176','printshop','padding-right','25',0,''),(358708,114226,'116176','printshop','padding-bottom','25',0,''),(358709,114226,'116176','printshop','text-align','left',0,''),(358710,114228,'116178','printshop','margin-bottom','7',0,''),(358711,114229,'116179','printshop','clear','both',0,''),(358712,114232,'116182','printshop','block_type','1',0,''),(358713,114232,'116182','printshop','style_class','item-holder',0,''),(358714,114232,'116182','printshop','padding-top','25',0,''),(358715,114232,'116182','printshop','padding-left','25',0,''),(358716,114232,'116182','printshop','padding-right','25',0,''),(358717,114232,'116182','printshop','padding-bottom','25',0,''),(358718,114232,'116182','printshop','text-align','left',0,''),(358719,114233,'116183','printshop','block_type','5',0,''),(358720,114236,'116186','printshop','margin-bottom','7',0,''),(358721,114237,'116187','printshop','clear','both',0,''),(358722,114238,'116188','printshop','block_type','1',0,''),(358723,114239,'116189','printshop','block_type','6',0,''),(358724,114239,'116189','printshop','font-weight','400',0,''),(358725,114239,'116189','printshop','schema','6-2',0,'5363'),(358726,114239,'116189','printshop','schema','6-2',0,'5342'),(358727,114240,'116190','printshop','font-weight','400',0,''),(358728,114240,'116190','printshop','padding-right','40',0,''),(358729,114240,'116190','printshop','padding-right','0',0,'5363'),(358730,114240,'116190','printshop','padding-right','0',0,'5342'),(358731,114241,'116191','printshop','block_type','5',0,''),(358732,114241,'116191','printshop','padding-top','10',0,''),(358733,114241,'116191','printshop','padding-bottom','10',0,''),(358734,114241,'116191','printshop','schema','5-2',0,'5363'),(358735,114241,'116191','printshop','border-top-color','$content-border-3',0,''),(358736,114241,'116191','printshop','border-top-width','1',0,''),(358737,114243,'116193','printshop','float','right',0,''),(358738,114245,'116195','printshop','col_in_row','3',0,''),(358739,114245,'116195','printshop','products_align','left',0,''),(358740,114245,'116195','printshop','font-weight','400',0,''),(358741,114245,'116195','printshop','show_qty_input','0',0,''),(358742,114245,'116195','printshop','listing_type','productListing',0,''),(358743,114245,'116195','printshop','listing_type_rows','no',0,''),(358744,114245,'116195','printshop','show_buy_button_b2b','on',0,''),(358745,114245,'116195','printshop','show_wishlist_button_b2b','1',0,''),(358746,114245,'116195','printshop','show_compare_b2b','1',0,''),(358747,114245,'116195','printshop','show_stock','0',0,''),(358748,114245,'116195','printshop','show_description','0',0,''),(358749,114245,'116195','printshop','show_model','0',0,''),(358750,114245,'116195','printshop','show_properties','0',0,''),(358751,114245,'116195','printshop','show_rating','0',0,''),(358752,114245,'116195','printshop','show_rating_counts','0',0,''),(358753,114245,'116195','printshop','show_price','0',0,''),(358754,114245,'116195','printshop','show_buy_button','0',0,''),(358755,114245,'116195','printshop','show_view_button','0',0,''),(358756,114245,'116195','printshop','show_wishlist_button','0',0,''),(358757,114245,'116195','printshop','show_compare','0',0,''),(358758,114245,'116195','printshop','show_name_rows','0',0,''),(358759,114245,'116195','printshop','show_image_rows','0',0,''),(358760,114245,'116195','printshop','show_stock_rows','0',0,''),(358761,114245,'116195','printshop','show_description_rows','0',0,''),(358762,114245,'116195','printshop','show_model_rows','0',0,''),(358763,114245,'116195','printshop','show_properties_rows','0',0,''),(358764,114245,'116195','printshop','show_rating_rows','0',0,''),(358765,114245,'116195','printshop','show_rating_counts_rows','0',0,''),(358766,114245,'116195','printshop','show_price_rows','0',0,''),(358767,114245,'116195','printshop','show_buy_button_rows','0',0,''),(358768,114245,'116195','printshop','show_qty_input_rows','0',0,''),(358769,114245,'116195','printshop','show_view_button_rows','0',0,''),(358770,114245,'116195','printshop','show_wishlist_button_rows','0',0,''),(358771,114245,'116195','printshop','show_compare_rows','0',0,''),(358772,114245,'116195','printshop','show_name_b2b','0',0,''),(358773,114245,'116195','printshop','show_image_b2b','0',0,''),(358774,114245,'116195','printshop','show_stock_b2b','0',0,''),(358775,114245,'116195','printshop','show_description_b2b','0',0,''),(358776,114245,'116195','printshop','show_model_b2b','0',0,''),(358777,114245,'116195','printshop','show_properties_b2b','0',0,''),(358778,114245,'116195','printshop','show_rating_b2b','0',0,''),(358779,114245,'116195','printshop','show_rating_counts_b2b','0',0,''),(358780,114245,'116195','printshop','show_price_b2b','0',0,''),(358781,114245,'116195','printshop','show_qty_input_b2b','0',0,''),(358782,114245,'116195','printshop','show_view_button_b2b','0',0,''),(358783,114245,'116195','printshop','show_attributes_b2b','0',0,''),(358784,114245,'116195','printshop','items_on_page','9',0,''),(358785,114245,'116195','printshop','col_in_row','2',0,'5342'),(358786,114245,'116195','printshop','col_in_row','1',0,'5363'),(358787,114245,'116195','printshop','product_names_teg','h2',0,''),(358788,114246,'116196','printshop','listing_type','productListing',0,''),(358789,114247,'116197','printshop','block_type','1',0,''),(358790,114247,'116197','printshop','padding-top','10',0,''),(358791,114247,'116197','printshop','padding-bottom','10',0,''),(358792,114247,'116197','printshop','border-bottom-width','1',0,''),(358793,114247,'116197','printshop','border-bottom-color','$content-border-3',0,''),(358794,114247,'116197','printshop','margin-left','0',0,''),(358795,114247,'116197','printshop','margin-right','0',0,''),(358796,114248,'116198','printshop','float','right',0,''),(358797,114248,'116198','printshop','display','none',0,'5363'),(358798,114249,'116199','printshop','margin-right','20',0,''),(358799,114249,'116199','printshop','float','right',0,''),(358800,114249,'116199','printshop','clear','none',0,''),(358801,114249,'116199','printshop','display','none',0,'5342'),(358802,114250,'116200','printshop','float','left',0,''),(358803,114250,'116200','printshop','clear','none',0,''),(358804,114250,'116200','printshop','margin-left','20',0,''),(358805,114250,'116200','printshop','display','none',0,'5363'),(358806,114251,'116201','printshop','float','left',0,''),(358807,114251,'116201','printshop','clear','none',0,''),(358808,114251,'116201','printshop','sort_pos_3','1',0,''),(358809,114251,'116201','printshop','sort_pos_4','2',0,''),(358810,114251,'116201','printshop','sort_pos_10','3',0,''),(358811,114251,'116201','printshop','sort_pos_9','4',0,''),(358812,114251,'116201','printshop','sort_pos_11','5',0,''),(358813,114251,'116201','printshop','sort_pos_12','6',0,''),(358814,114251,'116201','printshop','sort_pos_14','7',0,''),(358815,114251,'116201','printshop','sort_pos_13','8',0,''),(358816,114251,'116201','printshop','sort_pos_8','9',0,''),(358817,114251,'116201','printshop','sort_pos_7','10',0,''),(358818,114251,'116201','printshop','sort_pos_2','11',0,''),(358819,114251,'116201','printshop','sort_pos_1','12',0,''),(358820,114251,'116201','printshop','sort_pos_6','13',0,''),(358821,114251,'116201','printshop','sort_pos_5','14',0,''),(358822,114251,'116201','printshop','sort_pos_0','15',0,''),(358823,114251,'116201','printshop','sort_hide_10','1',0,''),(358824,114251,'116201','printshop','sort_hide_9','1',0,''),(358825,114251,'116201','printshop','hide_icons','1',0,''),(358826,114251,'116201','printshop','sort_hide_16','1',0,''),(358827,114251,'116201','printshop','sort_hide_15','1',0,''),(358828,114251,'116201','printshop','sort_hide_3','0',0,''),(358829,114251,'116201','printshop','sort_hide_4','0',0,''),(358830,114251,'116201','printshop','sort_hide_11','1',0,''),(358831,114251,'116201','printshop','sort_hide_12','1',0,''),(358832,114251,'116201','printshop','sort_hide_14','1',0,''),(358833,114251,'116201','printshop','sort_hide_13','1',0,''),(358834,114251,'116201','printshop','sort_hide_8','0',0,''),(358835,114251,'116201','printshop','sort_hide_7','0',0,''),(358836,114251,'116201','printshop','sort_hide_2','1',0,''),(358837,114251,'116201','printshop','sort_hide_1','1',0,''),(358838,114251,'116201','printshop','sort_hide_6','1',0,''),(358839,114251,'116201','printshop','sort_hide_5','1',0,''),(358840,114251,'116201','printshop','sort_hide_0','1',0,''),(358841,114254,'1683121571.054367','printshop','block_type','1',0,''),(358842,114254,'1683121571.054367','printshop','font-weight','normal',0,''),(358843,114254,'1683121571.054367','printshop','padding-top','20',0,''),(358844,114254,'1683121571.054367','printshop','background-color','$content-bg-2',0,''),(358845,114254,'1683121571.054367','printshop','style_class','shopping-cart-index',0,''),(358846,114254,'1683121571.054367','printshop','color','$content-color-2',0,''),(358847,114255,'1683121571.06664','printshop','block_type','4',0,''),(358848,114255,'1683121571.06664','printshop','schema','4-1',0,'5347'),(358849,114255,'1683121571.06664','printshop','schema','4-2',0,'5342'),(358850,114256,'1683121571.069437','printshop','block_type','1',0,''),(358851,114256,'1683121571.069437','printshop','background-color','$content-bg-1',0,''),(358852,114256,'1683121571.069437','printshop','padding-top','20',0,''),(358853,114256,'1683121571.069437','printshop','padding-bottom','20',0,''),(358854,114256,'1683121571.069437','printshop','padding-left','25',0,''),(358855,114256,'1683121571.069437','printshop','padding-right','25',0,''),(358856,114256,'1683121571.069437','printshop','margin-bottom','5',0,''),(358857,114256,'1683121571.069437','printshop','padding-left','15',0,'5333'),(358858,114256,'1683121571.069437','printshop','padding-right','15',0,'5333'),(358859,114256,'1683121571.069437','printshop','color','$content-color-1',0,''),(358860,114257,'1683121571.078735','printshop','block_type','1',0,''),(358861,114257,'1683121571.078735','printshop','background-color','$content-bg-1',0,''),(358862,114257,'1683121571.078735','printshop','margin-bottom','5',0,''),(358863,114257,'1683121571.078735','printshop','padding-left','25',0,''),(358864,114257,'1683121571.078735','printshop','padding-right','25',0,''),(358865,114257,'1683121571.078735','printshop','padding-bottom','25',0,''),(358866,114257,'1683121571.078735','printshop','padding-left','15',0,'5333'),(358867,114257,'1683121571.078735','printshop','padding-right','15',0,'5333'),(358868,114257,'1683121571.078735','printshop','color','$content-color-1',0,''),(358869,114258,'1683121571.080729','printshop','padding-top','20',0,''),(358870,114258,'1683121571.080729','printshop','padding-bottom','20',0,''),(358871,114259,'1683121571.081549','printshop','block_type','4',0,''),(358872,114259,'1683121571.081549','printshop','padding-bottom','20',0,''),(358873,114259,'1683121571.081549','printshop','padding-top','20',0,''),(358874,114259,'1683121571.081549','printshop','border-bottom-color','$content-border-3',0,''),(358875,114259,'1683121571.081549','printshop','border-bottom-width','1',0,''),(358876,114259,'1683121571.081549','printshop','schema','2-1',0,'5342'),(358877,114259,'1683121571.081549','printshop','schema','2-1',0,'5333'),(358878,114259,'1683121571.081549','printshop','schema','2-2',0,'5363'),(358879,114260,'1683121571.08463','printshop','float','left',0,''),(358880,114260,'1683121571.08463','printshop','float','none',0,'5342'),(358881,114261,'1683121571.085411','printshop','text-align','right',0,''),(358882,114261,'1683121571.085411','printshop','clear','none',0,''),(358883,114261,'1683121571.085411','printshop','float','right',0,''),(358884,114261,'1683121571.085411','printshop','padding-top','22',0,''),(358885,114261,'1683121571.085411','printshop','float','none',0,'5342'),(358886,114261,'1683121571.085411','printshop','text-align','left',0,'5342'),(358887,114262,'1683121571.086647','printshop','float','right',0,''),(358888,114262,'1683121571.086647','printshop','padding-top','26',0,''),(358889,114262,'1683121571.086647','printshop','text-align','left',0,'5363'),(358890,114262,'1683121571.086647','printshop','float','none',0,'5363'),(358891,114263,'1683121571.087562','printshop','block_type','1',0,''),(358892,114263,'1683121571.087562','printshop','font-weight','400',0,''),(358893,114263,'1683121571.087562','printshop','schema','2-2',0,'5333'),(358894,114263,'1683121571.087562','printshop','style_class','closeable-content',0,''),(358895,114264,'1683121571.088844','printshop','block_type','2',0,''),(358896,114264,'1683121571.088844','printshop','schema','2-2',0,'5333'),(358897,114266,'1683121571.09021','printshop','padding-right','24',0,''),(358898,114266,'1683121571.09021','printshop','padding-right','0',0,'5333'),(358899,114266,'1683121571.09021','printshop','padding-bottom','20',0,'5333'),(358900,114267,'1683121571.090954','printshop','text','<div><span>##TEXT_YOUR_SHOPPING_CART##</span></div>',0,''),(358901,114267,'1683121571.090954','printshop','style_class','cartTitle',0,''),(358902,114267,'1683121571.090954','printshop','font-size','36',0,''),(358903,114267,'1683121571.090954','printshop','font-weight','bold',0,''),(358904,114267,'1683121571.090954','printshop','text-align','center',0,''),(358905,114267,'1683121571.090954','printshop','padding-top','20',0,''),(358906,114267,'1683121571.090954','printshop','margin-bottom','20',0,''),(358907,114268,'1683121571.092944','printshop','font-weight','normal',0,''),(358908,114268,'1683121571.092944','printshop','hide_parents','2',0,''),(358909,114268,'1683121571.092944','printshop','background-color','$content-bg-1',0,''),(358910,114268,'1683121571.092944','printshop','padding-top','25',0,''),(358911,114268,'1683121571.092944','printshop','padding-left','25',0,''),(358912,114268,'1683121571.092944','printshop','padding-right','25',0,''),(358913,114268,'1683121571.092944','printshop','padding-bottom','25',0,''),(358914,114268,'1683121571.092944','printshop','margin-bottom','20',0,''),(358915,114268,'1683121571.092944','printshop','color','$content-color-1',0,''),(358916,114269,'1683121571.09410','printshop','style_class','order-summary',0,''),(358917,114269,'1683121571.09410','printshop','block_type','1',0,''),(358918,114269,'1683121571.09410','printshop','margin-left','25',0,''),(358919,114269,'1683121571.09410','printshop','margin-left','0',0,'5342'),(358920,114269,'1683121571.09410','printshop','margin-bottom','30',0,'5342'),(358921,114269,'1683121571.09410','printshop','background-color','$content-bg-1',0,''),(358922,114269,'1683121571.09410','printshop','color','$content-color-1',0,''),(358923,114270,'1683121571.095515','printshop','block_type','1',0,''),(358924,114271,'1683121571.096422','printshop','font-weight','400',0,''),(358925,114271,'1683121571.096422','printshop','padding-right','0',0,'5333'),(358926,114272,'1683121571.107437','printshop','font-weight','400',0,''),(358927,114272,'1683121571.107437','printshop','box_align','4',0,''),(358928,114272,'1683121571.107437','printshop','text-align','center',0,'5333'),(358929,114272,'1683121571.107437','printshop','float','none',0,'5333'),(358930,114272,'1683121571.107437','printshop','width','100',0,'5333'),(358931,114272,'1683121571.107437','printshop','width_measure','%',0,'5333'),(358932,114273,'1683121571.108775','printshop','style_class','bottom-totals',0,''),(358933,114274,'1683121571.109664','printshop','style_class','top-totals',0,''),(358934,114275,'1683121571.110832','printshop','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(358935,114276,'116242','printshop','block_type','1',0,''),(358936,114276,'116242','printshop','font-weight','normal',0,''),(358937,114276,'116242','printshop','padding-top','20',0,''),(358938,114276,'116242','printshop','background-color','$content-bg-2',0,''),(358939,114278,'116244','printshop','block_type','4',0,''),(358940,114278,'116244','printshop','schema','4-1',0,'5347'),(358941,114278,'116244','printshop','schema','4-2',0,'5342'),(358942,114279,'116245','printshop','block_type','1',0,''),(358943,114279,'116245','printshop','background-color','$content-bg-1',0,''),(358944,114279,'116245','printshop','padding-top','20',0,''),(358945,114279,'116245','printshop','padding-bottom','20',0,''),(358946,114279,'116245','printshop','padding-left','25',0,''),(358947,114279,'116245','printshop','padding-right','25',0,''),(358948,114279,'116245','printshop','margin-bottom','30',0,''),(358949,114280,'116246','printshop','col_in_row','3',0,''),(358950,114280,'116246','printshop','show_description','1',0,''),(358951,114280,'116246','printshop','show_model','1',0,''),(358952,114280,'116246','printshop','show_properties','1',0,''),(358953,114280,'116246','printshop','show_rating','1',0,''),(358954,114280,'116246','printshop','show_rating_counts','1',0,''),(358955,114280,'116246','printshop','show_qty_input','1',0,''),(358956,114280,'116246','printshop','show_view_button','1',0,''),(358957,114280,'116246','printshop','show_wishlist_button','1',0,''),(358958,114280,'116246','printshop','show_compare','1',0,''),(358959,114280,'116246','printshop','view_as','carousel',0,''),(358960,114280,'116246','printshop','hide_parents','2',0,''),(358961,114281,'116247','printshop','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(358962,114281,'116247','printshop','style_class','bell-ico',0,''),(358963,114282,'116248','printshop','block_type','1',0,''),(358964,114282,'116248','printshop','background-color','$content-bg-1',0,''),(358965,114282,'116248','printshop','margin-bottom','30',0,''),(358966,114283,'116249','printshop','padding-top','20',0,''),(358967,114283,'116249','printshop','padding-left','25',0,''),(358968,114283,'116249','printshop','padding-right','25',0,''),(358969,114283,'116249','printshop','padding-bottom','20',0,''),(358970,114284,'116250','printshop','block_type','2',0,''),(358971,114284,'116250','printshop','padding-bottom','20',0,''),(358972,114284,'116250','printshop','padding-top','20',0,''),(358973,114284,'116250','printshop','padding-left','25',0,''),(358974,114284,'116250','printshop','padding-right','25',0,''),(358975,114284,'116250','printshop','border-bottom-color','$content-border-3',0,''),(358976,114284,'116250','printshop','border-bottom-width','1',0,''),(358977,114284,'116250','printshop','schema','2-2',0,'5342'),(358978,114285,'116251','printshop','float','left',0,''),(358979,114286,'116252','printshop','text-align','right',0,''),(358980,114286,'116252','printshop','clear','none',0,''),(358981,114286,'116252','printshop','float','right',0,''),(358982,114286,'116252','printshop','padding-top','22',0,''),(358983,114287,'116253','printshop','float','right',0,''),(358984,114287,'116253','printshop','padding-top','26',0,''),(358985,114288,'116254','printshop','block_type','1',0,''),(358986,114288,'116254','printshop','padding-top','20',0,''),(358987,114288,'116254','printshop','padding-bottom','20',0,''),(358988,114288,'116254','printshop','padding-left','25',0,''),(358989,114288,'116254','printshop','padding-right','25',0,''),(358990,114288,'116254','printshop','background-color','$content-bg-1',0,''),(358991,114288,'116254','printshop','margin-bottom','30',0,''),(358992,114289,'116255','printshop','hide_parents','2',0,''),(358993,114290,'116256','printshop','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(358994,114291,'116257','printshop','block_type','1',0,''),(358995,114291,'116257','printshop','background-color','$content-bg-1',0,''),(358996,114291,'116257','printshop','padding-top','20',0,''),(358997,114291,'116257','printshop','padding-bottom','20',0,''),(358998,114291,'116257','printshop','padding-left','25',0,''),(358999,114291,'116257','printshop','padding-right','25',0,''),(359000,114291,'116257','printshop','margin-bottom','30',0,''),(359001,114291,'116257','printshop','style_class','closeable-box',0,''),(359002,114292,'116258','printshop','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(359003,114292,'116258','printshop','style_class','savings-ico closeable-heading closeable-event',0,''),(359004,114293,'116259','printshop','block_type','3',0,''),(359005,114293,'116259','printshop','font-weight','400',0,''),(359006,114293,'116259','printshop','schema','2-2',0,'5333'),(359007,114293,'116259','printshop','style_class','closeable-content',0,''),(359008,114293,'116259','printshop','padding-top','10',0,''),(359009,114294,'116260','printshop','font-weight','400',0,''),(359010,114294,'116260','printshop','padding-top','12',0,'5333'),(359011,114294,'116260','printshop','padding-left','0',0,'5333'),(359012,114297,'116263','printshop','block_type','1',0,''),(359013,114297,'116263','printshop','background-color','$content-bg-1',0,''),(359014,114297,'116263','printshop','padding-top','20',0,''),(359015,114297,'116263','printshop','padding-left','25',0,''),(359016,114297,'116263','printshop','padding-right','25',0,''),(359017,114297,'116263','printshop','padding-bottom','20',0,''),(359018,114297,'116263','printshop','margin-bottom','30',0,''),(359019,114297,'116263','printshop','style_class','closeable-box',0,''),(359020,114297,'116263','printshop','display','none',0,'5342'),(359021,114298,'116264','printshop','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(359022,114298,'116264','printshop','style_class','shipping-ico closeable-heading closeable-event',0,''),(359023,114299,'116265','printshop','font-weight','normal',0,''),(359024,114299,'116265','printshop','style_class','closeable-content',0,''),(359025,114299,'116265','printshop','padding-top','10',0,''),(359026,114299,'116265','printshop','hide_parents','2',0,''),(359027,114300,'116266','printshop','style_class','order-summary',0,''),(359028,114300,'116266','printshop','block_type','1',0,''),(359029,114300,'116266','printshop','margin-left','30',0,''),(359030,114300,'116266','printshop','margin-left','0',0,'5342'),(359031,114300,'116266','printshop','margin-bottom','30',0,'5342'),(359032,114301,'116267','printshop','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(359033,114302,'116268','printshop','block_type','1',0,''),(359034,114302,'116268','printshop','padding-left','20',0,''),(359035,114302,'116268','printshop','padding-right','20',0,''),(359036,114302,'116268','printshop','padding-bottom','20',0,''),(359037,114303,'116269','printshop','font-weight','400',0,''),(359038,114303,'116269','printshop','logo','themes/printshop/img/themes/printshop/img/payicons.png',1,''),(359039,114303,'116269','printshop','padding-top','20',0,''),(359040,114303,'116269','printshop','padding-bottom','10',0,''),(359041,114303,'116269','printshop','logo','themes/printshop/img/themes/printshop/img/payicons.png',2,''),(359042,114303,'116269','printshop','logo','themes/printshop/img/themes/printshop/img/payicons.png',3,''),(359043,114303,'116269','printshop','logo','themes/printshop/img/themes/printshop/img/payicons.png',4,''),(359044,114304,'116270','printshop','font-weight','400',0,''),(359045,114304,'116270','printshop','box_align','4',0,''),(359046,114304,'116270','printshop','text-align','center',0,'5333'),(359047,114304,'116270','printshop','float','none',0,'5333'),(359048,114304,'116270','printshop','width','100',0,'5333'),(359049,114304,'116270','printshop','width_measure','%',0,'5333'),(359054,114316,'116272','printshop','block_type','1',0,''),(359055,114319,'1644410221.0341','printshop','block_type','1',0,''),(359056,114319,'1644410221.0341','printshop','background-color','$content-bg-2',0,''),(359057,114319,'1644410221.0341','printshop','padding-top','10',0,''),(359058,114319,'1644410221.0341','printshop','padding-bottom','10',0,''),(359059,114319,'1644410221.0341','printshop','color','$content-color-2',0,''),(359060,114326,'116293','printshop','block_type','1',0,''),(359061,114328,'116295','printshop','block_type','6',0,''),(359062,114328,'116295','printshop','font-weight','400',0,''),(359063,114328,'116295','printshop','schema','6-2',0,'5363'),(359064,114328,'116295','printshop','schema','6-2',0,'5342'),(359065,114329,'116296','printshop','font-weight','400',0,''),(359066,114329,'116296','printshop','padding-right','40',0,''),(359067,114329,'116296','printshop','padding-right','0',0,'5363'),(359068,114329,'116296','printshop','padding-right','0',0,'5342'),(359069,114331,'116298','printshop','col_in_row','3',0,''),(359070,114331,'116298','printshop','products_align','left',0,''),(359071,114331,'116298','printshop','font-weight','400',0,''),(359072,114331,'116298','printshop','show_qty_input','0',0,''),(359073,114331,'116298','printshop','listing_type','productListing',0,''),(359074,114331,'116298','printshop','listing_type_rows','no',0,''),(359075,114331,'116298','printshop','show_buy_button_b2b','on',0,''),(359076,114331,'116298','printshop','show_wishlist_button_b2b','1',0,''),(359077,114331,'116298','printshop','show_compare_b2b','1',0,''),(359078,114331,'116298','printshop','show_stock','0',0,''),(359079,114331,'116298','printshop','show_description','0',0,''),(359080,114331,'116298','printshop','show_model','0',0,''),(359081,114331,'116298','printshop','show_properties','0',0,''),(359082,114331,'116298','printshop','show_rating','0',0,''),(359083,114331,'116298','printshop','show_rating_counts','0',0,''),(359084,114331,'116298','printshop','show_price','0',0,''),(359085,114331,'116298','printshop','show_buy_button','0',0,''),(359086,114331,'116298','printshop','show_view_button','0',0,''),(359087,114331,'116298','printshop','show_wishlist_button','0',0,''),(359088,114331,'116298','printshop','show_compare','0',0,''),(359089,114331,'116298','printshop','show_name_rows','0',0,''),(359090,114331,'116298','printshop','show_image_rows','0',0,''),(359091,114331,'116298','printshop','show_stock_rows','0',0,''),(359092,114331,'116298','printshop','show_description_rows','0',0,''),(359093,114331,'116298','printshop','show_model_rows','0',0,''),(359094,114331,'116298','printshop','show_properties_rows','0',0,''),(359095,114331,'116298','printshop','show_rating_rows','0',0,''),(359096,114331,'116298','printshop','show_rating_counts_rows','0',0,''),(359097,114331,'116298','printshop','show_price_rows','0',0,''),(359098,114331,'116298','printshop','show_buy_button_rows','0',0,''),(359099,114331,'116298','printshop','show_qty_input_rows','0',0,''),(359100,114331,'116298','printshop','show_view_button_rows','0',0,''),(359101,114331,'116298','printshop','show_wishlist_button_rows','0',0,''),(359102,114331,'116298','printshop','show_compare_rows','0',0,''),(359103,114331,'116298','printshop','show_name_b2b','0',0,''),(359104,114331,'116298','printshop','show_image_b2b','0',0,''),(359105,114331,'116298','printshop','show_stock_b2b','0',0,''),(359106,114331,'116298','printshop','show_description_b2b','0',0,''),(359107,114331,'116298','printshop','show_model_b2b','0',0,''),(359108,114331,'116298','printshop','show_properties_b2b','0',0,''),(359109,114331,'116298','printshop','show_rating_b2b','0',0,''),(359110,114331,'116298','printshop','show_rating_counts_b2b','0',0,''),(359111,114331,'116298','printshop','show_price_b2b','0',0,''),(359112,114331,'116298','printshop','show_qty_input_b2b','0',0,''),(359113,114331,'116298','printshop','show_view_button_b2b','0',0,''),(359114,114331,'116298','printshop','show_attributes_b2b','0',0,''),(359115,114331,'116298','printshop','items_on_page','9',0,''),(359116,114331,'116298','printshop','col_in_row','2',0,'5342'),(359117,114331,'116298','printshop','col_in_row','1',0,'5363'),(359118,114331,'116298','printshop','product_names_teg','h2',0,''),(359119,114332,'116299','printshop','block_type','1',0,''),(359120,114332,'116299','printshop','padding-top','10',0,''),(359121,114332,'116299','printshop','padding-bottom','10',0,''),(359122,114332,'116299','printshop','border-bottom-width','1',0,''),(359123,114332,'116299','printshop','border-bottom-color','$content-border-3',0,''),(359124,114332,'116299','printshop','margin-left','0',0,''),(359125,114332,'116299','printshop','margin-right','0',0,''),(359126,114333,'116300','printshop','float','left',0,''),(359127,114333,'116300','printshop','clear','none',0,''),(359128,114333,'116300','printshop','sort_pos_3','1',0,''),(359129,114333,'116300','printshop','sort_pos_4','2',0,''),(359130,114333,'116300','printshop','sort_pos_10','3',0,''),(359131,114333,'116300','printshop','sort_pos_9','4',0,''),(359132,114333,'116300','printshop','sort_pos_11','5',0,''),(359133,114333,'116300','printshop','sort_pos_12','6',0,''),(359134,114333,'116300','printshop','sort_pos_14','7',0,''),(359135,114333,'116300','printshop','sort_pos_13','8',0,''),(359136,114333,'116300','printshop','sort_pos_8','9',0,''),(359137,114333,'116300','printshop','sort_pos_7','10',0,''),(359138,114333,'116300','printshop','sort_pos_2','11',0,''),(359139,114333,'116300','printshop','sort_pos_1','12',0,''),(359140,114333,'116300','printshop','sort_pos_6','13',0,''),(359141,114333,'116300','printshop','sort_pos_5','14',0,''),(359142,114333,'116300','printshop','sort_pos_0','15',0,''),(359143,114333,'116300','printshop','sort_hide_10','1',0,''),(359144,114333,'116300','printshop','sort_hide_9','1',0,''),(359145,114333,'116300','printshop','hide_icons','1',0,''),(359146,114333,'116300','printshop','sort_hide_16','1',0,''),(359147,114333,'116300','printshop','sort_hide_15','1',0,''),(359148,114333,'116300','printshop','sort_hide_3','0',0,''),(359149,114333,'116300','printshop','sort_hide_4','0',0,''),(359150,114333,'116300','printshop','sort_hide_11','1',0,''),(359151,114333,'116300','printshop','sort_hide_12','1',0,''),(359152,114333,'116300','printshop','sort_hide_14','1',0,''),(359153,114333,'116300','printshop','sort_hide_13','1',0,''),(359154,114333,'116300','printshop','sort_hide_8','0',0,''),(359155,114333,'116300','printshop','sort_hide_7','0',0,''),(359156,114333,'116300','printshop','sort_hide_2','1',0,''),(359157,114333,'116300','printshop','sort_hide_1','1',0,''),(359158,114333,'116300','printshop','sort_hide_6','1',0,''),(359159,114333,'116300','printshop','sort_hide_5','1',0,''),(359160,114333,'116300','printshop','sort_hide_0','1',0,''),(359161,114334,'116301','printshop','float','left',0,''),(359162,114334,'116301','printshop','clear','none',0,''),(359163,114334,'116301','printshop','margin-left','20',0,''),(359164,114334,'116301','printshop','display','none',0,'5363'),(359165,114335,'116302','printshop','margin-right','20',0,''),(359166,114335,'116302','printshop','float','right',0,''),(359167,114335,'116302','printshop','clear','none',0,''),(359168,114335,'116302','printshop','display','none',0,'5342'),(359169,114336,'116303','printshop','float','right',0,''),(359170,114336,'116303','printshop','display','none',0,'5363'),(359171,114337,'116304','printshop','listing_type','productListing',0,''),(359172,114339,'116306','printshop','block_type','5',0,''),(359173,114339,'116306','printshop','padding-top','10',0,''),(359174,114339,'116306','printshop','padding-bottom','10',0,''),(359175,114339,'116306','printshop','schema','5-2',0,'5363'),(359176,114339,'116306','printshop','border-top-color','$content-border-3',0,''),(359177,114339,'116306','printshop','border-top-width','1',0,''),(359178,114341,'116308','printshop','float','right',0,''),(359179,114342,'116309','printshop','block_type','1',0,''),(359180,114345,'116312','printshop','block_type','1',0,''),(359181,114345,'116312','printshop','padding-top','10',0,''),(359182,114345,'116312','printshop','padding-bottom','10',0,''),(359183,114345,'116312','printshop','margin-left','0',0,''),(359184,114345,'116312','printshop','margin-right','0',0,''),(359185,114346,'116313','printshop','float','left',0,''),(359186,114346,'116313','printshop','clear','none',0,''),(359187,114346,'116313','printshop','margin-left','20',0,''),(359188,114346,'116313','printshop','display','none',0,'5363'),(359189,114347,'116314','printshop','float','left',0,''),(359190,114347,'116314','printshop','clear','none',0,''),(359191,114347,'116314','printshop','sort_pos_3','2',0,''),(359192,114347,'116314','printshop','sort_pos_4','3',0,''),(359193,114347,'116314','printshop','sort_pos_10','11',0,''),(359194,114347,'116314','printshop','sort_pos_9','10',0,''),(359195,114347,'116314','printshop','sort_pos_11','12',0,''),(359196,114347,'116314','printshop','sort_pos_12','13',0,''),(359197,114347,'116314','printshop','sort_pos_14','15',0,''),(359198,114347,'116314','printshop','sort_pos_13','14',0,''),(359199,114347,'116314','printshop','sort_pos_8','4',0,''),(359200,114347,'116314','printshop','sort_pos_7','5',0,''),(359201,114347,'116314','printshop','sort_pos_2','7',0,''),(359202,114347,'116314','printshop','sort_pos_1','6',0,''),(359203,114347,'116314','printshop','sort_pos_6','9',0,''),(359204,114347,'116314','printshop','sort_pos_5','8',0,''),(359205,114347,'116314','printshop','sort_pos_0','1',0,''),(359206,114347,'116314','printshop','sort_hide_10','1',0,''),(359207,114347,'116314','printshop','sort_hide_9','1',0,''),(359208,114347,'116314','printshop','hide_icons','1',0,''),(359209,114347,'116314','printshop','sort_hide_16','1',0,''),(359210,114347,'116314','printshop','sort_hide_15','1',0,''),(359211,114347,'116314','printshop','sort_hide_3','0',0,''),(359212,114347,'116314','printshop','sort_hide_4','0',0,''),(359213,114347,'116314','printshop','sort_hide_11','1',0,''),(359214,114347,'116314','printshop','sort_hide_12','1',0,''),(359215,114347,'116314','printshop','sort_hide_14','1',0,''),(359216,114347,'116314','printshop','sort_hide_13','1',0,''),(359217,114347,'116314','printshop','sort_hide_8','0',0,''),(359218,114347,'116314','printshop','sort_hide_7','0',0,''),(359219,114347,'116314','printshop','sort_hide_2','1',0,''),(359220,114347,'116314','printshop','sort_hide_1','1',0,''),(359221,114347,'116314','printshop','sort_hide_6','1',0,''),(359222,114347,'116314','printshop','sort_hide_5','1',0,''),(359223,114347,'116314','printshop','sort_hide_0','0',0,''),(359224,114347,'116314','printshop','sort_pos_15','16',0,''),(359225,114347,'116314','printshop','sort_pos_16','17',0,''),(359226,114348,'116315','printshop','margin-right','20',0,''),(359227,114348,'116315','printshop','float','right',0,''),(359228,114348,'116315','printshop','clear','none',0,''),(359229,114348,'116315','printshop','display','none',0,'5342'),(359230,114349,'116316','printshop','float','right',0,''),(359231,114349,'116316','printshop','display','none',0,'5363'),(359232,114350,'116317','printshop','clear','none',0,''),(359233,114350,'116317','printshop','float','left',0,''),(359234,114350,'116317','printshop','padding-top','3',0,''),(359235,114350,'116317','printshop','padding-left','20',0,''),(359236,114351,'116318','printshop','block_type','5',0,''),(359237,114351,'116318','printshop','padding-top','10',0,''),(359238,114351,'116318','printshop','padding-bottom','10',0,''),(359239,114351,'116318','printshop','schema','5-2',0,'5363'),(359240,114351,'116318','printshop','border-top-color','$content-border-3',0,''),(359241,114351,'116318','printshop','border-top-width','1',0,''),(359242,114353,'116320','printshop','float','right',0,''),(359243,114354,'116321','printshop','col_in_row','2',0,''),(359244,114354,'116321','printshop','products_align','left',0,''),(359245,114354,'116321','printshop','font-weight','400',0,''),(359246,114354,'116321','printshop','show_qty_input','0',0,''),(359247,114354,'116321','printshop','listing_type','productListing',0,''),(359248,114354,'116321','printshop','listing_type_rows','Rows',0,''),(359249,114354,'116321','printshop','show_buy_button_b2b','on',0,''),(359250,114354,'116321','printshop','show_wishlist_button_b2b','1',0,''),(359251,114354,'116321','printshop','show_compare_b2b','1',0,''),(359252,114354,'116321','printshop','show_image','0',0,''),(359253,114354,'116321','printshop','show_stock','0',0,''),(359254,114354,'116321','printshop','show_description','0',0,''),(359255,114354,'116321','printshop','show_model','0',0,''),(359256,114354,'116321','printshop','show_properties','0',0,''),(359257,114354,'116321','printshop','show_rating','0',0,''),(359258,114354,'116321','printshop','show_rating_counts','0',0,''),(359259,114354,'116321','printshop','show_price','0',0,''),(359260,114354,'116321','printshop','show_buy_button','0',0,''),(359261,114354,'116321','printshop','show_view_button','0',0,''),(359262,114354,'116321','printshop','show_wishlist_button','0',0,''),(359263,114354,'116321','printshop','show_compare','0',0,''),(359264,114354,'116321','printshop','show_name_rows','0',0,''),(359265,114354,'116321','printshop','show_image_rows','0',0,''),(359266,114354,'116321','printshop','show_stock_rows','0',0,''),(359267,114354,'116321','printshop','show_description_rows','0',0,''),(359268,114354,'116321','printshop','show_model_rows','0',0,''),(359269,114354,'116321','printshop','show_properties_rows','0',0,''),(359270,114354,'116321','printshop','show_rating_rows','0',0,''),(359271,114354,'116321','printshop','show_rating_counts_rows','0',0,''),(359272,114354,'116321','printshop','show_price_rows','0',0,''),(359273,114354,'116321','printshop','show_buy_button_rows','0',0,''),(359274,114354,'116321','printshop','show_qty_input_rows','0',0,''),(359275,114354,'116321','printshop','show_view_button_rows','0',0,''),(359276,114354,'116321','printshop','show_wishlist_button_rows','0',0,''),(359277,114354,'116321','printshop','show_compare_rows','0',0,''),(359278,114354,'116321','printshop','show_name_b2b','0',0,''),(359279,114354,'116321','printshop','show_image_b2b','0',0,''),(359280,114354,'116321','printshop','show_stock_b2b','0',0,''),(359281,114354,'116321','printshop','show_description_b2b','0',0,''),(359282,114354,'116321','printshop','show_model_b2b','0',0,''),(359283,114354,'116321','printshop','show_properties_b2b','0',0,''),(359284,114354,'116321','printshop','show_rating_b2b','0',0,''),(359285,114354,'116321','printshop','show_rating_counts_b2b','0',0,''),(359286,114354,'116321','printshop','show_price_b2b','0',0,''),(359287,114354,'116321','printshop','show_qty_input_b2b','0',0,''),(359288,114354,'116321','printshop','show_view_button_b2b','0',0,''),(359289,114354,'116321','printshop','show_attributes_b2b','0',0,''),(359290,114354,'116321','printshop','items_on_page','12',0,''),(359291,114354,'116321','printshop','col_in_row','1',0,'5363'),(359292,114354,'116321','printshop','product_names_teg','h2',0,''),(359293,114357,'1645199413.4466','printshop','block_type','1',0,''),(359294,114357,'1645199413.4466','printshop','background-color','$content-bg-2',0,''),(359295,114357,'1645199413.4466','printshop','padding-top','10',0,''),(359296,114357,'1645199413.4466','printshop','padding-bottom','10',0,''),(359297,114357,'1645199413.4466','printshop','color','$content-color-2',0,''),(359298,114359,'1683123155.763578','printshop','block_type','1',0,''),(359299,114359,'1683123155.763578','printshop','background-color','$content-bg-2',0,''),(359300,114359,'1683123155.763578','printshop','padding-top','30',0,''),(359301,114359,'1683123155.763578','printshop','padding-bottom','30',0,''),(359302,114359,'1683123155.763578','printshop','style_class','checkout-index-wrap',0,''),(359303,114359,'1683123155.763578','printshop','color','$content-color-2',0,''),(359304,114360,'1683123155.780265','printshop','block_type','4',0,''),(359305,114360,'1683123155.780265','printshop','schema','4-2',0,'5342'),(359306,114361,'1683123155.783425','printshop','block_type','1',0,''),(359307,114361,'1683123155.783425','printshop','padding-right','0',0,'5342'),(359308,114362,'1683123155.78537','printshop','block_type','1',0,''),(359309,114362,'1683123155.78537','printshop','background-color','$content-bg-1',0,''),(359310,114362,'1683123155.78537','printshop','padding-top','30',0,''),(359311,114362,'1683123155.78537','printshop','padding-left','30',0,''),(359312,114362,'1683123155.78537','printshop','padding-right','30',0,''),(359313,114362,'1683123155.78537','printshop','padding-bottom','14',0,''),(359314,114362,'1683123155.78537','printshop','margin-bottom','20',0,''),(359315,114362,'1683123155.78537','printshop','style_class','hiding-box closeable-box',0,''),(359316,114362,'1683123155.78537','printshop','padding-left','15',0,'5333'),(359317,114362,'1683123155.78537','printshop','padding-right','15',0,'5333'),(359318,114362,'1683123155.78537','printshop','padding-top','15',0,'5333'),(359319,114362,'1683123155.78537','printshop','padding-bottom','10',0,'5333'),(359320,114362,'1683123155.78537','printshop','color','$content-color-1',0,''),(359321,114363,'1683123155.788891','printshop','style_class','closeable-content',0,''),(359322,114363,'1683123155.788891','printshop','padding-bottom','20',0,''),(359323,114364,'1683123155.790851','printshop','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(359324,114364,'1683123155.790851','printshop','style_class','closeable-heading closeable-event closed',0,''),(359325,114365,'1683123155.79411','printshop','block_type','1',0,''),(359326,114365,'1683123155.79411','printshop','padding-top','30',0,''),(359327,114365,'1683123155.79411','printshop','padding-left','30',0,''),(359328,114365,'1683123155.79411','printshop','padding-right','30',0,''),(359329,114365,'1683123155.79411','printshop','padding-bottom','14',0,''),(359330,114365,'1683123155.79411','printshop','margin-bottom','20',0,''),(359331,114365,'1683123155.79411','printshop','background-color','$content-bg-1',0,''),(359332,114365,'1683123155.79411','printshop','style_class','hiding-box closeable-box',0,''),(359333,114365,'1683123155.79411','printshop','padding-left','15',0,'5333'),(359334,114365,'1683123155.79411','printshop','padding-right','15',0,'5333'),(359335,114365,'1683123155.79411','printshop','padding-top','15',0,'5333'),(359336,114365,'1683123155.79411','printshop','padding-bottom','10',0,'5333'),(359337,114365,'1683123155.79411','printshop','color','$content-color-1',0,''),(359338,114366,'1683123155.797477','printshop','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(359339,114366,'1683123155.797477','printshop','style_class','closeable-heading closeable-event closed',0,''),(359340,114367,'1683123155.799115','printshop','block_type','2',0,''),(359341,114367,'1683123155.799115','printshop','style_class','closeable-content',0,''),(359342,114367,'1683123155.799115','printshop','schema','2-2',0,'5342'),(359343,114368,'1683123155.800526','printshop','padding-right','20',0,''),(359344,114368,'1683123155.800526','printshop','padding-bottom','20',0,''),(359345,114368,'1683123155.800526','printshop','padding-right','0',0,'5342'),(359346,114369,'1683123155.802510','printshop','padding-left','20',0,''),(359347,114369,'1683123155.802510','printshop','padding-bottom','20',0,''),(359348,114369,'1683123155.802510','printshop','padding-left','0',0,'5342'),(359349,114370,'1683123155.804496','printshop','padding-left','20',0,''),(359350,114370,'1683123155.804496','printshop','padding-bottom','20',0,''),(359351,114370,'1683123155.804496','printshop','padding-left','0',0,'5342'),(359352,114371,'1683123155.806347','printshop','background-color','$content-bg-1',0,''),(359353,114371,'1683123155.806347','printshop','block_type','1',0,''),(359354,114371,'1683123155.806347','printshop','padding-top','30',0,''),(359355,114371,'1683123155.806347','printshop','padding-left','30',0,''),(359356,114371,'1683123155.806347','printshop','padding-right','30',0,''),(359357,114371,'1683123155.806347','printshop','padding-bottom','30',0,''),(359358,114371,'1683123155.806347','printshop','margin-bottom','20',0,''),(359359,114371,'1683123155.806347','printshop','style_class','hiding-box',0,''),(359360,114371,'1683123155.806347','printshop','padding-left','15',0,'5333'),(359361,114371,'1683123155.806347','printshop','padding-right','15',0,'5333'),(359362,114371,'1683123155.806347','printshop','padding-top','15',0,'5333'),(359363,114371,'1683123155.806347','printshop','padding-bottom','15',0,'5333'),(359364,114371,'1683123155.806347','printshop','color','$content-color-1',0,''),(359365,114372,'1683123155.808713','printshop','block_type','1',0,''),(359366,114372,'1683123155.808713','printshop','content','\\_',0,'3'),(359367,114372,'1683123155.808713','printshop','border-top-width','1',0,'3'),(359368,114372,'1683123155.808713','printshop','border-top-color','$content-border-3',0,'3'),(359369,114372,'1683123155.808713','printshop','display','block',0,'3'),(359370,114372,'1683123155.808713','printshop','position','absolute',0,'3'),(359371,114372,'1683123155.808713','printshop','top','19',0,'3'),(359372,114372,'1683123155.808713','printshop','left','0',0,'3'),(359373,114372,'1683123155.808713','printshop','right','0',0,'3'),(359374,114372,'1683123155.808713','printshop','margin-top','-2',0,'3'),(359375,114372,'1683123155.808713','printshop','position','relative',0,''),(359376,114373,'1683123155.81126','printshop','box_align','2',0,''),(359377,114373,'1683123155.81126','printshop','margin-bottom','10',0,''),(359378,114373,'1683123155.81126','printshop','background-color','$content-bg-1',0,''),(359379,114373,'1683123155.81126','printshop','position','relative',0,''),(359380,114374,'1683123155.81663','printshop','background-color','$content-bg-2',0,''),(359381,114374,'1683123155.81663','printshop','padding-top','10',0,''),(359382,114374,'1683123155.81663','printshop','padding-left','10',0,''),(359383,114374,'1683123155.81663','printshop','padding-right','10',0,''),(359384,114374,'1683123155.81663','printshop','padding-bottom','10',0,''),(359385,114374,'1683123155.81663','printshop','margin-top','10',0,''),(359386,114375,'1683123155.81847','printshop','block_type','2',0,''),(359387,114375,'1683123155.81847','printshop','schema','2-2',0,'5342'),(359388,114376,'1683123155.819772','printshop','block_type','1',0,''),(359389,114376,'1683123155.819772','printshop','padding-right','20',0,''),(359390,114376,'1683123155.819772','printshop','padding-left','0',0,'5342'),(359391,114376,'1683123155.819772','printshop','margin-bottom','20',0,'5342'),(359392,114376,'1683123155.819772','printshop','padding-right','0',0,'5342'),(359393,114377,'1683123155.821777','printshop','address_in','popup',0,''),(359394,114378,'1683123155.824396','printshop','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(359395,114381,'1683123155.830610','printshop','block_type','1',0,''),(359396,114381,'1683123155.830610','printshop','padding-left','20',0,''),(359397,114381,'1683123155.830610','printshop','padding-left','0',0,'5342'),(359398,114383,'1683123155.833668','printshop','border-top-width','1',0,''),(359399,114383,'1683123155.833668','printshop','border-top-color','$content-border-3',0,''),(359400,114383,'1683123155.833668','printshop','padding-top','13',0,''),(359401,114383,'1683123155.833668','printshop','padding-bottom','10',0,''),(359402,114384,'1683123155.835296','printshop','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(359403,114385,'1683123155.83711','printshop','show_day','next_day',0,''),(359404,114386,'1683123155.840722','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(359405,114387,'1683123155.842595','printshop','margin-bottom','20',0,''),(359406,114387,'1683123155.842595','printshop','style_class','hiding-box',0,''),(359407,114388,'1683123155.846131','printshop','padding-top','30',0,''),(359408,114388,'1683123155.846131','printshop','padding-left','30',0,''),(359409,114388,'1683123155.846131','printshop','padding-right','30',0,''),(359410,114388,'1683123155.846131','printshop','background-color','$content-bg-1',0,''),(359411,114388,'1683123155.846131','printshop','padding-bottom','30',0,''),(359412,114388,'1683123155.846131','printshop','padding-top','20',0,'5342'),(359413,114388,'1683123155.846131','printshop','padding-left','20',0,'5342'),(359414,114388,'1683123155.846131','printshop','padding-right','20',0,'5342'),(359415,114388,'1683123155.846131','printshop','padding-bottom','20',0,'5342'),(359416,114388,'1683123155.846131','printshop','margin-bottom','20',0,''),(359417,114388,'1683123155.846131','printshop','color','$content-color-1',0,''),(359418,114390,'1683123155.851776','printshop','block_type','1',0,''),(359419,114390,'1683123155.851776','printshop','padding-top','30',0,''),(359420,114390,'1683123155.851776','printshop','padding-left','30',0,''),(359421,114390,'1683123155.851776','printshop','padding-right','30',0,''),(359422,114390,'1683123155.851776','printshop','padding-bottom','23',0,''),(359423,114390,'1683123155.851776','printshop','margin-bottom','20',0,''),(359424,114390,'1683123155.851776','printshop','background-color','$content-bg-1',0,''),(359425,114390,'1683123155.851776','printshop','style_class','hiding-box',0,''),(359426,114390,'1683123155.851776','printshop','padding-left','15',0,'5333'),(359427,114390,'1683123155.851776','printshop','padding-right','15',0,'5333'),(359428,114390,'1683123155.851776','printshop','padding-top','15',0,'5333'),(359429,114390,'1683123155.851776','printshop','padding-bottom','10',0,'5333'),(359430,114390,'1683123155.851776','printshop','color','$content-color-1',0,''),(359431,114391,'1683123155.855125','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(359432,114392,'1683123155.856899','printshop','block_type','2',0,''),(359433,114392,'1683123155.856899','printshop','schema','2-2',0,'5342'),(359434,114393,'1683123155.858186','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359435,114394,'1683123155.859329','printshop','padding-right','20',0,''),(359436,114394,'1683123155.859329','printshop','padding-right','0',0,'5342'),(359437,114394,'1683123155.859329','printshop','padding-bottom','20',0,'5342'),(359438,114394,'1683123155.859329','printshop','address_in','popup',0,''),(359439,114395,'1683123155.863160','printshop','block_type','1',0,''),(359440,114395,'1683123155.863160','printshop','padding-left','20',0,''),(359441,114395,'1683123155.863160','printshop','padding-left','0',0,'5342'),(359442,114397,'1683123155.866124','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359443,114398,'1683123155.867656','printshop','block_type','1',0,''),(359444,114398,'1683123155.867656','printshop','background-color','$content-bg-1',0,''),(359445,114398,'1683123155.867656','printshop','padding-top','30',0,''),(359446,114398,'1683123155.867656','printshop','padding-left','30',0,''),(359447,114398,'1683123155.867656','printshop','padding-right','30',0,''),(359448,114398,'1683123155.867656','printshop','padding-bottom','30',0,''),(359449,114398,'1683123155.867656','printshop','margin-bottom','20',0,''),(359450,114398,'1683123155.867656','printshop','color','$content-color-1',0,''),(359451,114400,'1683123155.87110','printshop','block_type','1',0,''),(359452,114400,'1683123155.87110','printshop','background-color','$content-bg-1',0,''),(359453,114400,'1683123155.87110','printshop','style_class','order-summary',0,''),(359454,114400,'1683123155.87110','printshop','margin-left','25',0,''),(359455,114400,'1683123155.87110','printshop','margin-left','0',0,'5342'),(359456,114400,'1683123155.87110','printshop','color','$content-color-1',0,''),(359457,114401,'1683123155.877884','printshop','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(359458,114401,'1683123155.877884','printshop','text-align','center',0,''),(359459,114401,'1683123155.877884','printshop','font-size','14',0,''),(359460,114401,'1683123155.877884','printshop','color','$fade-color-1',0,''),(359461,114401,'1683123155.877884','printshop','padding-top','10',0,''),(359462,114402,'1683123155.879734','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(359463,114403,'1683123155.881441','printshop','hide_page','1',0,''),(359464,114403,'1683123155.881441','printshop','hide_continue_button','1',0,''),(359465,114404,'1683123155.883138','printshop','margin-bottom','10',0,''),(359466,114407,'116368','printshop','block_type','1',0,''),(359467,114409,'116370','printshop','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(359468,114410,'116371','printshop','link','products',0,''),(359469,114410,'116371','printshop','margin-top','-33',0,''),(359470,114410,'116371','printshop','float','right',0,''),(359471,114411,'116372','printshop','block_type','2',0,''),(359472,114411,'116372','printshop','margin-bottom','20',0,''),(359473,114411,'116372','printshop','schema','2-2',0,'5333'),(359474,114412,'116373','printshop','block_type','1',0,''),(359475,114412,'116373','printshop','padding-right','20',0,''),(359476,114412,'116373','printshop','padding-right','0',0,'5333'),(359477,114413,'116374','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(359478,114413,'116374','printshop','clear','none',0,''),(359479,114415,'116376','printshop','padding-left','20',0,''),(359480,114415,'116376','printshop','block_type','1',0,''),(359481,114415,'116376','printshop','padding-left','0',0,'5333'),(359482,114417,'116378','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359483,114417,'116378','printshop','clear','none',0,''),(359484,114418,'116379','printshop','text-align','right',0,''),(359485,114418,'116379','printshop','margin-bottom','20',0,''),(359486,114418,'116379','printshop','margin-top','20',0,''),(359487,114419,'116380','printshop','block_type','2',0,''),(359488,114419,'116380','printshop','margin-bottom','20',0,''),(359489,114419,'116380','printshop','schema','2-2',0,'5333'),(359490,114420,'116381','printshop','block_type','1',0,''),(359491,114420,'116381','printshop','padding-right','20',0,''),(359492,114420,'116381','printshop','padding-right','0',0,'5333'),(359493,114422,'116383','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(359494,114422,'116383','printshop','clear','none',0,''),(359495,114423,'116384','printshop','block_type','1',0,''),(359496,114423,'116384','printshop','padding-left','20',0,''),(359497,114423,'116384','printshop','padding-left','0',0,'5333'),(359498,114424,'116385','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359499,114424,'116385','printshop','clear','none',0,''),(359500,114426,'116387','printshop','margin-bottom','20',0,''),(359501,114426,'116387','printshop','text-align','right',0,''),(359502,114428,'116402','printshop','block_type','1',0,''),(359503,114429,'116403','printshop','text-align','right',0,''),(359504,114429,'116403','printshop','margin-bottom','20',0,''),(359505,114430,'116404','printshop','block_type','2',0,''),(359506,114430,'116404','printshop','margin-bottom','20',0,''),(359507,114430,'116404','printshop','schema','2-2',0,'5333'),(359508,114431,'116405','printshop','block_type','1',0,''),(359509,114431,'116405','printshop','padding-right','20',0,''),(359510,114431,'116405','printshop','padding-right','0',0,'5333'),(359511,114432,'116406','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359512,114432,'116406','printshop','clear','none',0,''),(359513,114434,'116408','printshop','block_type','1',0,''),(359514,114434,'116408','printshop','padding-left','20',0,''),(359515,114434,'116408','printshop','padding-left','0',0,'5333'),(359516,114435,'116409','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359517,114435,'116409','printshop','clear','none',0,''),(359518,114437,'116411','printshop','margin-bottom','20',0,''),(359519,114437,'116411','printshop','text-align','right',0,''),(359520,114440,'116414','printshop','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(359521,114441,'116389','printshop','block_type','1',0,''),(359522,114442,'116390','printshop','margin-bottom','20',0,''),(359523,114443,'116391','printshop','margin-bottom','20',0,''),(359524,114443,'116391','printshop','text-align','right',0,''),(359525,114444,'116392','printshop','text-align','right',0,''),(359526,114444,'116392','printshop','margin-bottom','20',0,''),(359527,114445,'116393','printshop','block_type','2',0,''),(359528,114445,'116393','printshop','margin-bottom','20',0,''),(359529,114445,'116393','printshop','schema','2-2',0,'5333'),(359530,114446,'116394','printshop','block_type','1',0,''),(359531,114446,'116394','printshop','padding-right','20',0,''),(359532,114446,'116394','printshop','padding-right','0',0,'5333'),(359533,114448,'116396','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359534,114448,'116396','printshop','clear','none',0,''),(359535,114449,'116397','printshop','block_type','1',0,''),(359536,114449,'116397','printshop','padding-left','20',0,''),(359537,114449,'116397','printshop','padding-left','0',0,'5333'),(359538,114451,'116399','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359539,114451,'116399','printshop','clear','none',0,''),(359540,114452,'116400','printshop','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(359541,114453,'116401','printshop','margin-bottom','20',0,''),(359542,114454,'116415','printshop','block_type','1',0,''),(359543,114455,'116416','printshop','block_type','2',0,''),(359544,114455,'116416','printshop','margin-bottom','20',0,''),(359545,114455,'116416','printshop','schema','2-2',0,'5333'),(359546,114456,'116417','printshop','block_type','1',0,''),(359547,114456,'116417','printshop','padding-right','20',0,''),(359548,114456,'116417','printshop','padding-right','0',0,'5333'),(359549,114458,'116419','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(359550,114458,'116419','printshop','clear','none',0,''),(359551,114459,'116420','printshop','block_type','1',0,''),(359552,114459,'116420','printshop','padding-left','20',0,''),(359553,114459,'116420','printshop','padding-left','0',0,'5333'),(359554,114461,'116422','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359555,114461,'116422','printshop','clear','none',0,''),(359556,114462,'116423','printshop','margin-bottom','20',0,''),(359557,114463,'116424','printshop','margin-bottom','20',0,''),(359558,114464,'116425','printshop','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(359559,114465,'116426','printshop','link','products',0,''),(359560,114465,'116426','printshop','margin-top','-33',0,''),(359561,114465,'116426','printshop','float','right',0,''),(359562,114466,'116427','printshop','text-align','right',0,''),(359563,114466,'116427','printshop','margin-bottom','20',0,''),(359564,114467,'116428','printshop','margin-bottom','20',0,''),(359565,114467,'116428','printshop','text-align','right',0,''),(359566,114468,'116429','printshop','block_type','2',0,''),(359567,114468,'116429','printshop','margin-bottom','20',0,''),(359568,114468,'116429','printshop','schema','2-2',0,'5333'),(359569,114469,'116430','printshop','block_type','1',0,''),(359570,114469,'116430','printshop','padding-right','20',0,''),(359571,114469,'116430','printshop','padding-right','0',0,'5333'),(359572,114470,'116431','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(359573,114470,'116431','printshop','clear','none',0,''),(359574,114472,'116433','printshop','padding-left','20',0,''),(359575,114472,'116433','printshop','block_type','1',0,''),(359576,114472,'116433','printshop','padding-left','0',0,'5333'),(359577,114473,'116434','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359578,114473,'116434','printshop','clear','none',0,''),(359579,114475,'116436','printshop','text','##TEXT_CONFIRMATION##',0,''),(359580,114476,'116437','printshop','text','##TEXT_CONFIRMATION##',0,''),(359581,114477,'116439','printshop','text','##TEXT_CONFIRMATION##',0,''),(359582,114478,'116438','printshop','text','##TEXT_CONFIRMATION##',0,''),(359583,114479,'116440','printshop','text','##TEXT_CONFIRMATION##',0,''),(359584,114480,'116441','printshop','text','##TEXT_CONFIRMATION##',0,''),(359585,114481,'116442','printshop','block_type','2',0,''),(359586,114481,'116442','printshop','schema','2-2',0,'5411'),(359587,114481,'116442','printshop','schema','2-1',0,'5333'),(359588,114482,'116443','printshop','block_type','1',0,''),(359589,114482,'116443','printshop','padding-right','20',0,''),(359590,114483,'116444','printshop','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(359591,114485,'116446','printshop','block_type','1',0,''),(359592,114485,'116446','printshop','padding-left','20',0,''),(359593,114485,'116446','printshop','padding-left','0',0,'5342'),(359594,114486,'116447','printshop','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(359595,114488,'116449','printshop','block_type','4',0,''),(359596,114488,'116449','printshop','schema','4-2',0,'5363'),(359597,114488,'116449','printshop','padding-top','20',0,''),(359598,114489,'116450','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359599,114489,'116450','printshop','text-align','right',0,''),(359600,114489,'116450','printshop','padding-top','10',0,''),(359601,114489,'116450','printshop','font_size_measure','em',0,''),(359602,114489,'116450','printshop','font-size','1.2',0,''),(359603,114489,'116450','printshop','text-align','center',0,'5411'),(359604,114490,'116451','printshop','text-align','right',0,''),(359605,114490,'116451','printshop','text-align','center',0,'5411'),(359606,114491,'116452','printshop','block_type','2',0,''),(359607,114491,'116452','printshop','schema','2-1',0,'5333'),(359608,114491,'116452','printshop','schema','2-2',0,'5411'),(359609,114492,'116453','printshop','block_type','1',0,''),(359610,114492,'116453','printshop','padding-right','20',0,''),(359611,114492,'116453','printshop','padding-right','0',0,'5342'),(359612,114493,'116454','printshop','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(359613,114495,'116456','printshop','block_type','1',0,''),(359614,114495,'116456','printshop','padding-right','0',0,'5342'),(359615,114495,'116456','printshop','padding-left','20',0,''),(359616,114495,'116456','printshop','padding-left','0',0,'5333'),(359617,114498,'116459','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(359618,114500,'116461','printshop','block_type','2',0,''),(359619,114501,'116462','printshop','block_type','1',0,''),(359620,114501,'116462','printshop','padding-right','20',0,''),(359621,114503,'116464','printshop','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(359622,114504,'116465','printshop','block_type','1',0,''),(359623,114504,'116465','printshop','padding-left','20',0,''),(359624,114504,'116465','printshop','padding-left','0',0,'5342'),(359625,114505,'116466','printshop','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(359626,114507,'116468','printshop','block_type','4',0,''),(359627,114507,'116468','printshop','schema','4-2',0,'5363'),(359628,114508,'116469','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359629,114508,'116469','printshop','text-align','right',0,''),(359630,114508,'116469','printshop','padding-top','10',0,''),(359631,114508,'116469','printshop','font_size_measure','em',0,''),(359632,114508,'116469','printshop','font-size','1.2',0,''),(359633,114509,'116470','printshop','text-align','right',0,''),(359634,114510,'116471','printshop','block_type','2',0,''),(359635,114511,'116472','printshop','block_type','1',0,''),(359636,114511,'116472','printshop','padding-right','20',0,''),(359637,114511,'116472','printshop','padding-right','0',0,'5342'),(359638,114513,'116474','printshop','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(359639,114514,'116475','printshop','block_type','1',0,''),(359640,114514,'116475','printshop','padding-right','0',0,'5342'),(359641,114514,'116475','printshop','padding-left','20',0,''),(359642,114516,'116477','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(359643,114519,'116480','printshop','block_type','4',0,''),(359644,114519,'116480','printshop','schema','4-2',0,'5363'),(359645,114520,'116481','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359646,114520,'116481','printshop','text-align','right',0,''),(359647,114520,'116481','printshop','padding-top','10',0,''),(359648,114520,'116481','printshop','font_size_measure','em',0,''),(359649,114520,'116481','printshop','font-size','1.2',0,''),(359650,114521,'116482','printshop','text-align','right',0,''),(359651,114522,'116483','printshop','block_type','2',0,''),(359652,114523,'116484','printshop','block_type','1',0,''),(359653,114523,'116484','printshop','padding-right','20',0,''),(359654,114525,'116486','printshop','block_type','1',0,''),(359655,114525,'116486','printshop','padding-left','20',0,''),(359656,114525,'116486','printshop','padding-left','0',0,'5342'),(359657,114526,'116487','printshop','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(359658,114528,'116489','printshop','block_type','4',0,''),(359659,114528,'116489','printshop','schema','4-2',0,'5363'),(359660,114529,'116490','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359661,114529,'116490','printshop','text-align','right',0,''),(359662,114529,'116490','printshop','padding-top','10',0,''),(359663,114529,'116490','printshop','font_size_measure','em',0,''),(359664,114529,'116490','printshop','font-size','1.2',0,''),(359665,114530,'116491','printshop','text-align','right',0,''),(359666,114531,'116492','printshop','block_type','2',0,''),(359667,114532,'116493','printshop','block_type','1',0,''),(359668,114532,'116493','printshop','padding-right','20',0,''),(359669,114534,'116495','printshop','block_type','1',0,''),(359670,114534,'116495','printshop','padding-left','20',0,''),(359671,114534,'116495','printshop','padding-left','0',0,'5342'),(359672,114536,'116497','printshop','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(359673,114537,'116498','printshop','text','##DELIVERY_DETAILS##',0,''),(359674,114538,'116499','printshop','text','##DELIVERY_DETAILS##',0,''),(359675,114539,'116501','printshop','text','##CONTACT_INFORMATION##',0,''),(359676,114540,'116500','printshop','text','##CONTACT_INFORMATION##',0,''),(359677,114541,'116502','printshop','text','##DELIVERY_DETAILS##',0,''),(359678,114542,'116503','printshop','text','##DELIVERY_DETAILS##',0,''),(359679,114543,'116504','printshop','block_type','1',0,''),(359680,114543,'116504','printshop','background-color','$content-bg-2',0,''),(359681,114543,'116504','printshop','padding-top','30',0,''),(359682,114543,'116504','printshop','padding-bottom','30',0,''),(359683,114544,'116505','printshop','block_type','7',0,''),(359684,114544,'116505','printshop','schema','4-2',0,'5342'),(359685,114545,'116506','printshop','block_type','1',0,''),(359686,114545,'116506','printshop','padding-right','0',0,'5342'),(359687,114546,'116508','printshop','block_type','1',0,''),(359688,114546,'116508','printshop','background-color','$content-bg-1',0,''),(359689,114546,'116508','printshop','padding-top','30',0,''),(359690,114546,'116508','printshop','padding-left','30',0,''),(359691,114546,'116508','printshop','padding-right','30',0,''),(359692,114546,'116508','printshop','padding-bottom','30',0,''),(359693,114546,'116508','printshop','margin-bottom','20',0,''),(359694,114546,'116508','printshop','style_class','hiding-box',0,''),(359695,114547,'116509','printshop','margin-bottom','20',0,''),(359696,114548,'116510','printshop','padding-top','10',0,''),(359697,114548,'116510','printshop','padding-left','20',0,''),(359698,114548,'116510','printshop','padding-right','20',0,''),(359699,114548,'116510','printshop','margin-top','20',0,''),(359700,114548,'116510','printshop','background-color','$content-bg-2',0,''),(359701,114548,'116510','printshop','padding-bottom','8',0,''),(359702,114549,'116511','printshop','block_type','1',0,''),(359703,114549,'116511','printshop','background-color','$content-bg-1',0,''),(359704,114549,'116511','printshop','padding-top','30',0,''),(359705,114549,'116511','printshop','padding-left','30',0,''),(359706,114549,'116511','printshop','padding-right','30',0,''),(359707,114549,'116511','printshop','padding-bottom','14',0,''),(359708,114549,'116511','printshop','margin-bottom','20',0,''),(359709,114549,'116511','printshop','style_class','hiding-box closeable-box',0,''),(359710,114550,'116512','printshop','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(359711,114550,'116512','printshop','style_class','closeable-heading closeable-event closed',0,''),(359712,114551,'116513','printshop','style_class','closeable-content',0,''),(359713,114551,'116513','printshop','padding-bottom','20',0,''),(359714,114552,'116514','printshop','background-color','$content-bg-1',0,''),(359715,114552,'116514','printshop','block_type','1',0,''),(359716,114552,'116514','printshop','padding-top','30',0,''),(359717,114552,'116514','printshop','padding-left','30',0,''),(359718,114552,'116514','printshop','padding-right','30',0,''),(359719,114552,'116514','printshop','padding-bottom','30',0,''),(359720,114552,'116514','printshop','margin-bottom','20',0,''),(359721,114552,'116514','printshop','style_class','hiding-box',0,''),(359722,114553,'116515','printshop','block_type','1',0,''),(359723,114553,'116515','printshop','content','\\_',0,'3'),(359724,114553,'116515','printshop','border-top-width','1',0,'3'),(359725,114553,'116515','printshop','border-top-color','$content-border-3',0,'3'),(359726,114553,'116515','printshop','display','block',0,'3'),(359727,114553,'116515','printshop','position','absolute',0,'3'),(359728,114553,'116515','printshop','top','19',0,'3'),(359729,114553,'116515','printshop','left','0',0,'3'),(359730,114553,'116515','printshop','right','0',0,'3'),(359731,114553,'116515','printshop','margin-top','-2',0,'3'),(359732,114553,'116515','printshop','position','relative',0,''),(359733,114554,'116516','printshop','box_align','2',0,''),(359734,114554,'116516','printshop','margin-bottom','10',0,''),(359735,114554,'116516','printshop','background-color','$content-bg-1',0,''),(359736,114554,'116516','printshop','position','relative',0,''),(359737,114555,'116517','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(359738,114556,'116518','printshop','block_type','2',0,''),(359739,114556,'116518','printshop','schema','2-2',0,'5342'),(359740,114557,'116519','printshop','block_type','1',0,''),(359741,114557,'116519','printshop','padding-right','20',0,''),(359742,114557,'116519','printshop','padding-left','0',0,'5342'),(359743,114557,'116519','printshop','margin-bottom','20',0,'5342'),(359744,114557,'116519','printshop','padding-right','0',0,'5342'),(359745,114560,'116522','printshop','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(359746,114561,'116523','printshop','block_type','1',0,''),(359747,114561,'116523','printshop','padding-left','20',0,''),(359748,114561,'116523','printshop','padding-left','0',0,'5342'),(359749,114562,'116524','printshop','padding-bottom','10',0,''),(359750,114563,'116525','printshop','background-color','$content-bg-2',0,''),(359751,114563,'116525','printshop','padding-top','10',0,''),(359752,114563,'116525','printshop','padding-left','10',0,''),(359753,114563,'116525','printshop','padding-right','10',0,''),(359754,114563,'116525','printshop','padding-bottom','10',0,''),(359755,114563,'116525','printshop','margin-top','10',0,''),(359756,114564,'116526','printshop','block_type','1',0,''),(359757,114564,'116526','printshop','padding-top','10',0,''),(359758,114564,'116526','printshop','padding-left','10',0,''),(359759,114564,'116526','printshop','padding-right','10',0,''),(359760,114564,'116526','printshop','padding-bottom','10',0,''),(359761,114564,'116526','printshop','background-color','$content-bg-1',0,''),(359762,114564,'116526','printshop','style_class','order-summary',0,''),(359763,114564,'116526','printshop','margin-left','25',0,''),(359764,114564,'116526','printshop','margin-left','0',0,'5342'),(359765,114565,'116527','printshop','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(359766,114565,'116527','printshop','text-align','center',0,''),(359767,114565,'116527','printshop','font-size','14',0,''),(359768,114565,'116527','printshop','color','$fade-color-1',0,''),(359769,114565,'116527','printshop','padding-top','10',0,''),(359770,114568,'1638957135.2709','printshop','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(359771,114569,'116529','printshop','block_type','1',0,''),(359772,114569,'116529','printshop','background-color','$content-bg-2',0,''),(359773,114569,'116529','printshop','padding-top','30',0,''),(359774,114569,'116529','printshop','padding-bottom','30',0,''),(359775,114569,'116529','printshop','color','$content-color-2',0,''),(359776,114570,'116530','printshop','block_type','7',0,''),(359777,114571,'116531','printshop','block_type','1',0,''),(359778,114572,'116532','printshop','block_type','1',0,''),(359779,114572,'116532','printshop','background-color','$content-bg-1',0,''),(359780,114572,'116532','printshop','padding-top','30',0,''),(359781,114572,'116532','printshop','padding-left','30',0,''),(359782,114572,'116532','printshop','padding-right','30',0,''),(359783,114572,'116532','printshop','padding-bottom','30',0,''),(359784,114572,'116532','printshop','margin-bottom','20',0,''),(359785,114572,'116532','printshop','style_class','hiding-box',0,''),(359786,114572,'116532','printshop','color','$content-color-1',0,''),(359787,114573,'116533','printshop','padding-top','10',0,''),(359788,114573,'116533','printshop','padding-left','20',0,''),(359789,114573,'116533','printshop','padding-right','20',0,''),(359790,114573,'116533','printshop','margin-top','20',0,''),(359791,114573,'116533','printshop','background-color','$content-bg-2',0,''),(359792,114573,'116533','printshop','padding-bottom','8',0,''),(359793,114573,'116533','printshop','color','$content-color-2',0,''),(359794,114574,'116534','printshop','margin-bottom','20',0,''),(359795,114575,'116535','printshop','block_type','1',0,''),(359796,114575,'116535','printshop','padding-top','30',0,''),(359797,114575,'116535','printshop','padding-left','30',0,''),(359798,114575,'116535','printshop','padding-right','30',0,''),(359799,114575,'116535','printshop','padding-bottom','23',0,''),(359800,114575,'116535','printshop','margin-bottom','20',0,''),(359801,114575,'116535','printshop','background-color','$content-bg-1',0,''),(359802,114575,'116535','printshop','style_class','hiding-box',0,''),(359803,114575,'116535','printshop','color','$content-color-1',0,''),(359804,114576,'116536','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(359805,114577,'116537','printshop','block_type','2',0,''),(359806,114578,'116538','printshop','padding-right','20',0,''),(359807,114579,'116539','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359808,114580,'116540','printshop','block_type','1',0,''),(359809,114580,'116540','printshop','padding-left','20',0,''),(359810,114581,'116541','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359811,114583,'116543','printshop','block_type','1',0,''),(359812,114583,'116543','printshop','padding-top','30',0,''),(359813,114583,'116543','printshop','padding-left','30',0,''),(359814,114583,'116543','printshop','padding-right','30',0,''),(359815,114583,'116543','printshop','padding-bottom','14',0,''),(359816,114583,'116543','printshop','margin-bottom','20',0,''),(359817,114583,'116543','printshop','background-color','$content-bg-1',0,''),(359818,114583,'116543','printshop','style_class','hiding-box closeable-box',0,''),(359819,114583,'116543','printshop','color','$content-color-1',0,''),(359820,114584,'116544','printshop','block_type','2',0,''),(359821,114584,'116544','printshop','style_class','closeable-content',0,''),(359822,114585,'116545','printshop','padding-right','20',0,''),(359823,114585,'116545','printshop','padding-bottom','20',0,''),(359824,114586,'116546','printshop','padding-left','20',0,''),(359825,114586,'116546','printshop','padding-bottom','20',0,''),(359826,114587,'116547','printshop','padding-left','20',0,''),(359827,114587,'116547','printshop','padding-bottom','20',0,''),(359828,114588,'116548','printshop','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(359829,114588,'116548','printshop','style_class','closeable-heading closeable-event closed',0,''),(359830,114589,'116549','printshop','block_type','1',0,''),(359831,114589,'116549','printshop','background-color','$content-bg-1',0,''),(359832,114589,'116549','printshop','padding-top','30',0,''),(359833,114589,'116549','printshop','padding-left','30',0,''),(359834,114589,'116549','printshop','padding-right','30',0,''),(359835,114589,'116549','printshop','padding-bottom','14',0,''),(359836,114589,'116549','printshop','margin-bottom','20',0,''),(359837,114589,'116549','printshop','style_class','hiding-box closeable-box',0,''),(359838,114589,'116549','printshop','color','$content-color-1',0,''),(359839,114590,'116550','printshop','style_class','closeable-content',0,''),(359840,114590,'116550','printshop','padding-bottom','20',0,''),(359841,114591,'116551','printshop','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(359842,114591,'116551','printshop','style_class','closeable-heading closeable-event closed',0,''),(359843,114592,'116552','printshop','block_type','1',0,''),(359844,114592,'116552','printshop','padding-top','10',0,''),(359845,114592,'116552','printshop','padding-left','10',0,''),(359846,114592,'116552','printshop','padding-right','10',0,''),(359847,114592,'116552','printshop','padding-bottom','10',0,''),(359848,114592,'116552','printshop','background-color','$content-bg-1',0,''),(359849,114592,'116552','printshop','style_class','order-summary hiding-box',0,''),(359850,114592,'116552','printshop','margin-left','25',0,''),(359851,114592,'116552','printshop','color','$content-color-1',0,''),(359852,114593,'116553','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(359853,114594,'116554','printshop','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(359854,114594,'116554','printshop','text-align','center',0,''),(359855,114594,'116554','printshop','font-size','14',0,''),(359856,114594,'116554','printshop','color','$fade-color-1',0,''),(359857,114594,'116554','printshop','padding-top','10',0,''),(359858,114595,'116555','printshop','margin-bottom','10',0,''),(359859,114597,'116557','printshop','hide_page','1',0,''),(359860,114597,'116557','printshop','hide_continue_button','1',0,''),(359861,114598,'116558','printshop','block_type','1',0,''),(359862,114600,'116560','printshop','block_type','4',0,''),(359863,114600,'116560','printshop','schema','4-2',0,'5363'),(359864,114601,'116561','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359865,114601,'116561','printshop','text-align','right',0,''),(359866,114601,'116561','printshop','padding-top','10',0,''),(359867,114601,'116561','printshop','font_size_measure','em',0,''),(359868,114601,'116561','printshop','font-size','1.2',0,''),(359869,114602,'116562','printshop','text-align','right',0,''),(359870,114603,'116563','printshop','block_type','2',0,''),(359871,114603,'116563','printshop','schema','2-2',0,'5342'),(359872,114604,'116564','printshop','block_type','1',0,''),(359873,114604,'116564','printshop','padding-right','20',0,''),(359874,114604,'116564','printshop','padding-right','0',0,'5342'),(359875,114606,'116566','printshop','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(359876,114607,'116567','printshop','block_type','1',0,''),(359877,114607,'116567','printshop','padding-left','20',0,''),(359878,114607,'116567','printshop','padding-left','0',0,'5342'),(359879,114609,'116569','printshop','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(359880,114610,'116570','printshop','block_type','2',0,''),(359881,114610,'116570','printshop','schema','2-2',0,'5342'),(359882,114611,'116571','printshop','block_type','1',0,''),(359883,114611,'116571','printshop','padding-right','20',0,''),(359884,114611,'116571','printshop','padding-right','0',0,'5342'),(359885,114612,'116572','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359886,114614,'116574','printshop','block_type','1',0,''),(359887,114614,'116574','printshop','padding-left','20',0,''),(359888,114614,'116574','printshop','padding-left','0',0,'5342'),(359889,114619,'116579','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359890,114620,'116580','printshop','margin-bottom','20',0,''),(359891,114621,'116581','printshop','block_type','1',0,''),(359892,114621,'116581','printshop','background-color','$content-bg-2',0,''),(359893,114621,'116581','printshop','padding-top','30',0,''),(359894,114621,'116581','printshop','padding-bottom','30',0,''),(359895,114622,'116582','printshop','block_type','7',0,''),(359896,114622,'116582','printshop','schema','4-2',0,'5342'),(359897,114622,'116582','printshop','margin-bottom','30',0,''),(359898,114623,'116583','printshop','block_type','1',0,''),(359899,114623,'116583','printshop','padding-right','0',0,'5342'),(359900,114624,'116585','printshop','block_type','1',0,''),(359901,114624,'116585','printshop','background-color','$content-bg-1',0,''),(359902,114624,'116585','printshop','padding-top','30',0,''),(359903,114624,'116585','printshop','padding-left','30',0,''),(359904,114624,'116585','printshop','padding-right','30',0,''),(359905,114624,'116585','printshop','padding-bottom','14',0,''),(359906,114624,'116585','printshop','margin-bottom','20',0,''),(359907,114624,'116585','printshop','style_class','hiding-box closeable-box',0,''),(359908,114625,'116586','printshop','style_class','closeable-content',0,''),(359909,114625,'116586','printshop','padding-bottom','20',0,''),(359910,114626,'116587','printshop','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(359911,114626,'116587','printshop','style_class','closeable-heading closeable-event closed',0,''),(359912,114627,'116588','printshop','block_type','1',0,''),(359913,114627,'116588','printshop','background-color','$content-bg-1',0,''),(359914,114627,'116588','printshop','padding-top','30',0,''),(359915,114627,'116588','printshop','padding-left','30',0,''),(359916,114627,'116588','printshop','padding-right','30',0,''),(359917,114627,'116588','printshop','padding-bottom','30',0,''),(359918,114627,'116588','printshop','margin-bottom','20',0,''),(359919,114627,'116588','printshop','style_class','hiding-box',0,''),(359920,114628,'116589','printshop','padding-top','10',0,''),(359921,114628,'116589','printshop','padding-left','20',0,''),(359922,114628,'116589','printshop','padding-right','20',0,''),(359923,114628,'116589','printshop','margin-top','20',0,''),(359924,114628,'116589','printshop','background-color','$content-bg-2',0,''),(359925,114628,'116589','printshop','padding-bottom','8',0,''),(359926,114629,'116590','printshop','margin-bottom','20',0,''),(359927,114630,'116591','printshop','block_type','1',0,''),(359928,114630,'116591','printshop','padding-top','30',0,''),(359929,114630,'116591','printshop','padding-left','30',0,''),(359930,114630,'116591','printshop','padding-right','30',0,''),(359931,114630,'116591','printshop','padding-bottom','23',0,''),(359932,114630,'116591','printshop','margin-bottom','20',0,''),(359933,114630,'116591','printshop','background-color','$content-bg-1',0,''),(359934,114630,'116591','printshop','style_class','hiding-box',0,''),(359935,114631,'116592','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(359936,114632,'116593','printshop','block_type','2',0,''),(359937,114632,'116593','printshop','schema','2-2',0,'5342'),(359938,114633,'116594','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359939,114634,'116595','printshop','padding-right','20',0,''),(359940,114634,'116595','printshop','padding-right','0',0,'5342'),(359941,114634,'116595','printshop','padding-bottom','20',0,'5342'),(359942,114635,'116596','printshop','block_type','1',0,''),(359943,114635,'116596','printshop','padding-left','20',0,''),(359944,114635,'116596','printshop','padding-left','0',0,'5342'),(359945,114637,'116598','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359946,114638,'116599','printshop','block_type','1',0,''),(359947,114638,'116599','printshop','padding-top','10',0,''),(359948,114638,'116599','printshop','padding-left','10',0,''),(359949,114638,'116599','printshop','padding-right','10',0,''),(359950,114638,'116599','printshop','padding-bottom','10',0,''),(359951,114638,'116599','printshop','background-color','$content-bg-1',0,''),(359952,114638,'116599','printshop','style_class','order-summary',0,''),(359953,114638,'116599','printshop','margin-left','25',0,''),(359954,114640,'116601','printshop','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(359955,114640,'116601','printshop','text-align','center',0,''),(359956,114640,'116601','printshop','font-size','14',0,''),(359957,114640,'116601','printshop','color','$fade-color-1',0,''),(359958,114640,'116601','printshop','padding-top','10',0,''),(359959,114641,'116602','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(359960,114642,'116603','printshop','margin-bottom','10',0,''),(359961,114644,'116604','printshop','block_type','2',0,''),(359962,114644,'116604','printshop','schema','2-2',0,'5411'),(359963,114645,'116605','printshop','block_type','1',0,''),(359964,114645,'116605','printshop','padding-left','0',0,'5342'),(359965,114645,'116605','printshop','padding-right','20',0,''),(359966,114647,'116607','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359967,114648,'116608','printshop','block_type','1',0,''),(359968,114648,'116608','printshop','padding-left','20',0,''),(359969,114648,'116608','printshop','padding-left','0',0,'5342'),(359970,114653,'116613','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359971,114654,'116614','printshop','block_type','4',0,''),(359972,114654,'116614','printshop','schema','4-2',0,'5363'),(359973,114654,'116614','printshop','padding-top','20',0,''),(359974,114655,'116615','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359975,114655,'116615','printshop','text-align','right',0,''),(359976,114655,'116615','printshop','padding-top','10',0,''),(359977,114655,'116615','printshop','font_size_measure','em',0,''),(359978,114655,'116615','printshop','font-size','1.2',0,''),(359979,114655,'116615','printshop','text-align','center',0,'5411'),(359980,114656,'116616','printshop','text-align','right',0,''),(359981,114656,'116616','printshop','text-align','center',0,'5411'),(359982,114657,'116617','printshop','block_type','2',0,''),(359983,114658,'116618','printshop','block_type','1',0,''),(359984,114658,'116618','printshop','padding-left','0',0,'5342'),(359985,114658,'116618','printshop','padding-right','20',0,''),(359986,114660,'116620','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(359987,114661,'116621','printshop','block_type','1',0,''),(359988,114661,'116621','printshop','padding-left','20',0,''),(359989,114661,'116621','printshop','padding-left','0',0,'5342'),(359990,114663,'116623','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(359991,114667,'116627','printshop','block_type','4',0,''),(359992,114667,'116627','printshop','schema','4-2',0,'5363'),(359993,114668,'116628','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(359994,114668,'116628','printshop','text-align','right',0,''),(359995,114668,'116628','printshop','padding-top','10',0,''),(359996,114668,'116628','printshop','font_size_measure','em',0,''),(359997,114668,'116628','printshop','font-size','1.2',0,''),(359998,114669,'116629','printshop','text-align','right',0,''),(359999,114670,'116630','printshop','block_type','4',0,''),(360000,114670,'116630','printshop','schema','4-2',0,'5363'),(360001,114671,'116631','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(360002,114671,'116631','printshop','text-align','right',0,''),(360003,114671,'116631','printshop','padding-top','10',0,''),(360004,114671,'116631','printshop','font_size_measure','em',0,''),(360005,114671,'116631','printshop','font-size','1.2',0,''),(360006,114672,'116632','printshop','text-align','right',0,''),(360007,114673,'116633','printshop','block_type','2',0,''),(360008,114674,'116634','printshop','block_type','1',0,''),(360009,114674,'116634','printshop','padding-left','0',0,'5342'),(360010,114674,'116634','printshop','padding-right','20',0,''),(360011,114675,'116635','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360012,114677,'116637','printshop','block_type','1',0,''),(360013,114677,'116637','printshop','padding-left','20',0,''),(360014,114677,'116637','printshop','padding-left','0',0,'5342'),(360015,114682,'116642','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360016,114683,'116643','printshop','block_type','4',0,''),(360017,114683,'116643','printshop','schema','4-2',0,'5363'),(360018,114684,'116644','printshop','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(360019,114684,'116644','printshop','text-align','right',0,''),(360020,114684,'116644','printshop','padding-top','10',0,''),(360021,114684,'116644','printshop','font_size_measure','em',0,''),(360022,114684,'116644','printshop','font-size','1.2',0,''),(360023,114685,'116645','printshop','text-align','right',0,''),(360024,114686,'116646','printshop','block_type','2',0,''),(360025,114687,'116647','printshop','block_type','1',0,''),(360026,114687,'116647','printshop','padding-left','0',0,'5342'),(360027,114687,'116647','printshop','padding-right','20',0,''),(360028,114689,'116649','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360029,114690,'116650','printshop','block_type','1',0,''),(360030,114690,'116650','printshop','padding-left','20',0,''),(360031,114690,'116650','printshop','padding-left','0',0,'5342'),(360032,114694,'116654','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360033,114696,'116656','printshop','text','##PAYMENT_DETAILS##',0,''),(360034,114697,'116657','printshop','text','##PAYMENT_DETAILS##',0,''),(360035,114698,'116658','printshop','text','##PAYMENT_DETAILS##',0,''),(360036,114699,'116659','printshop','text','##PAYMENT_DETAILS##',0,''),(360037,114700,'116660','printshop','text','##PAYMENT_DETAILS##',0,''),(360038,114701,'116661','printshop','text','##PAYMENT_DETAILS##',0,''),(360039,114702,'120947','printshop','block_type','1',0,''),(360040,114702,'120947','printshop','background-color','$content-bg-2',0,''),(360041,114702,'120947','printshop','padding-top','30',0,''),(360042,114702,'120947','printshop','padding-bottom','30',0,''),(360043,114703,'120948','printshop','block_type','7',0,''),(360044,114703,'120948','printshop','schema','4-2',0,'5342'),(360045,114704,'120949','printshop','block_type','1',0,''),(360046,114704,'120949','printshop','padding-right','0',0,'5342'),(360047,114705,'120950','printshop','block_type','1',0,''),(360048,114705,'120950','printshop','background-color','$content-bg-1',0,''),(360049,114705,'120950','printshop','padding-top','30',0,''),(360050,114705,'120950','printshop','padding-left','30',0,''),(360051,114705,'120950','printshop','padding-right','30',0,''),(360052,114705,'120950','printshop','padding-bottom','30',0,''),(360053,114705,'120950','printshop','margin-bottom','20',0,''),(360054,114705,'120950','printshop','style_class','hiding-box',0,''),(360055,114706,'120951','printshop','padding-top','10',0,''),(360056,114706,'120951','printshop','padding-left','20',0,''),(360057,114706,'120951','printshop','padding-right','20',0,''),(360058,114706,'120951','printshop','margin-top','20',0,''),(360059,114706,'120951','printshop','background-color','$content-bg-2',0,''),(360060,114706,'120951','printshop','padding-bottom','8',0,''),(360061,114707,'120952','printshop','margin-bottom','20',0,''),(360062,114708,'120953','printshop','background-color','$content-bg-1',0,''),(360063,114708,'120953','printshop','block_type','1',0,''),(360064,114708,'120953','printshop','padding-top','30',0,''),(360065,114708,'120953','printshop','padding-left','30',0,''),(360066,114708,'120953','printshop','padding-right','30',0,''),(360067,114708,'120953','printshop','padding-bottom','30',0,''),(360068,114708,'120953','printshop','margin-bottom','20',0,''),(360069,114708,'120953','printshop','style_class','hiding-box',0,''),(360070,114709,'120954','printshop','block_type','1',0,''),(360071,114709,'120954','printshop','content','\\_',0,'3'),(360072,114709,'120954','printshop','border-top-width','1',0,'3'),(360073,114709,'120954','printshop','border-top-color','$content-border-3',0,'3'),(360074,114709,'120954','printshop','display','block',0,'3'),(360075,114709,'120954','printshop','position','absolute',0,'3'),(360076,114709,'120954','printshop','top','19',0,'3'),(360077,114709,'120954','printshop','left','0',0,'3'),(360078,114709,'120954','printshop','right','0',0,'3'),(360079,114709,'120954','printshop','margin-top','-2',0,'3'),(360080,114709,'120954','printshop','position','relative',0,''),(360081,114710,'120955','printshop','box_align','2',0,''),(360082,114710,'120955','printshop','margin-bottom','10',0,''),(360083,114710,'120955','printshop','background-color','$content-bg-1',0,''),(360084,114710,'120955','printshop','position','relative',0,''),(360085,114711,'120956','printshop','background-color','$content-bg-2',0,''),(360086,114711,'120956','printshop','padding-top','10',0,''),(360087,114711,'120956','printshop','padding-left','10',0,''),(360088,114711,'120956','printshop','padding-right','10',0,''),(360089,114711,'120956','printshop','padding-bottom','10',0,''),(360090,114711,'120956','printshop','margin-top','10',0,''),(360091,114712,'120957','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(360092,114713,'120958','printshop','block_type','2',0,''),(360093,114713,'120958','printshop','schema','2-2',0,'5342'),(360094,114714,'120959','printshop','block_type','1',0,''),(360095,114714,'120959','printshop','padding-right','20',0,''),(360096,114714,'120959','printshop','padding-left','0',0,'5342'),(360097,114714,'120959','printshop','margin-bottom','20',0,'5342'),(360098,114714,'120959','printshop','padding-right','0',0,'5342'),(360099,114717,'120962','printshop','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(360100,114718,'120963','printshop','block_type','1',0,''),(360101,114718,'120963','printshop','padding-left','20',0,''),(360102,114718,'120963','printshop','padding-left','0',0,'5342'),(360103,114720,'120965','printshop','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(360104,114721,'120966','printshop','border-top-width','1',0,''),(360105,114721,'120966','printshop','border-top-color','$content-border-3',0,''),(360106,114721,'120966','printshop','padding-top','13',0,''),(360107,114721,'120966','printshop','padding-bottom','10',0,''),(360108,114722,'120967','printshop','block_type','1',0,''),(360109,114722,'120967','printshop','background-color','$content-bg-1',0,''),(360110,114722,'120967','printshop','padding-top','30',0,''),(360111,114722,'120967','printshop','padding-left','30',0,''),(360112,114722,'120967','printshop','padding-right','30',0,''),(360113,114722,'120967','printshop','padding-bottom','14',0,''),(360114,114722,'120967','printshop','margin-bottom','20',0,''),(360115,114722,'120967','printshop','style_class','hiding-box closeable-box',0,''),(360116,114723,'120968','printshop','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(360117,114723,'120968','printshop','style_class','closeable-heading closeable-event closed',0,''),(360118,114724,'120969','printshop','style_class','closeable-content',0,''),(360119,114724,'120969','printshop','padding-bottom','20',0,''),(360120,114725,'120970','printshop','block_type','1',0,''),(360121,114725,'120970','printshop','padding-top','30',0,''),(360122,114725,'120970','printshop','padding-left','30',0,''),(360123,114725,'120970','printshop','padding-right','30',0,''),(360124,114725,'120970','printshop','padding-bottom','23',0,''),(360125,114725,'120970','printshop','margin-bottom','20',0,''),(360126,114725,'120970','printshop','background-color','$content-bg-1',0,''),(360127,114725,'120970','printshop','style_class','hiding-box',0,''),(360128,114726,'120971','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(360129,114727,'120972','printshop','block_type','2',0,''),(360130,114727,'120972','printshop','schema','2-2',0,'5342'),(360131,114728,'120973','printshop','padding-right','20',0,''),(360132,114728,'120973','printshop','padding-right','0',0,'5342'),(360133,114728,'120973','printshop','padding-bottom','20',0,'5342'),(360134,114729,'120974','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360135,114730,'120975','printshop','block_type','1',0,''),(360136,114730,'120975','printshop','padding-left','20',0,''),(360137,114730,'120975','printshop','padding-left','0',0,'5342'),(360138,114732,'120977','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360139,114733,'120978','printshop','block_type','1',0,''),(360140,114733,'120978','printshop','padding-left','10',0,''),(360141,114733,'120978','printshop','padding-right','10',0,''),(360142,114733,'120978','printshop','padding-bottom','10',0,''),(360143,114733,'120978','printshop','background-color','$content-bg-1',0,''),(360144,114733,'120978','printshop','style_class','order-summary',0,''),(360145,114733,'120978','printshop','margin-left','25',0,''),(360146,114733,'120978','printshop','margin-left','0',0,'5342'),(360147,114734,'120979','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360148,114735,'120980','printshop','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(360149,114735,'120980','printshop','text-align','center',0,''),(360150,114735,'120980','printshop','font-size','14',0,''),(360151,114735,'120980','printshop','color','$fade-color-1',0,''),(360152,114735,'120980','printshop','padding-top','10',0,''),(360153,114736,'120981','printshop','margin-bottom','10',0,''),(360154,114738,'120983','printshop','hide_continue_button','1',0,''),(360155,114739,'116699','printshop','block_type','1',0,''),(360156,114739,'116699','printshop','background-color','$content-bg-2',0,''),(360157,114739,'116699','printshop','padding-top','30',0,''),(360158,114739,'116699','printshop','padding-bottom','30',0,''),(360159,114740,'116700','printshop','block_type','7',0,''),(360160,114740,'116700','printshop','schema','7-2',0,'5342'),(360161,114741,'116701','printshop','block_type','1',0,''),(360162,114741,'116701','printshop','padding-right','0',0,'5342'),(360163,114742,'116703','printshop','block_type','1',0,''),(360164,114742,'116703','printshop','background-color','$content-bg-1',0,''),(360165,114742,'116703','printshop','padding-top','30',0,''),(360166,114742,'116703','printshop','padding-left','30',0,''),(360167,114742,'116703','printshop','padding-right','30',0,''),(360168,114742,'116703','printshop','padding-bottom','30',0,''),(360169,114742,'116703','printshop','margin-bottom','20',0,''),(360170,114742,'116703','printshop','style_class','hiding-box',0,''),(360171,114743,'116704','printshop','margin-bottom','20',0,''),(360172,114744,'116705','printshop','padding-top','10',0,''),(360173,114744,'116705','printshop','padding-left','20',0,''),(360174,114744,'116705','printshop','padding-right','20',0,''),(360175,114744,'116705','printshop','margin-top','20',0,''),(360176,114744,'116705','printshop','background-color','$content-bg-2',0,''),(360177,114744,'116705','printshop','padding-bottom','8',0,''),(360178,114745,'116706','printshop','background-color','$content-bg-1',0,''),(360179,114745,'116706','printshop','block_type','1',0,''),(360180,114745,'116706','printshop','padding-top','30',0,''),(360181,114745,'116706','printshop','padding-left','30',0,''),(360182,114745,'116706','printshop','padding-right','30',0,''),(360183,114745,'116706','printshop','padding-bottom','30',0,''),(360184,114745,'116706','printshop','margin-bottom','20',0,''),(360185,114745,'116706','printshop','style_class','hiding-box',0,''),(360186,114746,'116707','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(360187,114747,'116708','printshop','background-color','$content-bg-2',0,''),(360188,114747,'116708','printshop','padding-top','10',0,''),(360189,114747,'116708','printshop','padding-left','10',0,''),(360190,114747,'116708','printshop','padding-right','10',0,''),(360191,114747,'116708','printshop','padding-bottom','10',0,''),(360192,114747,'116708','printshop','margin-top','10',0,''),(360193,114748,'116709','printshop','block_type','1',0,''),(360194,114748,'116709','printshop','content','\\_',0,'3'),(360195,114748,'116709','printshop','border-top-width','1',0,'3'),(360196,114748,'116709','printshop','border-top-color','$content-border-3',0,'3'),(360197,114748,'116709','printshop','display','block',0,'3'),(360198,114748,'116709','printshop','position','absolute',0,'3'),(360199,114748,'116709','printshop','top','19',0,'3'),(360200,114748,'116709','printshop','left','0',0,'3'),(360201,114748,'116709','printshop','right','0',0,'3'),(360202,114748,'116709','printshop','margin-top','-2',0,'3'),(360203,114748,'116709','printshop','position','relative',0,''),(360204,114749,'116710','printshop','box_align','2',0,''),(360205,114749,'116710','printshop','margin-bottom','10',0,''),(360206,114749,'116710','printshop','background-color','$content-bg-1',0,''),(360207,114749,'116710','printshop','position','relative',0,''),(360208,114750,'116711','printshop','block_type','2',0,''),(360209,114750,'116711','printshop','schema','2-2',0,'5342'),(360210,114751,'116712','printshop','block_type','1',0,''),(360211,114751,'116712','printshop','padding-right','20',0,''),(360212,114751,'116712','printshop','padding-left','0',0,'5342'),(360213,114751,'116712','printshop','margin-bottom','20',0,'5342'),(360214,114751,'116712','printshop','padding-right','0',0,'5342'),(360215,114754,'116715','printshop','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(360216,114755,'116716','printshop','block_type','1',0,''),(360217,114755,'116716','printshop','padding-left','20',0,''),(360218,114755,'116716','printshop','padding-left','0',0,'5342'),(360219,114757,'116718','printshop','border-top-width','1',0,''),(360220,114757,'116718','printshop','border-top-color','$content-border-3',0,''),(360221,114757,'116718','printshop','padding-top','13',0,''),(360222,114757,'116718','printshop','padding-bottom','10',0,''),(360223,114758,'116719','printshop','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(360224,114759,'116720','printshop','block_type','1',0,''),(360225,114759,'116720','printshop','padding-top','30',0,''),(360226,114759,'116720','printshop','padding-left','30',0,''),(360227,114759,'116720','printshop','padding-right','30',0,''),(360228,114759,'116720','printshop','padding-bottom','23',0,''),(360229,114759,'116720','printshop','margin-bottom','20',0,''),(360230,114759,'116720','printshop','background-color','$content-bg-1',0,''),(360231,114759,'116720','printshop','style_class','hiding-box',0,''),(360232,114760,'116721','printshop','block_type','2',0,''),(360233,114760,'116721','printshop','schema','2-2',0,'5342'),(360234,114761,'116722','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360235,114762,'116723','printshop','padding-right','20',0,''),(360236,114762,'116723','printshop','padding-right','0',0,'5342'),(360237,114762,'116723','printshop','padding-bottom','20',0,'5342'),(360238,114763,'116724','printshop','block_type','1',0,''),(360239,114763,'116724','printshop','padding-left','20',0,''),(360240,114763,'116724','printshop','padding-left','0',0,'5342'),(360241,114764,'116725','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360242,114766,'116727','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(360243,114767,'116728','printshop','block_type','1',0,''),(360244,114767,'116728','printshop','background-color','$content-bg-1',0,''),(360245,114767,'116728','printshop','padding-top','30',0,''),(360246,114767,'116728','printshop','padding-left','30',0,''),(360247,114767,'116728','printshop','padding-right','30',0,''),(360248,114767,'116728','printshop','padding-bottom','14',0,''),(360249,114767,'116728','printshop','margin-bottom','20',0,''),(360250,114767,'116728','printshop','style_class','hiding-box closeable-box',0,''),(360251,114768,'116729','printshop','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(360252,114768,'116729','printshop','style_class','closeable-heading closeable-event closed',0,''),(360253,114769,'116730','printshop','style_class','closeable-content',0,''),(360254,114769,'116730','printshop','padding-bottom','20',0,''),(360255,114770,'116731','printshop','block_type','1',0,''),(360256,114770,'116731','printshop','padding-top','30',0,''),(360257,114770,'116731','printshop','padding-left','30',0,''),(360258,114770,'116731','printshop','padding-right','30',0,''),(360259,114770,'116731','printshop','padding-bottom','14',0,''),(360260,114770,'116731','printshop','margin-bottom','20',0,''),(360261,114770,'116731','printshop','background-color','$content-bg-1',0,''),(360262,114770,'116731','printshop','style_class','hiding-box closeable-box',0,''),(360263,114771,'116732','printshop','block_type','2',0,''),(360264,114771,'116732','printshop','style_class','closeable-content',0,''),(360265,114771,'116732','printshop','schema','2-2',0,'5342'),(360266,114772,'116733','printshop','padding-right','20',0,''),(360267,114772,'116733','printshop','padding-bottom','20',0,''),(360268,114772,'116733','printshop','padding-right','0',0,'5342'),(360269,114773,'116734','printshop','padding-left','20',0,''),(360270,114773,'116734','printshop','padding-bottom','20',0,''),(360271,114773,'116734','printshop','padding-left','0',0,'5342'),(360272,114774,'116735','printshop','padding-left','20',0,''),(360273,114774,'116735','printshop','padding-bottom','20',0,''),(360274,114774,'116735','printshop','padding-left','0',0,'5342'),(360275,114775,'116736','printshop','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(360276,114775,'116736','printshop','style_class','closeable-heading closeable-event closed',0,''),(360277,114776,'116737','printshop','block_type','1',0,''),(360278,114776,'116737','printshop','padding-top','20',0,''),(360279,114776,'116737','printshop','padding-left','20',0,''),(360280,114776,'116737','printshop','padding-right','20',0,''),(360281,114776,'116737','printshop','padding-bottom','20',0,''),(360282,114776,'116737','printshop','background-color','$content-bg-1',0,''),(360283,114776,'116737','printshop','style_class','order-summary',0,''),(360284,114776,'116737','printshop','margin-left','25',0,''),(360285,114776,'116737','printshop','padding-left','0',0,'5342'),(360286,114777,'116738','printshop','margin-bottom','10',0,''),(360287,114778,'116739','printshop','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(360288,114778,'116739','printshop','text-align','center',0,''),(360289,114778,'116739','printshop','font-size','14',0,''),(360290,114778,'116739','printshop','color','$fade-color-1',0,''),(360291,114778,'116739','printshop','padding-top','10',0,''),(360292,114779,'116740','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360293,114781,'120986','printshop','hide_continue_button','1',0,''),(360294,114782,'116742','printshop','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(360295,114787,'116747','printshop','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(360296,114788,'116749','printshop','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(360297,114789,'116750','printshop','style_class','order-summary',0,''),(360298,114789,'116750','printshop','box_align','3',0,''),(360299,114789,'116750','printshop','width','400',0,''),(360300,114791,'116748','printshop','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(360301,114794,'116754','printshop','block_type','1',0,''),(360302,114795,'116755','printshop','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(360303,114796,'116756','printshop','float','right',0,''),(360304,114796,'116756','printshop','position','relative',0,''),(360305,114796,'116756','printshop','z-index','1',0,''),(360306,114796,'116756','printshop','top','30',0,''),(360307,114796,'116756','printshop','margin-bottom','-10',0,''),(360308,114797,'116757','printshop','margin-bottom','30',0,''),(360309,114798,'116758','printshop','block_type','1',0,''),(360310,114799,'116759','printshop','listing_type','CompareProduct',0,''),(360311,114800,'117665.000001','printshop','block_type','1',0,''),(360312,114800,'117665.000001','printshop','style_class','item-holder',0,''),(360313,114800,'117665.000001','printshop','padding-top','25',0,''),(360314,114800,'117665.000001','printshop','padding-left','25',0,''),(360315,114800,'117665.000001','printshop','padding-right','25',0,''),(360316,114800,'117665.000001','printshop','padding-bottom','25',0,''),(360317,114800,'117665.000001','printshop','text-align','left',0,''),(360318,114801,'120921.000001','printshop','block_type','1',0,''),(360319,114801,'120921.000001','printshop','style_class','item-wrapper',0,''),(360320,114802,'120919.000001','printshop','block_type','1',0,''),(360321,114802,'120919.000001','printshop','style_class','item-content',0,''),(360322,114803,'1638872990.9609','printshop','block_type','5',0,''),(360323,114805,'117677.000001','printshop','float','right',0,''),(360324,114806,'117675.000001','printshop','clear','none',0,''),(360325,114807,'117676.000001','printshop','margin-bottom','10',0,''),(360326,114808,'1638873112.0384','printshop','block_type','2',0,''),(360327,114810,'117673.000001','printshop','margin-bottom','7',0,''),(360328,114810,'117673.000001','printshop','text-align','right',0,''),(360329,114811,'116760','printshop','block_type','1',0,''),(360330,114811,'116760','printshop','style_class','item-holder',0,''),(360331,114811,'116760','printshop','padding-top','10',0,''),(360332,114811,'116760','printshop','padding-left','20',0,''),(360333,114811,'116760','printshop','padding-right','20',0,''),(360334,114811,'116760','printshop','padding-bottom','10',0,''),(360335,114811,'116760','printshop','text-align','left',0,''),(360336,114814,'116763','printshop','margin-bottom','10',0,''),(360337,114815,'116764','printshop','block_type','5',0,''),(360338,114817,'116766','printshop','clear','both',0,''),(360339,114818,'116767','printshop','block_type','2',0,''),(360340,114819,'116768','printshop','margin-bottom','7',0,''),(360341,114820,'116769','printshop','text-align','right',0,''),(360342,114820,'116769','printshop','margin-bottom','10',0,''),(360343,114820,'116769','printshop','float','right',0,''),(360344,114821,'116770','printshop','block_type','1',0,''),(360345,114821,'116770','printshop','background-color','$content-bg-2',0,''),(360346,114821,'116770','printshop','padding-bottom','30',0,''),(360347,114821,'116770','printshop','style_class','checkout-order-confirmation',0,''),(360348,114821,'116770','printshop','color','$content-color-2',0,''),(360349,114822,'116771','printshop','block_type','4',0,''),(360350,114822,'116771','printshop','schema','4-2',0,'5342'),(360351,114823,'116772','printshop','block_type','1',0,''),(360352,114823,'116772','printshop','padding-right','40',0,''),(360353,114823,'116772','printshop','padding-right','0',0,'5342'),(360354,114823,'116772','printshop','padding-bottom','20',0,''),(360355,114824,'116773','printshop','block_type','1',0,''),(360356,114824,'116773','printshop','padding-right','30',0,''),(360357,114824,'116773','printshop','background-color','$content-bg-1',0,''),(360358,114824,'116773','printshop','padding-top','20',0,''),(360359,114824,'116773','printshop','padding-left','30',0,''),(360360,114824,'116773','printshop','padding-bottom','20',0,''),(360361,114824,'116773','printshop','padding-left','20',0,'5342'),(360362,114824,'116773','printshop','padding-right','20',0,'5342'),(360363,114824,'116773','printshop','color','$content-color-1',0,''),(360364,114825,'116774','printshop','link','products',0,''),(360365,114825,'116774','printshop','float','right',0,''),(360366,114825,'116774','printshop','margin-top','-37',0,''),(360367,114827,'116776','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(360368,114828,'116777','printshop','block_type','1',0,''),(360369,114828,'116777','printshop','background-color','$content-bg-1',0,''),(360370,114828,'116777','printshop','padding-top','20',0,''),(360371,114828,'116777','printshop','padding-bottom','20',0,''),(360372,114828,'116777','printshop','padding-left','30',0,''),(360373,114828,'116777','printshop','padding-right','30',0,''),(360374,114828,'116777','printshop','margin-bottom','20',0,''),(360375,114828,'116777','printshop','color','$content-color-1',0,''),(360376,114829,'116778','printshop','float','right',0,''),(360377,114829,'116778','printshop','margin-top','-37',0,''),(360378,114829,'116778','printshop','link','comments',0,''),(360379,114830,'116779','printshop','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(360380,114831,'116780','printshop','hide_parents','2',0,''),(360381,114832,'116781','printshop','block_type','2',0,''),(360382,114832,'116781','printshop','margin-bottom','20',0,''),(360383,114832,'116781','printshop','schema','2-2',0,'5333'),(360384,114832,'116781','printshop','background-color','$content-bg-1',0,''),(360385,114832,'116781','printshop','color','$content-color-1',0,''),(360386,114833,'116782','printshop','block_type','1',0,''),(360387,114833,'116782','printshop','border-right-width','20',0,''),(360388,114833,'116782','printshop','border-right-color','$content-bg-2',0,''),(360389,114833,'116782','printshop','margin-right','-10',0,''),(360390,114833,'116782','printshop','padding-right','30',0,''),(360391,114833,'116782','printshop','padding-top','20',0,''),(360392,114833,'116782','printshop','padding-left','30',0,''),(360393,114833,'116782','printshop','padding-bottom','20',0,''),(360394,114833,'116782','printshop','border-right-width','0',0,'5342'),(360395,114833,'116782','printshop','margin-right','0',0,'5342'),(360396,114833,'116782','printshop','margin-bottom','20',0,'5342'),(360397,114833,'116782','printshop','padding-left','20',0,'5342'),(360398,114833,'116782','printshop','padding-right','20',0,'5342'),(360399,114833,'116782','printshop','margin-bottom','0',0,'5333'),(360400,114834,'116783','printshop','link','shipping_method',0,''),(360401,114834,'116783','printshop','float','right',0,''),(360402,114834,'116783','printshop','margin-top','-31',0,''),(360403,114836,'116785','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(360404,114836,'116785','printshop','padding-top','20',0,''),(360405,114837,'116786','printshop','link','contact_information',0,''),(360406,114837,'116786','printshop','margin-top','-31',0,''),(360407,114837,'116786','printshop','float','right',0,''),(360408,114838,'116787','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(360409,114838,'116787','printshop','clear','none',0,''),(360410,114840,'116789','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(360411,114841,'116790','printshop','link','shipping_address',0,''),(360412,114841,'116790','printshop','float','right',0,''),(360413,114841,'116790','printshop','margin-top','-31',0,''),(360414,114843,'116792','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(360415,114843,'116792','printshop','clear','none',0,''),(360416,114844,'116793','printshop','margin-bottom','20',0,''),(360417,114845,'116794','printshop','block_type','1',0,''),(360418,114845,'116794','printshop','padding-left','30',0,''),(360419,114845,'116794','printshop','border-left-width','20',0,''),(360420,114845,'116794','printshop','border-left-color','$content-bg-2',0,''),(360421,114845,'116794','printshop','margin-left','-10',0,''),(360422,114845,'116794','printshop','padding-right','30',0,''),(360423,114845,'116794','printshop','padding-top','20',0,''),(360424,114845,'116794','printshop','padding-bottom','20',0,''),(360425,114845,'116794','printshop','border-left-width','0',0,'5342'),(360426,114845,'116794','printshop','margin-left','0',0,'5342'),(360427,114845,'116794','printshop','padding-right','20',0,'5342'),(360428,114845,'116794','printshop','padding-left','20',0,'5342'),(360429,114846,'116795','printshop','link','payment_method',0,''),(360430,114846,'116795','printshop','float','right',0,''),(360431,114846,'116795','printshop','margin-top','-31',0,''),(360432,114847,'116796','printshop','link','billing_address',0,''),(360433,114847,'116796','printshop','float','right',0,''),(360434,114847,'116796','printshop','margin-top','-31',0,''),(360435,114849,'116798','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360436,114849,'116798','printshop','clear','none',0,''),(360437,114850,'116799','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(360438,114851,'116800','printshop','margin-bottom','20',0,''),(360439,114852,'116801','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360440,114852,'116801','printshop','clear','none',0,''),(360441,114854,'116803','printshop','block_type','1',0,''),(360442,114854,'116803','printshop','padding-top','10',0,''),(360443,114854,'116803','printshop','padding-left','20',0,''),(360444,114854,'116803','printshop','padding-right','20',0,''),(360445,114854,'116803','printshop','padding-bottom','10',0,''),(360446,114854,'116803','printshop','background-color','$content-bg-1',0,''),(360447,114854,'116803','printshop','style_class','order-summary hiding-box',0,''),(360448,114854,'116803','printshop','color','$content-color-1',0,''),(360449,114855,'116804','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360450,114856,'116805','printshop','margin-bottom','20',0,''),(360451,114856,'116805','printshop','text-align','right',0,''),(360452,114858,'116807','printshop','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(360453,114859,'116808','printshop','block_type','1',0,''),(360454,114859,'116808','printshop','background-color','$content-bg-2',0,''),(360455,114859,'116808','printshop','padding-bottom','30',0,''),(360456,114860,'116809','printshop','block_type','4',0,''),(360457,114860,'116809','printshop','schema','4-2',0,'5342'),(360458,114861,'116810','printshop','block_type','1',0,''),(360459,114861,'116810','printshop','padding-right','40',0,''),(360460,114861,'116810','printshop','padding-right','0',0,'5342'),(360461,114862,'116811','printshop','block_type','1',0,''),(360462,114862,'116811','printshop','background-color','$content-bg-1',0,''),(360463,114862,'116811','printshop','padding-top','20',0,''),(360464,114862,'116811','printshop','padding-bottom','20',0,''),(360465,114862,'116811','printshop','padding-left','30',0,''),(360466,114862,'116811','printshop','padding-right','30',0,''),(360467,114862,'116811','printshop','margin-bottom','20',0,''),(360468,114863,'116812','printshop','hide_parents','2',0,''),(360469,114864,'116813','printshop','float','right',0,''),(360470,114864,'116813','printshop','margin-top','-37',0,''),(360471,114864,'116813','printshop','link','comments',0,''),(360472,114865,'116814','printshop','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(360473,114866,'116815','printshop','block_type','1',0,''),(360474,114866,'116815','printshop','padding-right','30',0,''),(360475,114866,'116815','printshop','background-color','$content-bg-1',0,''),(360476,114866,'116815','printshop','padding-top','20',0,''),(360477,114866,'116815','printshop','padding-left','30',0,''),(360478,114866,'116815','printshop','padding-bottom','20',0,''),(360479,114866,'116815','printshop','padding-left','20',0,'5342'),(360480,114866,'116815','printshop','padding-right','20',0,'5342'),(360481,114867,'116816','printshop','link','products',0,''),(360482,114867,'116816','printshop','float','right',0,''),(360483,114867,'116816','printshop','margin-top','-37',0,''),(360484,114868,'116817','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(360485,114870,'116819','printshop','block_type','2',0,''),(360486,114870,'116819','printshop','margin-bottom','20',0,''),(360487,114870,'116819','printshop','schema','2-2',0,'5333'),(360488,114870,'116819','printshop','background-color','$content-bg-1',0,''),(360489,114871,'116820','printshop','block_type','1',0,''),(360490,114871,'116820','printshop','border-right-width','20',0,''),(360491,114871,'116820','printshop','border-right-color','$content-border-3',0,''),(360492,114871,'116820','printshop','margin-right','-10',0,''),(360493,114871,'116820','printshop','padding-right','30',0,''),(360494,114871,'116820','printshop','padding-top','20',0,''),(360495,114871,'116820','printshop','padding-left','30',0,''),(360496,114871,'116820','printshop','padding-bottom','20',0,''),(360497,114871,'116820','printshop','border-right-width','0',0,'5342'),(360498,114871,'116820','printshop','margin-right','0',0,'5342'),(360499,114871,'116820','printshop','margin-bottom','20',0,'5342'),(360500,114871,'116820','printshop','padding-left','20',0,'5342'),(360501,114871,'116820','printshop','padding-right','20',0,'5342'),(360502,114872,'116821','printshop','link','shipping_address',0,''),(360503,114872,'116821','printshop','float','right',0,''),(360504,114872,'116821','printshop','margin-top','-31',0,''),(360505,114874,'116823','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(360506,114874,'116823','printshop','clear','none',0,''),(360507,114875,'116824','printshop','link','shipping_method',0,''),(360508,114875,'116824','printshop','float','right',0,''),(360509,114875,'116824','printshop','margin-top','-31',0,''),(360510,114876,'116825','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(360511,114876,'116825','printshop','clear','none',0,''),(360512,114877,'116826','printshop','margin-bottom','20',0,''),(360513,114878,'116827','printshop','block_type','1',0,''),(360514,114878,'116827','printshop','padding-left','30',0,''),(360515,114878,'116827','printshop','border-left-width','20',0,''),(360516,114878,'116827','printshop','border-left-color','$content-border-3',0,''),(360517,114878,'116827','printshop','margin-left','-10',0,''),(360518,114878,'116827','printshop','padding-right','30',0,''),(360519,114878,'116827','printshop','padding-top','20',0,''),(360520,114878,'116827','printshop','padding-bottom','20',0,''),(360521,114878,'116827','printshop','border-left-width','0',0,'5342'),(360522,114881,'116830','printshop','link','contact_information',0,''),(360523,114881,'116830','printshop','margin-top','-31',0,''),(360524,114881,'116830','printshop','float','right',0,''),(360525,114882,'116831','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(360526,114883,'116832','printshop','block_type','1',0,''),(360527,114883,'116832','printshop','padding-top','20',0,''),(360528,114883,'116832','printshop','padding-left','20',0,''),(360529,114883,'116832','printshop','padding-right','20',0,''),(360530,114883,'116832','printshop','padding-bottom','20',0,''),(360531,114883,'116832','printshop','background-color','$content-bg-1',0,''),(360532,114883,'116832','printshop','style_class','order-summary',0,''),(360533,114884,'116833','printshop','margin-bottom','20',0,''),(360534,114884,'116833','printshop','text-align','right',0,''),(360535,114885,'116834','printshop','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(360536,114886,'116835','printshop','block_type','1',0,''),(360537,114886,'116835','printshop','background-color','$content-bg-2',0,''),(360538,114886,'116835','printshop','padding-bottom','30',0,''),(360539,114886,'116835','printshop','color','$content-color-2',0,''),(360540,114887,'116836','printshop','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(360541,114888,'116837','printshop','block_type','4',0,''),(360542,114889,'116838','printshop','block_type','1',0,''),(360543,114889,'116838','printshop','padding-right','40',0,''),(360544,114890,'116839','printshop','block_type','2',0,''),(360545,114890,'116839','printshop','margin-bottom','20',0,''),(360546,114890,'116839','printshop','schema','2-2',0,'5333'),(360547,114890,'116839','printshop','background-color','$content-bg-1',0,''),(360548,114890,'116839','printshop','color','$content-color-1',0,''),(360549,114891,'116840','printshop','block_type','1',0,''),(360550,114891,'116840','printshop','padding-right','0',0,'5333'),(360551,114891,'116840','printshop','border-right-width','20',0,''),(360552,114891,'116840','printshop','border-right-color','$content-bg-2',0,''),(360553,114891,'116840','printshop','margin-right','-10',0,''),(360554,114891,'116840','printshop','padding-right','30',0,''),(360555,114891,'116840','printshop','padding-top','20',0,''),(360556,114891,'116840','printshop','padding-left','30',0,''),(360557,114891,'116840','printshop','padding-bottom','20',0,''),(360558,114892,'116841','printshop','link','contact_information',0,''),(360559,114892,'116841','printshop','float','right',0,''),(360560,114893,'116842','printshop','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(360561,114895,'116844','printshop','block_type','1',0,''),(360562,114895,'116844','printshop','padding-left','30',0,''),(360563,114895,'116844','printshop','padding-left','0',0,'5333'),(360564,114895,'116844','printshop','border-left-width','20',0,''),(360565,114895,'116844','printshop','border-left-color','$content-bg-2',0,''),(360566,114895,'116844','printshop','margin-left','-10',0,''),(360567,114895,'116844','printshop','padding-right','30',0,''),(360568,114895,'116844','printshop','padding-top','20',0,''),(360569,114895,'116844','printshop','padding-bottom','20',0,''),(360570,114897,'116846','printshop','link','payment_method',0,''),(360571,114897,'116846','printshop','float','right',0,''),(360572,114897,'116846','printshop','margin-top','-31',0,''),(360573,114898,'116847','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360574,114898,'116847','printshop','clear','none',0,''),(360575,114899,'116848','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(360576,114900,'116849','printshop','link','billing_address',0,''),(360577,114900,'116849','printshop','float','right',0,''),(360578,114900,'116849','printshop','margin-top','-31',0,''),(360579,114901,'116850','printshop','margin-bottom','20',0,''),(360580,114902,'116851','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360581,114902,'116851','printshop','clear','none',0,''),(360582,114903,'116852','printshop','block_type','1',0,''),(360583,114903,'116852','printshop','background-color','$content-bg-1',0,''),(360584,114903,'116852','printshop','padding-top','20',0,''),(360585,114903,'116852','printshop','padding-bottom','20',0,''),(360586,114903,'116852','printshop','padding-left','30',0,''),(360587,114903,'116852','printshop','padding-right','30',0,''),(360588,114903,'116852','printshop','margin-bottom','20',0,''),(360589,114903,'116852','printshop','color','$content-color-1',0,''),(360590,114904,'116853','printshop','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(360591,114905,'116854','printshop','hide_parents','2',0,''),(360592,114906,'116855','printshop','float','right',0,''),(360593,114906,'116855','printshop','margin-top','-37',0,''),(360594,114906,'116855','printshop','link','comments',0,''),(360595,114907,'116856','printshop','block_type','1',0,''),(360596,114907,'116856','printshop','padding-right','30',0,''),(360597,114907,'116856','printshop','padding-right','0',0,'5333'),(360598,114907,'116856','printshop','background-color','$content-bg-1',0,''),(360599,114907,'116856','printshop','padding-top','20',0,''),(360600,114907,'116856','printshop','padding-left','30',0,''),(360601,114907,'116856','printshop','padding-bottom','20',0,''),(360602,114907,'116856','printshop','color','$content-color-1',0,''),(360603,114908,'116857','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(360604,114909,'116858','printshop','link','products',0,''),(360605,114909,'116858','printshop','float','right',0,''),(360606,114909,'116858','printshop','margin-top','-37',0,''),(360607,114911,'116860','printshop','block_type','1',0,''),(360608,114911,'116860','printshop','padding-top','20',0,''),(360609,114911,'116860','printshop','padding-left','20',0,''),(360610,114911,'116860','printshop','padding-right','20',0,''),(360611,114911,'116860','printshop','padding-bottom','20',0,''),(360612,114911,'116860','printshop','background-color','$content-bg-1',0,''),(360613,114911,'116860','printshop','style_class','order-summary2 hiding-box',0,''),(360614,114911,'116860','printshop','color','$content-bg-1',0,''),(360615,114912,'116861','printshop','margin-bottom','20',0,''),(360616,114912,'116861','printshop','text-align','right',0,''),(360617,114913,'116862','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360618,114915,'116864','printshop','block_type','1',0,''),(360619,114915,'116864','printshop','background-color','$content-bg-2',0,''),(360620,114915,'116864','printshop','padding-bottom','30',0,''),(360621,114916,'116865','printshop','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(360622,114917,'116866','printshop','block_type','4',0,''),(360623,114917,'116866','printshop','schema','4-2',0,'5342'),(360624,114918,'116867','printshop','block_type','1',0,''),(360625,114918,'116867','printshop','padding-right','40',0,''),(360626,114918,'116867','printshop','padding-right','0',0,'5342'),(360627,114919,'116868','printshop','block_type','1',0,''),(360628,114919,'116868','printshop','background-color','$content-bg-1',0,''),(360629,114919,'116868','printshop','padding-top','20',0,''),(360630,114919,'116868','printshop','padding-bottom','20',0,''),(360631,114919,'116868','printshop','padding-left','30',0,''),(360632,114919,'116868','printshop','padding-right','30',0,''),(360633,114919,'116868','printshop','margin-bottom','20',0,''),(360634,114920,'116869','printshop','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(360635,114921,'116870','printshop','hide_parents','2',0,''),(360636,114922,'116871','printshop','float','right',0,''),(360637,114922,'116871','printshop','margin-top','-37',0,''),(360638,114922,'116871','printshop','link','comments',0,''),(360639,114923,'116872','printshop','block_type','2',0,''),(360640,114923,'116872','printshop','margin-bottom','20',0,''),(360641,114923,'116872','printshop','schema','2-2',0,'5333'),(360642,114923,'116872','printshop','background-color','$content-bg-1',0,''),(360643,114924,'116873','printshop','block_type','1',0,''),(360644,114924,'116873','printshop','border-right-width','20',0,''),(360645,114924,'116873','printshop','border-right-color','$content-border-3',0,''),(360646,114924,'116873','printshop','margin-right','-10',0,''),(360647,114924,'116873','printshop','padding-right','30',0,''),(360648,114924,'116873','printshop','padding-top','20',0,''),(360649,114924,'116873','printshop','padding-left','30',0,''),(360650,114924,'116873','printshop','padding-bottom','20',0,''),(360651,114924,'116873','printshop','border-right-width','0',0,'5342'),(360652,114924,'116873','printshop','margin-right','0',0,'5342'),(360653,114924,'116873','printshop','margin-bottom','20',0,'5342'),(360654,114924,'116873','printshop','padding-left','20',0,'5342'),(360655,114924,'116873','printshop','padding-right','20',0,'5342'),(360656,114925,'116874','printshop','link','contact_information',0,''),(360657,114925,'116874','printshop','margin-top','-31',0,''),(360658,114925,'116874','printshop','float','right',0,''),(360659,114928,'116877','printshop','link','payment_method',0,''),(360660,114928,'116877','printshop','float','right',0,''),(360661,114928,'116877','printshop','margin-top','-31',0,''),(360662,114929,'116878','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(360663,114929,'116878','printshop','padding-top','20',0,''),(360664,114930,'116879','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360665,114930,'116879','printshop','clear','none',0,''),(360666,114931,'116880','printshop','block_type','1',0,''),(360667,114931,'116880','printshop','padding-left','30',0,''),(360668,114931,'116880','printshop','border-left-width','20',0,''),(360669,114931,'116880','printshop','border-left-color','$content-border-3',0,''),(360670,114931,'116880','printshop','margin-left','-10',0,''),(360671,114931,'116880','printshop','padding-right','30',0,''),(360672,114931,'116880','printshop','padding-top','20',0,''),(360673,114931,'116880','printshop','padding-bottom','20',0,''),(360674,114931,'116880','printshop','border-left-width','0',0,'5342'),(360675,114932,'116881','printshop','margin-bottom','20',0,''),(360676,114933,'116882','printshop','link','billing_address',0,''),(360677,114933,'116882','printshop','float','right',0,''),(360678,114933,'116882','printshop','margin-top','-31',0,''),(360679,114934,'116883','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360680,114934,'116883','printshop','clear','none',0,''),(360681,114935,'116884','printshop','block_type','1',0,''),(360682,114935,'116884','printshop','padding-right','30',0,''),(360683,114935,'116884','printshop','background-color','$content-bg-1',0,''),(360684,114935,'116884','printshop','padding-top','20',0,''),(360685,114935,'116884','printshop','padding-left','30',0,''),(360686,114935,'116884','printshop','padding-bottom','20',0,''),(360687,114935,'116884','printshop','padding-left','20',0,'5342'),(360688,114935,'116884','printshop','padding-right','20',0,'5342'),(360689,114936,'116885','printshop','link','products',0,''),(360690,114936,'116885','printshop','float','right',0,''),(360691,114936,'116885','printshop','margin-top','-37',0,''),(360692,114937,'116886','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(360693,114938,'116887','printshop','margin-bottom','20',0,''),(360694,114939,'116888','printshop','block_type','1',0,''),(360695,114939,'116888','printshop','padding-top','20',0,''),(360696,114939,'116888','printshop','padding-left','20',0,''),(360697,114939,'116888','printshop','padding-right','20',0,''),(360698,114939,'116888','printshop','padding-bottom','20',0,''),(360699,114939,'116888','printshop','background-color','$content-bg-1',0,''),(360700,114939,'116888','printshop','style_class','order-summary',0,''),(360701,114940,'116889','printshop','margin-bottom','20',0,''),(360702,114940,'116889','printshop','text-align','right',0,''),(360703,114942,'116891','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360704,114943,'116892','printshop','block_type','1',0,''),(360705,114943,'116892','printshop','background-color','$content-bg-2',0,''),(360706,114943,'116892','printshop','padding-bottom','30',0,''),(360707,114944,'116893','printshop','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(360708,114945,'116894','printshop','block_type','4',0,''),(360709,114945,'116894','printshop','schema','4-2',0,'5342'),(360710,114946,'116895','printshop','block_type','1',0,''),(360711,114946,'116895','printshop','padding-right','40',0,''),(360712,114946,'116895','printshop','padding-right','0',0,'5342'),(360713,114947,'116896','printshop','block_type','1',0,''),(360714,114947,'116896','printshop','padding-right','30',0,''),(360715,114947,'116896','printshop','background-color','$content-bg-1',0,''),(360716,114947,'116896','printshop','padding-top','20',0,''),(360717,114947,'116896','printshop','padding-left','30',0,''),(360718,114947,'116896','printshop','padding-bottom','20',0,''),(360719,114947,'116896','printshop','padding-left','20',0,'5342'),(360720,114947,'116896','printshop','padding-right','20',0,'5342'),(360721,114949,'116898','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(360722,114950,'116899','printshop','link','products',0,''),(360723,114950,'116899','printshop','float','right',0,''),(360724,114950,'116899','printshop','margin-top','-37',0,''),(360725,114951,'116900','printshop','block_type','2',0,''),(360726,114951,'116900','printshop','margin-bottom','20',0,''),(360727,114951,'116900','printshop','schema','2-2',0,'5333'),(360728,114951,'116900','printshop','background-color','$content-bg-1',0,''),(360729,114952,'116901','printshop','block_type','1',0,''),(360730,114952,'116901','printshop','border-right-width','20',0,''),(360731,114952,'116901','printshop','border-right-color','$content-border-3',0,''),(360732,114952,'116901','printshop','margin-right','-10',0,''),(360733,114952,'116901','printshop','padding-right','30',0,''),(360734,114952,'116901','printshop','padding-top','20',0,''),(360735,114952,'116901','printshop','padding-left','30',0,''),(360736,114952,'116901','printshop','padding-bottom','20',0,''),(360737,114952,'116901','printshop','border-right-width','0',0,'5342'),(360738,114952,'116901','printshop','margin-right','0',0,'5342'),(360739,114952,'116901','printshop','margin-bottom','20',0,'5342'),(360740,114952,'116901','printshop','padding-left','20',0,'5342'),(360741,114952,'116901','printshop','padding-right','20',0,'5342'),(360742,114953,'116902','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(360743,114954,'116903','printshop','link','contact_information',0,''),(360744,114954,'116903','printshop','margin-top','-31',0,''),(360745,114954,'116903','printshop','float','right',0,''),(360746,114955,'116904','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(360747,114955,'116904','printshop','clear','none',0,''),(360748,114957,'116906','printshop','margin-bottom','20',0,''),(360749,114959,'116908','printshop','link','shipping_address',0,''),(360750,114959,'116908','printshop','float','right',0,''),(360751,114959,'116908','printshop','margin-top','-31',0,''),(360752,114961,'116910','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(360753,114961,'116910','printshop','padding-top','20',0,''),(360754,114962,'116911','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(360755,114962,'116911','printshop','clear','none',0,''),(360756,114963,'116912','printshop','link','shipping_method',0,''),(360757,114963,'116912','printshop','float','right',0,''),(360758,114963,'116912','printshop','margin-top','-31',0,''),(360759,114964,'116913','printshop','block_type','1',0,''),(360760,114964,'116913','printshop','padding-left','30',0,''),(360761,114964,'116913','printshop','border-left-width','20',0,''),(360762,114964,'116913','printshop','border-left-color','$content-border-3',0,''),(360763,114964,'116913','printshop','margin-left','-10',0,''),(360764,114964,'116913','printshop','padding-right','30',0,''),(360765,114964,'116913','printshop','padding-top','20',0,''),(360766,114964,'116913','printshop','padding-bottom','20',0,''),(360767,114964,'116913','printshop','border-left-width','0',0,'5342'),(360768,114965,'116914','printshop','link','billing_address',0,''),(360769,114965,'116914','printshop','float','right',0,''),(360770,114965,'116914','printshop','margin-top','-31',0,''),(360771,114966,'116915','printshop','margin-bottom','20',0,''),(360772,114968,'116917','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(360773,114969,'116918','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360774,114969,'116918','printshop','clear','none',0,''),(360775,114970,'116919','printshop','link','payment_method',0,''),(360776,114970,'116919','printshop','float','right',0,''),(360777,114970,'116919','printshop','margin-top','-31',0,''),(360778,114971,'116920','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360779,114971,'116920','printshop','clear','none',0,''),(360780,114972,'116921','printshop','block_type','1',0,''),(360781,114972,'116921','printshop','background-color','$content-bg-1',0,''),(360782,114972,'116921','printshop','padding-top','20',0,''),(360783,114972,'116921','printshop','padding-bottom','20',0,''),(360784,114972,'116921','printshop','padding-left','30',0,''),(360785,114972,'116921','printshop','padding-right','30',0,''),(360786,114972,'116921','printshop','margin-bottom','20',0,''),(360787,114973,'116922','printshop','hide_parents','2',0,''),(360788,114974,'116923','printshop','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(360789,114975,'116924','printshop','float','right',0,''),(360790,114975,'116924','printshop','margin-top','-37',0,''),(360791,114975,'116924','printshop','link','comments',0,''),(360792,114976,'116925','printshop','block_type','1',0,''),(360793,114976,'116925','printshop','padding-top','20',0,''),(360794,114976,'116925','printshop','padding-left','20',0,''),(360795,114976,'116925','printshop','padding-right','20',0,''),(360796,114976,'116925','printshop','padding-bottom','20',0,''),(360797,114976,'116925','printshop','background-color','$content-bg-1',0,''),(360798,114976,'116925','printshop','style_class','order-summary',0,''),(360799,114977,'116926','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360800,114979,'116928','printshop','margin-bottom','20',0,''),(360801,114979,'116928','printshop','text-align','right',0,''),(360802,114980,'116929','printshop','block_type','1',0,''),(360803,114980,'116929','printshop','background-color','$content-bg-2',0,''),(360804,114980,'116929','printshop','padding-bottom','30',0,''),(360805,114981,'116930','printshop','block_type','4',0,''),(360806,114981,'116930','printshop','schema','4-2',0,'5342'),(360807,114982,'116931','printshop','block_type','1',0,''),(360808,114982,'116931','printshop','padding-right','40',0,''),(360809,114982,'116931','printshop','padding-right','0',0,'5342'),(360810,114983,'116932','printshop','block_type','2',0,''),(360811,114983,'116932','printshop','margin-bottom','20',0,''),(360812,114983,'116932','printshop','schema','2-2',0,'5333'),(360813,114983,'116932','printshop','background-color','$content-bg-1',0,''),(360814,114984,'116933','printshop','block_type','1',0,''),(360815,114984,'116933','printshop','border-right-width','20',0,''),(360816,114984,'116933','printshop','border-right-color','$content-border-3',0,''),(360817,114984,'116933','printshop','margin-right','-10',0,''),(360818,114984,'116933','printshop','padding-right','30',0,''),(360819,114984,'116933','printshop','padding-top','20',0,''),(360820,114984,'116933','printshop','padding-left','30',0,''),(360821,114984,'116933','printshop','padding-bottom','20',0,''),(360822,114984,'116933','printshop','border-right-width','0',0,'5342'),(360823,114984,'116933','printshop','margin-right','0',0,'5342'),(360824,114984,'116933','printshop','margin-bottom','20',0,'5342'),(360825,114984,'116933','printshop','padding-left','20',0,'5342'),(360826,114984,'116933','printshop','padding-right','20',0,'5342'),(360827,114985,'116934','printshop','margin-bottom','20',0,''),(360828,114986,'116935','printshop','link','shipping_address',0,''),(360829,114986,'116935','printshop','float','right',0,''),(360830,114986,'116935','printshop','margin-top','-31',0,''),(360831,114987,'116936','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(360832,114987,'116936','printshop','clear','none',0,''),(360833,114990,'116939','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(360834,114991,'116940','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(360835,114991,'116940','printshop','clear','none',0,''),(360836,114992,'116941','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(360837,114992,'116941','printshop','padding-top','20',0,''),(360838,114994,'116943','printshop','link','shipping_method',0,''),(360839,114994,'116943','printshop','float','right',0,''),(360840,114994,'116943','printshop','margin-top','-31',0,''),(360841,114995,'116944','printshop','link','contact_information',0,''),(360842,114995,'116944','printshop','margin-top','-31',0,''),(360843,114995,'116944','printshop','float','right',0,''),(360844,114996,'116945','printshop','block_type','1',0,''),(360845,114996,'116945','printshop','padding-left','30',0,''),(360846,114996,'116945','printshop','border-left-width','20',0,''),(360847,114996,'116945','printshop','border-left-color','$content-border-3',0,''),(360848,114996,'116945','printshop','margin-left','-10',0,''),(360849,114996,'116945','printshop','padding-right','30',0,''),(360850,114996,'116945','printshop','padding-top','20',0,''),(360851,114996,'116945','printshop','padding-bottom','20',0,''),(360852,114996,'116945','printshop','border-left-width','0',0,'5342'),(360853,114997,'116946','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(360854,114997,'116946','printshop','clear','none',0,''),(360855,114998,'116947','printshop','margin-bottom','20',0,''),(360856,114999,'116948','printshop','link','billing_address',0,''),(360857,114999,'116948','printshop','float','right',0,''),(360858,114999,'116948','printshop','margin-top','-31',0,''),(360859,115001,'116950','printshop','link','payment_method',0,''),(360860,115001,'116950','printshop','float','right',0,''),(360861,115001,'116950','printshop','margin-top','-31',0,''),(360862,115002,'116951','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(360863,115003,'116952','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(360864,115003,'116952','printshop','clear','none',0,''),(360865,115004,'116953','printshop','block_type','1',0,''),(360866,115004,'116953','printshop','padding-right','30',0,''),(360867,115004,'116953','printshop','background-color','$content-bg-1',0,''),(360868,115004,'116953','printshop','padding-top','20',0,''),(360869,115004,'116953','printshop','padding-left','30',0,''),(360870,115004,'116953','printshop','padding-bottom','20',0,''),(360871,115004,'116953','printshop','padding-left','20',0,'5342'),(360872,115004,'116953','printshop','padding-right','20',0,'5342'),(360873,115005,'116954','printshop','link','products',0,''),(360874,115005,'116954','printshop','float','right',0,''),(360875,115005,'116954','printshop','margin-top','-37',0,''),(360876,115006,'116955','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(360877,115008,'116957','printshop','block_type','1',0,''),(360878,115008,'116957','printshop','background-color','$content-bg-1',0,''),(360879,115008,'116957','printshop','padding-top','20',0,''),(360880,115008,'116957','printshop','padding-bottom','20',0,''),(360881,115008,'116957','printshop','padding-left','30',0,''),(360882,115008,'116957','printshop','padding-right','30',0,''),(360883,115008,'116957','printshop','margin-bottom','20',0,''),(360884,115009,'116958','printshop','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(360885,115010,'116959','printshop','float','right',0,''),(360886,115010,'116959','printshop','margin-top','-37',0,''),(360887,115010,'116959','printshop','link','comments',0,''),(360888,115011,'116960','printshop','hide_parents','2',0,''),(360889,115012,'116961','printshop','block_type','1',0,''),(360890,115012,'116961','printshop','padding-top','20',0,''),(360891,115012,'116961','printshop','padding-left','20',0,''),(360892,115012,'116961','printshop','padding-right','20',0,''),(360893,115012,'116961','printshop','padding-bottom','20',0,''),(360894,115012,'116961','printshop','background-color','$content-bg-1',0,''),(360895,115012,'116961','printshop','style_class','order-summary',0,''),(360896,115014,'116963','printshop','margin-bottom','20',0,''),(360897,115014,'116963','printshop','text-align','right',0,''),(360898,115015,'116964','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(360899,115016,'116965','printshop','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(360900,115017,'116966','printshop','block_type','1',0,''),(360901,115019,'116968','printshop','block_type','2',0,''),(360902,115019,'116968','printshop','font-weight','400',0,''),(360903,115019,'116968','printshop','padding-bottom','20',0,''),(360904,115019,'116968','printshop','schema','2-2',0,'5342'),(360905,115020,'116969','printshop','show_captcha','on',0,''),(360906,115021,'116970','printshop','font-weight','400',0,''),(360907,115021,'116970','printshop','padding-left','40',0,''),(360908,115021,'116970','printshop','time_format','24',0,''),(360909,115021,'116970','printshop','show_icons','on',0,''),(360910,115021,'116970','printshop','padding-left','0',0,'5342'),(360911,115022,'116971','printshop','block_type','1',0,''),(360912,115023,'116972','printshop','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(360913,115024,'116973','printshop','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(360914,115024,'116973','printshop','margin-bottom','40',0,''),(360915,115025,'116102.000001','printshop','block_type','1',0,''),(360916,115026,'116103.000001','printshop','block_type','6',0,''),(360917,115026,'116103.000001','printshop','schema','6-3',0,'5342'),(360918,115027,'116104.000001','printshop','aria_name','account-menu',0,''),(360981,115047,'116109.000001','printshop','text','<h1>##CREDIT_AMOUNT_HISTORY##</h1>',0,''),(360982,115048,'1638895944.9672','printshop','margin-bottom','20',0,''),(360983,115049,'116974','printshop','width','680',0,''),(360984,115049,'116974','printshop','font-weight','normal',0,''),(360985,115049,'116974','printshop','font-size','12',0,''),(360986,115049,'116974','printshop','padding-top','20',0,''),(360987,115049,'116974','printshop','padding-bottom','20',0,''),(360988,115049,'116974','printshop','color','$content-color-1',0,''),(360989,115050,'116975','printshop','block_type','3',0,''),(360990,115050,'116975','printshop','font-weight','normal',0,''),(360991,115050,'116975','printshop','padding-top','20',0,''),(360992,115051,'116976','printshop','font-size','12',0,''),(360993,115052,'116977','printshop','text','<p>If undelivered please return to:</p>',1,''),(360994,115052,'116977','printshop','font-size','12',0,''),(360995,115052,'116977','printshop','font-weight','bold',0,''),(360996,115052,'116977','printshop','text','<p>If undelivered please return to:</p>',2,''),(360997,115052,'116977','printshop','text','<p>If undelivered please return to:</p>',3,''),(360998,115052,'116977','printshop','text','<p>If undelivered please return to:</p>',4,''),(360999,115053,'116978','printshop','text','<p>Thank you for your order</p>',1,''),(361000,115053,'116978','printshop','color','$hileght-color-1',0,''),(361001,115053,'116978','printshop','font-size','13',0,''),(361002,115053,'116978','printshop','font-weight','bold',0,''),(361003,115053,'116978','printshop','padding-top','5',0,''),(361004,115053,'116978','printshop','text-align','center',0,''),(361005,115053,'116978','printshop','text','<p>Thank you for your order</p>',2,''),(361006,115053,'116978','printshop','text','<p>Thank you for your order</p>',3,''),(361007,115053,'116978','printshop','text','<p>Thank you for your order</p>',4,''),(361008,115054,'116979','printshop','font-weight','400',0,''),(361009,115054,'116979','printshop','text-align','center',0,''),(361010,115054,'116979','printshop','padding-top','0',0,''),(361012,115054,'116979','printshop','padding-left','20',0,''),(361013,115054,'116979','printshop','padding-right','20',0,''),(361017,115055,'116980','printshop','text','<p>If something has gone wrong please contact us at:</p>',1,''),(361018,115055,'116980','printshop','font-size','12',0,''),(361019,115055,'116980','printshop','font-weight','bold',0,''),(361020,115055,'116980','printshop','text-align','right',0,''),(361021,115055,'116980','printshop','text','<p>If something has gone wrong please contact us at:</p>',2,''),(361022,115055,'116980','printshop','text','<p>If something has gone wrong please contact us at:</p>',3,''),(361023,115055,'116980','printshop','text','<p>If something has gone wrong please contact us at:</p>',4,''),(361024,115056,'116981','printshop','block_type','6',0,''),(361025,115056,'116981','printshop','font-weight','normal',0,''),(361026,115056,'116981','printshop','font-size','16',0,''),(361027,115057,'116982','printshop','text','<p>Email:</p>',1,''),(361028,115057,'116982','printshop','font-weight','normal',0,''),(361029,115057,'116982','printshop','text-align','right',0,''),(361030,115057,'116982','printshop','font-size','12',0,''),(361031,115057,'116982','printshop','text','<p>Email:</p>',2,''),(361032,115057,'116982','printshop','text','<p>Email:</p>',3,''),(361033,115057,'116982','printshop','text','<p>Email:</p>',4,''),(361034,115058,'116983','printshop','font-weight','normal',0,''),(361035,115058,'116983','printshop','text-align','right',0,''),(361036,115058,'116983','printshop','font-size','12',0,''),(361037,115059,'116984','printshop','block_type','6',0,''),(361038,115059,'116984','printshop','font-weight','normal',0,''),(361039,115059,'116984','printshop','font-size','16',0,''),(361040,115060,'116985','printshop','text','<p>Phone:</p>',1,''),(361041,115060,'116985','printshop','font-weight','normal',0,''),(361042,115060,'116985','printshop','text-align','right',0,''),(361043,115060,'116985','printshop','font-size','12',0,''),(361044,115060,'116985','printshop','text','<p>Phone:</p>',2,''),(361045,115060,'116985','printshop','text','<p>Phone:</p>',3,''),(361046,115060,'116985','printshop','text','<p>Phone:</p>',4,''),(361047,115061,'116986','printshop','font-weight','normal',0,''),(361048,115061,'116986','printshop','text-align','right',0,''),(361049,115061,'116986','printshop','font-size','12',0,''),(361050,115062,'116987','printshop','font-weight','400',0,''),(361051,115062,'116987','printshop','padding-top','20',0,''),(361052,115062,'116987','printshop','padding-bottom','0',0,''),(361053,115062,'116987','printshop','font-size','12',0,''),(361054,115063,'116988','printshop','block_type','2',0,''),(361055,115063,'116988','printshop','font-weight','normal',0,''),(361056,115063,'116988','printshop','padding-bottom','20',0,''),(361057,115064,'116989','printshop','font-weight','400',0,''),(361058,115064,'116989','printshop','padding-top','20',0,''),(361063,115065,'116990','printshop','block_type','11',0,''),(361064,115065,'116990','printshop','font-weight','normal',0,''),(361065,115066,'116991','printshop','text','<p>Web:</p>',1,''),(361066,115066,'116991','printshop','font-weight','normal',0,''),(361067,115066,'116991','printshop','text-align','right',0,''),(361068,115066,'116991','printshop','text','<p>Web:</p>',2,''),(361069,115066,'116991','printshop','text','<p>Web:</p>',3,''),(361070,115066,'116991','printshop','text','<p>Web:</p>',4,''),(361071,115067,'116992','printshop','font-weight','normal',0,''),(361072,115067,'116992','printshop','text-align','right',0,''),(361073,115068,'116993','printshop','block_type','11',0,''),(361074,115068,'116993','printshop','font-weight','normal',0,''),(361075,115069,'116994','printshop','text','<p>Phone:</p>',1,''),(361076,115069,'116994','printshop','font-weight','normal',0,''),(361077,115069,'116994','printshop','text-align','right',0,''),(361078,115069,'116994','printshop','text','<p>Phone:</p>',2,''),(361079,115069,'116994','printshop','text','<p>Phone:</p>',3,''),(361080,115069,'116994','printshop','text','<p>Phone:</p>',4,''),(361081,115070,'116995','printshop','font-weight','normal',0,''),(361082,115070,'116995','printshop','text-align','right',0,''),(361083,115071,'116996','printshop','block_type','11',0,''),(361084,115071,'116996','printshop','font-weight','normal',0,''),(361085,115072,'116997','printshop','text','<p>Email:</p>',1,''),(361086,115072,'116997','printshop','font-weight','normal',0,''),(361087,115072,'116997','printshop','text-align','right',0,''),(361088,115072,'116997','printshop','text','<p>Email:</p>',2,''),(361089,115072,'116997','printshop','text','<p>Email:</p>',3,''),(361090,115072,'116997','printshop','text','<p>Email:</p>',4,''),(361091,115073,'116998','printshop','font-weight','normal',0,''),(361092,115073,'116998','printshop','text-align','right',0,''),(361093,115074,'116999','printshop','block_type','1',0,''),(361094,115075,'117000','printshop','font-weight','normal',0,''),(361095,115075,'117000','printshop','text-align','right',0,''),(361096,115075,'117000','printshop','padding-bottom','10',0,''),(361097,115075,'117000','printshop','address_spacer',',',0,''),(361098,115075,'117000','printshop','font-size','12',0,''),(361099,115076,'117001','printshop','block_type','5',0,''),(361100,115076,'117001','printshop','font-weight','normal',0,''),(361101,115076,'117001','printshop','border-bottom-width','1',0,''),(361102,115076,'117001','printshop','border-bottom-color','$content-border-3',0,''),(361103,115076,'117001','printshop','border-top-width','1',0,''),(361104,115076,'117001','printshop','border-top-color','$content-border-3',0,''),(361105,115076,'117001','printshop','border-left-color','$content-border-3',0,''),(361106,115076,'117001','printshop','border-left-width','1',0,''),(361107,115077,'117002','printshop','block_type','1',0,''),(361108,115077,'117002','printshop','font-weight','normal',0,''),(361109,115077,'117002','printshop','padding-top','10',0,''),(361110,115077,'117002','printshop','padding-left','10',0,''),(361111,115077,'117002','printshop','padding-right','10',0,''),(361112,115078,'117003','printshop','font-weight','400',0,''),(361113,115078,'117003','printshop','line-height','120',0,''),(361114,115078,'117003','printshop','line_height_measure','%',0,''),(361115,115078,'117003','printshop','font-size','12',0,''),(361116,115079,'117004','printshop','text','<p>SHIPPING ADDRESS:</p>',1,''),(361117,115079,'117004','printshop','font-size','14',0,''),(361118,115079,'117004','printshop','font-weight','bold',0,''),(361119,115079,'117004','printshop','padding-bottom','10',0,''),(361120,115079,'117004','printshop','text','<p>SHIPPING ADDRESS:</p>',2,''),(361121,115079,'117004','printshop','text','<p>SHIPPING ADDRESS:</p>',3,''),(361122,115079,'117004','printshop','text','<p>SHIPPING ADDRESS:</p>',4,''),(361123,115080,'117005','printshop','block_type','1',0,''),(361124,115080,'117005','printshop','background-color','$content-bg-2',0,''),(361125,115080,'117005','printshop','padding-top','20',0,''),(361126,115080,'117005','printshop','padding-left','10',0,''),(361127,115080,'117005','printshop','padding-right','10',0,''),(361128,115080,'117005','printshop','padding-bottom','20',0,''),(361129,115080,'117005','printshop','font-size','14',0,''),(361130,115081,'117006','printshop','block_type','4',0,''),(361131,115081,'117006','printshop','font-weight','normal',0,''),(361132,115081,'117006','printshop','border-top-width','1',0,''),(361133,115081,'117006','printshop','border-top-color','$content-border-3',0,''),(361134,115081,'117006','printshop','border-left-width','1',0,''),(361135,115081,'117006','printshop','border-left-color','$content-border-3',0,''),(361136,115081,'117006','printshop','border-right-width','1',0,''),(361137,115081,'117006','printshop','border-right-color','$content-border-3',0,''),(361138,115081,'117006','printshop','border-bottom-width','1',0,''),(361139,115081,'117006','printshop','border-bottom-color','$content-border-3',0,''),(361140,115082,'117007','printshop','block_type','2',0,''),(361141,115082,'117007','printshop','font-weight','normal',0,''),(361142,115082,'117007','printshop','border-right-width','1',0,''),(361143,115082,'117007','printshop','border-right-color','$content-border-3',0,''),(361144,115083,'117008','printshop','block_type','1',0,''),(361145,115083,'117008','printshop','font-weight','400',0,''),(361146,115083,'117008','printshop','background-color','$content-bg-2',0,''),(361147,115083,'117008','printshop','padding-top','10',0,''),(361148,115083,'117008','printshop','padding-left','10',0,''),(361149,115083,'117008','printshop','padding-right','10',0,''),(361150,115083,'117008','printshop','padding-bottom','30',0,''),(361151,115084,'117009','printshop','text','<p>INVOICE ADDRESS:</p>',1,''),(361152,115084,'117009','printshop','font-size','14',0,''),(361153,115084,'117009','printshop','font-weight','bold',0,''),(361154,115084,'117009','printshop','text','<p>INVOICE ADDRESS:</p>',2,''),(361155,115084,'117009','printshop','text','<p>INVOICE ADDRESS:</p>',3,''),(361156,115084,'117009','printshop','text','<p>INVOICE ADDRESS:</p>',4,''),(361157,115085,'117010','printshop','font-size','12',0,''),(361158,115086,'117011','printshop','block_type','1',0,''),(361159,115086,'117011','printshop','font-weight','normal',0,''),(361160,115086,'117011','printshop','padding-top','10',0,''),(361161,115086,'117011','printshop','padding-left','10',0,''),(361162,115086,'117011','printshop','padding-right','10',0,''),(361163,115086,'117011','printshop','padding-bottom','10',0,''),(361164,115087,'117012','printshop','font-weight','normal',0,''),(361165,115088,'117013','printshop','text','<p>CUSTOMER:</p>',1,''),(361166,115088,'117013','printshop','font-size','13',0,''),(361167,115088,'117013','printshop','font-weight','bold',0,''),(361168,115088,'117013','printshop','text','<p>CUSTOMER:</p>',2,''),(361169,115088,'117013','printshop','text','<p>CUSTOMER:</p>',3,''),(361170,115088,'117013','printshop','text','<p>CUSTOMER:</p>',4,''),(361171,115089,'117014','printshop','text','<p>PHONE NUMBER:</p>',1,''),(361172,115089,'117014','printshop','font-size','14',0,''),(361173,115089,'117014','printshop','font-weight','bold',0,''),(361174,115089,'117014','printshop','padding-top','10',0,''),(361175,115089,'117014','printshop','text','<p>PHONE NUMBER:</p>',2,''),(361176,115089,'117014','printshop','text','<p>PHONE NUMBER:</p>',3,''),(361177,115089,'117014','printshop','text','<p>PHONE NUMBER:</p>',4,''),(361178,115090,'117015','printshop','font-weight','normal',0,''),(361179,115092,'117017','printshop','text','<p>E-MAIL ADDRESS:</p>',1,''),(361180,115092,'117017','printshop','font-weight','bold',0,''),(361181,115092,'117017','printshop','font-size','14',0,''),(361182,115092,'117017','printshop','padding-top','10',0,''),(361183,115092,'117017','printshop','text','<p>E-MAIL ADDRESS:</p>',2,''),(361184,115092,'117017','printshop','text','<p>E-MAIL ADDRESS:</p>',3,''),(361185,115092,'117017','printshop','text','<p>E-MAIL ADDRESS:</p>',4,''),(361186,115093,'117018','printshop','block_type','2',0,''),(361187,115093,'117018','printshop','font-weight','normal',0,''),(361188,115093,'117018','printshop','border-top-width','1',0,''),(361189,115093,'117018','printshop','border-top-color','$content-border-3',0,''),(361190,115093,'117018','printshop','border-right-width','1',0,''),(361191,115093,'117018','printshop','border-right-color','$content-border-3',0,''),(361192,115094,'117019','printshop','block_type','1',0,''),(361193,115094,'117019','printshop','font-weight','normal',0,''),(361194,115094,'117019','printshop','padding-top','10',0,''),(361195,115094,'117019','printshop','padding-left','10',0,''),(361196,115094,'117019','printshop','padding-right','10',0,''),(361197,115094,'117019','printshop','padding-bottom','10',0,''),(361198,115094,'117019','printshop','border-right-width','1',0,''),(361199,115094,'117019','printshop','border-right-color','$content-border-3',0,''),(361200,115096,'117021','printshop','text','<p>Shipping via</p>',1,''),(361201,115096,'117021','printshop','font-weight','bold',0,''),(361202,115096,'117021','printshop','font-size','14',0,''),(361203,115096,'117021','printshop','text','<p>Shipping via</p>',2,''),(361204,115096,'117021','printshop','text','<p>Shipping via</p>',3,''),(361205,115096,'117021','printshop','text','<p>Shipping via</p>',4,''),(361206,115097,'117022','printshop','block_type','1',0,''),(361207,115097,'117022','printshop','font-weight','normal',0,''),(361208,115097,'117022','printshop','padding-top','10',0,''),(361209,115097,'117022','printshop','padding-left','10',0,''),(361210,115097,'117022','printshop','padding-right','10',0,''),(361211,115097,'117022','printshop','padding-bottom','10',0,''),(361212,115098,'117023','printshop','text','<p>Shipping service</p>',1,''),(361213,115098,'117023','printshop','font-weight','bold',0,''),(361214,115098,'117023','printshop','font-size','14',0,''),(361215,115098,'117023','printshop','text','<p>Shipping service</p>',2,''),(361216,115098,'117023','printshop','text','<p>Shipping service</p>',3,''),(361217,115098,'117023','printshop','text','<p>Shipping service</p>',4,''),(361218,115100,'117025','printshop','font-size','14',0,''),(361219,115100,'117025','printshop','font-weight','bold',0,''),(361220,115100,'117025','printshop','text-align','center',0,''),(361221,115100,'117025','printshop','padding-bottom','10',0,''),(361222,115100,'117025','printshop','padding-top','10',0,''),(361223,115101,'117026','printshop','text','<p>Payment date:</p>',1,''),(361224,115101,'117026','printshop','font-weight','bold',0,''),(361225,115101,'117026','printshop','text-align','center',0,''),(361226,115101,'117026','printshop','font-size','12',0,''),(361227,115101,'117026','printshop','text','<p>Payment date:</p>',2,''),(361228,115101,'117026','printshop','text','<p>Payment date:</p>',3,''),(361229,115101,'117026','printshop','text','<p>Payment date:</p>',4,''),(361230,115102,'117027','printshop','font-weight','normal',0,''),(361231,115102,'117027','printshop','text-align','center',0,''),(361232,115102,'117027','printshop','padding-bottom','10',0,''),(361233,115103,'117034','printshop','text-align','center',0,''),(361234,115103,'117034','printshop','padding-top','10',0,''),(361235,115104,'1639155816.3893','printshop','block_type','1',0,''),(361236,115105,'117028','printshop','padding-top','30',0,''),(361237,115105,'117028','printshop','padding-bottom','30',0,''),(361238,115109,'117032','printshop','col_in_row','4',0,''),(361239,115109,'117032','printshop','listing_type','productListing',0,''),(361240,115109,'117032','printshop','view_as','carousel',0,''),(361241,115109,'117032','printshop','col_in_row','3',0,'5342'),(361242,115109,'117032','printshop','col_in_row','2',0,'5333'),(361243,115109,'117032','printshop','col_in_row','1',0,'5363'),(361244,115111,'1639485067.5512','printshop','padding-top','30',0,''),(361245,115111,'1639485067.5512','printshop','padding-bottom','30',0,''),(361246,115113,'1639154415.2739','printshop','block_type','1',0,''),(361247,115115,'117036','printshop','heading_type','h1',0,''),(361248,115116,'1639419797.9718','printshop','page_id','4',0,''),(361249,115116,'1639419797.9718','printshop','padding-top','30',0,''),(361250,115116,'1639419797.9718','printshop','padding-bottom','30',0,''),(361251,115119,'117039','printshop','text-align','center',0,''),(361252,115119,'117039','printshop','padding-top','10',0,''),(361253,115124,'117044','printshop','block_type','1',0,''),(361254,115125,'117045','printshop','block_type','1',0,''),(361255,115125,'117045','printshop','max-width','800',0,''),(361256,115125,'117045','printshop','margin','0 auto',0,''),(361257,115125,'117045','printshop','background-color','$content-bg-1',0,''),(361258,115126,'117046','printshop','color','$content-color-1',0,''),(361259,115126,'117046','printshop','font-size','12',0,''),(361260,115126,'117046','printshop','padding-top','20',0,''),(361261,115126,'117046','printshop','padding-bottom','20',0,''),(361262,115126,'117046','printshop','border-top-width','1',0,''),(361263,115126,'117046','printshop','border-top-color','$content-border-3',0,''),(361264,115127,'117047','printshop','font-weight','normal',0,''),(361265,115127,'117047','printshop','padding-top','20',0,''),(361266,115127,'117047','printshop','padding-left','10',0,''),(361267,115127,'117047','printshop','padding-right','10',0,''),(361268,115127,'117047','printshop','padding-bottom','20',0,''),(361269,115127,'117047','printshop','color','$content-color-1',0,''),(361270,115127,'117047','printshop','font-size','14',0,''),(361271,115128,'117048','printshop','block_type','7',0,''),(361272,115128,'117048','printshop','font-weight','normal',0,''),(361273,115128,'117048','printshop','background-color','$highlight-box-bg-2',0,''),(361274,115128,'117048','printshop','padding-top','5',0,''),(361275,115128,'117048','printshop','padding-left','10',0,''),(361276,115128,'117048','printshop','padding-right','10',0,''),(361277,115128,'117048','printshop','padding-bottom','5',0,''),(361278,115129,'117049','printshop','color','$highlight-box-color-2',0,''),(361279,115129,'117049','printshop','font-size','14',0,''),(361280,115129,'117049','printshop','font-weight','normal',0,''),(361281,115130,'117050','printshop','font-weight','normal',0,''),(361282,115130,'117050','printshop','text-align','right',0,''),(361283,115130,'117050','printshop','color','$highlight-box-color-2',0,''),(361284,115130,'117050','printshop','font-size','12',0,''),(361285,115131,'117051','printshop','font-weight','normal',0,''),(361286,115131,'117051','printshop','padding-bottom','10',0,''),(361287,115131,'117051','printshop','padding-top','10',0,''),(361288,115131,'117051','printshop','logo_from','theme',0,''),(361289,115131,'117051','printshop','padding-left','20',0,''),(361290,115132,'117052','printshop','block_type','1',0,''),(361291,115133,'117053','printshop','block_type','1',0,''),(361292,115133,'117053','printshop','max-width','800',0,''),(361293,115133,'117053','printshop','margin','0 auto',0,''),(361294,115133,'117053','printshop','background-color','$content-bg-1',0,''),(361295,115134,'117054','printshop','color','$content-color-1',0,''),(361296,115134,'117054','printshop','font-size','12',0,''),(361297,115134,'117054','printshop','padding-top','20',0,''),(361298,115134,'117054','printshop','padding-bottom','20',0,''),(361299,115134,'117054','printshop','border-top-width','1',0,''),(361300,115134,'117054','printshop','border-top-color','$content-border-3',0,''),(361301,115135,'117055','printshop','font-weight','normal',0,''),(361302,115135,'117055','printshop','padding-bottom','10',0,''),(361303,115135,'117055','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',1,''),(361304,115135,'117055','printshop','padding-left','20',0,''),(361305,115135,'117055','printshop','padding-top','10',0,''),(361306,115135,'117055','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',2,''),(361307,115135,'117055','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',3,''),(361308,115135,'117055','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',4,''),(361309,115136,'117056','printshop','font-weight','normal',0,''),(361310,115136,'117056','printshop','padding-top','20',0,''),(361311,115136,'117056','printshop','padding-left','10',0,''),(361312,115136,'117056','printshop','padding-right','10',0,''),(361313,115136,'117056','printshop','padding-bottom','20',0,''),(361314,115136,'117056','printshop','color','$content-color-1',0,''),(361315,115136,'117056','printshop','font-size','14',0,''),(361316,115137,'117057','printshop','block_type','7',0,''),(361317,115137,'117057','printshop','font-weight','normal',0,''),(361318,115137,'117057','printshop','background-color','$highlight-box-bg-1',0,''),(361319,115137,'117057','printshop','padding-top','5',0,''),(361320,115137,'117057','printshop','padding-left','10',0,''),(361321,115137,'117057','printshop','padding-right','10',0,''),(361322,115137,'117057','printshop','padding-bottom','5',0,''),(361323,115138,'117058','printshop','color','$highlight-box-color-1',0,''),(361324,115138,'117058','printshop','font-size','15',0,''),(361325,115138,'117058','printshop','font-weight','700',0,''),(361326,115139,'117059','printshop','font-weight','normal',0,''),(361327,115139,'117059','printshop','text-align','right',0,''),(361328,115139,'117059','printshop','color','$highlight-box-color-1',0,''),(361329,115139,'117059','printshop','font-size','12',0,''),(361330,115140,'117060','printshop','block_type','1',0,''),(361331,115140,'117060','printshop','background-color','$content-bg-2',0,''),(361332,115141,'117061','printshop','block_type','1',0,''),(361333,115141,'117061','printshop','max-width','800',0,''),(361334,115141,'117061','printshop','margin','0 auto',0,''),(361335,115142,'117062','printshop','block_type','1',0,''),(361336,115142,'117062','printshop','background-color','$content-bg-1',0,''),(361337,115142,'117062','printshop','padding-top','20',0,''),(361338,115142,'117062','printshop','padding-left','20',0,''),(361339,115142,'117062','printshop','padding-right','20',0,''),(361340,115142,'117062','printshop','padding-bottom','20',0,''),(361341,115143,'117063','printshop','font-weight','normal',0,''),(361342,115143,'117063','printshop','padding-top','20',0,''),(361343,115143,'117063','printshop','padding-bottom','20',0,''),(361344,115143,'117063','printshop','color','$content-color-1',0,''),(361345,115143,'117063','printshop','font-size','14',0,''),(361346,115144,'117064','printshop','block_type','7',0,''),(361347,115144,'117064','printshop','font-weight','normal',0,''),(361348,115144,'117064','printshop','padding-left','10',0,''),(361349,115144,'117064','printshop','padding-right','10',0,''),(361350,115144,'117064','printshop','padding-bottom','15',0,''),(361351,115144,'117064','printshop','border-bottom-width','1',0,''),(361352,115144,'117064','printshop','border-bottom-color','$content-border-3',0,''),(361353,115145,'117065','printshop','color','$content-color-1',0,''),(361354,115145,'117065','printshop','font-size','14',0,''),(361355,115145,'117065','printshop','font-weight','700',0,''),(361356,115146,'117066','printshop','font-weight','normal',0,''),(361357,115146,'117066','printshop','text-align','right',0,''),(361358,115146,'117066','printshop','color','$fade-color-1',0,''),(361359,115146,'117066','printshop','font-size','11',0,''),(361360,115146,'117066','printshop','text-transform','uppercase',0,''),(361361,115147,'117067','printshop','color','$fade-color-1',0,''),(361362,115147,'117067','printshop','font-size','12',0,''),(361363,115147,'117067','printshop','padding-top','20',0,''),(361364,115147,'117067','printshop','padding-bottom','20',0,''),(361365,115147,'117067','printshop','text-align','center',0,''),(361366,115148,'117068','printshop','font-weight','normal',0,''),(361367,115148,'117068','printshop','padding-bottom','10',0,''),(361368,115148,'117068','printshop','padding-top','10',0,''),(361369,115148,'117068','printshop','text-align','center',0,''),(361370,115148,'117068','printshop','logo_from','theme',0,''),(361371,115149,'117069','printshop','block_type','1',0,''),(361372,115149,'117069','printshop','background-color','$content-bg-2',0,''),(361373,115149,'117069','printshop','padding-top','20',0,''),(361374,115149,'117069','printshop','padding-bottom','20',0,''),(361375,115150,'117070','printshop','block_type','1',0,''),(361376,115150,'117070','printshop','max-width','800',0,''),(361377,115150,'117070','printshop','margin','0 auto',0,''),(361378,115151,'117071','printshop','color','$fade-color-1',0,''),(361379,115151,'117071','printshop','font-size','12',0,''),(361380,115151,'117071','printshop','padding-top','20',0,''),(361381,115151,'117071','printshop','padding-bottom','20',0,''),(361382,115151,'117071','printshop','text-align','left',0,''),(361383,115152,'117072','printshop','block_type','1',0,''),(361384,115152,'117072','printshop','background-color','$content-bg-1',0,''),(361385,115152,'117072','printshop','padding-top','20',0,''),(361386,115152,'117072','printshop','padding-left','20',0,''),(361387,115152,'117072','printshop','padding-right','20',0,''),(361388,115152,'117072','printshop','padding-bottom','20',0,''),(361389,115152,'117072','printshop','border-top-width','1',0,''),(361390,115152,'117072','printshop','border-left-width','1',0,''),(361391,115152,'117072','printshop','border-right-width','1',0,''),(361392,115152,'117072','printshop','border-bottom-width','1',0,''),(361393,115152,'117072','printshop','border-top-color','$content-border-3',0,''),(361394,115152,'117072','printshop','border-left-color','$content-border-3',0,''),(361395,115152,'117072','printshop','border-bottom-color','$content-border-3',0,''),(361396,115152,'117072','printshop','border-right-color','$content-border-3',0,''),(361397,115153,'117073','printshop','block_type','2',0,''),(361398,115154,'117074','printshop','font-weight','normal',0,''),(361399,115154,'117074','printshop','padding-bottom','10',0,''),(361400,115154,'117074','printshop','padding-top','10',0,''),(361401,115154,'117074','printshop','logo_from','theme',0,''),(361402,115155,'117075','printshop','font-weight','normal',0,''),(361403,115155,'117075','printshop','text-align','right',0,''),(361404,115155,'117075','printshop','color','$fade-color-1',0,''),(361405,115155,'117075','printshop','font-size','11',0,''),(361406,115155,'117075','printshop','text-transform','uppercase',0,''),(361407,115156,'117076','printshop','color','$content-color-1',0,''),(361408,115156,'117076','printshop','font-size','14',0,''),(361409,115156,'117076','printshop','font-weight','700',0,''),(361410,115156,'117076','printshop','text-align','right',0,''),(361411,115157,'117077','printshop','font-weight','normal',0,''),(361412,115157,'117077','printshop','padding-top','20',0,''),(361413,115157,'117077','printshop','padding-bottom','20',0,''),(361414,115157,'117077','printshop','color','$content-color-1',0,''),(361415,115157,'117077','printshop','font-size','14',0,''),(361416,115158,'121029','printshop','block_type','1',0,''),(361417,115161,'121032','printshop','margin-bottom','30',0,''),(361418,115162,'121025','printshop','block_type','1',0,''),(361419,115163,'121026','printshop','text','<h1>CATALOGUE</h1>',0,''),(361420,115165,'117078','printshop','block_type','1',0,''),(361421,115165,'117078','printshop','font-weight','normal',0,''),(361422,115165,'117078','printshop','padding-top','50',0,''),(361423,115165,'117078','printshop','background-color','$footer-bg-1',0,''),(361424,115165,'117078','printshop','style_class','preFooter',0,''),(361425,115165,'117078','printshop','padding-bottom','25',0,''),(361426,115165,'117078','printshop','padding-top','20',0,'5342'),(361427,115165,'117078','printshop','padding-bottom','20',0,'5342'),(361428,115165,'117078','printshop','color','$footer-color-1',0,''),(361429,115166,'120869','printshop','block_type','3',0,''),(361430,115166,'120869','printshop','padding-top','30',0,''),(361431,115166,'120869','printshop','margin-top','24',0,''),(361432,115166,'120869','printshop','border-top-width','1',0,''),(361433,115166,'120869','printshop','border-top-color','$footer-border-1',0,''),(361434,115166,'120869','printshop','border-top-width','0',0,'5342'),(361435,115166,'120869','printshop','padding-top','0',0,'5342'),(361436,115166,'120869','printshop','schema','3-6',0,'5342'),(361437,115167,'120870','printshop','logo','themes/printshop/img/delivery-box.png',1,''),(361438,115167,'120870','printshop','float','left',0,''),(361439,115167,'120870','printshop','clear','none',0,''),(361440,115167,'120870','printshop','padding-bottom','20',0,'5342'),(361441,115167,'120870','printshop','text-align','center',0,'5342'),(361442,115167,'120870','printshop','float','none',0,'5342'),(361443,115167,'120870','printshop','logo','themes/printshop/img/delivery-box.png',2,''),(361444,115167,'120870','printshop','logo','themes/printshop/img/delivery-box.png',3,''),(361445,115167,'120870','printshop','logo','themes/printshop/img/delivery-box.png',4,''),(361446,115168,'1644341222.4626','printshop','text-align','center',0,''),(361447,115168,'1644341222.4626','printshop','padding-bottom','20',0,'5342'),(361448,115169,'1644573331.7071','printshop','logo','themes/printshop/img/Untitled-2.png',1,''),(361449,115169,'1644573331.7071','printshop','text-align','right',0,''),(361450,115169,'1644573331.7071','printshop','padding-top','4',0,''),(361451,115169,'1644573331.7071','printshop','text-align','center',0,'5342'),(361452,115169,'1644573331.7071','printshop','logo','themes/printshop/img/Untitled-2.png',2,''),(361453,115169,'1644573331.7071','printshop','logo','themes/printshop/img/Untitled-2.png',3,''),(361454,115169,'1644573331.7071','printshop','logo','themes/printshop/img/Untitled-2.png',4,''),(361455,115170,'1644340895.1318','printshop','block_type','12',0,''),(361456,115170,'1644340895.1318','printshop','schema','12-2',0,'5342'),(361457,115171,'117085','printshop','class','menu-style-2',0,''),(361458,115171,'117085','printshop','type','builder',0,''),(361459,115171,'117085','printshop','style','3',0,''),(361460,115171,'117085','printshop','lev2_vis','click',0,'5342'),(361461,115171,'117085','printshop','style_class','footer-menu',0,''),(361462,115172,'1644342832.3703','printshop','block_type','2',0,''),(361463,115172,'1644342832.3703','printshop','schema','2-2',0,'5333'),(361464,115173,'117091','printshop','view_item','address',0,''),(361465,115173,'117091','printshop','address_spacer',',<br>',0,''),(361466,115173,'117091','printshop','color','$fade-color-2',0,''),(361467,115173,'117091','printshop','data_format_content','<div>##TITLE##</div><div>Location: ##POST_ADDRESS##</div><div>Phone number: ##TELEPHONE##</div>',0,''),(361468,115173,'117091','printshop','margin-top','20',0,'5333'),(361469,115173,'117091','printshop','padding-right','30',0,''),(361470,115174,'1644406988.3921','printshop','text','Contact',1,''),(361471,115174,'1644406988.3921','printshop','color','$fade-color-2',0,''),(361472,115174,'1644406988.3921','printshop','font-size','18',0,''),(361473,115174,'1644406988.3921','printshop','text-transform','uppercase',0,''),(361474,115174,'1644406988.3921','printshop','margin-bottom','10',0,''),(361475,115174,'1644406988.3921','printshop','font-weight','300',0,''),(361476,115174,'1644406988.3921','printshop','text','Contact',2,''),(361477,115174,'1644406988.3921','printshop','text','Contact',3,''),(361478,115174,'1644406988.3921','printshop','text','Contact',4,''),(361479,115175,'1644406713.4425','printshop','view_item','phone_number',0,''),(361480,115175,'1644406713.4425','printshop','color','$fade-color-2',0,''),(361481,115175,'1644406713.4425','printshop','font-size','18',0,''),(361482,115175,'1644406713.4425','printshop','padding-top','40',0,''),(361483,115175,'1644406713.4425','printshop','content','\\f095',0,'3'),(361484,115175,'1644406713.4425','printshop','font-family','$font-icons-1',0,'3'),(361485,115175,'1644406713.4425','printshop','font-size','18',0,'3'),(361486,115175,'1644406713.4425','printshop','margin-right','14',0,'3'),(361487,115175,'1644406713.4425','printshop','display','inline-block',0,'3'),(361488,115175,'1644406713.4425','printshop','vertical-align','middle',0,'3'),(361489,115176,'1644406751.9542','printshop','view_item','email',0,''),(361490,115176,'1644406751.9542','printshop','add_link_on_email','1',0,''),(361491,115176,'1644406751.9542','printshop','color','$footer-color-2',0,''),(361492,115176,'1644406751.9542','printshop','font-size','16',0,''),(361493,115176,'1644406751.9542','printshop','content','\\e75a',0,'3'),(361494,115176,'1644406751.9542','printshop','font-family','$font-icons-3',0,'3'),(361495,115176,'1644406751.9542','printshop','font-size','18',0,'3'),(361496,115176,'1644406751.9542','printshop','margin-right','10',0,'3'),(361497,115176,'1644406751.9542','printshop','display','inline-block',0,'3'),(361498,115176,'1644406751.9542','printshop','vertical-align','middle',0,'3'),(361499,115176,'1644406751.9542','printshop','color','$fade-color-2',0,'3'),(361500,115177,'117093','printshop','block_type','1',0,''),(361501,115177,'117093','printshop','font-weight','400',0,''),(361502,115177,'117093','printshop','padding-top','20',0,''),(361503,115177,'117093','printshop','padding-bottom','20',0,''),(361504,115177,'117093','printshop','schema','2-2',0,''),(361505,115177,'117093','printshop','schema','2-3',0,'5342'),(361506,115177,'117093','printshop','background-color','$footer-bg-2',0,''),(361507,115177,'117093','printshop','color','$footer-color-1',0,''),(361508,115178,'117094','printshop','color','$fade-color-2',0,''),(361509,115178,'117094','printshop','text-align','center',0,''),(361510,115178,'117094','printshop','font-size','14',0,''),(361511,115178,'117094','printshop','font-family','$font-1',0,''),(361512,115178,'117094','printshop','font-weight','400',0,''),(361513,115179,'117096','printshop','block_type','5',0,''),(361514,115180,'117097','printshop','text','##TEXT_LANGUAGE##',0,''),(361515,115182,'117099','printshop','block_type','5',0,''),(361516,115183,'117100','printshop','text','##TEXT_CURRENCY##',0,''),(361517,115185,'117102','printshop','block_type','1',0,''),(361518,115185,'117102','printshop','font-weight','normal',0,''),(361519,115186,'117103','printshop','block_type','2',0,''),(361520,115186,'117103','printshop','font-weight','normal',0,''),(361521,115186,'117103','printshop','padding-bottom','20',0,''),(361522,115187,'117104','printshop','block_type','1',0,''),(361523,115187,'117104','printshop','margin-right','20',0,''),(361524,115190,'117107','printshop','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(361525,115190,'117107','printshop','font-weight','normal',0,''),(361526,115190,'117107','printshop','padding-bottom','20',0,''),(361527,115190,'117107','printshop','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(361528,115190,'117107','printshop','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(361529,115190,'117107','printshop','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(361530,115192,'117109','printshop','block_type','1',0,''),(361531,115192,'117109','printshop','font-weight','normal',0,''),(361532,115192,'117109','printshop','style_class','gift-card-view',0,''),(361533,115192,'117109','printshop','text-align','center',0,''),(361534,115192,'117109','printshop','padding-bottom','20',0,''),(361535,115192,'117109','printshop','background-color','$highlight-box-bg-1',0,''),(361536,115192,'117109','printshop','padding-left','20',0,''),(361537,115192,'117109','printshop','padding-right','20',0,''),(361538,115192,'117109','printshop','color','$highlight-box-color-1',0,''),(361539,115193,'117110','printshop','block_type','1',0,''),(361540,115193,'117110','printshop','font-weight','normal',0,''),(361541,115193,'117110','printshop','padding-top','10',0,''),(361542,115194,'117111','printshop','font-size','12',0,''),(361543,115194,'117111','printshop','font-weight','bold',0,''),(361544,115194,'117111','printshop','text-align','center',0,''),(361545,115194,'117111','printshop','style_class','email',0,''),(361546,115195,'117112','printshop','text','<p>If you require further assistance please contact us</p>',1,''),(361547,115195,'117112','printshop','font-weight','normal',0,''),(361548,115195,'117112','printshop','text-align','center',0,''),(361549,115195,'117112','printshop','font-size','12',0,''),(361550,115195,'117112','printshop','padding-top','10',0,''),(361551,115195,'117112','printshop','padding-bottom','5',0,''),(361552,115195,'117112','printshop','border-top-width','1',0,''),(361553,115195,'117112','printshop','border-top-color','$warning-border',0,''),(361554,115195,'117112','printshop','text','<p>If you require further assistance please contact us</p>',2,''),(361555,115195,'117112','printshop','text','<p>If you require further assistance please contact us</p>',3,''),(361556,115195,'117112','printshop','text','<p>If you require further assistance please contact us</p>',4,''),(361557,115196,'117113','printshop','font-size','12',0,''),(361558,115196,'117113','printshop','font-weight','bold',0,''),(361559,115196,'117113','printshop','text-align','center',0,''),(361560,115196,'117113','printshop','style_class','phone',0,''),(361561,115196,'117113','printshop','padding-bottom','5',0,''),(361562,115197,'117114','printshop','text','<p>WHAT TO DO NEXT:</p>',1,''),(361563,115197,'117114','printshop','font-weight','normal',0,''),(361564,115197,'117114','printshop','text-align','center',0,''),(361565,115197,'117114','printshop','padding-top','20',0,''),(361566,115197,'117114','printshop','padding-bottom','10',0,''),(361567,115197,'117114','printshop','style_class','question-ico',0,''),(361568,115197,'117114','printshop','border-top-width','1',0,''),(361569,115197,'117114','printshop','border-top-color','$warning-border',0,''),(361570,115197,'117114','printshop','font-size','18',0,''),(361571,115197,'117114','printshop','text','<p>WHAT TO DO NEXT:</p>',2,''),(361572,115197,'117114','printshop','text','<p>WHAT TO DO NEXT:</p>',3,''),(361573,115197,'117114','printshop','text','<p>WHAT TO DO NEXT:</p>',4,''),(361574,115198,'117115','printshop','text','<p>osCommerce</p>\n',1,''),(361575,115198,'117115','printshop','font-family','$font-1',0,''),(361576,115198,'117115','printshop','font-size','24',0,''),(361577,115198,'117115','printshop','font-weight','normal',0,''),(361578,115198,'117115','printshop','text-align','center',0,''),(361579,115198,'117115','printshop','padding-top','10',0,''),(361580,115198,'117115','printshop','padding-bottom','20',0,''),(361581,115198,'117115','printshop','text','<p>osCommerce</p>\n',2,''),(361582,115198,'117115','printshop','text','<p>osCommerce</p>\n',3,''),(361583,115198,'117115','printshop','text','<p>osCommerce</p>\n',4,''),(361584,115199,'117116','printshop','block_type','4',0,''),(361585,115199,'117116','printshop','color','$highlight-box-color-4',0,''),(361586,115199,'117116','printshop','font-size','30',0,''),(361587,115199,'117116','printshop','font-weight','normal',0,''),(361588,115199,'117116','printshop','background-color','$highlight-box-bg-4',0,''),(361589,115199,'117116','printshop','padding-top','5',0,''),(361590,115199,'117116','printshop','padding-left','10',0,''),(361591,115199,'117116','printshop','padding-right','10',0,''),(361592,115199,'117116','printshop','padding-bottom','5',0,''),(361593,115200,'117117','printshop','text','<p>Your code is:</p>',1,''),(361594,115200,'117117','printshop','font-weight','normal',0,''),(361595,115200,'117117','printshop','text','<p>Your code is:</p>',2,''),(361596,115200,'117117','printshop','text','<p>Your code is:</p>',3,''),(361597,115200,'117117','printshop','text','<p>Your code is:</p>',4,''),(361598,115202,'117119','printshop','font-weight','normal',0,''),(361599,115202,'117119','printshop','text-align','center',0,''),(361600,115202,'117119','printshop','padding-bottom','20',0,''),(361601,115203,'117120','printshop','font-size','60',0,''),(361602,115203,'117120','printshop','font-weight','bold',0,''),(361603,115203,'117120','printshop','text-align','center',0,''),(361604,115203,'117120','printshop','line-height','100',0,''),(361605,115203,'117120','printshop','padding-bottom','20',0,''),(361606,115203,'117120','printshop','line_height_measure','px',0,''),(361607,115204,'117121','printshop','text','<p>PERSONAL MESSAGE</p>',1,''),(361608,115204,'117121','printshop','font-size','18',0,''),(361609,115204,'117121','printshop','font-weight','normal',0,''),(361610,115204,'117121','printshop','text-align','center',0,''),(361611,115204,'117121','printshop','padding-top','20',0,''),(361612,115204,'117121','printshop','padding-bottom','10',0,''),(361613,115204,'117121','printshop','border-top-width','1',0,''),(361614,115204,'117121','printshop','border-top-color','$warning-border',0,''),(361615,115204,'117121','printshop','text','<p>PERSONAL MESSAGE</p>',2,''),(361616,115204,'117121','printshop','text','<p>PERSONAL MESSAGE</p>',3,''),(361617,115204,'117121','printshop','text','<p>PERSONAL MESSAGE</p>',4,''),(361618,115205,'117123','printshop','logo','themes/printshop/img/themes/printshop/img/Logo.jpg',1,''),(361619,115205,'117123','printshop','logo_from','theme',0,''),(361620,115205,'117123','printshop','padding-top','20',0,''),(361621,115205,'117123','printshop','text-align','center',0,''),(361622,115205,'117123','printshop','logo','themes/printshop/img/themes/printshop/img/Logo.jpg',2,''),(361623,115205,'117123','printshop','logo','themes/printshop/img/themes/printshop/img/Logo.jpg',3,''),(361624,115205,'117123','printshop','logo','themes/printshop/img/themes/printshop/img/Logo.jpg',4,''),(361625,115206,'117124','printshop','text','<p>GIFT CARD</p>',1,''),(361626,115206,'117124','printshop','font-size','30',0,''),(361627,115206,'117124','printshop','font-weight','normal',0,''),(361628,115206,'117124','printshop','border-top-width','1',0,''),(361629,115206,'117124','printshop','border-top-color','$warning-border',0,''),(361630,115206,'117124','printshop','style_class','gift-ico',0,''),(361631,115206,'117124','printshop','text-align','center',0,''),(361632,115206,'117124','printshop','padding-top','15',0,''),(361633,115206,'117124','printshop','text','<p>GIFT CARD</p>',2,''),(361634,115206,'117124','printshop','text','<p>GIFT CARD</p>',3,''),(361635,115206,'117124','printshop','text','<p>GIFT CARD</p>',4,''),(361636,115207,'117125','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(361637,115207,'117125','printshop','font-weight','normal',0,''),(361638,115207,'117125','printshop','text-align','center',0,''),(361639,115207,'117125','printshop','padding-bottom','10',0,''),(361640,115207,'117125','printshop','font-size','14',0,''),(361641,115207,'117125','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(361642,115207,'117125','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(361643,115207,'117125','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(361644,115208,'117126','printshop','block_type','1',0,''),(361645,115208,'117126','printshop','font-weight','normal',0,''),(361646,115208,'117126','printshop','style_class','gift-card-view',0,''),(361647,115208,'117126','printshop','text-align','center',0,''),(361648,115208,'117126','printshop','padding-bottom','20',0,''),(361649,115208,'117126','printshop','background-color','$highlight-box-bg-2',0,''),(361650,115208,'117126','printshop','padding-left','20',0,''),(361651,115208,'117126','printshop','padding-right','20',0,''),(361652,115208,'117126','printshop','color','$highlight-box-color-2',0,''),(361653,115209,'117127','printshop','font-size','60',0,''),(361654,115209,'117127','printshop','font-weight','bold',0,''),(361655,115209,'117127','printshop','text-align','center',0,''),(361656,115209,'117127','printshop','line-height','100',0,''),(361657,115209,'117127','printshop','padding-bottom','20',0,''),(361658,115209,'117127','printshop','line_height_measure','px',0,''),(361659,115210,'117128','printshop','block_type','4',0,''),(361660,115210,'117128','printshop','color','$highlight-box-color-4',0,''),(361661,115210,'117128','printshop','font-size','30',0,''),(361662,115210,'117128','printshop','font-weight','normal',0,''),(361663,115210,'117128','printshop','background-color','$highlight-box-bg-4',0,''),(361664,115210,'117128','printshop','padding-top','5',0,''),(361665,115210,'117128','printshop','padding-left','10',0,''),(361666,115210,'117128','printshop','padding-right','10',0,''),(361667,115210,'117128','printshop','padding-bottom','5',0,''),(361668,115211,'117129','printshop','text','<p>Your code is:</p>',1,''),(361669,115211,'117129','printshop','font-weight','normal',0,''),(361670,115211,'117129','printshop','text','<p>Your code is:</p>',2,''),(361671,115211,'117129','printshop','text','<p>Your code is:</p>',3,''),(361672,115211,'117129','printshop','text','<p>Your code is:</p>',4,''),(361673,115213,'117131','printshop','block_type','1',0,''),(361674,115213,'117131','printshop','font-weight','normal',0,''),(361675,115213,'117131','printshop','padding-top','10',0,''),(361676,115214,'117132','printshop','font-size','12',0,''),(361677,115214,'117132','printshop','font-weight','bold',0,''),(361678,115214,'117132','printshop','text-align','center',0,''),(361679,115214,'117132','printshop','style_class','email',0,''),(361680,115215,'117133','printshop','text','<p>If you require further assistance please contact us</p>',1,''),(361681,115215,'117133','printshop','font-weight','normal',0,''),(361682,115215,'117133','printshop','text-align','center',0,''),(361683,115215,'117133','printshop','font-size','12',0,''),(361684,115215,'117133','printshop','padding-top','10',0,''),(361685,115215,'117133','printshop','padding-bottom','5',0,''),(361686,115215,'117133','printshop','border-top-width','1',0,''),(361687,115215,'117133','printshop','border-top-color','$warning-border',0,''),(361688,115215,'117133','printshop','text','<p>If you require further assistance please contact us</p>',2,''),(361689,115215,'117133','printshop','text','<p>If you require further assistance please contact us</p>',3,''),(361690,115215,'117133','printshop','text','<p>If you require further assistance please contact us</p>',4,''),(361691,115216,'117134','printshop','font-size','12',0,''),(361692,115216,'117134','printshop','font-weight','bold',0,''),(361693,115216,'117134','printshop','text-align','center',0,''),(361694,115216,'117134','printshop','style_class','phone',0,''),(361695,115216,'117134','printshop','padding-bottom','5',0,''),(361696,115217,'117135','printshop','font-weight','normal',0,''),(361697,115217,'117135','printshop','text-align','center',0,''),(361698,115217,'117135','printshop','padding-bottom','20',0,''),(361699,115218,'117136','printshop','text','<p>PERSONAL MESSAGE</p>',1,''),(361700,115218,'117136','printshop','font-size','18',0,''),(361701,115218,'117136','printshop','font-weight','normal',0,''),(361702,115218,'117136','printshop','text-align','center',0,''),(361703,115218,'117136','printshop','padding-top','20',0,''),(361704,115218,'117136','printshop','padding-bottom','10',0,''),(361705,115218,'117136','printshop','border-top-width','1',0,''),(361706,115218,'117136','printshop','border-top-color','$warning-border',0,''),(361707,115218,'117136','printshop','text','<p>PERSONAL MESSAGE</p>',2,''),(361708,115218,'117136','printshop','text','<p>PERSONAL MESSAGE</p>',3,''),(361709,115218,'117136','printshop','text','<p>PERSONAL MESSAGE</p>',4,''),(361710,115219,'117137','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(361711,115219,'117137','printshop','font-weight','normal',0,''),(361712,115219,'117137','printshop','text-align','center',0,''),(361713,115219,'117137','printshop','padding-bottom','10',0,''),(361714,115219,'117137','printshop','font-size','14',0,''),(361715,115219,'117137','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(361716,115219,'117137','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(361717,115219,'117137','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(361718,115220,'117138','printshop','text','<p>GIFT CARD</p>',1,''),(361719,115220,'117138','printshop','font-size','30',0,''),(361720,115220,'117138','printshop','font-weight','normal',0,''),(361721,115220,'117138','printshop','border-top-width','1',0,''),(361722,115220,'117138','printshop','border-top-color','$warning-border',0,''),(361723,115220,'117138','printshop','style_class','gift-ico',0,''),(361724,115220,'117138','printshop','text-align','center',0,''),(361725,115220,'117138','printshop','padding-top','15',0,''),(361726,115220,'117138','printshop','text','<p>GIFT CARD</p>',2,''),(361727,115220,'117138','printshop','text','<p>GIFT CARD</p>',3,''),(361728,115220,'117138','printshop','text','<p>GIFT CARD</p>',4,''),(361729,115221,'117139','printshop','text','<p>WHAT TO DO NEXT:</p>',1,''),(361730,115221,'117139','printshop','font-weight','normal',0,''),(361731,115221,'117139','printshop','text-align','center',0,''),(361732,115221,'117139','printshop','padding-top','20',0,''),(361733,115221,'117139','printshop','padding-bottom','10',0,''),(361734,115221,'117139','printshop','style_class','question-ico',0,''),(361735,115221,'117139','printshop','border-top-width','1',0,''),(361736,115221,'117139','printshop','border-top-color','$warning-border',0,''),(361737,115221,'117139','printshop','font-size','18',0,''),(361738,115221,'117139','printshop','text','<p>WHAT TO DO NEXT:</p>',2,''),(361739,115221,'117139','printshop','text','<p>WHAT TO DO NEXT:</p>',3,''),(361740,115221,'117139','printshop','text','<p>WHAT TO DO NEXT:</p>',4,''),(361741,115222,'1638804282.8587','printshop','logo_from','theme',0,''),(361742,115222,'1638804282.8587','printshop','padding-top','20',0,''),(361743,115222,'1638804282.8587','printshop','text-align','center',0,''),(361744,115222,'1638804282.8587','printshop','padding-bottom','20',0,''),(361745,115223,'117141','printshop','block_type','1',0,''),(361746,115223,'117141','printshop','font-weight','normal',0,''),(361747,115223,'117141','printshop','style_class','gift-card-view',0,''),(361748,115223,'117141','printshop','text-align','center',0,''),(361749,115223,'117141','printshop','padding-bottom','20',0,''),(361750,115223,'117141','printshop','background-color','$highlight-box-bg-2',0,''),(361751,115223,'117141','printshop','padding-left','20',0,''),(361752,115223,'117141','printshop','padding-right','20',0,''),(361753,115223,'117141','printshop','color','$highlight-box-color-2',0,''),(361754,115224,'117142','printshop','block_type','1',0,''),(361755,115224,'117142','printshop','font-weight','normal',0,''),(361756,115224,'117142','printshop','padding-top','10',0,''),(361757,115225,'117143','printshop','font-size','12',0,''),(361758,115225,'117143','printshop','font-weight','bold',0,''),(361759,115225,'117143','printshop','text-align','center',0,''),(361760,115225,'117143','printshop','style_class','email',0,''),(361761,115225,'117143','printshop','color','$highlight-box-color-2',0,''),(361762,115226,'117144','printshop','font-size','12',0,''),(361763,115226,'117144','printshop','font-weight','bold',0,''),(361764,115226,'117144','printshop','text-align','center',0,''),(361765,115226,'117144','printshop','style_class','phone',0,''),(361766,115226,'117144','printshop','padding-bottom','5',0,''),(361767,115226,'117144','printshop','color','$highlight-box-color-2',0,''),(361768,115227,'117145','printshop','text','If you require further assistance please contact us',0,''),(361769,115227,'117145','printshop','font-size','12',0,''),(361770,115227,'117145','printshop','color','$highlight-box-color-2',0,''),(361771,115227,'117145','printshop','text-align','center',0,''),(361772,115227,'117145','printshop','padding-top','10',0,''),(361773,115228,'117146','printshop','block_type','4',0,''),(361774,115228,'117146','printshop','color','$highlight-box-color-4',0,''),(361775,115228,'117146','printshop','font-size','30',0,''),(361776,115228,'117146','printshop','font-weight','normal',0,''),(361777,115228,'117146','printshop','background-color','$highlight-box-bg-4',0,''),(361778,115228,'117146','printshop','padding-top','5',0,''),(361779,115228,'117146','printshop','padding-left','10',0,''),(361780,115228,'117146','printshop','padding-right','10',0,''),(361781,115228,'117146','printshop','padding-bottom','5',0,''),(361782,115229,'117147','printshop','text','Your code is:',0,''),(361783,115229,'117147','printshop','font-size','30',0,''),(361784,115229,'117147','printshop','color','$highlight-box-color-4',0,''),(361785,115230,'117148','printshop','font-size','30',0,''),(361786,115230,'117148','printshop','color','$highlight-box-color-4',0,''),(361787,115231,'117149','printshop','block_type','1',0,''),(361788,115232,'117150','printshop','text','<p>PERSONAL MESSAGE</p>',1,''),(361789,115232,'117150','printshop','font-size','18',0,''),(361790,115232,'117150','printshop','font-weight','normal',0,''),(361791,115232,'117150','printshop','text-align','center',0,'');
INSERT INTO `design_boxes_settings_tmp` VALUES (361792,115232,'117150','printshop','padding-top','20',0,''),(361793,115232,'117150','printshop','padding-bottom','10',0,''),(361794,115232,'117150','printshop','border-top-width','1',0,''),(361795,115232,'117150','printshop','border-top-color','$warning-border',0,''),(361796,115232,'117150','printshop','text','<p>PERSONAL MESSAGE</p>',2,''),(361797,115232,'117150','printshop','text','<p>PERSONAL MESSAGE</p>',3,''),(361798,115232,'117150','printshop','text','<p>PERSONAL MESSAGE</p>',4,''),(361799,115232,'117150','printshop','color','$highlight-box-color-2',0,''),(361800,115233,'117151','printshop','text','HOLBI',0,''),(361801,115233,'117151','printshop','font-size','24',0,''),(361802,115233,'117151','printshop','padding-top','20',0,''),(361803,115233,'117151','printshop','text-align','center',0,''),(361804,115233,'117151','printshop','padding-bottom','20',0,''),(361805,115233,'117151','printshop','color','$highlight-box-color-2',0,''),(361806,115234,'117152','printshop','border-top-color','$warning-border',0,''),(361807,115234,'117152','printshop','border-top-width','1',0,''),(361808,115234,'117152','printshop','padding-top','20',0,''),(361809,115234,'117152','printshop','font-size','30',0,''),(361810,115234,'117152','printshop','text-align','center',0,''),(361811,115234,'117152','printshop','text','GIFT CARD',0,''),(361812,115234,'117152','printshop','color','$highlight-box-color-2',0,''),(361813,115235,'117153','printshop','text-align','center',0,''),(361814,115235,'117153','printshop','font-weight','bold',0,''),(361815,115235,'117153','printshop','font-size','60',0,''),(361816,115235,'117153','printshop','color','$highlight-box-color-2',0,''),(361817,115236,'117154','printshop','font-size','20',0,''),(361818,115236,'117154','printshop','text-align','center',0,''),(361819,115236,'117154','printshop','color','$highlight-box-color-2',0,''),(361820,115236,'117154','printshop','padding-top','20',0,''),(361821,115236,'117154','printshop','padding-bottom','20',0,''),(361822,115237,'117155','printshop','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(361823,115237,'117155','printshop','text-align','center',0,''),(361824,115237,'117155','printshop','color','$highlight-box-color-2',0,''),(361825,115237,'117155','printshop','font-size','14',0,''),(361826,115237,'117155','printshop','padding-bottom','20',0,''),(361827,115238,'117156','printshop','text','WHAT TO DO NEXT:',0,''),(361828,115238,'117156','printshop','font-size','18',0,''),(361829,115238,'117156','printshop','text-align','center',0,''),(361830,115238,'117156','printshop','color','$highlight-box-color-2',0,''),(361831,115238,'117156','printshop','padding-top','20',0,''),(361832,115238,'117156','printshop','padding-bottom','10',0,''),(361833,115238,'117156','printshop','border-top-width','1',0,''),(361834,115238,'117156','printshop','border-top-color','$warning-border',0,''),(361835,115239,'117158','printshop','block_type','1',0,''),(361836,115239,'117158','printshop','font-weight','normal',0,''),(361837,115239,'117158','printshop','style_class','gift-card-view',0,''),(361838,115239,'117158','printshop','text-align','center',0,''),(361839,115239,'117158','printshop','padding-bottom','20',0,''),(361840,115239,'117158','printshop','background-color','$highlight-box-bg-1',0,''),(361841,115239,'117158','printshop','padding-left','20',0,''),(361842,115239,'117158','printshop','padding-right','20',0,''),(361843,115239,'117158','printshop','color','$highlight-box-color-1',0,''),(361844,115240,'117159','printshop','block_type','1',0,''),(361845,115240,'117159','printshop','font-weight','normal',0,''),(361846,115240,'117159','printshop','padding-top','10',0,''),(361847,115241,'117160','printshop','font-size','12',0,''),(361848,115241,'117160','printshop','font-weight','bold',0,''),(361849,115241,'117160','printshop','text-align','center',0,''),(361850,115241,'117160','printshop','style_class','email',0,''),(361851,115241,'117160','printshop','color','$highlight-box-color-1',0,''),(361852,115242,'117161','printshop','font-size','12',0,''),(361853,115242,'117161','printshop','font-weight','bold',0,''),(361854,115242,'117161','printshop','text-align','center',0,''),(361855,115242,'117161','printshop','style_class','phone',0,''),(361856,115242,'117161','printshop','padding-bottom','5',0,''),(361857,115242,'117161','printshop','color','$highlight-box-color-1',0,''),(361858,115243,'117162','printshop','text','If you require further assistance please contact us',0,''),(361859,115243,'117162','printshop','font-size','12',0,''),(361860,115243,'117162','printshop','color','$highlight-box-color-1',0,''),(361861,115243,'117162','printshop','text-align','center',0,''),(361862,115243,'117162','printshop','padding-top','10',0,''),(361863,115244,'117163','printshop','block_type','2',0,''),(361864,115244,'117163','printshop','color','$highlight-box-color-4',0,''),(361865,115244,'117163','printshop','font-size','30',0,''),(361866,115244,'117163','printshop','font-weight','normal',0,''),(361867,115244,'117163','printshop','background-color','$highlight-box-bg-4',0,''),(361868,115244,'117163','printshop','padding-top','5',0,''),(361869,115244,'117163','printshop','padding-left','10',0,''),(361870,115244,'117163','printshop','padding-right','10',0,''),(361871,115244,'117163','printshop','padding-bottom','5',0,''),(361872,115245,'117164','printshop','text','Your code is:',0,''),(361873,115245,'117164','printshop','font-size','30',0,''),(361874,115245,'117164','printshop','color','$highlight-box-color-4',0,''),(361875,115245,'117164','printshop','background-color','$hileght-color-4',0,''),(361876,115246,'117165','printshop','color','$highlight-box-color-4',0,''),(361877,115246,'117165','printshop','font-size','30',0,''),(361878,115247,'117166','printshop','block_type','1',0,''),(361879,115248,'117167','printshop','text','<p>PERSONAL MESSAGE</p>',1,''),(361880,115248,'117167','printshop','font-size','18',0,''),(361881,115248,'117167','printshop','font-weight','normal',0,''),(361882,115248,'117167','printshop','text-align','center',0,''),(361883,115248,'117167','printshop','padding-top','20',0,''),(361884,115248,'117167','printshop','padding-bottom','10',0,''),(361885,115248,'117167','printshop','border-top-width','1',0,''),(361886,115248,'117167','printshop','border-top-color','$warning-border',0,''),(361887,115248,'117167','printshop','text','<p>PERSONAL MESSAGE</p>',2,''),(361888,115248,'117167','printshop','text','<p>PERSONAL MESSAGE</p>',3,''),(361889,115248,'117167','printshop','text','<p>PERSONAL MESSAGE</p>',4,''),(361890,115249,'117169','printshop','border-top-color','$warning-border',0,''),(361891,115249,'117169','printshop','border-top-width','1',0,''),(361892,115249,'117169','printshop','padding-top','20',0,''),(361893,115249,'117169','printshop','font-size','30',0,''),(361894,115249,'117169','printshop','text-align','center',0,''),(361895,115249,'117169','printshop','color','$highlight-box-color-1',0,''),(361896,115249,'117169','printshop','text','GIFT CARD',0,''),(361897,115250,'117170','printshop','text-align','center',0,''),(361898,115250,'117170','printshop','font-weight','bold',0,''),(361899,115250,'117170','printshop','font-size','60',0,''),(361900,115250,'117170','printshop','color','$highlight-box-color-1',0,''),(361901,115251,'117171','printshop','font-size','20',0,''),(361902,115251,'117171','printshop','text-align','center',0,''),(361903,115251,'117171','printshop','color','$highlight-box-color-1',0,''),(361904,115251,'117171','printshop','padding-top','20',0,''),(361905,115251,'117171','printshop','padding-bottom','20',0,''),(361906,115252,'117172','printshop','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(361907,115252,'117172','printshop','text-align','center',0,''),(361908,115252,'117172','printshop','color','$highlight-box-color-1',0,''),(361909,115252,'117172','printshop','font-size','14',0,''),(361910,115252,'117172','printshop','padding-bottom','20',0,''),(361911,115253,'117173','printshop','text','WHAT TO DO NEXT:',0,''),(361912,115253,'117173','printshop','font-size','18',0,''),(361913,115253,'117173','printshop','text-align','center',0,''),(361914,115253,'117173','printshop','color','$highlight-box-color-1',0,''),(361915,115253,'117173','printshop','padding-top','20',0,''),(361916,115253,'117173','printshop','padding-bottom','10',0,''),(361917,115253,'117173','printshop','border-top-width','1',0,''),(361918,115253,'117173','printshop','border-top-color','$warning-border',0,''),(361919,115254,'1638978695.8384','printshop','logo_from','theme',0,''),(361920,115254,'1638978695.8384','printshop','text-align','center',0,''),(361921,115254,'1638978695.8384','printshop','padding-top','20',0,''),(361922,115254,'1638978695.8384','printshop','padding-bottom','20',0,''),(361923,115255,'117175','printshop','block_type','1',0,''),(361924,115255,'117175','printshop','padding-left','20',0,''),(361925,115255,'117175','printshop','padding-right','20',0,''),(361926,115255,'117175','printshop','padding-bottom','20',0,''),(361927,115257,'117177','printshop','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(361928,115257,'117177','printshop','text-align','center',0,''),(361929,115258,'117178','printshop','block_type','1',0,''),(361930,115258,'117178','printshop','font-weight','normal',0,''),(361931,115258,'117178','printshop','style_class','gift-card-view',0,''),(361932,115258,'117178','printshop','text-align','center',0,''),(361933,115258,'117178','printshop','padding-bottom','20',0,''),(361934,115258,'117178','printshop','background-color','$highlight-box-bg-3',0,''),(361935,115258,'117178','printshop','padding-left','20',0,''),(361936,115258,'117178','printshop','padding-right','20',0,''),(361937,115258,'117178','printshop','color','$highlight-box-color-3',0,''),(361938,115259,'117179','printshop','block_type','4',0,''),(361939,115259,'117179','printshop','color','$highlight-box-color-4',0,''),(361940,115259,'117179','printshop','font-size','30',0,''),(361941,115259,'117179','printshop','font-weight','normal',0,''),(361942,115259,'117179','printshop','background-color','$highlight-box-bg-4',0,''),(361943,115259,'117179','printshop','padding-top','5',0,''),(361944,115259,'117179','printshop','padding-left','10',0,''),(361945,115259,'117179','printshop','padding-right','10',0,''),(361946,115259,'117179','printshop','padding-bottom','5',0,''),(361947,115260,'117180','printshop','text','<p>Your code is:</p>',1,''),(361948,115260,'117180','printshop','font-weight','normal',0,''),(361949,115260,'117180','printshop','text','<p>Your code is:</p>',2,''),(361950,115260,'117180','printshop','text','<p>Your code is:</p>',3,''),(361951,115260,'117180','printshop','text','<p>Your code is:</p>',4,''),(361952,115262,'117182','printshop','text','<p>WHAT TO DO NEXT:</p>',1,''),(361953,115262,'117182','printshop','font-weight','normal',0,''),(361954,115262,'117182','printshop','text-align','center',0,''),(361955,115262,'117182','printshop','padding-top','20',0,''),(361956,115262,'117182','printshop','padding-bottom','10',0,''),(361957,115262,'117182','printshop','style_class','question-ico',0,''),(361958,115262,'117182','printshop','border-top-width','1',0,''),(361959,115262,'117182','printshop','border-top-color','$warning-border',0,''),(361960,115262,'117182','printshop','font-size','18',0,''),(361961,115262,'117182','printshop','text','<p>WHAT TO DO NEXT:</p>',2,''),(361962,115262,'117182','printshop','text','<p>WHAT TO DO NEXT:</p>',3,''),(361963,115262,'117182','printshop','text','<p>WHAT TO DO NEXT:</p>',4,''),(361964,115263,'117184','printshop','block_type','1',0,''),(361965,115263,'117184','printshop','font-weight','normal',0,''),(361966,115263,'117184','printshop','padding-top','10',0,''),(361967,115264,'117185','printshop','text','<p>If you require further assistance please contact us</p>',1,''),(361968,115264,'117185','printshop','font-weight','normal',0,''),(361969,115264,'117185','printshop','text-align','center',0,''),(361970,115264,'117185','printshop','font-size','12',0,''),(361971,115264,'117185','printshop','padding-top','10',0,''),(361972,115264,'117185','printshop','padding-bottom','5',0,''),(361973,115264,'117185','printshop','border-top-width','1',0,''),(361974,115264,'117185','printshop','border-top-color','$warning-border',0,''),(361975,115264,'117185','printshop','text','<p>If you require further assistance please contact us</p>',2,''),(361976,115264,'117185','printshop','text','<p>If you require further assistance please contact us</p>',3,''),(361977,115264,'117185','printshop','text','<p>If you require further assistance please contact us</p>',4,''),(361978,115265,'117186','printshop','font-size','12',0,''),(361979,115265,'117186','printshop','font-weight','bold',0,''),(361980,115265,'117186','printshop','text-align','center',0,''),(361981,115265,'117186','printshop','style_class','email',0,''),(361982,115266,'117187','printshop','font-size','12',0,''),(361983,115266,'117187','printshop','font-weight','bold',0,''),(361984,115266,'117187','printshop','text-align','center',0,''),(361985,115266,'117187','printshop','style_class','phone',0,''),(361986,115266,'117187','printshop','padding-bottom','5',0,''),(361987,115267,'117188','printshop','font-weight','normal',0,''),(361988,115267,'117188','printshop','text-align','center',0,''),(361989,115267,'117188','printshop','padding-bottom','20',0,''),(361990,115268,'117189','printshop','text','<p>GIFT CARD</p>',1,''),(361991,115268,'117189','printshop','font-size','30',0,''),(361992,115268,'117189','printshop','font-weight','normal',0,''),(361993,115268,'117189','printshop','border-top-width','1',0,''),(361994,115268,'117189','printshop','border-top-color','$warning-border',0,''),(361995,115268,'117189','printshop','style_class','gift-ico',0,''),(361996,115268,'117189','printshop','text-align','center',0,''),(361997,115268,'117189','printshop','padding-top','15',0,''),(361998,115268,'117189','printshop','text','<p>GIFT CARD</p>',2,''),(361999,115268,'117189','printshop','text','<p>GIFT CARD</p>',3,''),(362000,115268,'117189','printshop','text','<p>GIFT CARD</p>',4,''),(362001,115269,'117190','printshop','text','<p>PERSONAL MESSAGE</p>',1,''),(362002,115269,'117190','printshop','font-size','18',0,''),(362003,115269,'117190','printshop','font-weight','normal',0,''),(362004,115269,'117190','printshop','text-align','center',0,''),(362005,115269,'117190','printshop','padding-top','20',0,''),(362006,115269,'117190','printshop','padding-bottom','10',0,''),(362007,115269,'117190','printshop','border-top-width','1',0,''),(362008,115269,'117190','printshop','border-top-color','$warning-border',0,''),(362009,115269,'117190','printshop','text','<p>PERSONAL MESSAGE</p>',2,''),(362010,115269,'117190','printshop','text','<p>PERSONAL MESSAGE</p>',3,''),(362011,115269,'117190','printshop','text','<p>PERSONAL MESSAGE</p>',4,''),(362012,115270,'117191','printshop','font-size','60',0,''),(362013,115270,'117191','printshop','font-weight','bold',0,''),(362014,115270,'117191','printshop','text-align','center',0,''),(362015,115270,'117191','printshop','line-height','100',0,''),(362016,115270,'117191','printshop','padding-bottom','20',0,''),(362017,115270,'117191','printshop','line_height_measure','px',0,''),(362018,115271,'117192','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(362019,115271,'117192','printshop','font-weight','normal',0,''),(362020,115271,'117192','printshop','text-align','center',0,''),(362021,115271,'117192','printshop','padding-bottom','10',0,''),(362022,115271,'117192','printshop','font-size','14',0,''),(362023,115271,'117192','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(362024,115271,'117192','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(362025,115271,'117192','printshop','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(362026,115272,'1638804328.7281','printshop','logo_from','theme',0,''),(362027,115272,'1638804328.7281','printshop','padding-top','20',0,''),(362028,115272,'1638804328.7281','printshop','text-align','center',0,''),(362029,115272,'1638804328.7281','printshop','padding-bottom','20',0,''),(362030,115273,'117193','printshop','block_type','1',0,''),(362031,115273,'117193','printshop','font-weight','normal',0,''),(362032,115273,'117193','printshop','style_class','gift-card-view',0,''),(362033,115273,'117193','printshop','text-align','center',0,''),(362034,115273,'117193','printshop','padding-bottom','20',0,''),(362035,115273,'117193','printshop','background-color','$highlight-box-bg-3',0,''),(362036,115273,'117193','printshop','padding-left','20',0,''),(362037,115273,'117193','printshop','padding-right','20',0,''),(362038,115273,'117193','printshop','color','$highlight-box-color-3',0,''),(362039,115274,'117194','printshop','block_type','1',0,''),(362040,115274,'117194','printshop','font-weight','normal',0,''),(362041,115274,'117194','printshop','padding-top','10',0,''),(362042,115275,'117195','printshop','font-size','12',0,''),(362043,115275,'117195','printshop','font-weight','bold',0,''),(362044,115275,'117195','printshop','text-align','center',0,''),(362045,115275,'117195','printshop','style_class','email',0,''),(362046,115275,'117195','printshop','color','$highlight-box-color-3',0,''),(362047,115276,'117196','printshop','font-size','12',0,''),(362048,115276,'117196','printshop','font-weight','bold',0,''),(362049,115276,'117196','printshop','text-align','center',0,''),(362050,115276,'117196','printshop','style_class','phone',0,''),(362051,115276,'117196','printshop','padding-bottom','5',0,''),(362052,115277,'117197','printshop','text','If you require further assistance please contact us',0,''),(362053,115277,'117197','printshop','font-size','12',0,''),(362054,115277,'117197','printshop','color','$highlight-box-color-3',0,''),(362055,115277,'117197','printshop','text-align','center',0,''),(362056,115277,'117197','printshop','padding-top','10',0,''),(362057,115278,'117198','printshop','block_type','4',0,''),(362058,115278,'117198','printshop','color','$highlight-box-color-4',0,''),(362059,115278,'117198','printshop','font-size','30',0,''),(362060,115278,'117198','printshop','font-weight','normal',0,''),(362061,115278,'117198','printshop','background-color','$highlight-box-bg-4',0,''),(362062,115278,'117198','printshop','padding-top','5',0,''),(362063,115278,'117198','printshop','padding-left','10',0,''),(362064,115278,'117198','printshop','padding-right','10',0,''),(362065,115278,'117198','printshop','padding-bottom','5',0,''),(362066,115279,'117199','printshop','text','Your code is:',0,''),(362067,115279,'117199','printshop','font-size','30',0,''),(362068,115279,'117199','printshop','color','$highlight-box-color-4',0,''),(362069,115280,'117200','printshop','color','$highlight-box-color-4',0,''),(362070,115280,'117200','printshop','font-size','30',0,''),(362071,115281,'117201','printshop','block_type','1',0,''),(362072,115282,'117202','printshop','text','<p>PERSONAL MESSAGE</p>',1,''),(362073,115282,'117202','printshop','font-size','18',0,''),(362074,115282,'117202','printshop','font-weight','normal',0,''),(362075,115282,'117202','printshop','text-align','center',0,''),(362076,115282,'117202','printshop','padding-top','20',0,''),(362077,115282,'117202','printshop','padding-bottom','10',0,''),(362078,115282,'117202','printshop','border-top-width','1',0,''),(362079,115282,'117202','printshop','border-top-color','$warning-border',0,''),(362080,115282,'117202','printshop','text','<p>PERSONAL MESSAGE</p>',2,''),(362081,115282,'117202','printshop','text','<p>PERSONAL MESSAGE</p>',3,''),(362082,115282,'117202','printshop','text','<p>PERSONAL MESSAGE</p>',4,''),(362083,115283,'117203','printshop','text','HOLBI',0,''),(362084,115283,'117203','printshop','color','$highlight-box-color-3',0,''),(362085,115283,'117203','printshop','font-size','24',0,''),(362086,115283,'117203','printshop','padding-top','20',0,''),(362087,115283,'117203','printshop','text-align','center',0,''),(362088,115283,'117203','printshop','padding-bottom','20',0,''),(362089,115284,'117204','printshop','border-top-color','$warning-border',0,''),(362090,115284,'117204','printshop','border-top-width','1',0,''),(362091,115284,'117204','printshop','padding-top','20',0,''),(362092,115284,'117204','printshop','font-size','30',0,''),(362093,115284,'117204','printshop','text-align','center',0,''),(362094,115284,'117204','printshop','color','$highlight-box-color-3',0,''),(362095,115284,'117204','printshop','text','GIFT CARD',0,''),(362096,115285,'117205','printshop','text-align','center',0,''),(362097,115285,'117205','printshop','font-weight','bold',0,''),(362098,115285,'117205','printshop','font-size','60',0,''),(362099,115285,'117205','printshop','color','$highlight-box-color-3',0,''),(362100,115286,'117206','printshop','font-size','20',0,''),(362101,115286,'117206','printshop','text-align','center',0,''),(362102,115286,'117206','printshop','padding-top','20',0,''),(362103,115286,'117206','printshop','padding-bottom','20',0,''),(362104,115287,'117207','printshop','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(362105,115287,'117207','printshop','text-align','center',0,''),(362106,115287,'117207','printshop','color','$highlight-box-color-3',0,''),(362107,115287,'117207','printshop','font-size','14',0,''),(362108,115287,'117207','printshop','padding-bottom','20',0,''),(362109,115288,'117208','printshop','text','WHAT TO DO NEXT:',0,''),(362110,115288,'117208','printshop','font-size','18',0,''),(362111,115288,'117208','printshop','text-align','center',0,''),(362112,115288,'117208','printshop','color','$highlight-box-color-3',0,''),(362113,115288,'117208','printshop','padding-top','20',0,''),(362114,115288,'117208','printshop','padding-bottom','10',0,''),(362115,115288,'117208','printshop','border-top-width','1',0,''),(362116,115288,'117208','printshop','border-top-color','$warning-border',0,''),(362117,115289,'117212','printshop','block_type','1',0,''),(362118,115289,'117212','printshop','padding-top','3',0,''),(362119,115289,'117212','printshop','padding-top','0',0,'5363'),(362120,115289,'117212','printshop','padding-bottom','0',0,'5363'),(362121,115289,'117212','printshop','style_class','header-middle',0,''),(362122,115289,'117212','printshop','position','relative',0,''),(362123,115289,'117212','printshop','background-color','$header-bg-1',0,''),(362124,115289,'117212','printshop','border-bottom-width','1',0,''),(362125,115289,'117212','printshop','border-bottom-color','$header-border-1',0,''),(362126,115289,'117212','printshop','color','$header-color-1',0,''),(362209,115296,'117219','printshop','block_type','1',0,''),(362210,115296,'117219','printshop','border-bottom-width','1',0,''),(362211,115296,'117219','printshop','border-bottom-color','$header-border-1',0,''),(362212,115296,'117219','printshop','font-weight','normal',0,''),(362213,115296,'117219','printshop','visibility_checkout','1',0,''),(362214,115296,'117219','printshop','display_none','1',0,'5342'),(362215,115296,'117219','printshop','style_class','topHeader',0,''),(362216,115296,'117219','printshop','padding-top','10',0,''),(362217,115296,'117219','printshop','padding-bottom','10',0,''),(362218,115296,'117219','printshop','background-color','$header-bg-1',0,''),(362219,115296,'117219','printshop','color','$header-color-1',0,''),(362264,115306,'117224','printshop','block_type','1',0,''),(362265,115312,'117229','printshop','width','680',0,''),(362266,115312,'117229','printshop','font-weight','normal',0,''),(362267,115312,'117229','printshop','font-size','12',0,''),(362268,115312,'117229','printshop','padding-top','20',0,''),(362269,115312,'117229','printshop','padding-bottom','20',0,''),(362270,115312,'117229','printshop','color','$content-color-1',0,''),(362271,115313,'117230','printshop','block_type','4',0,''),(362272,115313,'117230','printshop','font-weight','normal',0,''),(362273,115313,'117230','printshop','border-top-width','1',0,''),(362274,115313,'117230','printshop','border-top-color','$content-border-3',0,''),(362275,115313,'117230','printshop','border-left-width','1',0,''),(362276,115313,'117230','printshop','border-left-color','$content-border-3',0,''),(362277,115313,'117230','printshop','border-right-width','1',0,''),(362278,115313,'117230','printshop','border-right-color','$content-border-3',0,''),(362279,115313,'117230','printshop','border-bottom-width','1',0,''),(362280,115313,'117230','printshop','border-bottom-color','$content-border-3',0,''),(362281,115314,'117231','printshop','block_type','2',0,''),(362282,115314,'117231','printshop','font-weight','normal',0,''),(362283,115314,'117231','printshop','border-top-width','1',0,''),(362284,115314,'117231','printshop','border-top-color','$content-border-3',0,''),(362285,115314,'117231','printshop','border-right-width','1',0,''),(362286,115314,'117231','printshop','border-right-color','$content-border-3',0,''),(362287,115315,'117232','printshop','block_type','1',0,''),(362288,115315,'117232','printshop','font-weight','normal',0,''),(362289,115315,'117232','printshop','padding-top','10',0,''),(362290,115315,'117232','printshop','padding-left','10',0,''),(362291,115315,'117232','printshop','padding-right','10',0,''),(362292,115315,'117232','printshop','padding-bottom','10',0,''),(362293,115315,'117232','printshop','border-right-width','1',0,''),(362294,115315,'117232','printshop','border-right-color','$content-border-3',0,''),(362295,115317,'117234','printshop','text','<p>Shipping via</p>',1,''),(362296,115317,'117234','printshop','font-weight','bold',0,''),(362297,115317,'117234','printshop','font-size','14',0,''),(362298,115317,'117234','printshop','text','<p>Shipping via</p>',2,''),(362299,115317,'117234','printshop','text','<p>Shipping via</p>',3,''),(362300,115317,'117234','printshop','text','<p>Shipping via</p>',4,''),(362301,115318,'117235','printshop','block_type','1',0,''),(362302,115318,'117235','printshop','font-weight','normal',0,''),(362303,115318,'117235','printshop','padding-top','10',0,''),(362304,115318,'117235','printshop','padding-left','10',0,''),(362305,115318,'117235','printshop','padding-right','10',0,''),(362306,115318,'117235','printshop','padding-bottom','10',0,''),(362307,115319,'117236','printshop','text','<p>Shipping service</p>',1,''),(362308,115319,'117236','printshop','font-weight','bold',0,''),(362309,115319,'117236','printshop','font-size','14',0,''),(362310,115319,'117236','printshop','text','<p>Shipping service</p>',2,''),(362311,115319,'117236','printshop','text','<p>Shipping service</p>',3,''),(362312,115319,'117236','printshop','text','<p>Shipping service</p>',4,''),(362313,115321,'117238','printshop','block_type','2',0,''),(362314,115321,'117238','printshop','font-weight','normal',0,''),(362315,115321,'117238','printshop','border-right-width','1',0,''),(362316,115321,'117238','printshop','border-right-color','$content-border-3',0,''),(362317,115322,'117239','printshop','block_type','1',0,''),(362318,115322,'117239','printshop','font-weight','400',0,''),(362319,115322,'117239','printshop','background-color','$content-bg-2',0,''),(362320,115322,'117239','printshop','padding-top','10',0,''),(362321,115322,'117239','printshop','padding-left','10',0,''),(362322,115322,'117239','printshop','padding-right','10',0,''),(362323,115322,'117239','printshop','padding-bottom','30',0,''),(362324,115323,'117240','printshop','text','<p>INVOICE ADDRESS:</p>',1,''),(362325,115323,'117240','printshop','font-size','14',0,''),(362326,115323,'117240','printshop','font-weight','bold',0,''),(362327,115323,'117240','printshop','text','<p>INVOICE ADDRESS:</p>',2,''),(362328,115323,'117240','printshop','text','<p>INVOICE ADDRESS:</p>',3,''),(362329,115323,'117240','printshop','text','<p>INVOICE ADDRESS:</p>',4,''),(362330,115324,'117241','printshop','font-size','12',0,''),(362331,115326,'117242','printshop','block_type','1',0,''),(362332,115326,'117242','printshop','font-weight','normal',0,''),(362333,115326,'117242','printshop','padding-top','10',0,''),(362334,115326,'117242','printshop','padding-left','10',0,''),(362335,115326,'117242','printshop','padding-right','10',0,''),(362336,115326,'117242','printshop','padding-bottom','10',0,''),(362337,115327,'117243','printshop','text','<p>E-MAIL ADDRESS:</p>',1,''),(362338,115327,'117243','printshop','font-weight','bold',0,''),(362339,115327,'117243','printshop','font-size','14',0,''),(362340,115327,'117243','printshop','padding-top','10',0,''),(362341,115327,'117243','printshop','text','<p>E-MAIL ADDRESS:</p>',2,''),(362342,115327,'117243','printshop','text','<p>E-MAIL ADDRESS:</p>',3,''),(362343,115327,'117243','printshop','text','<p>E-MAIL ADDRESS:</p>',4,''),(362344,115328,'117244','printshop','font-weight','normal',0,''),(362345,115329,'117245','printshop','font-weight','normal',0,''),(362346,115330,'117246','printshop','text','<p>CUSTOMER:</p>',1,''),(362347,115330,'117246','printshop','font-size','13',0,''),(362348,115330,'117246','printshop','font-weight','bold',0,''),(362349,115330,'117246','printshop','text','<p>CUSTOMER:</p>',2,''),(362350,115330,'117246','printshop','text','<p>CUSTOMER:</p>',3,''),(362351,115330,'117246','printshop','text','<p>CUSTOMER:</p>',4,''),(362352,115331,'117247','printshop','text','<p>PHONE NUMBER:</p>',1,''),(362353,115331,'117247','printshop','font-size','14',0,''),(362354,115331,'117247','printshop','font-weight','bold',0,''),(362355,115331,'117247','printshop','padding-top','10',0,''),(362356,115331,'117247','printshop','text','<p>PHONE NUMBER:</p>',2,''),(362357,115331,'117247','printshop','text','<p>PHONE NUMBER:</p>',3,''),(362358,115331,'117247','printshop','text','<p>PHONE NUMBER:</p>',4,''),(362359,115333,'117249','printshop','font-weight','normal',0,''),(362360,115333,'117249','printshop','text-align','center',0,''),(362361,115333,'117249','printshop','padding-bottom','20',0,''),(362362,115334,'117250','printshop','text','<p>Payment Method:</p>',1,''),(362363,115334,'117250','printshop','font-weight','bold',0,''),(362364,115334,'117250','printshop','text-align','center',0,''),(362365,115334,'117250','printshop','text','<p>Payment Method:</p>',2,''),(362366,115334,'117250','printshop','text','<p>Payment Method:</p>',3,''),(362367,115334,'117250','printshop','text','<p>Payment Method:</p>',4,''),(362368,115335,'117251','printshop','text','<p>Payment date:</p>',1,''),(362369,115335,'117251','printshop','font-weight','bold',0,''),(362370,115335,'117251','printshop','text-align','center',0,''),(362371,115335,'117251','printshop','font-size','12',0,''),(362372,115335,'117251','printshop','text','<p>Payment date:</p>',2,''),(362373,115335,'117251','printshop','text','<p>Payment date:</p>',3,''),(362374,115335,'117251','printshop','text','<p>Payment date:</p>',4,''),(362375,115336,'117252','printshop','font-size','14',0,''),(362376,115336,'117252','printshop','font-weight','bold',0,''),(362377,115336,'117252','printshop','text-align','center',0,''),(362378,115336,'117252','printshop','padding-bottom','10',0,''),(362379,115336,'117252','printshop','padding-top','10',0,''),(362380,115337,'117253','printshop','font-weight','normal',0,''),(362381,115337,'117253','printshop','text-align','center',0,''),(362382,115337,'117253','printshop','padding-bottom','10',0,''),(362383,115338,'117254','printshop','font-weight','normal',0,''),(362384,115338,'117254','printshop','text-align','center',0,''),(362385,115339,'117255','printshop','block_type','3',0,''),(362386,115339,'117255','printshop','font-weight','normal',0,''),(362387,115339,'117255','printshop','padding-top','20',0,''),(362388,115340,'117256','printshop','font-size','12',0,''),(362389,115341,'117257','printshop','text','<p>If undelivered please return to:</p>',1,''),(362390,115341,'117257','printshop','font-size','12',0,''),(362391,115341,'117257','printshop','font-weight','bold',0,''),(362392,115341,'117257','printshop','text','<p>If undelivered please return to:</p>',2,''),(362393,115341,'117257','printshop','text','<p>If undelivered please return to:</p>',3,''),(362394,115341,'117257','printshop','text','<p>If undelivered please return to:</p>',4,''),(362395,115342,'117258','printshop','text','<p>Thank you for your order</p>',1,''),(362396,115342,'117258','printshop','color','$hileght-color-1',0,''),(362397,115342,'117258','printshop','font-size','13',0,''),(362398,115342,'117258','printshop','font-weight','bold',0,''),(362399,115342,'117258','printshop','padding-top','5',0,''),(362400,115342,'117258','printshop','text-align','center',0,''),(362401,115342,'117258','printshop','text','<p>Thank you for your order</p>',2,''),(362402,115342,'117258','printshop','text','<p>Thank you for your order</p>',3,''),(362403,115342,'117258','printshop','text','<p>Thank you for your order</p>',4,''),(362404,115343,'117260','printshop','block_type','6',0,''),(362405,115343,'117260','printshop','font-weight','normal',0,''),(362406,115343,'117260','printshop','font-size','16',0,''),(362407,115344,'117261','printshop','text','<p>Email:</p>',1,''),(362408,115344,'117261','printshop','font-weight','normal',0,''),(362409,115344,'117261','printshop','text-align','right',0,''),(362410,115344,'117261','printshop','font-size','12',0,''),(362411,115344,'117261','printshop','text','<p>Email:</p>',2,''),(362412,115344,'117261','printshop','text','<p>Email:</p>',3,''),(362413,115344,'117261','printshop','text','<p>Email:</p>',4,''),(362414,115345,'117262','printshop','font-weight','normal',0,''),(362415,115345,'117262','printshop','text-align','right',0,''),(362416,115345,'117262','printshop','font-size','12',0,''),(362417,115346,'117263','printshop','block_type','6',0,''),(362418,115346,'117263','printshop','font-weight','normal',0,''),(362419,115346,'117263','printshop','font-size','16',0,''),(362420,115347,'117264','printshop','text','<p>Phone:</p>',1,''),(362421,115347,'117264','printshop','font-weight','normal',0,''),(362422,115347,'117264','printshop','text-align','right',0,''),(362423,115347,'117264','printshop','font-size','12',0,''),(362424,115347,'117264','printshop','text','<p>Phone:</p>',2,''),(362425,115347,'117264','printshop','text','<p>Phone:</p>',3,''),(362426,115347,'117264','printshop','text','<p>Phone:</p>',4,''),(362427,115348,'117265','printshop','font-weight','normal',0,''),(362428,115348,'117265','printshop','text-align','right',0,''),(362429,115348,'117265','printshop','font-size','12',0,''),(362430,115349,'117266','printshop','text','<p>If something has gone wrong please contact us at:</p>',1,''),(362431,115349,'117266','printshop','font-size','12',0,''),(362432,115349,'117266','printshop','font-weight','bold',0,''),(362433,115349,'117266','printshop','text-align','right',0,''),(362434,115349,'117266','printshop','text','<p>If something has gone wrong please contact us at:</p>',2,''),(362435,115349,'117266','printshop','text','<p>If something has gone wrong please contact us at:</p>',3,''),(362436,115349,'117266','printshop','text','<p>If something has gone wrong please contact us at:</p>',4,''),(362437,115350,'117267','printshop','font-weight','400',0,''),(362438,115350,'117267','printshop','padding-top','20',0,''),(362439,115350,'117267','printshop','padding-bottom','0',0,''),(362440,115350,'117267','printshop','font-size','12',0,''),(362441,115351,'117268','printshop','block_type','5',0,''),(362442,115351,'117268','printshop','font-weight','normal',0,''),(362443,115351,'117268','printshop','border-bottom-width','1',0,''),(362444,115351,'117268','printshop','border-bottom-color','$content-border-3',0,''),(362445,115351,'117268','printshop','border-top-width','1',0,''),(362446,115351,'117268','printshop','border-top-color','$content-border-3',0,''),(362447,115351,'117268','printshop','border-left-color','$content-border-3',0,''),(362448,115351,'117268','printshop','border-left-width','1',0,''),(362449,115352,'117269','printshop','block_type','1',0,''),(362450,115352,'117269','printshop','font-weight','normal',0,''),(362451,115352,'117269','printshop','padding-top','10',0,''),(362452,115352,'117269','printshop','padding-left','10',0,''),(362453,115352,'117269','printshop','padding-right','10',0,''),(362454,115353,'117270','printshop','font-weight','400',0,''),(362455,115353,'117270','printshop','line-height','120',0,''),(362456,115353,'117270','printshop','line_height_measure','%',0,''),(362457,115353,'117270','printshop','font-size','12',0,''),(362458,115354,'117271','printshop','text','<p>SHIPPING ADDRESS:</p>',1,''),(362459,115354,'117271','printshop','font-size','14',0,''),(362460,115354,'117271','printshop','font-weight','bold',0,''),(362461,115354,'117271','printshop','padding-bottom','10',0,''),(362462,115354,'117271','printshop','text','<p>SHIPPING ADDRESS:</p>',2,''),(362463,115354,'117271','printshop','text','<p>SHIPPING ADDRESS:</p>',3,''),(362464,115354,'117271','printshop','text','<p>SHIPPING ADDRESS:</p>',4,''),(362465,115355,'117272','printshop','block_type','1',0,''),(362466,115355,'117272','printshop','background-color','$content-bg-2',0,''),(362467,115355,'117272','printshop','padding-top','20',0,''),(362468,115355,'117272','printshop','padding-left','10',0,''),(362469,115355,'117272','printshop','padding-right','10',0,''),(362470,115355,'117272','printshop','padding-bottom','20',0,''),(362471,115355,'117272','printshop','font-size','14',0,''),(362472,115356,'117273','printshop','font-weight','normal',0,''),(362473,115356,'117273','printshop','text-align','right',0,''),(362474,115356,'117273','printshop','font-size','14',0,''),(362475,115356,'117273','printshop','box_align','3',0,''),(362476,115357,'117274','printshop','block_type','2',0,''),(362477,115357,'117274','printshop','font-weight','normal',0,''),(362478,115357,'117274','printshop','padding-bottom','20',0,''),(362479,115358,'117275','printshop','font-weight','400',0,''),(362480,115358,'117275','printshop','padding-top','20',0,''),(362481,115358,'117275','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',1,''),(362482,115358,'117275','printshop','padding-bottom','20',0,''),(362483,115358,'117275','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',2,''),(362484,115358,'117275','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',3,''),(362485,115358,'117275','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',4,''),(362486,115359,'117276','printshop','block_type','11',0,''),(362487,115359,'117276','printshop','font-weight','normal',0,''),(362488,115360,'117277','printshop','text','<p>Web:</p>',1,''),(362489,115360,'117277','printshop','font-weight','normal',0,''),(362490,115360,'117277','printshop','text-align','right',0,''),(362491,115360,'117277','printshop','text','<p>Web:</p>',2,''),(362492,115360,'117277','printshop','text','<p>Web:</p>',3,''),(362493,115360,'117277','printshop','text','<p>Web:</p>',4,''),(362494,115361,'117278','printshop','font-weight','normal',0,''),(362495,115361,'117278','printshop','text-align','right',0,''),(362496,115362,'117279','printshop','block_type','11',0,''),(362497,115362,'117279','printshop','font-weight','normal',0,''),(362498,115363,'117280','printshop','text','<p>Email:</p>',1,''),(362499,115363,'117280','printshop','font-weight','normal',0,''),(362500,115363,'117280','printshop','text-align','right',0,''),(362501,115363,'117280','printshop','text','<p>Email:</p>',2,''),(362502,115363,'117280','printshop','text','<p>Email:</p>',3,''),(362503,115363,'117280','printshop','text','<p>Email:</p>',4,''),(362504,115364,'117281','printshop','font-weight','normal',0,''),(362505,115364,'117281','printshop','text-align','right',0,''),(362506,115365,'117282','printshop','block_type','1',0,''),(362507,115366,'117283','printshop','font-weight','normal',0,''),(362508,115366,'117283','printshop','text-align','right',0,''),(362509,115366,'117283','printshop','padding-bottom','10',0,''),(362510,115366,'117283','printshop','address_spacer',',',0,''),(362511,115366,'117283','printshop','font-size','12',0,''),(362512,115367,'117284','printshop','block_type','11',0,''),(362513,115367,'117284','printshop','font-weight','normal',0,''),(362514,115368,'117285','printshop','text','<p>Phone:</p>',1,''),(362515,115368,'117285','printshop','font-weight','normal',0,''),(362516,115368,'117285','printshop','text-align','right',0,''),(362517,115368,'117285','printshop','text','<p>Phone:</p>',2,''),(362518,115368,'117285','printshop','text','<p>Phone:</p>',3,''),(362519,115368,'117285','printshop','text','<p>Phone:</p>',4,''),(362520,115369,'117286','printshop','font-weight','normal',0,''),(362521,115369,'117286','printshop','text-align','right',0,''),(362522,115370,'1640103567.8175','printshop','column_qty','1',0,''),(362523,115370,'1640103567.8175','printshop','column_name','1',0,''),(362524,115370,'1640103567.8175','printshop','column_model','1',0,''),(362525,115371,'117287','printshop','block_type','1',0,''),(362526,115371,'117287','printshop','padding-top','20',0,''),(362527,115372,'117288','printshop','tab_1','RETURNING CUSTOMER',1,''),(362528,115372,'117288','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(362529,115372,'117288','printshop','tab_1','RETURNING CUSTOMER',2,''),(362530,115372,'117288','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(362531,115372,'117288','printshop','tab_1','RETURNING CUSTOMER',3,''),(362532,115372,'117288','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(362533,115372,'117288','printshop','tab_1','RETURNING CUSTOMER',4,''),(362534,115372,'117288','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(362535,115373,'117289','printshop','max-width','600',0,''),(362536,115373,'117289','printshop','margin_left_measure','auto',0,''),(362537,115373,'117289','printshop','margin_right_measure','auto',0,''),(362538,115374,'117290','printshop','block_type','8',0,''),(362539,115374,'117290','printshop','schema','8-6',0,'5342'),(362540,115375,'117291','printshop','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(362541,115375,'117291','printshop','padding-left','20',0,'5342'),(362542,115376,'117292','printshop','block_type','1',0,''),(362543,115376,'117292','printshop','padding-left','20',0,''),(362544,115376,'117292','printshop','padding-right','20',0,''),(362545,115377,'117293','printshop','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(362546,115379,'117295','printshop','block_type','1',0,''),(362547,115380,'117296','printshop','text','##TEXT_OR##',0,''),(362548,115380,'117296','printshop','font-size','18',0,''),(362549,115380,'117296','printshop','font-weight','700',0,''),(362550,115380,'117296','printshop','padding-top','15',0,''),(362551,115380,'117296','printshop','text-align','center',0,''),(362552,115380,'117296','printshop','content','\\_',0,'3'),(362553,115380,'117296','printshop','height','5',0,'3'),(362554,115380,'117296','printshop','width','70',0,'3'),(362555,115380,'117296','printshop','display','inline-block',0,'3'),(362556,115380,'117296','printshop','border-top-width','1',0,'3'),(362557,115380,'117296','printshop','border-top-color','$content-border-3',0,'3'),(362558,115380,'117296','printshop','margin-left','10',0,'3'),(362559,115380,'117296','printshop','margin-right','10',0,'3'),(362560,115380,'117296','printshop','content','\\_',0,'4'),(362561,115380,'117296','printshop','display','inline-block',0,'4'),(362562,115380,'117296','printshop','width','70',0,'4'),(362563,115380,'117296','printshop','height','5',0,'4'),(362564,115380,'117296','printshop','border-top-width','1',0,'4'),(362565,115380,'117296','printshop','border-top-color','$content-border-3',0,'4'),(362566,115380,'117296','printshop','margin-left','10',0,'4'),(362567,115380,'117296','printshop','margin-right','10',0,'4'),(362568,115380,'117296','printshop','position','relative',0,''),(362569,115380,'117296','printshop','top','-10',0,''),(362570,115381,'117297','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362571,115381,'117297','printshop','font-size','26',0,''),(362572,115381,'117297','printshop','font-family','$font-1',0,''),(362573,115381,'117297','printshop','padding-top','15',0,''),(362574,115381,'117297','printshop','padding-bottom','15',0,''),(362575,115381,'117297','printshop','text-align','center',0,''),(362576,115382,'117298','printshop','text-align','center',0,''),(362577,115382,'117298','printshop','hide_parents','2',0,''),(362578,115383,'117299','printshop','block_type','1',0,''),(362579,115383,'117299','printshop','padding-top','40',0,''),(362580,115383,'117299','printshop','background-color','$content-bg-2',0,''),(362581,115383,'117299','printshop','padding-bottom','40',0,''),(362582,115383,'117299','printshop','style_class','checkout-login-wrap',0,''),(362583,115383,'117299','printshop','color','$content-bg-2',0,''),(362584,115384,'117300','printshop','block_type','2',0,''),(362585,115384,'117300','printshop','background-color','$content-bg-1',0,''),(362586,115384,'117300','printshop','max-width','830',0,''),(362587,115384,'117300','printshop','margin_left_measure','auto',0,''),(362588,115384,'117300','printshop','margin_right_measure','auto',0,''),(362589,115384,'117300','printshop','padding-top','40',0,''),(362590,115384,'117300','printshop','padding-bottom','40',0,''),(362591,115384,'117300','printshop','schema','2-1',0,'5342'),(362592,115384,'117300','printshop','schema','2-3',0,'5333'),(362593,115384,'117300','printshop','color','$content-color-1',0,''),(362594,115385,'1644496194.7022','printshop','block_type','1',0,''),(362595,115385,'1644496194.7022','printshop','padding-left','30',0,''),(362596,115385,'1644496194.7022','printshop','padding-right','20',0,''),(362597,115385,'1644496194.7022','printshop','padding-left','20',0,'5333'),(362598,115386,'117301','printshop','text-align','center',0,''),(362599,115386,'117301','printshop','margin-bottom','40',0,''),(362600,115387,'117302','printshop','text-align','center',0,''),(362601,115388,'117303','printshop','text','##TEXT_OR##',0,''),(362602,115388,'117303','printshop','font-size','18',0,''),(362603,115388,'117303','printshop','text-align','center',0,''),(362604,115388,'117303','printshop','content','\\_',0,'3'),(362605,115388,'117303','printshop','height','5',0,'3'),(362606,115388,'117303','printshop','width','70',0,'3'),(362607,115388,'117303','printshop','display','inline-block',0,'3'),(362608,115388,'117303','printshop','border-top-width','1',0,'3'),(362609,115388,'117303','printshop','border-top-color','$content-border-3',0,'3'),(362610,115388,'117303','printshop','margin-left','10',0,'3'),(362611,115388,'117303','printshop','margin-right','10',0,'3'),(362612,115388,'117303','printshop','content','\\_',0,'4'),(362613,115388,'117303','printshop','display','inline-block',0,'4'),(362614,115388,'117303','printshop','width','70',0,'4'),(362615,115388,'117303','printshop','height','5',0,'4'),(362616,115388,'117303','printshop','border-top-width','1',0,'4'),(362617,115388,'117303','printshop','border-top-color','$content-border-3',0,'4'),(362618,115388,'117303','printshop','margin-left','10',0,'4'),(362619,115388,'117303','printshop','margin-right','10',0,'4'),(362620,115388,'117303','printshop','position','relative',0,''),(362621,115388,'117303','printshop','padding-top','10',0,''),(362622,115388,'117303','printshop','padding-bottom','10',0,''),(362623,115388,'117303','printshop','font-family','$font-1',0,''),(362624,115389,'117304','printshop','block_type','1',0,''),(362625,115390,'117305','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362626,115390,'117305','printshop','font-size','20',0,''),(362627,115390,'117305','printshop','font-family','$font-1',0,''),(362628,115390,'117305','printshop','padding-top','12',0,''),(362629,115390,'117305','printshop','text-align','left',0,''),(362630,115390,'117305','printshop','font-weight','bold',0,''),(362631,115390,'117305','printshop','margin-bottom','20',0,''),(362632,115390,'117305','printshop','position','relative',0,''),(362633,115390,'117305','printshop','height','4',0,'3'),(362634,115390,'117305','printshop','width','54',0,'3'),(362635,115390,'117305','printshop','content',' ',0,'3'),(362636,115390,'117305','printshop','background-color','$highlight-box-border-2',0,'3'),(362637,115390,'117305','printshop','position','absolute',0,'3'),(362638,115390,'117305','printshop','top','0',0,'3'),(362639,115390,'117305','printshop','left','0',0,'3'),(362640,115391,'117306','printshop','text-align','center',0,''),(362641,115391,'117306','printshop','hide_parents','2',0,''),(362642,115392,'117307','printshop','text','##NEW_CUSTOMER##',0,''),(362643,115392,'117307','printshop','font-size','20',0,''),(362644,115392,'117307','printshop','font-family','$font-1',0,''),(362645,115392,'117307','printshop','margin-bottom','20',0,''),(362646,115392,'117307','printshop','font-weight','bold',0,''),(362647,115392,'117307','printshop','height','4',0,'3'),(362648,115392,'117307','printshop','width','54',0,'3'),(362649,115392,'117307','printshop','background-color','$highlight-box-border-2',0,'3'),(362650,115392,'117307','printshop','position','absolute',0,'3'),(362651,115392,'117307','printshop','top','0',0,'3'),(362652,115392,'117307','printshop','left','0',0,'3'),(362653,115392,'117307','printshop','position','relative',0,''),(362654,115392,'117307','printshop','display','block',0,'3'),(362655,115392,'117307','printshop','content',' ',0,'3'),(362656,115392,'117307','printshop','padding-top','12',0,''),(362657,115393,'1644496248.7478','printshop','block_type','1',0,''),(362658,115393,'1644496248.7478','printshop','padding-left','20',0,''),(362659,115393,'1644496248.7478','printshop','padding-right','30',0,''),(362660,115393,'1644496248.7478','printshop','padding-right','20',0,'5333'),(362661,115394,'117308','printshop','margin_left_measure','auto',0,''),(362662,115394,'117308','printshop','margin_right_measure','auto',0,''),(362663,115394,'117308','printshop','padding-top','0',0,'5333'),(362664,115395,'117309','printshop','text','##RETURNING_CUSTOMER##',0,''),(362665,115395,'117309','printshop','font-size','20',0,''),(362666,115395,'117309','printshop','font-family','$font-1',0,''),(362667,115395,'117309','printshop','text-align','left',0,''),(362668,115395,'117309','printshop','position','relative',0,''),(362669,115395,'117309','printshop','font-weight','bold',0,''),(362670,115395,'117309','printshop','padding-top','12',0,''),(362671,115395,'117309','printshop','margin-bottom','20',0,''),(362672,115395,'117309','printshop','background-color','$highlight-box-border-2',0,'3'),(362673,115395,'117309','printshop','content',' ',0,'3'),(362674,115395,'117309','printshop','width','54',0,'3'),(362675,115395,'117309','printshop','height','4',0,'3'),(362676,115395,'117309','printshop','position','absolute',0,'3'),(362677,115395,'117309','printshop','top','0',0,'3'),(362678,115395,'117309','printshop','left','0',0,'3'),(362679,115396,'117310','printshop','block_type','1',0,''),(362680,115396,'117310','printshop','padding-top','20',0,''),(362681,115397,'117311','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(362682,115397,'117311','printshop','tab_2','RETURNING CUSTOMER',1,''),(362683,115397,'117311','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(362684,115397,'117311','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(362685,115397,'117311','printshop','tab_2','RETURNING CUSTOMER',2,''),(362686,115397,'117311','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(362687,115397,'117311','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(362688,115397,'117311','printshop','tab_2','RETURNING CUSTOMER',3,''),(362689,115397,'117311','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(362690,115397,'117311','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(362691,115397,'117311','printshop','tab_2','RETURNING CUSTOMER',4,''),(362692,115397,'117311','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(362693,115398,'117312','printshop','block_type','8',0,''),(362694,115399,'117313','printshop','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(362695,115400,'117314','printshop','block_type','1',0,''),(362696,115400,'117314','printshop','padding-left','20',0,''),(362697,115400,'117314','printshop','padding-right','20',0,''),(362698,115402,'117316','printshop','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(362699,115402,'117316','printshop','border-top-width','1',0,''),(362700,115402,'117316','printshop','border-top-color','$content-border-3',0,''),(362701,115404,'117318','printshop','block_type','8',0,''),(362702,115405,'117319','printshop','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(362703,115406,'117320','printshop','block_type','1',0,''),(362704,115406,'117320','printshop','padding-left','20',0,''),(362705,115406,'117320','printshop','padding-right','20',0,''),(362706,115407,'117321','printshop','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(362707,115409,'117323','printshop','text-align','center',0,''),(362708,115410,'117324','printshop','text','##TEXT_OR##',0,''),(362709,115410,'117324','printshop','font-size','18',0,''),(362710,115410,'117324','printshop','font-weight','700',0,''),(362711,115410,'117324','printshop','padding-top','15',0,''),(362712,115410,'117324','printshop','text-align','center',0,''),(362713,115410,'117324','printshop','content','\\_',0,'3'),(362714,115410,'117324','printshop','height','5',0,'3'),(362715,115410,'117324','printshop','width','70',0,'3'),(362716,115410,'117324','printshop','display','inline-block',0,'3'),(362717,115410,'117324','printshop','border-top-width','1',0,'3'),(362718,115410,'117324','printshop','border-top-color','$content-border-3',0,'3'),(362719,115410,'117324','printshop','margin-left','10',0,'3'),(362720,115410,'117324','printshop','margin-right','10',0,'3'),(362721,115410,'117324','printshop','content','\\_',0,'4'),(362722,115410,'117324','printshop','display','inline-block',0,'4'),(362723,115410,'117324','printshop','width','70',0,'4'),(362724,115410,'117324','printshop','height','5',0,'4'),(362725,115410,'117324','printshop','border-top-width','1',0,'4'),(362726,115410,'117324','printshop','border-top-color','$content-border-3',0,'4'),(362727,115410,'117324','printshop','margin-left','10',0,'4'),(362728,115410,'117324','printshop','margin-right','10',0,'4'),(362729,115410,'117324','printshop','position','relative',0,''),(362730,115410,'117324','printshop','top','-10',0,''),(362731,115411,'117325','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362732,115411,'117325','printshop','font-size','26',0,''),(362733,115411,'117325','printshop','font-family','$font-1',0,''),(362734,115411,'117325','printshop','padding-top','15',0,''),(362735,115411,'117325','printshop','padding-bottom','15',0,''),(362736,115411,'117325','printshop','text-align','center',0,''),(362737,115412,'117326','printshop','block_type','1',0,''),(362738,115412,'117326','printshop','padding-top','20',0,''),(362739,115413,'117327','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(362740,115413,'117327','printshop','tab_2','RETURNING CUSTOMER',1,''),(362741,115413,'117327','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(362742,115413,'117327','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(362743,115413,'117327','printshop','tab_2','RETURNING CUSTOMER',2,''),(362744,115413,'117327','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(362745,115413,'117327','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(362746,115413,'117327','printshop','tab_2','RETURNING CUSTOMER',3,''),(362747,115413,'117327','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(362748,115413,'117327','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(362749,115413,'117327','printshop','tab_2','RETURNING CUSTOMER',4,''),(362750,115413,'117327','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(362751,115414,'117328','printshop','block_type','8',0,''),(362752,115415,'117329','printshop','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(362753,115418,'117332','printshop','block_type','8',0,''),(362754,115419,'117333','printshop','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(362755,115421,'117335','printshop','block_type','1',0,''),(362756,115421,'117335','printshop','padding-left','20',0,''),(362757,115421,'117335','printshop','padding-right','20',0,''),(362758,115423,'117337','printshop','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(362759,115424,'117338','printshop','text','##TEXT_OR##',0,''),(362760,115424,'117338','printshop','font-size','18',0,''),(362761,115424,'117338','printshop','font-weight','700',0,''),(362762,115424,'117338','printshop','padding-top','15',0,''),(362763,115424,'117338','printshop','text-align','center',0,''),(362764,115424,'117338','printshop','content','\\_',0,'3'),(362765,115424,'117338','printshop','height','5',0,'3'),(362766,115424,'117338','printshop','width','70',0,'3'),(362767,115424,'117338','printshop','display','inline-block',0,'3'),(362768,115424,'117338','printshop','border-top-width','1',0,'3'),(362769,115424,'117338','printshop','border-top-color','$content-border-3',0,'3'),(362770,115424,'117338','printshop','margin-left','10',0,'3'),(362771,115424,'117338','printshop','margin-right','10',0,'3'),(362772,115424,'117338','printshop','content','\\_',0,'4'),(362773,115424,'117338','printshop','display','inline-block',0,'4'),(362774,115424,'117338','printshop','width','70',0,'4'),(362775,115424,'117338','printshop','height','5',0,'4'),(362776,115424,'117338','printshop','border-top-width','1',0,'4'),(362777,115424,'117338','printshop','border-top-color','$content-border-3',0,'4'),(362778,115424,'117338','printshop','margin-left','10',0,'4'),(362779,115424,'117338','printshop','margin-right','10',0,'4'),(362780,115424,'117338','printshop','position','relative',0,''),(362781,115424,'117338','printshop','top','-10',0,''),(362782,115425,'117339','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362783,115425,'117339','printshop','font-size','26',0,''),(362784,115425,'117339','printshop','font-family','$font-1',0,''),(362785,115425,'117339','printshop','padding-top','15',0,''),(362786,115425,'117339','printshop','padding-bottom','15',0,''),(362787,115425,'117339','printshop','text-align','center',0,''),(362788,115426,'117340','printshop','text-align','center',0,''),(362789,115427,'117341','printshop','block_type','1',0,''),(362790,115427,'117341','printshop','padding-top','20',0,''),(362791,115428,'117342','printshop','text-align','center',0,''),(362792,115429,'117343','printshop','text','##TEXT_OR##',0,''),(362793,115429,'117343','printshop','font-size','18',0,''),(362794,115429,'117343','printshop','font-weight','700',0,''),(362795,115429,'117343','printshop','padding-top','15',0,''),(362796,115429,'117343','printshop','text-align','center',0,''),(362797,115429,'117343','printshop','content','\\_',0,'3'),(362798,115429,'117343','printshop','height','5',0,'3'),(362799,115429,'117343','printshop','width','70',0,'3'),(362800,115429,'117343','printshop','display','inline-block',0,'3'),(362801,115429,'117343','printshop','border-top-width','1',0,'3'),(362802,115429,'117343','printshop','border-top-color','$content-border-3',0,'3'),(362803,115429,'117343','printshop','margin-left','10',0,'3'),(362804,115429,'117343','printshop','margin-right','10',0,'3'),(362805,115429,'117343','printshop','content','\\_',0,'4'),(362806,115429,'117343','printshop','display','inline-block',0,'4'),(362807,115429,'117343','printshop','width','70',0,'4'),(362808,115429,'117343','printshop','height','5',0,'4'),(362809,115429,'117343','printshop','border-top-width','1',0,'4'),(362810,115429,'117343','printshop','border-top-color','$content-border-3',0,'4'),(362811,115429,'117343','printshop','margin-left','10',0,'4'),(362812,115429,'117343','printshop','margin-right','10',0,'4'),(362813,115429,'117343','printshop','position','relative',0,''),(362814,115429,'117343','printshop','top','-10',0,''),(362815,115430,'117344','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(362816,115430,'117344','printshop','tab_2','RETURNING CUSTOMER',1,''),(362817,115430,'117344','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(362818,115430,'117344','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(362819,115430,'117344','printshop','tab_2','RETURNING CUSTOMER',2,''),(362820,115430,'117344','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(362821,115430,'117344','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(362822,115430,'117344','printshop','tab_2','RETURNING CUSTOMER',3,''),(362823,115430,'117344','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(362824,115430,'117344','printshop','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(362825,115430,'117344','printshop','tab_2','RETURNING CUSTOMER',4,''),(362826,115430,'117344','printshop','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(362827,115431,'117345','printshop','block_type','8',0,''),(362828,115432,'117346','printshop','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(362829,115435,'117349','printshop','block_type','8',0,''),(362830,115436,'117350','printshop','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(362831,115437,'117351','printshop','block_type','1',0,''),(362832,115437,'117351','printshop','padding-left','20',0,''),(362833,115437,'117351','printshop','padding-right','20',0,''),(362834,115439,'117353','printshop','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(362835,115440,'117354','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362836,115440,'117354','printshop','font-size','26',0,''),(362837,115440,'117354','printshop','font-family','$font-1',0,''),(362838,115440,'117354','printshop','padding-top','15',0,''),(362839,115440,'117354','printshop','padding-bottom','15',0,''),(362840,115440,'117354','printshop','text-align','center',0,''),(362841,115441,'117355','printshop','block_type','1',0,''),(362842,115441,'117355','printshop','padding-top','40',0,''),(362843,115441,'117355','printshop','background-color','$content-bg-2',0,''),(362844,115441,'117355','printshop','padding-bottom','40',0,''),(362845,115442,'117356','printshop','block_type','2',0,''),(362846,115442,'117356','printshop','background-color','$content-bg-1',0,''),(362847,115442,'117356','printshop','max-width','830',0,''),(362848,115442,'117356','printshop','margin_left_measure','auto',0,''),(362849,115442,'117356','printshop','margin_right_measure','auto',0,''),(362850,115442,'117356','printshop','padding-top','40',0,''),(362851,115442,'117356','printshop','padding-bottom','40',0,''),(362852,115442,'117356','printshop','schema','2-3',0,'5342'),(362853,115443,'117357','printshop','block_type','1',0,''),(362854,115444,'117358','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362855,115444,'117358','printshop','font-size','18',0,''),(362856,115444,'117358','printshop','font-family','$font-1',0,''),(362857,115444,'117358','printshop','padding-top','15',0,''),(362858,115444,'117358','printshop','padding-bottom','15',0,''),(362859,115444,'117358','printshop','text-align','center',0,''),(362860,115444,'117358','printshop','text-transform','uppercase',0,''),(362861,115445,'117359','printshop','text-align','center',0,''),(362862,115445,'117359','printshop','hide_parents','2',0,''),(362863,115446,'117360','printshop','text-align','center',0,''),(362864,115447,'117361','printshop','text-align','center',0,''),(362865,115447,'117361','printshop','margin-bottom','40',0,''),(362866,115448,'117362','printshop','text','##TEXT_OR##',0,''),(362867,115448,'117362','printshop','font-size','18',0,''),(362868,115448,'117362','printshop','font-weight','700',0,''),(362869,115448,'117362','printshop','text-align','center',0,''),(362870,115448,'117362','printshop','content','\\_',0,'3'),(362871,115448,'117362','printshop','height','5',0,'3'),(362872,115448,'117362','printshop','width','70',0,'3'),(362873,115448,'117362','printshop','display','inline-block',0,'3'),(362874,115448,'117362','printshop','border-top-width','1',0,'3'),(362875,115448,'117362','printshop','border-top-color','$content-border-3',0,'3'),(362876,115448,'117362','printshop','margin-left','10',0,'3'),(362877,115448,'117362','printshop','margin-right','10',0,'3'),(362878,115448,'117362','printshop','content','\\_',0,'4'),(362879,115448,'117362','printshop','display','inline-block',0,'4'),(362880,115448,'117362','printshop','width','70',0,'4'),(362881,115448,'117362','printshop','height','5',0,'4'),(362882,115448,'117362','printshop','border-top-width','1',0,'4'),(362883,115448,'117362','printshop','border-top-color','$content-border-3',0,'4'),(362884,115448,'117362','printshop','margin-left','10',0,'4'),(362885,115448,'117362','printshop','margin-right','10',0,'4'),(362886,115448,'117362','printshop','position','relative',0,''),(362887,115448,'117362','printshop','padding-top','10',0,''),(362888,115448,'117362','printshop','padding-bottom','10',0,''),(362889,115449,'117363','printshop','text','##NEW_CUSTOMER##',0,''),(362890,115449,'117363','printshop','font-size','18',0,''),(362891,115449,'117363','printshop','font-family','$font-1',0,''),(362892,115449,'117363','printshop','text-align','center',0,''),(362893,115449,'117363','printshop','text-transform','uppercase',0,''),(362894,115449,'117363','printshop','margin-bottom','10',0,''),(362895,115450,'117364','printshop','text','##RETURNING_CUSTOMER##',0,''),(362896,115450,'117364','printshop','font-size','18',0,''),(362897,115450,'117364','printshop','font-family','$font-1',0,''),(362898,115450,'117364','printshop','text-transform','uppercase',0,''),(362899,115450,'117364','printshop','text-align','center',0,''),(362900,115451,'117365','printshop','max-width','230',0,''),(362901,115451,'117365','printshop','margin_left_measure','auto',0,''),(362902,115451,'117365','printshop','margin_right_measure','auto',0,''),(362903,115452,'117366','printshop','block_type','1',0,''),(362904,115452,'117366','printshop','padding-top','40',0,''),(362905,115452,'117366','printshop','background-color','$content-bg-2',0,''),(362906,115452,'117366','printshop','padding-bottom','40',0,''),(362907,115453,'117367','printshop','block_type','2',0,''),(362908,115453,'117367','printshop','background-color','$content-bg-1',0,''),(362909,115453,'117367','printshop','max-width','830',0,''),(362910,115453,'117367','printshop','margin_left_measure','auto',0,''),(362911,115453,'117367','printshop','margin_right_measure','auto',0,''),(362912,115453,'117367','printshop','padding-top','40',0,''),(362913,115453,'117367','printshop','padding-bottom','40',0,''),(362914,115453,'117367','printshop','schema','2-3',0,'5342'),(362915,115454,'117368','printshop','text','##NEW_CUSTOMER##',0,''),(362916,115454,'117368','printshop','font-size','18',0,''),(362917,115454,'117368','printshop','font-family','$font-1',0,''),(362918,115454,'117368','printshop','text-align','center',0,''),(362919,115454,'117368','printshop','text-transform','uppercase',0,''),(362920,115454,'117368','printshop','margin-bottom','10',0,''),(362921,115455,'117369','printshop','text-align','center',0,''),(362922,115456,'117370','printshop','text-align','center',0,''),(362923,115456,'117370','printshop','margin-bottom','40',0,''),(362924,115457,'117371','printshop','text','##TEXT_OR##',0,''),(362925,115457,'117371','printshop','font-size','18',0,''),(362926,115457,'117371','printshop','font-weight','700',0,''),(362927,115457,'117371','printshop','text-align','center',0,''),(362928,115457,'117371','printshop','content','\\_',0,'3'),(362929,115457,'117371','printshop','height','5',0,'3'),(362930,115457,'117371','printshop','width','70',0,'3'),(362931,115457,'117371','printshop','display','inline-block',0,'3'),(362932,115457,'117371','printshop','border-top-width','1',0,'3'),(362933,115457,'117371','printshop','border-top-color','$content-border-3',0,'3'),(362934,115457,'117371','printshop','margin-left','10',0,'3'),(362935,115457,'117371','printshop','margin-right','10',0,'3'),(362936,115457,'117371','printshop','content','\\_',0,'4'),(362937,115457,'117371','printshop','display','inline-block',0,'4'),(362938,115457,'117371','printshop','width','70',0,'4'),(362939,115457,'117371','printshop','height','5',0,'4'),(362940,115457,'117371','printshop','border-top-width','1',0,'4'),(362941,115457,'117371','printshop','border-top-color','$content-border-3',0,'4'),(362942,115457,'117371','printshop','margin-left','10',0,'4'),(362943,115457,'117371','printshop','margin-right','10',0,'4'),(362944,115457,'117371','printshop','position','relative',0,''),(362945,115457,'117371','printshop','padding-top','10',0,''),(362946,115457,'117371','printshop','padding-bottom','10',0,''),(362947,115458,'117372','printshop','block_type','1',0,''),(362948,115459,'117373','printshop','text','##LOGIN_WITH_SOCIAL##',0,''),(362949,115459,'117373','printshop','font-size','18',0,''),(362950,115459,'117373','printshop','font-family','$font-1',0,''),(362951,115459,'117373','printshop','padding-top','15',0,''),(362952,115459,'117373','printshop','padding-bottom','15',0,''),(362953,115459,'117373','printshop','text-align','center',0,''),(362954,115459,'117373','printshop','text-transform','uppercase',0,''),(362955,115460,'117374','printshop','text-align','center',0,''),(362956,115460,'117374','printshop','hide_parents','2',0,''),(362957,115461,'117375','printshop','text','##RETURNING_CUSTOMER##',0,''),(362958,115461,'117375','printshop','font-size','18',0,''),(362959,115461,'117375','printshop','font-family','$font-1',0,''),(362960,115461,'117375','printshop','text-transform','uppercase',0,''),(362961,115461,'117375','printshop','text-align','center',0,''),(362962,115462,'117376','printshop','max-width','230',0,''),(362963,115462,'117376','printshop','margin_left_measure','auto',0,''),(362964,115462,'117376','printshop','margin_right_measure','auto',0,''),(362965,115463,'117377','printshop','block_type','1',0,''),(362966,115464,'117378','printshop','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(362967,115464,'117378','printshop','margin-bottom','30',0,''),(362968,115465,'117379','printshop','block_type','1',0,''),(362969,115466,'117380','printshop','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(362970,115466,'117380','printshop','margin-bottom','30',0,''),(362971,115467,'117386','printshop','block_type','1',0,''),(362972,115467,'117386','printshop','font-weight','normal',0,''),(362973,115467,'117386','printshop','style_class','index-wrap',0,''),(362974,115468,'120856','printshop','block_type','1',0,''),(362975,115468,'120856','printshop','style_class','doubleBanner',0,''),(362976,115469,'120857','printshop','banners_group','double-pri',0,''),(362977,115469,'120857','printshop','template','1',0,''),(362978,115469,'120857','printshop','banners_type','banner',0,''),(362979,115470,'120862','printshop','block_type','1',0,''),(362980,115471,'117389','printshop','col_in_row','2',0,''),(362981,115471,'117389','printshop','show_attributes','1',0,''),(362982,115471,'117389','printshop','listing_type','productListing',0,''),(362983,115471,'117389','printshop','show_qty_input','1',0,''),(362984,115471,'117389','printshop','show_compare','1',0,''),(362985,115471,'117389','printshop','lazy_load','1',0,''),(362986,115471,'117389','printshop','show_model','1',0,''),(362987,115471,'117389','printshop','show_properties','1',0,''),(362988,115471,'117389','printshop','show_bonus_points','1',0,''),(362989,115471,'117389','printshop','show_buy_button','1',0,''),(362990,115471,'117389','printshop','show_wishlist_button','1',0,''),(362991,115471,'117389','printshop','hide_parents','2',0,''),(362992,115471,'117389','printshop','col_in_row','1',0,'5363'),(362993,115472,'121014','printshop','text','<h2>New Arrivals</h2>',0,''),(362994,115473,'1644485886.0558','printshop','block_type','1',0,''),(362995,115473,'1644485886.0558','printshop','style_class','tripleLine',0,''),(362996,115473,'1644485886.0558','printshop','padding-top','30',0,''),(362997,115473,'1644485886.0558','printshop','padding-bottom','30',0,''),(362998,115474,'1644486520.9017','printshop','banners_group','triple-lin',0,''),(362999,115474,'1644486520.9017','printshop','banners_type','banner',0,''),(363000,115474,'1644486520.9017','printshop','template','1',0,''),(363001,115475,'1644577826.0002','printshop','block_type','1',0,''),(363002,115475,'1644577826.0002','printshop','style_class','middleBanner',0,''),(363003,115476,'1644321730.7025','printshop','banners_group','middle-pri',0,''),(363004,115476,'1644321730.7025','printshop','margin-bottom','30',0,''),(363005,115476,'1644321730.7025','printshop','template','1',0,''),(363006,115476,'1644321730.7025','printshop','banners_type','banner',0,''),(363007,115476,'1644321730.7025','printshop','ban_id','124',0,''),(363008,115477,'1644580572.4789','printshop','block_type','1',0,''),(363009,115477,'1644580572.4789','printshop','style_class','bottomDoubleBanner',0,''),(363010,115478,'1644580744.5807','printshop','banners_group','bottom-dou',0,''),(363011,115478,'1644580744.5807','printshop','banners_type','banner',0,''),(363012,115478,'1644580744.5807','printshop','template','1',0,''),(363013,115479,'1644580721.7097','printshop','block_type','1',0,''),(363014,115479,'1644580721.7097','printshop','style_class','bottomBanner',0,''),(363015,115480,'120865','printshop','banners_group','home-botto',0,''),(363016,115480,'120865','printshop','banners_type','banner',0,''),(363017,115480,'120865','printshop','margin-bottom','30',0,''),(363018,115480,'120865','printshop','template','1',0,''),(363019,115481,'1644601798.7155','printshop','block_type','1',0,''),(363020,115481,'1644601798.7155','printshop','style_class','topBanner',0,''),(363021,115482,'1683025508.153','printshop','banners_group','4',0,''),(363022,115484,'117394','printshop','block_type','1',0,''),(363023,115485,'117395','printshop','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(363024,115487,'117397','printshop','block_type','1',0,''),(363025,115487,'117397','printshop','padding-top','40',0,''),(363026,115487,'117397','printshop','padding-bottom','80',0,''),(363027,115488,'117398','printshop','block_type','6',0,''),(363028,115489,'117399','printshop','block_type','1',0,''),(363029,115489,'117399','printshop','padding-top','20',0,''),(363030,115489,'117399','printshop','padding-left','20',0,''),(363031,115489,'117399','printshop','padding-right','20',0,''),(363032,115489,'117399','printshop','padding-bottom','20',0,''),(363033,115489,'117399','printshop','border-top-width','1',0,''),(363034,115489,'117399','printshop','border-left-width','1',0,''),(363035,115489,'117399','printshop','border-right-width','1',0,''),(363036,115489,'117399','printshop','border-bottom-width','1',0,''),(363037,115489,'117399','printshop','border-top-color','$content-border-3',0,''),(363038,115489,'117399','printshop','border-left-color','$content-border-3',0,''),(363039,115489,'117399','printshop','border-right-color','$content-border-3',0,''),(363040,115489,'117399','printshop','border-bottom-color','$content-border-3',0,''),(363041,115489,'117399','printshop','margin-right','20',0,''),(363042,115492,'117402','printshop','block_type','1',0,''),(363043,115492,'117402','printshop','padding-top','20',0,''),(363044,115493,'117403','printshop','block_type','6',0,''),(363045,115494,'117404','printshop','padding-right','20',0,''),(363046,115496,'117406','printshop','block_type','1',0,''),(363047,115496,'117406','printshop','padding-top','20',0,''),(363048,115497,'117407','printshop','block_type','6',0,''),(363049,115498,'117408','printshop','padding-right','20',0,''),(363050,115500,'117410','printshop','block_type','1',0,''),(363051,115500,'117410','printshop','style_class','account-password-wrap',0,''),(363052,115501,'117411','printshop','block_type','6',0,''),(363053,115501,'117411','printshop','schema','6-3',0,'5342'),(363054,115502,'117412','printshop','aria_name','account-menu',0,''),(363117,115523,'117414','printshop','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(363118,115524,'117415','printshop','block_type','1',0,''),(363119,115524,'117415','printshop','padding-top','20',0,''),(363120,115525,'117416','printshop','tab_1','RETURNING CUSTOMER',1,''),(363121,115525,'117416','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(363122,115525,'117416','printshop','tab_1','RETURNING CUSTOMER',2,''),(363123,115525,'117416','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(363124,115525,'117416','printshop','tab_1','RETURNING CUSTOMER',3,''),(363125,115525,'117416','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(363126,115525,'117416','printshop','tab_1','RETURNING CUSTOMER',4,''),(363127,115525,'117416','printshop','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(363128,115526,'117417','printshop','max-width','800',0,''),(363129,115526,'117417','printshop','margin_left_measure','auto',0,''),(363130,115526,'117417','printshop','margin_right_measure','auto',0,''),(363131,115527,'117418','printshop','block_type','8',0,''),(363132,115528,'117419','printshop','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(363133,115529,'117420','printshop','block_type','1',0,''),(363134,115529,'117420','printshop','padding-left','20',0,''),(363135,115529,'117420','printshop','padding-right','20',0,''),(363136,115531,'117422','printshop','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(363137,115532,'117423','printshop','block_type','1',0,''),(363138,115533,'117424','printshop','block_type','1',0,''),(363139,115534,'117425','printshop','margin-left','0',0,''),(363140,115534,'117425','printshop','margin-right','0',0,''),(363141,115534,'117425','printshop','margin-bottom','20',0,''),(363142,115535,'117426','printshop','margin-bottom','30',0,''),(363143,115536,'117427','printshop','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(363144,115537,'117428','printshop','block_type','1',0,''),(363145,115539,'117430','printshop','block_type','6',0,''),(363146,115539,'117430','printshop','font-weight','400',0,''),(363147,115539,'117430','printshop','schema','6-2',0,'5363'),(363148,115539,'117430','printshop','schema','6-2',0,'5342'),(363149,115540,'117431','printshop','font-weight','400',0,''),(363150,115540,'117431','printshop','padding-right','40',0,''),(363151,115540,'117431','printshop','padding-right','0',0,'5363'),(363152,115540,'117431','printshop','padding-right','0',0,'5342'),(363153,115541,'117432','printshop','col_in_row','3',0,''),(363154,115541,'117432','printshop','products_align','left',0,''),(363155,115541,'117432','printshop','font-weight','400',0,''),(363156,115541,'117432','printshop','show_qty_input','0',0,''),(363157,115541,'117432','printshop','listing_type','productListing',0,''),(363158,115541,'117432','printshop','listing_type_rows','no',0,''),(363159,115541,'117432','printshop','show_buy_button_b2b','on',0,''),(363160,115541,'117432','printshop','show_wishlist_button_b2b','1',0,''),(363161,115541,'117432','printshop','show_compare_b2b','1',0,''),(363162,115541,'117432','printshop','show_stock','0',0,''),(363163,115541,'117432','printshop','show_description','0',0,''),(363164,115541,'117432','printshop','show_model','0',0,''),(363165,115541,'117432','printshop','show_properties','0',0,''),(363166,115541,'117432','printshop','show_rating','0',0,''),(363167,115541,'117432','printshop','show_rating_counts','0',0,''),(363168,115541,'117432','printshop','show_price','0',0,''),(363169,115541,'117432','printshop','show_buy_button','0',0,''),(363170,115541,'117432','printshop','show_view_button','0',0,''),(363171,115541,'117432','printshop','show_wishlist_button','0',0,''),(363172,115541,'117432','printshop','show_compare','0',0,''),(363173,115541,'117432','printshop','show_name_rows','0',0,''),(363174,115541,'117432','printshop','show_image_rows','0',0,''),(363175,115541,'117432','printshop','show_stock_rows','0',0,''),(363176,115541,'117432','printshop','show_description_rows','0',0,''),(363177,115541,'117432','printshop','show_model_rows','0',0,''),(363178,115541,'117432','printshop','show_properties_rows','0',0,''),(363179,115541,'117432','printshop','show_rating_rows','0',0,''),(363180,115541,'117432','printshop','show_rating_counts_rows','0',0,''),(363181,115541,'117432','printshop','show_price_rows','0',0,''),(363182,115541,'117432','printshop','show_buy_button_rows','0',0,''),(363183,115541,'117432','printshop','show_qty_input_rows','0',0,''),(363184,115541,'117432','printshop','show_view_button_rows','0',0,''),(363185,115541,'117432','printshop','show_wishlist_button_rows','0',0,''),(363186,115541,'117432','printshop','show_compare_rows','0',0,''),(363187,115541,'117432','printshop','show_name_b2b','0',0,''),(363188,115541,'117432','printshop','show_image_b2b','0',0,''),(363189,115541,'117432','printshop','show_stock_b2b','0',0,''),(363190,115541,'117432','printshop','show_description_b2b','0',0,''),(363191,115541,'117432','printshop','show_model_b2b','0',0,''),(363192,115541,'117432','printshop','show_properties_b2b','0',0,''),(363193,115541,'117432','printshop','show_rating_b2b','0',0,''),(363194,115541,'117432','printshop','show_rating_counts_b2b','0',0,''),(363195,115541,'117432','printshop','show_price_b2b','0',0,''),(363196,115541,'117432','printshop','show_qty_input_b2b','0',0,''),(363197,115541,'117432','printshop','show_view_button_b2b','0',0,''),(363198,115541,'117432','printshop','show_attributes_b2b','0',0,''),(363199,115541,'117432','printshop','items_on_page','9',0,''),(363200,115541,'117432','printshop','col_in_row','2',0,'5342'),(363201,115541,'117432','printshop','col_in_row','1',0,'5363'),(363202,115541,'117432','printshop','product_names_teg','h2',0,''),(363203,115543,'117434','printshop','block_type','5',0,''),(363204,115543,'117434','printshop','padding-top','10',0,''),(363205,115543,'117434','printshop','padding-bottom','10',0,''),(363206,115543,'117434','printshop','schema','5-2',0,'5363'),(363207,115543,'117434','printshop','border-top-color','$content-border-3',0,''),(363208,115543,'117434','printshop','border-top-width','1',0,''),(363209,115545,'117436','printshop','float','right',0,''),(363210,115546,'117437','printshop','listing_type','productListing',0,''),(363211,115548,'117439','printshop','block_type','1',0,''),(363212,115548,'117439','printshop','padding-top','10',0,''),(363213,115548,'117439','printshop','padding-bottom','10',0,''),(363214,115548,'117439','printshop','border-bottom-width','1',0,''),(363215,115548,'117439','printshop','border-bottom-color','$content-border-3',0,''),(363216,115548,'117439','printshop','margin-left','0',0,''),(363217,115548,'117439','printshop','margin-right','0',0,''),(363218,115549,'117440','printshop','float','right',0,''),(363219,115549,'117440','printshop','display','none',0,'5363'),(363220,115550,'117441','printshop','float','left',0,''),(363221,115550,'117441','printshop','clear','none',0,''),(363222,115550,'117441','printshop','margin-left','20',0,''),(363223,115550,'117441','printshop','display','none',0,'5363'),(363224,115551,'117442','printshop','margin-right','20',0,''),(363225,115551,'117442','printshop','float','right',0,''),(363226,115551,'117442','printshop','clear','none',0,''),(363227,115551,'117442','printshop','display','none',0,'5342'),(363228,115552,'117443','printshop','float','left',0,''),(363229,115552,'117443','printshop','clear','none',0,''),(363230,115552,'117443','printshop','sort_pos_3','1',0,''),(363231,115552,'117443','printshop','sort_pos_4','2',0,''),(363232,115552,'117443','printshop','sort_pos_10','3',0,''),(363233,115552,'117443','printshop','sort_pos_9','4',0,''),(363234,115552,'117443','printshop','sort_pos_11','5',0,''),(363235,115552,'117443','printshop','sort_pos_12','6',0,''),(363236,115552,'117443','printshop','sort_pos_14','7',0,''),(363237,115552,'117443','printshop','sort_pos_13','8',0,''),(363238,115552,'117443','printshop','sort_pos_8','9',0,''),(363239,115552,'117443','printshop','sort_pos_7','10',0,''),(363240,115552,'117443','printshop','sort_pos_2','11',0,''),(363241,115552,'117443','printshop','sort_pos_1','12',0,''),(363242,115552,'117443','printshop','sort_pos_6','13',0,''),(363243,115552,'117443','printshop','sort_pos_5','14',0,''),(363244,115552,'117443','printshop','sort_pos_0','15',0,''),(363245,115552,'117443','printshop','sort_hide_10','1',0,''),(363246,115552,'117443','printshop','sort_hide_9','1',0,''),(363247,115552,'117443','printshop','hide_icons','1',0,''),(363248,115552,'117443','printshop','sort_hide_16','1',0,''),(363249,115552,'117443','printshop','sort_hide_15','1',0,''),(363250,115552,'117443','printshop','sort_hide_3','0',0,''),(363251,115552,'117443','printshop','sort_hide_4','0',0,''),(363252,115552,'117443','printshop','sort_hide_11','1',0,''),(363253,115552,'117443','printshop','sort_hide_12','1',0,''),(363254,115552,'117443','printshop','sort_hide_14','1',0,''),(363255,115552,'117443','printshop','sort_hide_13','1',0,''),(363256,115552,'117443','printshop','sort_hide_8','0',0,''),(363257,115552,'117443','printshop','sort_hide_7','0',0,''),(363258,115552,'117443','printshop','sort_hide_2','1',0,''),(363259,115552,'117443','printshop','sort_hide_1','1',0,''),(363260,115552,'117443','printshop','sort_hide_6','1',0,''),(363261,115552,'117443','printshop','sort_hide_5','1',0,''),(363262,115552,'117443','printshop','sort_hide_0','1',0,''),(363263,115553,'117444','printshop','block_type','1',0,''),(363264,115554,'117445','printshop','margin-bottom','30',0,''),(363265,115555,'117446','printshop','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(363266,115556,'117447','printshop','block_type','1',0,''),(363267,115557,'117448','printshop','block_type','5',0,''),(363268,115557,'117448','printshop','padding-top','10',0,''),(363269,115557,'117448','printshop','padding-bottom','10',0,''),(363270,115557,'117448','printshop','schema','5-2',0,'5363'),(363271,115557,'117448','printshop','border-top-color','$content-border-3',0,''),(363272,115557,'117448','printshop','border-top-width','1',0,''),(363273,115558,'117449','printshop','padding-top','3',0,''),(363274,115559,'117450','printshop','float','right',0,''),(363275,115559,'117450','printshop','height','31',0,''),(363276,115560,'117451','printshop','col_in_row','2',0,''),(363277,115560,'117451','printshop','products_align','left',0,''),(363278,115560,'117451','printshop','font-weight','400',0,''),(363279,115560,'117451','printshop','listing_type','productListing',0,''),(363280,115560,'117451','printshop','listing_type_rows','Rows',0,''),(363281,115560,'117451','printshop','show_buy_button_b2b','on',0,''),(363282,115560,'117451','printshop','show_wishlist_button_b2b','1',0,''),(363283,115560,'117451','printshop','show_compare_b2b','1',0,''),(363284,115560,'117451','printshop','show_image','0',0,''),(363285,115560,'117451','printshop','show_stock','0',0,''),(363286,115560,'117451','printshop','show_description','0',0,''),(363287,115560,'117451','printshop','show_model','0',0,''),(363288,115560,'117451','printshop','show_properties','0',0,''),(363289,115560,'117451','printshop','show_rating','0',0,''),(363290,115560,'117451','printshop','show_rating_counts','0',0,''),(363291,115560,'117451','printshop','show_price','0',0,''),(363292,115560,'117451','printshop','show_buy_button','0',0,''),(363293,115560,'117451','printshop','show_view_button','0',0,''),(363294,115560,'117451','printshop','show_wishlist_button','0',0,''),(363295,115560,'117451','printshop','show_compare','0',0,''),(363296,115560,'117451','printshop','show_name_rows','0',0,''),(363297,115560,'117451','printshop','show_image_rows','0',0,''),(363298,115560,'117451','printshop','show_stock_rows','0',0,''),(363299,115560,'117451','printshop','show_description_rows','0',0,''),(363300,115560,'117451','printshop','show_model_rows','0',0,''),(363301,115560,'117451','printshop','show_properties_rows','0',0,''),(363302,115560,'117451','printshop','show_rating_rows','0',0,''),(363303,115560,'117451','printshop','show_rating_counts_rows','0',0,''),(363304,115560,'117451','printshop','show_price_rows','0',0,''),(363305,115560,'117451','printshop','show_buy_button_rows','0',0,''),(363306,115560,'117451','printshop','show_qty_input_rows','0',0,''),(363307,115560,'117451','printshop','show_view_button_rows','0',0,''),(363308,115560,'117451','printshop','show_wishlist_button_rows','0',0,''),(363309,115560,'117451','printshop','show_compare_rows','0',0,''),(363310,115560,'117451','printshop','show_name_b2b','0',0,''),(363311,115560,'117451','printshop','show_image_b2b','0',0,''),(363312,115560,'117451','printshop','show_stock_b2b','0',0,''),(363313,115560,'117451','printshop','show_description_b2b','0',0,''),(363314,115560,'117451','printshop','show_model_b2b','0',0,''),(363315,115560,'117451','printshop','show_properties_b2b','0',0,''),(363316,115560,'117451','printshop','show_rating_b2b','0',0,''),(363317,115560,'117451','printshop','show_rating_counts_b2b','0',0,''),(363318,115560,'117451','printshop','show_price_b2b','0',0,''),(363319,115560,'117451','printshop','show_qty_input_b2b','0',0,''),(363320,115560,'117451','printshop','show_view_button_b2b','0',0,''),(363321,115560,'117451','printshop','show_attributes_b2b','0',0,''),(363322,115560,'117451','printshop','items_on_page','12',0,''),(363323,115560,'117451','printshop','col_in_row','2',0,'5342'),(363324,115560,'117451','printshop','col_in_row','1',0,'5363'),(363325,115560,'117451','printshop','product_names_teg','h2',0,''),(363326,115561,'117452','printshop','show_heading','h1',0,''),(363327,115563,'117454','printshop','block_type','1',0,''),(363328,115564,'117455','printshop','block_type','1',0,''),(363329,115564,'117455','printshop','padding-top','10',0,''),(363330,115564,'117455','printshop','padding-bottom','10',0,''),(363331,115564,'117455','printshop','margin-left','0',0,''),(363332,115564,'117455','printshop','margin-right','0',0,''),(363333,115565,'117456','printshop','clear','none',0,''),(363334,115565,'117456','printshop','float','left',0,''),(363335,115565,'117456','printshop','padding-top','3',0,''),(363336,115565,'117456','printshop','margin-left','20',0,''),(363337,115566,'117457','printshop','float','right',0,''),(363338,115566,'117457','printshop','display','none',0,'5363'),(363339,115567,'117458','printshop','margin-right','20',0,''),(363340,115567,'117458','printshop','float','right',0,''),(363341,115567,'117458','printshop','clear','none',0,''),(363342,115567,'117458','printshop','display','none',0,'5342'),(363343,115568,'117459','printshop','float','left',0,''),(363344,115568,'117459','printshop','clear','none',0,''),(363345,115568,'117459','printshop','margin-left','20',0,''),(363346,115568,'117459','printshop','display','none',0,'5363'),(363347,115569,'117460','printshop','float','left',0,''),(363348,115569,'117460','printshop','clear','none',0,''),(363349,115569,'117460','printshop','sort_pos_3','2',0,''),(363350,115569,'117460','printshop','sort_pos_4','3',0,''),(363351,115569,'117460','printshop','sort_pos_10','11',0,''),(363352,115569,'117460','printshop','sort_pos_9','10',0,''),(363353,115569,'117460','printshop','sort_pos_11','12',0,''),(363354,115569,'117460','printshop','sort_pos_12','13',0,''),(363355,115569,'117460','printshop','sort_pos_14','15',0,''),(363356,115569,'117460','printshop','sort_pos_13','14',0,''),(363357,115569,'117460','printshop','sort_pos_8','4',0,''),(363358,115569,'117460','printshop','sort_pos_7','5',0,''),(363359,115569,'117460','printshop','sort_pos_2','7',0,''),(363360,115569,'117460','printshop','sort_pos_1','6',0,''),(363361,115569,'117460','printshop','sort_pos_6','9',0,''),(363362,115569,'117460','printshop','sort_pos_5','8',0,''),(363363,115569,'117460','printshop','sort_pos_0','1',0,''),(363364,115569,'117460','printshop','sort_hide_10','1',0,''),(363365,115569,'117460','printshop','sort_hide_9','1',0,''),(363366,115569,'117460','printshop','sort_pos_15','16',0,''),(363367,115569,'117460','printshop','sort_pos_16','17',0,''),(363368,115569,'117460','printshop','sort_hide_4','0',0,''),(363369,115569,'117460','printshop','sort_hide_3','0',0,''),(363370,115569,'117460','printshop','sort_hide_16','1',0,''),(363371,115569,'117460','printshop','sort_hide_15','1',0,''),(363372,115569,'117460','printshop','sort_hide_11','1',0,''),(363373,115569,'117460','printshop','sort_hide_12','1',0,''),(363374,115569,'117460','printshop','sort_hide_14','1',0,''),(363375,115569,'117460','printshop','sort_hide_13','1',0,''),(363376,115569,'117460','printshop','sort_hide_8','0',0,''),(363377,115569,'117460','printshop','sort_hide_7','0',0,''),(363378,115569,'117460','printshop','sort_hide_2','1',0,''),(363379,115569,'117460','printshop','sort_hide_1','1',0,''),(363380,115569,'117460','printshop','sort_hide_6','1',0,''),(363381,115569,'117460','printshop','sort_hide_5','1',0,''),(363382,115569,'117460','printshop','sort_hide_0','0',0,''),(363383,115569,'117460','printshop','hide_icons','1',0,''),(363384,115570,'117461','printshop','margin-bottom','20',0,''),(363385,115571,'1645199275.381','printshop','block_type','1',0,''),(363386,115571,'1645199275.381','printshop','background-color','$content-bg-2',0,''),(363387,115571,'1645199275.381','printshop','padding-top','10',0,''),(363388,115571,'1645199275.381','printshop','padding-bottom','10',0,''),(363389,115571,'1645199275.381','printshop','color','$content-color-2',0,''),(363390,115573,'117462','printshop','block_type','1',0,''),(363391,115573,'117462','printshop','style_class','account-order-history',0,''),(363463,115597,'117467','printshop','block_type','1',0,''),(363464,115597,'117467','printshop','style_class','account-order-history-info',0,''),(363601,115656,'117507','printshop','block_type','1',0,''),(363602,115656,'117507','printshop','style_class','account-order-pay',0,''),(363603,115657,'117508','printshop','block_type','6',0,''),(363604,115657,'117508','printshop','schema','6-3',0,'5342'),(363605,115658,'117509','printshop','aria_name','account-menu',0,''),(363668,115679,'117511','printshop','block_type','3',0,''),(363669,115680,'117512','printshop','block_type','1',0,''),(363670,115680,'117512','printshop','padding-right','20',0,''),(363671,115680,'117512','printshop','padding-bottom','20',0,''),(363672,115681,'117513','printshop','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(363673,115682,'117514','printshop','orders_data','name',0,''),(363674,115682,'117514','printshop','padding-left','30',0,''),(363675,115683,'117515','printshop','block_type','1',0,''),(363676,115684,'117516','printshop','padding-left','30',0,''),(363677,115685,'117517','printshop','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(363678,115686,'117518','printshop','block_type','1',0,''),(363679,115686,'117518','printshop','padding-right','20',0,''),(363680,115686,'117518','printshop','padding-bottom','20',0,''),(363681,115687,'117519','printshop','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(363682,115688,'117520','printshop','orders_data','delivery_address',0,''),(363683,115688,'117520','printshop','padding-left','30',0,''),(363684,115689,'117521','printshop','block_type','1',0,''),(363685,115689,'117521','printshop','padding-right','20',0,''),(363686,115690,'117522','printshop','orders_data','shipping_method',0,''),(363687,115690,'117522','printshop','padding-left','30',0,''),(363688,115691,'117523','printshop','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(363689,115692,'117524','printshop','block_type','1',0,''),(363690,115693,'117525','printshop','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(363691,115694,'117526','printshop','orders_data','payment_method',0,''),(363692,115694,'117526','printshop','padding-left','30',0,''),(363693,115695,'117527','printshop','block_type','1',0,''),(363694,115695,'117527','printshop','padding-bottom','20',0,''),(363695,115696,'117528','printshop','orders_data','billing_address',0,''),(363696,115696,'117528','printshop','padding-left','30',0,''),(363697,115697,'117529','printshop','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(363698,115698,'117530','printshop','margin-bottom','20',0,''),(363699,115698,'117530','printshop','orders_data','name',0,''),(363700,115699,'117531','printshop','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(363701,115702,'117534','printshop','width','680',0,''),(363702,115702,'117534','printshop','font-weight','400',0,''),(363703,115702,'117534','printshop','font-size','12',0,''),(363704,115702,'117534','printshop','padding-top','20',0,''),(363705,115702,'117534','printshop','padding-bottom','20',0,''),(363706,115703,'117535','printshop','block_type','2',0,''),(363707,115703,'117535','printshop','font-weight','normal',0,''),(363708,115703,'117535','printshop','padding-bottom','20',0,''),(363709,115704,'117536','printshop','font-weight','400',0,''),(363710,115704,'117536','printshop','padding-top','10',0,''),(363711,115704,'117536','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',1,''),(363712,115704,'117536','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',2,''),(363713,115704,'117536','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',3,''),(363714,115704,'117536','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',4,''),(363715,115705,'117537','printshop','block_type','11',0,''),(363716,115705,'117537','printshop','font-weight','normal',0,''),(363717,115706,'117538','printshop','text','<p>Email:</p>',1,''),(363718,115706,'117538','printshop','font-weight','normal',0,''),(363719,115706,'117538','printshop','text-align','right',0,''),(363720,115706,'117538','printshop','text','<p>Email:</p>',2,''),(363721,115706,'117538','printshop','text','<p>Email:</p>',3,''),(363722,115706,'117538','printshop','text','<p>Email:</p>',4,''),(363723,115707,'117539','printshop','font-weight','normal',0,''),(363724,115707,'117539','printshop','text-align','right',0,''),(363725,115708,'117540','printshop','block_type','11',0,''),(363726,115708,'117540','printshop','font-weight','normal',0,''),(363727,115709,'117541','printshop','text','<p>Phone:</p>',1,''),(363728,115709,'117541','printshop','font-weight','normal',0,''),(363729,115709,'117541','printshop','text-align','right',0,''),(363730,115709,'117541','printshop','text','<p>Phone:</p>',2,''),(363731,115709,'117541','printshop','text','<p>Phone:</p>',3,''),(363732,115709,'117541','printshop','text','<p>Phone:</p>',4,''),(363733,115710,'117542','printshop','font-weight','normal',0,''),(363734,115710,'117542','printshop','text-align','right',0,''),(363735,115711,'117543','printshop','block_type','1',0,''),(363736,115712,'117544','printshop','font-weight','400',0,''),(363737,115712,'117544','printshop','text-align','right',0,''),(363738,115712,'117544','printshop','padding-bottom','10',0,''),(363739,115712,'117544','printshop','address_spacer',',',0,''),(363740,115712,'117544','printshop','font-size','12',0,''),(363741,115713,'117545','printshop','block_type','11',0,''),(363742,115713,'117545','printshop','font-weight','400',0,''),(363743,115714,'117546','printshop','text','<p>Web:</p>',1,''),(363744,115714,'117546','printshop','font-weight','400',0,''),(363745,115714,'117546','printshop','text-align','right',0,''),(363746,115714,'117546','printshop','text','<p>Web:</p>',2,''),(363747,115714,'117546','printshop','text','<p>Web:</p>',3,''),(363748,115714,'117546','printshop','text','<p>Web:</p>',4,''),(363749,115715,'117547','printshop','font-weight','normal',0,''),(363750,115715,'117547','printshop','text-align','right',0,''),(363751,115716,'117548','printshop','font-weight','normal',0,''),(363752,115716,'117548','printshop','padding-top','20',0,''),(363753,115716,'117548','printshop','font-size','12',0,''),(363754,115717,'117549','printshop','block_type','1',0,''),(363755,115717,'117549','printshop','font-weight','normal',0,''),(363756,115717,'117549','printshop','padding-top','10',0,''),(363757,115717,'117549','printshop','padding-bottom','10',0,''),(363758,115719,'117551','printshop','text','<p>If undelivered please return to:</p>',1,''),(363759,115719,'117551','printshop','font-weight','bold',0,''),(363760,115719,'117551','printshop','text','<p>If undelivered please return to:</p>',2,''),(363761,115719,'117551','printshop','text','<p>If undelivered please return to:</p>',3,''),(363762,115719,'117551','printshop','text','<p>If undelivered please return to:</p>',4,''),(363763,115720,'117552','printshop','block_type','4',0,''),(363764,115720,'117552','printshop','font-weight','400',0,''),(363765,115720,'117552','printshop','border-top-width','1',0,''),(363766,115720,'117552','printshop','border-top-color','$content-border-3',0,''),(363767,115720,'117552','printshop','border-left-width','1',0,''),(363768,115720,'117552','printshop','border-left-color','$content-border-3',0,''),(363769,115720,'117552','printshop','border-right-width','1',0,''),(363770,115720,'117552','printshop','border-right-color','$content-border-3',0,''),(363771,115720,'117552','printshop','border-bottom-width','1',0,''),(363772,115720,'117552','printshop','border-bottom-color','$content-border-3',0,''),(363773,115721,'117553','printshop','block_type','2',0,''),(363774,115721,'117553','printshop','font-weight','normal',0,''),(363775,115721,'117553','printshop','border-right-width','1',0,''),(363776,115721,'117553','printshop','border-right-color','$content-border-3',0,''),(363777,115722,'117554','printshop','block_type','1',0,''),(363778,115722,'117554','printshop','font-weight','normal',0,''),(363779,115722,'117554','printshop','border-right-width','1',0,''),(363780,115722,'117554','printshop','border-right-color','$content-border-3',0,''),(363781,115722,'117554','printshop','background-color','$content-bg-2',0,''),(363782,115722,'117554','printshop','padding-top','10',0,''),(363783,115722,'117554','printshop','padding-left','10',0,''),(363784,115722,'117554','printshop','padding-right','10',0,''),(363785,115722,'117554','printshop','padding-bottom','10',0,''),(363786,115723,'117555','printshop','font-size','12',0,''),(363787,115723,'117555','printshop','font-weight','normal',0,''),(363788,115724,'117556','printshop','text','<p>SHIPPING ADDRESS:</p>',1,''),(363789,115724,'117556','printshop','font-size','13',0,''),(363790,115724,'117556','printshop','font-weight','bold',0,''),(363791,115724,'117556','printshop','padding-bottom','10',0,''),(363792,115724,'117556','printshop','text','<p>SHIPPING ADDRESS:</p>',2,''),(363793,115724,'117556','printshop','text','<p>SHIPPING ADDRESS:</p>',3,''),(363794,115724,'117556','printshop','text','<p>SHIPPING ADDRESS:</p>',4,''),(363795,115725,'117557','printshop','block_type','1',0,''),(363796,115725,'117557','printshop','font-weight','normal',0,''),(363797,115725,'117557','printshop','padding-top','10',0,''),(363798,115725,'117557','printshop','padding-left','10',0,''),(363799,115725,'117557','printshop','padding-right','10',0,''),(363800,115725,'117557','printshop','padding-bottom','10',0,''),(363801,115726,'117558','printshop','text','<p>CUSTOMER:</p>',1,''),(363802,115726,'117558','printshop','font-size','13',0,''),(363803,115726,'117558','printshop','font-weight','bold',0,''),(363804,115726,'117558','printshop','text','<p>CUSTOMER:</p>',2,''),(363805,115726,'117558','printshop','text','<p>CUSTOMER:</p>',3,''),(363806,115726,'117558','printshop','text','<p>CUSTOMER:</p>',4,''),(363807,115727,'117559','printshop','font-size','12',0,''),(363808,115729,'117561','printshop','text','<p>PHONE NUMBER:</p>',1,''),(363809,115729,'117561','printshop','font-size','13',0,''),(363810,115729,'117561','printshop','font-weight','bold',0,''),(363811,115729,'117561','printshop','padding-top','10',0,''),(363812,115729,'117561','printshop','text','<p>PHONE NUMBER:</p>',2,''),(363813,115729,'117561','printshop','text','<p>PHONE NUMBER:</p>',3,''),(363814,115729,'117561','printshop','text','<p>PHONE NUMBER:</p>',4,''),(363815,115730,'117562','printshop','font-size','12',0,''),(363816,115731,'117563','printshop','text','<p>E-MAIL ADDRESS:</p>',1,''),(363817,115731,'117563','printshop','font-size','13',0,''),(363818,115731,'117563','printshop','font-weight','bold',0,''),(363819,115731,'117563','printshop','padding-top','10',0,''),(363820,115731,'117563','printshop','text','<p>E-MAIL ADDRESS:</p>',2,''),(363821,115731,'117563','printshop','text','<p>E-MAIL ADDRESS:</p>',3,''),(363822,115731,'117563','printshop','text','<p>E-MAIL ADDRESS:</p>',4,''),(363823,115732,'117564','printshop','block_type','2',0,''),(363824,115732,'117564','printshop','font-weight','normal',0,''),(363825,115732,'117564','printshop','border-right-width','1',0,''),(363826,115732,'117564','printshop','border-right-color','$content-border-3',0,''),(363827,115732,'117564','printshop','border-top-width','1',0,''),(363828,115732,'117564','printshop','border-top-color','$content-border-3',0,''),(363829,115733,'117565','printshop','block_type','1',0,''),(363830,115733,'117565','printshop','font-weight','normal',0,''),(363831,115733,'117565','printshop','padding-top','10',0,''),(363832,115733,'117565','printshop','padding-left','10',0,''),(363833,115733,'117565','printshop','padding-right','10',0,''),(363834,115733,'117565','printshop','padding-bottom','10',0,''),(363835,115733,'117565','printshop','border-right-width','1',0,''),(363836,115733,'117565','printshop','border-right-color','$content-border-3',0,''),(363837,115735,'117567','printshop','text','<p>Shipping via</p>',1,''),(363838,115735,'117567','printshop','font-weight','bold',0,''),(363839,115735,'117567','printshop','text','<p>Shipping via</p>',2,''),(363840,115735,'117567','printshop','text','<p>Shipping via</p>',3,''),(363841,115735,'117567','printshop','text','<p>Shipping via</p>',4,''),(363842,115736,'117568','printshop','block_type','1',0,''),(363843,115736,'117568','printshop','font-weight','normal',0,''),(363844,115736,'117568','printshop','padding-top','10',0,''),(363845,115736,'117568','printshop','padding-left','10',0,''),(363846,115736,'117568','printshop','padding-right','10',0,''),(363847,115736,'117568','printshop','padding-bottom','10',0,''),(363848,115738,'117570','printshop','text','<p>Shipping service</p>',1,''),(363849,115738,'117570','printshop','font-weight','bold',0,''),(363850,115738,'117570','printshop','text','<p>Shipping service</p>',2,''),(363851,115738,'117570','printshop','text','<p>Shipping service</p>',3,''),(363852,115738,'117570','printshop','text','<p>Shipping service</p>',4,''),(363853,115739,'117571','printshop','font-weight','normal',0,''),(363854,115739,'117571','printshop','text-align','center',0,''),(363855,115739,'117571','printshop','padding-top','40',0,''),(363856,115741,'1639661081.5616','printshop','padding-top','15',0,''),(363857,115742,'117572','printshop','block_type','1',0,''),(363858,115743,'117573','printshop','block_type','1',0,''),(363859,115744,'1638807246.6206','printshop','text','<span></span>',0,''),(363860,115745,'117574','printshop','text','##TEXT_MAIN##',0,''),(363861,115745,'117574','printshop','margin-bottom','20',0,''),(363862,115745,'117574','printshop','text-align','center',0,''),(363863,115746,'117575','printshop','margin-bottom','20',0,''),(363864,115747,'117576','printshop','text','<h1>##HEADING_TITLE##</h1>',0,''),(363865,115749,'117578','printshop','block_type','2',0,''),(363866,115750,'117579','printshop','block_type','1',0,''),(363867,115750,'117579','printshop','style_class','product',0,''),(363868,115750,'117579','printshop','padding-right','10',0,''),(363869,115750,'117579','printshop','padding-bottom','20',0,''),(363870,115751,'117580','printshop','block_type','1',0,''),(363871,115752,'117581','printshop','product_element','products_name',0,''),(363872,115752,'117581','printshop','font-family','$font-1',0,''),(363873,115752,'117581','printshop','padding-bottom','10',0,''),(363874,115752,'117581','printshop','font-size','16',0,''),(363875,115753,'117582','printshop','block_type','2',0,''),(363876,115754,'117583','printshop','product_element','image',0,''),(363877,115754,'117583','printshop','padding-right','10',0,''),(363878,115755,'117584','printshop','product_element','products_price_old',0,''),(363879,115755,'117584','printshop','font-family','$font-1',0,''),(363880,115755,'117584','printshop','font-size','14',0,''),(363881,115755,'117584','printshop','text-decoration','line-through',0,''),(363882,115756,'117585','printshop','product_element','products_price',0,''),(363883,115756,'117585','printshop','font-family','$font-1',0,''),(363884,115756,'117585','printshop','font-size','20',0,''),(363885,115756,'117585','printshop','padding-top','20',0,''),(363886,115757,'117586','printshop','block_type','1',0,''),(363887,115757,'117586','printshop','style_class','product',0,''),(363888,115757,'117586','printshop','padding-left','10',0,''),(363889,115757,'117586','printshop','padding-bottom','20',0,''),(363890,115758,'117587','printshop','block_type','2',0,''),(363891,115759,'117588','printshop','product_element','image',0,''),(363892,115759,'117588','printshop','padding-right','10',0,''),(363893,115760,'117589','printshop','font-size','14',0,''),(363894,115760,'117589','printshop','font-family','$font-1',0,''),(363895,115760,'117589','printshop','text-decoration','line-through',0,''),(363896,115760,'117589','printshop','product_element','products_price_old',0,''),(363897,115761,'117590','printshop','product_element','products_price',0,''),(363898,115761,'117590','printshop','font-family','$font-1',0,''),(363899,115761,'117590','printshop','font-size','20',0,''),(363900,115761,'117590','printshop','padding-top','20',0,''),(363901,115762,'117591','printshop','block_type','1',0,''),(363902,115763,'117592','printshop','product_element','products_name',0,''),(363903,115763,'117592','printshop','font-family','$font-1',0,''),(363904,115763,'117592','printshop','font-size','16',0,''),(363905,115763,'117592','printshop','padding-bottom','10',0,''),(363906,115764,'117593','printshop','font-size','30',0,''),(363907,115764,'117593','printshop','font-family','$font-1',0,''),(363908,115764,'117593','printshop','text-align','center',0,''),(363909,115764,'117593','printshop','padding-bottom','50',0,''),(363910,115765,'117594','printshop','padding-bottom','20',0,''),(363911,115765,'117594','printshop','text-align','center',0,''),(363912,115766,'117595','printshop','width','680',0,''),(363913,115767,'117596','printshop','padding-top','200',0,''),(363914,115767,'117596','printshop','padding-left','200',0,''),(363915,115767,'117596','printshop','logo','themes/printshop/img/themes/printshop/img/oscommerce_logo.jpg',1,''),(363916,115767,'117596','printshop','logo','themes/printshop/img/themes/printshop/img/oscommerce_logo.jpg',2,''),(363917,115767,'117596','printshop','logo','themes/printshop/img/themes/printshop/img/oscommerce_logo.jpg',3,''),(363918,115767,'117596','printshop','logo','themes/printshop/img/themes/printshop/img/oscommerce_logo.jpg',4,''),(363919,115768,'117597','printshop','text','osCommerce 4',1,''),(363920,115768,'117597','printshop','font-family','$font-1',0,''),(363921,115768,'117597','printshop','font-size','40',0,''),(363922,115768,'117597','printshop','padding-top','50',0,''),(363923,115768,'117597','printshop','text-align','center',0,''),(363924,115768,'117597','printshop','text','osCommerce 4',2,''),(363925,115768,'117597','printshop','text','osCommerce 4',3,''),(363926,115768,'117597','printshop','text','osCommerce 4',4,''),(363927,115769,'117598','printshop','block_type','2',0,''),(363928,115769,'117598','printshop','border-top-width','1',0,''),(363929,115769,'117598','printshop','border-top-color','$content-border-3',0,''),(363930,115770,'117599','printshop','text-align','right',0,''),(363931,115770,'117599','printshop','padding-top','15',0,''),(363932,115770,'117599','printshop','padding-bottom','15',0,''),(363933,115770,'117599','printshop','font-size','14',0,''),(363934,115771,'117600','printshop','font-family','$font-1',0,''),(363935,115771,'117600','printshop','text-align','center',0,''),(363936,115771,'117600','printshop','font-size','20',0,''),(363937,115771,'117600','printshop','color','$content-color-1',0,''),(363938,115771,'117600','printshop','border-bottom-width','1',0,''),(363939,115771,'117600','printshop','border-bottom-color','$content-border-3',0,''),(363940,115771,'117600','printshop','padding-top','10',0,''),(363941,115771,'117600','printshop','padding-bottom','10',0,''),(363942,115772,'117601','printshop','block_type','1',0,''),(363943,115773,'117602','printshop','block_type','6',0,''),(363944,115773,'117602','printshop','schema','6-3',0,'5342'),(363945,115774,'117603','printshop','aria_name','account-menu',0,''),(364008,115794,'117606','printshop','max_items','10',0,''),(364009,115794,'117606','printshop','padding-bottom','20',0,''),(364010,115795,'117604','printshop','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(364011,115796,'117607','printshop','block_type','1',0,''),(364012,115796,'117607','printshop','padding-top','20',0,''),(364013,115796,'117607','printshop','padding-left','20',0,''),(364014,115796,'117607','printshop','padding-right','20',0,''),(364015,115796,'117607','printshop','padding-bottom','20',0,''),(364016,115797,'117608','printshop','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(364017,115799,'117610','printshop','block_type','1',0,''),(364018,115800,'117611','printshop','margin_left_measure','auto',0,''),(364019,115800,'117611','printshop','margin_right_measure','auto',0,''),(364020,115800,'117611','printshop','max-width','560',0,''),(364021,115801,'117612','printshop','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(364022,115802,'117613','printshop','margin-bottom','30',0,''),(364023,115803,'1639053523.9657','printshop','block_type','1',0,''),(364024,115803,'1639053523.9657','printshop','background-color','$content-bg-2',0,''),(364025,115803,'1639053523.9657','printshop','padding-top','25',0,''),(364026,115803,'1639053523.9657','printshop','padding-bottom','25',0,''),(364027,115803,'1639053523.9657','printshop','color','$content-color-2',0,''),(364028,115804,'1638963486.2331','printshop','background-color','$content-bg-1',0,''),(364029,115804,'1638963486.2331','printshop','padding-top','20',0,''),(364030,115804,'1638963486.2331','printshop','padding-left','20',0,''),(364031,115804,'1638963486.2331','printshop','padding-right','20',0,''),(364032,115804,'1638963486.2331','printshop','padding-bottom','20',0,''),(364033,115804,'1638963486.2331','printshop','color','$content-color-1',0,''),(364034,115805,'1639659357.0881','printshop','block_type','1',0,''),(364035,115805,'1639659357.0881','printshop','background-color','$content-bg-1',0,''),(364036,115805,'1639659357.0881','printshop','padding-top','20',0,''),(364037,115805,'1639659357.0881','printshop','padding-left','20',0,''),(364038,115805,'1639659357.0881','printshop','padding-right','20',0,''),(364039,115805,'1639659357.0881','printshop','padding-bottom','20',0,''),(364040,115805,'1639659357.0881','printshop','margin-bottom','20',0,''),(364041,115805,'1639659357.0881','printshop','color','$content-color-1',0,''),(364042,115806,'1639659044.5523','printshop','count_products','4',0,''),(364043,115806,'1639659044.5523','printshop','view_as','carousel',0,''),(364044,115806,'1639659044.5523','printshop','col_in_row','4',0,''),(364045,115806,'1639659044.5523','printshop','listing_type','productListing',0,''),(364046,115806,'1639659044.5523','printshop','col_in_row','3',0,'5342'),(364047,115806,'1639659044.5523','printshop','col_in_row','2',0,'5333'),(364048,115806,'1639659044.5523','printshop','col_in_row','1',0,'5363'),(364049,115807,'1644421585.0243','printshop','block_type','1',0,''),(364050,115807,'1644421585.0243','printshop','padding-top','10',0,''),(364051,115807,'1644421585.0243','printshop','padding-bottom','10',0,''),(364052,115807,'1644421585.0243','printshop','background-color','$content-bg-2',0,''),(364053,115807,'1644421585.0243','printshop','color','$content-color-2',0,''),(364054,115808,'117644','printshop','font-weight','normal',0,''),(364055,115808,'117644','printshop','box_align','4',0,''),(364056,115809,'1683120066.375199','printshop','block_type','1',0,''),(364057,115810,'1683120066.40840','printshop','block_type','5',0,''),(364058,115810,'1683120066.40840','printshop','font-weight','400',0,''),(364059,115810,'1683120066.40840','printshop','padding-bottom','20',0,''),(364060,115810,'1683120066.40840','printshop','schema','2-2',0,'5363'),(364061,115810,'1683120066.40840','printshop','schema','2-2',0,'5342'),(364062,115810,'1683120066.40840','printshop','padding-bottom','0',0,'5342'),(364063,115811,'1683120066.411537','printshop','font-weight','400',0,''),(364064,115811,'1683120066.411537','printshop','padding-top','20',0,''),(364065,115811,'1683120066.411537','printshop','padding-right','20',0,''),(364066,115811,'1683120066.411537','printshop','box_align','4',0,''),(364067,115811,'1683120066.411537','printshop','margin-bottom','10',0,''),(364068,115811,'1683120066.411537','printshop','align_position','horizontal',0,''),(364069,115812,'1683120066.412741','printshop','float','left',0,''),(364070,115813,'1683120066.41444','printshop','padding-bottom','20',0,''),(364071,115814,'1696601788.1354','printshop','block_type','1',0,''),(364072,115814,'1696601788.1354','printshop','padding-left','30',0,''),(364073,115814,'1696601788.1354','printshop','padding-left','0',0,'5342'),(364074,115815,'1683120066.4157','printshop','block_type','2',0,''),(364075,115815,'1683120066.4157','printshop','schema','2-2',0,'5347'),(364076,115816,'1683120066.416580','printshop','margin-bottom','20',0,''),(364077,115816,'1683120066.416580','printshop','max-width','500',0,''),(364078,115817,'1683120066.417385','printshop','block_type','1',0,''),(364079,115817,'1683120066.417385','printshop','padding-right','9',0,''),(364080,115817,'1683120066.417385','printshop','padding-right','0',0,'5347'),(364081,115818,'1683120066.41899','printshop','padding-bottom','20',0,''),(364082,115819,'1683120066.41955','printshop','cat_description','on',0,''),(364083,115819,'1683120066.41955','printshop','length_description','250',0,''),(364084,115819,'1683120066.41955','printshop','padding-bottom','7',0,''),(364085,115819,'1683120066.41955','printshop','link_description','1',0,''),(364086,115819,'1683120066.41955','printshop','border-bottom-width','1',0,''),(364087,115819,'1683120066.41955','printshop','border-bottom-color','$content-border-3',0,''),(364088,115819,'1683120066.41955','printshop','margin-bottom','20',0,''),(364089,115820,'1683120066.42249','printshop','margin-bottom','20',0,''),(364090,115823,'1683120066.432243','printshop','block_type','1',0,''),(364091,115823,'1683120066.432243','printshop','padding-left','9',0,''),(364092,115823,'1683120066.432243','printshop','margin-top','20',0,'5347'),(364093,115823,'1683120066.432243','printshop','padding-left','0',0,'5347'),(364094,115824,'1683120066.43441','printshop','block_type','1',0,''),(364095,115824,'1683120066.43441','printshop','style_class','productNavigation',0,''),(364096,115824,'1683120066.43441','printshop','border-top-width','1',0,''),(364097,115824,'1683120066.43441','printshop','border-left-width','1',0,''),(364098,115824,'1683120066.43441','printshop','border-right-width','1',0,''),(364099,115824,'1683120066.43441','printshop','border-bottom-width','1',0,''),(364100,115824,'1683120066.43441','printshop','border-top-color','$content-border-3',0,''),(364101,115824,'1683120066.43441','printshop','border-left-color','$content-border-3',0,''),(364102,115824,'1683120066.43441','printshop','border-right-color','$content-border-3',0,''),(364103,115824,'1683120066.43441','printshop','border-bottom-color','$content-border-3',0,''),(364104,115825,'1683120066.437271','printshop','padding-top','15',0,''),(364105,115825,'1683120066.437271','printshop','padding-left','20',0,''),(364106,115825,'1683120066.437271','printshop','padding-right','20',0,''),(364107,115825,'1683120066.437271','printshop','padding-bottom','20',0,''),(364108,115825,'1683120066.437271','printshop','border-bottom-width','1',0,''),(364109,115825,'1683120066.437271','printshop','border-bottom-color','$content-border-3',0,''),(364110,115826,'1683120066.450387','printshop','block_type','1',0,''),(364111,115826,'1683120066.450387','printshop','padding-top','20',0,''),(364112,115826,'1683120066.450387','printshop','padding-left','20',0,''),(364113,115826,'1683120066.450387','printshop','padding-right','20',0,''),(364114,115826,'1683120066.450387','printshop','padding-bottom','20',0,''),(364115,115827,'1683120066.452834','printshop','margin-bottom','20',0,''),(364116,115828,'1683120066.454686','printshop','text-align','left',0,''),(364117,115828,'1683120066.454686','printshop','text-align','center',0,'5363'),(364118,115829,'1683120066.458637','printshop','block_type','1',0,''),(364119,115829,'1683120066.458637','printshop','schema','2-3',0,'5363'),(364120,115830,'1683120066.460688','printshop','font-size','36',0,''),(364121,115830,'1683120066.460688','printshop','font-weight','400',0,''),(364122,115830,'1683120066.460688','printshop','line-height','35',0,''),(364123,115830,'1683120066.460688','printshop','font-family','$font-1',0,''),(364124,115830,'1683120066.460688','printshop','line_height_measure','px',0,''),(364125,115830,'1683120066.460688','printshop','padding-top','5',0,''),(364126,115830,'1683120066.460688','printshop','text-align','left',0,''),(364127,115830,'1683120066.460688','printshop','padding-bottom','15',0,''),(364128,115830,'1683120066.460688','printshop','text-align','center',0,'5363'),(364129,115830,'1683120066.460688','printshop','float','left',0,''),(364130,115831,'1683120066.46336','printshop','padding-bottom','10',0,''),(364131,115831,'1683120066.46336','printshop','text-align','center',0,'5363'),(364132,115831,'1683120066.46336','printshop','text-align','right',0,''),(364133,115831,'1683120066.46336','printshop','float','right',0,''),(364134,115832,'1683120066.465283','printshop','block_type','2',0,''),(364135,115832,'1683120066.465283','printshop','schema','2-3',0,'5363'),(364136,115833,'1683120066.468523','printshop','width','100',0,'5333'),(364137,115833,'1683120066.468523','printshop','width_measure','%',0,'5333'),(364138,115833,'1683120066.468523','printshop','float','none',0,'5333'),(364139,115833,'1683120066.468523','printshop','hide_additional_buttons','1',0,''),(364140,115833,'1683120066.468523','printshop','margin-bottom','15',0,''),(364141,115833,'1683120066.468523','printshop','text-align','center',0,'5363'),(364142,115834,'1683120066.472391','printshop','box_align','4',0,''),(364143,115834,'1683120066.472391','printshop','margin-bottom','15',0,'5342'),(364144,115834,'1683120066.472391','printshop','text-align','right',0,'5342'),(364145,115834,'1683120066.472391','printshop','margin-bottom','25',0,''),(364146,115834,'1683120066.472391','printshop','text-align','center',0,'5363'),(364147,115835,'1683120066.480552','printshop','block_type','2',0,''),(364148,115835,'1683120066.480552','printshop','schema','2-2',0,'5363'),(364149,115836,'1683120066.48186','printshop','text-align','left',0,''),(364150,115836,'1683120066.48186','printshop','margin-bottom','10',0,''),(364151,115836,'1683120066.48186','printshop','text-align','center',0,'5363'),(364152,115837,'1683120066.483821','printshop','text-align','left',0,''),(364153,115837,'1683120066.483821','printshop','margin-bottom','10',0,''),(364154,115837,'1683120066.483821','printshop','text-align','center',0,'5363'),(364155,115838,'1683120066.485594','printshop','margin-bottom','15',0,''),(364156,115838,'1683120066.485594','printshop','padding-top','15',0,''),(364157,115839,'1683120066.488481','printshop','font-weight','400',0,''),(364158,115839,'1683120066.488481','printshop','show_heading','h1',0,''),(364159,115840,'1683120066.489437','printshop','block_type','1',0,''),(364160,115841,'1683120066.490651','printshop','font-weight','normal',0,''),(364161,115841,'1683120066.490651','printshop','padding-bottom','20',0,''),(364162,115843,'1683120087.08448','printshop','block_type','1',0,''),(364163,115843,'1683120087.08448','printshop','padding-top','25',0,''),(364164,115843,'1683120087.08448','printshop','padding-bottom','25',0,''),(364165,115843,'1683120087.08448','printshop','style_class','catalog-product-wrap',0,''),(364166,115844,'1683120087.116193','printshop','block_type','1',0,''),(364167,115845,'1683120087.118690','printshop','tab_1','##TEXT_PRODUCT_OVERVIEW##',1,''),(364168,115845,'1683120087.118690','printshop','tab_2','##TEXT_DELIVERY_AND_RETURNS##',1,''),(364169,115845,'1683120087.118690','printshop','font-weight','400',0,''),(364170,115845,'1683120087.118690','printshop','tab_3','##TEXT_ASSEMBLY##',1,''),(364171,115845,'1683120087.118690','printshop','tab_1','##TEXT_PRODUCT_OVERVIEW##',2,''),(364172,115845,'1683120087.118690','printshop','tab_2','##TEXT_DELIVERY_AND_RETURNS##',2,''),(364173,115845,'1683120087.118690','printshop','tab_3','##TEXT_ASSEMBLY##',2,''),(364174,115845,'1683120087.118690','printshop','tab_1','##TEXT_PRODUCT_OVERVIEW##',3,''),(364175,115845,'1683120087.118690','printshop','tab_2','##TEXT_DELIVERY_AND_RETURNS##',3,''),(364176,115845,'1683120087.118690','printshop','tab_3','##TEXT_ASSEMBLY##',3,''),(364177,115845,'1683120087.118690','printshop','tab_1','##TEXT_PRODUCT_OVERVIEW##',4,''),(364178,115845,'1683120087.118690','printshop','tab_2','##TEXT_DELIVERY_AND_RETURNS##',4,''),(364179,115845,'1683120087.118690','printshop','tab_3','##TEXT_ASSEMBLY##',4,''),(364180,115846,'1683120087.12923','printshop','hTagsInline','block',0,''),(364181,115847,'1683120087.13141','printshop','info_page','42',0,''),(364182,115849,'1683120087.14498','printshop','tab_1','##TEXT_CUSTOMER_ALSO_BOUGHT##',0,''),(364183,115849,'1683120087.14498','printshop','tab_2','##TEXT_YOU_RECENTLY_VIEWED##',0,''),(364184,115849,'1683120087.14498','printshop','margin-bottom','20',0,''),(364185,115850,'1683120087.145578','printshop','font-weight','400',0,''),(364186,115850,'1683120087.145578','printshop','padding-bottom','20',0,''),(364187,115850,'1683120087.145578','printshop','show_qty_input','1',0,''),(364188,115850,'1683120087.145578','printshop','show_compare','1',0,''),(364189,115850,'1683120087.145578','printshop','listing_type','productListing',0,''),(364190,115850,'1683120087.145578','printshop','view_as','carousel',0,''),(364191,115850,'1683120087.145578','printshop','show_name','0',0,''),(364192,115850,'1683120087.145578','printshop','show_image','0',0,''),(364193,115850,'1683120087.145578','printshop','show_stock','0',0,''),(364194,115850,'1683120087.145578','printshop','show_description','0',0,''),(364195,115850,'1683120087.145578','printshop','show_model','1',0,''),(364196,115850,'1683120087.145578','printshop','show_properties','1',0,''),(364197,115850,'1683120087.145578','printshop','show_rating','0',0,''),(364198,115850,'1683120087.145578','printshop','show_rating_counts','0',0,''),(364199,115850,'1683120087.145578','printshop','show_price','0',0,''),(364200,115850,'1683120087.145578','printshop','show_buy_button','1',0,''),(364201,115850,'1683120087.145578','printshop','show_view_button','1',0,''),(364202,115850,'1683120087.145578','printshop','show_wishlist_button','1',0,''),(364203,115850,'1683120087.145578','printshop','display','none',0,'5342'),(364204,115850,'1683120087.145578','printshop','product_names_teg','h2',0,''),(364205,115850,'1683120087.145578','printshop','show_attributes','1',0,''),(364206,115850,'1683120087.145578','printshop','col_in_row','2',0,''),(364207,115850,'1683120087.145578','printshop','show_bonus_points','1',0,''),(364208,115851,'1683120087.150199','printshop','font-weight','400',0,''),(364209,115851,'1683120087.150199','printshop','padding-bottom','20',0,''),(364210,115851,'1683120087.150199','printshop','show_compare','1',0,''),(364211,115851,'1683120087.150199','printshop','show_name','0',0,''),(364212,115851,'1683120087.150199','printshop','show_image','0',0,''),(364213,115851,'1683120087.150199','printshop','show_stock','0',0,''),(364214,115851,'1683120087.150199','printshop','show_description','0',0,''),(364215,115851,'1683120087.150199','printshop','show_model','1',0,''),(364216,115851,'1683120087.150199','printshop','show_properties','1',0,''),(364217,115851,'1683120087.150199','printshop','show_rating','0',0,''),(364218,115851,'1683120087.150199','printshop','show_rating_counts','0',0,''),(364219,115851,'1683120087.150199','printshop','show_price','0',0,''),(364220,115851,'1683120087.150199','printshop','show_buy_button','1',0,''),(364221,115851,'1683120087.150199','printshop','show_view_button','1',0,''),(364222,115851,'1683120087.150199','printshop','show_wishlist_button','1',0,''),(364223,115851,'1683120087.150199','printshop','listing_type','productListing',0,''),(364224,115851,'1683120087.150199','printshop','col_in_row','2',0,'5342'),(364225,115851,'1683120087.150199','printshop','col_in_row','1',0,'5363'),(364226,115851,'1683120087.150199','printshop','col_in_row','2',0,''),(364227,115851,'1683120087.150199','printshop','view_as','carousel',0,''),(364228,115851,'1683120087.150199','printshop','show_bonus_points','1',0,''),(364229,115851,'1683120087.150199','printshop','show_qty_input','1',0,''),(364230,115851,'1683120087.150199','printshop','show_attributes','1',0,''),(364231,115852,'1683120087.154258','printshop','block_type','1',0,''),(364232,115853,'1683120087.155397','printshop','padding-bottom','10',0,''),(364233,115853,'1683120087.155397','printshop','padding-top','5',0,''),(364234,115854,'1683120087.157963','printshop','block_type','1',0,''),(364235,115854,'1683120087.157963','printshop','style_class','tripleLine',0,''),(364236,115854,'1683120087.157963','printshop','padding-top','30',0,''),(364237,115854,'1683120087.157963','printshop','padding-bottom','50',0,''),(364238,115855,'1683120087.159777','printshop','banners_group','triple-lin',0,''),(364239,115866,'117665','printshop','block_type','1',0,''),(364240,115866,'117665','printshop','style_class','item-holder',0,''),(364241,115866,'117665','printshop','padding-top','25',0,''),(364242,115866,'117665','printshop','padding-left','25',0,''),(364243,115866,'117665','printshop','padding-right','25',0,''),(364244,115866,'117665','printshop','padding-bottom','25',0,''),(364245,115866,'117665','printshop','text-align','left',0,''),(364246,115867,'120921','printshop','block_type','11',0,''),(364247,115867,'120921','printshop','style_class','item-wrapper',0,''),(364248,115867,'120921','printshop','schema','11-2',0,'5363'),(364249,115867,'120921','printshop','schema','11-2',0,'5342'),(364250,115872,'120919','printshop','block_type','1',0,''),(364251,115872,'120919','printshop','style_class','item-content',0,''),(364252,115873,'117668','printshop','description_characters','90',0,''),(364253,115874,'117675','printshop','clear','both',0,''),(364254,115875,'1644336042.3199','printshop','block_type','2',0,''),(364255,115875,'1644336042.3199','printshop','padding-bottom','5',0,''),(364256,115875,'1644336042.3199','printshop','border-bottom-width','1',0,''),(364257,115875,'1644336042.3199','printshop','border-bottom-color','$content-border-3',0,''),(364258,115875,'1644336042.3199','printshop','margin-bottom','15',0,''),(364259,115876,'117676','printshop','margin-bottom','10',0,''),(364260,115879,'1644336088.4429','printshop','block_type','2',0,''),(364261,115879,'1644336088.4429','printshop','margin-bottom','15',0,''),(364262,115880,'117673','printshop','margin-bottom','7',0,''),(364263,115882,'1644336183.1139','printshop','block_type','2',0,''),(364264,115884,'117678','printshop','block_type','1',0,''),(364265,115884,'117678','printshop','padding-bottom','30',0,''),(364266,115885,'117679','printshop','block_type','6',0,''),(364267,115885,'117679','printshop','font-weight','400',0,''),(364268,115885,'117679','printshop','schema','6-2',0,'5363'),(364269,115885,'117679','printshop','schema','6-2',0,'5342'),(364270,115886,'117680','printshop','font-weight','400',0,''),(364271,115886,'117680','printshop','padding-right','40',0,''),(364272,115886,'117680','printshop','padding-right','0',0,'5363'),(364273,115886,'117680','printshop','padding-right','0',0,'5342'),(364274,115886,'117680','printshop','margin-bottom','20',0,''),(364275,115887,'117681','printshop','margin-bottom','20',0,''),(364276,115889,'117683','printshop','block_type','1',0,''),(364277,115889,'117683','printshop','padding-top','10',0,''),(364278,115889,'117683','printshop','padding-bottom','10',0,''),(364279,115889,'117683','printshop','border-bottom-width','1',0,''),(364280,115889,'117683','printshop','border-bottom-color','$content-border-3',0,''),(364281,115889,'117683','printshop','margin-left','0',0,''),(364282,115889,'117683','printshop','margin-right','0',0,''),(364283,115890,'117684','printshop','float','left',0,''),(364284,115890,'117684','printshop','clear','none',0,''),(364285,115890,'117684','printshop','sort_pos_3','2',0,''),(364286,115890,'117684','printshop','sort_pos_4','3',0,''),(364287,115890,'117684','printshop','sort_pos_10','11',0,''),(364288,115890,'117684','printshop','sort_pos_9','10',0,''),(364289,115890,'117684','printshop','sort_pos_11','12',0,''),(364290,115890,'117684','printshop','sort_pos_12','13',0,''),(364291,115890,'117684','printshop','sort_pos_14','15',0,''),(364292,115890,'117684','printshop','sort_pos_13','14',0,''),(364293,115890,'117684','printshop','sort_pos_8','4',0,''),(364294,115890,'117684','printshop','sort_pos_7','5',0,''),(364295,115890,'117684','printshop','sort_pos_2','7',0,''),(364296,115890,'117684','printshop','sort_pos_1','6',0,''),(364297,115890,'117684','printshop','sort_pos_6','9',0,''),(364298,115890,'117684','printshop','sort_pos_5','8',0,''),(364299,115890,'117684','printshop','sort_pos_0','1',0,''),(364300,115890,'117684','printshop','sort_hide_10','1',0,''),(364301,115890,'117684','printshop','sort_hide_9','1',0,''),(364302,115890,'117684','printshop','sort_pos_15','16',0,''),(364303,115890,'117684','printshop','sort_pos_16','17',0,''),(364304,115890,'117684','printshop','sort_hide_4','0',0,''),(364305,115890,'117684','printshop','sort_hide_3','0',0,''),(364306,115890,'117684','printshop','sort_hide_16','1',0,''),(364307,115890,'117684','printshop','sort_hide_15','1',0,''),(364308,115890,'117684','printshop','sort_hide_11','1',0,''),(364309,115890,'117684','printshop','sort_hide_12','1',0,''),(364310,115890,'117684','printshop','sort_hide_14','1',0,''),(364311,115890,'117684','printshop','sort_hide_13','1',0,''),(364312,115890,'117684','printshop','sort_hide_8','0',0,''),(364313,115890,'117684','printshop','sort_hide_7','0',0,''),(364314,115890,'117684','printshop','sort_hide_2','1',0,''),(364315,115890,'117684','printshop','sort_hide_1','1',0,''),(364316,115890,'117684','printshop','sort_hide_6','1',0,''),(364317,115890,'117684','printshop','sort_hide_5','1',0,''),(364318,115890,'117684','printshop','sort_hide_0','0',0,''),(364319,115890,'117684','printshop','hide_icons','1',0,''),(364320,115891,'117685','printshop','float','right',0,''),(364321,115891,'117685','printshop','display','none',0,'5363'),(364322,115892,'117686','printshop','float','left',0,''),(364323,115892,'117686','printshop','clear','none',0,''),(364324,115892,'117686','printshop','margin-left','20',0,''),(364325,115892,'117686','printshop','display','none',0,'5363'),(364326,115892,'117686','printshop','display','none',0,'5347'),(364327,115893,'117687','printshop','margin-right','20',0,''),(364328,115893,'117687','printshop','float','right',0,''),(364329,115893,'117687','printshop','clear','none',0,''),(364330,115893,'117687','printshop','display','none',0,'5342'),(364331,115894,'117688','printshop','block_type','5',0,''),(364332,115894,'117688','printshop','padding-top','10',0,''),(364333,115894,'117688','printshop','padding-bottom','10',0,''),(364334,115894,'117688','printshop','schema','5-2',0,'5363'),(364335,115894,'117688','printshop','border-top-color','$content-border-3',0,''),(364336,115894,'117688','printshop','border-top-width','1',0,''),(364337,115895,'117689','printshop','padding-top','3',0,''),(364338,115896,'117690','printshop','float','right',0,''),(364339,115896,'117690','printshop','height','31',0,''),(364340,115897,'117691','printshop','col_in_row','2',0,''),(364341,115897,'117691','printshop','products_align','left',0,''),(364342,115897,'117691','printshop','font-weight','400',0,''),(364343,115897,'117691','printshop','listing_type','productListing',0,''),(364344,115897,'117691','printshop','listing_type_rows','Rows',0,''),(364345,115897,'117691','printshop','show_buy_button_b2b','on',0,''),(364346,115897,'117691','printshop','show_wishlist_button_b2b','1',0,''),(364347,115897,'117691','printshop','show_compare_b2b','1',0,''),(364348,115897,'117691','printshop','show_image','0',0,''),(364349,115897,'117691','printshop','show_stock','0',0,''),(364350,115897,'117691','printshop','show_description','0',0,''),(364351,115897,'117691','printshop','show_rating','0',0,''),(364352,115897,'117691','printshop','show_rating_counts','0',0,''),(364353,115897,'117691','printshop','show_price','0',0,''),(364354,115897,'117691','printshop','show_view_button','0',0,''),(364355,115897,'117691','printshop','show_wishlist_button','0',0,''),(364356,115897,'117691','printshop','show_compare','0',0,''),(364357,115897,'117691','printshop','show_name_rows','0',0,''),(364358,115897,'117691','printshop','show_image_rows','0',0,''),(364359,115897,'117691','printshop','show_stock_rows','0',0,''),(364360,115897,'117691','printshop','show_description_rows','0',0,''),(364361,115897,'117691','printshop','show_model_rows','0',0,''),(364362,115897,'117691','printshop','show_properties_rows','0',0,''),(364363,115897,'117691','printshop','show_rating_rows','0',0,''),(364364,115897,'117691','printshop','show_rating_counts_rows','0',0,''),(364365,115897,'117691','printshop','show_price_rows','0',0,''),(364366,115897,'117691','printshop','show_buy_button_rows','0',0,''),(364367,115897,'117691','printshop','show_qty_input_rows','0',0,''),(364368,115897,'117691','printshop','show_view_button_rows','0',0,''),(364369,115897,'117691','printshop','show_wishlist_button_rows','0',0,''),(364370,115897,'117691','printshop','show_compare_rows','0',0,''),(364371,115897,'117691','printshop','show_name_b2b','0',0,''),(364372,115897,'117691','printshop','show_image_b2b','0',0,''),(364373,115897,'117691','printshop','show_stock_b2b','0',0,''),(364374,115897,'117691','printshop','show_description_b2b','0',0,''),(364375,115897,'117691','printshop','show_model_b2b','0',0,''),(364376,115897,'117691','printshop','show_properties_b2b','0',0,''),(364377,115897,'117691','printshop','show_rating_b2b','0',0,''),(364378,115897,'117691','printshop','show_rating_counts_b2b','0',0,''),(364379,115897,'117691','printshop','show_price_b2b','0',0,''),(364380,115897,'117691','printshop','show_qty_input_b2b','0',0,''),(364381,115897,'117691','printshop','show_view_button_b2b','0',0,''),(364382,115897,'117691','printshop','show_attributes_b2b','0',0,''),(364383,115897,'117691','printshop','items_on_page','8',0,''),(364384,115897,'117691','printshop','col_in_row','2',0,'5342'),(364385,115897,'117691','printshop','col_in_row','1',0,'5363'),(364386,115897,'117691','printshop','product_names_teg','h2',0,''),(364387,115897,'117691','printshop','padding-top','10',0,''),(364388,115897,'117691','printshop','padding-bottom','20',0,''),(364389,115897,'117691','printshop','col_in_row','2',0,'5347'),(364390,115898,'1639760443.0645','printshop','carousel','1',0,''),(364391,115898,'1639760443.0645','printshop','col_in_row','4',0,''),(364392,115898,'1639760443.0645','printshop','fancibox','1',0,''),(364393,115898,'1639760443.0645','printshop','col_in_row','3',0,'5347'),(364394,115898,'1639760443.0645','printshop','col_in_row','2',0,'5333'),(364395,115898,'1639760443.0645','printshop','col_in_row','1',0,'5363'),(364396,115899,'117692','printshop','show_heading','h1',0,''),(364397,115900,'117693','printshop','block_type','1',0,''),(364398,115901,'117694','printshop','margin-bottom','20',0,''),(364399,115904,'1645192276.9329','printshop','block_type','1',0,''),(364400,115904,'1645192276.9329','printshop','background-color','$content-bg-2',0,''),(364401,115904,'1645192276.9329','printshop','padding-top','10',0,''),(364402,115904,'1645192276.9329','printshop','padding-bottom','10',0,''),(364403,115904,'1645192276.9329','printshop','color','$content-color-2',0,''),(364404,115907,'117696','printshop','block_type','1',0,''),(364405,115909,'117698','printshop','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(364406,115910,'117699','printshop','width','680',0,''),(364407,115910,'117699','printshop','font-weight','normal',0,''),(364408,115910,'117699','printshop','font-size','12',0,''),(364409,115910,'117699','printshop','padding-top','20',0,''),(364410,115910,'117699','printshop','padding-bottom','20',0,''),(364411,115910,'117699','printshop','color','$content-color-1',0,''),(364412,115911,'117700','printshop','font-weight','400',0,''),(364413,115911,'117700','printshop','padding-top','20',0,''),(364414,115911,'117700','printshop','padding-bottom','0',0,''),(364415,115911,'117700','printshop','font-size','12',0,''),(364416,115912,'117701','printshop','block_type','3',0,''),(364417,115912,'117701','printshop','font-weight','normal',0,''),(364418,115912,'117701','printshop','padding-top','20',0,''),(364419,115913,'117702','printshop','text','<p>If undelivered please return to:</p>',1,''),(364420,115913,'117702','printshop','font-size','12',0,''),(364421,115913,'117702','printshop','font-weight','bold',0,''),(364422,115913,'117702','printshop','text','<p>If undelivered please return to:</p>',2,''),(364423,115913,'117702','printshop','text','<p>If undelivered please return to:</p>',3,''),(364424,115913,'117702','printshop','text','<p>If undelivered please return to:</p>',4,''),(364425,115914,'117703','printshop','font-size','12',0,''),(364426,115915,'117704','printshop','text','<p>Thank you for your order</p>',1,''),(364427,115915,'117704','printshop','color','$hileght-color-1',0,''),(364428,115915,'117704','printshop','font-size','13',0,''),(364429,115915,'117704','printshop','font-weight','bold',0,''),(364430,115915,'117704','printshop','padding-top','5',0,''),(364431,115915,'117704','printshop','text-align','center',0,''),(364432,115915,'117704','printshop','text','<p>Thank you for your order</p>',2,''),(364433,115915,'117704','printshop','text','<p>Thank you for your order</p>',3,''),(364434,115915,'117704','printshop','text','<p>Thank you for your order</p>',4,''),(364435,115916,'117705','printshop','font-weight','400',0,''),(364436,115916,'117705','printshop','text-align','center',0,''),(364437,115916,'117705','printshop','padding-top','0',0,''),(364439,115916,'117705','printshop','padding-left','20',0,''),(364440,115916,'117705','printshop','padding-right','20',0,''),(364444,115917,'117706','printshop','block_type','6',0,''),(364445,115917,'117706','printshop','font-weight','normal',0,''),(364446,115917,'117706','printshop','font-size','16',0,''),(364447,115918,'117707','printshop','text','<p>Email:</p>',1,''),(364448,115918,'117707','printshop','font-weight','normal',0,''),(364449,115918,'117707','printshop','text-align','right',0,''),(364450,115918,'117707','printshop','font-size','12',0,''),(364451,115918,'117707','printshop','text','<p>Email:</p>',2,''),(364452,115918,'117707','printshop','text','<p>Email:</p>',3,''),(364453,115918,'117707','printshop','text','<p>Email:</p>',4,''),(364454,115919,'117708','printshop','font-weight','normal',0,''),(364455,115919,'117708','printshop','text-align','right',0,''),(364456,115919,'117708','printshop','font-size','12',0,''),(364457,115920,'117709','printshop','text','<p>If something has gone wrong please contact us at:</p>',1,''),(364458,115920,'117709','printshop','font-size','12',0,''),(364459,115920,'117709','printshop','font-weight','bold',0,''),(364460,115920,'117709','printshop','text-align','right',0,''),(364461,115920,'117709','printshop','text','<p>If something has gone wrong please contact us at:</p>',2,''),(364462,115920,'117709','printshop','text','<p>If something has gone wrong please contact us at:</p>',3,''),(364463,115920,'117709','printshop','text','<p>If something has gone wrong please contact us at:</p>',4,''),(364464,115921,'117710','printshop','block_type','6',0,''),(364465,115921,'117710','printshop','font-weight','normal',0,''),(364466,115921,'117710','printshop','font-size','16',0,''),(364467,115922,'117711','printshop','text','<p>Phone:</p>',1,''),(364468,115922,'117711','printshop','font-weight','normal',0,''),(364469,115922,'117711','printshop','text-align','right',0,''),(364470,115922,'117711','printshop','font-size','12',0,''),(364471,115922,'117711','printshop','text','<p>Phone:</p>',2,''),(364472,115922,'117711','printshop','text','<p>Phone:</p>',3,''),(364473,115922,'117711','printshop','text','<p>Phone:</p>',4,''),(364474,115923,'117712','printshop','font-weight','normal',0,''),(364475,115923,'117712','printshop','text-align','right',0,''),(364476,115923,'117712','printshop','font-size','12',0,''),(364477,115924,'117713','printshop','block_type','2',0,''),(364478,115924,'117713','printshop','font-weight','normal',0,''),(364479,115924,'117713','printshop','padding-bottom','20',0,''),(364480,115925,'117714','printshop','font-weight','400',0,''),(364481,115925,'117714','printshop','padding-top','20',0,''),(364486,115926,'117715','printshop','block_type','11',0,''),(364487,115926,'117715','printshop','font-weight','normal',0,''),(364488,115927,'117716','printshop','text','<p>Phone:</p>',1,''),(364489,115927,'117716','printshop','font-weight','normal',0,''),(364490,115927,'117716','printshop','text-align','right',0,''),(364491,115927,'117716','printshop','text','<p>Phone:</p>',2,''),(364492,115927,'117716','printshop','text','<p>Phone:</p>',3,''),(364493,115927,'117716','printshop','text','<p>Phone:</p>',4,''),(364494,115928,'117717','printshop','font-weight','normal',0,''),(364495,115928,'117717','printshop','text-align','right',0,''),(364496,115929,'117718','printshop','block_type','11',0,''),(364497,115929,'117718','printshop','font-weight','normal',0,''),(364498,115930,'117719','printshop','text','<p>Web:</p>',1,''),(364499,115930,'117719','printshop','font-weight','normal',0,''),(364500,115930,'117719','printshop','text-align','right',0,''),(364501,115930,'117719','printshop','text','<p>Web:</p>',2,''),(364502,115930,'117719','printshop','text','<p>Web:</p>',3,''),(364503,115930,'117719','printshop','text','<p>Web:</p>',4,''),(364504,115931,'117720','printshop','font-weight','normal',0,''),(364505,115931,'117720','printshop','text-align','right',0,''),(364506,115932,'117721','printshop','block_type','1',0,''),(364507,115933,'117722','printshop','font-weight','normal',0,''),(364508,115933,'117722','printshop','text-align','right',0,''),(364509,115933,'117722','printshop','padding-bottom','10',0,''),(364510,115933,'117722','printshop','address_spacer',',',0,''),(364511,115933,'117722','printshop','font-size','12',0,''),(364512,115934,'117723','printshop','block_type','11',0,''),(364513,115934,'117723','printshop','font-weight','normal',0,''),(364514,115935,'117724','printshop','text','<p>Email:</p>',1,''),(364515,115935,'117724','printshop','font-weight','normal',0,''),(364516,115935,'117724','printshop','text-align','right',0,''),(364517,115935,'117724','printshop','text','<p>Email:</p>',2,''),(364518,115935,'117724','printshop','text','<p>Email:</p>',3,''),(364519,115935,'117724','printshop','text','<p>Email:</p>',4,''),(364520,115936,'117725','printshop','font-weight','normal',0,''),(364521,115936,'117725','printshop','text-align','right',0,''),(364522,115937,'117726','printshop','block_type','4',0,''),(364523,115937,'117726','printshop','font-weight','normal',0,''),(364524,115937,'117726','printshop','border-top-width','1',0,''),(364525,115937,'117726','printshop','border-top-color','$content-border-3',0,''),(364526,115937,'117726','printshop','border-left-width','1',0,''),(364527,115937,'117726','printshop','border-left-color','$content-border-3',0,''),(364528,115937,'117726','printshop','border-right-width','1',0,''),(364529,115937,'117726','printshop','border-right-color','$content-border-3',0,''),(364530,115937,'117726','printshop','border-bottom-width','1',0,''),(364531,115937,'117726','printshop','border-bottom-color','$content-border-3',0,''),(364532,115938,'117727','printshop','block_type','2',0,''),(364533,115938,'117727','printshop','font-weight','normal',0,''),(364534,115938,'117727','printshop','border-right-width','1',0,''),(364535,115938,'117727','printshop','border-right-color','$content-border-3',0,''),(364536,115939,'117728','printshop','block_type','1',0,''),(364537,115939,'117728','printshop','font-weight','400',0,''),(364538,115939,'117728','printshop','background-color','$content-bg-2',0,''),(364539,115939,'117728','printshop','padding-top','10',0,''),(364540,115939,'117728','printshop','padding-left','10',0,''),(364541,115939,'117728','printshop','padding-right','10',0,''),(364542,115939,'117728','printshop','padding-bottom','30',0,''),(364543,115940,'117729','printshop','font-size','12',0,''),(364544,115941,'117730','printshop','text','<p>ADDRESS:</p>\n',1,''),(364545,115941,'117730','printshop','font-size','14',0,''),(364546,115941,'117730','printshop','font-weight','bold',0,''),(364547,115941,'117730','printshop','text','<p>ADDRESS:</p>\n',2,''),(364548,115941,'117730','printshop','text','<p>ADDRESS:</p>\n',3,''),(364549,115941,'117730','printshop','text','<p>ADDRESS:</p>\n',4,''),(364550,115942,'117731','printshop','block_type','1',0,''),(364551,115942,'117731','printshop','font-weight','normal',0,''),(364552,115942,'117731','printshop','padding-top','10',0,''),(364553,115942,'117731','printshop','padding-left','10',0,''),(364554,115942,'117731','printshop','padding-right','10',0,''),(364555,115942,'117731','printshop','padding-bottom','10',0,''),(364556,115944,'117733','printshop','text','<p>E-MAIL ADDRESS:</p>',1,''),(364557,115944,'117733','printshop','font-weight','bold',0,''),(364558,115944,'117733','printshop','font-size','14',0,''),(364559,115944,'117733','printshop','padding-top','10',0,''),(364560,115944,'117733','printshop','text','<p>E-MAIL ADDRESS:</p>',2,''),(364561,115944,'117733','printshop','text','<p>E-MAIL ADDRESS:</p>',3,''),(364562,115944,'117733','printshop','text','<p>E-MAIL ADDRESS:</p>',4,''),(364563,115945,'117734','printshop','font-weight','normal',0,''),(364564,115946,'117735','printshop','font-weight','normal',0,''),(364565,115947,'117736','printshop','text','<p>PHONE NUMBER:</p>',1,''),(364566,115947,'117736','printshop','font-size','14',0,''),(364567,115947,'117736','printshop','font-weight','bold',0,''),(364568,115947,'117736','printshop','padding-top','10',0,''),(364569,115947,'117736','printshop','text','<p>PHONE NUMBER:</p>',2,''),(364570,115947,'117736','printshop','text','<p>PHONE NUMBER:</p>',3,''),(364571,115947,'117736','printshop','text','<p>PHONE NUMBER:</p>',4,''),(364572,115948,'117737','printshop','text','<p>CUSTOMER:</p>',1,''),(364573,115948,'117737','printshop','font-size','13',0,''),(364574,115948,'117737','printshop','font-weight','bold',0,''),(364575,115948,'117737','printshop','text','<p>CUSTOMER:</p>',2,''),(364576,115948,'117737','printshop','text','<p>CUSTOMER:</p>',3,''),(364577,115948,'117737','printshop','text','<p>CUSTOMER:</p>',4,''),(364578,115949,'117738','printshop','font-size','14',0,''),(364579,115949,'117738','printshop','font-weight','bold',0,''),(364580,115949,'117738','printshop','text-align','center',0,''),(364581,115949,'117738','printshop','padding-bottom','10',0,''),(364582,115949,'117738','printshop','padding-top','10',0,''),(364583,115950,'117739','printshop','text','<p>Order date:</p>\n',1,''),(364584,115950,'117739','printshop','font-weight','bold',0,''),(364585,115950,'117739','printshop','text-align','center',0,''),(364586,115950,'117739','printshop','font-size','12',0,''),(364587,115950,'117739','printshop','text','<p>Order date:</p>\n',2,''),(364588,115950,'117739','printshop','text','<p>Order date:</p>\n',3,''),(364589,115950,'117739','printshop','text','<p>Order date:</p>\n',4,''),(364590,115951,'117740','printshop','font-weight','normal',0,''),(364591,115951,'117740','printshop','text-align','center',0,''),(364592,115951,'117740','printshop','padding-bottom','10',0,''),(364593,115952,'117741','printshop','block_type','5',0,''),(364594,115952,'117741','printshop','font-weight','normal',0,''),(364595,115952,'117741','printshop','border-bottom-width','1',0,''),(364596,115952,'117741','printshop','border-bottom-color','$content-border-3',0,''),(364597,115952,'117741','printshop','border-top-width','1',0,''),(364598,115952,'117741','printshop','border-top-color','$content-border-3',0,''),(364599,115952,'117741','printshop','border-left-color','$content-border-3',0,''),(364600,115952,'117741','printshop','border-left-width','1',0,''),(364601,115953,'117742','printshop','block_type','1',0,''),(364602,115953,'117742','printshop','font-weight','normal',0,''),(364603,115953,'117742','printshop','padding-top','10',0,''),(364604,115953,'117742','printshop','padding-left','10',0,''),(364605,115953,'117742','printshop','padding-right','10',0,''),(364606,115954,'117743','printshop','font-weight','400',0,''),(364607,115954,'117743','printshop','line-height','120',0,''),(364608,115954,'117743','printshop','line_height_measure','%',0,''),(364609,115954,'117743','printshop','font-size','12',0,''),(364610,115955,'117744','printshop','text','<p>SHIPPING ADDRESS:</p>',1,''),(364611,115955,'117744','printshop','font-size','14',0,''),(364612,115955,'117744','printshop','font-weight','bold',0,''),(364613,115955,'117744','printshop','padding-bottom','10',0,''),(364614,115955,'117744','printshop','text','<p>SHIPPING ADDRESS:</p>',2,''),(364615,115955,'117744','printshop','text','<p>SHIPPING ADDRESS:</p>',3,''),(364616,115955,'117744','printshop','text','<p>SHIPPING ADDRESS:</p>',4,''),(364619,115959,'117745','printshop','block_type','1',0,''),(364620,115960,'117746','printshop','block_type','6',0,''),(364621,115960,'117746','printshop','schema','6-3',0,'5342'),(364622,115961,'117747','printshop','aria_name','account-menu',0,''),(364685,115981,'117748','printshop','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(364686,115982,'117749','printshop','link','Quotation Info',0,''),(364687,115982,'117749','printshop','margin-bottom','20',0,''),(364688,115983,'117750','printshop','block_type','1',0,''),(364689,115984,'117751','printshop','block_type','6',0,''),(364690,115984,'117751','printshop','schema','6-3',0,'5342'),(364691,115985,'117752','printshop','aria_name','account-menu',0,''),(364754,116005,'117753','printshop','block_type','3',0,''),(364755,116006,'117754','printshop','block_type','1',0,''),(364756,116006,'117754','printshop','padding-right','20',0,''),(364757,116006,'117754','printshop','padding-bottom','20',0,''),(364758,116007,'117755','printshop','orders_data','name',0,''),(364759,116008,'117756','printshop','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(364760,116009,'117757','printshop','block_type','1',0,''),(364761,116009,'117757','printshop','padding-right','20',0,''),(364762,116009,'117757','printshop','padding-bottom','20',0,''),(364763,116010,'117758','printshop','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(364764,116011,'117759','printshop','orders_data','telephone',0,''),(364765,116012,'117760','printshop','block_type','1',0,''),(364766,116012,'117760','printshop','padding-right','20',0,''),(364767,116013,'117761','printshop','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(364768,116014,'117762','printshop','orders_data','shipping_method',0,''),(364769,116015,'117763','printshop','block_type','1',0,''),(364770,116015,'117763','printshop','padding-right','20',0,''),(364771,116015,'117763','printshop','padding-bottom','20',0,''),(364772,116016,'117764','printshop','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(364773,116017,'117765','printshop','orders_data','delivery_address',0,''),(364774,116018,'117766','printshop','block_type','1',0,''),(364775,116018,'117766','printshop','padding-bottom','20',0,''),(364776,116019,'117767','printshop','orders_data','billing_address',0,''),(364777,116020,'117768','printshop','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(364778,116021,'117769','printshop','block_type','1',0,''),(364779,116022,'117770','printshop','orders_data','payment_method',0,''),(364780,116023,'117771','printshop','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(364781,116024,'117772','printshop','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(364782,116026,'117774','printshop','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(364783,116029,'117777','printshop','block_type','2',0,''),(364784,116029,'117777','printshop','padding-top','20',0,''),(364785,116029,'117777','printshop','margin-bottom','20',0,''),(364786,116030,'117778','printshop','like_button','1',0,''),(364787,116030,'117778','printshop','text','IMAGE_BUTTON_BACK',0,''),(364788,116030,'117778','printshop','link','Quotations',0,''),(364789,116031,'117779','printshop','text','<h1>##HEADING_TITLE##</h1>',0,''),(364790,116032,'117780','printshop','padding-top','20',0,''),(364791,116032,'117780','printshop','padding-bottom','20',0,''),(364792,116032,'117780','printshop','block_type','1',0,''),(364793,116032,'117780','printshop','background-color','$content-bg-2',0,''),(364794,116034,'117782','printshop','block_type','4',0,''),(364795,116034,'117782','printshop','schema','4-2',0,'5342'),(364796,116034,'117782','printshop','schema','4-2',0,'5333'),(364797,116035,'117783','printshop','background-color','$content-bg-1',0,''),(364798,116036,'117784','printshop','block_type','1',0,''),(364799,116036,'117784','printshop','style_class','order-summary',0,''),(364800,116036,'117784','printshop','margin-left','30',0,''),(364801,116036,'117784','printshop','margin-left','0',0,'5342'),(364802,116037,'117785','printshop','block_type','1',0,''),(364803,116037,'117785','printshop','padding-left','20',0,''),(364804,116037,'117785','printshop','padding-right','20',0,''),(364805,116037,'117785','printshop','padding-bottom','30',0,''),(364806,116038,'117786','printshop','max-width','300',0,'5342'),(364807,116038,'117786','printshop','margin_left_measure','auto',0,'5342'),(364808,116038,'117786','printshop','margin_right_measure','auto',0,'5342'),(364809,116038,'117786','printshop','margin-bottom','0',0,''),(364810,116040,'117788','printshop','block_type','1',0,''),(364878,116064,'117793','printshop','block_type','1',0,''),(364879,116066,'117795','printshop','pagination','bottom',0,''),(364880,116067,'117796','printshop','width','800',0,''),(364881,116068,'117797','printshop','block_type','11',0,''),(364882,116068,'117797','printshop','border-top-width','1',0,''),(364883,116068,'117797','printshop','border-left-width','1',0,''),(364884,116068,'117797','printshop','border-right-width','1',0,''),(364885,116068,'117797','printshop','border-bottom-width','1',0,''),(364886,116068,'117797','printshop','border-top-color','$highlight-box-border-1',0,''),(364887,116068,'117797','printshop','border-left-color','$highlight-box-border-1',0,''),(364888,116068,'117797','printshop','border-right-color','$highlight-box-border-1',0,''),(364889,116068,'117797','printshop','border-bottom-color','$highlight-box-border-1',0,''),(364890,116069,'117798','printshop','block_type','1',0,''),(364891,116069,'117798','printshop','border-right-width','1',0,''),(364892,116069,'117798','printshop','border-right-color','$highlight-box-border-1',0,''),(364893,116069,'117798','printshop','padding-top','10',0,''),(364894,116069,'117798','printshop','padding-right','10',0,''),(364895,116069,'117798','printshop','padding-bottom','10',0,''),(364896,116070,'117799','printshop','block_type','9',0,''),(364897,116071,'117800','printshop','text','1.',0,''),(364898,116071,'117800','printshop','font-size','12',0,''),(364899,116071,'117800','printshop','text-align','right',0,''),(364900,116071,'117800','printshop','padding-right','5',0,''),(364901,116072,'117801','printshop','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(364902,116072,'117801','printshop','font-size','12',0,''),(364903,116072,'117801','printshop','padding-bottom','5',0,''),(364904,116073,'117802','printshop','block_type','9',0,''),(364905,116074,'117803','printshop','text','4.',0,''),(364906,116074,'117803','printshop','font-size','12',0,''),(364907,116074,'117803','printshop','text-align','right',0,''),(364908,116074,'117803','printshop','margin-right','5',0,''),(364909,116075,'117804','printshop','text','Our Replacement Department will process your request.',0,''),(364910,116075,'117804','printshop','font-size','12',0,''),(364911,116075,'117804','printshop','padding-bottom','5',0,''),(364912,116076,'117805','printshop','block_type','9',0,''),(364913,116077,'117806','printshop','text','3.',0,''),(364914,116077,'117806','printshop','font-size','12',0,''),(364915,116077,'117806','printshop','text-align','right',0,''),(364916,116077,'117806','printshop','margin-right','5',0,''),(364917,116078,'117807','printshop','text','Return the authorized item(s) per shipping instructions.',0,''),(364918,116078,'117807','printshop','font-size','12',0,''),(364919,116078,'117807','printshop','padding-bottom','5',0,''),(364920,116079,'117808','printshop','block_type','9',0,''),(364921,116080,'117809','printshop','text','2.',0,''),(364922,116080,'117809','printshop','font-size','12',0,''),(364923,116080,'117809','printshop','text-align','right',0,''),(364924,116080,'117809','printshop','margin-right','5',0,''),(364925,116081,'117810','printshop','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(364926,116081,'117810','printshop','font-size','12',0,''),(364927,116081,'117810','printshop','padding-bottom','5',0,''),(364928,116082,'117811','printshop','block_type','1',0,''),(364929,116082,'117811','printshop','padding-left','15',0,''),(364930,116083,'117812','printshop','text','Replacement Policy:',0,''),(364931,116083,'117812','printshop','font-size','14',0,''),(364932,116083,'117812','printshop','padding-bottom','5',0,''),(364933,116083,'117812','printshop','font-weight','bold',0,''),(364934,116084,'117813','printshop','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(364935,116084,'117813','printshop','font-size','11',0,''),(364936,116084,'117813','printshop','font-style','italic',0,''),(364937,116084,'117813','printshop','padding-bottom','5',0,''),(364938,116085,'117814','printshop','block_type','1',0,''),(364939,116085,'117814','printshop','border-bottom-width','1',0,''),(364940,116085,'117814','printshop','border-bottom-color','$highlight-box-border-1',0,''),(364941,116086,'117815','printshop','text','Return Material Authorization (RMA) Form',0,''),(364942,116086,'117815','printshop','text-align','center',0,''),(364943,116086,'117815','printshop','font-size','16',0,''),(364944,116086,'117815','printshop','font-weight','bold',0,''),(364945,116087,'117816','printshop','text-align','center',0,''),(364946,116087,'117816','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',1,''),(364947,116087,'117816','printshop','padding-top','10',0,''),(364948,116087,'117816','printshop','padding-bottom','10',0,''),(364949,116087,'117816','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',2,''),(364950,116087,'117816','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',3,''),(364951,116087,'117816','printshop','logo','themes/printshop/img/themes/printshop/img/logo-2.png',4,''),(364952,116088,'117817','printshop','block_type','1',0,''),(364953,116088,'117817','printshop','padding-top','10',0,''),(364954,116088,'117817','printshop','padding-left','10',0,''),(364955,116088,'117817','printshop','padding-right','10',0,''),(364956,116088,'117817','printshop','padding-bottom','20',0,''),(364957,116089,'117818','printshop','block_type','2',0,''),(364958,116089,'117818','printshop','padding-top','5',0,''),(364959,116090,'117819','printshop','block_type','11',0,''),(364960,116091,'117820','printshop','text','Email:',0,''),(364961,116091,'117820','printshop','font-size','12',0,''),(364962,116092,'117821','printshop','data','rrDelivery_email_address',0,''),(364963,116092,'117821','printshop','font-size','12',0,''),(364964,116093,'117822','printshop','block_type','11',0,''),(364965,116094,'117823','printshop','text','Phone:',0,''),(364966,116094,'117823','printshop','font-size','12',0,''),(364967,116095,'117824','printshop','data','rrDelivery_telephone',0,''),(364968,116095,'117824','printshop','font-size','12',0,''),(364969,116096,'117825','printshop','block_type','2',0,''),(364970,116096,'117825','printshop','padding-top','5',0,''),(364971,116097,'117826','printshop','block_type','11',0,''),(364972,116098,'117827','printshop','text','Country:',0,''),(364973,116098,'117827','printshop','font-size','12',0,''),(364974,116099,'117828','printshop','data','rrDelivery_country',0,''),(364975,116099,'117828','printshop','font-size','12',0,''),(364976,116100,'117829','printshop','block_type','11',0,''),(364977,116101,'117830','printshop','text','Postcode:',0,''),(364978,116101,'117830','printshop','font-size','12',0,''),(364979,116102,'117831','printshop','data','rrDelivery_postcode',0,''),(364980,116102,'117831','printshop','font-size','12',0,''),(364981,116103,'117832','printshop','block_type','2',0,''),(364982,116103,'117832','printshop','padding-top','5',0,''),(364983,116104,'117833','printshop','block_type','11',0,''),(364984,116105,'117834','printshop','text','City:',0,''),(364985,116105,'117834','printshop','font-size','12',0,''),(364986,116106,'117835','printshop','data','rrDelivery_city',0,''),(364987,116106,'117835','printshop','font-size','12',0,''),(364988,116107,'117836','printshop','block_type','11',0,''),(364989,116108,'117837','printshop','text','State:',0,''),(364990,116108,'117837','printshop','font-size','12',0,''),(364991,116109,'117838','printshop','data','rrDelivery_state',0,''),(364992,116109,'117838','printshop','font-size','12',0,''),(364993,116110,'117839','printshop','block_type','9',0,''),(364994,116110,'117839','printshop','padding-top','5',0,''),(364995,116111,'117840','printshop','text','Address:',0,''),(364996,116111,'117840','printshop','font-size','12',0,''),(364997,116112,'117841','printshop','data','rrDelivery_street_address',0,''),(364998,116112,'117841','printshop','font-size','12',0,''),(364999,116113,'117842','printshop','block_type','2',0,''),(365000,116114,'117843','printshop','block_type','11',0,''),(365001,116115,'117844','printshop','text','Company:',0,''),(365002,116115,'117844','printshop','font-size','12',0,''),(365003,116116,'117845','printshop','data','rrDelivery_company',0,''),(365004,116116,'117845','printshop','font-size','12',0,''),(365005,116117,'117846','printshop','block_type','2',0,''),(365006,116118,'117847','printshop','text','Contact Name:',0,''),(365007,116118,'117847','printshop','font-size','12',0,''),(365008,116119,'117848','printshop','data','rrDelivery_name',0,''),(365009,116119,'117848','printshop','font-size','12',0,''),(365010,116120,'117849','printshop','block_type','2',0,''),(365011,116120,'117849','printshop','padding-left','10',0,''),(365012,116120,'117849','printshop','padding-top','20',0,''),(365013,116120,'117849','printshop','padding-right','10',0,''),(365014,116121,'117850','printshop','block_type','5',0,''),(365015,116122,'117851','printshop','text','RMA No:',0,''),(365016,116122,'117851','printshop','font-size','12',0,''),(365017,116122,'117851','printshop','font-weight','bold',0,''),(365018,116123,'117852','printshop','data','rrNumber',0,''),(365019,116123,'117852','printshop','font-size','12',0,''),(365020,116123,'117852','printshop','font-weight','bold',0,''),(365021,116124,'117853','printshop','block_type','2',0,''),(365022,116125,'117854','printshop','text','Date Issued:',0,''),(365023,116125,'117854','printshop','font-size','12',0,''),(365024,116125,'117854','printshop','font-weight','bold',0,''),(365025,116126,'117855','printshop','data','rrDateCreate',0,''),(365026,116126,'117855','printshop','font-size','12',0,''),(365027,116126,'117855','printshop','font-weight','bold',0,''),(365028,116127,'117856','printshop','block_type','1',0,''),(365029,116128,'117857','printshop','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(365030,116128,'117857','printshop','font-size','12',0,''),(365031,116128,'117857','printshop','font-style','italic',0,''),(365032,116128,'117857','printshop','padding-bottom','20',0,''),(365033,116130,'117859','printshop','block_type','1',0,''),(365034,116130,'117859','printshop','border-top-width','1',0,''),(365035,116130,'117859','printshop','border-left-width','1',0,''),(365036,116130,'117859','printshop','border-right-width','1',0,''),(365037,116130,'117859','printshop','border-bottom-width','1',0,''),(365038,116130,'117859','printshop','border-top-color','$highlight-box-border-1',0,''),(365039,116130,'117859','printshop','border-left-color','$highlight-box-border-1',0,''),(365040,116130,'117859','printshop','border-right-color','$highlight-box-border-1',0,''),(365041,116130,'117859','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365042,116131,'117860','printshop','block_type','11',0,''),(365043,116132,'117861','printshop','block_type','1',0,''),(365044,116132,'117861','printshop','padding-top','10',0,''),(365045,116132,'117861','printshop','padding-right','10',0,''),(365046,116132,'117861','printshop','padding-bottom','10',0,''),(365047,116132,'117861','printshop','border-right-width','1',0,''),(365048,116132,'117861','printshop','border-right-color','$highlight-box-border-1',0,''),(365049,116133,'117862','printshop','block_type','9',0,''),(365050,116134,'117863','printshop','text','4.',0,''),(365051,116134,'117863','printshop','font-size','12',0,''),(365052,116134,'117863','printshop','text-align','right',0,''),(365053,116134,'117863','printshop','padding-right','5',0,''),(365054,116135,'117864','printshop','font-size','11',0,''),(365055,116135,'117864','printshop','font-style','italic',0,''),(365056,116135,'117864','printshop','padding-bottom','5',0,''),(365057,116136,'117865','printshop','text','Ship returned items to:',0,''),(365058,116136,'117865','printshop','font-size','12',0,''),(365059,116136,'117865','printshop','padding-bottom','5',0,''),(365060,116137,'117866','printshop','block_type','9',0,''),(365061,116138,'117867','printshop','text','3.',0,''),(365062,116138,'117867','printshop','font-size','12',0,''),(365063,116138,'117867','printshop','text-align','right',0,''),(365064,116138,'117867','printshop','padding-right','5',0,''),(365065,116139,'117868','printshop','text','Ship only the items that are authorized.',0,''),(365066,116139,'117868','printshop','font-size','12',0,''),(365067,116139,'117868','printshop','padding-bottom','10',0,''),(365068,116140,'117869','printshop','block_type','9',0,''),(365069,116141,'117870','printshop','text','1.',0,''),(365070,116141,'117870','printshop','font-size','12',0,''),(365071,116141,'117870','printshop','text-align','right',0,''),(365072,116141,'117870','printshop','padding-right','5',0,''),(365073,116142,'117871','printshop','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(365074,116142,'117871','printshop','font-size','12',0,''),(365075,116142,'117871','printshop','padding-bottom','10',0,''),(365076,116143,'117872','printshop','block_type','1',0,''),(365077,116144,'117873','printshop','text','Shipping Instructions:',0,''),(365078,116144,'117873','printshop','font-weight','bold',0,''),(365079,116144,'117873','printshop','font-size','14',0,''),(365080,116144,'117873','printshop','padding-bottom','5',0,''),(365081,116144,'117873','printshop','padding-left','10',0,''),(365082,116145,'117874','printshop','block_type','9',0,''),(365083,116146,'117875','printshop','text','2.',0,''),(365084,116146,'117875','printshop','font-size','12',0,''),(365085,116146,'117875','printshop','text-align','right',0,''),(365086,116146,'117875','printshop','padding-right','5',0,''),(365087,116147,'117876','printshop','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(365088,116147,'117876','printshop','font-size','12',0,''),(365089,116147,'117876','printshop','padding-bottom','10',0,''),(365090,116148,'117877','printshop','block_type','1',0,''),(365091,116148,'117877','printshop','padding-left','10',0,''),(365092,116148,'117877','printshop','padding-right','10',0,''),(365093,116148,'117877','printshop','padding-bottom','10',0,''),(365094,116149,'117878','printshop','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(365095,116149,'117878','printshop','font-size','11',0,''),(365096,116149,'117878','printshop','font-style','italic',0,''),(365097,116150,'117879','printshop','block_type','1',0,''),(365098,116150,'117879','printshop','padding-top','10',0,''),(365099,116150,'117879','printshop','padding-left','40',0,''),(365100,116150,'117879','printshop','padding-right','40',0,''),(365101,116150,'117879','printshop','padding-bottom','10',0,''),(365102,116151,'117880','printshop','block_type','1',0,''),(365103,116151,'117880','printshop','padding-top','10',0,''),(365104,116151,'117880','printshop','padding-left','10',0,''),(365105,116151,'117880','printshop','padding-right','10',0,''),(365106,116151,'117880','printshop','padding-bottom','10',0,''),(365107,116151,'117880','printshop','border-top-width','1',0,''),(365108,116151,'117880','printshop','border-left-width','1',0,''),(365109,116151,'117880','printshop','border-right-width','1',0,''),(365110,116151,'117880','printshop','border-bottom-width','1',0,''),(365111,116151,'117880','printshop','border-top-color','$highlight-box-border-1',0,''),(365112,116151,'117880','printshop','border-left-color','$highlight-box-border-1',0,''),(365113,116151,'117880','printshop','border-right-color','$highlight-box-border-1',0,''),(365114,116151,'117880','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365115,116152,'117881','printshop','block_type','3',0,''),(365116,116153,'117882','printshop','data','rrDelivery_name',0,''),(365117,116153,'117882','printshop','font-size','9',0,''),(365118,116154,'117883','printshop','block_type','2',0,''),(365119,116155,'117884','printshop','text','RMA#:',0,''),(365120,116155,'117884','printshop','font-size','10',0,''),(365121,116156,'117885','printshop','data','rrNumber',0,''),(365122,116156,'117885','printshop','font-size','9',0,''),(365123,116157,'117886','printshop','block_type','5',0,''),(365124,116158,'117887','printshop','font-size','9',0,''),(365125,116159,'117888','printshop','block_type','1',0,''),(365126,116159,'117888','printshop','padding-left','10',0,''),(365127,116159,'117888','printshop','padding-right','10',0,''),(365128,116159,'117888','printshop','padding-bottom','10',0,''),(365129,116160,'117889','printshop','text','Use this space for additional Comments:',0,''),(365130,116160,'117889','printshop','font-size','11',0,''),(365131,116160,'117889','printshop','font-style','italic',0,''),(365132,116161,'117890','printshop','text','&nbsp;',0,''),(365133,116161,'117890','printshop','border-bottom-width','1',0,''),(365134,116161,'117890','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365135,116162,'117891','printshop','text','&nbsp;',0,''),(365136,116162,'117891','printshop','border-bottom-width','1',0,''),(365137,116162,'117891','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365138,116162,'117891','printshop','padding-top','5',0,''),(365139,116163,'117892','printshop','text','&nbsp;',0,''),(365140,116163,'117892','printshop','border-bottom-width','1',0,''),(365141,116163,'117892','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365142,116163,'117892','printshop','padding-top','5',0,''),(365143,116164,'117893','printshop','text','&nbsp;',0,''),(365144,116164,'117893','printshop','border-bottom-width','1',0,''),(365145,116164,'117893','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365146,116164,'117893','printshop','padding-top','5',0,''),(365147,116165,'117894','printshop','block_type','3',0,''),(365148,116165,'117894','printshop','padding-top','10',0,''),(365149,116165,'117894','printshop','padding-bottom','10',0,''),(365150,116165,'117894','printshop','padding-right','10',0,''),(365151,116166,'117895','printshop','font-size','11',0,''),(365152,116166,'117895','printshop','font-weight','bold',0,''),(365153,116166,'117895','printshop','text','Return Approval:',0,''),(365154,116166,'117895','printshop','padding-top','5',0,''),(365155,116166,'117895','printshop','padding-left','10',0,''),(365156,116167,'117896','printshop','border-bottom-width','1',0,''),(365157,116167,'117896','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365158,116167,'117896','printshop','text','&nbsp;',0,''),(365159,116168,'117897','printshop','block_type','5',0,''),(365160,116169,'117898','printshop','text','Date:',0,''),(365161,116169,'117898','printshop','padding-top','5',0,''),(365162,116169,'117898','printshop','font-size','11',0,''),(365163,116169,'117898','printshop','font-weight','bold',0,''),(365164,116169,'117898','printshop','padding-left','5',0,''),(365165,116170,'117899','printshop','text','&nbsp;',0,''),(365166,116170,'117899','printshop','border-bottom-width','1',0,''),(365167,116170,'117899','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365168,116171,'117900','printshop','block_type','3',0,''),(365169,116171,'117900','printshop','padding-right','10',0,''),(365170,116172,'117901','printshop','text','Customer Signature:',0,''),(365171,116172,'117901','printshop','font-weight','bold',0,''),(365172,116172,'117901','printshop','font-size','11',0,''),(365173,116172,'117901','printshop','padding-top','5',0,''),(365174,116172,'117901','printshop','padding-left','10',0,''),(365175,116173,'117902','printshop','text','&nbsp;',0,''),(365176,116173,'117902','printshop','border-bottom-width','1',0,''),(365177,116173,'117902','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365178,116174,'117903','printshop','block_type','5',0,''),(365179,116175,'117904','printshop','text','Date:',0,''),(365180,116175,'117904','printshop','padding-top','5',0,''),(365181,116175,'117904','printshop','font-size','11',0,''),(365182,116175,'117904','printshop','font-weight','bold',0,''),(365183,116175,'117904','printshop','padding-left','5',0,''),(365184,116176,'117905','printshop','text','&nbsp;',0,''),(365185,116176,'117905','printshop','border-bottom-width','1',0,''),(365186,116176,'117905','printshop','border-bottom-color','$highlight-box-border-1',0,''),(365187,116177,'117906','printshop','block_type','1',0,''),(365188,116177,'117906','printshop','style_class','item-holder',0,''),(365189,116177,'117906','printshop','padding-top','25',0,''),(365190,116177,'117906','printshop','padding-bottom','25',0,''),(365191,116177,'117906','printshop','text-align','left',0,''),(365192,116177,'117906','printshop','border-top-width','1',0,''),(365193,116177,'117906','printshop','border-top-color','$content-border-3',0,''),(365194,116178,'117907','printshop','block_type','7',0,''),(365195,116178,'117907','printshop','schema','7-2',0,'5342'),(365196,116179,'117908','printshop','block_type','5',0,''),(365197,116179,'117908','printshop','schema','5-2',0,'5342'),(365198,116180,'117909','printshop','clear','none',0,''),(365199,116180,'117909','printshop','padding-right','20',0,''),(365200,116181,'117910','printshop','padding-right','20',0,''),(365201,116181,'117910','printshop','max-width','300',0,'5342'),(365202,116181,'117910','printshop','margin_left_measure','auto',0,'5342'),(365203,116181,'117910','printshop','margin_right_measure','auto',0,'5342'),(365204,116182,'117914','printshop','padding-right','20',0,''),(365205,116183,'117915','printshop','description_characters','200',0,''),(365206,116183,'117915','printshop','clear','none',0,''),(365207,116183,'117915','printshop','padding-right','20',0,''),(365208,116184,'117916','printshop','clear','none',0,''),(365209,116185,'117917','printshop','margin-bottom','20',0,''),(365210,116188,'117918','printshop','block_type','1',0,''),(365211,116188,'117918','printshop','padding-left','40',0,''),(365212,116188,'117918','printshop','style_class','right-aria',0,''),(365213,116188,'117918','printshop','padding-left','0',0,'5342'),(365214,116189,'117911','printshop','block_type','1',0,''),(365215,116189,'117911','printshop','text-align','center',0,''),(365216,116190,'117912','printshop','margin-top','4',0,''),(365217,116190,'117912','printshop','margin-bottom','7',0,''),(365218,116191,'117913','printshop','padding-top','6',0,''),(365219,116191,'117913','printshop','padding-left','5',0,''),(365220,116192,'117919','printshop','margin-bottom','15',0,''),(365221,116192,'117919','printshop','text-align','center',0,''),(365222,116193,'117920','printshop','margin-bottom','10',0,''),(365223,116193,'117920','printshop','text-align','center',0,''),(365224,116194,'117922','printshop','text-align','center',0,''),(365225,116194,'117922','printshop','margin-bottom','15',0,''),(365226,116195,'117924','printshop','text-align','center',0,''),(365227,116195,'117924','printshop','margin-bottom','10',0,''),(365228,116197,'120926','printshop','text-align','center',0,''),(365229,116197,'120926','printshop','margin-bottom','15',0,''),(365230,116198,'120927','printshop','text-align','center',0,''),(365231,116198,'120927','printshop','margin-bottom','15',0,''),(365232,116199,'117925','printshop','block_type','1',0,''),(365233,116199,'117925','printshop','padding-top','20',0,''),(365234,116199,'117925','printshop','padding-bottom','20',0,''),(365235,116199,'117925','printshop','background-color','$content-bg-2',0,''),(365236,116201,'117927','printshop','block_type','7',0,''),(365237,116201,'117927','printshop','schema','4-2',0,'5342'),(365238,116202,'117928','printshop','padding-bottom','20',0,''),(365239,116202,'117928','printshop','background-color','$content-bg-1',0,''),(365240,116203,'117929','printshop','style_class','order-summary',0,''),(365241,116203,'117929','printshop','padding-left','25',0,''),(365242,116203,'117929','printshop','block_type','1',0,''),(365243,116203,'117929','printshop','padding-left','0',0,'5342'),(365244,116203,'117929','printshop','margin-top','30',0,'5342'),(365245,116204,'117930','printshop','block_type','1',0,''),(365246,116204,'117930','printshop','padding-left','20',0,''),(365247,116204,'117930','printshop','padding-right','20',0,''),(365248,116204,'117930','printshop','padding-bottom','20',0,''),(365249,116204,'117930','printshop','padding-top','20',0,''),(365250,116205,'117931','printshop','max-width','300',0,'5342'),(365251,116205,'117931','printshop','margin_left_measure','auto',0,'5342'),(365252,116205,'117931','printshop','margin_right_measure','auto',0,'5342'),(365253,116206,'117932','printshop','block_type','1',0,''),(365254,116206,'117932','printshop','style_class','account-samples',0,''),(365255,116207,'117933','printshop','block_type','6',0,''),(365256,116207,'117933','printshop','schema','6-3',0,'5342'),(365257,116208,'117934','printshop','aria_name','account-menu',0,''),(365320,116228,'117935','printshop','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(365321,116229,'117936','printshop','show_pagenation','1',0,''),(365322,116229,'117936','printshop','link','Sample Info',0,''),(365323,116229,'117936','printshop','margin-bottom','20',0,''),(365324,116230,'117937','printshop','block_type','1',0,''),(365325,116230,'117937','printshop','style_class','account-sample-info',0,''),(365326,116231,'117938','printshop','block_type','6',0,''),(365327,116231,'117938','printshop','schema','6-3',0,'5342'),(365328,116232,'117939','printshop','aria_name','account-menu',0,''),(365391,116252,'117940','printshop','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(365392,116253,'117941','printshop','block_type','2',0,''),(365393,116253,'117941','printshop','padding-top','20',0,''),(365394,116253,'117941','printshop','margin-bottom','20',0,''),(365395,116254,'117942','printshop','like_button','1',0,''),(365396,116254,'117942','printshop','text','IMAGE_BUTTON_BACK',0,''),(365397,116254,'117942','printshop','link','Samples',0,''),(365398,116256,'117944','printshop','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(365399,116259,'117947','printshop','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(365400,116260,'117948','printshop','block_type','3',0,''),(365401,116261,'117949','printshop','block_type','1',0,''),(365402,116261,'117949','printshop','padding-right','20',0,''),(365403,116261,'117949','printshop','padding-bottom','20',0,''),(365404,116262,'117950','printshop','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(365405,116263,'117951','printshop','orders_data','telephone',0,''),(365406,116264,'117952','printshop','block_type','1',0,''),(365407,116264,'117952','printshop','padding-right','20',0,''),(365408,116264,'117952','printshop','padding-bottom','20',0,''),(365409,116265,'117953','printshop','orders_data','name',0,''),(365410,116266,'117954','printshop','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(365411,116267,'117955','printshop','block_type','1',0,''),(365412,116267,'117955','printshop','padding-right','20',0,''),(365413,116268,'117956','printshop','orders_data','shipping_method',0,''),(365414,116269,'117957','printshop','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(365415,116270,'117958','printshop','block_type','1',0,''),(365416,116270,'117958','printshop','padding-right','20',0,''),(365417,116270,'117958','printshop','padding-bottom','20',0,''),(365418,116271,'117959','printshop','orders_data','delivery_address',0,''),(365419,116272,'117960','printshop','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(365420,116273,'117961','printshop','block_type','1',0,''),(365421,116274,'117962','printshop','orders_data','payment_method',0,''),(365422,116275,'117963','printshop','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(365423,116276,'117964','printshop','block_type','1',0,''),(365424,116276,'117964','printshop','padding-bottom','20',0,''),(365425,116277,'117965','printshop','orders_data','billing_address',0,''),(365426,116278,'117966','printshop','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(365427,116279,'117967','printshop','block_type','1',0,''),(365428,116280,'117968','printshop','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(365429,116281,'117969','printshop','block_type','6',0,''),(365430,116282,'117970','printshop','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(365431,116283,'117971','printshop','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(365432,116284,'117972','printshop','text','<div class=\"heading-4\">Categories</div>',0,''),(365433,116287,'117975','printshop','class','menu-simple',0,''),(365434,116289,'117977','printshop','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(365435,116290,'120878','printshop','float','left',0,''),(365436,116290,'120878','printshop','margin-right','10',0,''),(365437,116291,'117978','printshop','block_type','1',0,''),(365438,116292,'117979','printshop','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(365439,116292,'117979','printshop','style_class','middle-form',0,''),(365440,116293,'117980','printshop','style_class','middle-form',0,''),(365441,116294,'117981','printshop','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(365442,116295,'117982','printshop','style_class','middle-form',0,''),(365443,116295,'117982','printshop','margin-bottom','30',0,''),(365444,116296,'117983','printshop','block_type','1',0,''),(365445,116297,'117984','printshop','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(365446,116297,'117984','printshop','padding-top','100',0,''),(365447,116297,'117984','printshop','margin-bottom','100',0,''),(365448,116297,'117984','printshop','text-align','center',0,''),(365449,116297,'117984','printshop','font-size','20',0,''),(365450,116298,'117985','printshop','block_type','1',0,''),(365451,116299,'117986','printshop','block_type','6',0,''),(365452,116299,'117986','printshop','schema','6-3',0,'5342'),(365453,116300,'117987','printshop','aria_name','account-menu',0,''),(365516,116320,'117988','printshop','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(365517,116321,'117989','printshop','text','##SUBSCRIPTION_TEXT##',0,''),(365518,116323,'1694162315.037980','printshop','block_type','1',0,''),(365519,116323,'1694162315.037980','printshop','background-color','$content-bg-2',0,''),(365520,116323,'1694162315.037980','printshop','padding-bottom','30',0,''),(365521,116323,'1694162315.037980','printshop','style_class','success-page',0,''),(365522,116323,'1694162315.037980','printshop','color','$content-color-2',0,''),(365523,116324,'1694162315.120936','printshop','block_type','12',0,''),(365524,116324,'1694162315.120936','printshop','schema','4-2',0,'5342'),(365525,116325,'1694162315.123135','printshop','block_type','1',0,''),(365526,116325,'1694162315.123135','printshop','padding-right','40',0,''),(365527,116325,'1694162315.123135','printshop','padding-right','0',0,'5342'),(365528,116326,'1694162315.12436','printshop','block_type','2',0,''),(365529,116326,'1694162315.12436','printshop','margin-bottom','20',0,''),(365530,116326,'1694162315.12436','printshop','schema','2-2',0,'5333'),(365531,116326,'1694162315.12436','printshop','background-color','$content-bg-1',0,''),(365532,116326,'1694162315.12436','printshop','color','$content-color-1',0,''),(365533,116327,'1694162315.125735','printshop','block_type','1',0,''),(365534,116327,'1694162315.125735','printshop','border-right-width','20',0,''),(365535,116327,'1694162315.125735','printshop','border-right-color','$content-bg-2',0,''),(365536,116327,'1694162315.125735','printshop','margin-right','-10',0,''),(365537,116327,'1694162315.125735','printshop','padding-right','30',0,''),(365538,116327,'1694162315.125735','printshop','padding-top','20',0,''),(365539,116327,'1694162315.125735','printshop','padding-left','30',0,''),(365540,116327,'1694162315.125735','printshop','padding-bottom','20',0,''),(365541,116327,'1694162315.125735','printshop','border-right-width','0',0,'5342'),(365542,116327,'1694162315.125735','printshop','margin-right','0',0,'5342'),(365543,116327,'1694162315.125735','printshop','margin-bottom','20',0,'5342'),(365544,116327,'1694162315.125735','printshop','padding-left','20',0,'5342'),(365545,116327,'1694162315.125735','printshop','padding-right','20',0,'5342'),(365546,116327,'1694162315.125735','printshop','background-color','$content-bg-1',0,''),(365547,116329,'1694162315.128991','printshop','margin-bottom','20',0,''),(365548,116330,'1694162315.136','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(365549,116330,'1694162315.136','printshop','padding-top','20',0,''),(365550,116331,'1694162315.143264','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(365551,116331,'1694162315.143264','printshop','clear','none',0,''),(365552,116332,'1694162315.14584','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(365553,116334,'1694162315.147338','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(365554,116334,'1694162315.147338','printshop','clear','none',0,''),(365555,116335,'1694162315.14989','printshop','block_type','1',0,''),(365556,116335,'1694162315.14989','printshop','padding-left','30',0,''),(365557,116335,'1694162315.14989','printshop','border-left-width','20',0,''),(365558,116335,'1694162315.14989','printshop','border-left-color','$content-bg-2',0,''),(365559,116335,'1694162315.14989','printshop','margin-left','-10',0,''),(365560,116335,'1694162315.14989','printshop','padding-right','30',0,''),(365561,116335,'1694162315.14989','printshop','padding-top','20',0,''),(365562,116335,'1694162315.14989','printshop','padding-bottom','20',0,''),(365563,116335,'1694162315.14989','printshop','border-left-width','0',0,'5342'),(365564,116335,'1694162315.14989','printshop','background-color','$content-bg-1',0,''),(365565,116337,'1694162315.151341','printshop','margin-bottom','20',0,''),(365566,116338,'1694162315.152381','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(365567,116338,'1694162315.152381','printshop','clear','none',0,''),(365568,116339,'1694162315.153514','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(365569,116340,'1694162315.154777','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(365570,116340,'1694162315.154777','printshop','clear','none',0,''),(365571,116341,'1694162315.155812','printshop','text','<div class=\"page-success\">\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>',0,''),(365572,116341,'1694162315.155812','printshop','background-color','$content-bg-1',0,''),(365573,116341,'1694162315.155812','printshop','margin-bottom','30',0,''),(365574,116341,'1694162315.155812','printshop','padding-top','30',0,''),(365575,116341,'1694162315.155812','printshop','padding-bottom','30',0,''),(365576,116341,'1694162315.155812','printshop','padding-left','30',0,''),(365577,116341,'1694162315.155812','printshop','padding-right','30',0,''),(365578,116341,'1694162315.155812','printshop','color','$content-color-1',0,''),(365579,116342,'1694162315.15769','printshop','block_type','1',0,''),(365580,116342,'1694162315.15769','printshop','style_class','order-summary2 hiding-box',0,''),(365581,116343,'1694162315.158534','printshop','text-align','center',0,''),(365582,116343,'1694162315.158534','printshop','margin-bottom','20',0,''),(365583,116344,'1694162315.1668','printshop','text-align','center',0,''),(365584,116347,'1694162315.163184','printshop','block_type','12',0,''),(365585,116348,'1694162315.16467','printshop','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n</div>\n',0,''),(365586,116348,'1694162315.16467','printshop','margin-bottom','20',0,''),(365587,116349,'1694162315.165266','printshop','text-align','center',0,''),(365588,116349,'1694162315.165266','printshop','padding-top','40',0,''),(365589,116350,'117997','printshop','block_type','1',0,''),(365590,116351,'117998','printshop','block_type','1',0,''),(365591,116351,'117998','printshop','font-weight','normal',0,''),(365592,116352,'117999','printshop','block_type','1',0,''),(365593,116352,'117999','printshop','text-align','center',0,''),(365594,116352,'117999','printshop','padding-top','30',0,''),(365595,116352,'117999','printshop','margin-bottom','200',0,''),(365596,116353,'118000','printshop','display','inline-block',0,''),(365597,116353,'118000','printshop','clear','none',0,''),(365598,116353,'118000','printshop','margin-left','20',0,''),(365599,116354,'118001','printshop','display','inline-block',0,''),(365600,116355,'118002','printshop','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(365605,116360,'118007','printshop','width','680',0,''),(365606,116360,'118007','printshop','font-weight','normal',0,''),(365607,116360,'118007','printshop','font-size','12',0,''),(365608,116360,'118007','printshop','padding-top','20',0,''),(365609,116360,'118007','printshop','padding-bottom','20',0,''),(365610,116360,'118007','printshop','color','$content-color-1',0,''),(365611,116361,'118008','printshop','block_type','5',0,''),(365612,116361,'118008','printshop','font-weight','normal',0,''),(365613,116361,'118008','printshop','border-bottom-width','1',0,''),(365614,116361,'118008','printshop','border-bottom-color','$content-border-3',0,''),(365615,116361,'118008','printshop','border-top-width','1',0,''),(365616,116361,'118008','printshop','border-top-color','$content-border-3',0,''),(365617,116361,'118008','printshop','border-left-color','$content-border-3',0,''),(365618,116361,'118008','printshop','border-left-width','1',0,''),(365619,116362,'118009','printshop','block_type','1',0,''),(365620,116362,'118009','printshop','font-weight','normal',0,''),(365621,116362,'118009','printshop','padding-top','10',0,''),(365622,116362,'118009','printshop','padding-left','10',0,''),(365623,116362,'118009','printshop','padding-right','10',0,''),(365624,116363,'118010','printshop','font-weight','400',0,''),(365625,116363,'118010','printshop','line-height','120',0,''),(365626,116363,'118010','printshop','line_height_measure','%',0,''),(365627,116363,'118010','printshop','font-size','12',0,''),(365628,116364,'118011','printshop','text','<p>SHIPPING ADDRESS:</p>',1,''),(365629,116364,'118011','printshop','font-size','14',0,''),(365630,116364,'118011','printshop','font-weight','bold',0,''),(365631,116364,'118011','printshop','padding-bottom','10',0,''),(365632,116364,'118011','printshop','text','<p>SHIPPING ADDRESS:</p>',2,''),(365633,116364,'118011','printshop','text','<p>SHIPPING ADDRESS:</p>',3,''),(365634,116364,'118011','printshop','text','<p>SHIPPING ADDRESS:</p>',4,''),(365635,116365,'118012','printshop','block_type','1',0,''),(365636,116365,'118012','printshop','background-color','$content-bg-2',0,''),(365637,116365,'118012','printshop','padding-top','20',0,''),(365638,116365,'118012','printshop','padding-left','10',0,''),(365639,116365,'118012','printshop','padding-right','10',0,''),(365640,116365,'118012','printshop','padding-bottom','20',0,''),(365641,116365,'118012','printshop','font-size','14',0,''),(365642,116366,'118013','printshop','font-weight','normal',0,''),(365643,116366,'118013','printshop','text-align','right',0,''),(365644,116366,'118013','printshop','font-size','14',0,''),(365645,116366,'118013','printshop','box_align','3',0,''),(365646,116367,'118014','printshop','block_type','3',0,''),(365647,116367,'118014','printshop','font-weight','normal',0,''),(365648,116367,'118014','printshop','padding-top','20',0,''),(365649,116368,'118015','printshop','text','<p>If undelivered please return to:</p>',1,''),(365650,116368,'118015','printshop','font-size','12',0,''),(365651,116368,'118015','printshop','font-weight','bold',0,''),(365652,116368,'118015','printshop','text','<p>If undelivered please return to:</p>',2,''),(365653,116368,'118015','printshop','text','<p>If undelivered please return to:</p>',3,''),(365654,116368,'118015','printshop','text','<p>If undelivered please return to:</p>',4,''),(365655,116369,'118016','printshop','font-size','12',0,''),(365656,116370,'118018','printshop','text','<p>Thank you for your order</p>',1,''),(365657,116370,'118018','printshop','color','$hileght-color-1',0,''),(365658,116370,'118018','printshop','font-size','13',0,''),(365659,116370,'118018','printshop','font-weight','bold',0,''),(365660,116370,'118018','printshop','padding-top','5',0,''),(365661,116370,'118018','printshop','text-align','center',0,''),(365662,116370,'118018','printshop','text','<p>Thank you for your order</p>',2,''),(365663,116370,'118018','printshop','text','<p>Thank you for your order</p>',3,''),(365664,116370,'118018','printshop','text','<p>Thank you for your order</p>',4,''),(365665,116371,'118019','printshop','text','<p>If something has gone wrong please contact us at:</p>',1,''),(365666,116371,'118019','printshop','font-size','12',0,''),(365667,116371,'118019','printshop','font-weight','bold',0,''),(365668,116371,'118019','printshop','text-align','right',0,''),(365669,116371,'118019','printshop','text','<p>If something has gone wrong please contact us at:</p>',2,''),(365670,116371,'118019','printshop','text','<p>If something has gone wrong please contact us at:</p>',3,''),(365671,116371,'118019','printshop','text','<p>If something has gone wrong please contact us at:</p>',4,''),(365672,116372,'118020','printshop','block_type','6',0,''),(365673,116372,'118020','printshop','font-weight','normal',0,''),(365674,116372,'118020','printshop','font-size','16',0,''),(365675,116373,'118021','printshop','text','<p>Email:</p>',1,''),(365676,116373,'118021','printshop','font-weight','normal',0,''),(365677,116373,'118021','printshop','text-align','right',0,''),(365678,116373,'118021','printshop','font-size','12',0,''),(365679,116373,'118021','printshop','text','<p>Email:</p>',2,''),(365680,116373,'118021','printshop','text','<p>Email:</p>',3,''),(365681,116373,'118021','printshop','text','<p>Email:</p>',4,''),(365682,116374,'118022','printshop','font-weight','normal',0,''),(365683,116374,'118022','printshop','text-align','right',0,''),(365684,116374,'118022','printshop','font-size','12',0,''),(365685,116375,'118023','printshop','block_type','6',0,''),(365686,116375,'118023','printshop','font-weight','normal',0,''),(365687,116375,'118023','printshop','font-size','16',0,''),(365688,116376,'118024','printshop','text','<p>Phone:</p>',1,''),(365689,116376,'118024','printshop','font-weight','normal',0,''),(365690,116376,'118024','printshop','text-align','right',0,''),(365691,116376,'118024','printshop','font-size','12',0,''),(365692,116376,'118024','printshop','text','<p>Phone:</p>',2,''),(365693,116376,'118024','printshop','text','<p>Phone:</p>',3,''),(365694,116376,'118024','printshop','text','<p>Phone:</p>',4,''),(365695,116377,'118025','printshop','font-weight','normal',0,''),(365696,116377,'118025','printshop','text-align','right',0,''),(365697,116377,'118025','printshop','font-size','12',0,''),(365698,116378,'118026','printshop','font-weight','400',0,''),(365699,116378,'118026','printshop','padding-top','20',0,''),(365700,116378,'118026','printshop','padding-bottom','0',0,''),(365701,116378,'118026','printshop','font-size','12',0,''),(365702,116379,'118027','printshop','block_type','2',0,''),(365703,116379,'118027','printshop','font-weight','normal',0,''),(365704,116379,'118027','printshop','padding-bottom','20',0,''),(365705,116380,'118028','printshop','block_type','11',0,''),(365706,116380,'118028','printshop','font-weight','normal',0,''),(365707,116381,'118029','printshop','text','<p>Email:</p>',1,''),(365708,116381,'118029','printshop','font-weight','normal',0,''),(365709,116381,'118029','printshop','text-align','right',0,''),(365710,116381,'118029','printshop','text','<p>Email:</p>',2,''),(365711,116381,'118029','printshop','text','<p>Email:</p>',3,''),(365712,116381,'118029','printshop','text','<p>Email:</p>',4,''),(365713,116382,'118030','printshop','font-weight','normal',0,''),(365714,116382,'118030','printshop','text-align','right',0,''),(365715,116383,'118031','printshop','block_type','11',0,''),(365716,116383,'118031','printshop','font-weight','normal',0,''),(365717,116384,'118032','printshop','text','<p>Web:</p>',1,''),(365718,116384,'118032','printshop','font-weight','normal',0,''),(365719,116384,'118032','printshop','text-align','right',0,''),(365720,116384,'118032','printshop','text','<p>Web:</p>',2,''),(365721,116384,'118032','printshop','text','<p>Web:</p>',3,''),(365722,116384,'118032','printshop','text','<p>Web:</p>',4,''),(365723,116385,'118033','printshop','font-weight','normal',0,''),(365724,116385,'118033','printshop','text-align','right',0,''),(365725,116386,'118034','printshop','block_type','1',0,''),(365726,116387,'118035','printshop','font-weight','normal',0,''),(365727,116387,'118035','printshop','text-align','right',0,''),(365728,116387,'118035','printshop','padding-bottom','10',0,''),(365729,116387,'118035','printshop','address_spacer',',',0,''),(365730,116387,'118035','printshop','font-size','12',0,''),(365731,116388,'118036','printshop','block_type','11',0,''),(365732,116388,'118036','printshop','font-weight','normal',0,''),(365733,116389,'118037','printshop','text','<p>Phone:</p>',1,''),(365734,116389,'118037','printshop','font-weight','normal',0,''),(365735,116389,'118037','printshop','text-align','right',0,''),(365736,116389,'118037','printshop','text','<p>Phone:</p>',2,''),(365737,116389,'118037','printshop','text','<p>Phone:</p>',3,''),(365738,116389,'118037','printshop','text','<p>Phone:</p>',4,''),(365739,116390,'118038','printshop','font-weight','normal',0,''),(365740,116390,'118038','printshop','text-align','right',0,''),(365741,116391,'118039','printshop','block_type','4',0,''),(365742,116391,'118039','printshop','font-weight','normal',0,''),(365743,116391,'118039','printshop','border-top-width','1',0,''),(365744,116391,'118039','printshop','border-top-color','$content-border-3',0,''),(365745,116391,'118039','printshop','border-left-width','1',0,''),(365746,116391,'118039','printshop','border-left-color','$content-border-3',0,''),(365747,116391,'118039','printshop','border-right-width','1',0,''),(365748,116391,'118039','printshop','border-right-color','$content-border-3',0,''),(365749,116391,'118039','printshop','border-bottom-width','1',0,''),(365750,116391,'118039','printshop','border-bottom-color','$content-border-3',0,''),(365751,116392,'118040','printshop','block_type','2',0,''),(365752,116392,'118040','printshop','font-weight','normal',0,''),(365753,116392,'118040','printshop','border-top-width','1',0,''),(365754,116392,'118040','printshop','border-top-color','$content-border-3',0,''),(365755,116392,'118040','printshop','border-right-width','1',0,''),(365756,116392,'118040','printshop','border-right-color','$content-border-3',0,''),(365757,116393,'118041','printshop','block_type','1',0,''),(365758,116393,'118041','printshop','font-weight','normal',0,''),(365759,116393,'118041','printshop','padding-top','10',0,''),(365760,116393,'118041','printshop','padding-left','10',0,''),(365761,116393,'118041','printshop','padding-right','10',0,''),(365762,116393,'118041','printshop','padding-bottom','10',0,''),(365763,116393,'118041','printshop','border-right-width','1',0,''),(365764,116393,'118041','printshop','border-right-color','$content-border-3',0,''),(365765,116394,'118042','printshop','text','<p>Shipping via</p>',1,''),(365766,116394,'118042','printshop','font-weight','bold',0,''),(365767,116394,'118042','printshop','font-size','14',0,''),(365768,116394,'118042','printshop','text','<p>Shipping via</p>',2,''),(365769,116394,'118042','printshop','text','<p>Shipping via</p>',3,''),(365770,116394,'118042','printshop','text','<p>Shipping via</p>',4,''),(365771,116396,'118044','printshop','block_type','1',0,''),(365772,116396,'118044','printshop','font-weight','normal',0,''),(365773,116396,'118044','printshop','padding-top','10',0,''),(365774,116396,'118044','printshop','padding-left','10',0,''),(365775,116396,'118044','printshop','padding-right','10',0,''),(365776,116396,'118044','printshop','padding-bottom','10',0,''),(365777,116397,'118045','printshop','text','<p>Shipping service</p>',1,''),(365778,116397,'118045','printshop','font-weight','bold',0,''),(365779,116397,'118045','printshop','font-size','14',0,''),(365780,116397,'118045','printshop','text','<p>Shipping service</p>',2,''),(365781,116397,'118045','printshop','text','<p>Shipping service</p>',3,''),(365782,116397,'118045','printshop','text','<p>Shipping service</p>',4,''),(365783,116399,'118047','printshop','block_type','2',0,''),(365784,116399,'118047','printshop','font-weight','normal',0,''),(365785,116399,'118047','printshop','border-right-width','1',0,''),(365786,116399,'118047','printshop','border-right-color','$content-border-3',0,''),(365787,116400,'118048','printshop','block_type','1',0,''),(365788,116400,'118048','printshop','font-weight','400',0,''),(365789,116400,'118048','printshop','background-color','$content-bg-2',0,''),(365790,116400,'118048','printshop','padding-top','10',0,''),(365791,116400,'118048','printshop','padding-left','10',0,''),(365792,116400,'118048','printshop','padding-right','10',0,''),(365793,116400,'118048','printshop','padding-bottom','30',0,''),(365794,116401,'118049','printshop','font-size','12',0,''),(365795,116402,'118050','printshop','text','<p>INVOICE ADDRESS:</p>',1,''),(365796,116402,'118050','printshop','font-size','14',0,''),(365797,116402,'118050','printshop','font-weight','bold',0,''),(365798,116402,'118050','printshop','text','<p>INVOICE ADDRESS:</p>',2,''),(365799,116402,'118050','printshop','text','<p>INVOICE ADDRESS:</p>',3,''),(365800,116402,'118050','printshop','text','<p>INVOICE ADDRESS:</p>',4,''),(365801,116403,'118051','printshop','block_type','1',0,''),(365802,116403,'118051','printshop','font-weight','normal',0,''),(365803,116403,'118051','printshop','padding-top','10',0,''),(365804,116403,'118051','printshop','padding-left','10',0,''),(365805,116403,'118051','printshop','padding-right','10',0,''),(365806,116403,'118051','printshop','padding-bottom','10',0,''),(365807,116404,'118052','printshop','font-weight','normal',0,''),(365808,116405,'118053','printshop','text','<p>PHONE NUMBER:</p>',1,''),(365809,116405,'118053','printshop','font-size','14',0,''),(365810,116405,'118053','printshop','font-weight','bold',0,''),(365811,116405,'118053','printshop','padding-top','10',0,''),(365812,116405,'118053','printshop','text','<p>PHONE NUMBER:</p>',2,''),(365813,116405,'118053','printshop','text','<p>PHONE NUMBER:</p>',3,''),(365814,116405,'118053','printshop','text','<p>PHONE NUMBER:</p>',4,''),(365815,116407,'118055','printshop','font-weight','normal',0,''),(365816,116408,'118056','printshop','text','<p>E-MAIL ADDRESS:</p>',1,''),(365817,116408,'118056','printshop','font-weight','bold',0,''),(365818,116408,'118056','printshop','font-size','14',0,''),(365819,116408,'118056','printshop','padding-top','10',0,''),(365820,116408,'118056','printshop','text','<p>E-MAIL ADDRESS:</p>',2,''),(365821,116408,'118056','printshop','text','<p>E-MAIL ADDRESS:</p>',3,''),(365822,116408,'118056','printshop','text','<p>E-MAIL ADDRESS:</p>',4,''),(365823,116409,'118057','printshop','text','<p>CUSTOMER:</p>',1,''),(365824,116409,'118057','printshop','font-size','13',0,''),(365825,116409,'118057','printshop','font-weight','bold',0,''),(365826,116409,'118057','printshop','text','<p>CUSTOMER:</p>',2,''),(365827,116409,'118057','printshop','text','<p>CUSTOMER:</p>',3,''),(365828,116409,'118057','printshop','text','<p>CUSTOMER:</p>',4,''),(365829,116410,'118058','printshop','font-weight','normal',0,''),(365830,116410,'118058','printshop','text-align','center',0,''),(365831,116410,'118058','printshop','padding-bottom','10',0,''),(365832,116411,'118059','printshop','text','<p>Payment date:</p>',1,''),(365833,116411,'118059','printshop','font-weight','bold',0,''),(365834,116411,'118059','printshop','text-align','center',0,''),(365835,116411,'118059','printshop','font-size','12',0,''),(365836,116411,'118059','printshop','text','<p>Payment date:</p>',2,''),(365837,116411,'118059','printshop','text','<p>Payment date:</p>',3,''),(365838,116411,'118059','printshop','text','<p>Payment date:</p>',4,''),(365839,116412,'118060','printshop','text','<p>Payment Method:</p>',1,''),(365840,116412,'118060','printshop','font-weight','bold',0,''),(365841,116412,'118060','printshop','text-align','center',0,''),(365842,116412,'118060','printshop','text','<p>Payment Method:</p>',2,''),(365843,116412,'118060','printshop','text','<p>Payment Method:</p>',3,''),(365844,116412,'118060','printshop','text','<p>Payment Method:</p>',4,''),(365845,116413,'118061','printshop','font-size','14',0,''),(365846,116413,'118061','printshop','font-weight','bold',0,''),(365847,116413,'118061','printshop','text-align','center',0,''),(365848,116413,'118061','printshop','padding-bottom','10',0,''),(365849,116413,'118061','printshop','padding-top','10',0,''),(365850,116414,'118062','printshop','font-weight','normal',0,''),(365851,116414,'118062','printshop','text-align','center',0,''),(365852,116414,'118062','printshop','padding-bottom','20',0,''),(365853,116415,'118063','printshop','font-weight','normal',0,''),(365854,116415,'118063','printshop','text-align','center',0,''),(365855,116416,'118094','printshop','block_type','1',0,''),(365856,116417,'118095','printshop','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(365857,116419,'118318','printshop','block_type','1',0,''),(365858,116420,'118319','printshop','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(365859,116420,'118319','printshop','padding-top','100',0,''),(365860,116420,'118319','printshop','margin-bottom','100',0,''),(365861,116420,'118319','printshop','text-align','center',0,''),(365862,116420,'118319','printshop','font-size','20',0,''),(365863,116421,'118320','printshop','block_type','1',0,''),(365864,116421,'118320','printshop','background-color','$content-bg-2',0,''),(365865,116421,'118320','printshop','padding-bottom','30',0,''),(365866,116422,'118321','printshop','block_type','4',0,''),(365867,116422,'118321','printshop','schema','4-2',0,'5342'),(365868,116423,'118322','printshop','block_type','1',0,''),(365869,116423,'118322','printshop','padding-right','40',0,''),(365870,116423,'118322','printshop','padding-right','0',0,'5342'),(365871,116424,'118323','printshop','block_type','2',0,''),(365872,116424,'118323','printshop','margin-bottom','20',0,''),(365873,116424,'118323','printshop','schema','2-2',0,'5333'),(365874,116424,'118323','printshop','background-color','$content-bg-1',0,''),(365875,116425,'118324','printshop','block_type','1',0,''),(365876,116425,'118324','printshop','border-right-width','20',0,''),(365877,116425,'118324','printshop','border-right-color','$content-border-3',0,''),(365878,116425,'118324','printshop','margin-right','-10',0,''),(365879,116425,'118324','printshop','padding-right','30',0,''),(365880,116425,'118324','printshop','padding-top','20',0,''),(365881,116425,'118324','printshop','padding-left','30',0,''),(365882,116425,'118324','printshop','padding-bottom','20',0,''),(365883,116425,'118324','printshop','border-right-width','0',0,'5342'),(365884,116425,'118324','printshop','margin-right','0',0,'5342'),(365885,116425,'118324','printshop','margin-bottom','20',0,'5342'),(365886,116425,'118324','printshop','padding-left','20',0,'5342'),(365887,116425,'118324','printshop','padding-right','20',0,'5342'),(365888,116427,'118326','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(365889,116427,'118326','printshop','clear','none',0,''),(365890,116428,'118327','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(365891,116428,'118327','printshop','clear','none',0,''),(365892,116429,'118328','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(365893,116431,'118330','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(365894,116431,'118330','printshop','padding-top','20',0,''),(365895,116434,'118333','printshop','margin-bottom','20',0,''),(365896,116435,'118334','printshop','block_type','1',0,''),(365897,116435,'118334','printshop','padding-left','30',0,''),(365898,116435,'118334','printshop','border-left-width','20',0,''),(365899,116435,'118334','printshop','border-left-color','$content-border-3',0,''),(365900,116435,'118334','printshop','margin-left','-10',0,''),(365901,116435,'118334','printshop','padding-right','30',0,''),(365902,116435,'118334','printshop','padding-top','20',0,''),(365903,116435,'118334','printshop','padding-bottom','20',0,''),(365904,116435,'118334','printshop','border-left-width','0',0,'5342'),(365905,116436,'118335','printshop','margin-bottom','20',0,''),(365906,116438,'118337','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(365907,116439,'118338','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(365908,116439,'118338','printshop','clear','none',0,''),(365909,116440,'118339','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(365910,116440,'118339','printshop','clear','none',0,''),(365911,116441,'118340','printshop','block_type','1',0,''),(365912,116441,'118340','printshop','padding-right','30',0,''),(365913,116441,'118340','printshop','background-color','$content-bg-1',0,''),(365914,116441,'118340','printshop','padding-top','20',0,''),(365915,116441,'118340','printshop','padding-left','30',0,''),(365916,116441,'118340','printshop','padding-bottom','20',0,''),(365917,116441,'118340','printshop','padding-left','20',0,'5342'),(365918,116441,'118340','printshop','padding-right','20',0,'5342'),(365919,116443,'118342','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(365920,116444,'118343','printshop','block_type','1',0,''),(365921,116444,'118343','printshop','padding-top','20',0,''),(365922,116444,'118343','printshop','padding-left','20',0,''),(365923,116444,'118343','printshop','padding-right','20',0,''),(365924,116444,'118343','printshop','padding-bottom','20',0,''),(365925,116444,'118343','printshop','background-color','$content-bg-1',0,''),(365926,116444,'118343','printshop','style_class','order-summary',0,''),(365927,116445,'118344','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(365928,116449,'118348','printshop','block_type','1',0,''),(365929,116449,'118348','printshop','background-color','$content-bg-2',0,''),(365930,116449,'118348','printshop','padding-bottom','30',0,''),(365931,116450,'118349','printshop','block_type','4',0,''),(365932,116450,'118349','printshop','schema','4-2',0,'5342'),(365933,116451,'118350','printshop','block_type','1',0,''),(365934,116451,'118350','printshop','padding-right','40',0,''),(365935,116451,'118350','printshop','padding-right','0',0,'5342'),(365936,116451,'118350','printshop','padding-bottom','20',0,'5342'),(365937,116452,'118351','printshop','block_type','2',0,''),(365938,116452,'118351','printshop','margin-bottom','20',0,''),(365939,116452,'118351','printshop','schema','2-2',0,'5333'),(365940,116452,'118351','printshop','background-color','$content-bg-1',0,''),(365941,116453,'118352','printshop','block_type','1',0,''),(365942,116453,'118352','printshop','border-right-width','20',0,''),(365943,116453,'118352','printshop','border-right-color','$content-border-3',0,''),(365944,116453,'118352','printshop','margin-right','-10',0,''),(365945,116453,'118352','printshop','padding-right','30',0,''),(365946,116453,'118352','printshop','padding-top','20',0,''),(365947,116453,'118352','printshop','padding-left','30',0,''),(365948,116453,'118352','printshop','padding-bottom','20',0,''),(365949,116453,'118352','printshop','border-right-width','0',0,'5342'),(365950,116453,'118352','printshop','margin-right','0',0,'5342'),(365951,116453,'118352','printshop','margin-bottom','20',0,'5342'),(365952,116453,'118352','printshop','padding-left','20',0,'5342'),(365953,116453,'118352','printshop','padding-right','20',0,'5342'),(365954,116454,'118353','printshop','margin-bottom','20',0,''),(365955,116457,'118356','printshop','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(365956,116457,'118356','printshop','padding-top','20',0,''),(365957,116459,'118358','printshop','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(365958,116459,'118358','printshop','clear','none',0,''),(365959,116461,'118360','printshop','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(365960,116462,'118361','printshop','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(365961,116462,'118361','printshop','clear','none',0,''),(365962,116464,'118362','printshop','block_type','1',0,''),(365963,116464,'118362','printshop','padding-left','30',0,''),(365964,116464,'118362','printshop','border-left-width','20',0,''),(365965,116464,'118362','printshop','border-left-color','$content-border-3',0,''),(365966,116464,'118362','printshop','margin-left','-10',0,''),(365967,116464,'118362','printshop','padding-right','30',0,''),(365968,116464,'118362','printshop','padding-top','20',0,''),(365969,116464,'118362','printshop','padding-bottom','20',0,''),(365970,116464,'118362','printshop','border-left-width','0',0,'5342'),(365971,116465,'118363','printshop','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(365972,116466,'118364','printshop','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(365973,116466,'118364','printshop','clear','none',0,''),(365974,116467,'118365','printshop','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(365975,116467,'118365','printshop','clear','none',0,''),(365976,116468,'118366','printshop','margin-bottom','20',0,''),(365977,116469,'118367','printshop','orders_data','name',0,''),(365978,116470,'118368','printshop','block_type','1',0,''),(365979,116470,'118368','printshop','padding-right','30',0,''),(365980,116470,'118368','printshop','background-color','$content-bg-1',0,''),(365981,116470,'118368','printshop','padding-top','20',0,''),(365982,116470,'118368','printshop','padding-left','30',0,''),(365983,116470,'118368','printshop','padding-bottom','20',0,''),(365984,116470,'118368','printshop','padding-left','20',0,'5342'),(365985,116470,'118368','printshop','padding-right','20',0,'5342'),(365986,116471,'118369','printshop','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(365987,116473,'118371','printshop','block_type','1',0,''),(365988,116473,'118371','printshop','padding-top','20',0,''),(365989,116473,'118371','printshop','padding-left','20',0,''),(365990,116473,'118371','printshop','padding-right','20',0,''),(365991,116473,'118371','printshop','padding-bottom','20',0,''),(365992,116473,'118371','printshop','background-color','$content-bg-1',0,''),(365993,116473,'118371','printshop','style_class','order-summary',0,''),(365994,116476,'118374','printshop','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(365995,116478,'118440','printshop','block_type','1',0,''),(365996,116479,'118441','printshop','block_type','6',0,''),(365997,116479,'118441','printshop','schema','6-3',0,'5342'),(365998,116480,'118442','printshop','aria_name','account-menu',0,''),(365999,116481,'116126','printshop','block_type','1',0,''),(366000,116481,'116126','printshop','padding-right','30',0,''),(366001,116481,'116126','printshop','padding-bottom','30',0,''),(366002,116481,'116126','printshop','padding-top','0',0,'5342'),(366003,116481,'116126','printshop','padding-left','0',0,'5342'),(366004,116481,'116126','printshop','padding-right','0',0,'5342'),(366005,116481,'116126','printshop','padding-bottom','0',0,'5342'),(366061,116500,'118443','printshop','margin-bottom','20',0,''),(366062,116501,'118444','printshop','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(366063,116502,'118445','printshop','block_type','1',0,''),(366064,116502,'118445','printshop','padding-top','20',0,''),(366065,116502,'118445','printshop','padding-bottom','20',0,''),(366066,116504,'118447','printshop','padding-top','20',0,''),(366067,116504,'118447','printshop','padding-bottom','20',0,''),(382940,121477,'116005','deals','text','##TEXT_PAGE_NOT_FOUND##',0,''),(382941,121477,'116005','deals','text-align','center',0,''),(382942,121477,'116005','deals','padding-top','100',0,''),(382943,121477,'116005','deals','padding-bottom','100',0,''),(382944,121478,'116006','deals','block_type','1',0,''),(383063,121494,'116022','deals','block_type','1',0,''),(383182,121510,'116038','deals','block_type','1',0,''),(383301,121526,'116054','deals','block_type','1',0,''),(383420,121542,'116070','deals','block_type','1',0,''),(383539,121558,'116086','deals','block_type','1',0,''),(383658,121574,'116102','deals','block_type','1',0,''),(383659,121574,'116102','deals','style_class','account-index',0,''),(383898,121632,'116145','deals','block_type','1',0,''),(383899,121632,'116145','deals','style_class','account-edit-wrap',0,''),(383967,121656,'116150','deals','block_type','1',0,''),(383968,121656,'116150','deals','style_class','account-address-book',0,''),(384046,121681,'116156','deals','block_type','1',0,''),(384047,121681,'116156','deals','style_class','account-address-book-process',0,''),(384115,121705,'117906','deals','block_type','1',0,''),(384116,121705,'117906','deals','style_class','item-holder',0,''),(384117,121705,'117906','deals','padding-top','25',0,''),(384118,121705,'117906','deals','padding-bottom','25',0,''),(384119,121705,'117906','deals','text-align','left',0,''),(384120,121705,'117906','deals','border-top-width','1',0,''),(384121,121705,'117906','deals','border-top-color','$content-border-1',0,''),(384122,121706,'117907','deals','block_type','7',0,''),(384123,121706,'117907','deals','schema','7-2',0,'5639'),(384124,121707,'117908','deals','block_type','5',0,''),(384125,121707,'117908','deals','schema','5-2',0,'5639'),(384126,121708,'117909','deals','clear','none',0,''),(384127,121708,'117909','deals','padding-right','20',0,''),(384128,121709,'117910','deals','padding-right','20',0,''),(384129,121709,'117910','deals','max-width','300',0,'5639'),(384130,121709,'117910','deals','margin_left_measure','auto',0,'5639'),(384131,121709,'117910','deals','margin_right_measure','auto',0,'5639'),(384132,121710,'117914','deals','padding-right','20',0,''),(384133,121711,'117915','deals','description_characters','200',0,''),(384134,121711,'117915','deals','clear','none',0,''),(384135,121711,'117915','deals','padding-right','20',0,''),(384136,121712,'117916','deals','clear','none',0,''),(384137,121713,'117917','deals','margin-bottom','20',0,''),(384138,121715,'117918','deals','block_type','1',0,''),(384139,121715,'117918','deals','padding-left','40',0,''),(384140,121715,'117918','deals','style_class','right-aria',0,''),(384141,121715,'117918','deals','padding-left','0',0,'5639'),(384142,121716,'117911','deals','block_type','1',0,''),(384143,121716,'117911','deals','text-align','center',0,''),(384144,121717,'117912','deals','margin-top','4',0,''),(384145,121717,'117912','deals','margin-bottom','7',0,''),(384146,121718,'117913','deals','padding-top','6',0,''),(384147,121718,'117913','deals','padding-left','5',0,''),(384148,121719,'117919','deals','margin-bottom','15',0,''),(384149,121719,'117919','deals','text-align','right',0,''),(384150,121720,'117920','deals','margin-bottom','10',0,''),(384151,121720,'117920','deals','text-align','center',0,''),(384152,121721,'117924','deals','text-align','center',0,''),(384153,121721,'117924','deals','margin-bottom','10',0,''),(384154,121722,'120924','deals','block_type','1',0,''),(384155,121722,'120924','deals','style_class','item-nav',0,''),(384156,121726,'116176','deals','block_type','1',0,''),(384157,121726,'116176','deals','style_class','item-holder',0,''),(384158,121726,'116176','deals','padding-top','25',0,''),(384159,121726,'116176','deals','padding-left','25',0,''),(384160,121726,'116176','deals','padding-right','25',0,''),(384161,121726,'116176','deals','padding-bottom','25',0,''),(384162,121726,'116176','deals','text-align','left',0,''),(384163,121728,'116178','deals','margin-bottom','7',0,''),(384164,121729,'116179','deals','clear','both',0,''),(384165,121732,'116182','deals','block_type','1',0,''),(384166,121732,'116182','deals','style_class','item-holder',0,''),(384167,121732,'116182','deals','padding-top','25',0,''),(384168,121732,'116182','deals','padding-left','25',0,''),(384169,121732,'116182','deals','padding-right','25',0,''),(384170,121732,'116182','deals','padding-bottom','25',0,''),(384171,121732,'116182','deals','text-align','left',0,''),(384172,121733,'116183','deals','block_type','5',0,''),(384173,121736,'116186','deals','margin-bottom','7',0,''),(384174,121737,'116187','deals','clear','both',0,''),(384175,121738,'116188','deals','block_type','1',0,''),(384176,121739,'116189','deals','block_type','6',0,''),(384177,121739,'116189','deals','font-weight','400',0,''),(384178,121739,'116189','deals','schema','6-2',0,'5660'),(384179,121739,'116189','deals','schema','6-2',0,'5639'),(384180,121740,'116190','deals','font-weight','400',0,''),(384181,121740,'116190','deals','padding-right','40',0,''),(384182,121740,'116190','deals','padding-right','0',0,'5660'),(384183,121740,'116190','deals','padding-right','0',0,'5639'),(384184,121741,'116191','deals','block_type','5',0,''),(384185,121741,'116191','deals','padding-top','10',0,''),(384186,121741,'116191','deals','padding-bottom','10',0,''),(384187,121741,'116191','deals','schema','5-2',0,'5660'),(384188,121741,'116191','deals','border-top-color','$content-border-1',0,''),(384189,121741,'116191','deals','border-top-width','1',0,''),(384190,121743,'116193','deals','float','right',0,''),(384191,121745,'116195','deals','col_in_row','3',0,''),(384192,121745,'116195','deals','products_align','left',0,''),(384193,121745,'116195','deals','font-weight','400',0,''),(384194,121745,'116195','deals','show_qty_input','0',0,''),(384195,121745,'116195','deals','listing_type','productListing',0,''),(384196,121745,'116195','deals','listing_type_rows','no',0,''),(384197,121745,'116195','deals','show_buy_button_b2b','on',0,''),(384198,121745,'116195','deals','show_wishlist_button_b2b','1',0,''),(384199,121745,'116195','deals','show_compare_b2b','1',0,''),(384200,121745,'116195','deals','show_stock','0',0,''),(384201,121745,'116195','deals','show_description','0',0,''),(384202,121745,'116195','deals','show_model','0',0,''),(384203,121745,'116195','deals','show_properties','0',0,''),(384204,121745,'116195','deals','show_rating','0',0,''),(384205,121745,'116195','deals','show_rating_counts','0',0,''),(384206,121745,'116195','deals','show_price','0',0,''),(384207,121745,'116195','deals','show_buy_button','0',0,''),(384208,121745,'116195','deals','show_view_button','0',0,''),(384209,121745,'116195','deals','show_wishlist_button','0',0,''),(384210,121745,'116195','deals','show_compare','0',0,''),(384211,121745,'116195','deals','show_name_rows','0',0,''),(384212,121745,'116195','deals','show_image_rows','0',0,''),(384213,121745,'116195','deals','show_stock_rows','0',0,''),(384214,121745,'116195','deals','show_description_rows','0',0,''),(384215,121745,'116195','deals','show_model_rows','0',0,''),(384216,121745,'116195','deals','show_properties_rows','0',0,''),(384217,121745,'116195','deals','show_rating_rows','0',0,''),(384218,121745,'116195','deals','show_rating_counts_rows','0',0,''),(384219,121745,'116195','deals','show_price_rows','0',0,''),(384220,121745,'116195','deals','show_buy_button_rows','0',0,''),(384221,121745,'116195','deals','show_qty_input_rows','0',0,''),(384222,121745,'116195','deals','show_view_button_rows','0',0,''),(384223,121745,'116195','deals','show_wishlist_button_rows','0',0,''),(384224,121745,'116195','deals','show_compare_rows','0',0,''),(384225,121745,'116195','deals','show_name_b2b','0',0,''),(384226,121745,'116195','deals','show_image_b2b','0',0,''),(384227,121745,'116195','deals','show_stock_b2b','0',0,''),(384228,121745,'116195','deals','show_description_b2b','0',0,''),(384229,121745,'116195','deals','show_model_b2b','0',0,''),(384230,121745,'116195','deals','show_properties_b2b','0',0,''),(384231,121745,'116195','deals','show_rating_b2b','0',0,''),(384232,121745,'116195','deals','show_rating_counts_b2b','0',0,''),(384233,121745,'116195','deals','show_price_b2b','0',0,''),(384234,121745,'116195','deals','show_qty_input_b2b','0',0,''),(384235,121745,'116195','deals','show_view_button_b2b','0',0,''),(384236,121745,'116195','deals','show_attributes_b2b','0',0,''),(384237,121745,'116195','deals','items_on_page','9',0,''),(384238,121745,'116195','deals','col_in_row','2',0,'5639'),(384239,121745,'116195','deals','col_in_row','1',0,'5660'),(384240,121745,'116195','deals','product_names_teg','h2',0,''),(384241,121746,'116196','deals','listing_type','productListing',0,''),(384242,121747,'116197','deals','block_type','1',0,''),(384243,121747,'116197','deals','padding-top','10',0,''),(384244,121747,'116197','deals','padding-bottom','10',0,''),(384245,121747,'116197','deals','border-bottom-width','1',0,''),(384246,121747,'116197','deals','border-bottom-color','$content-border-1',0,''),(384247,121747,'116197','deals','margin-left','0',0,''),(384248,121747,'116197','deals','margin-right','0',0,''),(384249,121748,'116198','deals','float','right',0,''),(384250,121748,'116198','deals','display','none',0,'5660'),(384251,121749,'116199','deals','margin-right','20',0,''),(384252,121749,'116199','deals','float','right',0,''),(384253,121749,'116199','deals','clear','none',0,''),(384254,121749,'116199','deals','display','none',0,'5639'),(384255,121750,'116200','deals','float','left',0,''),(384256,121750,'116200','deals','clear','none',0,''),(384257,121750,'116200','deals','margin-left','20',0,''),(384258,121750,'116200','deals','display','none',0,'5660'),(384259,121751,'116201','deals','float','left',0,''),(384260,121751,'116201','deals','clear','none',0,''),(384261,121751,'116201','deals','sort_pos_3','1',0,''),(384262,121751,'116201','deals','sort_pos_4','2',0,''),(384263,121751,'116201','deals','sort_pos_10','3',0,''),(384264,121751,'116201','deals','sort_pos_9','4',0,''),(384265,121751,'116201','deals','sort_pos_11','5',0,''),(384266,121751,'116201','deals','sort_pos_12','6',0,''),(384267,121751,'116201','deals','sort_pos_14','7',0,''),(384268,121751,'116201','deals','sort_pos_13','8',0,''),(384269,121751,'116201','deals','sort_pos_8','9',0,''),(384270,121751,'116201','deals','sort_pos_7','10',0,''),(384271,121751,'116201','deals','sort_pos_2','11',0,''),(384272,121751,'116201','deals','sort_pos_1','12',0,''),(384273,121751,'116201','deals','sort_pos_6','13',0,''),(384274,121751,'116201','deals','sort_pos_5','14',0,''),(384275,121751,'116201','deals','sort_pos_0','15',0,''),(384276,121751,'116201','deals','sort_hide_10','1',0,''),(384277,121751,'116201','deals','sort_hide_9','1',0,''),(384278,121751,'116201','deals','hide_icons','1',0,''),(384279,121751,'116201','deals','sort_hide_16','1',0,''),(384280,121751,'116201','deals','sort_hide_15','1',0,''),(384281,121751,'116201','deals','sort_hide_3','0',0,''),(384282,121751,'116201','deals','sort_hide_4','0',0,''),(384283,121751,'116201','deals','sort_hide_11','1',0,''),(384284,121751,'116201','deals','sort_hide_12','1',0,''),(384285,121751,'116201','deals','sort_hide_14','1',0,''),(384286,121751,'116201','deals','sort_hide_13','1',0,''),(384287,121751,'116201','deals','sort_hide_8','0',0,''),(384288,121751,'116201','deals','sort_hide_7','0',0,''),(384289,121751,'116201','deals','sort_hide_2','1',0,''),(384290,121751,'116201','deals','sort_hide_1','1',0,''),(384291,121751,'116201','deals','sort_hide_6','1',0,''),(384292,121751,'116201','deals','sort_hide_5','1',0,''),(384293,121751,'116201','deals','sort_hide_0','1',0,''),(384294,121754,'1683114704.562135','deals','block_type','1',0,''),(384295,121754,'1683114704.562135','deals','font-weight','normal',0,''),(384296,121754,'1683114704.562135','deals','padding-top','20',0,''),(384297,121754,'1683114704.562135','deals','style_class','shopping-cart-index',0,''),(384298,121755,'1683114704.57226','deals','block_type','4',0,''),(384299,121755,'1683114704.57226','deals','schema','4-1',0,'5644'),(384300,121755,'1683114704.57226','deals','schema','4-2',0,'5639'),(384301,121756,'1683114704.58194','deals','block_type','1',0,''),(384302,121756,'1683114704.58194','deals','margin-bottom','25',0,''),(384303,121757,'1683114704.582420','deals','padding-top','20',0,''),(384304,121757,'1683114704.582420','deals','padding-bottom','20',0,''),(384305,121758,'1683114704.583230','deals','block_type','2',0,''),(384306,121758,'1683114704.583230','deals','padding-bottom','20',0,''),(384307,121758,'1683114704.583230','deals','padding-top','20',0,''),(384308,121758,'1683114704.583230','deals','border-bottom-color','$content-border-1',0,''),(384309,121758,'1683114704.583230','deals','border-bottom-width','1',0,''),(384310,121758,'1683114704.583230','deals','schema','2-2',0,'5639'),(384311,121759,'1683114704.585598','deals','float','left',0,''),(384312,121759,'1683114704.585598','deals','float','none',0,'5639'),(384313,121760,'1683114704.586389','deals','text-align','right',0,''),(384314,121760,'1683114704.586389','deals','clear','none',0,''),(384315,121760,'1683114704.586389','deals','float','right',0,''),(384316,121760,'1683114704.586389','deals','padding-top','22',0,''),(384317,121760,'1683114704.586389','deals','float','none',0,'5639'),(384318,121760,'1683114704.586389','deals','text-align','left',0,'5639'),(384319,121761,'1683114704.587718','deals','float','right',0,''),(384320,121761,'1683114704.587718','deals','padding-top','26',0,''),(384321,121761,'1683114704.587718','deals','float','none',0,'5639'),(384322,121761,'1683114704.587718','deals','text-align','left',0,'5639'),(384323,121762,'1683114704.58974','deals','text','<div>##TEXT_YOUR_SHOPPING_CART##</div>',0,''),(384324,121762,'1683114704.58974','deals','style_class','cartTitle',0,''),(384325,121762,'1683114704.58974','deals','padding-top','20',0,''),(384326,121762,'1683114704.58974','deals','margin-bottom','20',0,''),(384327,121762,'1683114704.58974','deals','font-size','24',0,'5639'),(384328,121762,'1683114704.58974','deals','font-size','32',0,''),(384329,121762,'1683114704.58974','deals','font-weight','400',0,''),(384330,121763,'1683114704.594755','deals','font-weight','normal',0,''),(384331,121763,'1683114704.594755','deals','hide_parents','2',0,''),(384332,121763,'1683114704.594755','deals','style_class','closeable-content',0,''),(384333,121763,'1683114704.594755','deals','margin-bottom','30',0,''),(384334,121764,'1683114704.595625','deals','listing_type','productListing',0,''),(384335,121764,'1683114704.595625','deals','col_in_row','4',0,''),(384336,121764,'1683114704.595625','deals','show_popup','1',0,''),(384337,121764,'1683114704.595625','deals','col_in_row','3',0,'5639'),(384338,121764,'1683114704.595625','deals','col_in_row','2',0,'5630'),(384339,121764,'1683114704.595625','deals','col_in_row','1',0,'5660'),(384340,121764,'1683114704.595625','deals','padding-top','20',0,''),(384341,121764,'1683114704.595625','deals','padding-left','25',0,''),(384342,121764,'1683114704.595625','deals','padding-right','25',0,''),(384343,121764,'1683114704.595625','deals','padding-bottom','20',0,''),(384344,121764,'1683114704.595625','deals','background-color','$content-bg-1',0,''),(384345,121764,'1683114704.595625','deals','margin-bottom','25',0,''),(384346,121765,'1683114704.601126','deals','block_type','1',0,''),(384347,121765,'1683114704.601126','deals','style_class','closeable-content',0,''),(384348,121766,'1683114704.602943','deals','block_type','2',0,''),(384349,121766,'1683114704.602943','deals','schema','2-2',0,'5630'),(384350,121768,'1683114704.605124','deals','padding-right','24',0,''),(384351,121768,'1683114704.605124','deals','padding-right','0',0,'5630'),(384352,121768,'1683114704.605124','deals','padding-bottom','20',0,'5630'),(384353,121769,'1683114704.606118','deals','style_class','order-summary',0,''),(384354,121769,'1683114704.606118','deals','block_type','1',0,''),(384355,121769,'1683114704.606118','deals','margin-left','25',0,''),(384356,121769,'1683114704.606118','deals','margin-left','0',0,'5639'),(384357,121769,'1683114704.606118','deals','margin-bottom','30',0,'5639'),(384358,121769,'1683114704.606118','deals','padding-bottom','10',0,''),(384359,121769,'1683114704.606118','deals','background-color','$content-bg-1',0,''),(384360,121770,'1683114704.608683','deals','block_type','1',0,''),(384361,121771,'1683114704.609838','deals','font-weight','400',0,''),(384362,121771,'1683114704.609838','deals','padding-right','0',0,'5630'),(384363,121772,'1683114704.623818','deals','font-weight','400',0,''),(384364,121772,'1683114704.623818','deals','box_align','4',0,''),(384365,121772,'1683114704.623818','deals','text-align','center',0,'5630'),(384366,121772,'1683114704.623818','deals','float','none',0,'5630'),(384367,121772,'1683114704.623818','deals','width','100',0,'5630'),(384368,121772,'1683114704.623818','deals','width_measure','%',0,'5630'),(384369,121773,'1683114704.62578','deals','style_class','bottom-totals',0,''),(384370,121774,'1683114704.626342','deals','style_class','top-totals',0,''),(384371,121775,'1683114704.62755','deals','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(384372,121776,'116242','deals','block_type','1',0,''),(384373,121776,'116242','deals','font-weight','normal',0,''),(384374,121776,'116242','deals','padding-top','20',0,''),(384375,121776,'116242','deals','background-color','$content-bg-2',0,''),(384376,121778,'116244','deals','block_type','4',0,''),(384377,121778,'116244','deals','schema','4-1',0,'5644'),(384378,121778,'116244','deals','schema','4-2',0,'5639'),(384379,121779,'116245','deals','block_type','1',0,''),(384380,121779,'116245','deals','background-color','$content-bg-1',0,''),(384381,121779,'116245','deals','padding-top','20',0,''),(384382,121779,'116245','deals','padding-bottom','20',0,''),(384383,121779,'116245','deals','padding-left','25',0,''),(384384,121779,'116245','deals','padding-right','25',0,''),(384385,121779,'116245','deals','margin-bottom','30',0,''),(384386,121780,'116246','deals','col_in_row','3',0,''),(384387,121780,'116246','deals','show_description','1',0,''),(384388,121780,'116246','deals','show_model','1',0,''),(384389,121780,'116246','deals','show_properties','1',0,''),(384390,121780,'116246','deals','show_rating','1',0,''),(384391,121780,'116246','deals','show_rating_counts','1',0,''),(384392,121780,'116246','deals','show_qty_input','1',0,''),(384393,121780,'116246','deals','show_view_button','1',0,''),(384394,121780,'116246','deals','show_wishlist_button','1',0,''),(384395,121780,'116246','deals','show_compare','1',0,''),(384396,121780,'116246','deals','view_as','carousel',0,''),(384397,121780,'116246','deals','hide_parents','2',0,''),(384398,121781,'116247','deals','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(384399,121781,'116247','deals','style_class','bell-ico',0,''),(384400,121782,'116248','deals','block_type','1',0,''),(384401,121782,'116248','deals','background-color','$content-bg-1',0,''),(384402,121782,'116248','deals','margin-bottom','30',0,''),(384403,121783,'116249','deals','padding-top','20',0,''),(384404,121783,'116249','deals','padding-left','25',0,''),(384405,121783,'116249','deals','padding-right','25',0,''),(384406,121783,'116249','deals','padding-bottom','20',0,''),(384407,121784,'116250','deals','block_type','2',0,''),(384408,121784,'116250','deals','padding-bottom','20',0,''),(384409,121784,'116250','deals','padding-top','20',0,''),(384410,121784,'116250','deals','padding-left','25',0,''),(384411,121784,'116250','deals','padding-right','25',0,''),(384412,121784,'116250','deals','border-bottom-color','$content-border-1',0,''),(384413,121784,'116250','deals','border-bottom-width','1',0,''),(384414,121784,'116250','deals','schema','2-2',0,'5639'),(384415,121785,'116251','deals','float','left',0,''),(384416,121786,'116252','deals','text-align','right',0,''),(384417,121786,'116252','deals','clear','none',0,''),(384418,121786,'116252','deals','float','right',0,''),(384419,121786,'116252','deals','padding-top','22',0,''),(384420,121787,'116253','deals','float','right',0,''),(384421,121787,'116253','deals','padding-top','26',0,''),(384422,121788,'116254','deals','block_type','1',0,''),(384423,121788,'116254','deals','padding-top','20',0,''),(384424,121788,'116254','deals','padding-bottom','20',0,''),(384425,121788,'116254','deals','padding-left','25',0,''),(384426,121788,'116254','deals','padding-right','25',0,''),(384427,121788,'116254','deals','background-color','$content-bg-1',0,''),(384428,121788,'116254','deals','margin-bottom','30',0,''),(384429,121789,'116255','deals','hide_parents','2',0,''),(384430,121790,'116256','deals','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(384431,121791,'116257','deals','block_type','1',0,''),(384432,121791,'116257','deals','background-color','$content-bg-1',0,''),(384433,121791,'116257','deals','padding-top','20',0,''),(384434,121791,'116257','deals','padding-bottom','20',0,''),(384435,121791,'116257','deals','padding-left','25',0,''),(384436,121791,'116257','deals','padding-right','25',0,''),(384437,121791,'116257','deals','margin-bottom','30',0,''),(384438,121791,'116257','deals','style_class','closeable-box',0,''),(384439,121792,'116258','deals','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(384440,121792,'116258','deals','style_class','savings-ico closeable-heading closeable-event',0,''),(384441,121793,'116259','deals','block_type','3',0,''),(384442,121793,'116259','deals','font-weight','400',0,''),(384443,121793,'116259','deals','schema','2-2',0,'5630'),(384444,121793,'116259','deals','style_class','closeable-content',0,''),(384445,121793,'116259','deals','padding-top','10',0,''),(384446,121794,'116260','deals','font-weight','400',0,''),(384447,121794,'116260','deals','padding-top','12',0,'5630'),(384448,121794,'116260','deals','padding-left','0',0,'5630'),(384449,121797,'116263','deals','block_type','1',0,''),(384450,121797,'116263','deals','background-color','$content-bg-1',0,''),(384451,121797,'116263','deals','padding-top','20',0,''),(384452,121797,'116263','deals','padding-left','25',0,''),(384453,121797,'116263','deals','padding-right','25',0,''),(384454,121797,'116263','deals','padding-bottom','20',0,''),(384455,121797,'116263','deals','margin-bottom','30',0,''),(384456,121797,'116263','deals','style_class','closeable-box',0,''),(384457,121797,'116263','deals','display','none',0,'5639'),(384458,121798,'116264','deals','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(384459,121798,'116264','deals','style_class','shipping-ico closeable-heading closeable-event',0,''),(384460,121799,'116265','deals','font-weight','normal',0,''),(384461,121799,'116265','deals','style_class','closeable-content',0,''),(384462,121799,'116265','deals','padding-top','10',0,''),(384463,121799,'116265','deals','hide_parents','2',0,''),(384464,121800,'116266','deals','style_class','order-summary',0,''),(384465,121800,'116266','deals','block_type','1',0,''),(384466,121800,'116266','deals','margin-left','30',0,''),(384467,121800,'116266','deals','margin-left','0',0,'5639'),(384468,121800,'116266','deals','margin-bottom','30',0,'5639'),(384469,121801,'116267','deals','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(384470,121802,'116268','deals','block_type','1',0,''),(384471,121802,'116268','deals','padding-left','20',0,''),(384472,121802,'116268','deals','padding-right','20',0,''),(384473,121802,'116268','deals','padding-bottom','20',0,''),(384474,121803,'116269','deals','font-weight','400',0,''),(384475,121803,'116269','deals','logo','themes/deals/img/payicons.png',1,''),(384476,121803,'116269','deals','padding-top','20',0,''),(384477,121803,'116269','deals','padding-bottom','10',0,''),(384478,121803,'116269','deals','logo','themes/deals/img/payicons.png',2,''),(384479,121803,'116269','deals','logo','themes/deals/img/payicons.png',3,''),(384480,121803,'116269','deals','logo','themes/deals/img/payicons.png',4,''),(384481,121804,'116270','deals','font-weight','400',0,''),(384482,121804,'116270','deals','box_align','4',0,''),(384483,121804,'116270','deals','text-align','center',0,'5630'),(384484,121804,'116270','deals','float','none',0,'5630'),(384485,121804,'116270','deals','width','100',0,'5630'),(384486,121804,'116270','deals','width_measure','%',0,'5630'),(384491,121816,'116272','deals','block_type','1',0,''),(384492,121817,'116275','deals','col_in_row','5',0,''),(384493,121817,'116275','deals','products_align','left',0,''),(384494,121817,'116275','deals','font-weight','400',0,''),(384495,121817,'116275','deals','listing_type','productListing',0,''),(384496,121817,'116275','deals','listing_type_rows','Rows',0,''),(384497,121817,'116275','deals','show_buy_button_b2b','on',0,''),(384498,121817,'116275','deals','show_wishlist_button_b2b','1',0,''),(384499,121817,'116275','deals','show_compare_b2b','1',0,''),(384500,121817,'116275','deals','show_price','0',0,''),(384501,121817,'116275','deals','show_view_button','0',0,''),(384502,121817,'116275','deals','show_name_rows','0',0,''),(384503,121817,'116275','deals','show_image_rows','0',0,''),(384504,121817,'116275','deals','show_stock_rows','0',0,''),(384505,121817,'116275','deals','show_description_rows','0',0,''),(384506,121817,'116275','deals','show_model_rows','0',0,''),(384507,121817,'116275','deals','show_properties_rows','0',0,''),(384508,121817,'116275','deals','show_rating_rows','0',0,''),(384509,121817,'116275','deals','show_rating_counts_rows','0',0,''),(384510,121817,'116275','deals','show_price_rows','0',0,''),(384511,121817,'116275','deals','show_buy_button_rows','0',0,''),(384512,121817,'116275','deals','show_qty_input_rows','0',0,''),(384513,121817,'116275','deals','show_view_button_rows','0',0,''),(384514,121817,'116275','deals','show_wishlist_button_rows','0',0,''),(384515,121817,'116275','deals','show_compare_rows','0',0,''),(384516,121817,'116275','deals','show_name_b2b','0',0,''),(384517,121817,'116275','deals','show_image_b2b','0',0,''),(384518,121817,'116275','deals','show_stock_b2b','0',0,''),(384519,121817,'116275','deals','show_description_b2b','0',0,''),(384520,121817,'116275','deals','show_model_b2b','0',0,''),(384521,121817,'116275','deals','show_properties_b2b','0',0,''),(384522,121817,'116275','deals','show_rating_b2b','0',0,''),(384523,121817,'116275','deals','show_rating_counts_b2b','0',0,''),(384524,121817,'116275','deals','show_price_b2b','0',0,''),(384525,121817,'116275','deals','show_qty_input_b2b','0',0,''),(384526,121817,'116275','deals','show_view_button_b2b','0',0,''),(384527,121817,'116275','deals','show_attributes_b2b','0',0,''),(384528,121817,'116275','deals','items_on_page','15',0,''),(384529,121817,'116275','deals','col_in_row','3',0,'5639'),(384530,121817,'116275','deals','col_in_row','1',0,'5660'),(384531,121817,'116275','deals','product_names_teg','h2',0,''),(384532,121817,'116275','deals','col_in_row','4',0,'5644'),(384533,121818,'116277','deals','block_type','5',0,''),(384534,121818,'116277','deals','padding-top','10',0,''),(384535,121818,'116277','deals','padding-bottom','10',0,''),(384536,121818,'116277','deals','schema','5-2',0,'5660'),(384537,121818,'116277','deals','border-top-color','$content-border-1',0,''),(384538,121818,'116277','deals','border-top-width','1',0,''),(384539,121820,'116279','deals','float','right',0,''),(384540,121822,'116282','deals','block_type','1',0,''),(384541,121822,'116282','deals','padding-top','10',0,''),(384542,121822,'116282','deals','padding-bottom','10',0,''),(384543,121822,'116282','deals','border-bottom-width','1',0,''),(384544,121822,'116282','deals','border-bottom-color','$content-border-1',0,''),(384545,121822,'116282','deals','margin-left','0',0,''),(384546,121822,'116282','deals','margin-right','0',0,''),(384547,121823,'116283','deals','float','right',0,''),(384548,121823,'116283','deals','display','none',0,'5660'),(384549,121825,'1641809968','deals','block_type','1',0,''),(384550,121825,'1641809968','deals','style_class','filterLine',0,''),(384551,121826,'116286','deals','float','left',0,''),(384552,121826,'116286','deals','clear','none',0,''),(384553,121826,'116286','deals','sort_pos_3','2',0,''),(384554,121826,'116286','deals','sort_pos_4','3',0,''),(384555,121826,'116286','deals','sort_pos_10','11',0,''),(384556,121826,'116286','deals','sort_pos_9','10',0,''),(384557,121826,'116286','deals','sort_pos_11','12',0,''),(384558,121826,'116286','deals','sort_pos_12','13',0,''),(384559,121826,'116286','deals','sort_pos_14','15',0,''),(384560,121826,'116286','deals','sort_pos_13','14',0,''),(384561,121826,'116286','deals','sort_pos_8','4',0,''),(384562,121826,'116286','deals','sort_pos_7','5',0,''),(384563,121826,'116286','deals','sort_pos_2','7',0,''),(384564,121826,'116286','deals','sort_pos_1','6',0,''),(384565,121826,'116286','deals','sort_pos_6','9',0,''),(384566,121826,'116286','deals','sort_pos_5','8',0,''),(384567,121826,'116286','deals','sort_pos_0','1',0,''),(384568,121826,'116286','deals','sort_hide_10','1',0,''),(384569,121826,'116286','deals','sort_hide_9','1',0,''),(384570,121826,'116286','deals','hide_icons','1',0,''),(384571,121826,'116286','deals','sort_hide_16','1',0,''),(384572,121826,'116286','deals','sort_hide_15','1',0,''),(384573,121826,'116286','deals','sort_hide_3','0',0,''),(384574,121826,'116286','deals','sort_hide_4','0',0,''),(384575,121826,'116286','deals','sort_hide_11','1',0,''),(384576,121826,'116286','deals','sort_hide_12','1',0,''),(384577,121826,'116286','deals','sort_hide_14','1',0,''),(384578,121826,'116286','deals','sort_hide_13','1',0,''),(384579,121826,'116286','deals','sort_hide_8','0',0,''),(384580,121826,'116286','deals','sort_hide_7','0',0,''),(384581,121826,'116286','deals','sort_hide_2','1',0,''),(384582,121826,'116286','deals','sort_hide_1','1',0,''),(384583,121826,'116286','deals','sort_hide_6','1',0,''),(384584,121826,'116286','deals','sort_hide_5','1',0,''),(384585,121826,'116286','deals','sort_hide_0','0',0,''),(384586,121826,'116286','deals','sort_pos_15','16',0,''),(384587,121826,'116286','deals','sort_pos_16','17',0,''),(384588,121827,'1641810239','deals','align_position','horizontal',0,''),(384589,121827,'1641810239','deals','open_filter','closed',0,''),(384590,121833,'116293','deals','block_type','1',0,''),(384591,121835,'116295','deals','block_type','6',0,''),(384592,121835,'116295','deals','font-weight','400',0,''),(384593,121835,'116295','deals','schema','6-2',0,'5660'),(384594,121835,'116295','deals','schema','6-2',0,'5639'),(384595,121836,'116296','deals','font-weight','400',0,''),(384596,121836,'116296','deals','padding-right','40',0,''),(384597,121836,'116296','deals','padding-right','0',0,'5660'),(384598,121836,'116296','deals','padding-right','0',0,'5639'),(384599,121838,'116298','deals','col_in_row','3',0,''),(384600,121838,'116298','deals','products_align','left',0,''),(384601,121838,'116298','deals','font-weight','400',0,''),(384602,121838,'116298','deals','show_qty_input','0',0,''),(384603,121838,'116298','deals','listing_type','productListing',0,''),(384604,121838,'116298','deals','listing_type_rows','no',0,''),(384605,121838,'116298','deals','show_buy_button_b2b','on',0,''),(384606,121838,'116298','deals','show_wishlist_button_b2b','1',0,''),(384607,121838,'116298','deals','show_compare_b2b','1',0,''),(384608,121838,'116298','deals','show_stock','0',0,''),(384609,121838,'116298','deals','show_description','0',0,''),(384610,121838,'116298','deals','show_model','0',0,''),(384611,121838,'116298','deals','show_properties','0',0,''),(384612,121838,'116298','deals','show_rating','0',0,''),(384613,121838,'116298','deals','show_rating_counts','0',0,''),(384614,121838,'116298','deals','show_price','0',0,''),(384615,121838,'116298','deals','show_buy_button','0',0,''),(384616,121838,'116298','deals','show_view_button','0',0,''),(384617,121838,'116298','deals','show_wishlist_button','0',0,''),(384618,121838,'116298','deals','show_compare','0',0,''),(384619,121838,'116298','deals','show_name_rows','0',0,''),(384620,121838,'116298','deals','show_image_rows','0',0,''),(384621,121838,'116298','deals','show_stock_rows','0',0,''),(384622,121838,'116298','deals','show_description_rows','0',0,''),(384623,121838,'116298','deals','show_model_rows','0',0,''),(384624,121838,'116298','deals','show_properties_rows','0',0,''),(384625,121838,'116298','deals','show_rating_rows','0',0,''),(384626,121838,'116298','deals','show_rating_counts_rows','0',0,''),(384627,121838,'116298','deals','show_price_rows','0',0,''),(384628,121838,'116298','deals','show_buy_button_rows','0',0,''),(384629,121838,'116298','deals','show_qty_input_rows','0',0,''),(384630,121838,'116298','deals','show_view_button_rows','0',0,''),(384631,121838,'116298','deals','show_wishlist_button_rows','0',0,''),(384632,121838,'116298','deals','show_compare_rows','0',0,''),(384633,121838,'116298','deals','show_name_b2b','0',0,''),(384634,121838,'116298','deals','show_image_b2b','0',0,''),(384635,121838,'116298','deals','show_stock_b2b','0',0,''),(384636,121838,'116298','deals','show_description_b2b','0',0,''),(384637,121838,'116298','deals','show_model_b2b','0',0,''),(384638,121838,'116298','deals','show_properties_b2b','0',0,''),(384639,121838,'116298','deals','show_rating_b2b','0',0,''),(384640,121838,'116298','deals','show_rating_counts_b2b','0',0,''),(384641,121838,'116298','deals','show_price_b2b','0',0,''),(384642,121838,'116298','deals','show_qty_input_b2b','0',0,''),(384643,121838,'116298','deals','show_view_button_b2b','0',0,''),(384644,121838,'116298','deals','show_attributes_b2b','0',0,''),(384645,121838,'116298','deals','items_on_page','9',0,''),(384646,121838,'116298','deals','col_in_row','2',0,'5639'),(384647,121838,'116298','deals','col_in_row','1',0,'5660'),(384648,121838,'116298','deals','product_names_teg','h2',0,''),(384649,121839,'116299','deals','block_type','1',0,''),(384650,121839,'116299','deals','padding-top','10',0,''),(384651,121839,'116299','deals','padding-bottom','10',0,''),(384652,121839,'116299','deals','border-bottom-width','1',0,''),(384653,121839,'116299','deals','border-bottom-color','$content-border-1',0,''),(384654,121839,'116299','deals','margin-left','0',0,''),(384655,121839,'116299','deals','margin-right','0',0,''),(384656,121840,'116300','deals','float','left',0,''),(384657,121840,'116300','deals','clear','none',0,''),(384658,121840,'116300','deals','sort_pos_3','1',0,''),(384659,121840,'116300','deals','sort_pos_4','2',0,''),(384660,121840,'116300','deals','sort_pos_10','3',0,''),(384661,121840,'116300','deals','sort_pos_9','4',0,''),(384662,121840,'116300','deals','sort_pos_11','5',0,''),(384663,121840,'116300','deals','sort_pos_12','6',0,''),(384664,121840,'116300','deals','sort_pos_14','7',0,''),(384665,121840,'116300','deals','sort_pos_13','8',0,''),(384666,121840,'116300','deals','sort_pos_8','9',0,''),(384667,121840,'116300','deals','sort_pos_7','10',0,''),(384668,121840,'116300','deals','sort_pos_2','11',0,''),(384669,121840,'116300','deals','sort_pos_1','12',0,''),(384670,121840,'116300','deals','sort_pos_6','13',0,''),(384671,121840,'116300','deals','sort_pos_5','14',0,''),(384672,121840,'116300','deals','sort_pos_0','15',0,''),(384673,121840,'116300','deals','sort_hide_10','1',0,''),(384674,121840,'116300','deals','sort_hide_9','1',0,''),(384675,121840,'116300','deals','hide_icons','1',0,''),(384676,121840,'116300','deals','sort_hide_16','1',0,''),(384677,121840,'116300','deals','sort_hide_15','1',0,''),(384678,121840,'116300','deals','sort_hide_3','0',0,''),(384679,121840,'116300','deals','sort_hide_4','0',0,''),(384680,121840,'116300','deals','sort_hide_11','1',0,''),(384681,121840,'116300','deals','sort_hide_12','1',0,''),(384682,121840,'116300','deals','sort_hide_14','1',0,''),(384683,121840,'116300','deals','sort_hide_13','1',0,''),(384684,121840,'116300','deals','sort_hide_8','0',0,''),(384685,121840,'116300','deals','sort_hide_7','0',0,''),(384686,121840,'116300','deals','sort_hide_2','1',0,''),(384687,121840,'116300','deals','sort_hide_1','1',0,''),(384688,121840,'116300','deals','sort_hide_6','1',0,''),(384689,121840,'116300','deals','sort_hide_5','1',0,''),(384690,121840,'116300','deals','sort_hide_0','1',0,''),(384691,121841,'116301','deals','float','left',0,''),(384692,121841,'116301','deals','clear','none',0,''),(384693,121841,'116301','deals','margin-left','20',0,''),(384694,121841,'116301','deals','display','none',0,'5660'),(384695,121842,'116302','deals','margin-right','20',0,''),(384696,121842,'116302','deals','float','right',0,''),(384697,121842,'116302','deals','clear','none',0,''),(384698,121842,'116302','deals','display','none',0,'5639'),(384699,121843,'116303','deals','float','right',0,''),(384700,121843,'116303','deals','display','none',0,'5660'),(384701,121844,'116304','deals','listing_type','productListing',0,''),(384702,121846,'116306','deals','block_type','5',0,''),(384703,121846,'116306','deals','padding-top','10',0,''),(384704,121846,'116306','deals','padding-bottom','10',0,''),(384705,121846,'116306','deals','schema','5-2',0,'5660'),(384706,121846,'116306','deals','border-top-color','$content-border-1',0,''),(384707,121846,'116306','deals','border-top-width','1',0,''),(384708,121848,'116308','deals','float','right',0,''),(384709,121849,'116309','deals','block_type','1',0,''),(384710,121852,'116312','deals','block_type','1',0,''),(384711,121852,'116312','deals','padding-top','10',0,''),(384712,121852,'116312','deals','padding-bottom','10',0,''),(384713,121852,'116312','deals','border-bottom-width','1',0,''),(384714,121852,'116312','deals','border-bottom-color','$content-border-1',0,''),(384715,121852,'116312','deals','margin-left','0',0,''),(384716,121852,'116312','deals','margin-right','0',0,''),(384717,121853,'116313','deals','float','left',0,''),(384718,121853,'116313','deals','clear','none',0,''),(384719,121853,'116313','deals','margin-left','20',0,''),(384720,121853,'116313','deals','display','none',0,'5660'),(384721,121853,'116313','deals','display_none','1',0,'5630'),(384722,121854,'116314','deals','float','left',0,''),(384723,121854,'116314','deals','clear','none',0,''),(384724,121854,'116314','deals','sort_pos_3','2',0,''),(384725,121854,'116314','deals','sort_pos_4','3',0,''),(384726,121854,'116314','deals','sort_pos_10','11',0,''),(384727,121854,'116314','deals','sort_pos_9','10',0,''),(384728,121854,'116314','deals','sort_pos_11','12',0,''),(384729,121854,'116314','deals','sort_pos_12','13',0,''),(384730,121854,'116314','deals','sort_pos_14','15',0,''),(384731,121854,'116314','deals','sort_pos_13','14',0,''),(384732,121854,'116314','deals','sort_pos_8','4',0,''),(384733,121854,'116314','deals','sort_pos_7','5',0,''),(384734,121854,'116314','deals','sort_pos_2','7',0,''),(384735,121854,'116314','deals','sort_pos_1','6',0,''),(384736,121854,'116314','deals','sort_pos_6','9',0,''),(384737,121854,'116314','deals','sort_pos_5','8',0,''),(384738,121854,'116314','deals','sort_pos_0','1',0,''),(384739,121854,'116314','deals','sort_hide_10','1',0,''),(384740,121854,'116314','deals','sort_hide_9','1',0,''),(384741,121854,'116314','deals','hide_icons','1',0,''),(384742,121854,'116314','deals','sort_hide_16','1',0,''),(384743,121854,'116314','deals','sort_hide_15','1',0,''),(384744,121854,'116314','deals','sort_hide_3','0',0,''),(384745,121854,'116314','deals','sort_hide_4','0',0,''),(384746,121854,'116314','deals','sort_hide_11','1',0,''),(384747,121854,'116314','deals','sort_hide_12','1',0,''),(384748,121854,'116314','deals','sort_hide_14','1',0,''),(384749,121854,'116314','deals','sort_hide_13','1',0,''),(384750,121854,'116314','deals','sort_hide_8','0',0,''),(384751,121854,'116314','deals','sort_hide_7','0',0,''),(384752,121854,'116314','deals','sort_hide_2','1',0,''),(384753,121854,'116314','deals','sort_hide_1','1',0,''),(384754,121854,'116314','deals','sort_hide_6','1',0,''),(384755,121854,'116314','deals','sort_hide_5','1',0,''),(384756,121854,'116314','deals','sort_hide_0','0',0,''),(384757,121854,'116314','deals','sort_pos_15','16',0,''),(384758,121854,'116314','deals','sort_pos_16','17',0,''),(384759,121855,'116315','deals','margin-right','20',0,''),(384760,121855,'116315','deals','float','right',0,''),(384761,121855,'116315','deals','clear','none',0,''),(384762,121855,'116315','deals','display','none',0,'5639'),(384763,121856,'116316','deals','float','right',0,''),(384764,121856,'116316','deals','display','none',0,'5660'),(384765,121857,'116318','deals','block_type','5',0,''),(384766,121857,'116318','deals','padding-top','10',0,''),(384767,121857,'116318','deals','padding-bottom','10',0,''),(384768,121857,'116318','deals','schema','5-2',0,'5660'),(384769,121857,'116318','deals','border-top-color','$content-border-1',0,''),(384770,121857,'116318','deals','border-top-width','1',0,''),(384771,121859,'116320','deals','float','right',0,''),(384772,121860,'116321','deals','col_in_row','4',0,''),(384773,121860,'116321','deals','products_align','left',0,''),(384774,121860,'116321','deals','font-weight','400',0,''),(384775,121860,'116321','deals','show_qty_input','0',0,''),(384776,121860,'116321','deals','listing_type','productListing',0,''),(384777,121860,'116321','deals','listing_type_rows','Rows',0,''),(384778,121860,'116321','deals','show_buy_button_b2b','on',0,''),(384779,121860,'116321','deals','show_wishlist_button_b2b','1',0,''),(384780,121860,'116321','deals','show_compare_b2b','1',0,''),(384781,121860,'116321','deals','listing_type_b2b','b2b',0,''),(384782,121860,'116321','deals','show_image','0',0,''),(384783,121860,'116321','deals','show_stock','0',0,''),(384784,121860,'116321','deals','show_description','0',0,''),(384785,121860,'116321','deals','show_model','0',0,''),(384786,121860,'116321','deals','show_properties','0',0,''),(384787,121860,'116321','deals','show_rating','0',0,''),(384788,121860,'116321','deals','show_rating_counts','0',0,''),(384789,121860,'116321','deals','show_price','0',0,''),(384790,121860,'116321','deals','show_buy_button','0',0,''),(384791,121860,'116321','deals','show_view_button','0',0,''),(384792,121860,'116321','deals','show_wishlist_button','0',0,''),(384793,121860,'116321','deals','show_compare','0',0,''),(384794,121860,'116321','deals','show_name_rows','0',0,''),(384795,121860,'116321','deals','show_image_rows','0',0,''),(384796,121860,'116321','deals','show_stock_rows','0',0,''),(384797,121860,'116321','deals','show_description_rows','0',0,''),(384798,121860,'116321','deals','show_model_rows','0',0,''),(384799,121860,'116321','deals','show_properties_rows','0',0,''),(384800,121860,'116321','deals','show_rating_rows','0',0,''),(384801,121860,'116321','deals','show_rating_counts_rows','0',0,''),(384802,121860,'116321','deals','show_price_rows','0',0,''),(384803,121860,'116321','deals','show_buy_button_rows','0',0,''),(384804,121860,'116321','deals','show_qty_input_rows','0',0,''),(384805,121860,'116321','deals','show_view_button_rows','0',0,''),(384806,121860,'116321','deals','show_wishlist_button_rows','0',0,''),(384807,121860,'116321','deals','show_compare_rows','0',0,''),(384808,121860,'116321','deals','show_name_b2b','0',0,''),(384809,121860,'116321','deals','show_image_b2b','0',0,''),(384810,121860,'116321','deals','show_stock_b2b','0',0,''),(384811,121860,'116321','deals','show_description_b2b','0',0,''),(384812,121860,'116321','deals','show_model_b2b','0',0,''),(384813,121860,'116321','deals','show_properties_b2b','0',0,''),(384814,121860,'116321','deals','show_rating_b2b','0',0,''),(384815,121860,'116321','deals','show_rating_counts_b2b','0',0,''),(384816,121860,'116321','deals','show_price_b2b','0',0,''),(384817,121860,'116321','deals','show_qty_input_b2b','0',0,''),(384818,121860,'116321','deals','show_view_button_b2b','0',0,''),(384819,121860,'116321','deals','show_attributes_b2b','0',0,''),(384820,121860,'116321','deals','items_on_page','12',0,''),(384821,121860,'116321','deals','col_in_row','2',0,'5639'),(384822,121860,'116321','deals','col_in_row','1',0,'5660'),(384823,121860,'116321','deals','product_names_teg','h2',0,''),(384824,121863,'1683116708.492798','deals','block_type','1',0,''),(384825,121863,'1683116708.492798','deals','padding-top','30',0,''),(384826,121863,'1683116708.492798','deals','padding-bottom','30',0,''),(384827,121863,'1683116708.492798','deals','style_class','checkout-index-wrap',0,''),(384828,121864,'1683116708.500294','deals','block_type','4',0,''),(384829,121864,'1683116708.500294','deals','schema','4-2',0,'5639'),(384830,121865,'1683116708.502483','deals','block_type','1',0,''),(384831,121865,'1683116708.502483','deals','padding-right','0',0,'5639'),(384832,121866,'1683116708.503841','deals','block_type','1',0,''),(384833,121866,'1683116708.503841','deals','background-color','$content-bg-1',0,''),(384834,121866,'1683116708.503841','deals','padding-top','30',0,''),(384835,121866,'1683116708.503841','deals','padding-left','30',0,''),(384836,121866,'1683116708.503841','deals','padding-right','30',0,''),(384837,121866,'1683116708.503841','deals','padding-bottom','30',0,''),(384838,121866,'1683116708.503841','deals','margin-bottom','20',0,''),(384839,121866,'1683116708.503841','deals','style_class','hiding-box closeable-box',0,''),(384840,121866,'1683116708.503841','deals','border-top-width','1',0,''),(384841,121866,'1683116708.503841','deals','border-left-width','1',0,''),(384842,121866,'1683116708.503841','deals','border-right-width','1',0,''),(384843,121866,'1683116708.503841','deals','border-bottom-width','1',0,''),(384844,121866,'1683116708.503841','deals','border-top-color','$content-border-1',0,''),(384845,121866,'1683116708.503841','deals','border-left-color','$content-border-1',0,''),(384846,121866,'1683116708.503841','deals','border-right-color','$content-border-1',0,''),(384847,121866,'1683116708.503841','deals','border-bottom-color','$content-border-1',0,''),(384848,121866,'1683116708.503841','deals','padding-top','15',0,'5639'),(384849,121866,'1683116708.503841','deals','padding-left','15',0,'5639'),(384850,121866,'1683116708.503841','deals','padding-right','15',0,'5639'),(384851,121866,'1683116708.503841','deals','padding-bottom','15',0,'5639'),(384852,121867,'1683116708.507547','deals','style_class','closeable-content',0,''),(384853,121867,'1683116708.507547','deals','padding-bottom','20',0,''),(384854,121868,'1683116708.50914','deals','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(384855,121868,'1683116708.50914','deals','style_class','closeable-heading closeable-event closed',0,''),(384856,121869,'1683116708.511660','deals','block_type','1',0,''),(384857,121869,'1683116708.511660','deals','padding-top','30',0,''),(384858,121869,'1683116708.511660','deals','padding-left','30',0,''),(384859,121869,'1683116708.511660','deals','padding-right','30',0,''),(384860,121869,'1683116708.511660','deals','padding-bottom','30',0,''),(384861,121869,'1683116708.511660','deals','margin-bottom','20',0,''),(384862,121869,'1683116708.511660','deals','background-color','$content-bg-1',0,''),(384863,121869,'1683116708.511660','deals','style_class','hiding-box closeable-box',0,''),(384864,121869,'1683116708.511660','deals','border-top-width','1',0,''),(384865,121869,'1683116708.511660','deals','border-left-width','1',0,''),(384866,121869,'1683116708.511660','deals','border-right-width','1',0,''),(384867,121869,'1683116708.511660','deals','border-bottom-width','1',0,''),(384868,121869,'1683116708.511660','deals','border-top-color','$content-border-1',0,''),(384869,121869,'1683116708.511660','deals','border-left-color','$content-border-1',0,''),(384870,121869,'1683116708.511660','deals','border-right-color','$content-border-1',0,''),(384871,121869,'1683116708.511660','deals','border-bottom-color','$content-border-1',0,''),(384872,121869,'1683116708.511660','deals','padding-top','15',0,'5639'),(384873,121869,'1683116708.511660','deals','padding-left','15',0,'5639'),(384874,121869,'1683116708.511660','deals','padding-right','15',0,'5639'),(384875,121869,'1683116708.511660','deals','padding-bottom','15',0,'5639'),(384876,121870,'1683116708.515882','deals','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(384877,121870,'1683116708.515882','deals','style_class','closeable-heading closeable-event closed',0,''),(384878,121871,'1683116708.517470','deals','block_type','2',0,''),(384879,121871,'1683116708.517470','deals','style_class','closeable-content',0,''),(384880,121871,'1683116708.517470','deals','schema','2-2',0,'5639'),(384881,121872,'1683116708.518949','deals','padding-right','20',0,''),(384882,121872,'1683116708.518949','deals','padding-bottom','20',0,''),(384883,121872,'1683116708.518949','deals','padding-right','0',0,'5639'),(384884,121873,'1683116708.519823','deals','padding-left','20',0,''),(384885,121873,'1683116708.519823','deals','padding-bottom','20',0,''),(384886,121873,'1683116708.519823','deals','padding-left','0',0,'5639'),(384887,121874,'1683116708.52078','deals','padding-left','20',0,''),(384888,121874,'1683116708.52078','deals','padding-bottom','20',0,''),(384889,121874,'1683116708.52078','deals','padding-left','0',0,'5639'),(384890,121875,'1683116708.521619','deals','background-color','$content-bg-1',0,''),(384891,121875,'1683116708.521619','deals','block_type','1',0,''),(384892,121875,'1683116708.521619','deals','padding-top','30',0,''),(384893,121875,'1683116708.521619','deals','padding-left','30',0,''),(384894,121875,'1683116708.521619','deals','padding-right','30',0,''),(384895,121875,'1683116708.521619','deals','padding-bottom','30',0,''),(384896,121875,'1683116708.521619','deals','margin-bottom','20',0,''),(384897,121875,'1683116708.521619','deals','style_class','hiding-box',0,''),(384898,121875,'1683116708.521619','deals','border-top-width','1',0,''),(384899,121875,'1683116708.521619','deals','border-left-width','1',0,''),(384900,121875,'1683116708.521619','deals','border-right-width','1',0,''),(384901,121875,'1683116708.521619','deals','border-bottom-width','1',0,''),(384902,121875,'1683116708.521619','deals','border-top-color','$content-border-1',0,''),(384903,121875,'1683116708.521619','deals','border-left-color','$content-border-1',0,''),(384904,121875,'1683116708.521619','deals','border-right-color','$content-border-1',0,''),(384905,121875,'1683116708.521619','deals','border-bottom-color','$content-border-1',0,''),(384906,121875,'1683116708.521619','deals','padding-top','15',0,'5639'),(384907,121875,'1683116708.521619','deals','padding-left','15',0,'5639'),(384908,121875,'1683116708.521619','deals','padding-right','15',0,'5639'),(384909,121875,'1683116708.521619','deals','padding-bottom','15',0,'5639'),(384910,121876,'1683116708.52521','deals','block_type','1',0,''),(384911,121876,'1683116708.52521','deals','content','\\_',0,'3'),(384912,121876,'1683116708.52521','deals','border-top-width','1',0,'3'),(384913,121876,'1683116708.52521','deals','border-top-color','$content-border-1',0,'3'),(384914,121876,'1683116708.52521','deals','display','block',0,'3'),(384915,121876,'1683116708.52521','deals','position','absolute',0,'3'),(384916,121876,'1683116708.52521','deals','top','19',0,'3'),(384917,121876,'1683116708.52521','deals','left','0',0,'3'),(384918,121876,'1683116708.52521','deals','right','0',0,'3'),(384919,121876,'1683116708.52521','deals','margin-top','-2',0,'3'),(384920,121876,'1683116708.52521','deals','position','relative',0,''),(384921,121877,'1683116708.527559','deals','box_align','2',0,''),(384922,121877,'1683116708.527559','deals','margin-bottom','10',0,''),(384923,121877,'1683116708.527559','deals','background-color','$content-bg-1',0,''),(384924,121877,'1683116708.527559','deals','position','relative',0,''),(384925,121878,'1683116708.528597','deals','background-color','$content-bg-2',0,''),(384926,121878,'1683116708.528597','deals','padding-top','10',0,''),(384927,121878,'1683116708.528597','deals','padding-left','10',0,''),(384928,121878,'1683116708.528597','deals','padding-right','10',0,''),(384929,121878,'1683116708.528597','deals','padding-bottom','10',0,''),(384930,121878,'1683116708.528597','deals','margin-top','10',0,''),(384931,121879,'1683116708.529860','deals','block_type','2',0,''),(384932,121879,'1683116708.529860','deals','schema','2-2',0,'5639'),(384933,121880,'1683116708.531118','deals','block_type','1',0,''),(384934,121880,'1683116708.531118','deals','padding-right','20',0,''),(384935,121880,'1683116708.531118','deals','padding-left','0',0,'5639'),(384936,121880,'1683116708.531118','deals','margin-bottom','20',0,'5639'),(384937,121880,'1683116708.531118','deals','padding-right','0',0,'5639'),(384938,121881,'1683116708.532686','deals','address_in','popup',0,''),(384939,121882,'1683116708.533279','deals','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(384940,121885,'1683116708.535390','deals','block_type','1',0,''),(384941,121885,'1683116708.535390','deals','padding-left','20',0,''),(384942,121885,'1683116708.535390','deals','padding-left','0',0,'5639'),(384943,121887,'1683116708.537397','deals','border-top-width','1',0,''),(384944,121887,'1683116708.537397','deals','border-top-color','$content-border-1',0,''),(384945,121887,'1683116708.537397','deals','padding-top','13',0,''),(384946,121887,'1683116708.537397','deals','padding-bottom','10',0,''),(384947,121888,'1683116708.538283','deals','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(384948,121889,'1683116708.539729','deals','show_day','next_day',0,''),(384949,121890,'1683116708.540444','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(384950,121891,'1683116708.541679','deals','block_type','1',0,''),(384951,121891,'1683116708.541679','deals','background-color','$content-bg-1',0,''),(384952,121891,'1683116708.541679','deals','padding-top','30',0,''),(384953,121891,'1683116708.541679','deals','padding-left','30',0,''),(384954,121891,'1683116708.541679','deals','padding-right','30',0,''),(384955,121891,'1683116708.541679','deals','padding-bottom','30',0,''),(384956,121891,'1683116708.541679','deals','margin-bottom','20',0,''),(384957,121891,'1683116708.541679','deals','style_class','hiding-box',0,''),(384958,121891,'1683116708.541679','deals','border-top-width','1',0,''),(384959,121891,'1683116708.541679','deals','border-left-width','1',0,''),(384960,121891,'1683116708.541679','deals','border-right-width','1',0,''),(384961,121891,'1683116708.541679','deals','border-bottom-width','1',0,''),(384962,121891,'1683116708.541679','deals','border-top-color','$content-border-1',0,''),(384963,121891,'1683116708.541679','deals','border-left-color','$content-border-1',0,''),(384964,121891,'1683116708.541679','deals','border-right-color','$content-border-1',0,''),(384965,121891,'1683116708.541679','deals','border-bottom-color','$content-border-1',0,''),(384966,121891,'1683116708.541679','deals','padding-top','15',0,'5639'),(384967,121891,'1683116708.541679','deals','padding-left','15',0,'5639'),(384968,121891,'1683116708.541679','deals','padding-right','15',0,'5639'),(384969,121891,'1683116708.541679','deals','padding-bottom','15',0,'5639'),(384970,121893,'1683116708.545373','deals','margin-bottom','20',0,''),(384971,121893,'1683116708.545373','deals','style_class','hiding-box',0,''),(384972,121893,'1683116708.545373','deals','padding-top','0',0,'5639'),(384973,121893,'1683116708.545373','deals','padding-left','0',0,'5639'),(384974,121893,'1683116708.545373','deals','padding-right','0',0,'5639'),(384975,121893,'1683116708.545373','deals','padding-bottom','0',0,'5639'),(384976,121893,'1683116708.545373','deals','border-top-width','0',0,'5639'),(384977,121893,'1683116708.545373','deals','border-left-width','0',0,'5639'),(384978,121893,'1683116708.545373','deals','border-right-width','0',0,'5639'),(384979,121893,'1683116708.545373','deals','border-bottom-width','0',0,'5639'),(384980,121894,'1683116708.547120','deals','padding-top','10',0,''),(384981,121894,'1683116708.547120','deals','padding-left','20',0,''),(384982,121894,'1683116708.547120','deals','padding-right','20',0,''),(384983,121894,'1683116708.547120','deals','margin-top','20',0,''),(384984,121894,'1683116708.547120','deals','background-color','$content-bg-2',0,''),(384985,121894,'1683116708.547120','deals','padding-bottom','8',0,''),(384986,121895,'1683116708.548247','deals','block_type','1',0,''),(384987,121895,'1683116708.548247','deals','padding-top','30',0,''),(384988,121895,'1683116708.548247','deals','padding-left','30',0,''),(384989,121895,'1683116708.548247','deals','padding-right','30',0,''),(384990,121895,'1683116708.548247','deals','padding-bottom','23',0,''),(384991,121895,'1683116708.548247','deals','margin-bottom','20',0,''),(384992,121895,'1683116708.548247','deals','background-color','$content-bg-1',0,''),(384993,121895,'1683116708.548247','deals','style_class','hiding-box',0,''),(384994,121895,'1683116708.548247','deals','border-top-width','1',0,''),(384995,121895,'1683116708.548247','deals','border-left-width','1',0,''),(384996,121895,'1683116708.548247','deals','border-right-width','1',0,''),(384997,121895,'1683116708.548247','deals','border-bottom-width','1',0,''),(384998,121895,'1683116708.548247','deals','border-top-color','$content-border-1',0,''),(384999,121895,'1683116708.548247','deals','border-left-color','$content-border-1',0,''),(385000,121895,'1683116708.548247','deals','border-right-color','$content-border-1',0,''),(385001,121895,'1683116708.548247','deals','border-bottom-color','$content-border-1',0,''),(385002,121895,'1683116708.548247','deals','padding-top','15',0,'5639'),(385003,121895,'1683116708.548247','deals','padding-left','15',0,'5639'),(385004,121895,'1683116708.548247','deals','padding-right','15',0,'5639'),(385005,121895,'1683116708.548247','deals','padding-bottom','8',0,'5639'),(385006,121896,'1683116708.551273','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(385007,121897,'1683116708.552428','deals','block_type','2',0,''),(385008,121897,'1683116708.552428','deals','schema','2-2',0,'5639'),(385009,121898,'1683116708.553758','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385010,121899,'1683116708.55521','deals','padding-right','20',0,''),(385011,121899,'1683116708.55521','deals','padding-right','0',0,'5639'),(385012,121899,'1683116708.55521','deals','padding-bottom','20',0,'5639'),(385013,121899,'1683116708.55521','deals','address_in','popup',0,''),(385014,121900,'1683116708.5566','deals','block_type','1',0,''),(385015,121900,'1683116708.5566','deals','padding-left','20',0,''),(385016,121900,'1683116708.5566','deals','padding-left','0',0,'5639'),(385017,121902,'1683116708.558367','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385018,121903,'1683116708.559513','deals','block_type','1',0,''),(385019,121903,'1683116708.559513','deals','padding-top','30',0,''),(385020,121903,'1683116708.559513','deals','padding-left','30',0,''),(385021,121903,'1683116708.559513','deals','padding-right','30',0,''),(385022,121903,'1683116708.559513','deals','padding-bottom','30',0,''),(385023,121903,'1683116708.559513','deals','margin-bottom','20',0,''),(385024,121903,'1683116708.559513','deals','border-top-width','1',0,''),(385025,121903,'1683116708.559513','deals','border-left-width','1',0,''),(385026,121903,'1683116708.559513','deals','border-right-width','1',0,''),(385027,121903,'1683116708.559513','deals','border-bottom-width','1',0,''),(385028,121903,'1683116708.559513','deals','border-top-color','$content-border-1',0,''),(385029,121903,'1683116708.559513','deals','border-left-color','$content-border-1',0,''),(385030,121903,'1683116708.559513','deals','border-right-color','$content-border-1',0,''),(385031,121903,'1683116708.559513','deals','border-bottom-color','$content-border-1',0,''),(385032,121903,'1683116708.559513','deals','style_class','hiding-box',0,''),(385033,121905,'1683116708.563392','deals','block_type','1',0,''),(385034,121905,'1683116708.563392','deals','background-color','$content-bg-1',0,''),(385035,121905,'1683116708.563392','deals','style_class','order-summary',0,''),(385036,121905,'1683116708.563392','deals','margin-left','25',0,''),(385037,121905,'1683116708.563392','deals','margin-left','0',0,'5639'),(385038,121905,'1683116708.563392','deals','margin-top','30',0,'5639'),(385039,121906,'1683116708.56533','deals','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(385040,121906,'1683116708.56533','deals','text-align','center',0,''),(385041,121906,'1683116708.56533','deals','font-size','14',0,''),(385042,121906,'1683116708.56533','deals','color','$fade-color-1',0,''),(385043,121906,'1683116708.56533','deals','padding-top','10',0,''),(385044,121907,'1683116708.56713','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(385045,121908,'1683116708.568362','deals','hide_page','1',0,''),(385046,121908,'1683116708.568362','deals','hide_continue_button','1',0,''),(385047,121909,'1683116708.568971','deals','margin-bottom','10',0,''),(385048,121912,'116368','deals','block_type','1',0,''),(385049,121913,'116369','deals','margin-top','20',0,''),(385050,121914,'116370','deals','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(385051,121915,'116371','deals','link','products',0,''),(385052,121915,'116371','deals','margin-top','-33',0,''),(385053,121915,'116371','deals','float','right',0,''),(385054,121916,'116372','deals','block_type','2',0,''),(385055,121916,'116372','deals','margin-bottom','20',0,''),(385056,121916,'116372','deals','schema','2-2',0,'5630'),(385057,121917,'116373','deals','block_type','1',0,''),(385058,121917,'116373','deals','padding-right','20',0,''),(385059,121917,'116373','deals','padding-right','0',0,'5630'),(385060,121918,'116374','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(385061,121918,'116374','deals','clear','none',0,''),(385062,121920,'116376','deals','padding-left','20',0,''),(385063,121920,'116376','deals','block_type','1',0,''),(385064,121920,'116376','deals','padding-left','0',0,'5630'),(385065,121922,'116378','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385066,121922,'116378','deals','clear','none',0,''),(385067,121923,'116379','deals','text-align','right',0,''),(385068,121923,'116379','deals','margin-bottom','20',0,''),(385069,121923,'116379','deals','margin-top','20',0,''),(385070,121924,'116380','deals','block_type','2',0,''),(385071,121924,'116380','deals','margin-bottom','20',0,''),(385072,121924,'116380','deals','schema','2-2',0,'5630'),(385073,121925,'116381','deals','block_type','1',0,''),(385074,121925,'116381','deals','padding-right','20',0,''),(385075,121925,'116381','deals','padding-right','0',0,'5630'),(385076,121927,'116383','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(385077,121927,'116383','deals','clear','none',0,''),(385078,121928,'116384','deals','block_type','1',0,''),(385079,121928,'116384','deals','padding-left','20',0,''),(385080,121928,'116384','deals','padding-left','0',0,'5630'),(385081,121929,'116385','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385082,121929,'116385','deals','clear','none',0,''),(385083,121931,'116387','deals','margin-bottom','20',0,''),(385084,121931,'116387','deals','text-align','right',0,''),(385085,121933,'116402','deals','block_type','1',0,''),(385086,121934,'116403','deals','text-align','right',0,''),(385087,121934,'116403','deals','margin-bottom','20',0,''),(385088,121935,'116404','deals','block_type','2',0,''),(385089,121935,'116404','deals','margin-bottom','20',0,''),(385090,121935,'116404','deals','schema','2-2',0,'5630'),(385091,121936,'116405','deals','block_type','1',0,''),(385092,121936,'116405','deals','padding-right','20',0,''),(385093,121936,'116405','deals','padding-right','0',0,'5630'),(385094,121937,'116406','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385095,121937,'116406','deals','clear','none',0,''),(385096,121939,'116408','deals','block_type','1',0,''),(385097,121939,'116408','deals','padding-left','20',0,''),(385098,121939,'116408','deals','padding-left','0',0,'5630'),(385099,121940,'116409','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385100,121940,'116409','deals','clear','none',0,''),(385101,121942,'116411','deals','margin-bottom','20',0,''),(385102,121942,'116411','deals','text-align','right',0,''),(385103,121945,'116414','deals','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(385104,121946,'116389','deals','block_type','1',0,''),(385105,121947,'116390','deals','margin-bottom','20',0,''),(385106,121948,'116391','deals','margin-bottom','20',0,''),(385107,121948,'116391','deals','text-align','right',0,''),(385108,121949,'116392','deals','text-align','right',0,''),(385109,121949,'116392','deals','margin-bottom','20',0,''),(385110,121950,'116393','deals','block_type','2',0,''),(385111,121950,'116393','deals','margin-bottom','20',0,''),(385112,121950,'116393','deals','schema','2-2',0,'5630'),(385113,121951,'116394','deals','block_type','1',0,''),(385114,121951,'116394','deals','padding-right','20',0,''),(385115,121951,'116394','deals','padding-right','0',0,'5630'),(385116,121953,'116396','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385117,121953,'116396','deals','clear','none',0,''),(385118,121954,'116397','deals','block_type','1',0,''),(385119,121954,'116397','deals','padding-left','20',0,''),(385120,121954,'116397','deals','padding-left','0',0,'5630'),(385121,121956,'116399','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385122,121956,'116399','deals','clear','none',0,''),(385123,121957,'116400','deals','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(385124,121958,'116401','deals','margin-bottom','20',0,''),(385125,121959,'116415','deals','block_type','1',0,''),(385126,121960,'116416','deals','block_type','2',0,''),(385127,121960,'116416','deals','margin-bottom','20',0,''),(385128,121960,'116416','deals','schema','2-2',0,'5630'),(385129,121961,'116417','deals','block_type','1',0,''),(385130,121961,'116417','deals','padding-right','20',0,''),(385131,121961,'116417','deals','padding-right','0',0,'5630'),(385132,121963,'116419','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(385133,121963,'116419','deals','clear','none',0,''),(385134,121964,'116420','deals','block_type','1',0,''),(385135,121964,'116420','deals','padding-left','20',0,''),(385136,121964,'116420','deals','padding-left','0',0,'5630'),(385137,121966,'116422','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385138,121966,'116422','deals','clear','none',0,''),(385139,121967,'116423','deals','margin-bottom','20',0,''),(385140,121968,'116424','deals','margin-bottom','20',0,''),(385141,121969,'116425','deals','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(385142,121970,'116426','deals','link','products',0,''),(385143,121970,'116426','deals','margin-top','-33',0,''),(385144,121970,'116426','deals','float','right',0,''),(385145,121971,'116427','deals','text-align','right',0,''),(385146,121971,'116427','deals','margin-bottom','20',0,''),(385147,121972,'116428','deals','margin-bottom','20',0,''),(385148,121972,'116428','deals','text-align','right',0,''),(385149,121973,'116429','deals','block_type','2',0,''),(385150,121973,'116429','deals','margin-bottom','20',0,''),(385151,121973,'116429','deals','schema','2-2',0,'5630'),(385152,121974,'116430','deals','block_type','1',0,''),(385153,121974,'116430','deals','padding-right','20',0,''),(385154,121974,'116430','deals','padding-right','0',0,'5630'),(385155,121975,'116431','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(385156,121975,'116431','deals','clear','none',0,''),(385157,121977,'116433','deals','padding-left','20',0,''),(385158,121977,'116433','deals','block_type','1',0,''),(385159,121977,'116433','deals','padding-left','0',0,'5630'),(385160,121978,'116434','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385161,121978,'116434','deals','clear','none',0,''),(385162,121980,'116436','deals','text','##TEXT_CONFIRMATION##',0,''),(385163,121981,'116437','deals','text','##TEXT_CONFIRMATION##',0,''),(385164,121982,'116439','deals','text','##TEXT_CONFIRMATION##',0,''),(385165,121983,'116438','deals','text','##TEXT_CONFIRMATION##',0,''),(385166,121984,'116440','deals','text','##TEXT_CONFIRMATION##',0,''),(385167,121985,'116441','deals','text','##TEXT_CONFIRMATION##',0,''),(385168,121986,'116442','deals','block_type','2',0,''),(385169,121986,'116442','deals','schema','2-2',0,'5630'),(385170,121987,'116443','deals','block_type','1',0,''),(385171,121987,'116443','deals','padding-right','20',0,''),(385172,121988,'116444','deals','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(385173,121990,'116446','deals','block_type','1',0,''),(385174,121990,'116446','deals','padding-left','20',0,''),(385175,121990,'116446','deals','padding-left','0',0,'5639'),(385176,121991,'116447','deals','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(385177,121993,'116449','deals','block_type','4',0,''),(385178,121993,'116449','deals','schema','4-2',0,'5660'),(385179,121993,'116449','deals','padding-top','20',0,''),(385180,121994,'116450','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385181,121994,'116450','deals','text-align','right',0,''),(385182,121994,'116450','deals','padding-top','10',0,''),(385183,121994,'116450','deals','font_size_measure','em',0,''),(385184,121994,'116450','deals','font-size','1.2',0,''),(385185,121994,'116450','deals','text-align','center',0,'5630'),(385186,121995,'116451','deals','text-align','right',0,''),(385187,121995,'116451','deals','text-align','center',0,'5630'),(385188,121996,'116452','deals','block_type','2',0,''),(385189,121996,'116452','deals','schema','2-2',0,'5630'),(385190,121997,'116453','deals','block_type','1',0,''),(385191,121997,'116453','deals','padding-right','20',0,''),(385192,121997,'116453','deals','padding-right','0',0,'5639'),(385193,121999,'116456','deals','block_type','1',0,''),(385194,121999,'116456','deals','padding-right','0',0,'5639'),(385195,121999,'116456','deals','padding-left','20',0,''),(385196,121999,'116456','deals','padding-left','0',0,'5630'),(385197,122002,'116459','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(385198,122004,'116461','deals','block_type','2',0,''),(385199,122005,'116462','deals','block_type','1',0,''),(385200,122005,'116462','deals','padding-right','20',0,''),(385201,122007,'116464','deals','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(385202,122008,'116465','deals','block_type','1',0,''),(385203,122008,'116465','deals','padding-left','20',0,''),(385204,122008,'116465','deals','padding-left','0',0,'5639'),(385205,122009,'116466','deals','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(385206,122011,'116468','deals','block_type','4',0,''),(385207,122011,'116468','deals','schema','4-2',0,'5660'),(385208,122012,'116469','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385209,122012,'116469','deals','text-align','right',0,''),(385210,122012,'116469','deals','padding-top','10',0,''),(385211,122012,'116469','deals','font_size_measure','em',0,''),(385212,122012,'116469','deals','font-size','1.2',0,''),(385213,122013,'116470','deals','text-align','right',0,''),(385214,122014,'116471','deals','block_type','2',0,''),(385215,122015,'116472','deals','block_type','1',0,''),(385216,122015,'116472','deals','padding-right','20',0,''),(385217,122015,'116472','deals','padding-right','0',0,'5639'),(385218,122017,'116474','deals','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(385219,122018,'116475','deals','block_type','1',0,''),(385220,122018,'116475','deals','padding-right','0',0,'5639'),(385221,122018,'116475','deals','padding-left','20',0,''),(385222,122020,'116477','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(385223,122023,'116480','deals','block_type','4',0,''),(385224,122023,'116480','deals','schema','4-2',0,'5660'),(385225,122024,'116481','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385226,122024,'116481','deals','text-align','right',0,''),(385227,122024,'116481','deals','padding-top','10',0,''),(385228,122024,'116481','deals','font_size_measure','em',0,''),(385229,122024,'116481','deals','font-size','1.2',0,''),(385230,122025,'116482','deals','text-align','right',0,''),(385231,122026,'116483','deals','block_type','2',0,''),(385232,122027,'116484','deals','block_type','1',0,''),(385233,122027,'116484','deals','padding-right','20',0,''),(385234,122029,'116486','deals','block_type','1',0,''),(385235,122029,'116486','deals','padding-left','20',0,''),(385236,122029,'116486','deals','padding-left','0',0,'5639'),(385237,122030,'116487','deals','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(385238,122032,'116489','deals','block_type','4',0,''),(385239,122032,'116489','deals','schema','4-2',0,'5660'),(385240,122033,'116490','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385241,122033,'116490','deals','text-align','right',0,''),(385242,122033,'116490','deals','padding-top','10',0,''),(385243,122033,'116490','deals','font_size_measure','em',0,''),(385244,122033,'116490','deals','font-size','1.2',0,''),(385245,122034,'116491','deals','text-align','right',0,''),(385246,122035,'116492','deals','block_type','2',0,''),(385247,122036,'116493','deals','block_type','1',0,''),(385248,122036,'116493','deals','padding-right','20',0,''),(385249,122038,'116495','deals','block_type','1',0,''),(385250,122038,'116495','deals','padding-left','20',0,''),(385251,122038,'116495','deals','padding-left','0',0,'5639'),(385252,122040,'116497','deals','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(385253,122041,'116498','deals','text','##DELIVERY_DETAILS##',0,''),(385254,122042,'116499','deals','text','##DELIVERY_DETAILS##',0,''),(385255,122043,'116501','deals','text','##CONTACT_INFORMATION##',0,''),(385256,122044,'116500','deals','text','##CONTACT_INFORMATION##',0,''),(385257,122045,'116502','deals','text','##DELIVERY_DETAILS##',0,''),(385258,122046,'116503','deals','text','##DELIVERY_DETAILS##',0,''),(385259,122047,'116504','deals','block_type','1',0,''),(385260,122047,'116504','deals','background-color','$content-bg-2',0,''),(385261,122047,'116504','deals','padding-top','30',0,''),(385262,122047,'116504','deals','padding-bottom','30',0,''),(385263,122048,'116505','deals','block_type','7',0,''),(385264,122048,'116505','deals','schema','4-2',0,'5639'),(385265,122049,'116506','deals','block_type','1',0,''),(385266,122049,'116506','deals','padding-right','0',0,'5639'),(385267,122050,'116508','deals','block_type','1',0,''),(385268,122050,'116508','deals','background-color','$content-bg-1',0,''),(385269,122050,'116508','deals','padding-top','30',0,''),(385270,122050,'116508','deals','padding-left','30',0,''),(385271,122050,'116508','deals','padding-right','30',0,''),(385272,122050,'116508','deals','padding-bottom','30',0,''),(385273,122050,'116508','deals','margin-bottom','20',0,''),(385274,122050,'116508','deals','style_class','hiding-box',0,''),(385275,122051,'116509','deals','margin-bottom','20',0,''),(385276,122052,'116510','deals','padding-top','10',0,''),(385277,122052,'116510','deals','padding-left','20',0,''),(385278,122052,'116510','deals','padding-right','20',0,''),(385279,122052,'116510','deals','margin-top','20',0,''),(385280,122052,'116510','deals','background-color','$content-bg-2',0,''),(385281,122052,'116510','deals','padding-bottom','8',0,''),(385282,122053,'116511','deals','block_type','1',0,''),(385283,122053,'116511','deals','background-color','$content-bg-1',0,''),(385284,122053,'116511','deals','padding-top','30',0,''),(385285,122053,'116511','deals','padding-left','30',0,''),(385286,122053,'116511','deals','padding-right','30',0,''),(385287,122053,'116511','deals','padding-bottom','14',0,''),(385288,122053,'116511','deals','margin-bottom','20',0,''),(385289,122053,'116511','deals','style_class','hiding-box closeable-box',0,''),(385290,122054,'116512','deals','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(385291,122054,'116512','deals','style_class','closeable-heading closeable-event closed',0,''),(385292,122055,'116513','deals','style_class','closeable-content',0,''),(385293,122055,'116513','deals','padding-bottom','20',0,''),(385294,122056,'116514','deals','background-color','$content-bg-1',0,''),(385295,122056,'116514','deals','block_type','1',0,''),(385296,122056,'116514','deals','padding-top','30',0,''),(385297,122056,'116514','deals','padding-left','30',0,''),(385298,122056,'116514','deals','padding-right','30',0,''),(385299,122056,'116514','deals','padding-bottom','30',0,''),(385300,122056,'116514','deals','margin-bottom','20',0,''),(385301,122056,'116514','deals','style_class','hiding-box',0,''),(385302,122057,'116515','deals','block_type','1',0,''),(385303,122057,'116515','deals','content','\\_',0,'3'),(385304,122057,'116515','deals','border-top-width','1',0,'3'),(385305,122057,'116515','deals','border-top-color','$content-border-1',0,'3'),(385306,122057,'116515','deals','display','block',0,'3'),(385307,122057,'116515','deals','position','absolute',0,'3'),(385308,122057,'116515','deals','top','19',0,'3'),(385309,122057,'116515','deals','left','0',0,'3'),(385310,122057,'116515','deals','right','0',0,'3'),(385311,122057,'116515','deals','margin-top','-2',0,'3'),(385312,122057,'116515','deals','position','relative',0,''),(385313,122058,'116516','deals','box_align','2',0,''),(385314,122058,'116516','deals','margin-bottom','10',0,''),(385315,122058,'116516','deals','background-color','$content-bg-1',0,''),(385316,122058,'116516','deals','position','relative',0,''),(385317,122059,'116517','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(385318,122060,'116518','deals','block_type','2',0,''),(385319,122060,'116518','deals','schema','2-2',0,'5639'),(385320,122061,'116519','deals','block_type','1',0,''),(385321,122061,'116519','deals','padding-right','20',0,''),(385322,122061,'116519','deals','padding-left','0',0,'5639'),(385323,122061,'116519','deals','margin-bottom','20',0,'5639'),(385324,122061,'116519','deals','padding-right','0',0,'5639'),(385325,122064,'116522','deals','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(385326,122065,'116523','deals','block_type','1',0,''),(385327,122065,'116523','deals','padding-left','20',0,''),(385328,122065,'116523','deals','padding-left','0',0,'5639'),(385329,122066,'116524','deals','padding-bottom','10',0,''),(385330,122067,'116525','deals','background-color','$content-bg-2',0,''),(385331,122067,'116525','deals','padding-top','10',0,''),(385332,122067,'116525','deals','padding-left','10',0,''),(385333,122067,'116525','deals','padding-right','10',0,''),(385334,122067,'116525','deals','padding-bottom','10',0,''),(385335,122067,'116525','deals','margin-top','10',0,''),(385336,122068,'116526','deals','block_type','1',0,''),(385337,122068,'116526','deals','padding-top','10',0,''),(385338,122068,'116526','deals','padding-left','10',0,''),(385339,122068,'116526','deals','padding-right','10',0,''),(385340,122068,'116526','deals','padding-bottom','10',0,''),(385341,122068,'116526','deals','background-color','$content-bg-1',0,''),(385342,122068,'116526','deals','style_class','order-summary',0,''),(385343,122068,'116526','deals','margin-left','25',0,''),(385344,122068,'116526','deals','margin-left','0',0,'5639'),(385345,122069,'116527','deals','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(385346,122069,'116527','deals','text-align','center',0,''),(385347,122069,'116527','deals','font-size','14',0,''),(385348,122069,'116527','deals','color','$fade-color-1',0,''),(385349,122069,'116527','deals','padding-top','10',0,''),(385350,122072,'1638957135','deals','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(385351,122073,'116529','deals','block_type','1',0,''),(385352,122073,'116529','deals','background-color','$content-bg-2',0,''),(385353,122073,'116529','deals','padding-top','30',0,''),(385354,122073,'116529','deals','padding-bottom','30',0,''),(385355,122074,'116530','deals','block_type','7',0,''),(385356,122075,'116531','deals','block_type','1',0,''),(385357,122076,'116532','deals','block_type','1',0,''),(385358,122076,'116532','deals','background-color','$content-bg-1',0,''),(385359,122076,'116532','deals','padding-top','30',0,''),(385360,122076,'116532','deals','padding-left','30',0,''),(385361,122076,'116532','deals','padding-right','30',0,''),(385362,122076,'116532','deals','padding-bottom','30',0,''),(385363,122076,'116532','deals','margin-bottom','20',0,''),(385364,122076,'116532','deals','style_class','hiding-box',0,''),(385365,122077,'116533','deals','padding-top','10',0,''),(385366,122077,'116533','deals','padding-left','20',0,''),(385367,122077,'116533','deals','padding-right','20',0,''),(385368,122077,'116533','deals','margin-top','20',0,''),(385369,122077,'116533','deals','background-color','$content-bg-2',0,''),(385370,122077,'116533','deals','padding-bottom','8',0,''),(385371,122078,'116534','deals','margin-bottom','20',0,''),(385372,122079,'116535','deals','block_type','1',0,''),(385373,122079,'116535','deals','padding-top','30',0,''),(385374,122079,'116535','deals','padding-left','30',0,''),(385375,122079,'116535','deals','padding-right','30',0,''),(385376,122079,'116535','deals','padding-bottom','23',0,''),(385377,122079,'116535','deals','margin-bottom','20',0,''),(385378,122079,'116535','deals','background-color','$content-bg-1',0,''),(385379,122079,'116535','deals','style_class','hiding-box',0,''),(385380,122080,'116536','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(385381,122081,'116537','deals','block_type','2',0,''),(385382,122082,'116538','deals','padding-right','20',0,''),(385383,122083,'116539','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385384,122084,'116540','deals','block_type','1',0,''),(385385,122084,'116540','deals','padding-left','20',0,''),(385386,122085,'116541','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385387,122087,'116543','deals','block_type','1',0,''),(385388,122087,'116543','deals','padding-top','30',0,''),(385389,122087,'116543','deals','padding-left','30',0,''),(385390,122087,'116543','deals','padding-right','30',0,''),(385391,122087,'116543','deals','padding-bottom','14',0,''),(385392,122087,'116543','deals','margin-bottom','20',0,''),(385393,122087,'116543','deals','background-color','$content-bg-1',0,''),(385394,122087,'116543','deals','style_class','hiding-box closeable-box',0,''),(385395,122088,'116544','deals','block_type','2',0,''),(385396,122088,'116544','deals','style_class','closeable-content',0,''),(385397,122089,'116545','deals','padding-right','20',0,''),(385398,122089,'116545','deals','padding-bottom','20',0,''),(385399,122090,'116546','deals','padding-left','20',0,''),(385400,122090,'116546','deals','padding-bottom','20',0,''),(385401,122091,'116547','deals','padding-left','20',0,''),(385402,122091,'116547','deals','padding-bottom','20',0,''),(385403,122092,'116548','deals','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(385404,122092,'116548','deals','style_class','closeable-heading closeable-event closed',0,''),(385405,122093,'116549','deals','block_type','1',0,''),(385406,122093,'116549','deals','background-color','$content-bg-1',0,''),(385407,122093,'116549','deals','padding-top','30',0,''),(385408,122093,'116549','deals','padding-left','30',0,''),(385409,122093,'116549','deals','padding-right','30',0,''),(385410,122093,'116549','deals','padding-bottom','14',0,''),(385411,122093,'116549','deals','margin-bottom','20',0,''),(385412,122093,'116549','deals','style_class','hiding-box closeable-box',0,''),(385413,122094,'116550','deals','style_class','closeable-content',0,''),(385414,122094,'116550','deals','padding-bottom','20',0,''),(385415,122095,'116551','deals','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(385416,122095,'116551','deals','style_class','closeable-heading closeable-event closed',0,''),(385417,122096,'116552','deals','block_type','1',0,''),(385418,122096,'116552','deals','padding-top','10',0,''),(385419,122096,'116552','deals','padding-left','10',0,''),(385420,122096,'116552','deals','padding-right','10',0,''),(385421,122096,'116552','deals','padding-bottom','10',0,''),(385422,122096,'116552','deals','background-color','$content-bg-1',0,''),(385423,122096,'116552','deals','style_class','order-summary hiding-box',0,''),(385424,122096,'116552','deals','margin-left','25',0,''),(385425,122097,'116553','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(385426,122098,'116554','deals','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(385427,122098,'116554','deals','text-align','center',0,''),(385428,122098,'116554','deals','font-size','14',0,''),(385429,122098,'116554','deals','color','$fade-color-1',0,''),(385430,122098,'116554','deals','padding-top','10',0,''),(385431,122099,'116555','deals','margin-bottom','10',0,''),(385432,122101,'116557','deals','hide_page','1',0,''),(385433,122101,'116557','deals','hide_continue_button','1',0,''),(385434,122102,'116558','deals','block_type','1',0,''),(385435,122104,'116560','deals','block_type','4',0,''),(385436,122104,'116560','deals','schema','4-2',0,'5660'),(385437,122105,'116561','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385438,122105,'116561','deals','text-align','right',0,''),(385439,122105,'116561','deals','padding-top','10',0,''),(385440,122105,'116561','deals','font_size_measure','em',0,''),(385441,122105,'116561','deals','font-size','1.2',0,''),(385442,122106,'116562','deals','text-align','right',0,''),(385443,122107,'116563','deals','block_type','2',0,''),(385444,122107,'116563','deals','schema','2-2',0,'5639'),(385445,122108,'116564','deals','block_type','1',0,''),(385446,122108,'116564','deals','padding-right','20',0,''),(385447,122108,'116564','deals','padding-right','0',0,'5639'),(385448,122110,'116566','deals','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(385449,122111,'116567','deals','block_type','1',0,''),(385450,122111,'116567','deals','padding-left','20',0,''),(385451,122111,'116567','deals','padding-left','0',0,'5639'),(385452,122113,'116569','deals','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(385453,122114,'116570','deals','block_type','2',0,''),(385454,122114,'116570','deals','schema','2-2',0,'5639'),(385455,122115,'116571','deals','block_type','1',0,''),(385456,122115,'116571','deals','padding-right','20',0,''),(385457,122115,'116571','deals','padding-right','0',0,'5639'),(385458,122116,'116572','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385459,122118,'116574','deals','block_type','1',0,''),(385460,122118,'116574','deals','padding-left','20',0,''),(385461,122118,'116574','deals','padding-left','0',0,'5639'),(385462,122123,'116579','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385463,122124,'116580','deals','margin-bottom','20',0,''),(385464,122125,'116581','deals','block_type','1',0,''),(385465,122125,'116581','deals','background-color','$content-bg-2',0,''),(385466,122125,'116581','deals','padding-top','30',0,''),(385467,122125,'116581','deals','padding-bottom','30',0,''),(385468,122126,'116582','deals','block_type','7',0,''),(385469,122126,'116582','deals','schema','4-2',0,'5639'),(385470,122126,'116582','deals','margin-bottom','30',0,''),(385471,122127,'116583','deals','block_type','1',0,''),(385472,122127,'116583','deals','padding-right','0',0,'5639'),(385473,122128,'116585','deals','block_type','1',0,''),(385474,122128,'116585','deals','background-color','$content-bg-1',0,''),(385475,122128,'116585','deals','padding-top','30',0,''),(385476,122128,'116585','deals','padding-left','30',0,''),(385477,122128,'116585','deals','padding-right','30',0,''),(385478,122128,'116585','deals','padding-bottom','14',0,''),(385479,122128,'116585','deals','margin-bottom','20',0,''),(385480,122128,'116585','deals','style_class','hiding-box closeable-box',0,''),(385481,122129,'116586','deals','style_class','closeable-content',0,''),(385482,122129,'116586','deals','padding-bottom','20',0,''),(385483,122130,'116587','deals','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(385484,122130,'116587','deals','style_class','closeable-heading closeable-event closed',0,''),(385485,122131,'116588','deals','block_type','1',0,''),(385486,122131,'116588','deals','background-color','$content-bg-1',0,''),(385487,122131,'116588','deals','padding-top','30',0,''),(385488,122131,'116588','deals','padding-left','30',0,''),(385489,122131,'116588','deals','padding-right','30',0,''),(385490,122131,'116588','deals','padding-bottom','30',0,''),(385491,122131,'116588','deals','margin-bottom','20',0,''),(385492,122131,'116588','deals','style_class','hiding-box',0,''),(385493,122132,'116589','deals','padding-top','10',0,''),(385494,122132,'116589','deals','padding-left','20',0,''),(385495,122132,'116589','deals','padding-right','20',0,''),(385496,122132,'116589','deals','margin-top','20',0,''),(385497,122132,'116589','deals','background-color','$content-bg-2',0,''),(385498,122132,'116589','deals','padding-bottom','8',0,''),(385499,122133,'116590','deals','margin-bottom','20',0,''),(385500,122134,'116591','deals','block_type','1',0,''),(385501,122134,'116591','deals','padding-top','30',0,''),(385502,122134,'116591','deals','padding-left','30',0,''),(385503,122134,'116591','deals','padding-right','30',0,''),(385504,122134,'116591','deals','padding-bottom','23',0,''),(385505,122134,'116591','deals','margin-bottom','20',0,''),(385506,122134,'116591','deals','background-color','$content-bg-1',0,''),(385507,122134,'116591','deals','style_class','hiding-box',0,''),(385508,122135,'116592','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(385509,122136,'116593','deals','block_type','2',0,''),(385510,122136,'116593','deals','schema','2-2',0,'5639'),(385511,122137,'116594','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385512,122138,'116595','deals','padding-right','20',0,''),(385513,122138,'116595','deals','padding-right','0',0,'5639'),(385514,122138,'116595','deals','padding-bottom','20',0,'5639'),(385515,122139,'116596','deals','block_type','1',0,''),(385516,122139,'116596','deals','padding-left','20',0,''),(385517,122139,'116596','deals','padding-left','0',0,'5639'),(385518,122141,'116598','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385519,122142,'116599','deals','block_type','1',0,''),(385520,122142,'116599','deals','padding-top','10',0,''),(385521,122142,'116599','deals','padding-left','10',0,''),(385522,122142,'116599','deals','padding-right','10',0,''),(385523,122142,'116599','deals','padding-bottom','10',0,''),(385524,122142,'116599','deals','background-color','$content-bg-1',0,''),(385525,122142,'116599','deals','style_class','order-summary',0,''),(385526,122142,'116599','deals','margin-left','25',0,''),(385527,122144,'116601','deals','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(385528,122144,'116601','deals','text-align','center',0,''),(385529,122144,'116601','deals','font-size','14',0,''),(385530,122144,'116601','deals','color','$fade-color-1',0,''),(385531,122144,'116601','deals','padding-top','10',0,''),(385532,122145,'116602','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(385533,122146,'116603','deals','margin-bottom','10',0,''),(385534,122148,'116604','deals','block_type','2',0,''),(385535,122148,'116604','deals','schema','2-2',0,'5630'),(385536,122149,'116605','deals','block_type','1',0,''),(385537,122149,'116605','deals','padding-left','0',0,'5639'),(385538,122149,'116605','deals','padding-right','20',0,''),(385539,122151,'116607','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385540,122152,'116608','deals','block_type','1',0,''),(385541,122152,'116608','deals','padding-left','20',0,''),(385542,122152,'116608','deals','padding-left','0',0,'5639'),(385543,122157,'116613','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385544,122158,'116614','deals','block_type','4',0,''),(385545,122158,'116614','deals','schema','4-2',0,'5660'),(385546,122158,'116614','deals','padding-top','20',0,''),(385547,122159,'116615','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385548,122159,'116615','deals','text-align','right',0,''),(385549,122159,'116615','deals','padding-top','10',0,''),(385550,122159,'116615','deals','font_size_measure','em',0,''),(385551,122159,'116615','deals','font-size','1.2',0,''),(385552,122159,'116615','deals','text-align','center',0,'5630'),(385553,122160,'116616','deals','text-align','right',0,''),(385554,122160,'116616','deals','text-align','center',0,'5630'),(385555,122161,'116617','deals','block_type','2',0,''),(385556,122162,'116618','deals','block_type','1',0,''),(385557,122162,'116618','deals','padding-left','0',0,'5639'),(385558,122162,'116618','deals','padding-right','20',0,''),(385559,122164,'116620','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385560,122165,'116621','deals','block_type','1',0,''),(385561,122165,'116621','deals','padding-left','20',0,''),(385562,122165,'116621','deals','padding-left','0',0,'5639'),(385563,122167,'116623','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385564,122171,'116627','deals','block_type','4',0,''),(385565,122171,'116627','deals','schema','4-2',0,'5660'),(385566,122172,'116628','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385567,122172,'116628','deals','text-align','right',0,''),(385568,122172,'116628','deals','padding-top','10',0,''),(385569,122172,'116628','deals','font_size_measure','em',0,''),(385570,122172,'116628','deals','font-size','1.2',0,''),(385571,122173,'116629','deals','text-align','right',0,''),(385572,122174,'116630','deals','block_type','4',0,''),(385573,122174,'116630','deals','schema','4-2',0,'5660'),(385574,122175,'116631','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385575,122175,'116631','deals','text-align','right',0,''),(385576,122175,'116631','deals','padding-top','10',0,''),(385577,122175,'116631','deals','font_size_measure','em',0,''),(385578,122175,'116631','deals','font-size','1.2',0,''),(385579,122176,'116632','deals','text-align','right',0,''),(385580,122177,'116633','deals','block_type','2',0,''),(385581,122178,'116634','deals','block_type','1',0,''),(385582,122178,'116634','deals','padding-left','0',0,'5639'),(385583,122178,'116634','deals','padding-right','20',0,''),(385584,122179,'116635','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385585,122181,'116637','deals','block_type','1',0,''),(385586,122181,'116637','deals','padding-left','20',0,''),(385587,122181,'116637','deals','padding-left','0',0,'5639'),(385588,122186,'116642','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385589,122187,'116643','deals','block_type','4',0,''),(385590,122187,'116643','deals','schema','4-2',0,'5660'),(385591,122188,'116644','deals','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(385592,122188,'116644','deals','text-align','right',0,''),(385593,122188,'116644','deals','padding-top','10',0,''),(385594,122188,'116644','deals','font_size_measure','em',0,''),(385595,122188,'116644','deals','font-size','1.2',0,''),(385596,122189,'116645','deals','text-align','right',0,''),(385597,122190,'116646','deals','block_type','2',0,''),(385598,122191,'116647','deals','block_type','1',0,''),(385599,122191,'116647','deals','padding-left','0',0,'5639'),(385600,122191,'116647','deals','padding-right','20',0,''),(385601,122193,'116649','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385602,122194,'116650','deals','block_type','1',0,''),(385603,122194,'116650','deals','padding-left','20',0,''),(385604,122194,'116650','deals','padding-left','0',0,'5639'),(385605,122198,'116654','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385606,122200,'116656','deals','text','##PAYMENT_DETAILS##',0,''),(385607,122201,'116657','deals','text','##PAYMENT_DETAILS##',0,''),(385608,122202,'116658','deals','text','##PAYMENT_DETAILS##',0,''),(385609,122203,'116659','deals','text','##PAYMENT_DETAILS##',0,''),(385610,122204,'116660','deals','text','##PAYMENT_DETAILS##',0,''),(385611,122205,'116661','deals','text','##PAYMENT_DETAILS##',0,''),(385612,122206,'120947','deals','block_type','1',0,''),(385613,122206,'120947','deals','background-color','$content-bg-2',0,''),(385614,122206,'120947','deals','padding-top','30',0,''),(385615,122206,'120947','deals','padding-bottom','30',0,''),(385616,122207,'120948','deals','block_type','7',0,''),(385617,122207,'120948','deals','schema','4-2',0,'5639'),(385618,122208,'120949','deals','block_type','1',0,''),(385619,122208,'120949','deals','padding-right','0',0,'5639'),(385620,122209,'120950','deals','block_type','1',0,''),(385621,122209,'120950','deals','background-color','$content-bg-1',0,''),(385622,122209,'120950','deals','padding-top','30',0,''),(385623,122209,'120950','deals','padding-left','30',0,''),(385624,122209,'120950','deals','padding-right','30',0,''),(385625,122209,'120950','deals','padding-bottom','30',0,''),(385626,122209,'120950','deals','margin-bottom','20',0,''),(385627,122209,'120950','deals','style_class','hiding-box',0,''),(385628,122210,'120951','deals','padding-top','10',0,''),(385629,122210,'120951','deals','padding-left','20',0,''),(385630,122210,'120951','deals','padding-right','20',0,''),(385631,122210,'120951','deals','margin-top','20',0,''),(385632,122210,'120951','deals','background-color','$content-bg-2',0,''),(385633,122210,'120951','deals','padding-bottom','8',0,''),(385634,122211,'120952','deals','margin-bottom','20',0,''),(385635,122212,'120953','deals','background-color','$content-bg-1',0,''),(385636,122212,'120953','deals','block_type','1',0,''),(385637,122212,'120953','deals','padding-top','30',0,''),(385638,122212,'120953','deals','padding-left','30',0,''),(385639,122212,'120953','deals','padding-right','30',0,''),(385640,122212,'120953','deals','padding-bottom','30',0,''),(385641,122212,'120953','deals','margin-bottom','20',0,''),(385642,122212,'120953','deals','style_class','hiding-box',0,''),(385643,122213,'120954','deals','block_type','1',0,''),(385644,122213,'120954','deals','content','\\_',0,'3'),(385645,122213,'120954','deals','border-top-width','1',0,'3'),(385646,122213,'120954','deals','border-top-color','$content-border-1',0,'3'),(385647,122213,'120954','deals','display','block',0,'3'),(385648,122213,'120954','deals','position','absolute',0,'3'),(385649,122213,'120954','deals','top','19',0,'3'),(385650,122213,'120954','deals','left','0',0,'3'),(385651,122213,'120954','deals','right','0',0,'3'),(385652,122213,'120954','deals','margin-top','-2',0,'3'),(385653,122213,'120954','deals','position','relative',0,''),(385654,122214,'120955','deals','box_align','2',0,''),(385655,122214,'120955','deals','margin-bottom','10',0,''),(385656,122214,'120955','deals','background-color','$content-bg-1',0,''),(385657,122214,'120955','deals','position','relative',0,''),(385658,122215,'120956','deals','background-color','$content-bg-2',0,''),(385659,122215,'120956','deals','padding-top','10',0,''),(385660,122215,'120956','deals','padding-left','10',0,''),(385661,122215,'120956','deals','padding-right','10',0,''),(385662,122215,'120956','deals','padding-bottom','10',0,''),(385663,122215,'120956','deals','margin-top','10',0,''),(385664,122216,'120957','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(385665,122217,'120958','deals','block_type','2',0,''),(385666,122217,'120958','deals','schema','2-2',0,'5639'),(385667,122218,'120959','deals','block_type','1',0,''),(385668,122218,'120959','deals','padding-right','20',0,''),(385669,122218,'120959','deals','padding-left','0',0,'5639'),(385670,122218,'120959','deals','margin-bottom','20',0,'5639'),(385671,122218,'120959','deals','padding-right','0',0,'5639'),(385672,122221,'120962','deals','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(385673,122222,'120963','deals','block_type','1',0,''),(385674,122222,'120963','deals','padding-left','20',0,''),(385675,122222,'120963','deals','padding-left','0',0,'5639'),(385676,122224,'120965','deals','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(385677,122225,'120966','deals','border-top-width','1',0,''),(385678,122225,'120966','deals','border-top-color','$content-border-1',0,''),(385679,122225,'120966','deals','padding-top','13',0,''),(385680,122225,'120966','deals','padding-bottom','10',0,''),(385681,122226,'120967','deals','block_type','1',0,''),(385682,122226,'120967','deals','background-color','$content-bg-1',0,''),(385683,122226,'120967','deals','padding-top','30',0,''),(385684,122226,'120967','deals','padding-left','30',0,''),(385685,122226,'120967','deals','padding-right','30',0,''),(385686,122226,'120967','deals','padding-bottom','14',0,''),(385687,122226,'120967','deals','margin-bottom','20',0,''),(385688,122226,'120967','deals','style_class','hiding-box closeable-box',0,''),(385689,122227,'120968','deals','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(385690,122227,'120968','deals','style_class','closeable-heading closeable-event closed',0,''),(385691,122228,'120969','deals','style_class','closeable-content',0,''),(385692,122228,'120969','deals','padding-bottom','20',0,''),(385693,122229,'120970','deals','block_type','1',0,''),(385694,122229,'120970','deals','padding-top','30',0,''),(385695,122229,'120970','deals','padding-left','30',0,''),(385696,122229,'120970','deals','padding-right','30',0,''),(385697,122229,'120970','deals','padding-bottom','23',0,''),(385698,122229,'120970','deals','margin-bottom','20',0,''),(385699,122229,'120970','deals','background-color','$content-bg-1',0,''),(385700,122229,'120970','deals','style_class','hiding-box',0,''),(385701,122230,'120971','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(385702,122231,'120972','deals','block_type','2',0,''),(385703,122231,'120972','deals','schema','2-2',0,'5639'),(385704,122232,'120973','deals','padding-right','20',0,''),(385705,122232,'120973','deals','padding-right','0',0,'5639'),(385706,122232,'120973','deals','padding-bottom','20',0,'5639'),(385707,122233,'120974','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385708,122234,'120975','deals','block_type','1',0,''),(385709,122234,'120975','deals','padding-left','20',0,''),(385710,122234,'120975','deals','padding-left','0',0,'5639'),(385711,122236,'120977','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385712,122237,'120978','deals','block_type','1',0,''),(385713,122237,'120978','deals','padding-left','10',0,''),(385714,122237,'120978','deals','padding-right','10',0,''),(385715,122237,'120978','deals','padding-bottom','10',0,''),(385716,122237,'120978','deals','background-color','$content-bg-1',0,''),(385717,122237,'120978','deals','style_class','order-summary',0,''),(385718,122237,'120978','deals','margin-left','25',0,''),(385719,122237,'120978','deals','margin-left','0',0,'5639'),(385720,122238,'120979','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(385721,122239,'120980','deals','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(385722,122239,'120980','deals','text-align','center',0,''),(385723,122239,'120980','deals','font-size','14',0,''),(385724,122239,'120980','deals','color','$fade-color-1',0,''),(385725,122239,'120980','deals','padding-top','10',0,''),(385726,122240,'120981','deals','margin-bottom','10',0,''),(385727,122242,'120983','deals','hide_continue_button','1',0,''),(385728,122243,'116699','deals','block_type','1',0,''),(385729,122243,'116699','deals','background-color','$content-bg-2',0,''),(385730,122243,'116699','deals','padding-top','30',0,''),(385731,122243,'116699','deals','padding-bottom','30',0,''),(385732,122244,'116700','deals','block_type','7',0,''),(385733,122244,'116700','deals','schema','7-2',0,'5639'),(385734,122245,'116701','deals','block_type','1',0,''),(385735,122245,'116701','deals','padding-right','0',0,'5639'),(385736,122246,'116703','deals','block_type','1',0,''),(385737,122246,'116703','deals','background-color','$content-bg-1',0,''),(385738,122246,'116703','deals','padding-top','30',0,''),(385739,122246,'116703','deals','padding-left','30',0,''),(385740,122246,'116703','deals','padding-right','30',0,''),(385741,122246,'116703','deals','padding-bottom','30',0,''),(385742,122246,'116703','deals','margin-bottom','20',0,''),(385743,122246,'116703','deals','style_class','hiding-box',0,''),(385744,122247,'116704','deals','margin-bottom','20',0,''),(385745,122248,'116705','deals','padding-top','10',0,''),(385746,122248,'116705','deals','padding-left','20',0,''),(385747,122248,'116705','deals','padding-right','20',0,''),(385748,122248,'116705','deals','margin-top','20',0,''),(385749,122248,'116705','deals','background-color','$content-bg-2',0,''),(385750,122248,'116705','deals','padding-bottom','8',0,''),(385751,122249,'116706','deals','background-color','$content-bg-1',0,''),(385752,122249,'116706','deals','block_type','1',0,''),(385753,122249,'116706','deals','padding-top','30',0,''),(385754,122249,'116706','deals','padding-left','30',0,''),(385755,122249,'116706','deals','padding-right','30',0,''),(385756,122249,'116706','deals','padding-bottom','30',0,''),(385757,122249,'116706','deals','margin-bottom','20',0,''),(385758,122249,'116706','deals','style_class','hiding-box',0,''),(385759,122250,'116707','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(385760,122251,'116708','deals','background-color','$content-bg-2',0,''),(385761,122251,'116708','deals','padding-top','10',0,''),(385762,122251,'116708','deals','padding-left','10',0,''),(385763,122251,'116708','deals','padding-right','10',0,''),(385764,122251,'116708','deals','padding-bottom','10',0,''),(385765,122251,'116708','deals','margin-top','10',0,''),(385766,122252,'116709','deals','block_type','1',0,''),(385767,122252,'116709','deals','content','\\_',0,'3'),(385768,122252,'116709','deals','border-top-width','1',0,'3'),(385769,122252,'116709','deals','border-top-color','$content-border-1',0,'3'),(385770,122252,'116709','deals','display','block',0,'3'),(385771,122252,'116709','deals','position','absolute',0,'3'),(385772,122252,'116709','deals','top','19',0,'3'),(385773,122252,'116709','deals','left','0',0,'3'),(385774,122252,'116709','deals','right','0',0,'3'),(385775,122252,'116709','deals','margin-top','-2',0,'3'),(385776,122252,'116709','deals','position','relative',0,''),(385777,122253,'116710','deals','box_align','2',0,''),(385778,122253,'116710','deals','margin-bottom','10',0,''),(385779,122253,'116710','deals','background-color','$content-bg-1',0,''),(385780,122253,'116710','deals','position','relative',0,''),(385781,122254,'116711','deals','block_type','2',0,''),(385782,122254,'116711','deals','schema','2-2',0,'5639'),(385783,122255,'116712','deals','block_type','1',0,''),(385784,122255,'116712','deals','padding-right','20',0,''),(385785,122255,'116712','deals','padding-left','0',0,'5639'),(385786,122255,'116712','deals','margin-bottom','20',0,'5639'),(385787,122255,'116712','deals','padding-right','0',0,'5639'),(385788,122258,'116715','deals','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(385789,122259,'116716','deals','block_type','1',0,''),(385790,122259,'116716','deals','padding-left','20',0,''),(385791,122259,'116716','deals','padding-left','0',0,'5639'),(385792,122261,'116718','deals','border-top-width','1',0,''),(385793,122261,'116718','deals','border-top-color','$content-border-1',0,''),(385794,122261,'116718','deals','padding-top','13',0,''),(385795,122261,'116718','deals','padding-bottom','10',0,''),(385796,122262,'116719','deals','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(385797,122263,'116720','deals','block_type','1',0,''),(385798,122263,'116720','deals','padding-top','30',0,''),(385799,122263,'116720','deals','padding-left','30',0,''),(385800,122263,'116720','deals','padding-right','30',0,''),(385801,122263,'116720','deals','padding-bottom','23',0,''),(385802,122263,'116720','deals','margin-bottom','20',0,''),(385803,122263,'116720','deals','background-color','$content-bg-1',0,''),(385804,122263,'116720','deals','style_class','hiding-box',0,''),(385805,122264,'116721','deals','block_type','2',0,''),(385806,122264,'116721','deals','schema','2-2',0,'5639'),(385807,122265,'116722','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(385808,122266,'116723','deals','padding-right','20',0,''),(385809,122266,'116723','deals','padding-right','0',0,'5639'),(385810,122266,'116723','deals','padding-bottom','20',0,'5639'),(385811,122267,'116724','deals','block_type','1',0,''),(385812,122267,'116724','deals','padding-left','20',0,''),(385813,122267,'116724','deals','padding-left','0',0,'5639'),(385814,122268,'116725','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(385815,122270,'116727','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(385816,122271,'116728','deals','block_type','1',0,''),(385817,122271,'116728','deals','background-color','$content-bg-1',0,''),(385818,122271,'116728','deals','padding-top','30',0,''),(385819,122271,'116728','deals','padding-left','30',0,''),(385820,122271,'116728','deals','padding-right','30',0,''),(385821,122271,'116728','deals','padding-bottom','14',0,''),(385822,122271,'116728','deals','margin-bottom','20',0,''),(385823,122271,'116728','deals','style_class','hiding-box closeable-box',0,''),(385824,122272,'116729','deals','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(385825,122272,'116729','deals','style_class','closeable-heading closeable-event closed',0,''),(385826,122273,'116730','deals','style_class','closeable-content',0,''),(385827,122273,'116730','deals','padding-bottom','20',0,''),(385828,122274,'116731','deals','block_type','1',0,''),(385829,122274,'116731','deals','padding-top','30',0,''),(385830,122274,'116731','deals','padding-left','30',0,''),(385831,122274,'116731','deals','padding-right','30',0,''),(385832,122274,'116731','deals','padding-bottom','14',0,''),(385833,122274,'116731','deals','margin-bottom','20',0,''),(385834,122274,'116731','deals','background-color','$content-bg-1',0,''),(385835,122274,'116731','deals','style_class','hiding-box closeable-box',0,''),(385836,122275,'116732','deals','block_type','2',0,''),(385837,122275,'116732','deals','style_class','closeable-content',0,''),(385838,122275,'116732','deals','schema','2-2',0,'5639'),(385839,122276,'116733','deals','padding-right','20',0,''),(385840,122276,'116733','deals','padding-bottom','20',0,''),(385841,122276,'116733','deals','padding-right','0',0,'5639'),(385842,122277,'116734','deals','padding-left','20',0,''),(385843,122277,'116734','deals','padding-bottom','20',0,''),(385844,122277,'116734','deals','padding-left','0',0,'5639'),(385845,122278,'116735','deals','padding-left','20',0,''),(385846,122278,'116735','deals','padding-bottom','20',0,''),(385847,122278,'116735','deals','padding-left','0',0,'5639'),(385848,122279,'116736','deals','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(385849,122279,'116736','deals','style_class','closeable-heading closeable-event closed',0,''),(385850,122280,'116737','deals','block_type','1',0,''),(385851,122280,'116737','deals','padding-top','20',0,''),(385852,122280,'116737','deals','padding-left','20',0,''),(385853,122280,'116737','deals','padding-right','20',0,''),(385854,122280,'116737','deals','padding-bottom','20',0,''),(385855,122280,'116737','deals','background-color','$content-bg-1',0,''),(385856,122280,'116737','deals','style_class','order-summary',0,''),(385857,122280,'116737','deals','margin-left','25',0,''),(385858,122280,'116737','deals','padding-left','0',0,'5639'),(385859,122281,'116738','deals','margin-bottom','10',0,''),(385860,122282,'116739','deals','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(385861,122282,'116739','deals','text-align','center',0,''),(385862,122282,'116739','deals','font-size','14',0,''),(385863,122282,'116739','deals','color','$fade-color-1',0,''),(385864,122282,'116739','deals','padding-top','10',0,''),(385865,122283,'116740','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(385866,122285,'120986','deals','hide_continue_button','1',0,''),(385867,122286,'116742','deals','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(385868,122291,'116747','deals','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(385869,122292,'116749','deals','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(385870,122293,'116750','deals','style_class','order-summary',0,''),(385871,122293,'116750','deals','box_align','3',0,''),(385872,122293,'116750','deals','width','400',0,''),(385873,122295,'116748','deals','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(385874,122298,'116754','deals','block_type','1',0,''),(385875,122299,'116755','deals','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(385876,122300,'116756','deals','float','right',0,''),(385877,122300,'116756','deals','position','relative',0,''),(385878,122300,'116756','deals','z-index','1',0,''),(385879,122300,'116756','deals','top','30',0,''),(385880,122300,'116756','deals','margin-bottom','-10',0,''),(385881,122301,'116757','deals','margin-bottom','30',0,''),(385882,122302,'116758','deals','block_type','1',0,''),(385883,122303,'116759','deals','listing_type','CompareProduct',0,''),(385884,122304,'117665','deals','block_type','1',0,''),(385885,122304,'117665','deals','style_class','item-holder',0,''),(385886,122304,'117665','deals','padding-top','25',0,''),(385887,122304,'117665','deals','padding-left','25',0,''),(385888,122304,'117665','deals','padding-right','25',0,''),(385889,122304,'117665','deals','padding-bottom','25',0,''),(385890,122304,'117665','deals','text-align','left',0,''),(385891,122305,'120921','deals','block_type','1',0,''),(385892,122305,'120921','deals','style_class','item-wrapper',0,''),(385893,122306,'120919','deals','block_type','1',0,''),(385894,122306,'120919','deals','style_class','item-content',0,''),(385895,122307,'1638872990','deals','block_type','5',0,''),(385896,122309,'117677','deals','float','right',0,''),(385897,122310,'117675','deals','clear','none',0,''),(385898,122311,'117676','deals','margin-bottom','10',0,''),(385899,122312,'1638873112','deals','block_type','2',0,''),(385900,122314,'117673','deals','margin-bottom','7',0,''),(385901,122314,'117673','deals','text-align','right',0,''),(385902,122315,'116760','deals','block_type','1',0,''),(385903,122315,'116760','deals','style_class','item-holder',0,''),(385904,122315,'116760','deals','padding-top','10',0,''),(385905,122315,'116760','deals','padding-left','20',0,''),(385906,122315,'116760','deals','padding-right','20',0,''),(385907,122315,'116760','deals','padding-bottom','10',0,''),(385908,122315,'116760','deals','text-align','left',0,''),(385909,122318,'116763','deals','margin-bottom','10',0,''),(385910,122319,'116764','deals','block_type','5',0,''),(385911,122321,'116766','deals','clear','both',0,''),(385912,122322,'116767','deals','block_type','2',0,''),(385913,122323,'116768','deals','margin-bottom','7',0,''),(385914,122324,'116769','deals','text-align','right',0,''),(385915,122324,'116769','deals','margin-bottom','10',0,''),(385916,122324,'116769','deals','float','right',0,''),(385917,122325,'116770','deals','block_type','1',0,''),(385918,122325,'116770','deals','padding-bottom','30',0,''),(385919,122325,'116770','deals','style_class','checkout-order-confirmation',0,''),(385920,122326,'116771','deals','block_type','4',0,''),(385921,122326,'116771','deals','schema','4-2',0,'5639'),(385922,122327,'116772','deals','block_type','1',0,''),(385923,122327,'116772','deals','padding-right','0',0,'5639'),(385924,122327,'116772','deals','margin-bottom','30',0,''),(385925,122328,'116773','deals','block_type','1',0,''),(385926,122328,'116773','deals','padding-right','20',0,''),(385927,122328,'116773','deals','background-color','$content-bg-1',0,''),(385928,122328,'116773','deals','padding-top','20',0,''),(385929,122328,'116773','deals','padding-left','20',0,''),(385930,122328,'116773','deals','padding-bottom','20',0,''),(385931,122328,'116773','deals','padding-left','15',0,'5639'),(385932,122328,'116773','deals','padding-right','15',0,'5639'),(385933,122328,'116773','deals','border-top-width','1',0,''),(385934,122328,'116773','deals','border-left-width','1',0,''),(385935,122328,'116773','deals','border-right-width','1',0,''),(385936,122328,'116773','deals','border-bottom-width','1',0,''),(385937,122328,'116773','deals','border-top-color','$content-border-1',0,''),(385938,122328,'116773','deals','border-left-color','$content-border-1',0,''),(385939,122328,'116773','deals','border-right-color','$content-border-1',0,''),(385940,122328,'116773','deals','border-bottom-color','$content-border-1',0,''),(385941,122328,'116773','deals','padding-top','15',0,'5639'),(385942,122328,'116773','deals','padding-bottom','15',0,'5639'),(385943,122329,'116774','deals','link','products',0,''),(385944,122329,'116774','deals','float','right',0,''),(385945,122329,'116774','deals','margin-top','-37',0,''),(385946,122331,'116776','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(385947,122332,'116777','deals','block_type','1',0,''),(385948,122332,'116777','deals','background-color','$content-bg-1',0,''),(385949,122332,'116777','deals','padding-top','20',0,''),(385950,122332,'116777','deals','padding-bottom','20',0,''),(385951,122332,'116777','deals','padding-left','20',0,''),(385952,122332,'116777','deals','padding-right','20',0,''),(385953,122332,'116777','deals','margin-bottom','20',0,''),(385954,122332,'116777','deals','border-top-width','1',0,''),(385955,122332,'116777','deals','border-left-width','1',0,''),(385956,122332,'116777','deals','border-right-width','1',0,''),(385957,122332,'116777','deals','border-bottom-width','1',0,''),(385958,122332,'116777','deals','border-top-color','$content-border-1',0,''),(385959,122332,'116777','deals','border-left-color','$content-border-1',0,''),(385960,122332,'116777','deals','border-right-color','$content-border-1',0,''),(385961,122332,'116777','deals','border-bottom-color','$content-border-1',0,''),(385962,122332,'116777','deals','padding-top','15',0,'5639'),(385963,122332,'116777','deals','padding-left','15',0,'5639'),(385964,122332,'116777','deals','padding-right','15',0,'5639'),(385965,122332,'116777','deals','padding-bottom','15',0,'5639'),(385966,122333,'116778','deals','float','right',0,''),(385967,122333,'116778','deals','margin-top','-37',0,''),(385968,122333,'116778','deals','link','comments',0,''),(385969,122334,'116779','deals','text',' <div class=\"heading-2\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(385970,122335,'116780','deals','hide_parents','2',0,''),(385971,122336,'116782','deals','block_type','1',0,''),(385972,122336,'116782','deals','padding-right','20',0,''),(385973,122336,'116782','deals','padding-top','20',0,''),(385974,122336,'116782','deals','padding-left','20',0,''),(385975,122336,'116782','deals','padding-bottom','20',0,''),(385976,122336,'116782','deals','margin-right','0',0,'5639'),(385977,122336,'116782','deals','margin-bottom','20',0,'5639'),(385978,122336,'116782','deals','padding-left','15',0,'5639'),(385979,122336,'116782','deals','padding-right','15',0,'5639'),(385980,122336,'116782','deals','border-top-width','1',0,''),(385981,122336,'116782','deals','border-left-width','1',0,''),(385982,122336,'116782','deals','border-right-width','1',0,''),(385983,122336,'116782','deals','border-bottom-width','1',0,''),(385984,122336,'116782','deals','border-top-color','$content-border-1',0,''),(385985,122336,'116782','deals','border-left-color','$content-border-1',0,''),(385986,122336,'116782','deals','border-right-color','$content-border-1',0,''),(385987,122336,'116782','deals','border-bottom-color','$content-border-1',0,''),(385988,122336,'116782','deals','margin-bottom','30',0,''),(385989,122337,'116789','deals','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(385990,122338,'1643301641','deals','block_type','2',0,''),(385991,122338,'1643301641','deals','schema','2-2',0,'5660'),(385992,122339,'116785','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(385993,122339,'116785','deals','padding-top','20',0,''),(385994,122339,'116785','deals','padding-top','0',0,'5660'),(385995,122340,'116786','deals','link','contact_information',0,''),(385996,122340,'116786','deals','margin-top','-31',0,''),(385997,122340,'116786','deals','float','right',0,''),(385998,122341,'116790','deals','link','shipping_address',0,''),(385999,122341,'116790','deals','float','right',0,''),(386000,122341,'116790','deals','margin-top','-31',0,''),(386001,122342,'116791','deals','padding-bottom','20',0,'5660'),(386002,122343,'116792','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(386003,122343,'116792','deals','clear','none',0,''),(386004,122344,'116793','deals','margin-bottom','20',0,''),(386005,122345,'116783','deals','link','shipping_method',0,''),(386006,122345,'116783','deals','float','right',0,''),(386007,122345,'116783','deals','margin-top','-31',0,''),(386008,122347,'116787','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(386009,122347,'116787','deals','clear','none',0,''),(386010,122349,'116794','deals','block_type','1',0,''),(386011,122349,'116794','deals','padding-left','20',0,''),(386012,122349,'116794','deals','border-left-width','1',0,''),(386013,122349,'116794','deals','border-left-color','$content-border-1',0,''),(386014,122349,'116794','deals','padding-right','20',0,''),(386015,122349,'116794','deals','padding-top','20',0,''),(386016,122349,'116794','deals','padding-bottom','20',0,''),(386017,122349,'116794','deals','border-top-width','1',0,''),(386018,122349,'116794','deals','border-right-width','1',0,''),(386019,122349,'116794','deals','border-bottom-width','1',0,''),(386020,122349,'116794','deals','border-top-color','$content-border-1',0,''),(386021,122349,'116794','deals','border-right-color','$content-border-1',0,''),(386022,122349,'116794','deals','border-bottom-color','$content-border-1',0,''),(386023,122349,'116794','deals','margin-bottom','30',0,''),(386024,122349,'116794','deals','padding-top','15',0,'5639'),(386025,122349,'116794','deals','padding-left','15',0,'5639'),(386026,122349,'116794','deals','padding-right','15',0,'5639'),(386027,122349,'116794','deals','padding-bottom','15',0,'5639'),(386028,122350,'116799','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(386029,122351,'1643301813','deals','block_type','2',0,''),(386030,122351,'1643301813','deals','schema','2-2',0,'5660'),(386031,122352,'116796','deals','link','billing_address',0,''),(386032,122352,'116796','deals','float','right',0,''),(386033,122352,'116796','deals','margin-top','-31',0,''),(386034,122353,'116800','deals','margin-bottom','20',0,''),(386035,122354,'116801','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(386036,122354,'116801','deals','clear','none',0,''),(386037,122355,'116795','deals','link','payment_method',0,''),(386038,122355,'116795','deals','float','right',0,''),(386039,122355,'116795','deals','margin-top','-31',0,''),(386040,122357,'116798','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(386041,122357,'116798','deals','clear','none',0,''),(386042,122359,'116803','deals','block_type','1',0,''),(386043,122359,'116803','deals','padding-left','30',0,''),(386044,122359,'116803','deals','background-color','$content-bg-1',0,''),(386045,122359,'116803','deals','style_class','order-summary',0,''),(386046,122359,'116803','deals','padding-left','0',0,'5639'),(386047,122360,'116804','deals','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(386048,122361,'116805','deals','margin-bottom','20',0,''),(386049,122361,'116805','deals','text-align','right',0,''),(386050,122363,'116807','deals','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(386051,122364,'116808','deals','block_type','1',0,''),(386052,122364,'116808','deals','background-color','$content-bg-2',0,''),(386053,122364,'116808','deals','padding-bottom','30',0,''),(386054,122365,'116809','deals','block_type','4',0,''),(386055,122365,'116809','deals','schema','4-2',0,'5639'),(386056,122366,'116810','deals','block_type','1',0,''),(386057,122366,'116810','deals','padding-right','40',0,''),(386058,122366,'116810','deals','padding-right','0',0,'5639'),(386059,122367,'116811','deals','block_type','1',0,''),(386060,122367,'116811','deals','background-color','$content-bg-1',0,''),(386061,122367,'116811','deals','padding-top','20',0,''),(386062,122367,'116811','deals','padding-bottom','20',0,''),(386063,122367,'116811','deals','padding-left','30',0,''),(386064,122367,'116811','deals','padding-right','30',0,''),(386065,122367,'116811','deals','margin-bottom','20',0,''),(386066,122368,'116812','deals','hide_parents','2',0,''),(386067,122369,'116813','deals','float','right',0,''),(386068,122369,'116813','deals','margin-top','-37',0,''),(386069,122369,'116813','deals','link','comments',0,''),(386070,122370,'116814','deals','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(386071,122371,'116815','deals','block_type','1',0,''),(386072,122371,'116815','deals','padding-right','30',0,''),(386073,122371,'116815','deals','background-color','$content-bg-1',0,''),(386074,122371,'116815','deals','padding-top','20',0,''),(386075,122371,'116815','deals','padding-left','30',0,''),(386076,122371,'116815','deals','padding-bottom','20',0,''),(386077,122371,'116815','deals','padding-left','20',0,'5639'),(386078,122371,'116815','deals','padding-right','20',0,'5639'),(386079,122372,'116816','deals','link','products',0,''),(386080,122372,'116816','deals','float','right',0,''),(386081,122372,'116816','deals','margin-top','-37',0,''),(386082,122373,'116817','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(386083,122375,'116819','deals','block_type','2',0,''),(386084,122375,'116819','deals','margin-bottom','20',0,''),(386085,122375,'116819','deals','schema','2-2',0,'5630'),(386086,122375,'116819','deals','background-color','$content-bg-1',0,''),(386087,122376,'116820','deals','block_type','1',0,''),(386088,122376,'116820','deals','border-right-width','20',0,''),(386089,122376,'116820','deals','border-right-color','$content-border-1',0,''),(386090,122376,'116820','deals','margin-right','-10',0,''),(386091,122376,'116820','deals','padding-right','30',0,''),(386092,122376,'116820','deals','padding-top','20',0,''),(386093,122376,'116820','deals','padding-left','30',0,''),(386094,122376,'116820','deals','padding-bottom','20',0,''),(386095,122376,'116820','deals','border-right-width','0',0,'5639'),(386096,122376,'116820','deals','margin-right','0',0,'5639'),(386097,122376,'116820','deals','margin-bottom','20',0,'5639'),(386098,122376,'116820','deals','padding-left','20',0,'5639'),(386099,122376,'116820','deals','padding-right','20',0,'5639'),(386100,122377,'116821','deals','link','shipping_address',0,''),(386101,122377,'116821','deals','float','right',0,''),(386102,122377,'116821','deals','margin-top','-31',0,''),(386103,122379,'116823','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(386104,122379,'116823','deals','clear','none',0,''),(386105,122380,'116824','deals','link','shipping_method',0,''),(386106,122380,'116824','deals','float','right',0,''),(386107,122380,'116824','deals','margin-top','-31',0,''),(386108,122381,'116825','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(386109,122381,'116825','deals','clear','none',0,''),(386110,122382,'116826','deals','margin-bottom','20',0,''),(386111,122383,'116827','deals','block_type','1',0,''),(386112,122383,'116827','deals','padding-left','30',0,''),(386113,122383,'116827','deals','border-left-width','20',0,''),(386114,122383,'116827','deals','border-left-color','$content-border-1',0,''),(386115,122383,'116827','deals','margin-left','-10',0,''),(386116,122383,'116827','deals','padding-right','30',0,''),(386117,122383,'116827','deals','padding-top','20',0,''),(386118,122383,'116827','deals','padding-bottom','20',0,''),(386119,122383,'116827','deals','border-left-width','0',0,'5639'),(386120,122386,'116830','deals','link','contact_information',0,''),(386121,122386,'116830','deals','margin-top','-31',0,''),(386122,122386,'116830','deals','float','right',0,''),(386123,122387,'116831','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(386124,122388,'116832','deals','block_type','1',0,''),(386125,122388,'116832','deals','padding-top','20',0,''),(386126,122388,'116832','deals','padding-left','20',0,''),(386127,122388,'116832','deals','padding-right','20',0,''),(386128,122388,'116832','deals','padding-bottom','20',0,''),(386129,122388,'116832','deals','background-color','$content-bg-1',0,''),(386130,122388,'116832','deals','style_class','order-summary',0,''),(386131,122389,'116833','deals','margin-bottom','20',0,''),(386132,122389,'116833','deals','text-align','right',0,''),(386133,122390,'116834','deals','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(386134,122391,'116835','deals','block_type','1',0,''),(386135,122391,'116835','deals','background-color','$content-bg-2',0,''),(386136,122391,'116835','deals','padding-bottom','30',0,''),(386137,122392,'116836','deals','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(386138,122393,'116837','deals','block_type','4',0,''),(386139,122394,'116838','deals','block_type','1',0,''),(386140,122394,'116838','deals','padding-right','40',0,''),(386141,122395,'116839','deals','block_type','2',0,''),(386142,122395,'116839','deals','margin-bottom','20',0,''),(386143,122395,'116839','deals','schema','2-2',0,'5630'),(386144,122395,'116839','deals','background-color','$content-bg-1',0,''),(386145,122396,'116840','deals','block_type','1',0,''),(386146,122396,'116840','deals','padding-right','0',0,'5630'),(386147,122396,'116840','deals','border-right-width','20',0,''),(386148,122396,'116840','deals','border-right-color','$content-border-1',0,''),(386149,122396,'116840','deals','margin-right','-10',0,''),(386150,122396,'116840','deals','padding-right','30',0,''),(386151,122396,'116840','deals','padding-top','20',0,''),(386152,122396,'116840','deals','padding-left','30',0,''),(386153,122396,'116840','deals','padding-bottom','20',0,''),(386154,122397,'116841','deals','link','contact_information',0,''),(386155,122397,'116841','deals','float','right',0,''),(386156,122398,'116842','deals','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(386157,122400,'116844','deals','block_type','1',0,''),(386158,122400,'116844','deals','padding-left','30',0,''),(386159,122400,'116844','deals','padding-left','0',0,'5630'),(386160,122400,'116844','deals','border-left-width','20',0,''),(386161,122400,'116844','deals','border-left-color','$content-border-1',0,''),(386162,122400,'116844','deals','margin-left','-10',0,''),(386163,122400,'116844','deals','padding-right','30',0,''),(386164,122400,'116844','deals','padding-top','20',0,''),(386165,122400,'116844','deals','padding-bottom','20',0,''),(386166,122402,'116846','deals','link','payment_method',0,''),(386167,122402,'116846','deals','float','right',0,''),(386168,122402,'116846','deals','margin-top','-31',0,''),(386169,122403,'116847','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(386170,122403,'116847','deals','clear','none',0,''),(386171,122404,'116848','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(386172,122405,'116849','deals','link','billing_address',0,''),(386173,122405,'116849','deals','float','right',0,''),(386174,122405,'116849','deals','margin-top','-31',0,''),(386175,122406,'116850','deals','margin-bottom','20',0,''),(386176,122407,'116851','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(386177,122407,'116851','deals','clear','none',0,''),(386178,122408,'116852','deals','block_type','1',0,''),(386179,122408,'116852','deals','background-color','$content-bg-1',0,''),(386180,122408,'116852','deals','padding-top','20',0,''),(386181,122408,'116852','deals','padding-bottom','20',0,''),(386182,122408,'116852','deals','padding-left','30',0,''),(386183,122408,'116852','deals','padding-right','30',0,''),(386184,122408,'116852','deals','margin-bottom','20',0,''),(386185,122409,'116853','deals','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(386186,122410,'116854','deals','hide_parents','2',0,''),(386187,122411,'116855','deals','float','right',0,''),(386188,122411,'116855','deals','margin-top','-37',0,''),(386189,122411,'116855','deals','link','comments',0,''),(386190,122412,'116856','deals','block_type','1',0,''),(386191,122412,'116856','deals','padding-right','30',0,''),(386192,122412,'116856','deals','padding-right','0',0,'5630'),(386193,122412,'116856','deals','background-color','$content-bg-1',0,''),(386194,122412,'116856','deals','padding-top','20',0,''),(386195,122412,'116856','deals','padding-left','30',0,''),(386196,122412,'116856','deals','padding-bottom','20',0,''),(386197,122413,'116857','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(386198,122414,'116858','deals','link','products',0,''),(386199,122414,'116858','deals','float','right',0,''),(386200,122414,'116858','deals','margin-top','-37',0,''),(386201,122416,'116860','deals','block_type','1',0,''),(386202,122416,'116860','deals','padding-top','20',0,''),(386203,122416,'116860','deals','padding-left','20',0,''),(386204,122416,'116860','deals','padding-right','20',0,''),(386205,122416,'116860','deals','padding-bottom','20',0,''),(386206,122416,'116860','deals','background-color','$content-bg-1',0,''),(386207,122416,'116860','deals','style_class','order-summary2 hiding-box',0,''),(386208,122417,'116861','deals','margin-bottom','20',0,''),(386209,122417,'116861','deals','text-align','right',0,''),(386210,122418,'116862','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(386211,122420,'116864','deals','block_type','1',0,''),(386212,122420,'116864','deals','background-color','$content-bg-2',0,''),(386213,122420,'116864','deals','padding-bottom','30',0,''),(386214,122421,'116865','deals','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(386215,122422,'116866','deals','block_type','4',0,''),(386216,122422,'116866','deals','schema','4-2',0,'5639'),(386217,122423,'116867','deals','block_type','1',0,''),(386218,122423,'116867','deals','padding-right','40',0,''),(386219,122423,'116867','deals','padding-right','0',0,'5639'),(386220,122424,'116868','deals','block_type','1',0,''),(386221,122424,'116868','deals','background-color','$content-bg-1',0,''),(386222,122424,'116868','deals','padding-top','20',0,''),(386223,122424,'116868','deals','padding-bottom','20',0,''),(386224,122424,'116868','deals','padding-left','30',0,''),(386225,122424,'116868','deals','padding-right','30',0,''),(386226,122424,'116868','deals','margin-bottom','20',0,''),(386227,122425,'116869','deals','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(386228,122426,'116870','deals','hide_parents','2',0,''),(386229,122427,'116871','deals','float','right',0,''),(386230,122427,'116871','deals','margin-top','-37',0,''),(386231,122427,'116871','deals','link','comments',0,''),(386232,122428,'116872','deals','block_type','2',0,''),(386233,122428,'116872','deals','margin-bottom','20',0,''),(386234,122428,'116872','deals','schema','2-2',0,'5630'),(386235,122428,'116872','deals','background-color','$content-bg-1',0,''),(386236,122429,'116873','deals','block_type','1',0,''),(386237,122429,'116873','deals','border-right-width','20',0,''),(386238,122429,'116873','deals','border-right-color','$content-border-1',0,''),(386239,122429,'116873','deals','margin-right','-10',0,''),(386240,122429,'116873','deals','padding-right','30',0,''),(386241,122429,'116873','deals','padding-top','20',0,''),(386242,122429,'116873','deals','padding-left','30',0,''),(386243,122429,'116873','deals','padding-bottom','20',0,''),(386244,122429,'116873','deals','border-right-width','0',0,'5639'),(386245,122429,'116873','deals','margin-right','0',0,'5639'),(386246,122429,'116873','deals','margin-bottom','20',0,'5639'),(386247,122429,'116873','deals','padding-left','20',0,'5639'),(386248,122429,'116873','deals','padding-right','20',0,'5639'),(386249,122430,'116874','deals','link','contact_information',0,''),(386250,122430,'116874','deals','margin-top','-31',0,''),(386251,122430,'116874','deals','float','right',0,''),(386252,122433,'116877','deals','link','payment_method',0,''),(386253,122433,'116877','deals','float','right',0,''),(386254,122433,'116877','deals','margin-top','-31',0,''),(386255,122434,'116878','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(386256,122434,'116878','deals','padding-top','20',0,''),(386257,122435,'116879','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(386258,122435,'116879','deals','clear','none',0,''),(386259,122436,'116880','deals','block_type','1',0,''),(386260,122436,'116880','deals','padding-left','30',0,''),(386261,122436,'116880','deals','border-left-width','20',0,''),(386262,122436,'116880','deals','border-left-color','$content-border-1',0,''),(386263,122436,'116880','deals','margin-left','-10',0,''),(386264,122436,'116880','deals','padding-right','30',0,''),(386265,122436,'116880','deals','padding-top','20',0,''),(386266,122436,'116880','deals','padding-bottom','20',0,''),(386267,122436,'116880','deals','border-left-width','0',0,'5639'),(386268,122437,'116881','deals','margin-bottom','20',0,''),(386269,122438,'116882','deals','link','billing_address',0,''),(386270,122438,'116882','deals','float','right',0,''),(386271,122438,'116882','deals','margin-top','-31',0,''),(386272,122439,'116883','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(386273,122439,'116883','deals','clear','none',0,''),(386274,122440,'116884','deals','block_type','1',0,''),(386275,122440,'116884','deals','padding-right','30',0,''),(386276,122440,'116884','deals','background-color','$content-bg-1',0,''),(386277,122440,'116884','deals','padding-top','20',0,''),(386278,122440,'116884','deals','padding-left','30',0,''),(386279,122440,'116884','deals','padding-bottom','20',0,''),(386280,122440,'116884','deals','padding-left','20',0,'5639'),(386281,122440,'116884','deals','padding-right','20',0,'5639'),(386282,122441,'116885','deals','link','products',0,''),(386283,122441,'116885','deals','float','right',0,''),(386284,122441,'116885','deals','margin-top','-37',0,''),(386285,122442,'116886','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(386286,122443,'116887','deals','margin-bottom','20',0,''),(386287,122444,'116888','deals','block_type','1',0,''),(386288,122444,'116888','deals','padding-top','20',0,''),(386289,122444,'116888','deals','padding-left','20',0,''),(386290,122444,'116888','deals','padding-right','20',0,''),(386291,122444,'116888','deals','padding-bottom','20',0,''),(386292,122444,'116888','deals','background-color','$content-bg-1',0,''),(386293,122444,'116888','deals','style_class','order-summary',0,''),(386294,122445,'116889','deals','margin-bottom','20',0,''),(386295,122445,'116889','deals','text-align','right',0,''),(386296,122447,'116891','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(386297,122448,'116892','deals','block_type','1',0,''),(386298,122448,'116892','deals','background-color','$content-bg-2',0,''),(386299,122448,'116892','deals','padding-bottom','30',0,''),(386300,122449,'116893','deals','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(386301,122450,'116894','deals','block_type','4',0,''),(386302,122450,'116894','deals','schema','4-2',0,'5639'),(386303,122451,'116895','deals','block_type','1',0,''),(386304,122451,'116895','deals','padding-right','40',0,''),(386305,122451,'116895','deals','padding-right','0',0,'5639'),(386306,122452,'116896','deals','block_type','1',0,''),(386307,122452,'116896','deals','padding-right','30',0,''),(386308,122452,'116896','deals','background-color','$content-bg-1',0,''),(386309,122452,'116896','deals','padding-top','20',0,''),(386310,122452,'116896','deals','padding-left','30',0,''),(386311,122452,'116896','deals','padding-bottom','20',0,''),(386312,122452,'116896','deals','padding-left','20',0,'5639'),(386313,122452,'116896','deals','padding-right','20',0,'5639'),(386314,122454,'116898','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(386315,122455,'116899','deals','link','products',0,''),(386316,122455,'116899','deals','float','right',0,''),(386317,122455,'116899','deals','margin-top','-37',0,''),(386318,122456,'116900','deals','block_type','2',0,''),(386319,122456,'116900','deals','margin-bottom','20',0,''),(386320,122456,'116900','deals','schema','2-2',0,'5630'),(386321,122456,'116900','deals','background-color','$content-bg-1',0,''),(386322,122457,'116901','deals','block_type','1',0,''),(386323,122457,'116901','deals','border-right-width','20',0,''),(386324,122457,'116901','deals','border-right-color','$content-border-1',0,''),(386325,122457,'116901','deals','margin-right','-10',0,''),(386326,122457,'116901','deals','padding-right','30',0,''),(386327,122457,'116901','deals','padding-top','20',0,''),(386328,122457,'116901','deals','padding-left','30',0,''),(386329,122457,'116901','deals','padding-bottom','20',0,''),(386330,122457,'116901','deals','border-right-width','0',0,'5639'),(386331,122457,'116901','deals','margin-right','0',0,'5639'),(386332,122457,'116901','deals','margin-bottom','20',0,'5639'),(386333,122457,'116901','deals','padding-left','20',0,'5639'),(386334,122457,'116901','deals','padding-right','20',0,'5639'),(386335,122458,'116902','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(386336,122459,'116903','deals','link','contact_information',0,''),(386337,122459,'116903','deals','margin-top','-31',0,''),(386338,122459,'116903','deals','float','right',0,''),(386339,122460,'116904','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(386340,122460,'116904','deals','clear','none',0,''),(386341,122462,'116906','deals','margin-bottom','20',0,''),(386342,122464,'116908','deals','link','shipping_address',0,''),(386343,122464,'116908','deals','float','right',0,''),(386344,122464,'116908','deals','margin-top','-31',0,''),(386345,122466,'116910','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(386346,122466,'116910','deals','padding-top','20',0,''),(386347,122467,'116911','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(386348,122467,'116911','deals','clear','none',0,''),(386349,122468,'116912','deals','link','shipping_method',0,''),(386350,122468,'116912','deals','float','right',0,''),(386351,122468,'116912','deals','margin-top','-31',0,''),(386352,122469,'116913','deals','block_type','1',0,''),(386353,122469,'116913','deals','padding-left','30',0,''),(386354,122469,'116913','deals','border-left-width','20',0,''),(386355,122469,'116913','deals','border-left-color','$content-border-1',0,''),(386356,122469,'116913','deals','margin-left','-10',0,''),(386357,122469,'116913','deals','padding-right','30',0,''),(386358,122469,'116913','deals','padding-top','20',0,''),(386359,122469,'116913','deals','padding-bottom','20',0,''),(386360,122469,'116913','deals','border-left-width','0',0,'5639'),(386361,122470,'116914','deals','link','billing_address',0,''),(386362,122470,'116914','deals','float','right',0,''),(386363,122470,'116914','deals','margin-top','-31',0,''),(386364,122471,'116915','deals','margin-bottom','20',0,''),(386365,122473,'116917','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(386366,122474,'116918','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(386367,122474,'116918','deals','clear','none',0,''),(386368,122475,'116919','deals','link','payment_method',0,''),(386369,122475,'116919','deals','float','right',0,''),(386370,122475,'116919','deals','margin-top','-31',0,''),(386371,122476,'116920','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(386372,122476,'116920','deals','clear','none',0,''),(386373,122477,'116921','deals','block_type','1',0,''),(386374,122477,'116921','deals','background-color','$content-bg-1',0,''),(386375,122477,'116921','deals','padding-top','20',0,''),(386376,122477,'116921','deals','padding-bottom','20',0,''),(386377,122477,'116921','deals','padding-left','30',0,''),(386378,122477,'116921','deals','padding-right','30',0,''),(386379,122477,'116921','deals','margin-bottom','20',0,''),(386380,122478,'116922','deals','hide_parents','2',0,''),(386381,122479,'116923','deals','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(386382,122480,'116924','deals','float','right',0,''),(386383,122480,'116924','deals','margin-top','-37',0,''),(386384,122480,'116924','deals','link','comments',0,''),(386385,122481,'116925','deals','block_type','1',0,''),(386386,122481,'116925','deals','padding-top','20',0,''),(386387,122481,'116925','deals','padding-left','20',0,''),(386388,122481,'116925','deals','padding-right','20',0,''),(386389,122481,'116925','deals','padding-bottom','20',0,''),(386390,122481,'116925','deals','background-color','$content-bg-1',0,''),(386391,122481,'116925','deals','style_class','order-summary',0,''),(386392,122482,'116926','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(386393,122484,'116928','deals','margin-bottom','20',0,''),(386394,122484,'116928','deals','text-align','right',0,''),(386395,122485,'116929','deals','block_type','1',0,''),(386396,122485,'116929','deals','background-color','$content-bg-2',0,''),(386397,122485,'116929','deals','padding-bottom','30',0,''),(386398,122486,'116930','deals','block_type','4',0,''),(386399,122486,'116930','deals','schema','4-2',0,'5639'),(386400,122487,'116931','deals','block_type','1',0,''),(386401,122487,'116931','deals','padding-right','40',0,''),(386402,122487,'116931','deals','padding-right','0',0,'5639'),(386403,122488,'116932','deals','block_type','2',0,''),(386404,122488,'116932','deals','margin-bottom','20',0,''),(386405,122488,'116932','deals','schema','2-2',0,'5630'),(386406,122488,'116932','deals','background-color','$content-bg-1',0,''),(386407,122489,'116933','deals','block_type','1',0,''),(386408,122489,'116933','deals','border-right-width','20',0,''),(386409,122489,'116933','deals','border-right-color','$content-border-1',0,''),(386410,122489,'116933','deals','margin-right','-10',0,''),(386411,122489,'116933','deals','padding-right','30',0,''),(386412,122489,'116933','deals','padding-top','20',0,''),(386413,122489,'116933','deals','padding-left','30',0,''),(386414,122489,'116933','deals','padding-bottom','20',0,''),(386415,122489,'116933','deals','border-right-width','0',0,'5639'),(386416,122489,'116933','deals','margin-right','0',0,'5639'),(386417,122489,'116933','deals','margin-bottom','20',0,'5639'),(386418,122489,'116933','deals','padding-left','20',0,'5639'),(386419,122489,'116933','deals','padding-right','20',0,'5639'),(386420,122490,'116934','deals','margin-bottom','20',0,''),(386421,122491,'116935','deals','link','shipping_address',0,''),(386422,122491,'116935','deals','float','right',0,''),(386423,122491,'116935','deals','margin-top','-31',0,''),(386424,122492,'116936','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(386425,122492,'116936','deals','clear','none',0,''),(386426,122495,'116939','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(386427,122496,'116940','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(386428,122496,'116940','deals','clear','none',0,''),(386429,122497,'116941','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(386430,122497,'116941','deals','padding-top','20',0,''),(386431,122499,'116943','deals','link','shipping_method',0,''),(386432,122499,'116943','deals','float','right',0,''),(386433,122499,'116943','deals','margin-top','-31',0,''),(386434,122500,'116944','deals','link','contact_information',0,''),(386435,122500,'116944','deals','margin-top','-31',0,''),(386436,122500,'116944','deals','float','right',0,''),(386437,122501,'116945','deals','block_type','1',0,''),(386438,122501,'116945','deals','padding-left','30',0,''),(386439,122501,'116945','deals','border-left-width','20',0,''),(386440,122501,'116945','deals','border-left-color','$content-border-1',0,''),(386441,122501,'116945','deals','margin-left','-10',0,''),(386442,122501,'116945','deals','padding-right','30',0,''),(386443,122501,'116945','deals','padding-top','20',0,''),(386444,122501,'116945','deals','padding-bottom','20',0,''),(386445,122501,'116945','deals','border-left-width','0',0,'5639'),(386446,122502,'116946','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(386447,122502,'116946','deals','clear','none',0,''),(386448,122503,'116947','deals','margin-bottom','20',0,''),(386449,122504,'116948','deals','link','billing_address',0,''),(386450,122504,'116948','deals','float','right',0,''),(386451,122504,'116948','deals','margin-top','-31',0,''),(386452,122506,'116950','deals','link','payment_method',0,''),(386453,122506,'116950','deals','float','right',0,''),(386454,122506,'116950','deals','margin-top','-31',0,''),(386455,122507,'116951','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(386456,122508,'116952','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(386457,122508,'116952','deals','clear','none',0,''),(386458,122509,'116953','deals','block_type','1',0,''),(386459,122509,'116953','deals','padding-right','30',0,''),(386460,122509,'116953','deals','background-color','$content-bg-1',0,''),(386461,122509,'116953','deals','padding-top','20',0,''),(386462,122509,'116953','deals','padding-left','30',0,''),(386463,122509,'116953','deals','padding-bottom','20',0,''),(386464,122509,'116953','deals','padding-left','20',0,'5639'),(386465,122509,'116953','deals','padding-right','20',0,'5639'),(386466,122510,'116954','deals','link','products',0,''),(386467,122510,'116954','deals','float','right',0,''),(386468,122510,'116954','deals','margin-top','-37',0,''),(386469,122511,'116955','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(386470,122513,'116957','deals','block_type','1',0,''),(386471,122513,'116957','deals','background-color','$content-bg-1',0,''),(386472,122513,'116957','deals','padding-top','20',0,''),(386473,122513,'116957','deals','padding-bottom','20',0,''),(386474,122513,'116957','deals','padding-left','30',0,''),(386475,122513,'116957','deals','padding-right','30',0,''),(386476,122513,'116957','deals','margin-bottom','20',0,''),(386477,122514,'116958','deals','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(386478,122515,'116959','deals','float','right',0,''),(386479,122515,'116959','deals','margin-top','-37',0,''),(386480,122515,'116959','deals','link','comments',0,''),(386481,122516,'116960','deals','hide_parents','2',0,''),(386482,122517,'116961','deals','block_type','1',0,''),(386483,122517,'116961','deals','padding-top','20',0,''),(386484,122517,'116961','deals','padding-left','20',0,''),(386485,122517,'116961','deals','padding-right','20',0,''),(386486,122517,'116961','deals','padding-bottom','20',0,''),(386487,122517,'116961','deals','background-color','$content-bg-1',0,''),(386488,122517,'116961','deals','style_class','order-summary',0,''),(386489,122519,'116963','deals','margin-bottom','20',0,''),(386490,122519,'116963','deals','text-align','right',0,''),(386491,122520,'116964','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(386492,122521,'116965','deals','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(386493,122522,'116966','deals','block_type','1',0,''),(386494,122524,'116968','deals','block_type','2',0,''),(386495,122524,'116968','deals','font-weight','400',0,''),(386496,122524,'116968','deals','padding-bottom','20',0,''),(386497,122524,'116968','deals','schema','2-2',0,'5639'),(386498,122525,'116969','deals','show_captcha','on',0,''),(386499,122526,'116970','deals','font-weight','400',0,''),(386500,122526,'116970','deals','padding-left','40',0,''),(386501,122526,'116970','deals','time_format','24',0,''),(386502,122526,'116970','deals','show_icons','on',0,''),(386503,122526,'116970','deals','padding-left','0',0,'5639'),(386504,122527,'116971','deals','block_type','1',0,''),(386505,122528,'116972','deals','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(386506,122529,'116973','deals','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(386507,122529,'116973','deals','margin-bottom','40',0,''),(386508,122530,'116102.000001','deals','block_type','1',0,''),(386509,122531,'116103.000001','deals','block_type','6',0,''),(386510,122531,'116103.000001','deals','schema','6-3',0,'5639'),(386511,122532,'116104.000001','deals','aria_name','account-menu',0,''),(386575,122552,'116109.000001','deals','text','<h1>##CREDIT_AMOUNT_HISTORY##</h1>',0,''),(386576,122553,'1638895944','deals','margin-bottom','20',0,''),(386577,122554,'116974','deals','width','680',0,''),(386578,122554,'116974','deals','font-weight','normal',0,''),(386579,122554,'116974','deals','font-size','12',0,''),(386580,122554,'116974','deals','padding-top','20',0,''),(386581,122554,'116974','deals','padding-bottom','20',0,''),(386582,122554,'116974','deals','color','$content-color-1',0,''),(386583,122555,'116975','deals','block_type','3',0,''),(386584,122555,'116975','deals','font-weight','normal',0,''),(386585,122555,'116975','deals','padding-top','20',0,''),(386586,122556,'116976','deals','font-size','12',0,''),(386587,122557,'116977','deals','text','<p>If undelivered please return to:</p>',1,''),(386588,122557,'116977','deals','font-size','12',0,''),(386589,122557,'116977','deals','font-weight','bold',0,''),(386590,122557,'116977','deals','text','<p>If undelivered please return to:</p>',2,''),(386591,122557,'116977','deals','text','<p>If undelivered please return to:</p>',3,''),(386592,122557,'116977','deals','text','<p>If undelivered please return to:</p>',4,''),(386593,122558,'116978','deals','text','<p>Thank you for your order</p>',1,''),(386594,122558,'116978','deals','color','$hileght-color-1',0,''),(386595,122558,'116978','deals','font-size','13',0,''),(386596,122558,'116978','deals','font-weight','bold',0,''),(386597,122558,'116978','deals','padding-top','5',0,''),(386598,122558,'116978','deals','text-align','center',0,''),(386599,122558,'116978','deals','text','<p>Thank you for your order</p>',2,''),(386600,122558,'116978','deals','text','<p>Thank you for your order</p>',3,''),(386601,122558,'116978','deals','text','<p>Thank you for your order</p>',4,''),(386602,122559,'116979','deals','font-weight','400',0,''),(386603,122559,'116979','deals','text-align','center',0,''),(386604,122559,'116979','deals','padding-top','0',0,''),(386606,122559,'116979','deals','padding-left','20',0,''),(386607,122559,'116979','deals','padding-right','20',0,''),(386611,122560,'116980','deals','text','<p>If something has gone wrong please contact us at:</p>',1,''),(386612,122560,'116980','deals','font-size','12',0,''),(386613,122560,'116980','deals','font-weight','bold',0,''),(386614,122560,'116980','deals','text-align','right',0,''),(386615,122560,'116980','deals','text','<p>If something has gone wrong please contact us at:</p>',2,''),(386616,122560,'116980','deals','text','<p>If something has gone wrong please contact us at:</p>',3,''),(386617,122560,'116980','deals','text','<p>If something has gone wrong please contact us at:</p>',4,''),(386618,122561,'116981','deals','block_type','6',0,''),(386619,122561,'116981','deals','font-weight','normal',0,''),(386620,122561,'116981','deals','font-size','16',0,''),(386621,122562,'116982','deals','text','<p>Email:</p>',1,''),(386622,122562,'116982','deals','font-weight','normal',0,''),(386623,122562,'116982','deals','text-align','right',0,''),(386624,122562,'116982','deals','font-size','12',0,''),(386625,122562,'116982','deals','text','<p>Email:</p>',2,''),(386626,122562,'116982','deals','text','<p>Email:</p>',3,''),(386627,122562,'116982','deals','text','<p>Email:</p>',4,''),(386628,122563,'116983','deals','font-weight','normal',0,''),(386629,122563,'116983','deals','text-align','right',0,''),(386630,122563,'116983','deals','font-size','12',0,''),(386631,122564,'116984','deals','block_type','6',0,''),(386632,122564,'116984','deals','font-weight','normal',0,''),(386633,122564,'116984','deals','font-size','16',0,''),(386634,122565,'116985','deals','text','<p>Phone:</p>',1,''),(386635,122565,'116985','deals','font-weight','normal',0,''),(386636,122565,'116985','deals','text-align','right',0,''),(386637,122565,'116985','deals','font-size','12',0,''),(386638,122565,'116985','deals','text','<p>Phone:</p>',2,''),(386639,122565,'116985','deals','text','<p>Phone:</p>',3,''),(386640,122565,'116985','deals','text','<p>Phone:</p>',4,''),(386641,122566,'116986','deals','font-weight','normal',0,''),(386642,122566,'116986','deals','text-align','right',0,''),(386643,122566,'116986','deals','font-size','12',0,''),(386644,122567,'116987','deals','font-weight','400',0,''),(386645,122567,'116987','deals','padding-top','20',0,''),(386646,122567,'116987','deals','padding-bottom','0',0,''),(386647,122567,'116987','deals','font-size','12',0,''),(386648,122568,'116988','deals','block_type','2',0,''),(386649,122568,'116988','deals','font-weight','normal',0,''),(386650,122568,'116988','deals','padding-bottom','20',0,''),(386651,122569,'116989','deals','font-weight','400',0,''),(386652,122569,'116989','deals','padding-top','20',0,''),(386657,122570,'116990','deals','block_type','11',0,''),(386658,122570,'116990','deals','font-weight','normal',0,''),(386659,122571,'116991','deals','text','<p>Web:</p>',1,''),(386660,122571,'116991','deals','font-weight','normal',0,''),(386661,122571,'116991','deals','text-align','right',0,''),(386662,122571,'116991','deals','text','<p>Web:</p>',2,''),(386663,122571,'116991','deals','text','<p>Web:</p>',3,''),(386664,122571,'116991','deals','text','<p>Web:</p>',4,''),(386665,122572,'116992','deals','font-weight','normal',0,''),(386666,122572,'116992','deals','text-align','right',0,''),(386667,122573,'116993','deals','block_type','11',0,''),(386668,122573,'116993','deals','font-weight','normal',0,''),(386669,122574,'116994','deals','text','<p>Phone:</p>',1,''),(386670,122574,'116994','deals','font-weight','normal',0,''),(386671,122574,'116994','deals','text-align','right',0,''),(386672,122574,'116994','deals','text','<p>Phone:</p>',2,''),(386673,122574,'116994','deals','text','<p>Phone:</p>',3,''),(386674,122574,'116994','deals','text','<p>Phone:</p>',4,''),(386675,122575,'116995','deals','font-weight','normal',0,''),(386676,122575,'116995','deals','text-align','right',0,''),(386677,122576,'116996','deals','block_type','11',0,''),(386678,122576,'116996','deals','font-weight','normal',0,''),(386679,122577,'116997','deals','text','<p>Email:</p>',1,''),(386680,122577,'116997','deals','font-weight','normal',0,''),(386681,122577,'116997','deals','text-align','right',0,''),(386682,122577,'116997','deals','text','<p>Email:</p>',2,''),(386683,122577,'116997','deals','text','<p>Email:</p>',3,''),(386684,122577,'116997','deals','text','<p>Email:</p>',4,''),(386685,122578,'116998','deals','font-weight','normal',0,''),(386686,122578,'116998','deals','text-align','right',0,''),(386687,122579,'116999','deals','block_type','1',0,''),(386688,122580,'117000','deals','font-weight','normal',0,''),(386689,122580,'117000','deals','text-align','right',0,''),(386690,122580,'117000','deals','padding-bottom','10',0,''),(386691,122580,'117000','deals','address_spacer',',',0,''),(386692,122580,'117000','deals','font-size','12',0,''),(386693,122581,'117001','deals','block_type','5',0,''),(386694,122581,'117001','deals','font-weight','normal',0,''),(386695,122581,'117001','deals','border-bottom-width','1',0,''),(386696,122581,'117001','deals','border-bottom-color','$content-border-1',0,''),(386697,122581,'117001','deals','border-top-width','1',0,''),(386698,122581,'117001','deals','border-top-color','$content-border-1',0,''),(386699,122581,'117001','deals','border-left-color','$content-border-1',0,''),(386700,122581,'117001','deals','border-left-width','1',0,''),(386701,122582,'117002','deals','block_type','1',0,''),(386702,122582,'117002','deals','font-weight','normal',0,''),(386703,122582,'117002','deals','padding-top','10',0,''),(386704,122582,'117002','deals','padding-left','10',0,''),(386705,122582,'117002','deals','padding-right','10',0,''),(386706,122583,'117003','deals','font-weight','400',0,''),(386707,122583,'117003','deals','line-height','120',0,''),(386708,122583,'117003','deals','line_height_measure','%',0,''),(386709,122583,'117003','deals','font-size','12',0,''),(386710,122584,'117004','deals','text','<p>SHIPPING ADDRESS:</p>',1,''),(386711,122584,'117004','deals','font-size','14',0,''),(386712,122584,'117004','deals','font-weight','bold',0,''),(386713,122584,'117004','deals','padding-bottom','10',0,''),(386714,122584,'117004','deals','text','<p>SHIPPING ADDRESS:</p>',2,''),(386715,122584,'117004','deals','text','<p>SHIPPING ADDRESS:</p>',3,''),(386716,122584,'117004','deals','text','<p>SHIPPING ADDRESS:</p>',4,''),(386717,122585,'117005','deals','block_type','1',0,''),(386718,122585,'117005','deals','background-color','$content-bg-2',0,''),(386719,122585,'117005','deals','padding-top','20',0,''),(386720,122585,'117005','deals','padding-left','10',0,''),(386721,122585,'117005','deals','padding-right','10',0,''),(386722,122585,'117005','deals','padding-bottom','20',0,''),(386723,122585,'117005','deals','font-size','14',0,''),(386724,122586,'117006','deals','block_type','4',0,''),(386725,122586,'117006','deals','font-weight','normal',0,''),(386726,122586,'117006','deals','border-top-width','1',0,''),(386727,122586,'117006','deals','border-top-color','$content-border-1',0,''),(386728,122586,'117006','deals','border-left-width','1',0,''),(386729,122586,'117006','deals','border-left-color','$content-border-1',0,''),(386730,122586,'117006','deals','border-right-width','1',0,''),(386731,122586,'117006','deals','border-right-color','$content-border-1',0,''),(386732,122586,'117006','deals','border-bottom-width','1',0,''),(386733,122586,'117006','deals','border-bottom-color','$content-border-1',0,''),(386734,122587,'117007','deals','block_type','2',0,''),(386735,122587,'117007','deals','font-weight','normal',0,''),(386736,122587,'117007','deals','border-right-width','1',0,''),(386737,122587,'117007','deals','border-right-color','$content-border-1',0,''),(386738,122588,'117008','deals','block_type','1',0,''),(386739,122588,'117008','deals','font-weight','400',0,''),(386740,122588,'117008','deals','background-color','$content-bg-2',0,''),(386741,122588,'117008','deals','padding-top','10',0,''),(386742,122588,'117008','deals','padding-left','10',0,''),(386743,122588,'117008','deals','padding-right','10',0,''),(386744,122588,'117008','deals','padding-bottom','30',0,''),(386745,122589,'117009','deals','text','<p>INVOICE ADDRESS:</p>',1,''),(386746,122589,'117009','deals','font-size','14',0,''),(386747,122589,'117009','deals','font-weight','bold',0,''),(386748,122589,'117009','deals','text','<p>INVOICE ADDRESS:</p>',2,''),(386749,122589,'117009','deals','text','<p>INVOICE ADDRESS:</p>',3,''),(386750,122589,'117009','deals','text','<p>INVOICE ADDRESS:</p>',4,''),(386751,122590,'117010','deals','font-size','12',0,''),(386752,122591,'117011','deals','block_type','1',0,''),(386753,122591,'117011','deals','font-weight','normal',0,''),(386754,122591,'117011','deals','padding-top','10',0,''),(386755,122591,'117011','deals','padding-left','10',0,''),(386756,122591,'117011','deals','padding-right','10',0,''),(386757,122591,'117011','deals','padding-bottom','10',0,''),(386758,122592,'117012','deals','font-weight','normal',0,''),(386759,122593,'117013','deals','text','<p>CUSTOMER:</p>',1,''),(386760,122593,'117013','deals','font-size','13',0,''),(386761,122593,'117013','deals','font-weight','bold',0,''),(386762,122593,'117013','deals','text','<p>CUSTOMER:</p>',2,''),(386763,122593,'117013','deals','text','<p>CUSTOMER:</p>',3,''),(386764,122593,'117013','deals','text','<p>CUSTOMER:</p>',4,''),(386765,122594,'117014','deals','text','<p>PHONE NUMBER:</p>',1,''),(386766,122594,'117014','deals','font-size','14',0,''),(386767,122594,'117014','deals','font-weight','bold',0,''),(386768,122594,'117014','deals','padding-top','10',0,''),(386769,122594,'117014','deals','text','<p>PHONE NUMBER:</p>',2,''),(386770,122594,'117014','deals','text','<p>PHONE NUMBER:</p>',3,''),(386771,122594,'117014','deals','text','<p>PHONE NUMBER:</p>',4,''),(386772,122595,'117015','deals','font-weight','normal',0,''),(386773,122597,'117017','deals','text','<p>E-MAIL ADDRESS:</p>',1,''),(386774,122597,'117017','deals','font-weight','bold',0,''),(386775,122597,'117017','deals','font-size','14',0,''),(386776,122597,'117017','deals','padding-top','10',0,''),(386777,122597,'117017','deals','text','<p>E-MAIL ADDRESS:</p>',2,''),(386778,122597,'117017','deals','text','<p>E-MAIL ADDRESS:</p>',3,''),(386779,122597,'117017','deals','text','<p>E-MAIL ADDRESS:</p>',4,''),(386780,122598,'117018','deals','block_type','2',0,''),(386781,122598,'117018','deals','font-weight','normal',0,''),(386782,122598,'117018','deals','border-top-width','1',0,''),(386783,122598,'117018','deals','border-top-color','$content-border-1',0,''),(386784,122598,'117018','deals','border-right-width','1',0,''),(386785,122598,'117018','deals','border-right-color','$content-border-1',0,''),(386786,122599,'117019','deals','block_type','1',0,''),(386787,122599,'117019','deals','font-weight','normal',0,''),(386788,122599,'117019','deals','padding-top','10',0,''),(386789,122599,'117019','deals','padding-left','10',0,''),(386790,122599,'117019','deals','padding-right','10',0,''),(386791,122599,'117019','deals','padding-bottom','10',0,''),(386792,122599,'117019','deals','border-right-width','1',0,''),(386793,122599,'117019','deals','border-right-color','$content-border-1',0,''),(386794,122601,'117021','deals','text','<p>Shipping via</p>',1,''),(386795,122601,'117021','deals','font-weight','bold',0,''),(386796,122601,'117021','deals','font-size','14',0,''),(386797,122601,'117021','deals','text','<p>Shipping via</p>',2,''),(386798,122601,'117021','deals','text','<p>Shipping via</p>',3,''),(386799,122601,'117021','deals','text','<p>Shipping via</p>',4,''),(386800,122602,'117022','deals','block_type','1',0,''),(386801,122602,'117022','deals','font-weight','normal',0,''),(386802,122602,'117022','deals','padding-top','10',0,''),(386803,122602,'117022','deals','padding-left','10',0,''),(386804,122602,'117022','deals','padding-right','10',0,''),(386805,122602,'117022','deals','padding-bottom','10',0,''),(386806,122603,'117023','deals','text','<p>Shipping service</p>',1,''),(386807,122603,'117023','deals','font-weight','bold',0,''),(386808,122603,'117023','deals','font-size','14',0,''),(386809,122603,'117023','deals','text','<p>Shipping service</p>',2,''),(386810,122603,'117023','deals','text','<p>Shipping service</p>',3,''),(386811,122603,'117023','deals','text','<p>Shipping service</p>',4,''),(386812,122605,'117025','deals','font-size','14',0,''),(386813,122605,'117025','deals','font-weight','bold',0,''),(386814,122605,'117025','deals','text-align','center',0,''),(386815,122605,'117025','deals','padding-bottom','10',0,''),(386816,122605,'117025','deals','padding-top','10',0,''),(386817,122606,'117026','deals','text','<p>Payment date:</p>',1,''),(386818,122606,'117026','deals','font-weight','bold',0,''),(386819,122606,'117026','deals','text-align','center',0,''),(386820,122606,'117026','deals','font-size','12',0,''),(386821,122606,'117026','deals','text','<p>Payment date:</p>',2,''),(386822,122606,'117026','deals','text','<p>Payment date:</p>',3,''),(386823,122606,'117026','deals','text','<p>Payment date:</p>',4,''),(386824,122607,'117027','deals','font-weight','normal',0,''),(386825,122607,'117027','deals','text-align','center',0,''),(386826,122607,'117027','deals','padding-bottom','10',0,''),(386827,122608,'117034','deals','text-align','center',0,''),(386828,122608,'117034','deals','padding-top','10',0,''),(386829,122609,'1639155816','deals','block_type','1',0,''),(386830,122610,'117028','deals','padding-top','30',0,''),(386831,122610,'117028','deals','padding-bottom','30',0,''),(386832,122614,'117032','deals','col_in_row','4',0,''),(386833,122614,'117032','deals','listing_type','productListing',0,''),(386834,122614,'117032','deals','view_as','carousel',0,''),(386835,122614,'117032','deals','col_in_row','3',0,'5639'),(386836,122614,'117032','deals','col_in_row','2',0,'5630'),(386837,122614,'117032','deals','col_in_row','1',0,'5660'),(386838,122616,'1639485067','deals','padding-top','30',0,''),(386839,122616,'1639485067','deals','padding-bottom','30',0,''),(386840,122618,'1639154415','deals','block_type','1',0,''),(386841,122620,'117036','deals','heading_type','h1',0,''),(386842,122621,'1639419797','deals','page_id','4',0,''),(386843,122621,'1639419797','deals','padding-top','30',0,''),(386844,122621,'1639419797','deals','padding-bottom','30',0,''),(386845,122624,'117039','deals','text-align','center',0,''),(386846,122624,'117039','deals','padding-top','10',0,''),(386847,122629,'117044','deals','block_type','1',0,''),(386848,122630,'117045','deals','block_type','1',0,''),(386849,122630,'117045','deals','max-width','800',0,''),(386850,122630,'117045','deals','margin','0 auto',0,''),(386851,122630,'117045','deals','background-color','$content-bg-1',0,''),(386852,122631,'117046','deals','color','$content-color-1',0,''),(386853,122631,'117046','deals','font-size','12',0,''),(386854,122631,'117046','deals','padding-top','20',0,''),(386855,122631,'117046','deals','padding-bottom','20',0,''),(386856,122631,'117046','deals','border-top-width','1',0,''),(386857,122631,'117046','deals','border-top-color','$content-border-1',0,''),(386858,122632,'117047','deals','font-weight','normal',0,''),(386859,122632,'117047','deals','padding-top','20',0,''),(386860,122632,'117047','deals','padding-left','10',0,''),(386861,122632,'117047','deals','padding-right','10',0,''),(386862,122632,'117047','deals','padding-bottom','20',0,''),(386863,122632,'117047','deals','color','$content-color-1',0,''),(386864,122632,'117047','deals','font-size','14',0,''),(386865,122633,'117048','deals','block_type','7',0,''),(386866,122633,'117048','deals','font-weight','normal',0,''),(386867,122633,'117048','deals','background-color','$highlight-box-bg-2',0,''),(386868,122633,'117048','deals','padding-top','5',0,''),(386869,122633,'117048','deals','padding-left','10',0,''),(386870,122633,'117048','deals','padding-right','10',0,''),(386871,122633,'117048','deals','padding-bottom','5',0,''),(386872,122634,'117049','deals','color','$highlight-box-color-2',0,''),(386873,122634,'117049','deals','font-size','14',0,''),(386874,122634,'117049','deals','font-weight','normal',0,''),(386875,122635,'117050','deals','font-weight','normal',0,''),(386876,122635,'117050','deals','text-align','right',0,''),(386877,122635,'117050','deals','color','$highlight-box-color-2',0,''),(386878,122635,'117050','deals','font-size','12',0,''),(386879,122636,'117051','deals','font-weight','normal',0,''),(386880,122636,'117051','deals','padding-bottom','10',0,''),(386881,122636,'117051','deals','padding-top','10',0,''),(386882,122636,'117051','deals','logo_from','theme',0,''),(386883,122636,'117051','deals','padding-left','20',0,''),(386884,122637,'117052','deals','block_type','1',0,''),(386885,122638,'117053','deals','block_type','1',0,''),(386886,122638,'117053','deals','max-width','800',0,''),(386887,122638,'117053','deals','margin','0 auto',0,''),(386888,122638,'117053','deals','background-color','$content-bg-1',0,''),(386889,122639,'117054','deals','color','$content-color-1',0,''),(386890,122639,'117054','deals','font-size','12',0,''),(386891,122639,'117054','deals','padding-top','20',0,''),(386892,122639,'117054','deals','padding-bottom','20',0,''),(386893,122639,'117054','deals','border-top-width','1',0,''),(386894,122639,'117054','deals','border-top-color','$content-border-1',0,''),(386895,122640,'117055','deals','font-weight','normal',0,''),(386896,122640,'117055','deals','padding-bottom','10',0,''),(386897,122640,'117055','deals','logo','themes/deals/img/logo-2.png',1,''),(386898,122640,'117055','deals','padding-left','20',0,''),(386899,122640,'117055','deals','padding-top','10',0,''),(386900,122640,'117055','deals','logo','themes/deals/img/logo-2.png',2,''),(386901,122640,'117055','deals','logo','themes/deals/img/logo-2.png',3,''),(386902,122640,'117055','deals','logo','themes/deals/img/logo-2.png',4,''),(386903,122641,'117056','deals','font-weight','normal',0,''),(386904,122641,'117056','deals','padding-top','20',0,''),(386905,122641,'117056','deals','padding-left','10',0,''),(386906,122641,'117056','deals','padding-right','10',0,''),(386907,122641,'117056','deals','padding-bottom','20',0,''),(386908,122641,'117056','deals','color','$content-color-1',0,''),(386909,122641,'117056','deals','font-size','14',0,''),(386910,122642,'117057','deals','block_type','7',0,''),(386911,122642,'117057','deals','font-weight','normal',0,''),(386912,122642,'117057','deals','background-color','$highlight-box-bg-1',0,''),(386913,122642,'117057','deals','padding-top','5',0,''),(386914,122642,'117057','deals','padding-left','10',0,''),(386915,122642,'117057','deals','padding-right','10',0,''),(386916,122642,'117057','deals','padding-bottom','5',0,''),(386917,122643,'117058','deals','color','$highlight-box-color-1',0,''),(386918,122643,'117058','deals','font-size','15',0,''),(386919,122643,'117058','deals','font-weight','700',0,''),(386920,122644,'117059','deals','font-weight','normal',0,''),(386921,122644,'117059','deals','text-align','right',0,''),(386922,122644,'117059','deals','color','$highlight-box-color-1',0,''),(386923,122644,'117059','deals','font-size','12',0,''),(386924,122645,'117060','deals','block_type','1',0,''),(386925,122645,'117060','deals','background-color','$content-bg-2',0,''),(386926,122646,'117061','deals','block_type','1',0,''),(386927,122646,'117061','deals','max-width','800',0,''),(386928,122646,'117061','deals','margin','0 auto',0,''),(386929,122647,'117062','deals','block_type','1',0,''),(386930,122647,'117062','deals','background-color','$content-bg-1',0,''),(386931,122647,'117062','deals','padding-top','20',0,''),(386932,122647,'117062','deals','padding-left','20',0,''),(386933,122647,'117062','deals','padding-right','20',0,''),(386934,122647,'117062','deals','padding-bottom','20',0,''),(386935,122648,'117063','deals','font-weight','normal',0,''),(386936,122648,'117063','deals','padding-top','20',0,''),(386937,122648,'117063','deals','padding-bottom','20',0,''),(386938,122648,'117063','deals','color','$content-color-1',0,''),(386939,122648,'117063','deals','font-size','14',0,''),(386940,122649,'117064','deals','block_type','7',0,''),(386941,122649,'117064','deals','font-weight','normal',0,''),(386942,122649,'117064','deals','padding-left','10',0,''),(386943,122649,'117064','deals','padding-right','10',0,''),(386944,122649,'117064','deals','padding-bottom','15',0,''),(386945,122649,'117064','deals','border-bottom-width','1',0,''),(386946,122649,'117064','deals','border-bottom-color','$content-border-1',0,''),(386947,122650,'117065','deals','color','$content-color-1',0,''),(386948,122650,'117065','deals','font-size','14',0,''),(386949,122650,'117065','deals','font-weight','700',0,''),(386950,122651,'117066','deals','font-weight','normal',0,''),(386951,122651,'117066','deals','text-align','right',0,''),(386952,122651,'117066','deals','color','$fade-color-1',0,''),(386953,122651,'117066','deals','font-size','11',0,''),(386954,122651,'117066','deals','text-transform','uppercase',0,''),(386955,122652,'117067','deals','color','$fade-color-1',0,''),(386956,122652,'117067','deals','font-size','12',0,''),(386957,122652,'117067','deals','padding-top','20',0,''),(386958,122652,'117067','deals','padding-bottom','20',0,''),(386959,122652,'117067','deals','text-align','center',0,''),(386960,122653,'117068','deals','font-weight','normal',0,''),(386961,122653,'117068','deals','padding-bottom','10',0,''),(386962,122653,'117068','deals','padding-top','10',0,''),(386963,122653,'117068','deals','text-align','center',0,''),(386964,122653,'117068','deals','logo_from','theme',0,''),(386965,122654,'117069','deals','block_type','1',0,''),(386966,122654,'117069','deals','background-color','$content-bg-2',0,''),(386967,122654,'117069','deals','padding-top','20',0,''),(386968,122654,'117069','deals','padding-bottom','20',0,''),(386969,122655,'117070','deals','block_type','1',0,''),(386970,122655,'117070','deals','max-width','800',0,''),(386971,122655,'117070','deals','margin','0 auto',0,''),(386972,122656,'117071','deals','color','$fade-color-1',0,''),(386973,122656,'117071','deals','font-size','12',0,''),(386974,122656,'117071','deals','padding-top','20',0,''),(386975,122656,'117071','deals','padding-bottom','20',0,''),(386976,122656,'117071','deals','text-align','left',0,''),(386977,122657,'117072','deals','block_type','1',0,''),(386978,122657,'117072','deals','background-color','$content-bg-1',0,''),(386979,122657,'117072','deals','padding-top','20',0,''),(386980,122657,'117072','deals','padding-left','20',0,''),(386981,122657,'117072','deals','padding-right','20',0,''),(386982,122657,'117072','deals','padding-bottom','20',0,''),(386983,122657,'117072','deals','border-top-width','1',0,''),(386984,122657,'117072','deals','border-left-width','1',0,''),(386985,122657,'117072','deals','border-right-width','1',0,''),(386986,122657,'117072','deals','border-bottom-width','1',0,''),(386987,122657,'117072','deals','border-top-color','$content-border-1',0,''),(386988,122657,'117072','deals','border-left-color','$content-border-1',0,''),(386989,122657,'117072','deals','border-bottom-color','$content-border-1',0,''),(386990,122657,'117072','deals','border-right-color','$content-border-1',0,''),(386991,122658,'117073','deals','block_type','2',0,''),(386992,122659,'117074','deals','font-weight','normal',0,''),(386993,122659,'117074','deals','padding-bottom','10',0,''),(386994,122659,'117074','deals','padding-top','10',0,''),(386995,122659,'117074','deals','logo_from','theme',0,''),(386996,122660,'117075','deals','font-weight','normal',0,''),(386997,122660,'117075','deals','text-align','right',0,''),(386998,122660,'117075','deals','color','$fade-color-1',0,''),(386999,122660,'117075','deals','font-size','11',0,''),(387000,122660,'117075','deals','text-transform','uppercase',0,''),(387001,122661,'117076','deals','color','$content-color-1',0,''),(387002,122661,'117076','deals','font-size','14',0,''),(387003,122661,'117076','deals','font-weight','700',0,''),(387004,122661,'117076','deals','text-align','right',0,''),(387005,122662,'117077','deals','font-weight','normal',0,''),(387006,122662,'117077','deals','padding-top','20',0,''),(387007,122662,'117077','deals','padding-bottom','20',0,''),(387008,122662,'117077','deals','color','$content-color-1',0,''),(387009,122662,'117077','deals','font-size','14',0,''),(387010,122663,'121029','deals','block_type','1',0,''),(387011,122666,'121032','deals','margin-bottom','30',0,''),(387012,122667,'121025','deals','block_type','1',0,''),(387013,122668,'121026','deals','text','<h1>CATALOGUE</h1>',0,''),(387014,122670,'117078','deals','block_type','1',0,''),(387015,122670,'117078','deals','font-weight','normal',0,''),(387016,122670,'117078','deals','padding-top','20',0,''),(387017,122670,'117078','deals','style_class','preFooter',0,''),(387018,122670,'117078','deals','padding-bottom','25',0,''),(387019,122670,'117078','deals','background-color','$footer-bg-1',0,''),(387020,122670,'117078','deals','color','$footer-color-1',0,''),(387021,122671,'120872','deals','banners_group','payment',0,''),(387022,122671,'120872','deals','float','none',0,''),(387023,122671,'120872','deals','padding-top','15',0,''),(387024,122671,'120872','deals','clear','none',0,''),(387025,122671,'120872','deals','margin-bottom','20',0,''),(387026,122671,'120872','deals','text-align','center',0,''),(387027,122672,'117094','deals','color','$footer-color-3',0,''),(387028,122672,'117094','deals','text-align','center',0,''),(387029,122672,'117094','deals','font-size','14',0,''),(387030,122673,'1641484988','deals','block_type','2',0,''),(387031,122673,'1641484988','deals','schema','2-2',0,'5639'),(387032,122674,'117085','deals','class','menu-style-2',0,''),(387033,122674,'117085','deals','type','builder',0,''),(387034,122674,'117085','deals','style','3',0,''),(387035,122674,'117085','deals','lev2_vis','click',0,'5630'),(387036,122674,'117085','deals','style_class','footer-menu',0,''),(387037,122675,'117091','deals','view_item','data_format',0,''),(387038,122675,'117091','deals','address_spacer',',<span> </span>',0,''),(387039,122675,'117091','deals','color','$footer-color-2',0,''),(387040,122675,'117091','deals','add_link_on_phone','1',0,''),(387041,122675,'117091','deals','data_format_content','<div>Registered address</div>\n##COMPANY##\n##STREET_ADDRESS##\n##CITY##\n##STATE##\n\n',0,''),(387042,122675,'117091','deals','margin-top','20',0,'5630'),(387043,122675,'117091','deals','float','right',0,''),(387044,122675,'117091','deals','max-width','170',0,''),(387045,122675,'117091','deals','margin-bottom','20',0,''),(387046,122675,'117091','deals','float','none',0,'5639'),(387047,122675,'117091','deals','padding-top','20',0,'5639'),(387048,122676,'120868','deals','logo_from','theme',0,''),(387049,122676,'120868','deals','margin-bottom','25',0,''),(387050,122676,'120868','deals','padding-right','20',0,''),(387051,122676,'120868','deals','display_none','1',0,'5630'),(387052,122676,'120868','deals','text-align','right',0,''),(387053,122676,'120868','deals','clear','both',0,''),(387054,122676,'120868','deals','text-align','left',0,'5639'),(387055,122677,'117096','deals','block_type','5',0,''),(387056,122678,'117097','deals','text','##TEXT_LANGUAGE##',0,''),(387057,122680,'117099','deals','block_type','5',0,''),(387058,122681,'117100','deals','text','##TEXT_CURRENCY##',0,''),(387059,122683,'117102','deals','block_type','1',0,''),(387060,122683,'117102','deals','font-weight','normal',0,''),(387061,122684,'117103','deals','block_type','2',0,''),(387062,122684,'117103','deals','font-weight','normal',0,''),(387063,122684,'117103','deals','padding-bottom','20',0,''),(387064,122685,'117104','deals','block_type','1',0,''),(387065,122685,'117104','deals','margin-right','20',0,''),(387066,122688,'117107','deals','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(387067,122688,'117107','deals','font-weight','normal',0,''),(387068,122688,'117107','deals','padding-bottom','20',0,''),(387069,122688,'117107','deals','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',2,''),(387070,122688,'117107','deals','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',3,''),(387071,122688,'117107','deals','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',4,''),(387072,122690,'117109','deals','block_type','1',0,''),(387073,122690,'117109','deals','font-weight','normal',0,''),(387074,122690,'117109','deals','style_class','gift-card-view',0,''),(387075,122690,'117109','deals','text-align','center',0,''),(387076,122690,'117109','deals','padding-bottom','20',0,''),(387077,122690,'117109','deals','padding-left','20',0,''),(387078,122690,'117109','deals','padding-right','20',0,''),(387079,122691,'117110','deals','block_type','1',0,''),(387080,122691,'117110','deals','font-weight','normal',0,''),(387081,122691,'117110','deals','padding-top','10',0,''),(387082,122692,'117111','deals','font-size','12',0,''),(387083,122692,'117111','deals','font-weight','bold',0,''),(387084,122692,'117111','deals','text-align','center',0,''),(387085,122692,'117111','deals','style_class','email',0,''),(387086,122693,'117112','deals','text','<p>If you require further assistance please contact us</p>',1,''),(387087,122693,'117112','deals','font-weight','normal',0,''),(387088,122693,'117112','deals','text-align','center',0,''),(387089,122693,'117112','deals','font-size','12',0,''),(387090,122693,'117112','deals','padding-top','10',0,''),(387091,122693,'117112','deals','padding-bottom','5',0,''),(387092,122693,'117112','deals','border-top-width','1',0,''),(387093,122693,'117112','deals','border-top-color','$content-border-1',0,''),(387094,122693,'117112','deals','text','<p>If you require further assistance please contact us</p>',2,''),(387095,122693,'117112','deals','text','<p>If you require further assistance please contact us</p>',3,''),(387096,122693,'117112','deals','text','<p>If you require further assistance please contact us</p>',4,''),(387097,122694,'117113','deals','font-size','12',0,''),(387098,122694,'117113','deals','font-weight','bold',0,''),(387099,122694,'117113','deals','text-align','center',0,''),(387100,122694,'117113','deals','style_class','phone',0,''),(387101,122694,'117113','deals','padding-bottom','5',0,''),(387102,122695,'117114','deals','text','<p>WHAT TO DO NEXT:</p>',1,''),(387103,122695,'117114','deals','font-weight','normal',0,''),(387104,122695,'117114','deals','text-align','center',0,''),(387105,122695,'117114','deals','padding-top','20',0,''),(387106,122695,'117114','deals','padding-bottom','10',0,''),(387107,122695,'117114','deals','style_class','question-ico',0,''),(387108,122695,'117114','deals','border-top-width','1',0,''),(387109,122695,'117114','deals','border-top-color','$content-border-1',0,''),(387110,122695,'117114','deals','font-size','18',0,''),(387111,122695,'117114','deals','text','<p>WHAT TO DO NEXT:</p>',2,''),(387112,122695,'117114','deals','text','<p>WHAT TO DO NEXT:</p>',3,''),(387113,122695,'117114','deals','text','<p>WHAT TO DO NEXT:</p>',4,''),(387114,122696,'117115','deals','text','<p>osCommerce</p>\n',1,''),(387115,122696,'117115','deals','font-family','$font-2',0,''),(387116,122696,'117115','deals','font-size','24',0,''),(387117,122696,'117115','deals','font-weight','normal',0,''),(387118,122696,'117115','deals','text-align','center',0,''),(387119,122696,'117115','deals','padding-top','10',0,''),(387120,122696,'117115','deals','padding-bottom','20',0,''),(387121,122696,'117115','deals','text','<p>osCommerce</p>\n',2,''),(387122,122696,'117115','deals','text','<p>osCommerce</p>\n',3,''),(387123,122696,'117115','deals','text','<p>osCommerce</p>\n',4,''),(387124,122697,'117116','deals','block_type','4',0,''),(387125,122697,'117116','deals','font-size','30',0,''),(387126,122697,'117116','deals','font-weight','normal',0,''),(387127,122697,'117116','deals','padding-top','5',0,''),(387128,122697,'117116','deals','padding-left','10',0,''),(387129,122697,'117116','deals','padding-right','10',0,''),(387130,122697,'117116','deals','padding-bottom','5',0,''),(387131,122697,'117116','deals','border-top-width','2',0,''),(387132,122697,'117116','deals','border-left-width','2',0,''),(387133,122697,'117116','deals','border-right-width','2',0,''),(387134,122697,'117116','deals','border-bottom-width','2',0,''),(387135,122697,'117116','deals','border-top-color','$highlight-box-border-2',0,''),(387136,122697,'117116','deals','border-left-color','$highlight-box-border-2',0,''),(387137,122697,'117116','deals','border-right-color','$highlight-box-border-2',0,''),(387138,122697,'117116','deals','border-bottom-color','$highlight-box-border-2',0,''),(387139,122698,'117117','deals','text','<p>Your code is:</p>',1,''),(387140,122698,'117117','deals','font-weight','normal',0,''),(387141,122698,'117117','deals','text','<p>Your code is:</p>',2,''),(387142,122698,'117117','deals','text','<p>Your code is:</p>',3,''),(387143,122698,'117117','deals','text','<p>Your code is:</p>',4,''),(387144,122700,'117119','deals','font-weight','normal',0,''),(387145,122700,'117119','deals','text-align','center',0,''),(387146,122700,'117119','deals','padding-bottom','20',0,''),(387147,122701,'117120','deals','font-size','60',0,''),(387148,122701,'117120','deals','font-weight','bold',0,''),(387149,122701,'117120','deals','text-align','center',0,''),(387150,122701,'117120','deals','line-height','100',0,''),(387151,122701,'117120','deals','padding-bottom','20',0,''),(387152,122701,'117120','deals','line_height_measure','px',0,''),(387153,122702,'117121','deals','text','<p>PERSONAL MESSAGE</p>',1,''),(387154,122702,'117121','deals','font-size','18',0,''),(387155,122702,'117121','deals','font-weight','normal',0,''),(387156,122702,'117121','deals','text-align','center',0,''),(387157,122702,'117121','deals','padding-top','20',0,''),(387158,122702,'117121','deals','padding-bottom','10',0,''),(387159,122702,'117121','deals','border-top-width','1',0,''),(387160,122702,'117121','deals','border-top-color','$content-border-1',0,''),(387161,122702,'117121','deals','text','<p>PERSONAL MESSAGE</p>',2,''),(387162,122702,'117121','deals','text','<p>PERSONAL MESSAGE</p>',3,''),(387163,122702,'117121','deals','text','<p>PERSONAL MESSAGE</p>',4,''),(387164,122703,'117123','deals','logo','themes/deals/img/Logo.jpg',1,''),(387165,122703,'117123','deals','logo_from','theme',0,''),(387166,122703,'117123','deals','padding-top','20',0,''),(387167,122703,'117123','deals','text-align','center',0,''),(387168,122703,'117123','deals','logo','themes/deals/img/Logo.jpg',2,''),(387169,122703,'117123','deals','logo','themes/deals/img/Logo.jpg',3,''),(387170,122703,'117123','deals','logo','themes/deals/img/Logo.jpg',4,''),(387171,122704,'117124','deals','text','<p>GIFT CARD</p>',1,''),(387172,122704,'117124','deals','font-size','30',0,''),(387173,122704,'117124','deals','font-weight','normal',0,''),(387174,122704,'117124','deals','border-top-width','1',0,''),(387175,122704,'117124','deals','border-top-color','$content-border-1',0,''),(387176,122704,'117124','deals','style_class','gift-ico',0,''),(387177,122704,'117124','deals','text-align','center',0,''),(387178,122704,'117124','deals','padding-top','15',0,''),(387179,122704,'117124','deals','text','<p>GIFT CARD</p>',2,''),(387180,122704,'117124','deals','text','<p>GIFT CARD</p>',3,''),(387181,122704,'117124','deals','text','<p>GIFT CARD</p>',4,''),(387182,122705,'117125','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(387183,122705,'117125','deals','font-weight','normal',0,''),(387184,122705,'117125','deals','text-align','center',0,''),(387185,122705,'117125','deals','padding-bottom','10',0,''),(387186,122705,'117125','deals','font-size','14',0,''),(387187,122705,'117125','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(387188,122705,'117125','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(387189,122705,'117125','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(387190,122706,'117126','deals','block_type','1',0,''),(387191,122706,'117126','deals','font-weight','normal',0,''),(387192,122706,'117126','deals','style_class','gift-card-view',0,''),(387193,122706,'117126','deals','text-align','center',0,''),(387194,122706,'117126','deals','padding-bottom','20',0,''),(387195,122706,'117126','deals','background-color','$highlight-box-bg-1',0,''),(387196,122706,'117126','deals','padding-left','20',0,''),(387197,122706,'117126','deals','padding-right','20',0,''),(387198,122706,'117126','deals','color','$highlight-box-color-1',0,''),(387199,122707,'117127','deals','font-size','60',0,''),(387200,122707,'117127','deals','font-weight','bold',0,''),(387201,122707,'117127','deals','text-align','center',0,''),(387202,122707,'117127','deals','line-height','100',0,''),(387203,122707,'117127','deals','padding-bottom','20',0,''),(387204,122707,'117127','deals','line_height_measure','px',0,''),(387205,122708,'117128','deals','block_type','4',0,''),(387206,122708,'117128','deals','color','$highlight-box-color-2',0,''),(387207,122708,'117128','deals','font-size','30',0,''),(387208,122708,'117128','deals','font-weight','normal',0,''),(387209,122708,'117128','deals','background-color','$highlight-box-bg-2',0,''),(387210,122708,'117128','deals','padding-top','5',0,''),(387211,122708,'117128','deals','padding-left','10',0,''),(387212,122708,'117128','deals','padding-right','10',0,''),(387213,122708,'117128','deals','padding-bottom','5',0,''),(387214,122709,'117129','deals','text','<p>Your code is:</p>',1,''),(387215,122709,'117129','deals','font-weight','normal',0,''),(387216,122709,'117129','deals','text','<p>Your code is:</p>',2,''),(387217,122709,'117129','deals','text','<p>Your code is:</p>',3,''),(387218,122709,'117129','deals','text','<p>Your code is:</p>',4,''),(387219,122711,'117131','deals','block_type','1',0,''),(387220,122711,'117131','deals','font-weight','normal',0,''),(387221,122711,'117131','deals','padding-top','10',0,''),(387222,122712,'117132','deals','font-size','12',0,''),(387223,122712,'117132','deals','font-weight','bold',0,''),(387224,122712,'117132','deals','text-align','center',0,''),(387225,122712,'117132','deals','style_class','email',0,''),(387226,122713,'117133','deals','text','<p>If you require further assistance please contact us</p>',1,''),(387227,122713,'117133','deals','font-weight','normal',0,''),(387228,122713,'117133','deals','text-align','center',0,''),(387229,122713,'117133','deals','font-size','12',0,''),(387230,122713,'117133','deals','padding-top','10',0,''),(387231,122713,'117133','deals','padding-bottom','5',0,''),(387232,122713,'117133','deals','border-top-width','1',0,''),(387233,122713,'117133','deals','border-top-color','$warning-border',0,''),(387234,122713,'117133','deals','text','<p>If you require further assistance please contact us</p>',2,''),(387235,122713,'117133','deals','text','<p>If you require further assistance please contact us</p>',3,''),(387236,122713,'117133','deals','text','<p>If you require further assistance please contact us</p>',4,''),(387237,122714,'117134','deals','font-size','12',0,''),(387238,122714,'117134','deals','font-weight','bold',0,''),(387239,122714,'117134','deals','text-align','center',0,''),(387240,122714,'117134','deals','style_class','phone',0,''),(387241,122714,'117134','deals','padding-bottom','5',0,''),(387242,122715,'117135','deals','font-weight','normal',0,''),(387243,122715,'117135','deals','text-align','center',0,''),(387244,122715,'117135','deals','padding-bottom','20',0,''),(387245,122716,'117136','deals','text','<p>PERSONAL MESSAGE</p>',1,''),(387246,122716,'117136','deals','font-size','18',0,''),(387247,122716,'117136','deals','font-weight','normal',0,''),(387248,122716,'117136','deals','text-align','center',0,''),(387249,122716,'117136','deals','padding-top','20',0,''),(387250,122716,'117136','deals','padding-bottom','10',0,''),(387251,122716,'117136','deals','border-top-width','1',0,''),(387252,122716,'117136','deals','border-top-color','$warning-border',0,''),(387253,122716,'117136','deals','text','<p>PERSONAL MESSAGE</p>',2,''),(387254,122716,'117136','deals','text','<p>PERSONAL MESSAGE</p>',3,''),(387255,122716,'117136','deals','text','<p>PERSONAL MESSAGE</p>',4,''),(387256,122717,'117137','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(387257,122717,'117137','deals','font-weight','normal',0,''),(387258,122717,'117137','deals','text-align','center',0,''),(387259,122717,'117137','deals','padding-bottom','10',0,''),(387260,122717,'117137','deals','font-size','14',0,''),(387261,122717,'117137','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(387262,122717,'117137','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(387263,122717,'117137','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(387264,122718,'117138','deals','text','<p>GIFT CARD</p>',1,''),(387265,122718,'117138','deals','font-size','30',0,''),(387266,122718,'117138','deals','font-weight','normal',0,''),(387267,122718,'117138','deals','border-top-width','1',0,''),(387268,122718,'117138','deals','border-top-color','$warning-border',0,''),(387269,122718,'117138','deals','style_class','gift-ico',0,''),(387270,122718,'117138','deals','text-align','center',0,''),(387271,122718,'117138','deals','padding-top','15',0,''),(387272,122718,'117138','deals','text','<p>GIFT CARD</p>',2,''),(387273,122718,'117138','deals','text','<p>GIFT CARD</p>',3,''),(387274,122718,'117138','deals','text','<p>GIFT CARD</p>',4,''),(387275,122719,'117139','deals','text','<p>WHAT TO DO NEXT:</p>',1,''),(387276,122719,'117139','deals','font-weight','normal',0,''),(387277,122719,'117139','deals','text-align','center',0,''),(387278,122719,'117139','deals','padding-top','20',0,''),(387279,122719,'117139','deals','padding-bottom','10',0,''),(387280,122719,'117139','deals','style_class','question-ico',0,''),(387281,122719,'117139','deals','border-top-width','1',0,''),(387282,122719,'117139','deals','border-top-color','$warning-border',0,''),(387283,122719,'117139','deals','font-size','18',0,''),(387284,122719,'117139','deals','text','<p>WHAT TO DO NEXT:</p>',2,''),(387285,122719,'117139','deals','text','<p>WHAT TO DO NEXT:</p>',3,''),(387286,122719,'117139','deals','text','<p>WHAT TO DO NEXT:</p>',4,''),(387287,122720,'1638804282','deals','logo_from','theme',0,''),(387288,122720,'1638804282','deals','padding-top','20',0,''),(387289,122720,'1638804282','deals','text-align','center',0,''),(387290,122720,'1638804282','deals','padding-bottom','20',0,''),(387291,122721,'117141','deals','block_type','1',0,''),(387292,122721,'117141','deals','font-weight','normal',0,''),(387293,122721,'117141','deals','style_class','gift-card-view',0,''),(387294,122721,'117141','deals','text-align','center',0,''),(387295,122721,'117141','deals','padding-bottom','20',0,''),(387296,122721,'117141','deals','background-color','$highlight-box-bg-1',0,''),(387297,122721,'117141','deals','padding-left','20',0,''),(387298,122721,'117141','deals','padding-right','20',0,''),(387299,122721,'117141','deals','color','$highlight-box-color-1',0,''),(387300,122722,'117142','deals','block_type','1',0,''),(387301,122722,'117142','deals','font-weight','normal',0,''),(387302,122722,'117142','deals','padding-top','10',0,''),(387303,122723,'117143','deals','font-size','12',0,''),(387304,122723,'117143','deals','font-weight','bold',0,''),(387305,122723,'117143','deals','text-align','center',0,''),(387306,122723,'117143','deals','style_class','email',0,''),(387307,122723,'117143','deals','color','$highlight-box-color-1',0,''),(387308,122724,'117144','deals','font-size','12',0,''),(387309,122724,'117144','deals','font-weight','bold',0,''),(387310,122724,'117144','deals','text-align','center',0,''),(387311,122724,'117144','deals','style_class','phone',0,''),(387312,122724,'117144','deals','padding-bottom','5',0,''),(387313,122724,'117144','deals','color','$highlight-box-color-1',0,''),(387314,122725,'117145','deals','text','If you require further assistance please contact us',0,''),(387315,122725,'117145','deals','font-size','12',0,''),(387316,122725,'117145','deals','color','$highlight-box-color-1',0,''),(387317,122725,'117145','deals','text-align','center',0,''),(387318,122725,'117145','deals','padding-top','10',0,''),(387319,122726,'117146','deals','block_type','4',0,''),(387320,122726,'117146','deals','color','$highlight-box-color-2',0,''),(387321,122726,'117146','deals','font-size','30',0,''),(387322,122726,'117146','deals','font-weight','normal',0,''),(387323,122726,'117146','deals','background-color','$highlight-box-bg-2',0,''),(387324,122726,'117146','deals','padding-top','5',0,''),(387325,122726,'117146','deals','padding-left','10',0,''),(387326,122726,'117146','deals','padding-right','10',0,''),(387327,122726,'117146','deals','padding-bottom','5',0,''),(387328,122727,'117147','deals','text','Your code is:',0,''),(387329,122727,'117147','deals','font-size','30',0,''),(387330,122727,'117147','deals','color','$highlight-box-color-2',0,''),(387331,122728,'117148','deals','color','$highlight-box-color-2',0,''),(387332,122728,'117148','deals','font-size','30',0,''),(387333,122729,'117149','deals','block_type','1',0,''),(387334,122730,'117150','deals','text','<p>PERSONAL MESSAGE</p>',1,''),(387335,122730,'117150','deals','font-size','18',0,''),(387336,122730,'117150','deals','font-weight','normal',0,''),(387337,122730,'117150','deals','text-align','center',0,''),(387338,122730,'117150','deals','padding-top','20',0,''),(387339,122730,'117150','deals','padding-bottom','10',0,''),(387340,122730,'117150','deals','border-top-width','1',0,''),(387341,122730,'117150','deals','border-top-color','$warning-border',0,''),(387342,122730,'117150','deals','text','<p>PERSONAL MESSAGE</p>',2,''),(387343,122730,'117150','deals','text','<p>PERSONAL MESSAGE</p>',3,''),(387344,122730,'117150','deals','text','<p>PERSONAL MESSAGE</p>',4,''),(387345,122730,'117150','deals','color','$highlight-box-color-1',0,''),(387346,122731,'117151','deals','text','HOLBI',0,''),(387347,122731,'117151','deals','color','$highlight-box-color-1',0,''),(387348,122731,'117151','deals','font-size','24',0,''),(387349,122731,'117151','deals','padding-top','20',0,''),(387350,122731,'117151','deals','text-align','center',0,''),(387351,122731,'117151','deals','padding-bottom','20',0,''),(387352,122732,'117152','deals','border-top-color','$warning-border',0,''),(387353,122732,'117152','deals','border-top-width','1',0,''),(387354,122732,'117152','deals','padding-top','20',0,''),(387355,122732,'117152','deals','font-size','30',0,''),(387356,122732,'117152','deals','text-align','center',0,''),(387357,122732,'117152','deals','color','$highlight-box-color-1',0,''),(387358,122732,'117152','deals','text','GIFT CARD',0,''),(387359,122733,'117153','deals','text-align','center',0,''),(387360,122733,'117153','deals','font-weight','bold',0,''),(387361,122733,'117153','deals','font-size','60',0,''),(387362,122733,'117153','deals','color','$highlight-box-color-1',0,''),(387363,122734,'117154','deals','font-size','20',0,''),(387364,122734,'117154','deals','text-align','center',0,''),(387365,122734,'117154','deals','color','$highlight-box-color-1',0,''),(387366,122734,'117154','deals','padding-top','20',0,''),(387367,122734,'117154','deals','padding-bottom','20',0,''),(387368,122735,'117155','deals','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(387369,122735,'117155','deals','text-align','center',0,''),(387370,122735,'117155','deals','color','$highlight-box-color-1',0,''),(387371,122735,'117155','deals','font-size','14',0,''),(387372,122735,'117155','deals','padding-bottom','20',0,''),(387373,122736,'117156','deals','text','WHAT TO DO NEXT:',0,''),(387374,122736,'117156','deals','font-size','18',0,''),(387375,122736,'117156','deals','text-align','center',0,''),(387376,122736,'117156','deals','color','$highlight-box-color-1',0,''),(387377,122736,'117156','deals','padding-top','20',0,''),(387378,122736,'117156','deals','padding-bottom','10',0,''),(387379,122736,'117156','deals','border-top-width','1',0,''),(387380,122736,'117156','deals','border-top-color','$warning-border',0,''),(387381,122737,'117158','deals','block_type','1',0,''),(387382,122737,'117158','deals','font-weight','normal',0,''),(387383,122737,'117158','deals','style_class','gift-card-view',0,''),(387384,122737,'117158','deals','text-align','center',0,''),(387385,122737,'117158','deals','padding-bottom','20',0,''),(387386,122737,'117158','deals','padding-left','20',0,''),(387387,122737,'117158','deals','padding-right','20',0,''),(387388,122737,'117158','deals','color','$fade-color-2',0,''),(387389,122738,'117159','deals','block_type','1',0,''),(387390,122738,'117159','deals','font-weight','normal',0,''),(387391,122738,'117159','deals','padding-top','10',0,''),(387392,122739,'117160','deals','font-size','12',0,''),(387393,122739,'117160','deals','font-weight','bold',0,''),(387394,122739,'117160','deals','text-align','center',0,''),(387395,122739,'117160','deals','style_class','email',0,''),(387396,122739,'117160','deals','color','$content-color-1',0,''),(387397,122740,'117161','deals','font-size','12',0,''),(387398,122740,'117161','deals','font-weight','bold',0,''),(387399,122740,'117161','deals','text-align','center',0,''),(387400,122740,'117161','deals','style_class','phone',0,''),(387401,122740,'117161','deals','padding-bottom','5',0,''),(387402,122740,'117161','deals','color','$content-color-1',0,''),(387403,122741,'117162','deals','text','If you require further assistance please contact us',0,''),(387404,122741,'117162','deals','font-size','12',0,''),(387405,122741,'117162','deals','color','$content-color-1',0,''),(387406,122741,'117162','deals','text-align','center',0,''),(387407,122741,'117162','deals','padding-top','10',0,''),(387408,122742,'117163','deals','block_type','2',0,''),(387409,122742,'117163','deals','color','$highlight-box-color-2',0,''),(387410,122742,'117163','deals','font-size','30',0,''),(387411,122742,'117163','deals','font-weight','normal',0,''),(387412,122742,'117163','deals','background-color','$highlight-box-bg-2',0,''),(387413,122742,'117163','deals','padding-top','5',0,''),(387414,122742,'117163','deals','padding-left','10',0,''),(387415,122742,'117163','deals','padding-right','10',0,''),(387416,122742,'117163','deals','padding-bottom','5',0,''),(387417,122743,'117164','deals','text','Your code is:',0,''),(387418,122743,'117164','deals','font-size','30',0,''),(387419,122743,'117164','deals','color','$highlight-box-color-2',0,''),(387420,122744,'117165','deals','color','$highlight-box-color-2',0,''),(387421,122744,'117165','deals','font-size','30',0,''),(387422,122745,'117166','deals','block_type','1',0,''),(387423,122746,'117167','deals','text','<p>PERSONAL MESSAGE</p>',1,''),(387424,122746,'117167','deals','font-size','18',0,''),(387425,122746,'117167','deals','font-weight','normal',0,''),(387426,122746,'117167','deals','text-align','center',0,''),(387427,122746,'117167','deals','padding-top','20',0,''),(387428,122746,'117167','deals','padding-bottom','10',0,''),(387429,122746,'117167','deals','border-top-width','1',0,''),(387430,122746,'117167','deals','border-top-color','$content-border-1',0,''),(387431,122746,'117167','deals','color','$content-color-1',0,''),(387432,122746,'117167','deals','text','<p>PERSONAL MESSAGE</p>',2,''),(387433,122746,'117167','deals','text','<p>PERSONAL MESSAGE</p>',3,''),(387434,122746,'117167','deals','text','<p>PERSONAL MESSAGE</p>',4,''),(387435,122747,'117169','deals','border-top-color','$content-border-1',0,''),(387436,122747,'117169','deals','border-top-width','1',0,''),(387437,122747,'117169','deals','padding-top','20',0,''),(387438,122747,'117169','deals','font-size','30',0,''),(387439,122747,'117169','deals','text-align','center',0,''),(387440,122747,'117169','deals','color','$content-color-1',0,''),(387441,122747,'117169','deals','text','GIFT CARD',0,''),(387442,122748,'117170','deals','text-align','center',0,''),(387443,122748,'117170','deals','font-weight','bold',0,''),(387444,122748,'117170','deals','font-size','60',0,''),(387445,122748,'117170','deals','color','$content-color-1',0,''),(387446,122749,'117171','deals','font-size','20',0,''),(387447,122749,'117171','deals','text-align','center',0,''),(387448,122749,'117171','deals','color','$content-color-1',0,''),(387449,122749,'117171','deals','padding-top','20',0,''),(387450,122749,'117171','deals','padding-bottom','20',0,''),(387451,122750,'117172','deals','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(387452,122750,'117172','deals','text-align','center',0,''),(387453,122750,'117172','deals','color','$content-color-1',0,''),(387454,122750,'117172','deals','font-size','14',0,''),(387455,122750,'117172','deals','padding-bottom','20',0,''),(387456,122751,'117173','deals','text','WHAT TO DO NEXT:',0,''),(387457,122751,'117173','deals','font-size','18',0,''),(387458,122751,'117173','deals','text-align','center',0,''),(387459,122751,'117173','deals','color','$content-color-1',0,''),(387460,122751,'117173','deals','padding-top','20',0,''),(387461,122751,'117173','deals','padding-bottom','10',0,''),(387462,122751,'117173','deals','border-top-width','1',0,''),(387463,122751,'117173','deals','border-top-color','$content-border-1',0,''),(387464,122752,'1638978695','deals','logo_from','theme',0,''),(387465,122752,'1638978695','deals','text-align','center',0,''),(387466,122752,'1638978695','deals','padding-top','20',0,''),(387467,122752,'1638978695','deals','padding-bottom','20',0,''),(387468,122753,'117175','deals','block_type','1',0,''),(387469,122753,'117175','deals','padding-left','20',0,''),(387470,122753,'117175','deals','padding-right','20',0,''),(387471,122753,'117175','deals','padding-bottom','20',0,''),(387472,122755,'117177','deals','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(387473,122755,'117177','deals','text-align','center',0,''),(387474,122756,'117178','deals','block_type','1',0,''),(387475,122756,'117178','deals','font-weight','normal',0,''),(387476,122756,'117178','deals','style_class','gift-card-view',0,''),(387477,122756,'117178','deals','text-align','center',0,''),(387478,122756,'117178','deals','padding-bottom','20',0,''),(387479,122756,'117178','deals','background-color','$highlight-box-bg-4',0,''),(387480,122756,'117178','deals','padding-left','20',0,''),(387481,122756,'117178','deals','padding-right','20',0,''),(387482,122756,'117178','deals','color','$highlight-box-color-4',0,''),(387483,122757,'117179','deals','block_type','4',0,''),(387484,122757,'117179','deals','color','$highlight-box-color-2',0,''),(387485,122757,'117179','deals','font-size','30',0,''),(387486,122757,'117179','deals','font-weight','normal',0,''),(387487,122757,'117179','deals','background-color','$highlight-box-bg-2',0,''),(387488,122757,'117179','deals','padding-top','5',0,''),(387489,122757,'117179','deals','padding-left','10',0,''),(387490,122757,'117179','deals','padding-right','10',0,''),(387491,122757,'117179','deals','padding-bottom','5',0,''),(387492,122758,'117180','deals','text','<p>Your code is:</p>',1,''),(387493,122758,'117180','deals','font-weight','normal',0,''),(387494,122758,'117180','deals','text','<p>Your code is:</p>',2,''),(387495,122758,'117180','deals','text','<p>Your code is:</p>',3,''),(387496,122758,'117180','deals','text','<p>Your code is:</p>',4,''),(387497,122760,'117182','deals','text','<p>WHAT TO DO NEXT:</p>',1,''),(387498,122760,'117182','deals','font-weight','normal',0,''),(387499,122760,'117182','deals','text-align','center',0,''),(387500,122760,'117182','deals','padding-top','20',0,''),(387501,122760,'117182','deals','padding-bottom','10',0,''),(387502,122760,'117182','deals','style_class','question-ico',0,''),(387503,122760,'117182','deals','border-top-width','1',0,''),(387504,122760,'117182','deals','border-top-color','$warning-border',0,''),(387505,122760,'117182','deals','font-size','18',0,''),(387506,122760,'117182','deals','text','<p>WHAT TO DO NEXT:</p>',2,''),(387507,122760,'117182','deals','text','<p>WHAT TO DO NEXT:</p>',3,''),(387508,122760,'117182','deals','text','<p>WHAT TO DO NEXT:</p>',4,''),(387509,122761,'117184','deals','block_type','1',0,''),(387510,122761,'117184','deals','font-weight','normal',0,''),(387511,122761,'117184','deals','padding-top','10',0,''),(387512,122762,'117185','deals','text','<p>If you require further assistance please contact us</p>',1,''),(387513,122762,'117185','deals','font-weight','normal',0,''),(387514,122762,'117185','deals','text-align','center',0,''),(387515,122762,'117185','deals','font-size','12',0,''),(387516,122762,'117185','deals','padding-top','10',0,''),(387517,122762,'117185','deals','padding-bottom','5',0,''),(387518,122762,'117185','deals','border-top-width','1',0,''),(387519,122762,'117185','deals','border-top-color','$warning-border',0,''),(387520,122762,'117185','deals','text','<p>If you require further assistance please contact us</p>',2,''),(387521,122762,'117185','deals','text','<p>If you require further assistance please contact us</p>',3,''),(387522,122762,'117185','deals','text','<p>If you require further assistance please contact us</p>',4,''),(387523,122763,'117186','deals','font-size','12',0,''),(387524,122763,'117186','deals','font-weight','bold',0,''),(387525,122763,'117186','deals','text-align','center',0,''),(387526,122763,'117186','deals','style_class','email',0,''),(387527,122764,'117187','deals','font-size','12',0,''),(387528,122764,'117187','deals','font-weight','bold',0,''),(387529,122764,'117187','deals','text-align','center',0,''),(387530,122764,'117187','deals','style_class','phone',0,''),(387531,122764,'117187','deals','padding-bottom','5',0,''),(387532,122765,'117188','deals','font-weight','normal',0,''),(387533,122765,'117188','deals','text-align','center',0,''),(387534,122765,'117188','deals','padding-bottom','20',0,''),(387535,122766,'117189','deals','text','<p>GIFT CARD</p>',1,''),(387536,122766,'117189','deals','font-size','30',0,''),(387537,122766,'117189','deals','font-weight','normal',0,''),(387538,122766,'117189','deals','border-top-width','1',0,''),(387539,122766,'117189','deals','border-top-color','$warning-border',0,''),(387540,122766,'117189','deals','style_class','gift-ico',0,''),(387541,122766,'117189','deals','text-align','center',0,''),(387542,122766,'117189','deals','padding-top','15',0,''),(387543,122766,'117189','deals','text','<p>GIFT CARD</p>',2,''),(387544,122766,'117189','deals','text','<p>GIFT CARD</p>',3,''),(387545,122766,'117189','deals','text','<p>GIFT CARD</p>',4,''),(387546,122767,'117190','deals','text','<p>PERSONAL MESSAGE</p>',1,''),(387547,122767,'117190','deals','font-size','18',0,''),(387548,122767,'117190','deals','font-weight','normal',0,''),(387549,122767,'117190','deals','text-align','center',0,''),(387550,122767,'117190','deals','padding-top','20',0,''),(387551,122767,'117190','deals','padding-bottom','10',0,''),(387552,122767,'117190','deals','border-top-width','1',0,''),(387553,122767,'117190','deals','border-top-color','$warning-border',0,''),(387554,122767,'117190','deals','text','<p>PERSONAL MESSAGE</p>',2,''),(387555,122767,'117190','deals','text','<p>PERSONAL MESSAGE</p>',3,''),(387556,122767,'117190','deals','text','<p>PERSONAL MESSAGE</p>',4,''),(387557,122768,'117191','deals','font-size','60',0,''),(387558,122768,'117191','deals','font-weight','bold',0,''),(387559,122768,'117191','deals','text-align','center',0,''),(387560,122768,'117191','deals','line-height','100',0,''),(387561,122768,'117191','deals','padding-bottom','20',0,''),(387562,122768,'117191','deals','line_height_measure','px',0,''),(387563,122769,'117192','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(387564,122769,'117192','deals','font-weight','normal',0,''),(387565,122769,'117192','deals','text-align','center',0,''),(387566,122769,'117192','deals','padding-bottom','10',0,''),(387567,122769,'117192','deals','font-size','14',0,''),(387568,122769,'117192','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',2,''),(387569,122769,'117192','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',3,''),(387570,122769,'117192','deals','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',4,''),(387571,122770,'1638804328','deals','logo_from','theme',0,''),(387572,122770,'1638804328','deals','padding-top','20',0,''),(387573,122770,'1638804328','deals','text-align','center',0,''),(387574,122770,'1638804328','deals','padding-bottom','20',0,''),(387575,122771,'117193','deals','block_type','1',0,''),(387576,122771,'117193','deals','font-weight','normal',0,''),(387577,122771,'117193','deals','style_class','gift-card-view',0,''),(387578,122771,'117193','deals','text-align','center',0,''),(387579,122771,'117193','deals','padding-bottom','20',0,''),(387580,122771,'117193','deals','background-color','$highlight-box-bg-4',0,''),(387581,122771,'117193','deals','padding-left','20',0,''),(387582,122771,'117193','deals','padding-right','20',0,''),(387583,122771,'117193','deals','color','$highlight-box-color-4',0,''),(387584,122772,'117194','deals','block_type','1',0,''),(387585,122772,'117194','deals','font-weight','normal',0,''),(387586,122772,'117194','deals','padding-top','10',0,''),(387587,122773,'117195','deals','font-size','12',0,''),(387588,122773,'117195','deals','font-weight','bold',0,''),(387589,122773,'117195','deals','text-align','center',0,''),(387590,122773,'117195','deals','style_class','email',0,''),(387591,122773,'117195','deals','color','$highlight-box-color-4',0,''),(387592,122774,'117196','deals','font-size','12',0,''),(387593,122774,'117196','deals','font-weight','bold',0,''),(387594,122774,'117196','deals','text-align','center',0,''),(387595,122774,'117196','deals','style_class','phone',0,''),(387596,122774,'117196','deals','padding-bottom','5',0,''),(387597,122774,'117196','deals','color','$highlight-box-color-4',0,''),(387598,122775,'117197','deals','text','If you require further assistance please contact us',0,''),(387599,122775,'117197','deals','font-size','12',0,''),(387600,122775,'117197','deals','color','$highlight-box-color-4',0,''),(387601,122775,'117197','deals','text-align','center',0,''),(387602,122775,'117197','deals','padding-top','10',0,''),(387603,122776,'117198','deals','block_type','4',0,''),(387604,122776,'117198','deals','color','$highlight-box-color-2',0,''),(387605,122776,'117198','deals','font-size','30',0,''),(387606,122776,'117198','deals','font-weight','normal',0,''),(387607,122776,'117198','deals','background-color','$highlight-box-bg-2',0,''),(387608,122776,'117198','deals','padding-top','5',0,''),(387609,122776,'117198','deals','padding-left','10',0,''),(387610,122776,'117198','deals','padding-right','10',0,''),(387611,122776,'117198','deals','padding-bottom','5',0,''),(387612,122777,'117199','deals','text','Your code is:',0,''),(387613,122777,'117199','deals','font-size','30',0,''),(387614,122777,'117199','deals','color','$highlight-box-color-2',0,''),(387615,122778,'117200','deals','color','$highlight-box-color-2',0,''),(387616,122778,'117200','deals','font-size','30',0,''),(387617,122779,'117201','deals','block_type','1',0,''),(387618,122780,'117202','deals','text','<p>PERSONAL MESSAGE</p>',1,''),(387619,122780,'117202','deals','font-size','18',0,''),(387620,122780,'117202','deals','font-weight','normal',0,''),(387621,122780,'117202','deals','text-align','center',0,''),(387622,122780,'117202','deals','padding-top','20',0,''),(387623,122780,'117202','deals','padding-bottom','10',0,''),(387624,122780,'117202','deals','border-top-width','1',0,''),(387625,122780,'117202','deals','border-top-color','$warning-border',0,''),(387626,122780,'117202','deals','text','<p>PERSONAL MESSAGE</p>',2,''),(387627,122780,'117202','deals','text','<p>PERSONAL MESSAGE</p>',3,''),(387628,122780,'117202','deals','text','<p>PERSONAL MESSAGE</p>',4,''),(387629,122780,'117202','deals','color','$highlight-box-color-2',0,''),(387630,122781,'117203','deals','text','HOLBI',0,''),(387631,122781,'117203','deals','color','$highlight-box-color-2',0,''),(387632,122781,'117203','deals','font-size','24',0,''),(387633,122781,'117203','deals','padding-top','20',0,''),(387634,122781,'117203','deals','text-align','center',0,''),(387635,122781,'117203','deals','padding-bottom','20',0,''),(387636,122782,'117204','deals','border-top-color','$warning-border',0,''),(387637,122782,'117204','deals','border-top-width','1',0,''),(387638,122782,'117204','deals','padding-top','20',0,''),(387639,122782,'117204','deals','font-size','30',0,''),(387640,122782,'117204','deals','text-align','center',0,''),(387641,122782,'117204','deals','color','$highlight-box-color-4',0,''),(387642,122782,'117204','deals','text','GIFT CARD',0,''),(387643,122783,'117205','deals','text-align','center',0,''),(387644,122783,'117205','deals','font-weight','bold',0,''),(387645,122783,'117205','deals','font-size','60',0,''),(387646,122783,'117205','deals','color','$highlight-box-color-4',0,''),(387647,122784,'117206','deals','font-size','20',0,''),(387648,122784,'117206','deals','text-align','center',0,''),(387649,122784,'117206','deals','color','$highlight-box-color-2',0,''),(387650,122784,'117206','deals','padding-top','20',0,''),(387651,122784,'117206','deals','padding-bottom','20',0,''),(387652,122785,'117207','deals','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(387653,122785,'117207','deals','text-align','center',0,''),(387654,122785,'117207','deals','color','$highlight-box-color-2',0,''),(387655,122785,'117207','deals','font-size','14',0,''),(387656,122785,'117207','deals','padding-bottom','20',0,''),(387657,122786,'117208','deals','text','WHAT TO DO NEXT:',0,''),(387658,122786,'117208','deals','font-size','18',0,''),(387659,122786,'117208','deals','text-align','center',0,''),(387660,122786,'117208','deals','color','$highlight-box-color-2',0,''),(387661,122786,'117208','deals','padding-top','20',0,''),(387662,122786,'117208','deals','padding-bottom','10',0,''),(387663,122786,'117208','deals','border-top-width','1',0,''),(387664,122786,'117208','deals','border-top-color','$warning-border',0,''),(387665,122788,'0','deals','block_type','1',0,''),(387666,122788,'0','deals','style_class','headerWrap fixed-header-1',0,''),(387667,122788,'0','deals','padding-top','10',0,'5630'),(387668,122788,'0','deals','padding-top','5',0,'5660'),(387669,122788,'0','deals','background-color','$header-bg-1',0,''),(387670,122788,'0','deals','color','$header-color-1',0,''),(387728,122798,'1683115085.234893','deals','block_type','1',0,''),(387729,122798,'1683115085.234893','deals','style_class','breadcrumb-box',0,''),(387730,122798,'1683115085.234893','deals','visibility_home','1',0,''),(387731,122800,'117224.000001','deals','block_type','1',0,''),(387732,122806,'117229','deals','width','680',0,''),(387733,122806,'117229','deals','font-weight','normal',0,''),(387734,122806,'117229','deals','font-size','12',0,''),(387735,122806,'117229','deals','padding-top','20',0,''),(387736,122806,'117229','deals','padding-bottom','20',0,''),(387737,122806,'117229','deals','color','$content-color-1',0,''),(387738,122807,'117230','deals','block_type','4',0,''),(387739,122807,'117230','deals','font-weight','normal',0,''),(387740,122807,'117230','deals','border-top-width','1',0,''),(387741,122807,'117230','deals','border-top-color','$content-border-1',0,''),(387742,122807,'117230','deals','border-left-width','1',0,''),(387743,122807,'117230','deals','border-left-color','$content-border-1',0,''),(387744,122807,'117230','deals','border-right-width','1',0,''),(387745,122807,'117230','deals','border-right-color','$content-border-1',0,''),(387746,122807,'117230','deals','border-bottom-width','1',0,''),(387747,122807,'117230','deals','border-bottom-color','$content-border-1',0,''),(387748,122808,'117231','deals','block_type','2',0,''),(387749,122808,'117231','deals','font-weight','normal',0,''),(387750,122808,'117231','deals','border-top-width','1',0,''),(387751,122808,'117231','deals','border-top-color','$content-border-1',0,''),(387752,122808,'117231','deals','border-right-width','1',0,''),(387753,122808,'117231','deals','border-right-color','$content-border-1',0,''),(387754,122809,'117232','deals','block_type','1',0,''),(387755,122809,'117232','deals','font-weight','normal',0,''),(387756,122809,'117232','deals','padding-top','10',0,''),(387757,122809,'117232','deals','padding-left','10',0,''),(387758,122809,'117232','deals','padding-right','10',0,''),(387759,122809,'117232','deals','padding-bottom','10',0,''),(387760,122809,'117232','deals','border-right-width','1',0,''),(387761,122809,'117232','deals','border-right-color','$content-border-1',0,''),(387762,122811,'117234','deals','text','<p>Shipping via</p>',1,''),(387763,122811,'117234','deals','font-weight','bold',0,''),(387764,122811,'117234','deals','font-size','14',0,''),(387765,122811,'117234','deals','text','<p>Shipping via</p>',2,''),(387766,122811,'117234','deals','text','<p>Shipping via</p>',3,''),(387767,122811,'117234','deals','text','<p>Shipping via</p>',4,''),(387768,122812,'117235','deals','block_type','1',0,''),(387769,122812,'117235','deals','font-weight','normal',0,''),(387770,122812,'117235','deals','padding-top','10',0,''),(387771,122812,'117235','deals','padding-left','10',0,''),(387772,122812,'117235','deals','padding-right','10',0,''),(387773,122812,'117235','deals','padding-bottom','10',0,''),(387774,122813,'117236','deals','text','<p>Shipping service</p>',1,''),(387775,122813,'117236','deals','font-weight','bold',0,''),(387776,122813,'117236','deals','font-size','14',0,''),(387777,122813,'117236','deals','text','<p>Shipping service</p>',2,''),(387778,122813,'117236','deals','text','<p>Shipping service</p>',3,''),(387779,122813,'117236','deals','text','<p>Shipping service</p>',4,''),(387780,122815,'117238','deals','block_type','2',0,''),(387781,122815,'117238','deals','font-weight','normal',0,''),(387782,122815,'117238','deals','border-right-width','1',0,''),(387783,122815,'117238','deals','border-right-color','$content-border-1',0,''),(387784,122816,'117239','deals','block_type','1',0,''),(387785,122816,'117239','deals','font-weight','400',0,''),(387786,122816,'117239','deals','background-color','$content-bg-2',0,''),(387787,122816,'117239','deals','padding-top','10',0,''),(387788,122816,'117239','deals','padding-left','10',0,''),(387789,122816,'117239','deals','padding-right','10',0,''),(387790,122816,'117239','deals','padding-bottom','30',0,''),(387791,122817,'117240','deals','text','<p>INVOICE ADDRESS:</p>',1,''),(387792,122817,'117240','deals','font-size','14',0,''),(387793,122817,'117240','deals','font-weight','bold',0,''),(387794,122817,'117240','deals','text','<p>INVOICE ADDRESS:</p>',2,''),(387795,122817,'117240','deals','text','<p>INVOICE ADDRESS:</p>',3,''),(387796,122817,'117240','deals','text','<p>INVOICE ADDRESS:</p>',4,''),(387797,122818,'117241','deals','font-size','12',0,''),(387798,122820,'117242','deals','block_type','1',0,''),(387799,122820,'117242','deals','font-weight','normal',0,''),(387800,122820,'117242','deals','padding-top','10',0,''),(387801,122820,'117242','deals','padding-left','10',0,''),(387802,122820,'117242','deals','padding-right','10',0,''),(387803,122820,'117242','deals','padding-bottom','10',0,''),(387804,122821,'117243','deals','text','<p>E-MAIL ADDRESS:</p>',1,''),(387805,122821,'117243','deals','font-weight','bold',0,''),(387806,122821,'117243','deals','font-size','14',0,''),(387807,122821,'117243','deals','padding-top','10',0,''),(387808,122821,'117243','deals','text','<p>E-MAIL ADDRESS:</p>',2,''),(387809,122821,'117243','deals','text','<p>E-MAIL ADDRESS:</p>',3,''),(387810,122821,'117243','deals','text','<p>E-MAIL ADDRESS:</p>',4,''),(387811,122822,'117244','deals','font-weight','normal',0,''),(387812,122823,'117245','deals','font-weight','normal',0,''),(387813,122824,'117246','deals','text','<p>CUSTOMER:</p>',1,''),(387814,122824,'117246','deals','font-size','13',0,''),(387815,122824,'117246','deals','font-weight','bold',0,''),(387816,122824,'117246','deals','text','<p>CUSTOMER:</p>',2,''),(387817,122824,'117246','deals','text','<p>CUSTOMER:</p>',3,''),(387818,122824,'117246','deals','text','<p>CUSTOMER:</p>',4,''),(387819,122825,'117247','deals','text','<p>PHONE NUMBER:</p>',1,''),(387820,122825,'117247','deals','font-size','14',0,''),(387821,122825,'117247','deals','font-weight','bold',0,''),(387822,122825,'117247','deals','padding-top','10',0,''),(387823,122825,'117247','deals','text','<p>PHONE NUMBER:</p>',2,''),(387824,122825,'117247','deals','text','<p>PHONE NUMBER:</p>',3,''),(387825,122825,'117247','deals','text','<p>PHONE NUMBER:</p>',4,''),(387826,122827,'117249','deals','font-weight','normal',0,''),(387827,122827,'117249','deals','text-align','center',0,''),(387828,122827,'117249','deals','padding-bottom','20',0,''),(387829,122828,'117250','deals','text','<p>Payment Method:</p>',1,''),(387830,122828,'117250','deals','font-weight','bold',0,''),(387831,122828,'117250','deals','text-align','center',0,''),(387832,122828,'117250','deals','text','<p>Payment Method:</p>',2,''),(387833,122828,'117250','deals','text','<p>Payment Method:</p>',3,''),(387834,122828,'117250','deals','text','<p>Payment Method:</p>',4,''),(387835,122829,'117251','deals','text','<p>Payment date:</p>',1,''),(387836,122829,'117251','deals','font-weight','bold',0,''),(387837,122829,'117251','deals','text-align','center',0,''),(387838,122829,'117251','deals','font-size','12',0,''),(387839,122829,'117251','deals','text','<p>Payment date:</p>',2,''),(387840,122829,'117251','deals','text','<p>Payment date:</p>',3,''),(387841,122829,'117251','deals','text','<p>Payment date:</p>',4,''),(387842,122830,'117252','deals','font-size','14',0,''),(387843,122830,'117252','deals','font-weight','bold',0,''),(387844,122830,'117252','deals','text-align','center',0,''),(387845,122830,'117252','deals','padding-bottom','10',0,''),(387846,122830,'117252','deals','padding-top','10',0,''),(387847,122831,'117253','deals','font-weight','normal',0,''),(387848,122831,'117253','deals','text-align','center',0,''),(387849,122831,'117253','deals','padding-bottom','10',0,''),(387850,122832,'117254','deals','font-weight','normal',0,''),(387851,122832,'117254','deals','text-align','center',0,''),(387852,122833,'117255','deals','block_type','3',0,''),(387853,122833,'117255','deals','font-weight','normal',0,''),(387854,122833,'117255','deals','padding-top','20',0,''),(387855,122834,'117256','deals','font-size','12',0,''),(387856,122835,'117257','deals','text','<p>If undelivered please return to:</p>',1,''),(387857,122835,'117257','deals','font-size','12',0,''),(387858,122835,'117257','deals','font-weight','bold',0,''),(387859,122835,'117257','deals','text','<p>If undelivered please return to:</p>',2,''),(387860,122835,'117257','deals','text','<p>If undelivered please return to:</p>',3,''),(387861,122835,'117257','deals','text','<p>If undelivered please return to:</p>',4,''),(387862,122836,'117258','deals','text','<p>Thank you for your order</p>',1,''),(387863,122836,'117258','deals','color','$hileght-color-1',0,''),(387864,122836,'117258','deals','font-size','13',0,''),(387865,122836,'117258','deals','font-weight','bold',0,''),(387866,122836,'117258','deals','padding-top','5',0,''),(387867,122836,'117258','deals','text-align','center',0,''),(387868,122836,'117258','deals','text','<p>Thank you for your order</p>',2,''),(387869,122836,'117258','deals','text','<p>Thank you for your order</p>',3,''),(387870,122836,'117258','deals','text','<p>Thank you for your order</p>',4,''),(387871,122837,'117260','deals','block_type','6',0,''),(387872,122837,'117260','deals','font-weight','normal',0,''),(387873,122837,'117260','deals','font-size','16',0,''),(387874,122838,'117261','deals','text','<p>Email:</p>',1,''),(387875,122838,'117261','deals','font-weight','normal',0,''),(387876,122838,'117261','deals','text-align','right',0,''),(387877,122838,'117261','deals','font-size','12',0,''),(387878,122838,'117261','deals','text','<p>Email:</p>',2,''),(387879,122838,'117261','deals','text','<p>Email:</p>',3,''),(387880,122838,'117261','deals','text','<p>Email:</p>',4,''),(387881,122839,'117262','deals','font-weight','normal',0,''),(387882,122839,'117262','deals','text-align','right',0,''),(387883,122839,'117262','deals','font-size','12',0,''),(387884,122840,'117263','deals','block_type','6',0,''),(387885,122840,'117263','deals','font-weight','normal',0,''),(387886,122840,'117263','deals','font-size','16',0,''),(387887,122841,'117264','deals','text','<p>Phone:</p>',1,''),(387888,122841,'117264','deals','font-weight','normal',0,''),(387889,122841,'117264','deals','text-align','right',0,''),(387890,122841,'117264','deals','font-size','12',0,''),(387891,122841,'117264','deals','text','<p>Phone:</p>',2,''),(387892,122841,'117264','deals','text','<p>Phone:</p>',3,''),(387893,122841,'117264','deals','text','<p>Phone:</p>',4,''),(387894,122842,'117265','deals','font-weight','normal',0,''),(387895,122842,'117265','deals','text-align','right',0,''),(387896,122842,'117265','deals','font-size','12',0,''),(387897,122843,'117266','deals','text','<p>If something has gone wrong please contact us at:</p>',1,''),(387898,122843,'117266','deals','font-size','12',0,''),(387899,122843,'117266','deals','font-weight','bold',0,''),(387900,122843,'117266','deals','text-align','right',0,''),(387901,122843,'117266','deals','text','<p>If something has gone wrong please contact us at:</p>',2,''),(387902,122843,'117266','deals','text','<p>If something has gone wrong please contact us at:</p>',3,''),(387903,122843,'117266','deals','text','<p>If something has gone wrong please contact us at:</p>',4,''),(387904,122844,'117267','deals','font-weight','400',0,''),(387905,122844,'117267','deals','padding-top','20',0,''),(387906,122844,'117267','deals','padding-bottom','0',0,''),(387907,122844,'117267','deals','font-size','12',0,''),(387908,122845,'117268','deals','block_type','5',0,''),(387909,122845,'117268','deals','font-weight','normal',0,''),(387910,122845,'117268','deals','border-bottom-width','1',0,''),(387911,122845,'117268','deals','border-bottom-color','$content-border-1',0,''),(387912,122845,'117268','deals','border-top-width','1',0,''),(387913,122845,'117268','deals','border-top-color','$content-border-1',0,''),(387914,122845,'117268','deals','border-left-color','$content-border-1',0,''),(387915,122845,'117268','deals','border-left-width','1',0,''),(387916,122846,'117269','deals','block_type','1',0,''),(387917,122846,'117269','deals','font-weight','normal',0,''),(387918,122846,'117269','deals','padding-top','10',0,''),(387919,122846,'117269','deals','padding-left','10',0,''),(387920,122846,'117269','deals','padding-right','10',0,''),(387921,122847,'117270','deals','font-weight','400',0,''),(387922,122847,'117270','deals','line-height','120',0,''),(387923,122847,'117270','deals','line_height_measure','%',0,''),(387924,122847,'117270','deals','font-size','12',0,''),(387925,122848,'117271','deals','text','<p>SHIPPING ADDRESS:</p>',1,''),(387926,122848,'117271','deals','font-size','14',0,''),(387927,122848,'117271','deals','font-weight','bold',0,''),(387928,122848,'117271','deals','padding-bottom','10',0,''),(387929,122848,'117271','deals','text','<p>SHIPPING ADDRESS:</p>',2,''),(387930,122848,'117271','deals','text','<p>SHIPPING ADDRESS:</p>',3,''),(387931,122848,'117271','deals','text','<p>SHIPPING ADDRESS:</p>',4,''),(387932,122849,'117272','deals','block_type','1',0,''),(387933,122849,'117272','deals','background-color','$content-bg-2',0,''),(387934,122849,'117272','deals','padding-top','20',0,''),(387935,122849,'117272','deals','padding-left','10',0,''),(387936,122849,'117272','deals','padding-right','10',0,''),(387937,122849,'117272','deals','padding-bottom','20',0,''),(387938,122849,'117272','deals','font-size','14',0,''),(387939,122850,'117273','deals','font-weight','normal',0,''),(387940,122850,'117273','deals','text-align','right',0,''),(387941,122850,'117273','deals','font-size','12',0,''),(387942,122850,'117273','deals','box_align','3',0,''),(387943,122851,'117274','deals','block_type','2',0,''),(387944,122851,'117274','deals','font-weight','normal',0,''),(387945,122851,'117274','deals','padding-bottom','20',0,''),(387946,122852,'117275','deals','font-weight','400',0,''),(387947,122852,'117275','deals','padding-top','20',0,''),(387948,122852,'117275','deals','logo','themes/deals/img/logo-2.png',1,''),(387949,122852,'117275','deals','padding-bottom','20',0,''),(387950,122852,'117275','deals','logo','themes/deals/img/logo-2.png',2,''),(387951,122852,'117275','deals','logo','themes/deals/img/logo-2.png',3,''),(387952,122852,'117275','deals','logo','themes/deals/img/logo-2.png',4,''),(387953,122853,'117276','deals','block_type','11',0,''),(387954,122853,'117276','deals','font-weight','normal',0,''),(387955,122854,'117277','deals','text','<p>Web:</p>',1,''),(387956,122854,'117277','deals','font-weight','normal',0,''),(387957,122854,'117277','deals','text-align','right',0,''),(387958,122854,'117277','deals','text','<p>Web:</p>',2,''),(387959,122854,'117277','deals','text','<p>Web:</p>',3,''),(387960,122854,'117277','deals','text','<p>Web:</p>',4,''),(387961,122855,'117278','deals','font-weight','normal',0,''),(387962,122855,'117278','deals','text-align','right',0,''),(387963,122856,'117279','deals','block_type','11',0,''),(387964,122856,'117279','deals','font-weight','normal',0,''),(387965,122857,'117280','deals','text','<p>Email:</p>',1,''),(387966,122857,'117280','deals','font-weight','normal',0,''),(387967,122857,'117280','deals','text-align','right',0,''),(387968,122857,'117280','deals','text','<p>Email:</p>',2,''),(387969,122857,'117280','deals','text','<p>Email:</p>',3,''),(387970,122857,'117280','deals','text','<p>Email:</p>',4,''),(387971,122858,'117281','deals','font-weight','normal',0,''),(387972,122858,'117281','deals','text-align','right',0,''),(387973,122859,'117282','deals','block_type','1',0,''),(387974,122860,'117283','deals','font-weight','normal',0,''),(387975,122860,'117283','deals','text-align','right',0,''),(387976,122860,'117283','deals','padding-bottom','10',0,''),(387977,122860,'117283','deals','address_spacer',',',0,''),(387978,122860,'117283','deals','font-size','12',0,''),(387979,122861,'117284','deals','block_type','11',0,''),(387980,122861,'117284','deals','font-weight','normal',0,''),(387981,122862,'117285','deals','text','<p>Phone:</p>',1,''),(387982,122862,'117285','deals','font-weight','normal',0,''),(387983,122862,'117285','deals','text-align','right',0,''),(387984,122862,'117285','deals','text','<p>Phone:</p>',2,''),(387985,122862,'117285','deals','text','<p>Phone:</p>',3,''),(387986,122862,'117285','deals','text','<p>Phone:</p>',4,''),(387987,122863,'117286','deals','font-weight','normal',0,''),(387988,122863,'117286','deals','text-align','right',0,''),(387989,122864,'1640103567','deals','column_qty','1',0,''),(387990,122864,'1640103567','deals','column_name','1',0,''),(387991,122864,'1640103567','deals','column_model','1',0,''),(387992,122865,'117287','deals','block_type','1',0,''),(387993,122865,'117287','deals','padding-top','20',0,''),(387994,122866,'117288','deals','tab_1','RETURNING CUSTOMER',1,''),(387995,122866,'117288','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(387996,122866,'117288','deals','tab_1','RETURNING CUSTOMER',2,''),(387997,122866,'117288','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(387998,122866,'117288','deals','tab_1','RETURNING CUSTOMER',3,''),(387999,122866,'117288','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(388000,122866,'117288','deals','tab_1','RETURNING CUSTOMER',4,''),(388001,122866,'117288','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(388002,122867,'117289','deals','max-width','600',0,''),(388003,122867,'117289','deals','margin_left_measure','auto',0,''),(388004,122867,'117289','deals','margin_right_measure','auto',0,''),(388005,122868,'117292','deals','block_type','1',0,''),(388006,122868,'117292','deals','padding-left','20',0,''),(388007,122868,'117292','deals','padding-right','20',0,''),(388008,122868,'117292','deals','style_class','loginWrapper',0,''),(388009,122869,'117293','deals','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(388010,122871,'117295','deals','block_type','1',0,''),(388011,122872,'117296','deals','text','##TEXT_OR##',0,''),(388012,122872,'117296','deals','font-size','18',0,''),(388013,122872,'117296','deals','font-weight','700',0,''),(388014,122872,'117296','deals','padding-top','15',0,''),(388015,122872,'117296','deals','text-align','center',0,''),(388016,122872,'117296','deals','content','\\_',0,'3'),(388017,122872,'117296','deals','height','5',0,'3'),(388018,122872,'117296','deals','width','70',0,'3'),(388019,122872,'117296','deals','display','inline-block',0,'3'),(388020,122872,'117296','deals','border-top-width','1',0,'3'),(388021,122872,'117296','deals','border-top-color','$content-border-1',0,'3'),(388022,122872,'117296','deals','margin-left','10',0,'3'),(388023,122872,'117296','deals','margin-right','10',0,'3'),(388024,122872,'117296','deals','content','\\_',0,'4'),(388025,122872,'117296','deals','display','inline-block',0,'4'),(388026,122872,'117296','deals','width','70',0,'4'),(388027,122872,'117296','deals','height','5',0,'4'),(388028,122872,'117296','deals','border-top-width','1',0,'4'),(388029,122872,'117296','deals','border-top-color','$content-border-1',0,'4'),(388030,122872,'117296','deals','margin-left','10',0,'4'),(388031,122872,'117296','deals','margin-right','10',0,'4'),(388032,122872,'117296','deals','position','relative',0,''),(388033,122872,'117296','deals','top','-10',0,''),(388034,122873,'117297','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388035,122873,'117297','deals','font-size','26',0,''),(388036,122873,'117297','deals','font-family','$font-1',0,''),(388037,122873,'117297','deals','padding-top','15',0,''),(388038,122873,'117297','deals','padding-bottom','15',0,''),(388039,122873,'117297','deals','text-align','center',0,''),(388040,122874,'117298','deals','text-align','center',0,''),(388041,122874,'117298','deals','hide_parents','2',0,''),(388042,122875,'117299','deals','block_type','1',0,''),(388043,122875,'117299','deals','padding-top','40',0,''),(388044,122875,'117299','deals','padding-bottom','40',0,''),(388045,122875,'117299','deals','style_class','checkout-login-wrap',0,''),(388046,122876,'117300','deals','block_type','2',0,''),(388047,122876,'117300','deals','background-color','$content-bg-1',0,''),(388048,122876,'117300','deals','max-width','830',0,''),(388049,122876,'117300','deals','margin_left_measure','auto',0,''),(388050,122876,'117300','deals','margin_right_measure','auto',0,''),(388051,122876,'117300','deals','padding-top','40',0,''),(388052,122876,'117300','deals','padding-bottom','40',0,''),(388053,122876,'117300','deals','schema','2-3',0,'5639'),(388054,122876,'117300','deals','border-top-width','1',0,''),(388055,122876,'117300','deals','border-left-width','1',0,''),(388056,122876,'117300','deals','border-right-width','1',0,''),(388057,122876,'117300','deals','border-bottom-width','1',0,''),(388058,122876,'117300','deals','border-top-color','$content-border-1',0,''),(388059,122876,'117300','deals','border-left-color','$content-border-1',0,''),(388060,122876,'117300','deals','border-right-color','$content-border-1',0,''),(388061,122876,'117300','deals','border-bottom-color','$content-border-1',0,''),(388062,122877,'117301','deals','text-align','center',0,''),(388063,122877,'117301','deals','margin-bottom','40',0,''),(388064,122878,'117302','deals','text-align','center',0,''),(388065,122879,'117303','deals','text','##TEXT_OR##',0,''),(388066,122879,'117303','deals','font-size','18',0,''),(388067,122879,'117303','deals','font-weight','700',0,''),(388068,122879,'117303','deals','text-align','center',0,''),(388069,122879,'117303','deals','content','\\_',0,'3'),(388070,122879,'117303','deals','height','5',0,'3'),(388071,122879,'117303','deals','width','70',0,'3'),(388072,122879,'117303','deals','display','inline-block',0,'3'),(388073,122879,'117303','deals','border-top-width','1',0,'3'),(388074,122879,'117303','deals','border-top-color','$content-border-1',0,'3'),(388075,122879,'117303','deals','margin-left','10',0,'3'),(388076,122879,'117303','deals','margin-right','10',0,'3'),(388077,122879,'117303','deals','content','\\_',0,'4'),(388078,122879,'117303','deals','display','inline-block',0,'4'),(388079,122879,'117303','deals','width','70',0,'4'),(388080,122879,'117303','deals','height','5',0,'4'),(388081,122879,'117303','deals','border-top-width','1',0,'4'),(388082,122879,'117303','deals','border-top-color','$content-border-1',0,'4'),(388083,122879,'117303','deals','margin-left','10',0,'4'),(388084,122879,'117303','deals','margin-right','10',0,'4'),(388085,122879,'117303','deals','position','relative',0,''),(388086,122879,'117303','deals','padding-top','10',0,''),(388087,122879,'117303','deals','padding-bottom','10',0,''),(388088,122880,'117304','deals','block_type','1',0,''),(388089,122881,'117305','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388090,122881,'117305','deals','font-size','18',0,''),(388091,122881,'117305','deals','padding-top','15',0,''),(388092,122881,'117305','deals','padding-bottom','15',0,''),(388093,122881,'117305','deals','text-align','center',0,''),(388094,122881,'117305','deals','text-transform','uppercase',0,''),(388095,122882,'117306','deals','text-align','center',0,''),(388096,122882,'117306','deals','hide_parents','2',0,''),(388097,122883,'117307','deals','text','##NEW_CUSTOMER##',0,''),(388098,122883,'117307','deals','font-size','18',0,''),(388099,122883,'117307','deals','text-align','center',0,''),(388100,122883,'117307','deals','text-transform','uppercase',0,''),(388101,122883,'117307','deals','margin-bottom','10',0,''),(388102,122884,'117308','deals','max-width','230',0,''),(388103,122884,'117308','deals','margin_left_measure','auto',0,''),(388104,122884,'117308','deals','margin_right_measure','auto',0,''),(388105,122885,'117309','deals','text','##RETURNING_CUSTOMER##',0,''),(388106,122885,'117309','deals','font-size','18',0,''),(388107,122885,'117309','deals','text-transform','uppercase',0,''),(388108,122885,'117309','deals','text-align','center',0,''),(388109,122886,'117310','deals','block_type','1',0,''),(388110,122886,'117310','deals','padding-top','20',0,''),(388111,122887,'117311','deals','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(388112,122887,'117311','deals','tab_2','RETURNING CUSTOMER',1,''),(388113,122887,'117311','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(388114,122887,'117311','deals','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(388115,122887,'117311','deals','tab_2','RETURNING CUSTOMER',2,''),(388116,122887,'117311','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(388117,122887,'117311','deals','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(388118,122887,'117311','deals','tab_2','RETURNING CUSTOMER',3,''),(388119,122887,'117311','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(388120,122887,'117311','deals','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(388121,122887,'117311','deals','tab_2','RETURNING CUSTOMER',4,''),(388122,122887,'117311','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(388123,122888,'117312','deals','block_type','8',0,''),(388124,122889,'117313','deals','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(388125,122890,'117314','deals','block_type','1',0,''),(388126,122890,'117314','deals','padding-left','20',0,''),(388127,122890,'117314','deals','padding-right','20',0,''),(388128,122892,'117316','deals','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(388129,122892,'117316','deals','border-top-width','1',0,''),(388130,122892,'117316','deals','border-top-color','$content-border-1',0,''),(388131,122894,'117318','deals','block_type','8',0,''),(388132,122895,'117319','deals','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(388133,122896,'117320','deals','block_type','1',0,''),(388134,122896,'117320','deals','padding-left','20',0,''),(388135,122896,'117320','deals','padding-right','20',0,''),(388136,122897,'117321','deals','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(388137,122899,'117323','deals','text-align','center',0,''),(388138,122900,'117324','deals','text','##TEXT_OR##',0,''),(388139,122900,'117324','deals','font-size','18',0,''),(388140,122900,'117324','deals','font-weight','700',0,''),(388141,122900,'117324','deals','padding-top','15',0,''),(388142,122900,'117324','deals','text-align','center',0,''),(388143,122900,'117324','deals','content','\\_',0,'3'),(388144,122900,'117324','deals','height','5',0,'3'),(388145,122900,'117324','deals','width','70',0,'3'),(388146,122900,'117324','deals','display','inline-block',0,'3'),(388147,122900,'117324','deals','border-top-width','1',0,'3'),(388148,122900,'117324','deals','border-top-color','$content-border-1',0,'3'),(388149,122900,'117324','deals','margin-left','10',0,'3'),(388150,122900,'117324','deals','margin-right','10',0,'3'),(388151,122900,'117324','deals','content','\\_',0,'4'),(388152,122900,'117324','deals','display','inline-block',0,'4'),(388153,122900,'117324','deals','width','70',0,'4'),(388154,122900,'117324','deals','height','5',0,'4'),(388155,122900,'117324','deals','border-top-width','1',0,'4'),(388156,122900,'117324','deals','border-top-color','$content-border-1',0,'4'),(388157,122900,'117324','deals','margin-left','10',0,'4'),(388158,122900,'117324','deals','margin-right','10',0,'4'),(388159,122900,'117324','deals','position','relative',0,''),(388160,122900,'117324','deals','top','-10',0,''),(388161,122901,'117325','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388162,122901,'117325','deals','font-size','26',0,''),(388163,122901,'117325','deals','font-family','$font-1',0,''),(388164,122901,'117325','deals','padding-top','15',0,''),(388165,122901,'117325','deals','padding-bottom','15',0,''),(388166,122901,'117325','deals','text-align','center',0,''),(388167,122902,'117326','deals','block_type','1',0,''),(388168,122902,'117326','deals','padding-top','20',0,''),(388169,122903,'117327','deals','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(388170,122903,'117327','deals','tab_2','RETURNING CUSTOMER',1,''),(388171,122903,'117327','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(388172,122903,'117327','deals','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(388173,122903,'117327','deals','tab_2','RETURNING CUSTOMER',2,''),(388174,122903,'117327','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(388175,122903,'117327','deals','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(388176,122903,'117327','deals','tab_2','RETURNING CUSTOMER',3,''),(388177,122903,'117327','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(388178,122903,'117327','deals','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(388179,122903,'117327','deals','tab_2','RETURNING CUSTOMER',4,''),(388180,122903,'117327','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(388181,122904,'117328','deals','block_type','8',0,''),(388182,122905,'117329','deals','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(388183,122908,'117332','deals','block_type','8',0,''),(388184,122909,'117333','deals','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(388185,122911,'117335','deals','block_type','1',0,''),(388186,122911,'117335','deals','padding-left','20',0,''),(388187,122911,'117335','deals','padding-right','20',0,''),(388188,122913,'117337','deals','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(388189,122914,'117338','deals','text','##TEXT_OR##',0,''),(388190,122914,'117338','deals','font-size','18',0,''),(388191,122914,'117338','deals','font-weight','700',0,''),(388192,122914,'117338','deals','padding-top','15',0,''),(388193,122914,'117338','deals','text-align','center',0,''),(388194,122914,'117338','deals','content','\\_',0,'3'),(388195,122914,'117338','deals','height','5',0,'3'),(388196,122914,'117338','deals','width','70',0,'3'),(388197,122914,'117338','deals','display','inline-block',0,'3'),(388198,122914,'117338','deals','border-top-width','1',0,'3'),(388199,122914,'117338','deals','border-top-color','$content-border-1',0,'3'),(388200,122914,'117338','deals','margin-left','10',0,'3'),(388201,122914,'117338','deals','margin-right','10',0,'3'),(388202,122914,'117338','deals','content','\\_',0,'4'),(388203,122914,'117338','deals','display','inline-block',0,'4'),(388204,122914,'117338','deals','width','70',0,'4'),(388205,122914,'117338','deals','height','5',0,'4'),(388206,122914,'117338','deals','border-top-width','1',0,'4'),(388207,122914,'117338','deals','border-top-color','$content-border-1',0,'4'),(388208,122914,'117338','deals','margin-left','10',0,'4'),(388209,122914,'117338','deals','margin-right','10',0,'4'),(388210,122914,'117338','deals','position','relative',0,''),(388211,122914,'117338','deals','top','-10',0,''),(388212,122915,'117339','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388213,122915,'117339','deals','font-size','26',0,''),(388214,122915,'117339','deals','font-family','$font-1',0,''),(388215,122915,'117339','deals','padding-top','15',0,''),(388216,122915,'117339','deals','padding-bottom','15',0,''),(388217,122915,'117339','deals','text-align','center',0,''),(388218,122916,'117340','deals','text-align','center',0,''),(388219,122917,'117341','deals','block_type','1',0,''),(388220,122917,'117341','deals','padding-top','20',0,''),(388221,122918,'117342','deals','text-align','center',0,''),(388222,122919,'117343','deals','text','##TEXT_OR##',0,''),(388223,122919,'117343','deals','font-size','18',0,''),(388224,122919,'117343','deals','font-weight','700',0,''),(388225,122919,'117343','deals','padding-top','15',0,''),(388226,122919,'117343','deals','text-align','center',0,''),(388227,122919,'117343','deals','content','\\_',0,'3'),(388228,122919,'117343','deals','height','5',0,'3'),(388229,122919,'117343','deals','width','70',0,'3'),(388230,122919,'117343','deals','display','inline-block',0,'3'),(388231,122919,'117343','deals','border-top-width','1',0,'3'),(388232,122919,'117343','deals','border-top-color','$content-border-1',0,'3'),(388233,122919,'117343','deals','margin-left','10',0,'3'),(388234,122919,'117343','deals','margin-right','10',0,'3'),(388235,122919,'117343','deals','content','\\_',0,'4'),(388236,122919,'117343','deals','display','inline-block',0,'4'),(388237,122919,'117343','deals','width','70',0,'4'),(388238,122919,'117343','deals','height','5',0,'4'),(388239,122919,'117343','deals','border-top-width','1',0,'4'),(388240,122919,'117343','deals','border-top-color','$content-border-1',0,'4'),(388241,122919,'117343','deals','margin-left','10',0,'4'),(388242,122919,'117343','deals','margin-right','10',0,'4'),(388243,122919,'117343','deals','position','relative',0,''),(388244,122919,'117343','deals','top','-10',0,''),(388245,122920,'117344','deals','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(388246,122920,'117344','deals','tab_2','RETURNING CUSTOMER',1,''),(388247,122920,'117344','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(388248,122920,'117344','deals','tab_1','GUEST – SINGLE USE ACCOUNT',2,''),(388249,122920,'117344','deals','tab_2','RETURNING CUSTOMER',2,''),(388250,122920,'117344','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',2,''),(388251,122920,'117344','deals','tab_1','GUEST – SINGLE USE ACCOUNT',3,''),(388252,122920,'117344','deals','tab_2','RETURNING CUSTOMER',3,''),(388253,122920,'117344','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',3,''),(388254,122920,'117344','deals','tab_1','GUEST – SINGLE USE ACCOUNT',4,''),(388255,122920,'117344','deals','tab_2','RETURNING CUSTOMER',4,''),(388256,122920,'117344','deals','tab_3','REGISTER TO SAVE YOUR DETAILS',4,''),(388257,122921,'117345','deals','block_type','8',0,''),(388258,122922,'117346','deals','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(388259,122925,'117349','deals','block_type','8',0,''),(388260,122926,'117350','deals','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(388261,122927,'117351','deals','block_type','1',0,''),(388262,122927,'117351','deals','padding-left','20',0,''),(388263,122927,'117351','deals','padding-right','20',0,''),(388264,122929,'117353','deals','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(388265,122930,'117354','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388266,122930,'117354','deals','font-size','26',0,''),(388267,122930,'117354','deals','font-family','$font-1',0,''),(388268,122930,'117354','deals','padding-top','15',0,''),(388269,122930,'117354','deals','padding-bottom','15',0,''),(388270,122930,'117354','deals','text-align','center',0,''),(388271,122931,'117355','deals','block_type','1',0,''),(388272,122931,'117355','deals','padding-top','40',0,''),(388273,122931,'117355','deals','background-color','$content-bg-2',0,''),(388274,122931,'117355','deals','padding-bottom','40',0,''),(388275,122932,'117356','deals','block_type','2',0,''),(388276,122932,'117356','deals','background-color','$content-bg-1',0,''),(388277,122932,'117356','deals','max-width','830',0,''),(388278,122932,'117356','deals','margin_left_measure','auto',0,''),(388279,122932,'117356','deals','margin_right_measure','auto',0,''),(388280,122932,'117356','deals','padding-top','40',0,''),(388281,122932,'117356','deals','padding-bottom','40',0,''),(388282,122932,'117356','deals','schema','2-3',0,'5639'),(388283,122933,'117357','deals','block_type','1',0,''),(388284,122934,'117358','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388285,122934,'117358','deals','font-size','18',0,''),(388286,122934,'117358','deals','font-family','$font-1',0,''),(388287,122934,'117358','deals','padding-top','15',0,''),(388288,122934,'117358','deals','padding-bottom','15',0,''),(388289,122934,'117358','deals','text-align','center',0,''),(388290,122934,'117358','deals','text-transform','uppercase',0,''),(388291,122935,'117359','deals','text-align','center',0,''),(388292,122935,'117359','deals','hide_parents','2',0,''),(388293,122936,'117360','deals','text-align','center',0,''),(388294,122937,'117361','deals','text-align','center',0,''),(388295,122937,'117361','deals','margin-bottom','40',0,''),(388296,122938,'117362','deals','text','##TEXT_OR##',0,''),(388297,122938,'117362','deals','font-size','18',0,''),(388298,122938,'117362','deals','font-weight','700',0,''),(388299,122938,'117362','deals','text-align','center',0,''),(388300,122938,'117362','deals','content','\\_',0,'3'),(388301,122938,'117362','deals','height','5',0,'3'),(388302,122938,'117362','deals','width','70',0,'3'),(388303,122938,'117362','deals','display','inline-block',0,'3'),(388304,122938,'117362','deals','border-top-width','1',0,'3'),(388305,122938,'117362','deals','border-top-color','$content-border-1',0,'3'),(388306,122938,'117362','deals','margin-left','10',0,'3'),(388307,122938,'117362','deals','margin-right','10',0,'3'),(388308,122938,'117362','deals','content','\\_',0,'4'),(388309,122938,'117362','deals','display','inline-block',0,'4'),(388310,122938,'117362','deals','width','70',0,'4'),(388311,122938,'117362','deals','height','5',0,'4'),(388312,122938,'117362','deals','border-top-width','1',0,'4'),(388313,122938,'117362','deals','border-top-color','$content-border-1',0,'4'),(388314,122938,'117362','deals','margin-left','10',0,'4'),(388315,122938,'117362','deals','margin-right','10',0,'4'),(388316,122938,'117362','deals','position','relative',0,''),(388317,122938,'117362','deals','padding-top','10',0,''),(388318,122938,'117362','deals','padding-bottom','10',0,''),(388319,122939,'117363','deals','text','##NEW_CUSTOMER##',0,''),(388320,122939,'117363','deals','font-size','18',0,''),(388321,122939,'117363','deals','font-family','$font-1',0,''),(388322,122939,'117363','deals','text-align','center',0,''),(388323,122939,'117363','deals','text-transform','uppercase',0,''),(388324,122939,'117363','deals','margin-bottom','10',0,''),(388325,122940,'117364','deals','text','##RETURNING_CUSTOMER##',0,''),(388326,122940,'117364','deals','font-size','18',0,''),(388327,122940,'117364','deals','font-family','$font-1',0,''),(388328,122940,'117364','deals','text-transform','uppercase',0,''),(388329,122940,'117364','deals','text-align','center',0,''),(388330,122941,'117365','deals','max-width','230',0,''),(388331,122941,'117365','deals','margin_left_measure','auto',0,''),(388332,122941,'117365','deals','margin_right_measure','auto',0,''),(388333,122942,'117366','deals','block_type','1',0,''),(388334,122942,'117366','deals','padding-top','40',0,''),(388335,122942,'117366','deals','background-color','$content-bg-2',0,''),(388336,122942,'117366','deals','padding-bottom','40',0,''),(388337,122943,'117367','deals','block_type','2',0,''),(388338,122943,'117367','deals','background-color','$content-bg-1',0,''),(388339,122943,'117367','deals','max-width','830',0,''),(388340,122943,'117367','deals','margin_left_measure','auto',0,''),(388341,122943,'117367','deals','margin_right_measure','auto',0,''),(388342,122943,'117367','deals','padding-top','40',0,''),(388343,122943,'117367','deals','padding-bottom','40',0,''),(388344,122943,'117367','deals','schema','2-3',0,'5639'),(388345,122944,'117368','deals','text','##NEW_CUSTOMER##',0,''),(388346,122944,'117368','deals','font-size','18',0,''),(388347,122944,'117368','deals','font-family','$font-1',0,''),(388348,122944,'117368','deals','text-align','center',0,''),(388349,122944,'117368','deals','text-transform','uppercase',0,''),(388350,122944,'117368','deals','margin-bottom','10',0,''),(388351,122945,'117369','deals','text-align','center',0,''),(388352,122946,'117370','deals','text-align','center',0,''),(388353,122946,'117370','deals','margin-bottom','40',0,''),(388354,122947,'117371','deals','text','##TEXT_OR##',0,''),(388355,122947,'117371','deals','font-size','18',0,''),(388356,122947,'117371','deals','font-weight','700',0,''),(388357,122947,'117371','deals','text-align','center',0,''),(388358,122947,'117371','deals','content','\\_',0,'3'),(388359,122947,'117371','deals','height','5',0,'3'),(388360,122947,'117371','deals','width','70',0,'3'),(388361,122947,'117371','deals','display','inline-block',0,'3'),(388362,122947,'117371','deals','border-top-width','1',0,'3'),(388363,122947,'117371','deals','border-top-color','$content-border-1',0,'3'),(388364,122947,'117371','deals','margin-left','10',0,'3'),(388365,122947,'117371','deals','margin-right','10',0,'3'),(388366,122947,'117371','deals','content','\\_',0,'4'),(388367,122947,'117371','deals','display','inline-block',0,'4'),(388368,122947,'117371','deals','width','70',0,'4'),(388369,122947,'117371','deals','height','5',0,'4'),(388370,122947,'117371','deals','border-top-width','1',0,'4'),(388371,122947,'117371','deals','border-top-color','$content-border-1',0,'4'),(388372,122947,'117371','deals','margin-left','10',0,'4'),(388373,122947,'117371','deals','margin-right','10',0,'4'),(388374,122947,'117371','deals','position','relative',0,''),(388375,122947,'117371','deals','padding-top','10',0,''),(388376,122947,'117371','deals','padding-bottom','10',0,''),(388377,122948,'117372','deals','block_type','1',0,''),(388378,122949,'117373','deals','text','##LOGIN_WITH_SOCIAL##',0,''),(388379,122949,'117373','deals','font-size','18',0,''),(388380,122949,'117373','deals','font-family','$font-1',0,''),(388381,122949,'117373','deals','padding-top','15',0,''),(388382,122949,'117373','deals','padding-bottom','15',0,''),(388383,122949,'117373','deals','text-align','center',0,''),(388384,122949,'117373','deals','text-transform','uppercase',0,''),(388385,122950,'117374','deals','text-align','center',0,''),(388386,122950,'117374','deals','hide_parents','2',0,''),(388387,122951,'117375','deals','text','##RETURNING_CUSTOMER##',0,''),(388388,122951,'117375','deals','font-size','18',0,''),(388389,122951,'117375','deals','font-family','$font-1',0,''),(388390,122951,'117375','deals','text-transform','uppercase',0,''),(388391,122951,'117375','deals','text-align','center',0,''),(388392,122952,'117376','deals','max-width','230',0,''),(388393,122952,'117376','deals','margin_left_measure','auto',0,''),(388394,122952,'117376','deals','margin_right_measure','auto',0,''),(388395,122953,'117377','deals','block_type','1',0,''),(388396,122954,'117378','deals','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(388397,122954,'117378','deals','margin-bottom','30',0,''),(388398,122955,'117379','deals','block_type','1',0,''),(388399,122956,'117380','deals','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(388400,122956,'117380','deals','margin-bottom','30',0,''),(388401,122957,'1641480784','deals','block_type','1',0,''),(388402,122957,'1641480784','deals','style_class','parallaxWrap',0,''),(388403,122957,'1641480784','deals','background_image','themes/deals/img/grey-bg.jpg',0,''),(388404,122957,'1641480784','deals','background-position','center',0,''),(388405,122957,'1641480784','deals','background-repeat','no-repeat',0,''),(388406,122957,'1641480784','deals','margin-bottom','30',0,''),(388407,122958,'1641480810','deals','info_page','40',0,''),(388408,122959,'1641549359','deals','block_type','1',0,''),(388409,122959,'1641549359','deals','padding-top','60',0,''),(388410,122959,'1641549359','deals','padding-bottom','70',0,''),(388411,122959,'1641549359','deals','style_class','bannersWrap',0,''),(388412,122959,'1641549359','deals','padding-top','30',0,'5639'),(388413,122959,'1641549359','deals','padding-bottom','30',0,'5639'),(388414,122960,'1641549444','deals','block_type','12',0,''),(388415,122961,'1641549385','deals','banners_group','horizontal',0,''),(388416,122961,'1641549385','deals','style_class','leftBanner',0,''),(388417,122961,'1641549385','deals','banners_type','banner',0,''),(388418,122961,'1641549385','deals','template','1',0,''),(388419,122962,'1641549553','deals','banners_group','vertical',0,''),(388420,122962,'1641549553','deals','style_class','rightBanner',0,''),(388421,122962,'1641549553','deals','banners_type','banner',0,''),(388422,122962,'1641549553','deals','template','1',0,''),(388423,122963,'1641570125','deals','block_type','1',0,''),(388424,122964,'1641570075','deals','padding-top','75',0,''),(388425,122964,'1641570075','deals','padding-bottom','70',0,''),(388426,122964,'1641570075','deals','border-top-color','$content-border-1',0,''),(388427,122964,'1641570075','deals','border-top-width','1',0,''),(388428,122964,'1641570075','deals','padding-top','30',0,'5639'),(388429,122964,'1641570075','deals','padding-bottom','30',0,'5639'),(388430,122965,'1683024814.1915','deals','banners_group','18',0,''),(388431,122965,'1683024814.1915','deals','style_class','homeBanner',0,''),(388432,122967,'117394','deals','block_type','1',0,''),(388433,122968,'117395','deals','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(388434,122970,'117397','deals','block_type','1',0,''),(388435,122970,'117397','deals','padding-top','40',0,''),(388436,122970,'117397','deals','padding-bottom','80',0,''),(388437,122971,'117398','deals','block_type','6',0,''),(388438,122972,'117399','deals','block_type','1',0,''),(388439,122972,'117399','deals','padding-top','20',0,''),(388440,122972,'117399','deals','padding-left','20',0,''),(388441,122972,'117399','deals','padding-right','20',0,''),(388442,122972,'117399','deals','padding-bottom','20',0,''),(388443,122972,'117399','deals','border-top-width','1',0,''),(388444,122972,'117399','deals','border-left-width','1',0,''),(388445,122972,'117399','deals','border-right-width','1',0,''),(388446,122972,'117399','deals','border-bottom-width','1',0,''),(388447,122972,'117399','deals','border-top-color','$content-border-1',0,''),(388448,122972,'117399','deals','border-left-color','$content-border-1',0,''),(388449,122972,'117399','deals','border-right-color','$content-border-1',0,''),(388450,122972,'117399','deals','border-bottom-color','$content-border-1',0,''),(388451,122972,'117399','deals','margin-right','20',0,''),(388452,122975,'117402','deals','block_type','1',0,''),(388453,122975,'117402','deals','padding-top','20',0,''),(388454,122976,'117403','deals','block_type','6',0,''),(388455,122977,'117404','deals','padding-right','20',0,''),(388456,122979,'117406','deals','block_type','1',0,''),(388457,122979,'117406','deals','padding-top','20',0,''),(388458,122980,'117407','deals','block_type','6',0,''),(388459,122981,'117408','deals','padding-right','20',0,''),(388460,122983,'117410','deals','block_type','1',0,''),(388461,122983,'117410','deals','style_class','account-password-wrap',0,''),(388462,122984,'117411','deals','block_type','6',0,''),(388463,122984,'117411','deals','schema','6-3',0,'5639'),(388464,122985,'117412','deals','aria_name','account-menu',0,''),(388528,123006,'117414','deals','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(388529,123007,'117415','deals','block_type','1',0,''),(388530,123007,'117415','deals','padding-top','20',0,''),(388531,123008,'117416','deals','tab_1','RETURNING CUSTOMER',1,''),(388532,123008,'117416','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(388533,123008,'117416','deals','tab_1','RETURNING CUSTOMER',2,''),(388534,123008,'117416','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',2,''),(388535,123008,'117416','deals','tab_1','RETURNING CUSTOMER',3,''),(388536,123008,'117416','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',3,''),(388537,123008,'117416','deals','tab_1','RETURNING CUSTOMER',4,''),(388538,123008,'117416','deals','tab_2','REGISTER TO SAVE YOUR DETAILS',4,''),(388539,123009,'117417','deals','max-width','800',0,''),(388540,123009,'117417','deals','margin_left_measure','auto',0,''),(388541,123009,'117417','deals','margin_right_measure','auto',0,''),(388542,123010,'117418','deals','block_type','8',0,''),(388543,123011,'117419','deals','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(388544,123012,'117420','deals','block_type','1',0,''),(388545,123012,'117420','deals','padding-left','20',0,''),(388546,123012,'117420','deals','padding-right','20',0,''),(388547,123014,'117422','deals','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(388548,123015,'117423','deals','block_type','1',0,''),(388549,123016,'117424','deals','block_type','1',0,''),(388550,123017,'117425','deals','margin-left','0',0,''),(388551,123017,'117425','deals','margin-right','0',0,''),(388552,123017,'117425','deals','margin-bottom','20',0,''),(388553,123018,'117426','deals','margin-bottom','30',0,''),(388554,123019,'117427','deals','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(388555,123020,'117428','deals','block_type','1',0,''),(388556,123022,'117430','deals','block_type','6',0,''),(388557,123022,'117430','deals','font-weight','400',0,''),(388558,123022,'117430','deals','schema','6-2',0,'5660'),(388559,123022,'117430','deals','schema','6-2',0,'5639'),(388560,123023,'117431','deals','font-weight','400',0,''),(388561,123023,'117431','deals','padding-right','40',0,''),(388562,123023,'117431','deals','padding-right','0',0,'5660'),(388563,123023,'117431','deals','padding-right','0',0,'5639'),(388564,123024,'117432','deals','col_in_row','3',0,''),(388565,123024,'117432','deals','products_align','left',0,''),(388566,123024,'117432','deals','font-weight','400',0,''),(388567,123024,'117432','deals','show_qty_input','0',0,''),(388568,123024,'117432','deals','listing_type','productListing',0,''),(388569,123024,'117432','deals','listing_type_rows','no',0,''),(388570,123024,'117432','deals','show_buy_button_b2b','on',0,''),(388571,123024,'117432','deals','show_wishlist_button_b2b','1',0,''),(388572,123024,'117432','deals','show_compare_b2b','1',0,''),(388573,123024,'117432','deals','show_stock','0',0,''),(388574,123024,'117432','deals','show_description','0',0,''),(388575,123024,'117432','deals','show_model','0',0,''),(388576,123024,'117432','deals','show_properties','0',0,''),(388577,123024,'117432','deals','show_rating','0',0,''),(388578,123024,'117432','deals','show_rating_counts','0',0,''),(388579,123024,'117432','deals','show_price','0',0,''),(388580,123024,'117432','deals','show_buy_button','0',0,''),(388581,123024,'117432','deals','show_view_button','0',0,''),(388582,123024,'117432','deals','show_wishlist_button','0',0,''),(388583,123024,'117432','deals','show_compare','0',0,''),(388584,123024,'117432','deals','show_name_rows','0',0,''),(388585,123024,'117432','deals','show_image_rows','0',0,''),(388586,123024,'117432','deals','show_stock_rows','0',0,''),(388587,123024,'117432','deals','show_description_rows','0',0,''),(388588,123024,'117432','deals','show_model_rows','0',0,''),(388589,123024,'117432','deals','show_properties_rows','0',0,''),(388590,123024,'117432','deals','show_rating_rows','0',0,''),(388591,123024,'117432','deals','show_rating_counts_rows','0',0,''),(388592,123024,'117432','deals','show_price_rows','0',0,''),(388593,123024,'117432','deals','show_buy_button_rows','0',0,''),(388594,123024,'117432','deals','show_qty_input_rows','0',0,''),(388595,123024,'117432','deals','show_view_button_rows','0',0,''),(388596,123024,'117432','deals','show_wishlist_button_rows','0',0,''),(388597,123024,'117432','deals','show_compare_rows','0',0,''),(388598,123024,'117432','deals','show_name_b2b','0',0,''),(388599,123024,'117432','deals','show_image_b2b','0',0,''),(388600,123024,'117432','deals','show_stock_b2b','0',0,''),(388601,123024,'117432','deals','show_description_b2b','0',0,''),(388602,123024,'117432','deals','show_model_b2b','0',0,''),(388603,123024,'117432','deals','show_properties_b2b','0',0,''),(388604,123024,'117432','deals','show_rating_b2b','0',0,''),(388605,123024,'117432','deals','show_rating_counts_b2b','0',0,''),(388606,123024,'117432','deals','show_price_b2b','0',0,''),(388607,123024,'117432','deals','show_qty_input_b2b','0',0,''),(388608,123024,'117432','deals','show_view_button_b2b','0',0,''),(388609,123024,'117432','deals','show_attributes_b2b','0',0,''),(388610,123024,'117432','deals','items_on_page','9',0,''),(388611,123024,'117432','deals','col_in_row','2',0,'5639'),(388612,123024,'117432','deals','col_in_row','1',0,'5660'),(388613,123024,'117432','deals','product_names_teg','h2',0,''),(388614,123026,'117434','deals','block_type','5',0,''),(388615,123026,'117434','deals','padding-top','10',0,''),(388616,123026,'117434','deals','padding-bottom','10',0,''),(388617,123026,'117434','deals','schema','5-2',0,'5660'),(388618,123026,'117434','deals','border-top-color','$content-border-1',0,''),(388619,123026,'117434','deals','border-top-width','1',0,''),(388620,123028,'117436','deals','float','right',0,''),(388621,123029,'117437','deals','listing_type','productListing',0,''),(388622,123031,'117439','deals','block_type','1',0,''),(388623,123031,'117439','deals','padding-top','10',0,''),(388624,123031,'117439','deals','padding-bottom','10',0,''),(388625,123031,'117439','deals','border-bottom-width','1',0,''),(388626,123031,'117439','deals','border-bottom-color','$content-border-1',0,''),(388627,123031,'117439','deals','margin-left','0',0,''),(388628,123031,'117439','deals','margin-right','0',0,''),(388629,123032,'117440','deals','float','right',0,''),(388630,123032,'117440','deals','display','none',0,'5660'),(388631,123033,'117441','deals','float','left',0,''),(388632,123033,'117441','deals','clear','none',0,''),(388633,123033,'117441','deals','margin-left','20',0,''),(388634,123033,'117441','deals','display','none',0,'5660'),(388635,123034,'117442','deals','margin-right','20',0,''),(388636,123034,'117442','deals','float','right',0,''),(388637,123034,'117442','deals','clear','none',0,''),(388638,123034,'117442','deals','display','none',0,'5639'),(388639,123035,'117443','deals','float','left',0,''),(388640,123035,'117443','deals','clear','none',0,''),(388641,123035,'117443','deals','sort_pos_3','1',0,''),(388642,123035,'117443','deals','sort_pos_4','2',0,''),(388643,123035,'117443','deals','sort_pos_10','3',0,''),(388644,123035,'117443','deals','sort_pos_9','4',0,''),(388645,123035,'117443','deals','sort_pos_11','5',0,''),(388646,123035,'117443','deals','sort_pos_12','6',0,''),(388647,123035,'117443','deals','sort_pos_14','7',0,''),(388648,123035,'117443','deals','sort_pos_13','8',0,''),(388649,123035,'117443','deals','sort_pos_8','9',0,''),(388650,123035,'117443','deals','sort_pos_7','10',0,''),(388651,123035,'117443','deals','sort_pos_2','11',0,''),(388652,123035,'117443','deals','sort_pos_1','12',0,''),(388653,123035,'117443','deals','sort_pos_6','13',0,''),(388654,123035,'117443','deals','sort_pos_5','14',0,''),(388655,123035,'117443','deals','sort_pos_0','15',0,''),(388656,123035,'117443','deals','sort_hide_10','1',0,''),(388657,123035,'117443','deals','sort_hide_9','1',0,''),(388658,123035,'117443','deals','hide_icons','1',0,''),(388659,123035,'117443','deals','sort_hide_16','1',0,''),(388660,123035,'117443','deals','sort_hide_15','1',0,''),(388661,123035,'117443','deals','sort_hide_3','0',0,''),(388662,123035,'117443','deals','sort_hide_4','0',0,''),(388663,123035,'117443','deals','sort_hide_11','1',0,''),(388664,123035,'117443','deals','sort_hide_12','1',0,''),(388665,123035,'117443','deals','sort_hide_14','1',0,''),(388666,123035,'117443','deals','sort_hide_13','1',0,''),(388667,123035,'117443','deals','sort_hide_8','0',0,''),(388668,123035,'117443','deals','sort_hide_7','0',0,''),(388669,123035,'117443','deals','sort_hide_2','1',0,''),(388670,123035,'117443','deals','sort_hide_1','1',0,''),(388671,123035,'117443','deals','sort_hide_6','1',0,''),(388672,123035,'117443','deals','sort_hide_5','1',0,''),(388673,123035,'117443','deals','sort_hide_0','1',0,''),(388674,123036,'117444','deals','block_type','1',0,''),(388675,123037,'117445','deals','margin-bottom','30',0,''),(388676,123038,'117446','deals','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(388677,123039,'117447','deals','block_type','1',0,''),(388678,123040,'117448','deals','block_type','5',0,''),(388679,123040,'117448','deals','padding-top','10',0,''),(388680,123040,'117448','deals','padding-bottom','10',0,''),(388681,123040,'117448','deals','schema','5-2',0,'5660'),(388682,123040,'117448','deals','border-top-color','$content-border-1',0,''),(388683,123040,'117448','deals','border-top-width','1',0,''),(388684,123041,'117449','deals','padding-top','3',0,''),(388685,123042,'117450','deals','float','right',0,''),(388686,123042,'117450','deals','height','31',0,''),(388687,123043,'117451','deals','col_in_row','4',0,''),(388688,123043,'117451','deals','products_align','left',0,''),(388689,123043,'117451','deals','font-weight','400',0,''),(388690,123043,'117451','deals','listing_type','productListing',0,''),(388691,123043,'117451','deals','listing_type_rows','Rows',0,''),(388692,123043,'117451','deals','show_buy_button_b2b','on',0,''),(388693,123043,'117451','deals','show_wishlist_button_b2b','1',0,''),(388694,123043,'117451','deals','show_compare_b2b','1',0,''),(388695,123043,'117451','deals','show_image','0',0,''),(388696,123043,'117451','deals','show_stock','0',0,''),(388697,123043,'117451','deals','show_description','0',0,''),(388698,123043,'117451','deals','show_model','0',0,''),(388699,123043,'117451','deals','show_properties','0',0,''),(388700,123043,'117451','deals','show_rating','0',0,''),(388701,123043,'117451','deals','show_rating_counts','0',0,''),(388702,123043,'117451','deals','show_price','0',0,''),(388703,123043,'117451','deals','show_buy_button','0',0,''),(388704,123043,'117451','deals','show_view_button','0',0,''),(388705,123043,'117451','deals','show_wishlist_button','0',0,''),(388706,123043,'117451','deals','show_compare','0',0,''),(388707,123043,'117451','deals','show_name_rows','0',0,''),(388708,123043,'117451','deals','show_image_rows','0',0,''),(388709,123043,'117451','deals','show_stock_rows','0',0,''),(388710,123043,'117451','deals','show_description_rows','0',0,''),(388711,123043,'117451','deals','show_model_rows','0',0,''),(388712,123043,'117451','deals','show_properties_rows','0',0,''),(388713,123043,'117451','deals','show_rating_rows','0',0,''),(388714,123043,'117451','deals','show_rating_counts_rows','0',0,''),(388715,123043,'117451','deals','show_price_rows','0',0,''),(388716,123043,'117451','deals','show_buy_button_rows','0',0,''),(388717,123043,'117451','deals','show_qty_input_rows','0',0,''),(388718,123043,'117451','deals','show_view_button_rows','0',0,''),(388719,123043,'117451','deals','show_wishlist_button_rows','0',0,''),(388720,123043,'117451','deals','show_compare_rows','0',0,''),(388721,123043,'117451','deals','show_name_b2b','0',0,''),(388722,123043,'117451','deals','show_image_b2b','0',0,''),(388723,123043,'117451','deals','show_stock_b2b','0',0,''),(388724,123043,'117451','deals','show_description_b2b','0',0,''),(388725,123043,'117451','deals','show_model_b2b','0',0,''),(388726,123043,'117451','deals','show_properties_b2b','0',0,''),(388727,123043,'117451','deals','show_rating_b2b','0',0,''),(388728,123043,'117451','deals','show_rating_counts_b2b','0',0,''),(388729,123043,'117451','deals','show_price_b2b','0',0,''),(388730,123043,'117451','deals','show_qty_input_b2b','0',0,''),(388731,123043,'117451','deals','show_view_button_b2b','0',0,''),(388732,123043,'117451','deals','show_attributes_b2b','0',0,''),(388733,123043,'117451','deals','items_on_page','12',0,''),(388734,123043,'117451','deals','col_in_row','2',0,'5639'),(388735,123043,'117451','deals','col_in_row','1',0,'5660'),(388736,123043,'117451','deals','product_names_teg','h2',0,''),(388737,123046,'117454','deals','block_type','1',0,''),(388738,123047,'117455','deals','block_type','1',0,''),(388739,123047,'117455','deals','padding-top','10',0,''),(388740,123047,'117455','deals','padding-bottom','10',0,''),(388741,123047,'117455','deals','border-bottom-width','1',0,''),(388742,123047,'117455','deals','border-bottom-color','$content-border-1',0,''),(388743,123047,'117455','deals','margin-left','0',0,''),(388744,123047,'117455','deals','margin-right','0',0,''),(388745,123048,'117456','deals','clear','none',0,''),(388746,123048,'117456','deals','float','left',0,''),(388747,123048,'117456','deals','padding-top','3',0,''),(388748,123048,'117456','deals','margin-left','20',0,''),(388749,123048,'117456','deals','display_none','1',0,'5639'),(388750,123049,'117457','deals','float','right',0,''),(388751,123049,'117457','deals','display','none',0,'5660'),(388752,123050,'117458','deals','margin-right','20',0,''),(388753,123050,'117458','deals','float','right',0,''),(388754,123050,'117458','deals','clear','none',0,''),(388755,123050,'117458','deals','display','none',0,'5639'),(388756,123051,'117459','deals','float','left',0,''),(388757,123051,'117459','deals','clear','none',0,''),(388758,123051,'117459','deals','margin-left','20',0,''),(388759,123051,'117459','deals','display','none',0,'5660'),(388760,123051,'117459','deals','display_none','1',0,'5630'),(388761,123052,'117460','deals','float','left',0,''),(388762,123052,'117460','deals','clear','none',0,''),(388763,123052,'117460','deals','sort_pos_3','2',0,''),(388764,123052,'117460','deals','sort_pos_4','3',0,''),(388765,123052,'117460','deals','sort_pos_10','11',0,''),(388766,123052,'117460','deals','sort_pos_9','10',0,''),(388767,123052,'117460','deals','sort_pos_11','12',0,''),(388768,123052,'117460','deals','sort_pos_12','13',0,''),(388769,123052,'117460','deals','sort_pos_14','15',0,''),(388770,123052,'117460','deals','sort_pos_13','14',0,''),(388771,123052,'117460','deals','sort_pos_8','4',0,''),(388772,123052,'117460','deals','sort_pos_7','5',0,''),(388773,123052,'117460','deals','sort_pos_2','7',0,''),(388774,123052,'117460','deals','sort_pos_1','6',0,''),(388775,123052,'117460','deals','sort_pos_6','9',0,''),(388776,123052,'117460','deals','sort_pos_5','8',0,''),(388777,123052,'117460','deals','sort_pos_0','1',0,''),(388778,123052,'117460','deals','sort_hide_10','1',0,''),(388779,123052,'117460','deals','sort_hide_9','1',0,''),(388780,123052,'117460','deals','sort_pos_15','16',0,''),(388781,123052,'117460','deals','sort_pos_16','17',0,''),(388782,123052,'117460','deals','sort_hide_4','0',0,''),(388783,123052,'117460','deals','sort_hide_3','0',0,''),(388784,123052,'117460','deals','sort_hide_16','1',0,''),(388785,123052,'117460','deals','sort_hide_15','1',0,''),(388786,123052,'117460','deals','sort_hide_11','1',0,''),(388787,123052,'117460','deals','sort_hide_12','1',0,''),(388788,123052,'117460','deals','sort_hide_14','1',0,''),(388789,123052,'117460','deals','sort_hide_13','1',0,''),(388790,123052,'117460','deals','sort_hide_8','0',0,''),(388791,123052,'117460','deals','sort_hide_7','0',0,''),(388792,123052,'117460','deals','sort_hide_2','1',0,''),(388793,123052,'117460','deals','sort_hide_1','1',0,''),(388794,123052,'117460','deals','sort_hide_6','1',0,''),(388795,123052,'117460','deals','sort_hide_5','1',0,''),(388796,123052,'117460','deals','sort_hide_0','0',0,''),(388797,123052,'117460','deals','hide_icons','1',0,''),(388798,123053,'117461','deals','margin-bottom','20',0,''),(388799,123055,'117462','deals','block_type','1',0,''),(388800,123055,'117462','deals','style_class','account-order-history',0,''),(388873,123079,'117467','deals','block_type','1',0,''),(388874,123079,'117467','deals','style_class','account-order-history-info',0,''),(389041,123138,'117507','deals','block_type','1',0,''),(389042,123138,'117507','deals','style_class','account-order-pay',0,''),(389043,123139,'117508','deals','block_type','6',0,''),(389044,123139,'117508','deals','schema','6-3',0,'5639'),(389045,123140,'117509','deals','aria_name','account-menu',0,''),(389109,123161,'117511','deals','block_type','3',0,''),(389110,123162,'117512','deals','block_type','1',0,''),(389111,123162,'117512','deals','padding-right','20',0,''),(389112,123162,'117512','deals','padding-bottom','20',0,''),(389113,123163,'117513','deals','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(389114,123164,'117514','deals','orders_data','name',0,''),(389115,123164,'117514','deals','padding-left','30',0,''),(389116,123165,'117515','deals','block_type','1',0,''),(389117,123166,'117516','deals','padding-left','30',0,''),(389118,123167,'117517','deals','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(389119,123168,'117518','deals','block_type','1',0,''),(389120,123168,'117518','deals','padding-right','20',0,''),(389121,123168,'117518','deals','padding-bottom','20',0,''),(389122,123169,'117519','deals','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(389123,123170,'117520','deals','orders_data','delivery_address',0,''),(389124,123170,'117520','deals','padding-left','30',0,''),(389125,123171,'117521','deals','block_type','1',0,''),(389126,123171,'117521','deals','padding-right','20',0,''),(389127,123172,'117522','deals','orders_data','shipping_method',0,''),(389128,123172,'117522','deals','padding-left','30',0,''),(389129,123173,'117523','deals','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(389130,123174,'117524','deals','block_type','1',0,''),(389131,123175,'117525','deals','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(389132,123176,'117526','deals','orders_data','payment_method',0,''),(389133,123176,'117526','deals','padding-left','30',0,''),(389134,123177,'117527','deals','block_type','1',0,''),(389135,123177,'117527','deals','padding-bottom','20',0,''),(389136,123178,'117528','deals','orders_data','billing_address',0,''),(389137,123178,'117528','deals','padding-left','30',0,''),(389138,123179,'117529','deals','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(389139,123180,'117530','deals','margin-bottom','20',0,''),(389140,123180,'117530','deals','orders_data','name',0,''),(389141,123181,'117531','deals','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(389142,123184,'117534','deals','width','680',0,''),(389143,123184,'117534','deals','font-weight','400',0,''),(389144,123184,'117534','deals','font-size','12',0,''),(389145,123184,'117534','deals','padding-top','20',0,''),(389146,123184,'117534','deals','padding-bottom','20',0,''),(389147,123185,'117535','deals','block_type','2',0,''),(389148,123185,'117535','deals','font-weight','normal',0,''),(389149,123185,'117535','deals','padding-bottom','20',0,''),(389150,123186,'117536','deals','font-weight','400',0,''),(389151,123186,'117536','deals','padding-top','10',0,''),(389152,123186,'117536','deals','logo','themes/deals/img/logo-2.png',1,''),(389153,123186,'117536','deals','logo','themes/deals/img/logo-2.png',2,''),(389154,123186,'117536','deals','logo','themes/deals/img/logo-2.png',3,''),(389155,123186,'117536','deals','logo','themes/deals/img/logo-2.png',4,''),(389156,123187,'117537','deals','block_type','11',0,''),(389157,123187,'117537','deals','font-weight','normal',0,''),(389158,123188,'117538','deals','text','<p>Email:</p>',1,''),(389159,123188,'117538','deals','font-weight','normal',0,''),(389160,123188,'117538','deals','text-align','right',0,''),(389161,123188,'117538','deals','text','<p>Email:</p>',2,''),(389162,123188,'117538','deals','text','<p>Email:</p>',3,''),(389163,123188,'117538','deals','text','<p>Email:</p>',4,''),(389164,123189,'117539','deals','font-weight','normal',0,''),(389165,123189,'117539','deals','text-align','right',0,''),(389166,123190,'117540','deals','block_type','11',0,''),(389167,123190,'117540','deals','font-weight','normal',0,''),(389168,123191,'117541','deals','text','<p>Phone:</p>',1,''),(389169,123191,'117541','deals','font-weight','normal',0,''),(389170,123191,'117541','deals','text-align','right',0,''),(389171,123191,'117541','deals','text','<p>Phone:</p>',2,''),(389172,123191,'117541','deals','text','<p>Phone:</p>',3,''),(389173,123191,'117541','deals','text','<p>Phone:</p>',4,''),(389174,123192,'117542','deals','font-weight','normal',0,''),(389175,123192,'117542','deals','text-align','right',0,''),(389176,123193,'117543','deals','block_type','1',0,''),(389177,123194,'117544','deals','font-weight','400',0,''),(389178,123194,'117544','deals','text-align','right',0,''),(389179,123194,'117544','deals','padding-bottom','10',0,''),(389180,123194,'117544','deals','address_spacer',',',0,''),(389181,123194,'117544','deals','font-size','12',0,''),(389182,123195,'117545','deals','block_type','11',0,''),(389183,123195,'117545','deals','font-weight','400',0,''),(389184,123196,'117546','deals','text','<p>Web:</p>',1,''),(389185,123196,'117546','deals','font-weight','400',0,''),(389186,123196,'117546','deals','text-align','right',0,''),(389187,123196,'117546','deals','text','<p>Web:</p>',2,''),(389188,123196,'117546','deals','text','<p>Web:</p>',3,''),(389189,123196,'117546','deals','text','<p>Web:</p>',4,''),(389190,123197,'117547','deals','font-weight','normal',0,''),(389191,123197,'117547','deals','text-align','right',0,''),(389192,123198,'117548','deals','font-weight','normal',0,''),(389193,123198,'117548','deals','padding-top','20',0,''),(389194,123198,'117548','deals','font-size','12',0,''),(389195,123199,'117549','deals','block_type','1',0,''),(389196,123199,'117549','deals','font-weight','normal',0,''),(389197,123199,'117549','deals','padding-top','10',0,''),(389198,123199,'117549','deals','padding-bottom','10',0,''),(389199,123201,'117551','deals','text','<p>If undelivered please return to:</p>',1,''),(389200,123201,'117551','deals','font-weight','bold',0,''),(389201,123201,'117551','deals','text','<p>If undelivered please return to:</p>',2,''),(389202,123201,'117551','deals','text','<p>If undelivered please return to:</p>',3,''),(389203,123201,'117551','deals','text','<p>If undelivered please return to:</p>',4,''),(389204,123202,'117552','deals','block_type','4',0,''),(389205,123202,'117552','deals','font-weight','400',0,''),(389206,123202,'117552','deals','border-top-width','1',0,''),(389207,123202,'117552','deals','border-top-color','$content-border-1',0,''),(389208,123202,'117552','deals','border-left-width','1',0,''),(389209,123202,'117552','deals','border-left-color','$content-border-1',0,''),(389210,123202,'117552','deals','border-right-width','1',0,''),(389211,123202,'117552','deals','border-right-color','$content-border-1',0,''),(389212,123202,'117552','deals','border-bottom-width','1',0,''),(389213,123202,'117552','deals','border-bottom-color','$content-border-1',0,''),(389214,123203,'117553','deals','block_type','2',0,''),(389215,123203,'117553','deals','font-weight','normal',0,''),(389216,123203,'117553','deals','border-right-width','1',0,''),(389217,123203,'117553','deals','border-right-color','$content-border-1',0,''),(389218,123204,'117554','deals','block_type','1',0,''),(389219,123204,'117554','deals','font-weight','normal',0,''),(389220,123204,'117554','deals','border-right-width','1',0,''),(389221,123204,'117554','deals','border-right-color','$content-border-1',0,''),(389222,123204,'117554','deals','background-color','$content-bg-2',0,''),(389223,123204,'117554','deals','padding-top','10',0,''),(389224,123204,'117554','deals','padding-left','10',0,''),(389225,123204,'117554','deals','padding-right','10',0,''),(389226,123204,'117554','deals','padding-bottom','10',0,''),(389227,123205,'117555','deals','font-size','12',0,''),(389228,123205,'117555','deals','font-weight','normal',0,''),(389229,123206,'117556','deals','text','<p>SHIPPING ADDRESS:</p>',1,''),(389230,123206,'117556','deals','font-size','13',0,''),(389231,123206,'117556','deals','font-weight','bold',0,''),(389232,123206,'117556','deals','padding-bottom','10',0,''),(389233,123206,'117556','deals','text','<p>SHIPPING ADDRESS:</p>',2,''),(389234,123206,'117556','deals','text','<p>SHIPPING ADDRESS:</p>',3,''),(389235,123206,'117556','deals','text','<p>SHIPPING ADDRESS:</p>',4,''),(389236,123207,'117557','deals','block_type','1',0,''),(389237,123207,'117557','deals','font-weight','normal',0,''),(389238,123207,'117557','deals','padding-top','10',0,''),(389239,123207,'117557','deals','padding-left','10',0,''),(389240,123207,'117557','deals','padding-right','10',0,''),(389241,123207,'117557','deals','padding-bottom','10',0,''),(389242,123208,'117558','deals','text','<p>CUSTOMER:</p>',1,''),(389243,123208,'117558','deals','font-size','13',0,''),(389244,123208,'117558','deals','font-weight','bold',0,''),(389245,123208,'117558','deals','text','<p>CUSTOMER:</p>',2,''),(389246,123208,'117558','deals','text','<p>CUSTOMER:</p>',3,''),(389247,123208,'117558','deals','text','<p>CUSTOMER:</p>',4,''),(389248,123209,'117559','deals','font-size','12',0,''),(389249,123211,'117561','deals','text','<p>PHONE NUMBER:</p>',1,''),(389250,123211,'117561','deals','font-size','13',0,''),(389251,123211,'117561','deals','font-weight','bold',0,''),(389252,123211,'117561','deals','padding-top','10',0,''),(389253,123211,'117561','deals','text','<p>PHONE NUMBER:</p>',2,''),(389254,123211,'117561','deals','text','<p>PHONE NUMBER:</p>',3,''),(389255,123211,'117561','deals','text','<p>PHONE NUMBER:</p>',4,''),(389256,123212,'117562','deals','font-size','12',0,''),(389257,123213,'117563','deals','text','<p>E-MAIL ADDRESS:</p>',1,''),(389258,123213,'117563','deals','font-size','13',0,''),(389259,123213,'117563','deals','font-weight','bold',0,''),(389260,123213,'117563','deals','padding-top','10',0,''),(389261,123213,'117563','deals','text','<p>E-MAIL ADDRESS:</p>',2,''),(389262,123213,'117563','deals','text','<p>E-MAIL ADDRESS:</p>',3,''),(389263,123213,'117563','deals','text','<p>E-MAIL ADDRESS:</p>',4,''),(389264,123214,'117564','deals','block_type','2',0,''),(389265,123214,'117564','deals','font-weight','normal',0,''),(389266,123214,'117564','deals','border-right-width','1',0,''),(389267,123214,'117564','deals','border-right-color','$content-border-1',0,''),(389268,123214,'117564','deals','border-top-width','1',0,''),(389269,123214,'117564','deals','border-top-color','$content-border-1',0,''),(389270,123215,'117565','deals','block_type','1',0,''),(389271,123215,'117565','deals','font-weight','normal',0,''),(389272,123215,'117565','deals','padding-top','10',0,''),(389273,123215,'117565','deals','padding-left','10',0,''),(389274,123215,'117565','deals','padding-right','10',0,''),(389275,123215,'117565','deals','padding-bottom','10',0,''),(389276,123215,'117565','deals','border-right-width','1',0,''),(389277,123215,'117565','deals','border-right-color','$content-border-1',0,''),(389278,123217,'117567','deals','text','<p>Shipping via</p>',1,''),(389279,123217,'117567','deals','font-weight','bold',0,''),(389280,123217,'117567','deals','text','<p>Shipping via</p>',2,''),(389281,123217,'117567','deals','text','<p>Shipping via</p>',3,''),(389282,123217,'117567','deals','text','<p>Shipping via</p>',4,''),(389283,123218,'117568','deals','block_type','1',0,''),(389284,123218,'117568','deals','font-weight','normal',0,''),(389285,123218,'117568','deals','padding-top','10',0,''),(389286,123218,'117568','deals','padding-left','10',0,''),(389287,123218,'117568','deals','padding-right','10',0,''),(389288,123218,'117568','deals','padding-bottom','10',0,''),(389289,123220,'117570','deals','text','<p>Shipping service</p>',1,''),(389290,123220,'117570','deals','font-weight','bold',0,''),(389291,123220,'117570','deals','text','<p>Shipping service</p>',2,''),(389292,123220,'117570','deals','text','<p>Shipping service</p>',3,''),(389293,123220,'117570','deals','text','<p>Shipping service</p>',4,''),(389294,123221,'117571','deals','font-weight','normal',0,''),(389295,123221,'117571','deals','text-align','center',0,''),(389296,123221,'117571','deals','padding-top','40',0,''),(389297,123223,'1639661081','deals','padding-top','15',0,''),(389298,123224,'117572','deals','block_type','1',0,''),(389299,123225,'117573','deals','block_type','8',0,''),(389300,123226,'1638807246','deals','text','<span></span>',0,''),(389301,123227,'117574','deals','text','##TEXT_MAIN##',0,''),(389302,123227,'117574','deals','margin-bottom','20',0,''),(389303,123227,'117574','deals','text-align','center',0,''),(389304,123228,'117575','deals','margin-bottom','20',0,''),(389305,123229,'117576','deals','text','<h1>##HEADING_TITLE##</h1>',0,''),(389306,123231,'117578','deals','block_type','2',0,''),(389307,123232,'117579','deals','block_type','1',0,''),(389308,123232,'117579','deals','style_class','product',0,''),(389309,123232,'117579','deals','padding-right','10',0,''),(389310,123232,'117579','deals','padding-bottom','20',0,''),(389311,123233,'117580','deals','block_type','1',0,''),(389312,123234,'117581','deals','product_element','products_name',0,''),(389313,123234,'117581','deals','font-family','$font-1',0,''),(389314,123234,'117581','deals','padding-bottom','10',0,''),(389315,123234,'117581','deals','font-size','16',0,''),(389316,123235,'117582','deals','block_type','2',0,''),(389317,123236,'117583','deals','product_element','image',0,''),(389318,123236,'117583','deals','padding-right','10',0,''),(389319,123237,'117584','deals','product_element','products_price_old',0,''),(389320,123237,'117584','deals','font-family','$font-1',0,''),(389321,123237,'117584','deals','font-size','14',0,''),(389322,123237,'117584','deals','text-decoration','line-through',0,''),(389323,123238,'117585','deals','product_element','products_price',0,''),(389324,123238,'117585','deals','font-family','$font-1',0,''),(389325,123238,'117585','deals','font-size','20',0,''),(389326,123238,'117585','deals','padding-top','20',0,''),(389327,123239,'117586','deals','block_type','1',0,''),(389328,123239,'117586','deals','style_class','product',0,''),(389329,123239,'117586','deals','padding-left','10',0,''),(389330,123239,'117586','deals','padding-bottom','20',0,''),(389331,123240,'117587','deals','block_type','2',0,''),(389332,123241,'117588','deals','product_element','image',0,''),(389333,123241,'117588','deals','padding-right','10',0,''),(389334,123242,'117589','deals','font-size','14',0,''),(389335,123242,'117589','deals','font-family','$font-1',0,''),(389336,123242,'117589','deals','text-decoration','line-through',0,''),(389337,123242,'117589','deals','product_element','products_price_old',0,''),(389338,123243,'117590','deals','product_element','products_price',0,''),(389339,123243,'117590','deals','font-family','$font-1',0,''),(389340,123243,'117590','deals','font-size','20',0,''),(389341,123243,'117590','deals','padding-top','20',0,''),(389342,123244,'117591','deals','block_type','1',0,''),(389343,123245,'117592','deals','product_element','products_name',0,''),(389344,123245,'117592','deals','font-family','$font-1',0,''),(389345,123245,'117592','deals','font-size','16',0,''),(389346,123245,'117592','deals','padding-bottom','10',0,''),(389347,123246,'117593','deals','font-size','30',0,''),(389348,123246,'117593','deals','font-family','$font-1',0,''),(389349,123246,'117593','deals','text-align','center',0,''),(389350,123246,'117593','deals','padding-bottom','50',0,''),(389351,123247,'117594','deals','padding-bottom','20',0,''),(389352,123247,'117594','deals','text-align','center',0,''),(389353,123248,'117595','deals','width','680',0,''),(389354,123249,'117596','deals','padding-top','200',0,''),(389355,123249,'117596','deals','padding-left','200',0,''),(389356,123249,'117596','deals','logo','themes/deals/img/oscommerce_logo.jpg',1,''),(389357,123249,'117596','deals','logo','themes/deals/img/oscommerce_logo.jpg',2,''),(389358,123249,'117596','deals','logo','themes/deals/img/oscommerce_logo.jpg',3,''),(389359,123249,'117596','deals','logo','themes/deals/img/oscommerce_logo.jpg',4,''),(389360,123250,'117597','deals','text','osCommerce 4',1,''),(389361,123250,'117597','deals','font-family','$font-1',0,''),(389362,123250,'117597','deals','font-size','40',0,''),(389363,123250,'117597','deals','padding-top','50',0,''),(389364,123250,'117597','deals','text-align','center',0,''),(389365,123250,'117597','deals','text','osCommerce 4',2,''),(389366,123250,'117597','deals','text','osCommerce 4',3,''),(389367,123250,'117597','deals','text','osCommerce 4',4,''),(389368,123251,'117598','deals','block_type','2',0,''),(389369,123251,'117598','deals','border-top-width','1',0,''),(389370,123251,'117598','deals','border-top-color','$content-border-1',0,''),(389371,123252,'117599','deals','text-align','right',0,''),(389372,123252,'117599','deals','padding-top','15',0,''),(389373,123252,'117599','deals','padding-bottom','15',0,''),(389374,123252,'117599','deals','font-size','14',0,''),(389375,123253,'117600','deals','font-family','$font-1',0,''),(389376,123253,'117600','deals','text-align','center',0,''),(389377,123253,'117600','deals','font-size','20',0,''),(389378,123253,'117600','deals','color','$content-color-1',0,''),(389379,123253,'117600','deals','border-bottom-width','1',0,''),(389380,123253,'117600','deals','border-bottom-color','$content-border-1',0,''),(389381,123253,'117600','deals','padding-top','10',0,''),(389382,123253,'117600','deals','padding-bottom','10',0,''),(389383,123254,'117601','deals','block_type','1',0,''),(389384,123255,'117602','deals','block_type','6',0,''),(389385,123255,'117602','deals','schema','6-3',0,'5639'),(389386,123256,'117603','deals','aria_name','account-menu',0,''),(389450,123276,'117604','deals','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(389451,123277,'117606','deals','max_items','10',0,''),(389452,123277,'117606','deals','padding-bottom','20',0,''),(389453,123278,'117607','deals','block_type','1',0,''),(389454,123278,'117607','deals','padding-top','20',0,''),(389455,123278,'117607','deals','padding-left','20',0,''),(389456,123278,'117607','deals','padding-right','20',0,''),(389457,123278,'117607','deals','padding-bottom','20',0,''),(389458,123279,'117608','deals','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(389459,123281,'117610','deals','block_type','1',0,''),(389460,123282,'117611','deals','margin_left_measure','auto',0,''),(389461,123282,'117611','deals','margin_right_measure','auto',0,''),(389462,123282,'117611','deals','max-width','560',0,''),(389463,123283,'117612','deals','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(389464,123284,'117613','deals','margin-bottom','30',0,''),(389465,123285,'1683114469.26259','deals','block_type','1',0,''),(389466,123286,'1683114469.295895','deals','font-weight','400',0,''),(389467,123287,'1683114469.29722','deals','block_type','11',0,''),(389468,123287,'1683114469.29722','deals','padding-bottom','30',0,''),(389469,123287,'1683114469.29722','deals','schema','11-2',0,'5630'),(389470,123287,'1683114469.29722','deals','padding-bottom','20',0,'5639'),(389471,123288,'1683114469.299773','deals','font-weight','400',0,''),(389472,123288,'1683114469.299773','deals','padding-top','20',0,''),(389473,123288,'1683114469.299773','deals','padding-right','20',0,''),(389474,123288,'1683114469.299773','deals','box_align','4',0,''),(389475,123288,'1683114469.299773','deals','margin-bottom','50',0,''),(389476,123288,'1683114469.299773','deals','align_position','horizontal',0,''),(389477,123289,'1683114469.301198','deals','float','left',0,''),(389478,123291,'1683114469.30314','deals','block_type','2',0,''),(389479,123292,'1683114469.304286','deals','margin-bottom','10',0,''),(389480,123293,'1683114469.304862','deals','reviews_count','right',0,''),(389481,123293,'1683114469.304862','deals','padding-bottom','15',0,''),(389482,123294,'1683114469.306253','deals','text-align','right',0,''),(389483,123295,'1683114469.307492','deals','text-align','right',0,''),(389484,123296,'1683114469.3081','deals','block_type','2',0,''),(389485,123296,'1683114469.3081','deals','schema','2-2',0,'5660'),(389486,123297,'1683114469.309625','deals','padding-right','20',0,''),(389487,123297,'1683114469.309625','deals','margin-bottom','20',0,''),(389488,123297,'1683114469.309625','deals','padding-right','0',0,'5660'),(389489,123298,'1683114469.310518','deals','text','&nbsp;',0,''),(389490,123299,'1683114469.31285','deals','padding-right','20',0,''),(389491,123299,'1683114469.31285','deals','padding-right','0',0,'5660'),(389492,123300,'1683114469.313585','deals','margin-bottom','20',0,''),(389493,123300,'1683114469.313585','deals','max-width','500',0,''),(389494,123300,'1683114469.313585','deals','padding-right','20',0,''),(389495,123300,'1683114469.313585','deals','padding-right','0',0,'5660'),(389496,123301,'1683114469.319743','deals','padding-right','20',0,''),(389497,123301,'1683114469.319743','deals','padding-right','0',0,'5660'),(389498,123302,'1683114469.328177','deals','padding-right','20',0,''),(389499,123302,'1683114469.328177','deals','padding-right','0',0,'5660'),(389500,123302,'1683114469.328177','deals','padding-bottom','15',0,''),(389501,123303,'1683114469.329314','deals','padding-right','20',0,''),(389502,123303,'1683114469.329314','deals','padding-right','0',0,'5660'),(389503,123303,'1683114469.329314','deals','padding-bottom','15',0,'5660'),(389504,123304,'1683114469.33265','deals','block_type','1',0,''),(389505,123304,'1683114469.33265','deals','float','right',0,''),(389506,123304,'1683114469.33265','deals','float','none',0,'5660'),(389507,123305,'1683114469.333690','deals','font-weight','400',0,''),(389508,123305,'1683114469.333690','deals','line_height_measure','px',0,''),(389509,123305,'1683114469.333690','deals','text-align','right',0,''),(389510,123305,'1683114469.333690','deals','float','right',0,''),(389511,123306,'1683114469.334771','deals','box_align','2',0,''),(389512,123306,'1683114469.334771','deals','margin-bottom','15',0,'5639'),(389513,123306,'1683114469.334771','deals','text-align','right',0,'5639'),(389514,123306,'1683114469.334771','deals','text-align','center',0,''),(389515,123306,'1683114469.334771','deals','float','right',0,''),(389516,123306,'1683114469.334771','deals','padding-right','10',0,''),(389517,123306,'1683114469.334771','deals','float','left',0,'5660'),(389518,123306,'1683114469.334771','deals','text-align','left',0,'5660'),(389519,123307,'1683114469.34343','deals','text-align','right',0,''),(389520,123307,'1683114469.34343','deals','width','100',0,'5630'),(389521,123307,'1683114469.34343','deals','width_measure','%',0,'5630'),(389522,123307,'1683114469.34343','deals','float','none',0,'5630'),(389523,123307,'1683114469.34343','deals','margin-bottom','15',0,''),(389524,123307,'1683114469.34343','deals','padding-top','10',0,''),(389525,123307,'1683114469.34343','deals','clear','both',0,''),(389526,123308,'1683114469.347391','deals','text-align','right',0,''),(389527,123308,'1683114469.347391','deals','margin-bottom','15',0,''),(389528,123309,'1683114469.351242','deals','cat_description','1',0,''),(389529,123309,'1683114469.351242','deals','link_description','1',0,''),(389530,123309,'1683114469.351242','deals','length_description','300',0,''),(389531,123309,'1683114469.351242','deals','margin-bottom','20',0,''),(389532,123310,'1683114493.817723','deals','block_type','1',0,''),(389533,123310,'1683114493.817723','deals','padding-top','25',0,''),(389534,123310,'1683114493.817723','deals','padding-bottom','25',0,''),(389535,123310,'1683114493.817723','deals','padding-top','0',0,'5639'),(389536,123310,'1683114493.817723','deals','style_class','catalog-product-wrap',0,''),(389537,123311,'1683114493.851867','deals','hTagsInline','block',0,''),(389538,123311,'1683114493.851867','deals','padding-bottom','30',0,''),(389539,123312,'1683114493.853236','deals','padding-bottom','10',0,''),(389540,123312,'1683114493.853236','deals','padding-top','5',0,''),(389541,123313,'1683114493.85674','deals','block_type','1',0,''),(389542,123314,'1683114493.857344','deals','font-weight','400',0,''),(389543,123314,'1683114493.857344','deals','padding-bottom','20',0,''),(389544,123314,'1683114493.857344','deals','show_compare','1',0,''),(389545,123314,'1683114493.857344','deals','show_name','0',0,''),(389546,123314,'1683114493.857344','deals','show_image','0',0,''),(389547,123314,'1683114493.857344','deals','show_stock','0',0,''),(389548,123314,'1683114493.857344','deals','show_description','0',0,''),(389549,123314,'1683114493.857344','deals','show_model','1',0,''),(389550,123314,'1683114493.857344','deals','show_properties','1',0,''),(389551,123314,'1683114493.857344','deals','show_rating','0',0,''),(389552,123314,'1683114493.857344','deals','show_rating_counts','0',0,''),(389553,123314,'1683114493.857344','deals','show_price','0',0,''),(389554,123314,'1683114493.857344','deals','show_buy_button','1',0,''),(389555,123314,'1683114493.857344','deals','show_view_button','1',0,''),(389556,123314,'1683114493.857344','deals','show_wishlist_button','1',0,''),(389557,123314,'1683114493.857344','deals','listing_type','productListing',0,''),(389558,123314,'1683114493.857344','deals','col_in_row','2',0,'5639'),(389559,123314,'1683114493.857344','deals','col_in_row','1',0,'5660'),(389560,123314,'1683114493.857344','deals','col_in_row','4',0,''),(389561,123314,'1683114493.857344','deals','view_as','carousel',0,''),(389562,123314,'1683114493.857344','deals','show_bonus_points','1',0,''),(389563,123314,'1683114493.857344','deals','show_qty_input','1',0,''),(389564,123314,'1683114493.857344','deals','show_attributes','1',0,''),(389565,123314,'1683114493.857344','deals','hide_parents','2',0,''),(389566,123315,'1683114493.861475','deals','text','<h2>##VIEWED_PRODUCTS##</h2>',0,''),(389567,123316,'1683114493.86940','deals','block_type','1',0,''),(389568,123316,'1683114493.86940','deals','margin-bottom','30',0,''),(389569,123329,'120919.000001','deals','block_type','1',0,''),(389570,123329,'120919.000001','deals','style_class','item-holder',0,''),(389571,123329,'120919.000001','deals','padding-top','25',0,''),(389572,123329,'120919.000001','deals','padding-left','25',0,''),(389573,123329,'120919.000001','deals','padding-right','25',0,''),(389574,123329,'120919.000001','deals','padding-bottom','25',0,''),(389575,123332,'117668','deals','description_characters','90',0,''),(389576,123335,'117673.000001','deals','margin-bottom','7',0,''),(389577,123336,'117675.000001','deals','clear','both',0,''),(389578,123337,'117676.000001','deals','margin-bottom','10',0,''),(389579,123346,'117678','deals','block_type','1',0,''),(389580,123346,'117678','deals','padding-bottom','30',0,''),(389581,123347,'117683','deals','block_type','1',0,''),(389582,123347,'117683','deals','padding-top','10',0,''),(389583,123347,'117683','deals','padding-bottom','10',0,''),(389584,123347,'117683','deals','border-bottom-width','1',0,''),(389585,123347,'117683','deals','border-bottom-color','$content-border-1',0,''),(389586,123347,'117683','deals','margin-left','0',0,''),(389587,123347,'117683','deals','margin-right','0',0,''),(389588,123348,'117685','deals','float','right',0,''),(389589,123348,'117685','deals','display','none',0,'5660'),(389590,123349,'117687','deals','margin-right','20',0,''),(389591,123349,'117687','deals','float','right',0,''),(389592,123349,'117687','deals','clear','none',0,''),(389593,123349,'117687','deals','display','none',0,'5639'),(389594,123350,'117691','deals','col_in_row','5',0,''),(389595,123350,'117691','deals','products_align','left',0,''),(389596,123350,'117691','deals','font-weight','400',0,''),(389597,123350,'117691','deals','listing_type','productListing',0,''),(389598,123350,'117691','deals','listing_type_rows','Rows',0,''),(389599,123350,'117691','deals','show_buy_button_b2b','on',0,''),(389600,123350,'117691','deals','show_wishlist_button_b2b','1',0,''),(389601,123350,'117691','deals','show_compare_b2b','1',0,''),(389602,123350,'117691','deals','show_image','0',0,''),(389603,123350,'117691','deals','show_price','0',0,''),(389604,123350,'117691','deals','show_view_button','0',0,''),(389605,123350,'117691','deals','show_name_rows','0',0,''),(389606,123350,'117691','deals','show_image_rows','0',0,''),(389607,123350,'117691','deals','show_stock_rows','0',0,''),(389608,123350,'117691','deals','show_description_rows','0',0,''),(389609,123350,'117691','deals','show_model_rows','0',0,''),(389610,123350,'117691','deals','show_properties_rows','0',0,''),(389611,123350,'117691','deals','show_rating_rows','0',0,''),(389612,123350,'117691','deals','show_rating_counts_rows','0',0,''),(389613,123350,'117691','deals','show_price_rows','0',0,''),(389614,123350,'117691','deals','show_buy_button_rows','0',0,''),(389615,123350,'117691','deals','show_qty_input_rows','0',0,''),(389616,123350,'117691','deals','show_view_button_rows','0',0,''),(389617,123350,'117691','deals','show_wishlist_button_rows','0',0,''),(389618,123350,'117691','deals','show_compare_rows','0',0,''),(389619,123350,'117691','deals','show_name_b2b','0',0,''),(389620,123350,'117691','deals','show_image_b2b','0',0,''),(389621,123350,'117691','deals','show_stock_b2b','0',0,''),(389622,123350,'117691','deals','show_description_b2b','0',0,''),(389623,123350,'117691','deals','show_model_b2b','0',0,''),(389624,123350,'117691','deals','show_properties_b2b','0',0,''),(389625,123350,'117691','deals','show_rating_b2b','0',0,''),(389626,123350,'117691','deals','show_rating_counts_b2b','0',0,''),(389627,123350,'117691','deals','show_price_b2b','0',0,''),(389628,123350,'117691','deals','show_qty_input_b2b','0',0,''),(389629,123350,'117691','deals','show_view_button_b2b','0',0,''),(389630,123350,'117691','deals','show_attributes_b2b','0',0,''),(389631,123350,'117691','deals','items_on_page','10',0,''),(389632,123350,'117691','deals','col_in_row','3',0,'5639'),(389633,123350,'117691','deals','col_in_row','1',0,'5660'),(389634,123350,'117691','deals','product_names_teg','h2',0,''),(389635,123350,'117691','deals','padding-top','20',0,''),(389636,123350,'117691','deals','padding-bottom','20',0,''),(389637,123350,'117691','deals','col_in_row','4',0,'5644'),(389638,123350,'117691','deals','col_in_row','2',0,'5630'),(389639,123351,'120912','deals','block_type','5',0,''),(389640,123351,'120912','deals','padding-top','10',0,''),(389641,123351,'120912','deals','schema','5-2',0,'5660'),(389642,123352,'120913','deals','padding-top','3',0,''),(389643,123353,'120914','deals','float','right',0,''),(389644,123353,'120914','deals','height','31',0,''),(389645,123354,'117692','deals','show_heading','h1',0,''),(389646,123355,'117693','deals','block_type','1',0,''),(389647,123356,'117694','deals','margin-bottom','20',0,''),(389648,123357,'1641894402','deals','block_type','1',0,''),(389649,123358,'1641809968.0001','deals','block_type','1',0,''),(389650,123358,'1641809968.0001','deals','style_class','filterLine',0,''),(389651,123359,'116286.000001','deals','float','left',0,''),(389652,123359,'116286.000001','deals','clear','none',0,''),(389653,123359,'116286.000001','deals','sort_pos_3','2',0,''),(389654,123359,'116286.000001','deals','sort_pos_4','3',0,''),(389655,123359,'116286.000001','deals','sort_pos_10','11',0,''),(389656,123359,'116286.000001','deals','sort_pos_9','10',0,''),(389657,123359,'116286.000001','deals','sort_pos_11','12',0,''),(389658,123359,'116286.000001','deals','sort_pos_12','13',0,''),(389659,123359,'116286.000001','deals','sort_pos_14','15',0,''),(389660,123359,'116286.000001','deals','sort_pos_13','14',0,''),(389661,123359,'116286.000001','deals','sort_pos_8','4',0,''),(389662,123359,'116286.000001','deals','sort_pos_7','5',0,''),(389663,123359,'116286.000001','deals','sort_pos_2','7',0,''),(389664,123359,'116286.000001','deals','sort_pos_1','6',0,''),(389665,123359,'116286.000001','deals','sort_pos_6','9',0,''),(389666,123359,'116286.000001','deals','sort_pos_5','8',0,''),(389667,123359,'116286.000001','deals','sort_pos_0','1',0,''),(389668,123359,'116286.000001','deals','sort_hide_10','1',0,''),(389669,123359,'116286.000001','deals','sort_hide_9','1',0,''),(389670,123359,'116286.000001','deals','hide_icons','1',0,''),(389671,123359,'116286.000001','deals','sort_hide_16','1',0,''),(389672,123359,'116286.000001','deals','sort_hide_15','1',0,''),(389673,123359,'116286.000001','deals','sort_hide_3','0',0,''),(389674,123359,'116286.000001','deals','sort_hide_4','0',0,''),(389675,123359,'116286.000001','deals','sort_hide_11','1',0,''),(389676,123359,'116286.000001','deals','sort_hide_12','1',0,''),(389677,123359,'116286.000001','deals','sort_hide_14','1',0,''),(389678,123359,'116286.000001','deals','sort_hide_13','1',0,''),(389679,123359,'116286.000001','deals','sort_hide_8','0',0,''),(389680,123359,'116286.000001','deals','sort_hide_7','0',0,''),(389681,123359,'116286.000001','deals','sort_hide_2','1',0,''),(389682,123359,'116286.000001','deals','sort_hide_1','1',0,''),(389683,123359,'116286.000001','deals','sort_hide_6','1',0,''),(389684,123359,'116286.000001','deals','sort_hide_5','1',0,''),(389685,123359,'116286.000001','deals','sort_hide_0','0',0,''),(389686,123359,'116286.000001','deals','sort_pos_15','16',0,''),(389687,123359,'116286.000001','deals','sort_pos_16','17',0,''),(389688,123360,'1641810239.0001','deals','align_position','horizontal',0,''),(389689,123360,'1641810239.0001','deals','open_filter','closed',0,''),(389690,123363,'117696','deals','block_type','1',0,''),(389691,123365,'117698','deals','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(389692,123366,'117699','deals','width','680',0,''),(389693,123366,'117699','deals','font-weight','normal',0,''),(389694,123366,'117699','deals','font-size','12',0,''),(389695,123366,'117699','deals','padding-top','20',0,''),(389696,123366,'117699','deals','padding-bottom','20',0,''),(389697,123366,'117699','deals','color','$content-color-1',0,''),(389698,123367,'117700','deals','font-weight','400',0,''),(389699,123367,'117700','deals','padding-top','20',0,''),(389700,123367,'117700','deals','padding-bottom','0',0,''),(389701,123367,'117700','deals','font-size','12',0,''),(389702,123368,'117701','deals','block_type','3',0,''),(389703,123368,'117701','deals','font-weight','normal',0,''),(389704,123368,'117701','deals','padding-top','20',0,''),(389705,123369,'117702','deals','text','<p>If undelivered please return to:</p>',1,''),(389706,123369,'117702','deals','font-size','12',0,''),(389707,123369,'117702','deals','font-weight','bold',0,''),(389708,123369,'117702','deals','text','<p>If undelivered please return to:</p>',2,''),(389709,123369,'117702','deals','text','<p>If undelivered please return to:</p>',3,''),(389710,123369,'117702','deals','text','<p>If undelivered please return to:</p>',4,''),(389711,123370,'117703','deals','font-size','12',0,''),(389712,123371,'117704','deals','text','<p>Thank you for your order</p>',1,''),(389713,123371,'117704','deals','color','$hileght-color-1',0,''),(389714,123371,'117704','deals','font-size','13',0,''),(389715,123371,'117704','deals','font-weight','bold',0,''),(389716,123371,'117704','deals','padding-top','5',0,''),(389717,123371,'117704','deals','text-align','center',0,''),(389718,123371,'117704','deals','text','<p>Thank you for your order</p>',2,''),(389719,123371,'117704','deals','text','<p>Thank you for your order</p>',3,''),(389720,123371,'117704','deals','text','<p>Thank you for your order</p>',4,''),(389721,123372,'117705','deals','font-weight','400',0,''),(389722,123372,'117705','deals','text-align','center',0,''),(389723,123372,'117705','deals','padding-top','0',0,''),(389725,123372,'117705','deals','padding-left','20',0,''),(389726,123372,'117705','deals','padding-right','20',0,''),(389730,123373,'117706','deals','block_type','6',0,''),(389731,123373,'117706','deals','font-weight','normal',0,''),(389732,123373,'117706','deals','font-size','16',0,''),(389733,123374,'117707','deals','text','<p>Email:</p>',1,''),(389734,123374,'117707','deals','font-weight','normal',0,''),(389735,123374,'117707','deals','text-align','right',0,''),(389736,123374,'117707','deals','font-size','12',0,''),(389737,123374,'117707','deals','text','<p>Email:</p>',2,''),(389738,123374,'117707','deals','text','<p>Email:</p>',3,''),(389739,123374,'117707','deals','text','<p>Email:</p>',4,''),(389740,123375,'117708','deals','font-weight','normal',0,''),(389741,123375,'117708','deals','text-align','right',0,''),(389742,123375,'117708','deals','font-size','12',0,''),(389743,123376,'117709','deals','text','<p>If something has gone wrong please contact us at:</p>',1,''),(389744,123376,'117709','deals','font-size','12',0,''),(389745,123376,'117709','deals','font-weight','bold',0,''),(389746,123376,'117709','deals','text-align','right',0,''),(389747,123376,'117709','deals','text','<p>If something has gone wrong please contact us at:</p>',2,''),(389748,123376,'117709','deals','text','<p>If something has gone wrong please contact us at:</p>',3,''),(389749,123376,'117709','deals','text','<p>If something has gone wrong please contact us at:</p>',4,''),(389750,123377,'117710','deals','block_type','6',0,''),(389751,123377,'117710','deals','font-weight','normal',0,''),(389752,123377,'117710','deals','font-size','16',0,''),(389753,123378,'117711','deals','text','<p>Phone:</p>',1,''),(389754,123378,'117711','deals','font-weight','normal',0,''),(389755,123378,'117711','deals','text-align','right',0,''),(389756,123378,'117711','deals','font-size','12',0,''),(389757,123378,'117711','deals','text','<p>Phone:</p>',2,''),(389758,123378,'117711','deals','text','<p>Phone:</p>',3,''),(389759,123378,'117711','deals','text','<p>Phone:</p>',4,''),(389760,123379,'117712','deals','font-weight','normal',0,''),(389761,123379,'117712','deals','text-align','right',0,''),(389762,123379,'117712','deals','font-size','12',0,''),(389763,123380,'117713','deals','block_type','2',0,''),(389764,123380,'117713','deals','font-weight','normal',0,''),(389765,123380,'117713','deals','padding-bottom','20',0,''),(389766,123381,'117714','deals','font-weight','400',0,''),(389767,123381,'117714','deals','padding-top','20',0,''),(389772,123382,'117715','deals','block_type','11',0,''),(389773,123382,'117715','deals','font-weight','normal',0,''),(389774,123383,'117716','deals','text','<p>Phone:</p>',1,''),(389775,123383,'117716','deals','font-weight','normal',0,''),(389776,123383,'117716','deals','text-align','right',0,''),(389777,123383,'117716','deals','text','<p>Phone:</p>',2,''),(389778,123383,'117716','deals','text','<p>Phone:</p>',3,''),(389779,123383,'117716','deals','text','<p>Phone:</p>',4,''),(389780,123384,'117717','deals','font-weight','normal',0,''),(389781,123384,'117717','deals','text-align','right',0,''),(389782,123385,'117718','deals','block_type','11',0,''),(389783,123385,'117718','deals','font-weight','normal',0,''),(389784,123386,'117719','deals','text','<p>Web:</p>',1,''),(389785,123386,'117719','deals','font-weight','normal',0,''),(389786,123386,'117719','deals','text-align','right',0,''),(389787,123386,'117719','deals','text','<p>Web:</p>',2,''),(389788,123386,'117719','deals','text','<p>Web:</p>',3,''),(389789,123386,'117719','deals','text','<p>Web:</p>',4,''),(389790,123387,'117720','deals','font-weight','normal',0,''),(389791,123387,'117720','deals','text-align','right',0,''),(389792,123388,'117721','deals','block_type','1',0,''),(389793,123389,'117722','deals','font-weight','normal',0,''),(389794,123389,'117722','deals','text-align','right',0,''),(389795,123389,'117722','deals','padding-bottom','10',0,''),(389796,123389,'117722','deals','address_spacer',',',0,''),(389797,123389,'117722','deals','font-size','12',0,''),(389798,123390,'117723','deals','block_type','11',0,''),(389799,123390,'117723','deals','font-weight','normal',0,''),(389800,123391,'117724','deals','text','<p>Email:</p>',1,''),(389801,123391,'117724','deals','font-weight','normal',0,''),(389802,123391,'117724','deals','text-align','right',0,''),(389803,123391,'117724','deals','text','<p>Email:</p>',2,''),(389804,123391,'117724','deals','text','<p>Email:</p>',3,''),(389805,123391,'117724','deals','text','<p>Email:</p>',4,''),(389806,123392,'117725','deals','font-weight','normal',0,''),(389807,123392,'117725','deals','text-align','right',0,''),(389808,123393,'117726','deals','block_type','4',0,''),(389809,123393,'117726','deals','font-weight','normal',0,''),(389810,123393,'117726','deals','border-top-width','1',0,''),(389811,123393,'117726','deals','border-top-color','$content-border-1',0,''),(389812,123393,'117726','deals','border-left-width','1',0,''),(389813,123393,'117726','deals','border-left-color','$content-border-1',0,''),(389814,123393,'117726','deals','border-right-width','1',0,''),(389815,123393,'117726','deals','border-right-color','$content-border-1',0,''),(389816,123393,'117726','deals','border-bottom-width','1',0,''),(389817,123393,'117726','deals','border-bottom-color','$content-border-1',0,''),(389818,123394,'117727','deals','block_type','2',0,''),(389819,123394,'117727','deals','font-weight','normal',0,''),(389820,123394,'117727','deals','border-right-width','1',0,''),(389821,123394,'117727','deals','border-right-color','$content-border-1',0,''),(389822,123395,'117728','deals','block_type','1',0,''),(389823,123395,'117728','deals','font-weight','400',0,''),(389824,123395,'117728','deals','background-color','$content-bg-2',0,''),(389825,123395,'117728','deals','padding-top','10',0,''),(389826,123395,'117728','deals','padding-left','10',0,''),(389827,123395,'117728','deals','padding-right','10',0,''),(389828,123395,'117728','deals','padding-bottom','30',0,''),(389829,123396,'117729','deals','font-size','12',0,''),(389830,123397,'117730','deals','text','<p>ADDRESS:</p>\n',1,''),(389831,123397,'117730','deals','font-size','14',0,''),(389832,123397,'117730','deals','font-weight','bold',0,''),(389833,123397,'117730','deals','text','<p>ADDRESS:</p>\n',2,''),(389834,123397,'117730','deals','text','<p>ADDRESS:</p>\n',3,''),(389835,123397,'117730','deals','text','<p>ADDRESS:</p>\n',4,''),(389836,123398,'117731','deals','block_type','1',0,''),(389837,123398,'117731','deals','font-weight','normal',0,''),(389838,123398,'117731','deals','padding-top','10',0,''),(389839,123398,'117731','deals','padding-left','10',0,''),(389840,123398,'117731','deals','padding-right','10',0,''),(389841,123398,'117731','deals','padding-bottom','10',0,''),(389842,123400,'117733','deals','text','<p>E-MAIL ADDRESS:</p>',1,''),(389843,123400,'117733','deals','font-weight','bold',0,''),(389844,123400,'117733','deals','font-size','14',0,''),(389845,123400,'117733','deals','padding-top','10',0,''),(389846,123400,'117733','deals','text','<p>E-MAIL ADDRESS:</p>',2,''),(389847,123400,'117733','deals','text','<p>E-MAIL ADDRESS:</p>',3,''),(389848,123400,'117733','deals','text','<p>E-MAIL ADDRESS:</p>',4,''),(389849,123401,'117734','deals','font-weight','normal',0,''),(389850,123402,'117735','deals','font-weight','normal',0,''),(389851,123403,'117736','deals','text','<p>PHONE NUMBER:</p>',1,''),(389852,123403,'117736','deals','font-size','14',0,''),(389853,123403,'117736','deals','font-weight','bold',0,''),(389854,123403,'117736','deals','padding-top','10',0,''),(389855,123403,'117736','deals','text','<p>PHONE NUMBER:</p>',2,''),(389856,123403,'117736','deals','text','<p>PHONE NUMBER:</p>',3,''),(389857,123403,'117736','deals','text','<p>PHONE NUMBER:</p>',4,''),(389858,123404,'117737','deals','text','<p>CUSTOMER:</p>',1,''),(389859,123404,'117737','deals','font-size','13',0,''),(389860,123404,'117737','deals','font-weight','bold',0,''),(389861,123404,'117737','deals','text','<p>CUSTOMER:</p>',2,''),(389862,123404,'117737','deals','text','<p>CUSTOMER:</p>',3,''),(389863,123404,'117737','deals','text','<p>CUSTOMER:</p>',4,''),(389864,123405,'117738','deals','font-size','14',0,''),(389865,123405,'117738','deals','font-weight','bold',0,''),(389866,123405,'117738','deals','text-align','center',0,''),(389867,123405,'117738','deals','padding-bottom','10',0,''),(389868,123405,'117738','deals','padding-top','10',0,''),(389869,123406,'117739','deals','text','<p>Order date:</p>\n',1,''),(389870,123406,'117739','deals','font-weight','bold',0,''),(389871,123406,'117739','deals','text-align','center',0,''),(389872,123406,'117739','deals','font-size','12',0,''),(389873,123406,'117739','deals','text','<p>Order date:</p>\n',2,''),(389874,123406,'117739','deals','text','<p>Order date:</p>\n',3,''),(389875,123406,'117739','deals','text','<p>Order date:</p>\n',4,''),(389876,123407,'117740','deals','font-weight','normal',0,''),(389877,123407,'117740','deals','text-align','center',0,''),(389878,123407,'117740','deals','padding-bottom','10',0,''),(389879,123408,'117741','deals','block_type','5',0,''),(389880,123408,'117741','deals','font-weight','normal',0,''),(389881,123408,'117741','deals','border-bottom-width','1',0,''),(389882,123408,'117741','deals','border-bottom-color','$content-border-1',0,''),(389883,123408,'117741','deals','border-top-width','1',0,''),(389884,123408,'117741','deals','border-top-color','$content-border-1',0,''),(389885,123408,'117741','deals','border-left-color','$content-border-1',0,''),(389886,123408,'117741','deals','border-left-width','1',0,''),(389887,123409,'117742','deals','block_type','1',0,''),(389888,123409,'117742','deals','font-weight','normal',0,''),(389889,123409,'117742','deals','padding-top','10',0,''),(389890,123409,'117742','deals','padding-left','10',0,''),(389891,123409,'117742','deals','padding-right','10',0,''),(389892,123410,'117743','deals','font-weight','400',0,''),(389893,123410,'117743','deals','line-height','120',0,''),(389894,123410,'117743','deals','line_height_measure','%',0,''),(389895,123410,'117743','deals','font-size','12',0,''),(389896,123411,'117744','deals','text','<p>SHIPPING ADDRESS:</p>',1,''),(389897,123411,'117744','deals','font-size','14',0,''),(389898,123411,'117744','deals','font-weight','bold',0,''),(389899,123411,'117744','deals','padding-bottom','10',0,''),(389900,123411,'117744','deals','text','<p>SHIPPING ADDRESS:</p>',2,''),(389901,123411,'117744','deals','text','<p>SHIPPING ADDRESS:</p>',3,''),(389902,123411,'117744','deals','text','<p>SHIPPING ADDRESS:</p>',4,''),(389905,123415,'117745','deals','block_type','1',0,''),(389906,123416,'117746','deals','block_type','6',0,''),(389907,123416,'117746','deals','schema','6-3',0,'5639'),(389908,123417,'117747','deals','aria_name','account-menu',0,''),(389972,123437,'117748','deals','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(389973,123438,'117749','deals','link','Quotation Info',0,''),(389974,123438,'117749','deals','margin-bottom','20',0,''),(389975,123439,'117750','deals','block_type','1',0,''),(389976,123440,'117751','deals','block_type','6',0,''),(389977,123440,'117751','deals','schema','6-3',0,'5639'),(389978,123441,'117752','deals','aria_name','account-menu',0,''),(390042,123461,'117753','deals','block_type','3',0,''),(390043,123462,'117754','deals','block_type','1',0,''),(390044,123462,'117754','deals','padding-right','20',0,''),(390045,123462,'117754','deals','padding-bottom','20',0,''),(390046,123463,'117755','deals','orders_data','name',0,''),(390047,123464,'117756','deals','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(390048,123465,'117757','deals','block_type','1',0,''),(390049,123465,'117757','deals','padding-right','20',0,''),(390050,123465,'117757','deals','padding-bottom','20',0,''),(390051,123466,'117758','deals','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(390052,123467,'117759','deals','orders_data','telephone',0,''),(390053,123468,'117760','deals','block_type','1',0,''),(390054,123468,'117760','deals','padding-right','20',0,''),(390055,123469,'117761','deals','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(390056,123470,'117762','deals','orders_data','shipping_method',0,''),(390057,123471,'117763','deals','block_type','1',0,''),(390058,123471,'117763','deals','padding-right','20',0,''),(390059,123471,'117763','deals','padding-bottom','20',0,''),(390060,123472,'117764','deals','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(390061,123473,'117765','deals','orders_data','delivery_address',0,''),(390062,123474,'117766','deals','block_type','1',0,''),(390063,123474,'117766','deals','padding-bottom','20',0,''),(390064,123475,'117767','deals','orders_data','billing_address',0,''),(390065,123476,'117768','deals','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(390066,123477,'117769','deals','block_type','1',0,''),(390067,123478,'117770','deals','orders_data','payment_method',0,''),(390068,123479,'117771','deals','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(390069,123480,'117772','deals','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(390070,123482,'117774','deals','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(390071,123485,'117777','deals','block_type','2',0,''),(390072,123485,'117777','deals','padding-top','20',0,''),(390073,123485,'117777','deals','margin-bottom','20',0,''),(390074,123486,'117778','deals','like_button','1',0,''),(390075,123486,'117778','deals','text','IMAGE_BUTTON_BACK',0,''),(390076,123486,'117778','deals','link','Quotations',0,''),(390077,123487,'117779','deals','text','<h1>##HEADING_TITLE##</h1>',0,''),(390078,123488,'117780','deals','padding-top','20',0,''),(390079,123488,'117780','deals','padding-bottom','20',0,''),(390080,123488,'117780','deals','block_type','1',0,''),(390081,123490,'117782','deals','block_type','4',0,''),(390082,123490,'117782','deals','schema','4-2',0,'5639'),(390083,123490,'117782','deals','schema','4-2',0,'5630'),(390084,123491,'117783','deals','background-color','$content-bg-1',0,''),(390085,123492,'117784','deals','block_type','1',0,''),(390086,123492,'117784','deals','style_class','order-summary',0,''),(390087,123492,'117784','deals','margin-left','30',0,''),(390088,123492,'117784','deals','margin-left','0',0,'5639'),(390089,123493,'117785','deals','block_type','1',0,''),(390090,123493,'117785','deals','padding-left','20',0,''),(390091,123493,'117785','deals','padding-right','20',0,''),(390092,123493,'117785','deals','padding-bottom','30',0,''),(390093,123494,'117786','deals','max-width','300',0,'5639'),(390094,123494,'117786','deals','margin_left_measure','auto',0,'5639'),(390095,123494,'117786','deals','margin_right_measure','auto',0,'5639'),(390096,123494,'117786','deals','margin-bottom','0',0,''),(390097,123496,'117788','deals','block_type','1',0,''),(390166,123520,'117793','deals','block_type','1',0,''),(390167,123522,'117795','deals','pagination','bottom',0,''),(390168,123523,'117796','deals','width','800',0,''),(390169,123524,'117797','deals','block_type','11',0,''),(390170,123524,'117797','deals','border-top-width','1',0,''),(390171,123524,'117797','deals','border-left-width','1',0,''),(390172,123524,'117797','deals','border-right-width','1',0,''),(390173,123524,'117797','deals','border-bottom-width','1',0,''),(390174,123524,'117797','deals','border-top-color','$highlight-box-border-1',0,''),(390175,123524,'117797','deals','border-left-color','$highlight-box-border-1',0,''),(390176,123524,'117797','deals','border-right-color','$highlight-box-border-1',0,''),(390177,123524,'117797','deals','border-bottom-color','$highlight-box-border-1',0,''),(390178,123525,'117798','deals','block_type','1',0,''),(390179,123525,'117798','deals','border-right-width','1',0,''),(390180,123525,'117798','deals','border-right-color','$highlight-box-border-1',0,''),(390181,123525,'117798','deals','padding-top','10',0,''),(390182,123525,'117798','deals','padding-right','10',0,''),(390183,123525,'117798','deals','padding-bottom','10',0,''),(390184,123526,'117799','deals','block_type','9',0,''),(390185,123527,'117800','deals','text','1.',0,''),(390186,123527,'117800','deals','font-size','12',0,''),(390187,123527,'117800','deals','text-align','right',0,''),(390188,123527,'117800','deals','padding-right','5',0,''),(390189,123528,'117801','deals','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(390190,123528,'117801','deals','font-size','12',0,''),(390191,123528,'117801','deals','padding-bottom','5',0,''),(390192,123529,'117802','deals','block_type','9',0,''),(390193,123530,'117803','deals','text','4.',0,''),(390194,123530,'117803','deals','font-size','12',0,''),(390195,123530,'117803','deals','text-align','right',0,''),(390196,123530,'117803','deals','margin-right','5',0,''),(390197,123531,'117804','deals','text','Our Replacement Department will process your request.',0,''),(390198,123531,'117804','deals','font-size','12',0,''),(390199,123531,'117804','deals','padding-bottom','5',0,''),(390200,123532,'117805','deals','block_type','9',0,''),(390201,123533,'117806','deals','text','3.',0,''),(390202,123533,'117806','deals','font-size','12',0,''),(390203,123533,'117806','deals','text-align','right',0,''),(390204,123533,'117806','deals','margin-right','5',0,''),(390205,123534,'117807','deals','text','Return the authorized item(s) per shipping instructions.',0,''),(390206,123534,'117807','deals','font-size','12',0,''),(390207,123534,'117807','deals','padding-bottom','5',0,''),(390208,123535,'117808','deals','block_type','9',0,''),(390209,123536,'117809','deals','text','2.',0,''),(390210,123536,'117809','deals','font-size','12',0,''),(390211,123536,'117809','deals','text-align','right',0,''),(390212,123536,'117809','deals','margin-right','5',0,''),(390213,123537,'117810','deals','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(390214,123537,'117810','deals','font-size','12',0,''),(390215,123537,'117810','deals','padding-bottom','5',0,''),(390216,123538,'117811','deals','block_type','1',0,''),(390217,123538,'117811','deals','padding-left','15',0,''),(390218,123539,'117812','deals','text','Replacement Policy:',0,''),(390219,123539,'117812','deals','font-size','14',0,''),(390220,123539,'117812','deals','padding-bottom','5',0,''),(390221,123539,'117812','deals','font-weight','bold',0,''),(390222,123540,'117813','deals','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(390223,123540,'117813','deals','font-size','11',0,''),(390224,123540,'117813','deals','font-style','italic',0,''),(390225,123540,'117813','deals','padding-bottom','5',0,''),(390226,123541,'117814','deals','block_type','1',0,''),(390227,123541,'117814','deals','border-bottom-width','1',0,''),(390228,123541,'117814','deals','border-bottom-color','$highlight-box-border-1',0,''),(390229,123542,'117815','deals','text','Return Material Authorization (RMA) Form',0,''),(390230,123542,'117815','deals','text-align','center',0,''),(390231,123542,'117815','deals','font-size','16',0,''),(390232,123542,'117815','deals','font-weight','bold',0,''),(390233,123543,'117816','deals','text-align','center',0,''),(390234,123543,'117816','deals','logo','themes/deals/img/logo-2.png',1,''),(390235,123543,'117816','deals','padding-top','10',0,''),(390236,123543,'117816','deals','padding-bottom','10',0,''),(390237,123543,'117816','deals','logo','themes/deals/img/logo-2.png',2,''),(390238,123543,'117816','deals','logo','themes/deals/img/logo-2.png',3,''),(390239,123543,'117816','deals','logo','themes/deals/img/logo-2.png',4,''),(390240,123544,'117817','deals','block_type','1',0,''),(390241,123544,'117817','deals','padding-top','10',0,''),(390242,123544,'117817','deals','padding-left','10',0,''),(390243,123544,'117817','deals','padding-right','10',0,''),(390244,123544,'117817','deals','padding-bottom','20',0,''),(390245,123545,'117818','deals','block_type','2',0,''),(390246,123545,'117818','deals','padding-top','5',0,''),(390247,123546,'117819','deals','block_type','11',0,''),(390248,123547,'117820','deals','text','Email:',0,''),(390249,123547,'117820','deals','font-size','12',0,''),(390250,123548,'117821','deals','data','rrDelivery_email_address',0,''),(390251,123548,'117821','deals','font-size','12',0,''),(390252,123549,'117822','deals','block_type','11',0,''),(390253,123550,'117823','deals','text','Phone:',0,''),(390254,123550,'117823','deals','font-size','12',0,''),(390255,123551,'117824','deals','data','rrDelivery_telephone',0,''),(390256,123551,'117824','deals','font-size','12',0,''),(390257,123552,'117825','deals','block_type','2',0,''),(390258,123552,'117825','deals','padding-top','5',0,''),(390259,123553,'117826','deals','block_type','11',0,''),(390260,123554,'117827','deals','text','Country:',0,''),(390261,123554,'117827','deals','font-size','12',0,''),(390262,123555,'117828','deals','data','rrDelivery_country',0,''),(390263,123555,'117828','deals','font-size','12',0,''),(390264,123556,'117829','deals','block_type','11',0,''),(390265,123557,'117830','deals','text','Postcode:',0,''),(390266,123557,'117830','deals','font-size','12',0,''),(390267,123558,'117831','deals','data','rrDelivery_postcode',0,''),(390268,123558,'117831','deals','font-size','12',0,''),(390269,123559,'117832','deals','block_type','2',0,''),(390270,123559,'117832','deals','padding-top','5',0,''),(390271,123560,'117833','deals','block_type','11',0,''),(390272,123561,'117834','deals','text','City:',0,''),(390273,123561,'117834','deals','font-size','12',0,''),(390274,123562,'117835','deals','data','rrDelivery_city',0,''),(390275,123562,'117835','deals','font-size','12',0,''),(390276,123563,'117836','deals','block_type','11',0,''),(390277,123564,'117837','deals','text','State:',0,''),(390278,123564,'117837','deals','font-size','12',0,''),(390279,123565,'117838','deals','data','rrDelivery_state',0,''),(390280,123565,'117838','deals','font-size','12',0,''),(390281,123566,'117839','deals','block_type','9',0,''),(390282,123566,'117839','deals','padding-top','5',0,''),(390283,123567,'117840','deals','text','Address:',0,''),(390284,123567,'117840','deals','font-size','12',0,''),(390285,123568,'117841','deals','data','rrDelivery_street_address',0,''),(390286,123568,'117841','deals','font-size','12',0,''),(390287,123569,'117842','deals','block_type','2',0,''),(390288,123570,'117843','deals','block_type','11',0,''),(390289,123571,'117844','deals','text','Company:',0,''),(390290,123571,'117844','deals','font-size','12',0,''),(390291,123572,'117845','deals','data','rrDelivery_company',0,''),(390292,123572,'117845','deals','font-size','12',0,''),(390293,123573,'117846','deals','block_type','2',0,''),(390294,123574,'117847','deals','text','Contact Name:',0,''),(390295,123574,'117847','deals','font-size','12',0,''),(390296,123575,'117848','deals','data','rrDelivery_name',0,''),(390297,123575,'117848','deals','font-size','12',0,''),(390298,123576,'117849','deals','block_type','2',0,''),(390299,123576,'117849','deals','padding-left','10',0,''),(390300,123576,'117849','deals','padding-top','20',0,''),(390301,123576,'117849','deals','padding-right','10',0,''),(390302,123577,'117850','deals','block_type','5',0,''),(390303,123578,'117851','deals','text','RMA No:',0,''),(390304,123578,'117851','deals','font-size','12',0,''),(390305,123578,'117851','deals','font-weight','bold',0,''),(390306,123579,'117852','deals','data','rrNumber',0,''),(390307,123579,'117852','deals','font-size','12',0,''),(390308,123579,'117852','deals','font-weight','bold',0,''),(390309,123580,'117853','deals','block_type','2',0,''),(390310,123581,'117854','deals','text','Date Issued:',0,''),(390311,123581,'117854','deals','font-size','12',0,''),(390312,123581,'117854','deals','font-weight','bold',0,''),(390313,123582,'117855','deals','data','rrDateCreate',0,''),(390314,123582,'117855','deals','font-size','12',0,''),(390315,123582,'117855','deals','font-weight','bold',0,''),(390316,123583,'117856','deals','block_type','1',0,''),(390317,123584,'117857','deals','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(390318,123584,'117857','deals','font-size','12',0,''),(390319,123584,'117857','deals','font-style','italic',0,''),(390320,123584,'117857','deals','padding-bottom','20',0,''),(390321,123586,'117859','deals','block_type','1',0,''),(390322,123586,'117859','deals','border-top-width','1',0,''),(390323,123586,'117859','deals','border-left-width','1',0,''),(390324,123586,'117859','deals','border-right-width','1',0,''),(390325,123586,'117859','deals','border-bottom-width','1',0,''),(390326,123586,'117859','deals','border-top-color','$highlight-box-border-1',0,''),(390327,123586,'117859','deals','border-left-color','$highlight-box-border-1',0,''),(390328,123586,'117859','deals','border-right-color','$highlight-box-border-1',0,''),(390329,123586,'117859','deals','border-bottom-color','$highlight-box-border-1',0,''),(390330,123587,'117860','deals','block_type','11',0,''),(390331,123588,'117861','deals','block_type','1',0,''),(390332,123588,'117861','deals','padding-top','10',0,''),(390333,123588,'117861','deals','padding-right','10',0,''),(390334,123588,'117861','deals','padding-bottom','10',0,''),(390335,123588,'117861','deals','border-right-width','1',0,''),(390336,123588,'117861','deals','border-right-color','$highlight-box-border-1',0,''),(390337,123589,'117862','deals','block_type','9',0,''),(390338,123590,'117863','deals','text','4.',0,''),(390339,123590,'117863','deals','font-size','12',0,''),(390340,123590,'117863','deals','text-align','right',0,''),(390341,123590,'117863','deals','padding-right','5',0,''),(390342,123591,'117864','deals','font-size','11',0,''),(390343,123591,'117864','deals','font-style','italic',0,''),(390344,123591,'117864','deals','padding-bottom','5',0,''),(390345,123592,'117865','deals','text','Ship returned items to:',0,''),(390346,123592,'117865','deals','font-size','12',0,''),(390347,123592,'117865','deals','padding-bottom','5',0,''),(390348,123593,'117866','deals','block_type','9',0,''),(390349,123594,'117867','deals','text','3.',0,''),(390350,123594,'117867','deals','font-size','12',0,''),(390351,123594,'117867','deals','text-align','right',0,''),(390352,123594,'117867','deals','padding-right','5',0,''),(390353,123595,'117868','deals','text','Ship only the items that are authorized.',0,''),(390354,123595,'117868','deals','font-size','12',0,''),(390355,123595,'117868','deals','padding-bottom','10',0,''),(390356,123596,'117869','deals','block_type','9',0,''),(390357,123597,'117870','deals','text','1.',0,''),(390358,123597,'117870','deals','font-size','12',0,''),(390359,123597,'117870','deals','text-align','right',0,''),(390360,123597,'117870','deals','padding-right','5',0,''),(390361,123598,'117871','deals','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(390362,123598,'117871','deals','font-size','12',0,''),(390363,123598,'117871','deals','padding-bottom','10',0,''),(390364,123599,'117872','deals','block_type','1',0,''),(390365,123600,'117873','deals','text','Shipping Instructions:',0,''),(390366,123600,'117873','deals','font-weight','bold',0,''),(390367,123600,'117873','deals','font-size','14',0,''),(390368,123600,'117873','deals','padding-bottom','5',0,''),(390369,123600,'117873','deals','padding-left','10',0,''),(390370,123601,'117874','deals','block_type','9',0,''),(390371,123602,'117875','deals','text','2.',0,''),(390372,123602,'117875','deals','font-size','12',0,''),(390373,123602,'117875','deals','text-align','right',0,''),(390374,123602,'117875','deals','padding-right','5',0,''),(390375,123603,'117876','deals','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(390376,123603,'117876','deals','font-size','12',0,''),(390377,123603,'117876','deals','padding-bottom','10',0,''),(390378,123604,'117877','deals','block_type','1',0,''),(390379,123604,'117877','deals','padding-left','10',0,''),(390380,123604,'117877','deals','padding-right','10',0,''),(390381,123604,'117877','deals','padding-bottom','10',0,''),(390382,123605,'117878','deals','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(390383,123605,'117878','deals','font-size','11',0,''),(390384,123605,'117878','deals','font-style','italic',0,''),(390385,123606,'117879','deals','block_type','1',0,''),(390386,123606,'117879','deals','padding-top','10',0,''),(390387,123606,'117879','deals','padding-left','40',0,''),(390388,123606,'117879','deals','padding-right','40',0,''),(390389,123606,'117879','deals','padding-bottom','10',0,''),(390390,123607,'117880','deals','block_type','1',0,''),(390391,123607,'117880','deals','padding-top','10',0,''),(390392,123607,'117880','deals','padding-left','10',0,''),(390393,123607,'117880','deals','padding-right','10',0,''),(390394,123607,'117880','deals','padding-bottom','10',0,''),(390395,123607,'117880','deals','border-top-width','1',0,''),(390396,123607,'117880','deals','border-left-width','1',0,''),(390397,123607,'117880','deals','border-right-width','1',0,''),(390398,123607,'117880','deals','border-bottom-width','1',0,''),(390399,123607,'117880','deals','border-top-color','$highlight-box-border-1',0,''),(390400,123607,'117880','deals','border-left-color','$highlight-box-border-1',0,''),(390401,123607,'117880','deals','border-right-color','$highlight-box-border-1',0,''),(390402,123607,'117880','deals','border-bottom-color','$highlight-box-border-1',0,''),(390403,123608,'117881','deals','block_type','3',0,''),(390404,123609,'117882','deals','data','rrDelivery_name',0,''),(390405,123609,'117882','deals','font-size','9',0,''),(390406,123610,'117883','deals','block_type','2',0,''),(390407,123611,'117884','deals','text','RMA#:',0,''),(390408,123611,'117884','deals','font-size','10',0,''),(390409,123612,'117885','deals','data','rrNumber',0,''),(390410,123612,'117885','deals','font-size','9',0,''),(390411,123613,'117886','deals','block_type','5',0,''),(390412,123614,'117887','deals','font-size','9',0,''),(390413,123615,'117888','deals','block_type','1',0,''),(390414,123615,'117888','deals','padding-left','10',0,''),(390415,123615,'117888','deals','padding-right','10',0,''),(390416,123615,'117888','deals','padding-bottom','10',0,''),(390417,123616,'117889','deals','text','Use this space for additional Comments:',0,''),(390418,123616,'117889','deals','font-size','11',0,''),(390419,123616,'117889','deals','font-style','italic',0,''),(390420,123617,'117890','deals','text','&nbsp;',0,''),(390421,123617,'117890','deals','border-bottom-width','1',0,''),(390422,123617,'117890','deals','border-bottom-color','$highlight-box-border-1',0,''),(390423,123618,'117891','deals','text','&nbsp;',0,''),(390424,123618,'117891','deals','border-bottom-width','1',0,''),(390425,123618,'117891','deals','border-bottom-color','$highlight-box-border-1',0,''),(390426,123618,'117891','deals','padding-top','5',0,''),(390427,123619,'117892','deals','text','&nbsp;',0,''),(390428,123619,'117892','deals','border-bottom-width','1',0,''),(390429,123619,'117892','deals','border-bottom-color','$highlight-box-border-1',0,''),(390430,123619,'117892','deals','padding-top','5',0,''),(390431,123620,'117893','deals','text','&nbsp;',0,''),(390432,123620,'117893','deals','border-bottom-width','1',0,''),(390433,123620,'117893','deals','border-bottom-color','$highlight-box-border-1',0,''),(390434,123620,'117893','deals','padding-top','5',0,''),(390435,123621,'117894','deals','block_type','3',0,''),(390436,123621,'117894','deals','padding-top','10',0,''),(390437,123621,'117894','deals','padding-bottom','10',0,''),(390438,123621,'117894','deals','padding-right','10',0,''),(390439,123622,'117895','deals','font-size','11',0,''),(390440,123622,'117895','deals','font-weight','bold',0,''),(390441,123622,'117895','deals','text','Return Approval:',0,''),(390442,123622,'117895','deals','padding-top','5',0,''),(390443,123622,'117895','deals','padding-left','10',0,''),(390444,123623,'117896','deals','border-bottom-width','1',0,''),(390445,123623,'117896','deals','border-bottom-color','$highlight-box-border-1',0,''),(390446,123623,'117896','deals','text','&nbsp;',0,''),(390447,123624,'117897','deals','block_type','5',0,''),(390448,123625,'117898','deals','text','Date:',0,''),(390449,123625,'117898','deals','padding-top','5',0,''),(390450,123625,'117898','deals','font-size','11',0,''),(390451,123625,'117898','deals','font-weight','bold',0,''),(390452,123625,'117898','deals','padding-left','5',0,''),(390453,123626,'117899','deals','text','&nbsp;',0,''),(390454,123626,'117899','deals','border-bottom-width','1',0,''),(390455,123626,'117899','deals','border-bottom-color','$highlight-box-border-1',0,''),(390456,123627,'117900','deals','block_type','3',0,''),(390457,123627,'117900','deals','padding-right','10',0,''),(390458,123628,'117901','deals','text','Customer Signature:',0,''),(390459,123628,'117901','deals','font-weight','bold',0,''),(390460,123628,'117901','deals','font-size','11',0,''),(390461,123628,'117901','deals','padding-top','5',0,''),(390462,123628,'117901','deals','padding-left','10',0,''),(390463,123629,'117902','deals','text','&nbsp;',0,''),(390464,123629,'117902','deals','border-bottom-width','1',0,''),(390465,123629,'117902','deals','border-bottom-color','$highlight-box-border-1',0,''),(390466,123630,'117903','deals','block_type','5',0,''),(390467,123631,'117904','deals','text','Date:',0,''),(390468,123631,'117904','deals','padding-top','5',0,''),(390469,123631,'117904','deals','font-size','11',0,''),(390470,123631,'117904','deals','font-weight','bold',0,''),(390471,123631,'117904','deals','padding-left','5',0,''),(390472,123632,'117905','deals','text','&nbsp;',0,''),(390473,123632,'117905','deals','border-bottom-width','1',0,''),(390474,123632,'117905','deals','border-bottom-color','$highlight-box-border-1',0,''),(390475,123633,'117906.000001','deals','block_type','1',0,''),(390476,123633,'117906.000001','deals','style_class','item-holder',0,''),(390477,123633,'117906.000001','deals','padding-top','25',0,''),(390478,123633,'117906.000001','deals','padding-bottom','25',0,''),(390479,123633,'117906.000001','deals','text-align','left',0,''),(390480,123633,'117906.000001','deals','border-top-width','1',0,''),(390481,123633,'117906.000001','deals','border-top-color','$content-border-1',0,''),(390482,123634,'117907.000001','deals','block_type','7',0,''),(390483,123634,'117907.000001','deals','schema','7-2',0,'5639'),(390484,123635,'117908.000001','deals','block_type','5',0,''),(390485,123635,'117908.000001','deals','schema','5-2',0,'5639'),(390486,123636,'117909.000001','deals','clear','none',0,''),(390487,123636,'117909.000001','deals','padding-right','20',0,''),(390488,123637,'117910.000001','deals','padding-right','20',0,''),(390489,123637,'117910.000001','deals','max-width','300',0,'5639'),(390490,123637,'117910.000001','deals','margin_left_measure','auto',0,'5639'),(390491,123637,'117910.000001','deals','margin_right_measure','auto',0,'5639'),(390492,123638,'117914.000001','deals','padding-right','20',0,''),(390493,123639,'117915.000001','deals','description_characters','200',0,''),(390494,123639,'117915.000001','deals','clear','none',0,''),(390495,123639,'117915.000001','deals','padding-right','20',0,''),(390496,123640,'117916.000001','deals','clear','none',0,''),(390497,123641,'117917.000001','deals','margin-bottom','20',0,''),(390498,123644,'117918.000001','deals','block_type','1',0,''),(390499,123644,'117918.000001','deals','padding-left','40',0,''),(390500,123644,'117918.000001','deals','style_class','right-aria',0,''),(390501,123644,'117918.000001','deals','padding-left','0',0,'5639'),(390502,123645,'117911.000001','deals','block_type','1',0,''),(390503,123645,'117911.000001','deals','text-align','center',0,''),(390504,123646,'117912.000001','deals','margin-top','4',0,''),(390505,123646,'117912.000001','deals','margin-bottom','7',0,''),(390506,123647,'117913.000001','deals','padding-top','6',0,''),(390507,123647,'117913.000001','deals','padding-left','5',0,''),(390508,123648,'117919.000001','deals','margin-bottom','15',0,''),(390509,123648,'117919.000001','deals','text-align','right',0,''),(390510,123649,'117920.000001','deals','margin-bottom','10',0,''),(390511,123649,'117920.000001','deals','text-align','center',0,''),(390512,123650,'117922.000001','deals','text-align','right',0,''),(390513,123650,'117922.000001','deals','margin-bottom','15',0,''),(390514,123651,'117924.000001','deals','text-align','center',0,''),(390515,123651,'117924.000001','deals','margin-bottom','10',0,''),(390516,123652,'120924.000001','deals','block_type','1',0,''),(390517,123652,'120924.000001','deals','style_class','item-nav',0,''),(390518,123656,'117925','deals','block_type','1',0,''),(390519,123656,'117925','deals','padding-top','20',0,''),(390520,123656,'117925','deals','padding-bottom','20',0,''),(390521,123658,'117927','deals','block_type','7',0,''),(390522,123658,'117927','deals','schema','4-2',0,'5639'),(390523,123659,'117928','deals','padding-bottom','20',0,''),(390524,123659,'117928','deals','background-color','$content-bg-1',0,''),(390525,123660,'117929','deals','style_class','order-summary',0,''),(390526,123660,'117929','deals','padding-left','25',0,''),(390527,123660,'117929','deals','block_type','1',0,''),(390528,123660,'117929','deals','padding-left','0',0,'5639'),(390529,123660,'117929','deals','margin-top','30',0,'5639'),(390530,123661,'117930','deals','block_type','1',0,''),(390531,123661,'117930','deals','padding-left','20',0,''),(390532,123661,'117930','deals','padding-right','20',0,''),(390533,123661,'117930','deals','padding-bottom','20',0,''),(390534,123661,'117930','deals','padding-top','20',0,''),(390535,123662,'117931','deals','max-width','300',0,'5639'),(390536,123662,'117931','deals','margin_left_measure','auto',0,'5639'),(390537,123662,'117931','deals','margin_right_measure','auto',0,'5639'),(390538,123663,'117932','deals','block_type','1',0,''),(390539,123663,'117932','deals','style_class','account-samples',0,''),(390540,123664,'117933','deals','block_type','6',0,''),(390541,123664,'117933','deals','schema','6-3',0,'5639'),(390542,123665,'117934','deals','aria_name','account-menu',0,''),(390606,123685,'117935','deals','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(390607,123686,'117936','deals','show_pagenation','1',0,''),(390608,123686,'117936','deals','link','Sample Info',0,''),(390609,123686,'117936','deals','margin-bottom','20',0,''),(390610,123687,'117937','deals','block_type','1',0,''),(390611,123687,'117937','deals','style_class','account-sample-info',0,''),(390612,123688,'117938','deals','block_type','6',0,''),(390613,123688,'117938','deals','schema','6-3',0,'5639'),(390614,123689,'117939','deals','aria_name','account-menu',0,''),(390678,123709,'117940','deals','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(390679,123710,'117941','deals','block_type','2',0,''),(390680,123710,'117941','deals','padding-top','20',0,''),(390681,123710,'117941','deals','margin-bottom','20',0,''),(390682,123711,'117942','deals','like_button','1',0,''),(390683,123711,'117942','deals','text','IMAGE_BUTTON_BACK',0,''),(390684,123711,'117942','deals','link','Samples',0,''),(390685,123713,'117944','deals','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(390686,123716,'117947','deals','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(390687,123717,'117948','deals','block_type','3',0,''),(390688,123718,'117949','deals','block_type','1',0,''),(390689,123718,'117949','deals','padding-right','20',0,''),(390690,123718,'117949','deals','padding-bottom','20',0,''),(390691,123719,'117950','deals','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(390692,123720,'117951','deals','orders_data','telephone',0,''),(390693,123721,'117952','deals','block_type','1',0,''),(390694,123721,'117952','deals','padding-right','20',0,''),(390695,123721,'117952','deals','padding-bottom','20',0,''),(390696,123722,'117953','deals','orders_data','name',0,''),(390697,123723,'117954','deals','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(390698,123724,'117955','deals','block_type','1',0,''),(390699,123724,'117955','deals','padding-right','20',0,''),(390700,123725,'117956','deals','orders_data','shipping_method',0,''),(390701,123726,'117957','deals','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(390702,123727,'117958','deals','block_type','1',0,''),(390703,123727,'117958','deals','padding-right','20',0,''),(390704,123727,'117958','deals','padding-bottom','20',0,''),(390705,123728,'117959','deals','orders_data','delivery_address',0,''),(390706,123729,'117960','deals','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(390707,123730,'117961','deals','block_type','1',0,''),(390708,123731,'117962','deals','orders_data','payment_method',0,''),(390709,123732,'117963','deals','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(390710,123733,'117964','deals','block_type','1',0,''),(390711,123733,'117964','deals','padding-bottom','20',0,''),(390712,123734,'117965','deals','orders_data','billing_address',0,''),(390713,123735,'117966','deals','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(390714,123736,'117967','deals','block_type','1',0,''),(390715,123737,'117968','deals','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(390716,123738,'117969','deals','block_type','6',0,''),(390717,123739,'117970','deals','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(390718,123740,'117971','deals','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(390719,123741,'117972','deals','text','<div class=\"heading-4\">Categories</div>',0,''),(390720,123744,'117975','deals','class','menu-simple',0,''),(390721,123746,'117977','deals','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(390722,123747,'120878','deals','float','left',0,''),(390723,123747,'120878','deals','margin-right','10',0,''),(390724,123748,'117978','deals','block_type','1',0,''),(390725,123749,'117979','deals','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(390726,123749,'117979','deals','style_class','middle-form',0,''),(390727,123750,'117980','deals','style_class','middle-form',0,''),(390728,123751,'117981','deals','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(390729,123752,'117982','deals','style_class','middle-form',0,''),(390730,123752,'117982','deals','margin-bottom','30',0,''),(390731,123753,'117983','deals','block_type','1',0,''),(390732,123754,'117984','deals','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(390733,123754,'117984','deals','padding-top','100',0,''),(390734,123754,'117984','deals','margin-bottom','100',0,''),(390735,123754,'117984','deals','text-align','center',0,''),(390736,123754,'117984','deals','font-size','20',0,''),(390737,123755,'117985','deals','block_type','1',0,''),(390738,123756,'117986','deals','block_type','6',0,''),(390739,123756,'117986','deals','schema','6-3',0,'5639'),(390740,123757,'117987','deals','aria_name','account-menu',0,''),(390804,123777,'117988','deals','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(390805,123778,'117989','deals','text','##SUBSCRIPTION_TEXT##',0,''),(390806,123780,'1694163942.487488','deals','block_type','1',0,''),(390807,123780,'1694163942.487488','deals','background-color','$content-bg-1',0,''),(390808,123780,'1694163942.487488','deals','padding-bottom','30',0,''),(390809,123780,'1694163942.487488','deals','style_class','success-page',0,''),(390810,123781,'1694163942.571966','deals','block_type','12',0,''),(390811,123781,'1694163942.571966','deals','schema','4-2',0,'5639'),(390812,123782,'1694163942.574743','deals','block_type','1',0,''),(390813,123782,'1694163942.574743','deals','padding-right','40',0,''),(390814,123782,'1694163942.574743','deals','padding-right','0',0,'5639'),(390815,123783,'1694163942.57618','deals','block_type','2',0,''),(390816,123783,'1694163942.57618','deals','margin-bottom','20',0,''),(390817,123783,'1694163942.57618','deals','schema','2-2',0,'5630'),(390818,123783,'1694163942.57618','deals','border-top-width','1',0,''),(390819,123783,'1694163942.57618','deals','border-left-width','1',0,''),(390820,123783,'1694163942.57618','deals','border-right-width','1',0,''),(390821,123783,'1694163942.57618','deals','border-bottom-width','1',0,''),(390822,123783,'1694163942.57618','deals','border-top-color','$content-border-1',0,''),(390823,123783,'1694163942.57618','deals','border-left-color','$content-border-1',0,''),(390824,123783,'1694163942.57618','deals','border-right-color','$content-border-1',0,''),(390825,123783,'1694163942.57618','deals','border-bottom-color','$content-border-1',0,''),(390826,123784,'1694163942.578938','deals','block_type','1',0,''),(390827,123784,'1694163942.578938','deals','margin-right','-10',0,''),(390828,123784,'1694163942.578938','deals','padding-right','30',0,''),(390829,123784,'1694163942.578938','deals','padding-top','20',0,''),(390830,123784,'1694163942.578938','deals','padding-left','30',0,''),(390831,123784,'1694163942.578938','deals','padding-bottom','20',0,''),(390832,123784,'1694163942.578938','deals','border-right-width','0',0,'5639'),(390833,123784,'1694163942.578938','deals','margin-right','0',0,'5639'),(390834,123784,'1694163942.578938','deals','margin-bottom','20',0,'5639'),(390835,123784,'1694163942.578938','deals','padding-left','20',0,'5639'),(390836,123784,'1694163942.578938','deals','padding-right','20',0,'5639'),(390837,123786,'1694163942.582929','deals','margin-bottom','20',0,''),(390838,123787,'1694163942.58424','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(390839,123787,'1694163942.58424','deals','padding-top','20',0,''),(390840,123788,'1694163942.58813','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(390841,123788,'1694163942.58813','deals','clear','none',0,''),(390842,123789,'1694163942.590','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(390843,123791,'1694163942.592641','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(390844,123791,'1694163942.592641','deals','clear','none',0,''),(390845,123792,'1694163942.594491','deals','block_type','1',0,''),(390846,123792,'1694163942.594491','deals','padding-left','30',0,''),(390847,123792,'1694163942.594491','deals','margin-left','-10',0,''),(390848,123792,'1694163942.594491','deals','padding-right','30',0,''),(390849,123792,'1694163942.594491','deals','padding-top','20',0,''),(390850,123792,'1694163942.594491','deals','padding-bottom','20',0,''),(390851,123792,'1694163942.594491','deals','border-left-width','0',0,'5639'),(390852,123794,'1694163942.59754','deals','margin-bottom','20',0,''),(390853,123795,'1694163942.598173','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(390854,123795,'1694163942.598173','deals','clear','none',0,''),(390855,123796,'1694163942.599378','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(390856,123797,'1694163942.600432','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(390857,123797,'1694163942.600432','deals','clear','none',0,''),(390858,123798,'1694163942.601780','deals','text','<div class=\"page-success\">\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>',0,''),(390859,123798,'1694163942.601780','deals','margin-bottom','30',0,''),(390860,123798,'1694163942.601780','deals','padding-top','30',0,''),(390861,123798,'1694163942.601780','deals','padding-bottom','30',0,''),(390862,123798,'1694163942.601780','deals','padding-left','30',0,''),(390863,123798,'1694163942.601780','deals','padding-right','30',0,''),(390864,123798,'1694163942.601780','deals','border-top-width','1',0,''),(390865,123798,'1694163942.601780','deals','border-left-width','1',0,''),(390866,123798,'1694163942.601780','deals','border-right-width','1',0,''),(390867,123798,'1694163942.601780','deals','border-bottom-width','1',0,''),(390868,123798,'1694163942.601780','deals','border-top-color','$content-border-1',0,''),(390869,123798,'1694163942.601780','deals','border-left-color','$content-border-1',0,''),(390870,123798,'1694163942.601780','deals','border-right-color','$content-border-1',0,''),(390871,123798,'1694163942.601780','deals','border-bottom-color','$content-border-1',0,''),(390872,123799,'1694163942.604213','deals','block_type','1',0,''),(390873,123799,'1694163942.604213','deals','style_class','order-summary2 hiding-box',0,''),(390874,123800,'1694163942.605131','deals','text-align','center',0,''),(390875,123800,'1694163942.605131','deals','margin-bottom','20',0,''),(390876,123801,'1694163942.606115','deals','text-align','center',0,''),(390877,123804,'1694163942.609249','deals','block_type','12',0,''),(390878,123805,'1694163942.610273','deals','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n</div>\n',0,''),(390879,123805,'1694163942.610273','deals','margin-bottom','20',0,''),(390880,123806,'1694163942.611982','deals','text-align','center',0,''),(390881,123806,'1694163942.611982','deals','padding-top','40',0,''),(390882,123807,'117997','deals','block_type','1',0,''),(390883,123808,'117998','deals','block_type','1',0,''),(390884,123808,'117998','deals','font-weight','normal',0,''),(390885,123809,'117999','deals','block_type','1',0,''),(390886,123809,'117999','deals','text-align','center',0,''),(390887,123809,'117999','deals','padding-top','30',0,''),(390888,123809,'117999','deals','margin-bottom','200',0,''),(390889,123810,'118000','deals','display','inline-block',0,''),(390890,123810,'118000','deals','clear','none',0,''),(390891,123810,'118000','deals','margin-left','20',0,''),(390892,123811,'118001','deals','display','inline-block',0,''),(390893,123812,'118002','deals','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(390898,123817,'118007','deals','width','680',0,''),(390899,123817,'118007','deals','font-weight','normal',0,''),(390900,123817,'118007','deals','font-size','12',0,''),(390901,123817,'118007','deals','padding-top','20',0,''),(390902,123817,'118007','deals','padding-bottom','20',0,''),(390903,123817,'118007','deals','color','$content-color-1',0,''),(390904,123818,'118008','deals','block_type','5',0,''),(390905,123818,'118008','deals','font-weight','normal',0,''),(390906,123818,'118008','deals','border-bottom-width','1',0,''),(390907,123818,'118008','deals','border-bottom-color','$content-border-1',0,''),(390908,123818,'118008','deals','border-top-width','1',0,''),(390909,123818,'118008','deals','border-top-color','$content-border-1',0,''),(390910,123818,'118008','deals','border-left-color','$content-border-1',0,''),(390911,123818,'118008','deals','border-left-width','1',0,''),(390912,123819,'118009','deals','block_type','1',0,''),(390913,123819,'118009','deals','font-weight','normal',0,''),(390914,123819,'118009','deals','padding-top','10',0,''),(390915,123819,'118009','deals','padding-left','10',0,''),(390916,123819,'118009','deals','padding-right','10',0,''),(390917,123820,'118010','deals','font-weight','400',0,''),(390918,123820,'118010','deals','line-height','120',0,''),(390919,123820,'118010','deals','line_height_measure','%',0,''),(390920,123820,'118010','deals','font-size','12',0,''),(390921,123821,'118011','deals','text','<p>SHIPPING ADDRESS:</p>',1,''),(390922,123821,'118011','deals','font-size','14',0,''),(390923,123821,'118011','deals','font-weight','bold',0,''),(390924,123821,'118011','deals','padding-bottom','10',0,''),(390925,123821,'118011','deals','text','<p>SHIPPING ADDRESS:</p>',2,''),(390926,123821,'118011','deals','text','<p>SHIPPING ADDRESS:</p>',3,''),(390927,123821,'118011','deals','text','<p>SHIPPING ADDRESS:</p>',4,''),(390928,123822,'118012','deals','block_type','1',0,''),(390929,123822,'118012','deals','background-color','$content-bg-2',0,''),(390930,123822,'118012','deals','padding-top','20',0,''),(390931,123822,'118012','deals','padding-left','10',0,''),(390932,123822,'118012','deals','padding-right','10',0,''),(390933,123822,'118012','deals','padding-bottom','20',0,''),(390934,123822,'118012','deals','font-size','14',0,''),(390935,123823,'118013','deals','font-weight','normal',0,''),(390936,123823,'118013','deals','text-align','right',0,''),(390937,123823,'118013','deals','font-size','14',0,''),(390938,123823,'118013','deals','box_align','3',0,''),(390939,123824,'118014','deals','block_type','3',0,''),(390940,123824,'118014','deals','font-weight','normal',0,''),(390941,123824,'118014','deals','padding-top','20',0,''),(390942,123825,'118015','deals','text','<p>If undelivered please return to:</p>',1,''),(390943,123825,'118015','deals','font-size','12',0,''),(390944,123825,'118015','deals','font-weight','bold',0,''),(390945,123825,'118015','deals','text','<p>If undelivered please return to:</p>',2,''),(390946,123825,'118015','deals','text','<p>If undelivered please return to:</p>',3,''),(390947,123825,'118015','deals','text','<p>If undelivered please return to:</p>',4,''),(390948,123826,'118016','deals','font-size','12',0,''),(390949,123827,'118018','deals','text','<p>Thank you for your order</p>',1,''),(390950,123827,'118018','deals','color','$hileght-color-1',0,''),(390951,123827,'118018','deals','font-size','13',0,''),(390952,123827,'118018','deals','font-weight','bold',0,''),(390953,123827,'118018','deals','padding-top','5',0,''),(390954,123827,'118018','deals','text-align','center',0,''),(390955,123827,'118018','deals','text','<p>Thank you for your order</p>',2,''),(390956,123827,'118018','deals','text','<p>Thank you for your order</p>',3,''),(390957,123827,'118018','deals','text','<p>Thank you for your order</p>',4,''),(390958,123828,'118019','deals','text','<p>If something has gone wrong please contact us at:</p>',1,''),(390959,123828,'118019','deals','font-size','12',0,''),(390960,123828,'118019','deals','font-weight','bold',0,''),(390961,123828,'118019','deals','text-align','right',0,''),(390962,123828,'118019','deals','text','<p>If something has gone wrong please contact us at:</p>',2,''),(390963,123828,'118019','deals','text','<p>If something has gone wrong please contact us at:</p>',3,''),(390964,123828,'118019','deals','text','<p>If something has gone wrong please contact us at:</p>',4,''),(390965,123829,'118020','deals','block_type','6',0,''),(390966,123829,'118020','deals','font-weight','normal',0,''),(390967,123829,'118020','deals','font-size','16',0,''),(390968,123830,'118021','deals','text','<p>Email:</p>',1,''),(390969,123830,'118021','deals','font-weight','normal',0,''),(390970,123830,'118021','deals','text-align','right',0,''),(390971,123830,'118021','deals','font-size','12',0,''),(390972,123830,'118021','deals','text','<p>Email:</p>',2,''),(390973,123830,'118021','deals','text','<p>Email:</p>',3,''),(390974,123830,'118021','deals','text','<p>Email:</p>',4,''),(390975,123831,'118022','deals','font-weight','normal',0,''),(390976,123831,'118022','deals','text-align','right',0,''),(390977,123831,'118022','deals','font-size','12',0,''),(390978,123832,'118023','deals','block_type','6',0,''),(390979,123832,'118023','deals','font-weight','normal',0,''),(390980,123832,'118023','deals','font-size','16',0,''),(390981,123833,'118024','deals','text','<p>Phone:</p>',1,''),(390982,123833,'118024','deals','font-weight','normal',0,''),(390983,123833,'118024','deals','text-align','right',0,''),(390984,123833,'118024','deals','font-size','12',0,''),(390985,123833,'118024','deals','text','<p>Phone:</p>',2,''),(390986,123833,'118024','deals','text','<p>Phone:</p>',3,''),(390987,123833,'118024','deals','text','<p>Phone:</p>',4,''),(390988,123834,'118025','deals','font-weight','normal',0,''),(390989,123834,'118025','deals','text-align','right',0,''),(390990,123834,'118025','deals','font-size','12',0,''),(390991,123835,'118026','deals','font-weight','400',0,''),(390992,123835,'118026','deals','padding-top','20',0,''),(390993,123835,'118026','deals','padding-bottom','0',0,''),(390994,123835,'118026','deals','font-size','12',0,''),(390995,123836,'118027','deals','block_type','2',0,''),(390996,123836,'118027','deals','font-weight','normal',0,''),(390997,123836,'118027','deals','padding-bottom','20',0,''),(390998,123837,'1643890423','deals','logo','themes/deals/img/logo-2.png',1,''),(390999,123837,'1643890423','deals','logo','themes/deals/img/logo-2.png',2,''),(391000,123837,'1643890423','deals','logo','themes/deals/img/logo-2.png',3,''),(391001,123837,'1643890423','deals','logo','themes/deals/img/logo-2.png',4,''),(391002,123838,'118028','deals','block_type','11',0,''),(391003,123838,'118028','deals','font-weight','normal',0,''),(391004,123839,'118029','deals','text','<p>Email:</p>',1,''),(391005,123839,'118029','deals','font-weight','normal',0,''),(391006,123839,'118029','deals','text-align','right',0,''),(391007,123839,'118029','deals','text','<p>Email:</p>',2,''),(391008,123839,'118029','deals','text','<p>Email:</p>',3,''),(391009,123839,'118029','deals','text','<p>Email:</p>',4,''),(391010,123840,'118030','deals','font-weight','normal',0,''),(391011,123840,'118030','deals','text-align','right',0,''),(391012,123841,'118031','deals','block_type','11',0,''),(391013,123841,'118031','deals','font-weight','normal',0,''),(391014,123842,'118032','deals','text','<p>Web:</p>',1,''),(391015,123842,'118032','deals','font-weight','normal',0,''),(391016,123842,'118032','deals','text-align','right',0,''),(391017,123842,'118032','deals','text','<p>Web:</p>',2,''),(391018,123842,'118032','deals','text','<p>Web:</p>',3,''),(391019,123842,'118032','deals','text','<p>Web:</p>',4,''),(391020,123843,'118033','deals','font-weight','normal',0,''),(391021,123843,'118033','deals','text-align','right',0,''),(391022,123844,'118034','deals','block_type','1',0,''),(391023,123845,'118035','deals','font-weight','normal',0,''),(391024,123845,'118035','deals','text-align','right',0,''),(391025,123845,'118035','deals','padding-bottom','10',0,''),(391026,123845,'118035','deals','address_spacer',',',0,''),(391027,123845,'118035','deals','font-size','12',0,''),(391028,123846,'118036','deals','block_type','11',0,''),(391029,123846,'118036','deals','font-weight','normal',0,''),(391030,123847,'118037','deals','text','<p>Phone:</p>',1,''),(391031,123847,'118037','deals','font-weight','normal',0,''),(391032,123847,'118037','deals','text-align','right',0,''),(391033,123847,'118037','deals','text','<p>Phone:</p>',2,''),(391034,123847,'118037','deals','text','<p>Phone:</p>',3,''),(391035,123847,'118037','deals','text','<p>Phone:</p>',4,''),(391036,123848,'118038','deals','font-weight','normal',0,''),(391037,123848,'118038','deals','text-align','right',0,''),(391038,123849,'118039','deals','block_type','4',0,''),(391039,123849,'118039','deals','font-weight','normal',0,''),(391040,123849,'118039','deals','border-top-width','1',0,''),(391041,123849,'118039','deals','border-top-color','$content-border-1',0,''),(391042,123849,'118039','deals','border-left-width','1',0,''),(391043,123849,'118039','deals','border-left-color','$content-border-1',0,''),(391044,123849,'118039','deals','border-right-width','1',0,''),(391045,123849,'118039','deals','border-right-color','$content-border-1',0,''),(391046,123849,'118039','deals','border-bottom-width','1',0,''),(391047,123849,'118039','deals','border-bottom-color','$content-border-1',0,''),(391048,123850,'118040','deals','block_type','2',0,''),(391049,123850,'118040','deals','font-weight','normal',0,''),(391050,123850,'118040','deals','border-top-width','1',0,''),(391051,123850,'118040','deals','border-top-color','$content-border-1',0,''),(391052,123850,'118040','deals','border-right-width','1',0,''),(391053,123850,'118040','deals','border-right-color','$content-border-1',0,''),(391054,123851,'118041','deals','block_type','1',0,''),(391055,123851,'118041','deals','font-weight','normal',0,''),(391056,123851,'118041','deals','padding-top','10',0,''),(391057,123851,'118041','deals','padding-left','10',0,''),(391058,123851,'118041','deals','padding-right','10',0,''),(391059,123851,'118041','deals','padding-bottom','10',0,''),(391060,123851,'118041','deals','border-right-width','1',0,''),(391061,123851,'118041','deals','border-right-color','$content-border-1',0,''),(391062,123852,'118042','deals','text','<p>Shipping via</p>',1,''),(391063,123852,'118042','deals','font-weight','bold',0,''),(391064,123852,'118042','deals','font-size','14',0,''),(391065,123852,'118042','deals','text','<p>Shipping via</p>',2,''),(391066,123852,'118042','deals','text','<p>Shipping via</p>',3,''),(391067,123852,'118042','deals','text','<p>Shipping via</p>',4,''),(391068,123854,'118044','deals','block_type','1',0,''),(391069,123854,'118044','deals','font-weight','normal',0,''),(391070,123854,'118044','deals','padding-top','10',0,''),(391071,123854,'118044','deals','padding-left','10',0,''),(391072,123854,'118044','deals','padding-right','10',0,''),(391073,123854,'118044','deals','padding-bottom','10',0,''),(391074,123855,'118045','deals','text','<p>Shipping service</p>',1,''),(391075,123855,'118045','deals','font-weight','bold',0,''),(391076,123855,'118045','deals','font-size','14',0,''),(391077,123855,'118045','deals','text','<p>Shipping service</p>',2,''),(391078,123855,'118045','deals','text','<p>Shipping service</p>',3,''),(391079,123855,'118045','deals','text','<p>Shipping service</p>',4,''),(391080,123857,'118047','deals','block_type','2',0,''),(391081,123857,'118047','deals','font-weight','normal',0,''),(391082,123857,'118047','deals','border-right-width','1',0,''),(391083,123857,'118047','deals','border-right-color','$content-border-1',0,''),(391084,123858,'118048','deals','block_type','1',0,''),(391085,123858,'118048','deals','font-weight','400',0,''),(391086,123858,'118048','deals','background-color','$content-bg-2',0,''),(391087,123858,'118048','deals','padding-top','10',0,''),(391088,123858,'118048','deals','padding-left','10',0,''),(391089,123858,'118048','deals','padding-right','10',0,''),(391090,123858,'118048','deals','padding-bottom','30',0,''),(391091,123859,'118049','deals','font-size','12',0,''),(391092,123860,'118050','deals','text','<p>INVOICE ADDRESS:</p>',1,''),(391093,123860,'118050','deals','font-size','14',0,''),(391094,123860,'118050','deals','font-weight','bold',0,''),(391095,123860,'118050','deals','text','<p>INVOICE ADDRESS:</p>',2,''),(391096,123860,'118050','deals','text','<p>INVOICE ADDRESS:</p>',3,''),(391097,123860,'118050','deals','text','<p>INVOICE ADDRESS:</p>',4,''),(391098,123861,'118051','deals','block_type','1',0,''),(391099,123861,'118051','deals','font-weight','normal',0,''),(391100,123861,'118051','deals','padding-top','10',0,''),(391101,123861,'118051','deals','padding-left','10',0,''),(391102,123861,'118051','deals','padding-right','10',0,''),(391103,123861,'118051','deals','padding-bottom','10',0,''),(391104,123862,'118052','deals','font-weight','normal',0,''),(391105,123863,'118053','deals','text','<p>PHONE NUMBER:</p>',1,''),(391106,123863,'118053','deals','font-size','14',0,''),(391107,123863,'118053','deals','font-weight','bold',0,''),(391108,123863,'118053','deals','padding-top','10',0,''),(391109,123863,'118053','deals','text','<p>PHONE NUMBER:</p>',2,''),(391110,123863,'118053','deals','text','<p>PHONE NUMBER:</p>',3,''),(391111,123863,'118053','deals','text','<p>PHONE NUMBER:</p>',4,''),(391112,123865,'118055','deals','font-weight','normal',0,''),(391113,123866,'118056','deals','text','<p>E-MAIL ADDRESS:</p>',1,''),(391114,123866,'118056','deals','font-weight','bold',0,''),(391115,123866,'118056','deals','font-size','14',0,''),(391116,123866,'118056','deals','padding-top','10',0,''),(391117,123866,'118056','deals','text','<p>E-MAIL ADDRESS:</p>',2,''),(391118,123866,'118056','deals','text','<p>E-MAIL ADDRESS:</p>',3,''),(391119,123866,'118056','deals','text','<p>E-MAIL ADDRESS:</p>',4,''),(391120,123867,'118057','deals','text','<p>CUSTOMER:</p>',1,''),(391121,123867,'118057','deals','font-size','13',0,''),(391122,123867,'118057','deals','font-weight','bold',0,''),(391123,123867,'118057','deals','text','<p>CUSTOMER:</p>',2,''),(391124,123867,'118057','deals','text','<p>CUSTOMER:</p>',3,''),(391125,123867,'118057','deals','text','<p>CUSTOMER:</p>',4,''),(391126,123868,'118058','deals','font-weight','normal',0,''),(391127,123868,'118058','deals','text-align','center',0,''),(391128,123868,'118058','deals','padding-bottom','10',0,''),(391129,123869,'118059','deals','text','<p>Payment date:</p>',1,''),(391130,123869,'118059','deals','font-weight','bold',0,''),(391131,123869,'118059','deals','text-align','center',0,''),(391132,123869,'118059','deals','font-size','12',0,''),(391133,123869,'118059','deals','text','<p>Payment date:</p>',2,''),(391134,123869,'118059','deals','text','<p>Payment date:</p>',3,''),(391135,123869,'118059','deals','text','<p>Payment date:</p>',4,''),(391136,123870,'118060','deals','text','<p>Payment Method:</p>',1,''),(391137,123870,'118060','deals','font-weight','bold',0,''),(391138,123870,'118060','deals','text-align','center',0,''),(391139,123870,'118060','deals','text','<p>Payment Method:</p>',2,''),(391140,123870,'118060','deals','text','<p>Payment Method:</p>',3,''),(391141,123870,'118060','deals','text','<p>Payment Method:</p>',4,''),(391142,123871,'118061','deals','font-size','14',0,''),(391143,123871,'118061','deals','font-weight','bold',0,''),(391144,123871,'118061','deals','text-align','center',0,''),(391145,123871,'118061','deals','padding-bottom','10',0,''),(391146,123871,'118061','deals','padding-top','10',0,''),(391147,123872,'118062','deals','font-weight','normal',0,''),(391148,123872,'118062','deals','text-align','center',0,''),(391149,123872,'118062','deals','padding-bottom','20',0,''),(391150,123873,'118063','deals','font-weight','normal',0,''),(391151,123873,'118063','deals','text-align','center',0,''),(391152,123874,'118094','deals','block_type','1',0,''),(391153,123875,'118095','deals','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(391154,123877,'118318','deals','block_type','1',0,''),(391155,123878,'118319','deals','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(391156,123878,'118319','deals','padding-top','100',0,''),(391157,123878,'118319','deals','margin-bottom','100',0,''),(391158,123878,'118319','deals','text-align','center',0,''),(391159,123878,'118319','deals','font-size','20',0,''),(391160,123879,'118320','deals','block_type','1',0,''),(391161,123879,'118320','deals','background-color','$content-bg-2',0,''),(391162,123879,'118320','deals','padding-bottom','30',0,''),(391163,123880,'118321','deals','block_type','4',0,''),(391164,123880,'118321','deals','schema','4-2',0,'5639'),(391165,123881,'118322','deals','block_type','1',0,''),(391166,123881,'118322','deals','padding-right','40',0,''),(391167,123881,'118322','deals','padding-right','0',0,'5639'),(391168,123882,'118323','deals','block_type','2',0,''),(391169,123882,'118323','deals','margin-bottom','20',0,''),(391170,123882,'118323','deals','schema','2-2',0,'5630'),(391171,123882,'118323','deals','background-color','$content-bg-1',0,''),(391172,123883,'118324','deals','block_type','1',0,''),(391173,123883,'118324','deals','border-right-width','20',0,''),(391174,123883,'118324','deals','border-right-color','$content-border-1',0,''),(391175,123883,'118324','deals','margin-right','-10',0,''),(391176,123883,'118324','deals','padding-right','30',0,''),(391177,123883,'118324','deals','padding-top','20',0,''),(391178,123883,'118324','deals','padding-left','30',0,''),(391179,123883,'118324','deals','padding-bottom','20',0,''),(391180,123883,'118324','deals','border-right-width','0',0,'5639'),(391181,123883,'118324','deals','margin-right','0',0,'5639'),(391182,123883,'118324','deals','margin-bottom','20',0,'5639'),(391183,123883,'118324','deals','padding-left','20',0,'5639'),(391184,123883,'118324','deals','padding-right','20',0,'5639'),(391185,123885,'118326','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(391186,123885,'118326','deals','clear','none',0,''),(391187,123886,'118327','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(391188,123886,'118327','deals','clear','none',0,''),(391189,123887,'118328','deals','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(391190,123889,'118330','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(391191,123889,'118330','deals','padding-top','20',0,''),(391192,123892,'118333','deals','margin-bottom','20',0,''),(391193,123893,'118334','deals','block_type','1',0,''),(391194,123893,'118334','deals','padding-left','30',0,''),(391195,123893,'118334','deals','border-left-width','20',0,''),(391196,123893,'118334','deals','border-left-color','$content-border-1',0,''),(391197,123893,'118334','deals','margin-left','-10',0,''),(391198,123893,'118334','deals','padding-right','30',0,''),(391199,123893,'118334','deals','padding-top','20',0,''),(391200,123893,'118334','deals','padding-bottom','20',0,''),(391201,123893,'118334','deals','border-left-width','0',0,'5639'),(391202,123894,'118335','deals','margin-bottom','20',0,''),(391203,123896,'118337','deals','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(391204,123897,'118338','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(391205,123897,'118338','deals','clear','none',0,''),(391206,123898,'118339','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(391207,123898,'118339','deals','clear','none',0,''),(391208,123899,'118340','deals','block_type','1',0,''),(391209,123899,'118340','deals','padding-right','30',0,''),(391210,123899,'118340','deals','background-color','$content-bg-1',0,''),(391211,123899,'118340','deals','padding-top','20',0,''),(391212,123899,'118340','deals','padding-left','30',0,''),(391213,123899,'118340','deals','padding-bottom','20',0,''),(391214,123899,'118340','deals','padding-left','20',0,'5639'),(391215,123899,'118340','deals','padding-right','20',0,'5639'),(391216,123901,'118342','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(391217,123902,'118343','deals','block_type','1',0,''),(391218,123902,'118343','deals','padding-top','20',0,''),(391219,123902,'118343','deals','padding-left','20',0,''),(391220,123902,'118343','deals','padding-right','20',0,''),(391221,123902,'118343','deals','padding-bottom','20',0,''),(391222,123902,'118343','deals','background-color','$content-bg-1',0,''),(391223,123902,'118343','deals','style_class','order-summary',0,''),(391224,123903,'118344','deals','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(391225,123907,'118348','deals','block_type','1',0,''),(391226,123907,'118348','deals','padding-bottom','30',0,''),(391227,123908,'118349','deals','block_type','4',0,''),(391228,123908,'118349','deals','schema','4-2',0,'5639'),(391229,123909,'118350','deals','block_type','1',0,''),(391230,123909,'118350','deals','padding-right','20',0,''),(391231,123909,'118350','deals','padding-top','20',0,''),(391232,123909,'118350','deals','padding-left','20',0,''),(391233,123909,'118350','deals','padding-bottom','20',0,''),(391234,123909,'118350','deals','border-top-width','1',0,''),(391235,123909,'118350','deals','border-left-width','1',0,''),(391236,123909,'118350','deals','border-right-width','1',0,''),(391237,123909,'118350','deals','border-bottom-width','1',0,''),(391238,123909,'118350','deals','border-top-color','$content-border-1',0,''),(391239,123909,'118350','deals','border-left-color','$content-border-1',0,''),(391240,123909,'118350','deals','border-right-color','$content-border-1',0,''),(391241,123909,'118350','deals','border-bottom-color','$content-border-1',0,''),(391242,123909,'118350','deals','margin-bottom','30',0,''),(391243,123909,'118350','deals','padding-top','15',0,'5639'),(391244,123909,'118350','deals','padding-left','15',0,'5639'),(391245,123909,'118350','deals','padding-right','15',0,'5639'),(391246,123909,'118350','deals','padding-bottom','15',0,'5639'),(391247,123910,'118351','deals','block_type','2',0,''),(391248,123910,'118351','deals','margin-bottom','20',0,''),(391249,123910,'118351','deals','schema','2-1',0,'5630'),(391250,123910,'118351','deals','background-color','$content-bg-1',0,''),(391251,123910,'118351','deals','schema','2-2',0,'5660'),(391252,123911,'118352','deals','block_type','1',0,''),(391253,123911,'118352','deals','border-right-width','0',0,'5639'),(391254,123911,'118352','deals','margin-right','0',0,'5639'),(391255,123911,'118352','deals','padding-right','20',0,''),(391256,123911,'118352','deals','margin-bottom','20',0,'5660'),(391257,123912,'118353','deals','margin-bottom','20',0,''),(391258,123915,'118356','deals','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(391259,123915,'118356','deals','padding-top','20',0,''),(391260,123917,'118358','deals','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(391261,123917,'118358','deals','clear','none',0,''),(391262,123919,'118360','deals','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(391263,123920,'118361','deals','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(391264,123920,'118361','deals','clear','none',0,''),(391265,123922,'118362','deals','block_type','1',0,''),(391266,123922,'118362','deals','padding-left','20',0,''),(391267,123922,'118362','deals','border-left-width','0',0,'5639'),(391268,123922,'118362','deals','padding-left','0',0,'5660'),(391269,123923,'118363','deals','text','<div class=\"heading-2\">##TEXT_PAYMENT##</div>',0,''),(391270,123924,'118364','deals','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(391271,123924,'118364','deals','clear','none',0,''),(391272,123925,'118365','deals','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(391273,123925,'118365','deals','clear','none',0,''),(391274,123926,'118366','deals','margin-bottom','20',0,''),(391275,123927,'118367','deals','orders_data','name',0,''),(391276,123928,'118368','deals','block_type','1',0,''),(391277,123928,'118368','deals','padding-right','20',0,''),(391278,123928,'118368','deals','background-color','$content-bg-1',0,''),(391279,123928,'118368','deals','padding-top','20',0,''),(391280,123928,'118368','deals','padding-left','20',0,''),(391281,123928,'118368','deals','padding-bottom','20',0,''),(391282,123928,'118368','deals','padding-left','15',0,'5639'),(391283,123928,'118368','deals','padding-right','15',0,'5639'),(391284,123928,'118368','deals','border-top-width','1',0,''),(391285,123928,'118368','deals','border-left-width','1',0,''),(391286,123928,'118368','deals','border-right-width','1',0,''),(391287,123928,'118368','deals','border-bottom-width','1',0,''),(391288,123928,'118368','deals','border-top-color','$content-border-1',0,''),(391289,123928,'118368','deals','border-left-color','$content-border-1',0,''),(391290,123928,'118368','deals','border-right-color','$content-border-1',0,''),(391291,123928,'118368','deals','border-bottom-color','$content-border-1',0,''),(391292,123928,'118368','deals','padding-top','15',0,'5639'),(391293,123928,'118368','deals','padding-bottom','15',0,'5639'),(391294,123928,'118368','deals','margin-bottom','30',0,'5639'),(391295,123929,'118369','deals','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(391296,123931,'118371','deals','block_type','1',0,''),(391297,123931,'118371','deals','padding-left','30',0,''),(391298,123931,'118371','deals','background-color','$content-bg-1',0,''),(391299,123931,'118371','deals','style_class','order-summary',0,''),(391300,123931,'118371','deals','padding-left','0',0,'5639'),(391301,123934,'118374','deals','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(391302,123936,'118440','deals','block_type','1',0,''),(391303,123937,'118441','deals','block_type','6',0,''),(391304,123937,'118441','deals','schema','6-3',0,'5639'),(391305,123938,'118442','deals','aria_name','account-menu',0,''),(391306,123939,'116126','deals','block_type','1',0,''),(391307,123939,'116126','deals','padding-top','80',0,''),(391308,123939,'116126','deals','padding-right','30',0,''),(391309,123939,'116126','deals','padding-bottom','30',0,''),(391310,123939,'116126','deals','padding-top','0',0,'5639'),(391311,123939,'116126','deals','padding-left','0',0,'5639'),(391312,123939,'116126','deals','padding-right','0',0,'5639'),(391313,123939,'116126','deals','padding-bottom','0',0,'5639'),(391369,123958,'118443','deals','margin-bottom','20',0,''),(391370,123959,'118444','deals','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(391371,123960,'118445','deals','block_type','1',0,''),(391372,123960,'118445','deals','padding-top','20',0,''),(391373,123960,'118445','deals','padding-bottom','20',0,''),(391374,123962,'118447','deals','padding-top','20',0,''),(391375,123962,'118447','deals','padding-bottom','20',0,''),(570622,179319,'1712569858.457560','furniture','from_file','header_2.zip',0,''),(570623,179320,'1712569858.46511','furniture','block_type','1',0,''),(570624,179320,'1712569858.46511','furniture','border-bottom-width','1',0,''),(570625,179320,'1712569858.46511','furniture','border-bottom-color','$header-border-1',0,''),(570626,179320,'1712569858.46511','furniture','font-weight','normal',0,''),(570627,179320,'1712569858.46511','furniture','visibility_checkout','1',0,''),(570628,179320,'1712569858.46511','furniture','background-color','$header-bg-1',0,''),(570629,179320,'1712569858.46511','furniture','color','$header-color-1',0,''),(570630,179320,'1712569858.46511','furniture','from_file','header_2.zip',0,''),(570652,179326,'1712569858.628847','furniture','block_type','1',0,''),(570653,179326,'1712569858.628847','furniture','padding-top','3',0,''),(570654,179326,'1712569858.628847','furniture','padding-top','0',0,'5161'),(570655,179326,'1712569858.628847','furniture','padding-bottom','0',0,'5161'),(570656,179326,'1712569858.628847','furniture','background-color','$header-bg-1',0,''),(570657,179326,'1712569858.628847','furniture','color','$header-color-1',0,''),(570658,179326,'1712569858.628847','furniture','style_class','header-middle',0,''),(570659,179326,'1712569858.628847','furniture','from_file','header_2.zip',0,''),(570687,179332,'1712569858.854422','furniture','block_type','1',0,''),(570688,179332,'1712569858.854422','furniture','font-weight','400',0,''),(570689,179332,'1712569858.854422','furniture','background-color','$header-menu-bg-1',0,''),(570690,179332,'1712569858.854422','furniture','visibility_checkout','1',0,''),(570691,179332,'1712569858.854422','furniture','style_class','header-menu-holder',0,''),(570692,179332,'1712569858.854422','furniture','from_file','header_2.zip',0,''),(570727,179334,'1712672669.73341','furniture','from_file','header_2.zip',0,''),(570728,179335,'1712672669.737451','furniture','block_type','1',0,''),(570729,179335,'1712672669.737451','furniture','border-bottom-width','1',0,''),(570730,179335,'1712672669.737451','furniture','border-bottom-color','$header-border-1',0,''),(570731,179335,'1712672669.737451','furniture','font-weight','normal',0,''),(570732,179335,'1712672669.737451','furniture','visibility_checkout','1',0,''),(570733,179335,'1712672669.737451','furniture','background-color','$header-bg-1',0,''),(570734,179335,'1712672669.737451','furniture','color','$header-color-1',0,''),(570735,179335,'1712672669.737451','furniture','from_file','header_2.zip',0,''),(570757,179341,'1712672669.895430','furniture','block_type','1',0,''),(570758,179341,'1712672669.895430','furniture','padding-top','3',0,''),(570759,179341,'1712672669.895430','furniture','padding-top','0',0,'5161'),(570760,179341,'1712672669.895430','furniture','padding-bottom','0',0,'5161'),(570761,179341,'1712672669.895430','furniture','background-color','$header-bg-1',0,''),(570762,179341,'1712672669.895430','furniture','color','$header-color-1',0,''),(570763,179341,'1712672669.895430','furniture','style_class','header-middle',0,''),(570764,179341,'1712672669.895430','furniture','from_file','header_2.zip',0,''),(570792,179347,'1712672670.192374','furniture','block_type','1',0,''),(570793,179347,'1712672670.192374','furniture','font-weight','400',0,''),(570794,179347,'1712672670.192374','furniture','background-color','$header-menu-bg-1',0,''),(570795,179347,'1712672670.192374','furniture','visibility_checkout','1',0,''),(570796,179347,'1712672670.192374','furniture','style_class','header-menu-holder',0,''),(570797,179347,'1712672670.192374','furniture','from_file','header_2.zip',0,''),(570832,179349,'1712673366.442350','furniture','from_file','header_2.zip',0,''),(570833,179350,'1712673366.452464','furniture','block_type','1',0,''),(570834,179350,'1712673366.452464','furniture','border-bottom-width','1',0,''),(570835,179350,'1712673366.452464','furniture','border-bottom-color','$header-border-1',0,''),(570836,179350,'1712673366.452464','furniture','font-weight','normal',0,''),(570837,179350,'1712673366.452464','furniture','visibility_checkout','1',0,''),(570838,179350,'1712673366.452464','furniture','background-color','$header-bg-1',0,''),(570839,179350,'1712673366.452464','furniture','color','$header-color-1',0,''),(570840,179350,'1712673366.452464','furniture','from_file','header_2.zip',0,''),(570862,179356,'1712673366.616449','furniture','block_type','1',0,''),(570863,179356,'1712673366.616449','furniture','padding-top','3',0,''),(570864,179356,'1712673366.616449','furniture','padding-top','0',0,'5161'),(570865,179356,'1712673366.616449','furniture','padding-bottom','0',0,'5161'),(570866,179356,'1712673366.616449','furniture','background-color','$header-bg-1',0,''),(570867,179356,'1712673366.616449','furniture','color','$header-color-1',0,''),(570868,179356,'1712673366.616449','furniture','style_class','header-middle',0,''),(570869,179356,'1712673366.616449','furniture','from_file','header_2.zip',0,''),(570897,179362,'1712673366.847874','furniture','block_type','1',0,''),(570898,179362,'1712673366.847874','furniture','font-weight','400',0,''),(570899,179362,'1712673366.847874','furniture','background-color','$header-menu-bg-1',0,''),(570900,179362,'1712673366.847874','furniture','visibility_checkout','1',0,''),(570901,179362,'1712673366.847874','furniture','style_class','header-menu-holder',0,''),(570902,179362,'1712673366.847874','furniture','from_file','header_2.zip',0,''),(570937,179364,'1712674966.930853','furniture','from_file','header_2.zip',0,''),(570938,179365,'1712674966.934154','furniture','block_type','1',0,''),(570939,179365,'1712674966.934154','furniture','border-bottom-width','1',0,''),(570940,179365,'1712674966.934154','furniture','border-bottom-color','$header-border-1',0,''),(570941,179365,'1712674966.934154','furniture','font-weight','normal',0,''),(570942,179365,'1712674966.934154','furniture','visibility_checkout','1',0,''),(570943,179365,'1712674966.934154','furniture','background-color','$header-bg-1',0,''),(570944,179365,'1712674966.934154','furniture','color','$header-color-1',0,''),(570945,179365,'1712674966.934154','furniture','from_file','header_2.zip',0,''),(570946,179366,'1712674966.936778','furniture','block_type','2',0,''),(570947,179366,'1712674966.936778','furniture','font-weight','400',0,''),(570948,179366,'1712674966.936778','furniture','schema','2-2',0,''),(570949,179366,'1712674966.936778','furniture','schema','5-1',0,'5140'),(570950,179366,'1712674966.936778','furniture','schema','2-2',0,'5131'),(570951,179367,'1712674966.939493','furniture','class','menu-horizontal',0,''),(570952,179367,'1712674966.939493','furniture','box_align','1',0,''),(570953,179367,'1712674966.939493','furniture','font-weight','400',0,''),(570954,179367,'1712674966.939493','furniture','float','left',0,''),(570955,179367,'1712674966.939493','furniture','display_none','1',0,'5161'),(570956,179367,'1712674966.939493','furniture','display','none',0,'5140'),(570957,179368,'1712674967.04388','furniture','block_type','1',0,''),(570958,179369,'1712674967.045458','furniture','box_align','3',0,''),(570959,179369,'1712674967.045458','furniture','font-weight','normal',0,''),(570960,179369,'1712674967.045458','furniture','show_symbol_left','1',0,''),(570961,179369,'1712674967.045458','furniture','show_symbol_right','1',0,''),(570962,179370,'1712674967.072331','furniture','box_align','3',0,''),(570963,179370,'1712674967.072331','furniture','font-weight','normal',0,''),(570964,179370,'1712674967.072331','furniture','border-left-width','1',0,''),(570965,179370,'1712674967.072331','furniture','border-left-color','$content-border-1',0,''),(570966,179370,'1712674967.072331','furniture','show_title','1',0,''),(570967,179371,'1712674967.095974','furniture','block_type','1',0,''),(570968,179371,'1712674967.095974','furniture','padding-top','3',0,''),(570969,179371,'1712674967.095974','furniture','padding-top','0',0,'5161'),(570970,179371,'1712674967.095974','furniture','padding-bottom','0',0,'5161'),(570971,179371,'1712674967.095974','furniture','background-color','$header-bg-1',0,''),(570972,179371,'1712674967.095974','furniture','color','$header-color-1',0,''),(570973,179371,'1712674967.095974','furniture','style_class','header-middle',0,''),(570974,179371,'1712674967.095974','furniture','from_file','header_2.zip',0,''),(570975,179372,'1712674967.104961','furniture','font-weight','400',0,''),(570976,179372,'1712674967.104961','furniture','box_align','1',0,''),(570978,179372,'1712674967.104961','furniture','float','left',0,''),(570979,179372,'1712674967.104961','furniture','clear','both',0,''),(570980,179372,'1712674967.104961','furniture','margin-top','22',0,''),(570981,179372,'1712674967.104961','furniture','margin-bottom','22',0,''),(570982,179372,'1712674967.104961','furniture','max-width','250',0,''),(570983,179372,'1712674967.104961','furniture','margin-top','10',0,'5140'),(570984,179372,'1712674967.104961','furniture','margin-bottom','10',0,'5140'),(570985,179373,'1712674967.10848','furniture','visibility_checkout','1',0,''),(570986,179373,'1712674967.10848','furniture','search_history','1',0,''),(570987,179373,'1712674967.10848','furniture','padding-left','20',0,''),(570988,179374,'1712674967.177380','furniture','box_align','3',0,''),(570989,179374,'1712674967.177380','furniture','only_icon','on',0,''),(570990,179374,'1712674967.177380','furniture','items','1',0,''),(570991,179374,'1712674967.177380','furniture','total','1',0,''),(570992,179374,'1712674967.177380','furniture','show_products','dropdown',0,''),(570993,179374,'1712674967.177380','furniture','margin-left','20',0,''),(570994,179375,'1712674967.300450','furniture','box_align','3',0,''),(570995,179375,'1712674967.300450','furniture','only_icon','on',0,''),(570996,179375,'1712674967.300450','furniture','margin-left','20',0,''),(570997,179375,'1712674967.300450','furniture','link_or_dropdown','1',0,''),(570998,179376,'1712674967.356553','furniture','float','left',0,''),(570999,179376,'1712674967.356553','furniture','clear','none',0,''),(571000,179376,'1712674967.356553','furniture','display_none','1',0,'5145'),(571001,179376,'1712674967.356553','furniture','logo','themes/furniture/img/header-img.png',1,''),(571002,179377,'1712674967.37028','furniture','block_type','1',0,''),(571003,179377,'1712674967.37028','furniture','font-weight','400',0,''),(571004,179377,'1712674967.37028','furniture','background-color','$header-menu-bg-1',0,''),(571005,179377,'1712674967.37028','furniture','visibility_checkout','1',0,''),(571006,179377,'1712674967.37028','furniture','style_class','header-menu-holder',0,''),(571007,179377,'1712674967.37028','furniture','from_file','header_2.zip',0,''),(571008,179378,'1712674967.380976','furniture','class','menu-style-1',0,''),(571009,179378,'1712674967.380976','furniture','box_align','4',0,''),(571010,179378,'1712674967.380976','furniture','font-weight','400',0,''),(571011,179378,'1712674967.380976','furniture','hide_menu','on',0,''),(571012,179378,'1712674967.380976','furniture','color','$highlight-box-color-2',0,''),(571013,179378,'1712674967.380976','furniture','hide_menu','1',0,'5140'),(571014,179378,'1712674967.380976','furniture','show_new','1',0,''),(571015,179378,'1712674967.380976','furniture','type','builder',0,''),(571016,179378,'1712674967.380976','furniture','burger_icon','1',0,'5140'),(571017,179378,'1712674967.380976','furniture','style','2',0,'5140'),(571018,179378,'1712674967.380976','furniture','open_from','left',0,'5140'),(571019,179378,'1712674967.380976','furniture','lev2_vis','click',0,'5140'),(571020,179378,'1712674967.380976','furniture','style','1',0,'5198'),(571021,179378,'1712674967.380976','furniture','position','horizontal_flex',0,'5198'),(571022,179378,'1712674967.380976','furniture','lev2_vis','over',0,'5198'),(571023,179378,'1712674967.380976','furniture','lev3_vis','over',0,'5198'),(571024,179378,'1712674967.380976','furniture','lev4_vis','over',0,'5198'),(571025,179378,'1712674967.380976','furniture','lev5_vis','over',0,'5198'),(571026,179378,'1712674967.380976','furniture','lev6_vis','over',0,'5198'),(571027,179378,'1712674967.380976','furniture','lev2_display','down',0,'5198'),(571028,179378,'1712674967.380976','furniture','lev3_display','lra',0,'5198'),(571029,179378,'1712674967.380976','furniture','lev4_display','lra',0,'5198'),(571030,179378,'1712674967.380976','furniture','lev5_display','lra',0,'5198'),(571031,179378,'1712674967.380976','furniture','lev6_display','lra',0,'5198'),(571032,179378,'1712674967.380976','furniture','lev2_display','slide',0,'5140'),(571033,179378,'1712674967.380976','furniture','lev3_display','slide',0,'5140'),(571034,179378,'1712674967.380976','furniture','lev3_vis','click',0,'5140'),(571035,179378,'1712674967.380976','furniture','lev4_vis','click',0,'5140'),(571036,179378,'1712674967.380976','furniture','lev4_display','slide',0,'5140'),(571037,179378,'1712674967.380976','furniture','lev5_vis','click',0,'5140'),(571038,179378,'1712674967.380976','furniture','lev5_display','slide',0,'5140'),(571039,179378,'1712674967.380976','furniture','lev6_vis','click',0,'5140'),(571040,179378,'1712674967.380976','furniture','lev6_display','slide',0,'5140'),(571041,179378,'1712674967.380976','furniture','style_class','header-menu',0,''),(571042,179379,'1712679985.656435','watch','from_file','header_1.zip',0,''),(571043,179380,'1712679985.659674','watch','block_type','1',0,''),(571044,179380,'1712679985.659674','watch','border-bottom-width','1',0,''),(571045,179380,'1712679985.659674','watch','border-bottom-color','$header-border-1',0,''),(571046,179380,'1712679985.659674','watch','font-weight','normal',0,''),(571047,179380,'1712679985.659674','watch','visibility_checkout','1',0,''),(571048,179380,'1712679985.659674','watch','background-color','$header-bg-1',0,''),(571049,179380,'1712679985.659674','watch','color','$header-color-1',0,''),(571050,179380,'1712679985.659674','watch','from_file','header_1.zip',0,''),(571051,179381,'1712679985.661821','watch','block_type','5',0,''),(571052,179381,'1712679985.661821','watch','font-weight','400',0,''),(571053,179381,'1712679985.661821','watch','schema','2-2',0,''),(571054,179381,'1712679985.661821','watch','schema','5-2',0,'5240'),(571055,179381,'1712679985.661821','watch','schema','5-1',0,'5261'),(571056,179382,'1712679985.663776','watch','class','menu-horizontal',0,''),(571057,179382,'1712679985.663776','watch','box_align','1',0,''),(571058,179382,'1712679985.663776','watch','font-weight','400',0,''),(571059,179382,'1712679985.663776','watch','border-top-width','1',0,'5240'),(571060,179382,'1712679985.663776','watch','border-top-color','$content-border-1',0,'5240'),(571061,179382,'1712679985.663776','watch','display','none',0,'5240'),(571062,179383,'1712679985.705953','watch','block_type','1',0,''),(571063,179384,'1712679985.707292','watch','font-weight','400',0,''),(571064,179384,'1712679985.707292','watch','box_align','3',0,''),(571065,179384,'1712679985.707292','watch','show_products','dropdown',0,''),(571066,179384,'1712679985.707292','watch','only_icon','on',0,''),(571067,179385,'1712679985.760839','watch','font-weight','normal',0,''),(571068,179385,'1712679985.760839','watch','box_align','3',0,''),(571069,179385,'1712679985.760839','watch','border-left-width','1',0,''),(571070,179385,'1712679985.760839','watch','border-left-color','$header-border-1',0,''),(571071,179385,'1712679985.760839','watch','only_icon','on',0,''),(571072,179386,'1712679985.804792','watch','box_align','3',0,''),(571073,179386,'1712679985.804792','watch','font-weight','normal',0,''),(571074,179386,'1712679985.804792','watch','padding-top','0',0,'5240'),(571075,179386,'1712679985.804792','watch','padding-right','0',0,'5240'),(571076,179386,'1712679985.804792','watch','padding-bottom','0',0,'5240'),(571077,179386,'1712679985.804792','watch','padding-left','0',0,'5240'),(571078,179386,'1712679985.804792','watch','show_symbol_left','1',0,''),(571079,179386,'1712679985.804792','watch','show_symbol_right','1',0,''),(571080,179387,'1712679985.832720','watch','box_align','3',0,''),(571081,179387,'1712679985.832720','watch','font-weight','normal',0,''),(571082,179387,'1712679985.832720','watch','border-left-width','1',0,''),(571083,179387,'1712679985.832720','watch','border-left-color','$header-border-1',0,''),(571084,179387,'1712679985.832720','watch','padding-top','0',0,'5240'),(571085,179387,'1712679985.832720','watch','padding-right','0',0,'5240'),(571086,179387,'1712679985.832720','watch','padding-bottom','0',0,'5240'),(571087,179387,'1712679985.832720','watch','padding-left','0',0,'5240'),(571088,179387,'1712679985.832720','watch','show_title','1',0,''),(571089,179388,'1712679985.861268','watch','block_type','1',0,''),(571090,179388,'1712679985.861268','watch','padding-top','20',0,''),(571091,179388,'1712679985.861268','watch','padding-bottom','20',0,''),(571092,179388,'1712679985.861268','watch','style_class','header-content',0,''),(571093,179388,'1712679985.861268','watch','color','$header-color-1',0,''),(571094,179388,'1712679985.861268','watch','background-color','$header-bg-1',0,''),(571095,179388,'1712679985.861268','watch','from_file','header_1.zip',0,''),(571096,179388,'1712679985.861268','watch','padding-top','12',0,'5232'),(571097,179388,'1712679985.861268','watch','padding-bottom','12',0,'5232'),(571098,179389,'1712679985.873114','watch','font-weight','400',0,''),(571099,179389,'1712679985.873114','watch','box_align','1',0,''),(571100,179389,'1712679985.873114','watch','text-align','center',0,'5261'),(571101,179389,'1712679985.873114','watch','width','100',0,'5261'),(571102,179389,'1712679985.873114','watch','width_measure','%',0,'5261'),(571103,179389,'1712679985.873114','watch','logo_from','theme',0,''),(571104,179389,'1712679985.873114','watch','padding-right','20',0,''),(571105,179390,'1712679985.87751','watch','visibility_checkout','1',0,''),(571106,179390,'1712679985.87751','watch','search_history','1',0,''),(571107,179390,'1712679985.87751','watch','history_items','5',0,''),(571108,179390,'1712679985.87751','watch','margin-left','20',0,''),(571109,179391,'1712679985.999727','watch','text','<p class=\"customer-service\">Customer service <b>08000112569</b></p>',1,''),(571110,179391,'1712679985.999727','watch','float','right',0,''),(571111,179391,'1712679985.999727','watch','display_none','1',0,'5261'),(571112,179391,'1712679985.999727','watch','text','<p class=\"customer-service\">Customer service <b>08000112569</b></p>',0,''),(571113,179391,'1712679985.999727','watch','display','none',0,'5240'),(571114,179391,'1712679985.999727','watch','margin-left','20',0,''),(571115,179392,'1712679986.031228','watch','block_type','1',0,''),(571116,179392,'1712679986.031228','watch','font-weight','400',0,''),(571117,179392,'1712679986.031228','watch','background-color','$header-menu-bg-1',0,''),(571118,179392,'1712679986.031228','watch','visibility_checkout','1',0,''),(571119,179392,'1712679986.031228','watch','color','$header-menu-color-1',0,''),(571120,179392,'1712679986.031228','watch','from_file','header_1.zip',0,''),(571121,179392,'1712679986.031228','watch','style_class','header-menu-holder',0,''),(571122,179393,'1712679986.036538','watch','class','menu-style-1',0,''),(571123,179393,'1712679986.036538','watch','box_align','4',0,''),(571124,179393,'1712679986.036538','watch','font-weight','400',0,''),(571125,179393,'1712679986.036538','watch','hide_menu','on',0,''),(571126,179393,'1712679986.036538','watch','color','$header-menu-color-1',0,''),(571127,179393,'1712679986.036538','watch','hide_menu','1',0,'5240'),(571128,179393,'1712679986.036538','watch','show_new','1',0,''),(571129,179393,'1712679986.036538','watch','style_class','header-menu',0,''),(571130,179393,'1712679986.036538','watch','type','builder',0,''),(571131,179393,'1712679986.036538','watch','position','horizontal_center',0,'7918'),(571132,179393,'1712679986.036538','watch','style','1',0,'7918'),(571133,179393,'1712679986.036538','watch','lev2_vis','over',0,'7918'),(571134,179393,'1712679986.036538','watch','lev2_display','down',0,'7918'),(571135,179393,'1712679986.036538','watch','lev3_vis','over',0,'7918'),(571136,179393,'1712679986.036538','watch','lev4_vis','over',0,'7918'),(571137,179393,'1712679986.036538','watch','lev5_vis','over',0,'7918'),(571138,179393,'1712679986.036538','watch','lev6_vis','over',0,'7918'),(571139,179393,'1712679986.036538','watch','lev3_display','lra',0,'7918'),(571140,179393,'1712679986.036538','watch','lev4_display','lra',0,'7918'),(571141,179393,'1712679986.036538','watch','lev5_display','lra',0,'7918'),(571142,179393,'1712679986.036538','watch','lev6_display','lra',0,'7918'),(571143,179393,'1712679986.036538','watch','style','2',0,'5240'),(571144,179393,'1712679986.036538','watch','burger_icon','1',0,'5240'),(571145,179393,'1712679986.036538','watch','open_from','top',0,'5240'),(571146,179393,'1712679986.036538','watch','lev2_vis','click',0,'5240'),(571147,179393,'1712679986.036538','watch','lev3_vis','click',0,'5240'),(571148,179393,'1712679986.036538','watch','lev4_vis','click',0,'5240'),(571149,179393,'1712679986.036538','watch','lev5_vis','click',0,'5240'),(571150,179393,'1712679986.036538','watch','lev6_vis','click',0,'5240'),(571151,179393,'1712679986.036538','watch','from_file','menu_1.zip',0,''),(571152,179394,'1712755911.507134','printshop','from_file','h.zip',0,''),(571153,179395,'1712755911.510718','printshop','block_type','1',0,''),(571154,179395,'1712755911.510718','printshop','border-bottom-width','1',0,''),(571155,179395,'1712755911.510718','printshop','border-bottom-color','$header-border-1',0,''),(571156,179395,'1712755911.510718','printshop','font-weight','normal',0,''),(571157,179395,'1712755911.510718','printshop','visibility_checkout','1',0,''),(571158,179395,'1712755911.510718','printshop','display_none','1',0,'5342'),(571159,179395,'1712755911.510718','printshop','style_class','topHeader',0,''),(571160,179395,'1712755911.510718','printshop','padding-top','10',0,''),(571161,179395,'1712755911.510718','printshop','padding-bottom','10',0,''),(571162,179395,'1712755911.510718','printshop','background-color','$header-bg-1',0,''),(571163,179395,'1712755911.510718','printshop','color','$header-color-1',0,''),(571164,179395,'1712755911.510718','printshop','from_file','h.zip',0,''),(571202,179404,'1712755911.735376','printshop','block_type','1',0,''),(571203,179404,'1712755911.735376','printshop','padding-top','3',0,''),(571204,179404,'1712755911.735376','printshop','padding-top','0',0,'5363'),(571205,179404,'1712755911.735376','printshop','padding-bottom','0',0,'5363'),(571206,179404,'1712755911.735376','printshop','style_class','header-middle',0,''),(571207,179404,'1712755911.735376','printshop','position','relative',0,''),(571208,179404,'1712755911.735376','printshop','background-color','$header-bg-1',0,''),(571209,179404,'1712755911.735376','printshop','border-bottom-width','1',0,''),(571210,179404,'1712755911.735376','printshop','border-bottom-color','$header-border-1',0,''),(571211,179404,'1712755911.735376','printshop','color','$header-color-1',0,''),(571212,179404,'1712755911.735376','printshop','from_file','h.zip',0,''),(571276,179411,'1712756000.134372','printshop','from_file','header_1.zip',0,''),(571277,179412,'1712756000.136830','printshop','block_type','1',0,''),(571278,179412,'1712756000.136830','printshop','border-bottom-width','1',0,''),(571279,179412,'1712756000.136830','printshop','border-bottom-color','$header-border-1',0,''),(571280,179412,'1712756000.136830','printshop','font-weight','normal',0,''),(571281,179412,'1712756000.136830','printshop','visibility_checkout','1',0,''),(571282,179412,'1712756000.136830','printshop','background-color','$header-bg-1',0,''),(571283,179412,'1712756000.136830','printshop','color','$header-color-1',0,''),(571284,179412,'1712756000.136830','printshop','from_file','header_1.zip',0,''),(571323,179420,'1712756000.37386','printshop','block_type','1',0,''),(571324,179420,'1712756000.37386','printshop','padding-top','20',0,''),(571325,179420,'1712756000.37386','printshop','padding-bottom','20',0,''),(571326,179420,'1712756000.37386','printshop','style_class','header-content',0,''),(571327,179420,'1712756000.37386','printshop','color','$header-color-1',0,''),(571328,179420,'1712756000.37386','printshop','background-color','$header-bg-1',0,''),(571329,179420,'1712756000.37386','printshop','from_file','header_1.zip',0,''),(571330,179420,'1712756000.37386','printshop','padding-top','12',0,'5333'),(571331,179420,'1712756000.37386','printshop','padding-bottom','12',0,'5333'),(571349,179424,'1712756000.489135','printshop','block_type','1',0,''),(571350,179424,'1712756000.489135','printshop','font-weight','400',0,''),(571351,179424,'1712756000.489135','printshop','background-color','$header-menu-bg-1',0,''),(571352,179424,'1712756000.489135','printshop','visibility_checkout','1',0,''),(571353,179424,'1712756000.489135','printshop','color','$header-menu-color-1',0,''),(571354,179424,'1712756000.489135','printshop','from_file','header_1.zip',0,''),(571355,179424,'1712756000.489135','printshop','style_class','header-menu-holder',0,''),(571386,179426,'1712756007.569966','printshop','from_file','h.zip',0,''),(571387,179427,'1712756007.57315','printshop','block_type','1',0,''),(571388,179427,'1712756007.57315','printshop','border-bottom-width','1',0,''),(571389,179427,'1712756007.57315','printshop','border-bottom-color','$header-border-1',0,''),(571390,179427,'1712756007.57315','printshop','font-weight','normal',0,''),(571391,179427,'1712756007.57315','printshop','visibility_checkout','1',0,''),(571392,179427,'1712756007.57315','printshop','display_none','1',0,'5342'),(571393,179427,'1712756007.57315','printshop','style_class','topHeader',0,''),(571394,179427,'1712756007.57315','printshop','padding-top','10',0,''),(571395,179427,'1712756007.57315','printshop','padding-bottom','10',0,''),(571396,179427,'1712756007.57315','printshop','background-color','$header-bg-1',0,''),(571397,179427,'1712756007.57315','printshop','color','$header-color-1',0,''),(571398,179427,'1712756007.57315','printshop','from_file','h.zip',0,''),(571399,179428,'1712756007.585982','printshop','block_type','5',0,''),(571400,179428,'1712756007.585982','printshop','font-weight','400',0,''),(571401,179428,'1712756007.585982','printshop','schema','2-2',0,''),(571402,179428,'1712756007.585982','printshop','schema','5-1',0,'5342'),(571403,179429,'1712756007.5885','printshop','view_item','phone_number',0,''),(571404,179429,'1712756007.5885','printshop','font-size','15',0,''),(571405,179430,'1712756007.589787','printshop','text','<span class=\"phone-title\">Phone:</span>',1,''),(571406,179430,'1712756007.589787','printshop','display','inline-block',0,''),(571407,179430,'1712756007.589787','printshop','float','left',0,''),(571408,179430,'1712756007.589787','printshop','font-size','15',0,''),(571409,179430,'1712756007.589787','printshop','color','$fade-color-1',0,''),(571410,179430,'1712756007.589787','printshop','text','<span class=\"phone-title\">Phone:</span>',0,''),(571411,179431,'1712756007.62595','printshop','block_type','1',0,''),(571412,179432,'1712756007.627579','printshop','class','menu-horizontal',0,''),(571413,179432,'1712756007.627579','printshop','box_align','2',0,''),(571414,179432,'1712756007.627579','printshop','font-weight','400',0,''),(571415,179432,'1712756007.627579','printshop','float','right',0,''),(571416,179432,'1712756007.627579','printshop','display_none','1',0,'5363'),(571417,179432,'1712756007.627579','printshop','padding-right','5',0,''),(571418,179432,'1712756007.627579','printshop','line-height','1.4',0,''),(571419,179432,'1712756007.627579','printshop','padding-top','2',0,''),(571420,179433,'1712756007.729922','printshop','float','right',0,''),(571421,179434,'1712756007.738185','printshop','text','<span class=\"email-title\">E-mail:</span>',1,''),(571422,179434,'1712756007.738185','printshop','font-size','15',0,''),(571423,179434,'1712756007.738185','printshop','color','$fade-color-1',0,''),(571424,179434,'1712756007.738185','printshop','float','right',0,''),(571425,179434,'1712756007.738185','printshop','margin-right','7',0,'3'),(571426,179434,'1712756007.738185','printshop','line-height','1',0,''),(571427,179434,'1712756007.738185','printshop','padding-left','15',0,''),(571428,179434,'1712756007.738185','printshop','border-left-width','1',0,''),(571429,179434,'1712756007.738185','printshop','border-left-color','$content-border-1',0,''),(571430,179434,'1712756007.738185','printshop','padding-top','3',0,''),(571431,179434,'1712756007.738185','printshop','text','<span class=\"email-title\">E-mail:</span>',0,''),(571432,179435,'1712756007.772518','printshop','view_item','email',0,''),(571433,179435,'1712756007.772518','printshop','float','right',0,''),(571434,179435,'1712756007.772518','printshop','add_link_on_email','1',0,''),(571435,179435,'1712756007.772518','printshop','font-size','15',0,''),(571436,179436,'1712756007.774661','printshop','block_type','1',0,''),(571437,179436,'1712756007.774661','printshop','padding-top','3',0,''),(571438,179436,'1712756007.774661','printshop','padding-top','0',0,'5363'),(571439,179436,'1712756007.774661','printshop','padding-bottom','0',0,'5363'),(571440,179436,'1712756007.774661','printshop','style_class','header-middle',0,''),(571441,179436,'1712756007.774661','printshop','position','relative',0,''),(571442,179436,'1712756007.774661','printshop','background-color','$header-bg-1',0,''),(571443,179436,'1712756007.774661','printshop','border-bottom-width','1',0,''),(571444,179436,'1712756007.774661','printshop','border-bottom-color','$header-border-1',0,''),(571445,179436,'1712756007.774661','printshop','color','$header-color-1',0,''),(571446,179436,'1712756007.774661','printshop','from_file','h.zip',0,''),(571447,179437,'1712756007.779822','printshop','font-weight','400',0,''),(571448,179437,'1712756007.779822','printshop','box_align','1',0,''),(571449,179437,'1712756007.779822','printshop','width_measure','%',0,'5363'),(571450,179437,'1712756007.779822','printshop','logo_from','theme',0,''),(571451,179437,'1712756007.779822','printshop','float','left',0,''),(571452,179437,'1712756007.779822','printshop','clear','both',0,''),(571453,179437,'1712756007.779822','printshop','margin-top','22',0,''),(571454,179437,'1712756007.779822','printshop','margin-bottom','22',0,''),(571455,179437,'1712756007.779822','printshop','width','130',0,'5342'),(571456,179437,'1712756007.779822','printshop','padding-right','40',0,''),(571457,179437,'1712756007.779822','printshop','margin-right','70',0,''),(571458,179437,'1712756007.779822','printshop','border-right-width','1',0,''),(571459,179437,'1712756007.779822','printshop','border-right-color','$header-border-1',0,''),(571460,179437,'1712756007.779822','printshop','width','130',0,'5333'),(571461,179437,'1712756007.779822','printshop','padding-right','10',0,'5333'),(571462,179437,'1712756007.779822','printshop','margin-right','10',0,'5333'),(571463,179437,'1712756007.779822','printshop','margin-top','10',0,'5342'),(571464,179437,'1712756007.779822','printshop','margin-bottom','10',0,'5342'),(571465,179438,'1712756007.783714','printshop','font-weight','400',0,''),(571466,179438,'1712756007.783714','printshop','visibility_checkout','1',0,''),(571467,179438,'1712756007.783714','printshop','float','right',0,''),(571468,179438,'1712756007.783714','printshop','clear','none',0,''),(571469,179438,'1712756007.783714','printshop','margin-top','7',0,'5342'),(571470,179438,'1712756007.783714','printshop','color','$content-color-1',0,''),(571471,179438,'1712756007.783714','printshop','search_history','1',0,''),(571472,179439,'1712756007.85127','printshop','font-weight','400',0,''),(571473,179439,'1712756007.85127','printshop','box_align','3',0,''),(571474,179439,'1712756007.85127','printshop','only_icon','on',0,''),(571475,179439,'1712756007.85127','printshop','items','1',0,''),(571476,179439,'1712756007.85127','printshop','show_products','dropdown',0,''),(571477,179440,'1712756007.912178','printshop','font-weight','normal',0,''),(571478,179440,'1712756007.912178','printshop','box_align','3',0,''),(571479,179440,'1712756007.912178','printshop','only_icon','on',0,''),(571480,179440,'1712756007.912178','printshop','margin-left','20',0,''),(571481,179440,'1712756007.912178','printshop','margin-left','10',0,'5342'),(571482,179440,'1712756007.912178','printshop','link_or_dropdown','1',0,''),(571483,179440,'1712756007.912178','printshop','margin-left','0',0,'5333'),(571484,179441,'1712756007.950557','printshop','block_type','1',0,''),(571485,179441,'1712756007.950557','printshop','float','left',0,''),(571486,179441,'1712756007.950557','printshop','style_class','header-menu-holder',0,''),(571487,179442,'1712756007.953578','printshop','class','menu-style-1',0,''),(571488,179442,'1712756007.953578','printshop','box_align','4',0,''),(571489,179442,'1712756007.953578','printshop','hide_menu','on',0,''),(571490,179442,'1712756007.953578','printshop','hide_menu','1',0,'5342'),(571491,179442,'1712756007.953578','printshop','show_new','1',0,''),(571492,179442,'1712756007.953578','printshop','type','builder',0,''),(571493,179442,'1712756007.953578','printshop','open_from','top',0,'5342'),(571494,179442,'1712756007.953578','printshop','lev2_vis','click',0,'5342'),(571495,179442,'1712756007.953578','printshop','lev3_vis','click',0,'5400'),(571496,179442,'1712756007.953578','printshop','style','1',0,'5408'),(571497,179442,'1712756007.953578','printshop','position','horizontal_left',0,'5408'),(571498,179442,'1712756007.953578','printshop','lev2_vis','over',0,'5408'),(571499,179442,'1712756007.953578','printshop','lev2_display','width',0,'5408'),(571500,179442,'1712756007.953578','printshop','open_from','top',0,'5347'),(571501,179442,'1712756007.953578','printshop','lev2_vis','click',0,'5347'),(571502,179442,'1712756007.953578','printshop','lev4_vis','click',0,'5347'),(571503,179442,'1712756007.953578','printshop','burger_icon','1',0,'5347'),(571504,179442,'1712756007.953578','printshop','style','2',0,'5347'),(571505,179442,'1712756007.953578','printshop','lev3_vis','click',0,'5347'),(571506,179442,'1712756007.953578','printshop','lev3_vis','click',0,'5342'),(571507,179442,'1712756007.953578','printshop','style','2',0,'5342'),(571508,179442,'1712756007.953578','printshop','burger_icon','1',0,'5342'),(571509,179442,'1712756007.953578','printshop','style_class','header-menu',0,''),(571510,179443,'1712823796.145167','deals','from_file','header_1.zip',0,''),(571511,179444,'1712823796.149115','deals','block_type','1',0,''),(571512,179444,'1712823796.149115','deals','border-bottom-width','1',0,''),(571513,179444,'1712823796.149115','deals','border-bottom-color','$header-border-1',0,''),(571514,179444,'1712823796.149115','deals','font-weight','normal',0,''),(571515,179444,'1712823796.149115','deals','visibility_checkout','1',0,''),(571516,179444,'1712823796.149115','deals','background-color','$header-bg-1',0,''),(571517,179444,'1712823796.149115','deals','color','$header-color-1',0,''),(571518,179444,'1712823796.149115','deals','from_file','header_1.zip',0,''),(571557,179452,'1712823796.44032','deals','block_type','1',0,''),(571558,179452,'1712823796.44032','deals','padding-top','20',0,''),(571559,179452,'1712823796.44032','deals','padding-bottom','20',0,''),(571560,179452,'1712823796.44032','deals','style_class','header-content',0,''),(571561,179452,'1712823796.44032','deals','color','$header-color-1',0,''),(571562,179452,'1712823796.44032','deals','background-color','$header-bg-1',0,''),(571563,179452,'1712823796.44032','deals','from_file','header_1.zip',0,''),(571564,179452,'1712823796.44032','deals','padding-top','12',0,'5630'),(571565,179452,'1712823796.44032','deals','padding-bottom','12',0,'5630'),(571583,179456,'1712823796.566882','deals','block_type','1',0,''),(571584,179456,'1712823796.566882','deals','font-weight','400',0,''),(571585,179456,'1712823796.566882','deals','background-color','$header-menu-bg-1',0,''),(571586,179456,'1712823796.566882','deals','visibility_checkout','1',0,''),(571587,179456,'1712823796.566882','deals','color','$header-menu-color-1',0,''),(571588,179456,'1712823796.566882','deals','from_file','header_1.zip',0,''),(571589,179456,'1712823796.566882','deals','style_class','header-menu-holder',0,''),(571620,179458,'1712823935.978146','deals','block_type','1',0,''),(571621,179458,'1712823935.978146','deals','style_class','fixed-header',0,''),(571622,179458,'1712823935.978146','deals','from_file','header_4.zip',0,''),(571623,179459,'1712823935.987731','deals','block_type','1',0,''),(571624,179459,'1712823935.987731','deals','style_class','header-content',0,''),(571625,179460,'1712823935.994767','deals','font-weight','400',0,''),(571626,179460,'1712823935.994767','deals','box_align','1',0,''),(571627,179460,'1712823935.994767','deals','logo','themes/deals/img/Logo-TPD-orange-2.jpg',1,''),(571628,179460,'1712823935.994767','deals','text-align','left',0,'5660'),(571629,179460,'1712823935.994767','deals','width_measure','%',0,'5660'),(571630,179460,'1712823935.994767','deals','margin-right','40',0,''),(571631,179460,'1712823935.994767','deals','logo_from','theme',0,''),(571632,179460,'1712823935.994767','deals','logo','themes/deals/img/Logo-TPD-orange-2.jpg',0,''),(571633,179461,'1712823935.997331','deals','font-weight','400',0,''),(571634,179461,'1712823935.997331','deals','search_history','1',0,''),(571635,179462,'1712823936.133379','deals','font-weight','400',0,''),(571636,179462,'1712823936.133379','deals','box_align','3',0,''),(571637,179462,'1712823936.133379','deals','show_products','dropdown',0,''),(571638,179462,'1712823936.133379','deals','only_icon','on',0,''),(571639,179462,'1712823936.133379','deals','items','1',0,''),(571640,179463,'1712823936.18733','deals','font-weight','normal',0,''),(571641,179463,'1712823936.18733','deals','box_align','3',0,''),(571642,179463,'1712823936.18733','deals','only_icon','on',0,''),(571643,179463,'1712823936.18733','deals','link_or_dropdown','1',0,''),(571644,179464,'1712823936.243618','deals','block_type','1',0,''),(571645,179465,'1712823936.245254','deals','box_align','4',0,''),(571646,179465,'1712823936.245254','deals','hide_menu','on',0,''),(571647,179465,'1712823936.245254','deals','style_class','topMenu',0,''),(571648,179465,'1712823936.245254','deals','show_images','10',0,''),(571649,179465,'1712823936.245254','deals','type','builder',0,''),(571650,179465,'1712823936.245254','deals','lev2_vis','click',0,'5630'),(571651,179465,'1712823936.245254','deals','style','1',0,'5705'),(571652,179465,'1712823936.245254','deals','style','2',0,'5630'),(571653,179465,'1712823936.245254','deals','lev2_vis','over',0,'5705'),(571654,179465,'1712823936.245254','deals','lev3_vis','over',0,'5705'),(571655,179465,'1712823936.245254','deals','lev3_display','lra',0,'5705'),(571656,179465,'1712823936.245254','deals','lev3_vis','click',0,'5630'),(571657,179465,'1712823936.245254','deals','lev3_display','slide',0,'5630'),(571658,179465,'1712823936.245254','deals','visibility_checkout','1',0,''),(571659,179465,'1712823936.245254','deals','lev2_display','down',0,''),(571660,179465,'1712823936.245254','deals','lev2_vis','over',0,''),(571661,179465,'1712823936.245254','deals','burger_icon','1',0,''),(571662,179465,'1712823936.245254','deals','lev2_display','lra',0,'5705'),(571663,179465,'1712823936.245254','deals','lev4_display','lra',0,'5705'),(571664,179465,'1712823936.245254','deals','lev5_display','lra',0,'5705'),(571665,179465,'1712823936.245254','deals','lev6_display','lra',0,'5705'),(571666,179465,'1712823936.245254','deals','lev4_vis','over',0,'5705'),(571667,179465,'1712823936.245254','deals','lev5_vis','over',0,'5705'),(571668,179465,'1712823936.245254','deals','lev6_vis','over',0,'5705'),(571669,179465,'1712823936.245254','deals','burger_icon','1',0,'5630'),(571670,179465,'1712823936.245254','deals','open_from','left',0,'5630'),(571671,179465,'1712823936.245254','deals','lev2_display','slide',0,'5630'),(600618,188838,'1713773685.115477','watch','block_type','1',0,''),(600619,188838,'1713773685.115477','watch','style_class','account-index',0,''),(600620,188838,'1713773685.115477','watch','from_file','account_main_pages.zip',0,''),(600624,188841,'73374','watch','block_type','1',0,''),(600625,188841,'73374','watch','padding-top','70',0,''),(600626,188841,'73374','watch','padding-right','30',0,''),(600627,188841,'73374','watch','padding-bottom','30',0,''),(600628,188841,'73374','watch','padding-top','0',0,'5240'),(600629,188841,'73374','watch','padding-left','0',0,'5240'),(600630,188841,'73374','watch','padding-right','0',0,'5240'),(600631,188841,'73374','watch','padding-bottom','0',0,'5240'),(600801,188883,'1713773685.730386','watch','block_type','1',0,''),(600802,188883,'1713773685.730386','watch','from_file','account_main_pages.zip',0,''),(600806,188886,'73374','watch','block_type','1',0,''),(600807,188886,'73374','watch','padding-top','70',0,''),(600808,188886,'73374','watch','padding-right','30',0,''),(600809,188886,'73374','watch','padding-bottom','30',0,''),(600810,188886,'73374','watch','padding-top','0',0,'5240'),(600811,188886,'73374','watch','padding-left','0',0,'5240'),(600812,188886,'73374','watch','padding-right','0',0,'5240'),(600813,188886,'73374','watch','padding-bottom','0',0,'5240'),(600865,188907,'1713773686.073331','watch','block_type','1',0,''),(600866,188907,'1713773686.073331','watch','style_class','account-order-history-info',0,''),(600867,188907,'1713773686.073331','watch','from_file','account_main_pages.zip',0,''),(600871,188910,'73374','watch','block_type','1',0,''),(600872,188910,'73374','watch','padding-top','70',0,''),(600873,188910,'73374','watch','padding-right','30',0,''),(600874,188910,'73374','watch','padding-bottom','30',0,''),(600875,188910,'73374','watch','padding-top','0',0,'5240'),(600876,188910,'73374','watch','padding-left','0',0,'5240'),(600877,188910,'73374','watch','padding-right','0',0,'5240'),(600878,188910,'73374','watch','padding-bottom','0',0,'5240'),(600999,188966,'1713773686.551292','watch','block_type','1',0,''),(601000,188966,'1713773686.551292','watch','style_class','account-edit-wrap',0,''),(601001,188966,'1713773686.551292','watch','from_file','account_main_pages.zip',0,''),(601005,188969,'73374','watch','block_type','1',0,''),(601006,188969,'73374','watch','padding-top','70',0,''),(601007,188969,'73374','watch','padding-right','30',0,''),(601008,188969,'73374','watch','padding-bottom','30',0,''),(601009,188969,'73374','watch','padding-top','0',0,'5240'),(601010,188969,'73374','watch','padding-left','0',0,'5240'),(601011,188969,'73374','watch','padding-right','0',0,'5240'),(601012,188969,'73374','watch','padding-bottom','0',0,'5240'),(601063,188990,'1713773686.886195','watch','block_type','1',0,''),(601064,188990,'1713773686.886195','watch','style_class','account-order-history',0,''),(601065,188990,'1713773686.886195','watch','from_file','account_main_pages.zip',0,''),(601069,188993,'73374','watch','block_type','1',0,''),(601070,188993,'73374','watch','padding-top','70',0,''),(601071,188993,'73374','watch','padding-right','30',0,''),(601072,188993,'73374','watch','padding-bottom','30',0,''),(601073,188993,'73374','watch','padding-top','0',0,'5240'),(601074,188993,'73374','watch','padding-left','0',0,'5240'),(601075,188993,'73374','watch','padding-right','0',0,'5240'),(601076,188993,'73374','watch','padding-bottom','0',0,'5240'),(601132,189014,'1713774131.524999','watch','block_type','1',0,''),(601133,189014,'1713774131.524999','watch','style_class','account-index',0,''),(601134,189014,'1713774131.524999','watch','from_file','account-2.zip',0,''),(601135,189015,'1713774131.631466','watch','block_type','6',0,''),(601136,189015,'1713774131.631466','watch','schema','6-3',0,'5240'),(601137,189016,'1713774131.633419','watch','aria_name','account-menu',0,''),(601138,189017,'73374','watch','block_type','1',0,''),(601139,189017,'73374','watch','padding-top','70',0,''),(601140,189017,'73374','watch','padding-right','30',0,''),(601141,189017,'73374','watch','padding-bottom','30',0,''),(601142,189017,'73374','watch','padding-top','0',0,'5240'),(601143,189017,'73374','watch','padding-left','0',0,'5240'),(601144,189017,'73374','watch','padding-right','0',0,'5240'),(601145,189017,'73374','watch','padding-bottom','0',0,'5240'),(601188,189036,'1713774131.989231','watch','block_type','1',0,''),(601189,189037,'1713774131.990525','watch','link','Order History Info',0,''),(601190,189037,'1713774131.990525','watch','text','TEXT_VIEW',0,''),(601191,189037,'1713774131.990525','watch','max_orders','3',0,''),(601192,189037,'1713774131.990525','watch','link_pay','Order pay',0,''),(601193,189037,'1713774131.990525','watch','margin-bottom','30',0,''),(601194,189037,'1713774131.990525','watch','text_pay','ORDER_PAY',0,''),(601195,189038,'1713774131.992548','watch','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(601196,189039,'1713774131.995359','watch','text','<h1>##HEADING_TITLE##</h1>',0,''),(601197,189040,'1713774132.011364','watch','block_type','1',0,''),(601198,189040,'1713774132.011364','watch','padding-top','20',0,''),(601199,189040,'1713774132.011364','watch','padding-left','20',0,''),(601200,189040,'1713774132.011364','watch','padding-right','20',0,''),(601201,189040,'1713774132.011364','watch','padding-bottom','20',0,''),(601202,189040,'1713774132.011364','watch','margin-bottom','30',0,''),(601203,189040,'1713774132.011364','watch','border-top-width','1',0,''),(601204,189040,'1713774132.011364','watch','border-left-width','1',0,''),(601205,189040,'1713774132.011364','watch','border-right-width','1',0,''),(601206,189040,'1713774132.011364','watch','border-bottom-width','1',0,''),(601207,189040,'1713774132.011364','watch','border-top-color','$content-border-1',0,''),(601208,189040,'1713774132.011364','watch','border-left-color','$content-border-1',0,''),(601209,189040,'1713774132.011364','watch','border-right-color','$content-border-1',0,''),(601210,189040,'1713774132.011364','watch','border-bottom-color','$content-border-1',0,''),(601211,189040,'1713774132.011364','watch','style_class','account-content-top',0,''),(601212,189041,'1713774132.020828','watch','block_type','1',0,''),(601213,189042,'1713774132.02226','watch','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(601214,189042,'1713774132.02226','watch','font-family','trueloaded',0,'3'),(601215,189042,'1713774132.02226','watch','content','\\e920',0,'3'),(601216,189042,'1713774132.02226','watch','color','$highlight-color-3',0,'3'),(601217,189042,'1713774132.02226','watch','font-size','30',0,'3'),(601218,189042,'1713774132.02226','watch','text-align','center',0,'3'),(601219,189042,'1713774132.02226','watch','margin-bottom','10',0,'3'),(601220,189042,'1713774132.02226','watch','text-align','center',0,''),(601221,189042,'1713774132.02226','watch','font-size','16',0,''),(601222,189042,'1713774132.02226','watch','text-transform','uppercase',0,''),(601223,189042,'1713774132.02226','watch','line-height','1',0,'3'),(601224,189042,'1713774132.02226','watch','font-size','14',0,'5232'),(601225,189043,'1713774132.02710','watch','font-family','$font-1',0,''),(601226,189043,'1713774132.02710','watch','color','$highlight-color-3',0,''),(601227,189043,'1713774132.02710','watch','font-size','14',0,''),(601228,189043,'1713774132.02710','watch','text-align','center',0,''),(601229,189044,'1713774132.037763','watch','block_type','1',0,''),(601230,189045,'1713774132.039110','watch','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(601231,189045,'1713774132.039110','watch','font-family','trueloaded',0,'3'),(601232,189045,'1713774132.039110','watch','content','\\e928',0,'3'),(601233,189045,'1713774132.039110','watch','color','$highlight-color-3',0,'3'),(601234,189045,'1713774132.039110','watch','font-size','30',0,'3'),(601235,189045,'1713774132.039110','watch','text-align','center',0,'3'),(601236,189045,'1713774132.039110','watch','text-align','center',0,''),(601237,189045,'1713774132.039110','watch','font-size','16',0,''),(601238,189045,'1713774132.039110','watch','text-transform','uppercase',0,''),(601239,189045,'1713774132.039110','watch','line-height','1',0,'3'),(601240,189045,'1713774132.039110','watch','font-size','14',0,'5232'),(601241,189046,'1713774132.04388','watch','font-family','$font-1',0,''),(601242,189046,'1713774132.04388','watch','color','$highlight-color-3',0,''),(601243,189046,'1713774132.04388','watch','font-size','14',0,''),(601244,189046,'1713774132.04388','watch','text-align','center',0,''),(601245,189047,'1713774132.045662','watch','link','download_orders',0,''),(601246,189047,'1713774132.045662','watch','text','TEXT_DOWNLOAD_ORDERS',0,''),(601247,189047,'1713774132.045662','watch','hide_link','orders',0,''),(601248,189047,'1713774132.045662','watch','text-align','center',0,''),(601249,189047,'1713774132.045662','watch','popup','2',0,''),(601250,189047,'1713774132.045662','watch','font-size','14',0,''),(601251,189048,'1713774132.047643','watch','block_type','1',0,''),(601252,189049,'1713774132.048770','watch','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(601253,189049,'1713774132.048770','watch','font-family','trueloaded',0,'3'),(601254,189049,'1713774132.048770','watch','content','\\e922',0,'3'),(601255,189049,'1713774132.048770','watch','color','$highlight-color-3',0,'3'),(601256,189049,'1713774132.048770','watch','font-size','30',0,'3'),(601257,189049,'1713774132.048770','watch','line-height','1',0,'3'),(601258,189049,'1713774132.048770','watch','font-size','16',0,''),(601259,189049,'1713774132.048770','watch','text-align','center',0,''),(601260,189049,'1713774132.048770','watch','text-transform','uppercase',0,''),(601261,189049,'1713774132.048770','watch','font-size','14',0,'5232'),(601262,189050,'1713774132.053414','watch','font-family','$font-1',0,''),(601263,189050,'1713774132.053414','watch','color','$highlight-color-3',0,''),(601264,189050,'1713774132.053414','watch','line-height','1',0,''),(601265,189050,'1713774132.053414','watch','text-align','center',0,''),(601266,189050,'1713774132.053414','watch','font-size','14',0,''),(601267,189051,'1713774132.055889','watch','block_type','1',0,''),(601268,189052,'1713774132.05740','watch','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(601269,189052,'1713774132.05740','watch','content','\\e994',0,'3'),(601270,189052,'1713774132.05740','watch','font-family','trueloaded',0,'3'),(601271,189052,'1713774132.05740','watch','color','$highlight-color-3',0,'3'),(601272,189052,'1713774132.05740','watch','font-size','30',0,'3'),(601273,189052,'1713774132.05740','watch','line-height','1',0,'3'),(601274,189052,'1713774132.05740','watch','font-size','16',0,''),(601275,189052,'1713774132.05740','watch','text-align','center',0,''),(601276,189052,'1713774132.05740','watch','text-transform','uppercase',0,''),(601277,189052,'1713774132.05740','watch','font-size','14',0,'5232'),(601278,189053,'1713774132.061556','watch','font-family','$font-1',0,''),(601279,189053,'1713774132.061556','watch','color','$highlight-color-3',0,''),(601280,189053,'1713774132.061556','watch','font-size','14',0,''),(601281,189053,'1713774132.061556','watch','text-align','center',0,''),(601282,189054,'1713774132.127825','watch','link','Gift Certificate',0,''),(601283,189054,'1713774132.127825','watch','text','GIFT_CERTIFICATE',0,''),(601284,189054,'1713774132.127825','watch','popup','1',0,''),(601285,189054,'1713774132.127825','watch','text-align','center',0,''),(601286,189054,'1713774132.127825','watch','font-size','14',0,''),(601287,189055,'1713774132.130117','watch','block_type','1',0,''),(601288,189056,'1713774132.131332','watch','text','TEXT_VIEW_HISTORY',0,''),(601289,189056,'1713774132.131332','watch','popup','1',0,''),(601290,189056,'1713774132.131332','watch','text-align','center',0,''),(601291,189056,'1713774132.131332','watch','link','Points Earnt History',0,''),(601292,189056,'1713774132.131332','watch','font-size','14',0,''),(601293,189057,'1713774132.133341','watch','font-family','$font-1',0,''),(601294,189057,'1713774132.133341','watch','color','$highlight-color-3',0,''),(601295,189057,'1713774132.133341','watch','font-size','14',0,''),(601296,189057,'1713774132.133341','watch','text-align','center',0,''),(601297,189058,'1713774132.13514','watch','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(601298,189058,'1713774132.13514','watch','content','\\e990',0,'3'),(601299,189058,'1713774132.13514','watch','font-family','trueloaded',0,'3'),(601300,189058,'1713774132.13514','watch','font-size','30',0,'3'),(601301,189058,'1713774132.13514','watch','text-align','center',0,'3'),(601302,189058,'1713774132.13514','watch','line-height','1',0,'3'),(601303,189058,'1713774132.13514','watch','color','$highlight-color-3',0,'3'),(601304,189058,'1713774132.13514','watch','font-size','16',0,''),(601305,189058,'1713774132.13514','watch','text-align','center',0,''),(601306,189058,'1713774132.13514','watch','text-transform','uppercase',0,''),(601307,189058,'1713774132.13514','watch','font-size','14',0,'5232'),(601308,189059,'1713774132.139570','watch','block_type','1',0,''),(601309,189059,'1713774132.139570','watch','from_file','account-2.zip',0,''),(601310,189060,'1713774132.140834','watch','block_type','6',0,''),(601311,189060,'1713774132.140834','watch','schema','6-3',0,'5240'),(601312,189061,'1713774132.141911','watch','aria_name','account-menu',0,''),(601313,189062,'73374','watch','block_type','1',0,''),(601314,189062,'73374','watch','padding-top','70',0,''),(601315,189062,'73374','watch','padding-right','30',0,''),(601316,189062,'73374','watch','padding-bottom','30',0,''),(601317,189062,'73374','watch','padding-top','0',0,'5240'),(601318,189062,'73374','watch','padding-left','0',0,'5240'),(601319,189062,'73374','watch','padding-right','0',0,'5240'),(601320,189062,'73374','watch','padding-bottom','0',0,'5240'),(601363,189081,'1713774132.504954','watch','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(601364,189082,'1713774132.508462','watch','margin-bottom','20',0,''),(601365,189083,'1713774132.514786','watch','block_type','1',0,''),(601366,189083,'1713774132.514786','watch','style_class','account-order-history-info',0,''),(601367,189083,'1713774132.514786','watch','from_file','account-2.zip',0,''),(601368,189084,'1713774132.550697','watch','block_type','6',0,''),(601369,189084,'1713774132.550697','watch','schema','6-3',0,'5240'),(601370,189085,'1713774132.552317','watch','aria_name','account-menu',0,''),(601371,189086,'73374','watch','block_type','1',0,''),(601372,189086,'73374','watch','padding-top','70',0,''),(601373,189086,'73374','watch','padding-right','30',0,''),(601374,189086,'73374','watch','padding-bottom','30',0,''),(601375,189086,'73374','watch','padding-top','0',0,'5240'),(601376,189086,'73374','watch','padding-left','0',0,'5240'),(601377,189086,'73374','watch','padding-right','0',0,'5240'),(601378,189086,'73374','watch','padding-bottom','0',0,'5240'),(601421,189105,'1713774132.898941','watch','float','right',0,''),(601422,189105,'1713774132.898941','watch','clear','none',0,''),(601423,189105,'1713774132.898941','watch','margin-left','20',0,''),(601424,189107,'1713774132.901231','watch','float','right',0,''),(601425,189107,'1713774132.901231','watch','clear','none',0,''),(601426,189107,'1713774132.901231','watch','like_button','2',0,''),(601427,189107,'1713774132.901231','watch','link','Order pay',0,''),(601428,189108,'1713774132.902540','watch','block_type','2',0,''),(601429,189108,'1713774132.902540','watch','padding-top','20',0,''),(601430,189108,'1713774132.902540','watch','margin-bottom','20',0,''),(601431,189109,'1713774132.903770','watch','like_button','1',0,''),(601432,189109,'1713774132.903770','watch','text','IMAGE_BUTTON_BACK',0,''),(601433,189109,'1713774132.903770','watch','link','Order History',0,''),(601434,189110,'1713774132.90524','watch','text-align','right',0,''),(601435,189111,'1713774132.905816','watch','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(601436,189113,'1713774132.910483','watch','float','right',0,''),(601437,189113,'1713774132.910483','watch','clear','none',0,''),(601438,189113,'1713774132.910483','watch','margin-left','20',0,''),(601439,189115,'1713774132.913316','watch','float','right',0,''),(601440,189116,'1713774132.915188','watch','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(601441,189118,'1713774132.918550','watch','float','left',0,''),(601442,189119,'1713774132.919848','watch','block_type','3',0,''),(601443,189119,'1713774132.919848','watch','clear','both',0,''),(601444,189119,'1713774132.919848','watch','padding-top','20',0,''),(601445,189119,'1713774132.919848','watch','schema','3-4',0,'5232'),(601446,189120,'1713774132.921595','watch','block_type','1',0,''),(601447,189120,'1713774132.921595','watch','margin-bottom','20',0,''),(601448,189120,'1713774132.921595','watch','padding-right','20',0,''),(601449,189121,'1713774132.92285','watch','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(601450,189122,'1713774132.92519','watch','padding-left','30',0,''),(601451,189122,'1713774132.92519','watch','orders_data','telephone',0,''),(601452,189122,'1713774132.92519','watch','hide_parents','2',0,''),(601453,189123,'1713774132.92663','watch','block_type','1',0,''),(601454,189123,'1713774132.92663','watch','padding-right','20',0,''),(601455,189123,'1713774132.92663','watch','padding-bottom','20',0,''),(601456,189124,'1713774132.9280','watch','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(601457,189125,'1713774132.932360','watch','orders_data','name',0,''),(601458,189125,'1713774132.932360','watch','padding-left','30',0,''),(601459,189126,'1713774132.933540','watch','block_type','1',0,''),(601460,189126,'1713774132.933540','watch','padding-right','20',0,''),(601461,189126,'1713774132.933540','watch','margin-bottom','20',0,''),(601462,189127,'1713774132.93487','watch','short_view','1',0,''),(601463,189127,'1713774132.93487','watch','hide_parents','2',0,''),(601464,189128,'1713774132.936634','watch','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(601465,189129,'1713774132.938818','watch','link','Tracking numbers',0,''),(601466,189129,'1713774132.938818','watch','text','MORE_TRACKING_NUMBER',0,''),(601467,189129,'1713774132.938818','watch','popup','1',0,''),(601468,189129,'1713774132.938818','watch','order_id','1',0,''),(601469,189129,'1713774132.938818','watch','popup_class','tracking-numbers-popup',0,''),(601470,189129,'1713774132.938818','watch','font-weight','700',0,''),(601471,189129,'1713774132.938818','watch','font-size','18',0,''),(601472,189130,'1713774132.940770','watch','block_type','1',0,''),(601473,189130,'1713774132.940770','watch','padding-right','20',0,''),(601474,189131,'1713774132.941988','watch','orders_data','shipping_method',0,''),(601475,189131,'1713774132.941988','watch','padding-left','30',0,''),(601476,189132,'1713774132.94319','watch','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(601477,189133,'1713774132.945272','watch','block_type','1',0,''),(601478,189133,'1713774132.945272','watch','padding-right','20',0,''),(601479,189133,'1713774132.945272','watch','padding-bottom','20',0,''),(601480,189134,'1713774132.946358','watch','orders_data','delivery_address',0,''),(601481,189134,'1713774132.946358','watch','padding-left','30',0,''),(601482,189135,'1713774132.947328','watch','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(601483,189136,'1713774132.949323','watch','block_type','1',0,''),(601484,189137,'1713774132.950533','watch','orders_data','payment_method',0,''),(601485,189137,'1713774132.950533','watch','padding-left','30',0,''),(601486,189138,'1713774132.951838','watch','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(601487,189139,'1713774132.953990','watch','block_type','1',0,''),(601488,189139,'1713774132.953990','watch','padding-bottom','20',0,''),(601489,189140,'1713774132.955210','watch','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(601490,189141,'1713774132.957413','watch','orders_data','billing_address',0,''),(601491,189141,'1713774132.957413','watch','padding-left','30',0,''),(601492,189142,'1713774132.958422','watch','block_type','1',0,''),(601493,189142,'1713774132.958422','watch','style_class','account-address-book',0,''),(601494,189142,'1713774132.958422','watch','from_file','account-2.zip',0,''),(601495,189143,'1713774132.959666','watch','block_type','6',0,''),(601496,189143,'1713774132.959666','watch','schema','6-3',0,'5240'),(601497,189144,'1713774132.960615','watch','aria_name','account-menu',0,''),(601498,189145,'73374','watch','block_type','1',0,''),(601499,189145,'73374','watch','padding-top','70',0,''),(601500,189145,'73374','watch','padding-right','30',0,''),(601501,189145,'73374','watch','padding-bottom','30',0,''),(601502,189145,'73374','watch','padding-top','0',0,'5240'),(601503,189145,'73374','watch','padding-left','0',0,'5240'),(601504,189145,'73374','watch','padding-right','0',0,'5240'),(601505,189145,'73374','watch','padding-bottom','0',0,'5240'),(601548,189164,'1713774133.357999','watch','padding-top','15',0,''),(601549,189164,'1713774133.357999','watch','padding-bottom','15',0,''),(601550,189164,'1713774133.357999','watch','link','Address Book Process',0,''),(601551,189164,'1713774133.357999','watch','text','EDIT',0,''),(601552,189164,'1713774133.357999','watch','link_add','Address Book Process',0,''),(601553,189164,'1713774133.357999','watch','like_button_add','2',0,''),(601554,189164,'1713774133.357999','watch','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(601555,189165,'1713774133.369549','watch','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(601556,189166,'1713774133.371715','watch','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(601557,189167,'1713774133.3740','watch','block_type','1',0,''),(601558,189167,'1713774133.3740','watch','style_class','account-edit-wrap',0,''),(601559,189167,'1713774133.3740','watch','from_file','account-2.zip',0,''),(601560,189168,'1713774133.377154','watch','block_type','6',0,''),(601561,189168,'1713774133.377154','watch','schema','6-3',0,'5240'),(601562,189169,'1713774133.37823','watch','aria_name','account-menu',0,''),(601563,189170,'73374','watch','block_type','1',0,''),(601564,189170,'73374','watch','padding-top','70',0,''),(601565,189170,'73374','watch','padding-right','30',0,''),(601566,189170,'73374','watch','padding-bottom','30',0,''),(601567,189170,'73374','watch','padding-top','0',0,'5240'),(601568,189170,'73374','watch','padding-left','0',0,'5240'),(601569,189170,'73374','watch','padding-right','0',0,'5240'),(601570,189170,'73374','watch','padding-bottom','0',0,'5240'),(601613,189190,'1713774133.710153','watch','text','<h1>##HEADING_TITLE##</h1>',0,''),(601614,189191,'1713774133.722971','watch','block_type','1',0,''),(601615,189191,'1713774133.722971','watch','style_class','account-order-history',0,''),(601616,189191,'1713774133.722971','watch','from_file','account-2.zip',0,''),(601617,189192,'1713774133.772271','watch','block_type','6',0,''),(601618,189192,'1713774133.772271','watch','schema','6-3',0,'5240'),(601619,189193,'1713774133.773863','watch','aria_name','account-menu',0,''),(601620,189194,'73374','watch','block_type','1',0,''),(601621,189194,'73374','watch','padding-top','70',0,''),(601622,189194,'73374','watch','padding-right','30',0,''),(601623,189194,'73374','watch','padding-bottom','30',0,''),(601624,189194,'73374','watch','padding-top','0',0,'5240'),(601625,189194,'73374','watch','padding-left','0',0,'5240'),(601626,189194,'73374','watch','padding-right','0',0,'5240'),(601627,189194,'73374','watch','padding-bottom','0',0,'5240'),(601670,189213,'1713774134.186274','watch','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(601671,189214,'1713774134.188218','watch','link','Order History Info',0,''),(601672,189214,'1713774134.188218','watch','text','TEXT_VIEW',0,''),(601673,189214,'1713774134.188218','watch','show_pagenation','1',0,''),(601674,189214,'1713774134.188218','watch','link_pay','Order pay',0,''),(601675,189214,'1713774134.188218','watch','margin-bottom','20',0,''),(601676,189215,'1713774134.189849','watch','block_type','1',0,''),(601677,189215,'1713774134.189849','watch','style_class','account-address-book-process',0,''),(601678,189215,'1713774134.189849','watch','from_file','account-2.zip',0,''),(601679,189216,'1713774134.19293','watch','block_type','6',0,''),(601680,189216,'1713774134.19293','watch','schema','6-3',0,'5240'),(601681,189217,'1713774134.194197','watch','aria_name','account-menu',0,''),(601682,189218,'73374','watch','block_type','1',0,''),(601683,189218,'73374','watch','padding-top','70',0,''),(601684,189218,'73374','watch','padding-right','30',0,''),(601685,189218,'73374','watch','padding-bottom','30',0,''),(601686,189218,'73374','watch','padding-top','0',0,'5240'),(601687,189218,'73374','watch','padding-left','0',0,'5240'),(601688,189218,'73374','watch','padding-right','0',0,'5240'),(601689,189218,'73374','watch','padding-bottom','0',0,'5240'),(601690,189219,'73375','watch','block_type','1',0,''),(601691,189219,'73375','watch','style_class','account-menu',0,''),(601692,189220,'73376','watch','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(601693,189220,'73376','watch','style_class','heading-settings',0,''),(601694,189221,'73377','watch','link','logoff',0,''),(601695,189222,'73378','watch','link','delete',0,''),(601696,189222,'73378','watch','text','DELETE_ACCOUNT',0,''),(601697,189223,'73379','watch','text','TEXT_DASHBOARD',0,''),(601698,189223,'73379','watch','font-family','$font-1',0,''),(601699,189223,'73379','watch','font-size','18',0,''),(601700,189223,'73379','watch','text-transform','uppercase',0,''),(601701,189224,'73380','watch','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(601702,189224,'73380','watch','style_class','heading-saved-lists',0,''),(601703,189225,'73381','watch','link','Personal Catalog',0,''),(601704,189225,'73381','watch','text','TEXT_PERSONAL_CATALOG',0,''),(601705,189225,'73381','watch','hide_link','personal_catalog',0,''),(601706,189226,'73382','watch','link','Order History',0,''),(601707,189226,'73382','watch','text','HEADING_ORDER_HISTORY',0,''),(601708,189226,'73382','watch','active_link','Order History Info,Order pay',0,''),(601709,189227,'73383','watch','link','Address Book',0,''),(601710,189227,'73383','watch','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(601711,189228,'73384','watch','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(601712,189228,'73384','watch','style_class','heading-ordered-items',0,''),(601713,189229,'73385','watch','link','Wishlist',0,''),(601714,189229,'73385','watch','hide_link','wishlist',0,''),(601715,189229,'73385','watch','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(601716,189230,'73386','watch','link','My password',0,''),(601717,189230,'73386','watch','text','TEXT_MY_PASSWORD',0,''),(601718,189231,'73387','watch','link','Samples',0,''),(601719,189231,'73387','watch','text','TEXT_HEADING_SAMPLE_CART',0,''),(601720,189231,'73387','watch','hide_link','samples',0,''),(601721,189232,'73388','watch','link','Review',0,''),(601722,189232,'73388','watch','text','REVIEWS',0,''),(601723,189233,'73389','watch','link','Quotations',0,''),(601724,189233,'73389','watch','hide_link','quotations',0,''),(601725,189233,'73389','watch','text','TEXT_HEADING_QUOTE_CART',0,''),(601726,189234,'73390','watch','link','Account edit',0,''),(601727,189234,'73390','watch','text','ACCOUNT_EDIT',0,''),(601728,189235,'73391','watch','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(601729,189235,'73391','watch','style_class','heading-settings',0,''),(601730,189236,'73392','watch','link','trade_form',0,''),(601731,189236,'73392','watch','text','TRADE_FORM',0,''),(601732,189237,'1713774134.555525','watch','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(601733,189239,'1713774279.864294','furniture','block_type','1',0,''),(601734,189239,'1713774279.864294','furniture','style_class','account-index',0,''),(601735,189239,'1713774279.864294','furniture','from_file','account-2.zip',0,''),(601736,189240,'1713774279.969680','furniture','block_type','6',0,''),(601737,189240,'1713774279.969680','furniture','schema','6-3',0,'5140'),(601738,189241,'1713774279.971753','furniture','aria_name','account-menu',0,''),(601739,189242,'73374','furniture','block_type','1',0,''),(601740,189242,'73374','furniture','padding-top','70',0,''),(601741,189242,'73374','furniture','padding-right','30',0,''),(601742,189242,'73374','furniture','padding-bottom','30',0,''),(601743,189242,'73374','furniture','padding-top','0',0,'5140'),(601744,189242,'73374','furniture','padding-left','0',0,'5140'),(601745,189242,'73374','furniture','padding-right','0',0,'5140'),(601746,189242,'73374','furniture','padding-bottom','0',0,'5140'),(601789,189261,'1713774280.297397','furniture','block_type','1',0,''),(601790,189262,'1713774280.298583','furniture','link','Order History Info',0,''),(601791,189262,'1713774280.298583','furniture','text','TEXT_VIEW',0,''),(601792,189262,'1713774280.298583','furniture','max_orders','3',0,''),(601793,189262,'1713774280.298583','furniture','link_pay','Order pay',0,''),(601794,189262,'1713774280.298583','furniture','margin-bottom','30',0,''),(601795,189262,'1713774280.298583','furniture','text_pay','ORDER_PAY',0,''),(601796,189263,'1713774280.300742','furniture','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(601797,189264,'1713774280.304538','furniture','text','<h1>##HEADING_TITLE##</h1>',0,''),(601798,189265,'1713774280.32165','furniture','block_type','1',0,''),(601799,189265,'1713774280.32165','furniture','padding-top','20',0,''),(601800,189265,'1713774280.32165','furniture','padding-left','20',0,''),(601801,189265,'1713774280.32165','furniture','padding-right','20',0,''),(601802,189265,'1713774280.32165','furniture','padding-bottom','20',0,''),(601803,189265,'1713774280.32165','furniture','margin-bottom','30',0,''),(601804,189265,'1713774280.32165','furniture','border-top-width','1',0,''),(601805,189265,'1713774280.32165','furniture','border-left-width','1',0,''),(601806,189265,'1713774280.32165','furniture','border-right-width','1',0,''),(601807,189265,'1713774280.32165','furniture','border-bottom-width','1',0,''),(601808,189265,'1713774280.32165','furniture','border-top-color','$content-border-1',0,''),(601809,189265,'1713774280.32165','furniture','border-left-color','$content-border-1',0,''),(601810,189265,'1713774280.32165','furniture','border-right-color','$content-border-1',0,''),(601811,189265,'1713774280.32165','furniture','border-bottom-color','$content-border-1',0,''),(601812,189265,'1713774280.32165','furniture','style_class','account-content-top',0,''),(601813,189266,'1713774280.334674','furniture','block_type','1',0,''),(601814,189267,'1713774280.336154','furniture','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(601815,189267,'1713774280.336154','furniture','font-family','trueloaded',0,'3'),(601816,189267,'1713774280.336154','furniture','content','\\e920',0,'3'),(601817,189267,'1713774280.336154','furniture','color','$highlight-color-3',0,'3'),(601818,189267,'1713774280.336154','furniture','font-size','30',0,'3'),(601819,189267,'1713774280.336154','furniture','text-align','center',0,'3'),(601820,189267,'1713774280.336154','furniture','margin-bottom','10',0,'3'),(601821,189267,'1713774280.336154','furniture','text-align','center',0,''),(601822,189267,'1713774280.336154','furniture','font-size','16',0,''),(601823,189267,'1713774280.336154','furniture','text-transform','uppercase',0,''),(601824,189267,'1713774280.336154','furniture','line-height','1',0,'3'),(601825,189267,'1713774280.336154','furniture','font-size','14',0,'5131'),(601826,189268,'1713774280.341288','furniture','font-family','$font-1',0,''),(601827,189268,'1713774280.341288','furniture','color','$highlight-color-3',0,''),(601828,189268,'1713774280.341288','furniture','font-size','14',0,''),(601829,189268,'1713774280.341288','furniture','text-align','center',0,''),(601830,189269,'1713774280.35188','furniture','block_type','1',0,''),(601831,189270,'1713774280.352867','furniture','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(601832,189270,'1713774280.352867','furniture','font-family','trueloaded',0,'3'),(601833,189270,'1713774280.352867','furniture','content','\\e928',0,'3'),(601834,189270,'1713774280.352867','furniture','color','$highlight-color-3',0,'3'),(601835,189270,'1713774280.352867','furniture','font-size','30',0,'3'),(601836,189270,'1713774280.352867','furniture','text-align','center',0,'3'),(601837,189270,'1713774280.352867','furniture','text-align','center',0,''),(601838,189270,'1713774280.352867','furniture','font-size','16',0,''),(601839,189270,'1713774280.352867','furniture','text-transform','uppercase',0,''),(601840,189270,'1713774280.352867','furniture','line-height','1',0,'3'),(601841,189270,'1713774280.352867','furniture','font-size','14',0,'5131'),(601842,189271,'1713774280.356398','furniture','font-family','$font-1',0,''),(601843,189271,'1713774280.356398','furniture','color','$highlight-color-3',0,''),(601844,189271,'1713774280.356398','furniture','font-size','14',0,''),(601845,189271,'1713774280.356398','furniture','text-align','center',0,''),(601846,189272,'1713774280.357628','furniture','link','download_orders',0,''),(601847,189272,'1713774280.357628','furniture','text','TEXT_DOWNLOAD_ORDERS',0,''),(601848,189272,'1713774280.357628','furniture','hide_link','orders',0,''),(601849,189272,'1713774280.357628','furniture','text-align','center',0,''),(601850,189272,'1713774280.357628','furniture','popup','2',0,''),(601851,189272,'1713774280.357628','furniture','font-size','14',0,''),(601852,189273,'1713774280.359356','furniture','block_type','1',0,''),(601853,189274,'1713774280.360175','furniture','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(601854,189274,'1713774280.360175','furniture','font-family','trueloaded',0,'3'),(601855,189274,'1713774280.360175','furniture','content','\\e922',0,'3'),(601856,189274,'1713774280.360175','furniture','color','$highlight-color-3',0,'3'),(601857,189274,'1713774280.360175','furniture','font-size','30',0,'3'),(601858,189274,'1713774280.360175','furniture','line-height','1',0,'3'),(601859,189274,'1713774280.360175','furniture','font-size','16',0,''),(601860,189274,'1713774280.360175','furniture','text-align','center',0,''),(601861,189274,'1713774280.360175','furniture','text-transform','uppercase',0,''),(601862,189274,'1713774280.360175','furniture','font-size','14',0,'5131'),(601863,189275,'1713774280.362861','furniture','font-family','$font-1',0,''),(601864,189275,'1713774280.362861','furniture','color','$highlight-color-3',0,''),(601865,189275,'1713774280.362861','furniture','line-height','1',0,''),(601866,189275,'1713774280.362861','furniture','text-align','center',0,''),(601867,189275,'1713774280.362861','furniture','font-size','14',0,''),(601868,189276,'1713774280.364168','furniture','block_type','1',0,''),(601869,189277,'1713774280.36559','furniture','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(601870,189277,'1713774280.36559','furniture','content','\\e994',0,'3'),(601871,189277,'1713774280.36559','furniture','font-family','trueloaded',0,'3'),(601872,189277,'1713774280.36559','furniture','color','$highlight-color-3',0,'3'),(601873,189277,'1713774280.36559','furniture','font-size','30',0,'3'),(601874,189277,'1713774280.36559','furniture','line-height','1',0,'3'),(601875,189277,'1713774280.36559','furniture','font-size','16',0,''),(601876,189277,'1713774280.36559','furniture','text-align','center',0,''),(601877,189277,'1713774280.36559','furniture','text-transform','uppercase',0,''),(601878,189277,'1713774280.36559','furniture','font-size','14',0,'5131'),(601879,189278,'1713774280.367684','furniture','font-family','$font-1',0,''),(601880,189278,'1713774280.367684','furniture','color','$highlight-color-3',0,''),(601881,189278,'1713774280.367684','furniture','font-size','14',0,''),(601882,189278,'1713774280.367684','furniture','text-align','center',0,''),(601883,189279,'1713774280.368994','furniture','link','Gift Certificate',0,''),(601884,189279,'1713774280.368994','furniture','text','GIFT_CERTIFICATE',0,''),(601885,189279,'1713774280.368994','furniture','popup','1',0,''),(601886,189279,'1713774280.368994','furniture','text-align','center',0,''),(601887,189279,'1713774280.368994','furniture','font-size','14',0,''),(601888,189280,'1713774280.370288','furniture','block_type','1',0,''),(601889,189281,'1713774280.3715','furniture','text','TEXT_VIEW_HISTORY',0,''),(601890,189281,'1713774280.3715','furniture','popup','1',0,''),(601891,189281,'1713774280.3715','furniture','text-align','center',0,''),(601892,189281,'1713774280.3715','furniture','link','Points Earnt History',0,''),(601893,189281,'1713774280.3715','furniture','font-size','14',0,''),(601894,189282,'1713774280.372214','furniture','font-family','$font-1',0,''),(601895,189282,'1713774280.372214','furniture','color','$highlight-color-3',0,''),(601896,189282,'1713774280.372214','furniture','font-size','14',0,''),(601897,189282,'1713774280.372214','furniture','text-align','center',0,''),(601898,189283,'1713774280.373397','furniture','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(601899,189283,'1713774280.373397','furniture','content','\\e990',0,'3'),(601900,189283,'1713774280.373397','furniture','font-family','trueloaded',0,'3'),(601901,189283,'1713774280.373397','furniture','font-size','30',0,'3'),(601902,189283,'1713774280.373397','furniture','text-align','center',0,'3'),(601903,189283,'1713774280.373397','furniture','line-height','1',0,'3'),(601904,189283,'1713774280.373397','furniture','color','$highlight-color-3',0,'3'),(601905,189283,'1713774280.373397','furniture','font-size','16',0,''),(601906,189283,'1713774280.373397','furniture','text-align','center',0,''),(601907,189283,'1713774280.373397','furniture','text-transform','uppercase',0,''),(601908,189283,'1713774280.373397','furniture','font-size','14',0,'5131'),(601909,189284,'1713774280.375920','furniture','block_type','1',0,''),(601910,189284,'1713774280.375920','furniture','from_file','account-2.zip',0,''),(601911,189285,'1713774280.37681','furniture','block_type','6',0,''),(601912,189285,'1713774280.37681','furniture','schema','6-3',0,'5140'),(601913,189286,'1713774280.377779','furniture','aria_name','account-menu',0,''),(601914,189287,'73374','furniture','block_type','1',0,''),(601915,189287,'73374','furniture','padding-top','70',0,''),(601916,189287,'73374','furniture','padding-right','30',0,''),(601917,189287,'73374','furniture','padding-bottom','30',0,''),(601918,189287,'73374','furniture','padding-top','0',0,'5140'),(601919,189287,'73374','furniture','padding-left','0',0,'5140'),(601920,189287,'73374','furniture','padding-right','0',0,'5140'),(601921,189287,'73374','furniture','padding-bottom','0',0,'5140'),(601964,189306,'1713774280.725312','furniture','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(601965,189307,'1713774280.727712','furniture','margin-bottom','20',0,''),(601966,189308,'1713774280.733870','furniture','block_type','1',0,''),(601967,189308,'1713774280.733870','furniture','style_class','account-order-history-info',0,''),(601968,189308,'1713774280.733870','furniture','from_file','account-2.zip',0,''),(601969,189309,'1713774280.76691','furniture','block_type','6',0,''),(601970,189309,'1713774280.76691','furniture','schema','6-3',0,'5140'),(601971,189310,'1713774280.768459','furniture','aria_name','account-menu',0,''),(601972,189311,'73374','furniture','block_type','1',0,''),(601973,189311,'73374','furniture','padding-top','70',0,''),(601974,189311,'73374','furniture','padding-right','30',0,''),(601975,189311,'73374','furniture','padding-bottom','30',0,''),(601976,189311,'73374','furniture','padding-top','0',0,'5140'),(601977,189311,'73374','furniture','padding-left','0',0,'5140'),(601978,189311,'73374','furniture','padding-right','0',0,'5140'),(601979,189311,'73374','furniture','padding-bottom','0',0,'5140'),(602022,189330,'1713774281.071110','furniture','float','right',0,''),(602023,189330,'1713774281.071110','furniture','clear','none',0,''),(602024,189330,'1713774281.071110','furniture','margin-left','20',0,''),(602025,189332,'1713774281.073313','furniture','float','right',0,''),(602026,189332,'1713774281.073313','furniture','clear','none',0,''),(602027,189332,'1713774281.073313','furniture','like_button','2',0,''),(602028,189332,'1713774281.073313','furniture','link','Order pay',0,''),(602029,189333,'1713774281.074856','furniture','block_type','2',0,''),(602030,189333,'1713774281.074856','furniture','padding-top','20',0,''),(602031,189333,'1713774281.074856','furniture','margin-bottom','20',0,''),(602032,189334,'1713774281.076345','furniture','like_button','1',0,''),(602033,189334,'1713774281.076345','furniture','text','IMAGE_BUTTON_BACK',0,''),(602034,189334,'1713774281.076345','furniture','link','Order History',0,''),(602035,189335,'1713774281.07759','furniture','text-align','right',0,''),(602036,189336,'1713774281.078437','furniture','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(602037,189338,'1713774281.08131','furniture','float','right',0,''),(602038,189338,'1713774281.08131','furniture','clear','none',0,''),(602039,189338,'1713774281.08131','furniture','margin-left','20',0,''),(602040,189340,'1713774281.083285','furniture','float','right',0,''),(602041,189341,'1713774281.086740','furniture','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(602042,189343,'1713774281.089731','furniture','float','left',0,''),(602043,189344,'1713774281.090797','furniture','block_type','3',0,''),(602044,189344,'1713774281.090797','furniture','clear','both',0,''),(602045,189344,'1713774281.090797','furniture','padding-top','20',0,''),(602046,189344,'1713774281.090797','furniture','schema','3-4',0,'5131'),(602047,189345,'1713774281.092211','furniture','block_type','1',0,''),(602048,189345,'1713774281.092211','furniture','margin-bottom','20',0,''),(602049,189345,'1713774281.092211','furniture','padding-right','20',0,''),(602050,189346,'1713774281.093966','furniture','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(602051,189347,'1713774281.096334','furniture','padding-left','30',0,''),(602052,189347,'1713774281.096334','furniture','orders_data','telephone',0,''),(602053,189347,'1713774281.096334','furniture','hide_parents','2',0,''),(602054,189348,'1713774281.097991','furniture','block_type','1',0,''),(602055,189348,'1713774281.097991','furniture','padding-right','20',0,''),(602056,189348,'1713774281.097991','furniture','padding-bottom','20',0,''),(602057,189349,'1713774281.09931','furniture','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(602058,189350,'1713774281.104376','furniture','orders_data','name',0,''),(602059,189350,'1713774281.104376','furniture','padding-left','30',0,''),(602060,189351,'1713774281.105683','furniture','block_type','1',0,''),(602061,189351,'1713774281.105683','furniture','padding-right','20',0,''),(602062,189351,'1713774281.105683','furniture','margin-bottom','20',0,''),(602063,189352,'1713774281.10733','furniture','short_view','1',0,''),(602064,189352,'1713774281.10733','furniture','hide_parents','2',0,''),(602065,189353,'1713774281.108498','furniture','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(602066,189354,'1713774281.11113','furniture','link','Tracking numbers',0,''),(602067,189354,'1713774281.11113','furniture','text','MORE_TRACKING_NUMBER',0,''),(602068,189354,'1713774281.11113','furniture','popup','1',0,''),(602069,189354,'1713774281.11113','furniture','order_id','1',0,''),(602070,189354,'1713774281.11113','furniture','popup_class','tracking-numbers-popup',0,''),(602071,189354,'1713774281.11113','furniture','font-weight','700',0,''),(602072,189354,'1713774281.11113','furniture','font-size','18',0,''),(602073,189355,'1713774281.113595','furniture','block_type','1',0,''),(602074,189355,'1713774281.113595','furniture','padding-right','20',0,''),(602075,189356,'1713774281.114856','furniture','orders_data','shipping_method',0,''),(602076,189356,'1713774281.114856','furniture','padding-left','30',0,''),(602077,189357,'1713774281.116185','furniture','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(602078,189358,'1713774281.118622','furniture','block_type','1',0,''),(602079,189358,'1713774281.118622','furniture','padding-right','20',0,''),(602080,189358,'1713774281.118622','furniture','padding-bottom','20',0,''),(602081,189359,'1713774281.120129','furniture','orders_data','delivery_address',0,''),(602082,189359,'1713774281.120129','furniture','padding-left','30',0,''),(602083,189360,'1713774281.121493','furniture','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(602084,189361,'1713774281.123873','furniture','block_type','1',0,''),(602085,189362,'1713774281.124980','furniture','orders_data','payment_method',0,''),(602086,189362,'1713774281.124980','furniture','padding-left','30',0,''),(602087,189363,'1713774281.126172','furniture','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(602088,189364,'1713774281.128587','furniture','block_type','1',0,''),(602089,189364,'1713774281.128587','furniture','padding-bottom','20',0,''),(602090,189365,'1713774281.129973','furniture','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(602091,189366,'1713774281.132385','furniture','orders_data','billing_address',0,''),(602092,189366,'1713774281.132385','furniture','padding-left','30',0,''),(602093,189367,'1713774281.133667','furniture','block_type','1',0,''),(602094,189367,'1713774281.133667','furniture','style_class','account-address-book',0,''),(602095,189367,'1713774281.133667','furniture','from_file','account-2.zip',0,''),(602096,189368,'1713774281.13597','furniture','block_type','6',0,''),(602097,189368,'1713774281.13597','furniture','schema','6-3',0,'5140'),(602098,189369,'1713774281.136347','furniture','aria_name','account-menu',0,''),(602099,189370,'73374','furniture','block_type','1',0,''),(602100,189370,'73374','furniture','padding-top','70',0,''),(602101,189370,'73374','furniture','padding-right','30',0,''),(602102,189370,'73374','furniture','padding-bottom','30',0,''),(602103,189370,'73374','furniture','padding-top','0',0,'5140'),(602104,189370,'73374','furniture','padding-left','0',0,'5140'),(602105,189370,'73374','furniture','padding-right','0',0,'5140'),(602106,189370,'73374','furniture','padding-bottom','0',0,'5140'),(602149,189389,'1713774281.475435','furniture','padding-top','15',0,''),(602150,189389,'1713774281.475435','furniture','padding-bottom','15',0,''),(602151,189389,'1713774281.475435','furniture','link','Address Book Process',0,''),(602152,189389,'1713774281.475435','furniture','text','EDIT',0,''),(602153,189389,'1713774281.475435','furniture','link_add','Address Book Process',0,''),(602154,189389,'1713774281.475435','furniture','like_button_add','2',0,''),(602155,189389,'1713774281.475435','furniture','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(602156,189390,'1713774281.489799','furniture','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(602157,189391,'1713774281.493151','furniture','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(602158,189392,'1713774281.496820','furniture','block_type','1',0,''),(602159,189392,'1713774281.496820','furniture','style_class','account-edit-wrap',0,''),(602160,189392,'1713774281.496820','furniture','from_file','account-2.zip',0,''),(602161,189393,'1713774281.501632','furniture','block_type','6',0,''),(602162,189393,'1713774281.501632','furniture','schema','6-3',0,'5140'),(602163,189394,'1713774281.503794','furniture','aria_name','account-menu',0,''),(602164,189395,'73374','furniture','block_type','1',0,''),(602165,189395,'73374','furniture','padding-top','70',0,''),(602166,189395,'73374','furniture','padding-right','30',0,''),(602167,189395,'73374','furniture','padding-bottom','30',0,''),(602168,189395,'73374','furniture','padding-top','0',0,'5140'),(602169,189395,'73374','furniture','padding-left','0',0,'5140'),(602170,189395,'73374','furniture','padding-right','0',0,'5140'),(602171,189395,'73374','furniture','padding-bottom','0',0,'5140'),(602214,189415,'1713774281.890686','furniture','text','<h1>##HEADING_TITLE##</h1>',0,''),(602215,189416,'1713774281.907128','furniture','block_type','1',0,''),(602216,189416,'1713774281.907128','furniture','style_class','account-order-history',0,''),(602217,189416,'1713774281.907128','furniture','from_file','account-2.zip',0,''),(602218,189417,'1713774281.953936','furniture','block_type','6',0,''),(602219,189417,'1713774281.953936','furniture','schema','6-3',0,'5140'),(602220,189418,'1713774281.955250','furniture','aria_name','account-menu',0,''),(602221,189419,'73374','furniture','block_type','1',0,''),(602222,189419,'73374','furniture','padding-top','70',0,''),(602223,189419,'73374','furniture','padding-right','30',0,''),(602224,189419,'73374','furniture','padding-bottom','30',0,''),(602225,189419,'73374','furniture','padding-top','0',0,'5140'),(602226,189419,'73374','furniture','padding-left','0',0,'5140'),(602227,189419,'73374','furniture','padding-right','0',0,'5140'),(602228,189419,'73374','furniture','padding-bottom','0',0,'5140'),(602271,189438,'1713774282.25493','furniture','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(602272,189439,'1713774282.257271','furniture','link','Order History Info',0,''),(602273,189439,'1713774282.257271','furniture','text','TEXT_VIEW',0,''),(602274,189439,'1713774282.257271','furniture','show_pagenation','1',0,''),(602275,189439,'1713774282.257271','furniture','link_pay','Order pay',0,''),(602276,189439,'1713774282.257271','furniture','margin-bottom','20',0,''),(602277,189440,'1713774282.2593','furniture','block_type','1',0,''),(602278,189440,'1713774282.2593','furniture','style_class','account-address-book-process',0,''),(602279,189440,'1713774282.2593','furniture','from_file','account-2.zip',0,''),(602280,189441,'1713774282.263247','furniture','block_type','6',0,''),(602281,189441,'1713774282.263247','furniture','schema','6-3',0,'5140'),(602282,189442,'1713774282.264620','furniture','aria_name','account-menu',0,''),(602283,189443,'73374','furniture','block_type','1',0,''),(602284,189443,'73374','furniture','padding-top','70',0,''),(602285,189443,'73374','furniture','padding-right','30',0,''),(602286,189443,'73374','furniture','padding-bottom','30',0,''),(602287,189443,'73374','furniture','padding-top','0',0,'5140'),(602288,189443,'73374','furniture','padding-left','0',0,'5140'),(602289,189443,'73374','furniture','padding-right','0',0,'5140'),(602290,189443,'73374','furniture','padding-bottom','0',0,'5140'),(602291,189444,'73375','furniture','block_type','1',0,''),(602292,189444,'73375','furniture','style_class','account-menu',0,''),(602293,189445,'73376','furniture','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(602294,189445,'73376','furniture','style_class','heading-settings',0,''),(602295,189446,'73377','furniture','link','logoff',0,''),(602296,189447,'73378','furniture','link','delete',0,''),(602297,189447,'73378','furniture','text','DELETE_ACCOUNT',0,''),(602298,189448,'73379','furniture','text','TEXT_DASHBOARD',0,''),(602299,189448,'73379','furniture','font-family','$font-1',0,''),(602300,189448,'73379','furniture','font-size','18',0,''),(602301,189448,'73379','furniture','text-transform','uppercase',0,''),(602302,189449,'73380','furniture','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(602303,189449,'73380','furniture','style_class','heading-saved-lists',0,''),(602304,189450,'73381','furniture','link','Personal Catalog',0,''),(602305,189450,'73381','furniture','text','TEXT_PERSONAL_CATALOG',0,''),(602306,189450,'73381','furniture','hide_link','personal_catalog',0,''),(602307,189451,'73382','furniture','link','Order History',0,''),(602308,189451,'73382','furniture','text','HEADING_ORDER_HISTORY',0,''),(602309,189451,'73382','furniture','active_link','Order History Info,Order pay',0,''),(602310,189452,'73383','furniture','link','Address Book',0,''),(602311,189452,'73383','furniture','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(602312,189453,'73384','furniture','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(602313,189453,'73384','furniture','style_class','heading-ordered-items',0,''),(602314,189454,'73385','furniture','link','Wishlist',0,''),(602315,189454,'73385','furniture','hide_link','wishlist',0,''),(602316,189454,'73385','furniture','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(602317,189455,'73386','furniture','link','My password',0,''),(602318,189455,'73386','furniture','text','TEXT_MY_PASSWORD',0,''),(602319,189456,'73387','furniture','link','Samples',0,''),(602320,189456,'73387','furniture','text','TEXT_HEADING_SAMPLE_CART',0,''),(602321,189456,'73387','furniture','hide_link','samples',0,''),(602322,189457,'73388','furniture','link','Review',0,''),(602323,189457,'73388','furniture','text','REVIEWS',0,''),(602324,189458,'73389','furniture','link','Quotations',0,''),(602325,189458,'73389','furniture','hide_link','quotations',0,''),(602326,189458,'73389','furniture','text','TEXT_HEADING_QUOTE_CART',0,''),(602327,189459,'73390','furniture','link','Account edit',0,''),(602328,189459,'73390','furniture','text','ACCOUNT_EDIT',0,''),(602329,189460,'73391','furniture','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(602330,189460,'73391','furniture','style_class','heading-settings',0,''),(602331,189461,'73392','furniture','link','trade_form',0,''),(602332,189461,'73392','furniture','text','TRADE_FORM',0,''),(602333,189462,'1713774282.668269','furniture','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(602334,189464,'1713774291.283818','printshop','block_type','1',0,''),(602335,189464,'1713774291.283818','printshop','style_class','account-index',0,''),(602336,189464,'1713774291.283818','printshop','from_file','account-2.zip',0,''),(602337,189465,'1713774291.388533','printshop','block_type','6',0,''),(602338,189465,'1713774291.388533','printshop','schema','6-3',0,'5342'),(602339,189466,'1713774291.390348','printshop','aria_name','account-menu',0,''),(602340,189467,'73374','printshop','block_type','1',0,''),(602341,189467,'73374','printshop','padding-top','70',0,''),(602342,189467,'73374','printshop','padding-right','30',0,''),(602343,189467,'73374','printshop','padding-bottom','30',0,''),(602344,189467,'73374','printshop','padding-top','0',0,'5342'),(602345,189467,'73374','printshop','padding-left','0',0,'5342'),(602346,189467,'73374','printshop','padding-right','0',0,'5342'),(602347,189467,'73374','printshop','padding-bottom','0',0,'5342'),(602390,189486,'1713774291.784653','printshop','block_type','1',0,''),(602391,189487,'1713774291.785492','printshop','link','Order History Info',0,''),(602392,189487,'1713774291.785492','printshop','text','TEXT_VIEW',0,''),(602393,189487,'1713774291.785492','printshop','max_orders','3',0,''),(602394,189487,'1713774291.785492','printshop','link_pay','Order pay',0,''),(602395,189487,'1713774291.785492','printshop','margin-bottom','30',0,''),(602396,189487,'1713774291.785492','printshop','text_pay','ORDER_PAY',0,''),(602397,189488,'1713774291.78762','printshop','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(602398,189489,'1713774291.78938','printshop','text','<h1>##HEADING_TITLE##</h1>',0,''),(602399,189490,'1713774291.799772','printshop','block_type','1',0,''),(602400,189490,'1713774291.799772','printshop','padding-top','20',0,''),(602401,189490,'1713774291.799772','printshop','padding-left','20',0,''),(602402,189490,'1713774291.799772','printshop','padding-right','20',0,''),(602403,189490,'1713774291.799772','printshop','padding-bottom','20',0,''),(602404,189490,'1713774291.799772','printshop','margin-bottom','30',0,''),(602405,189490,'1713774291.799772','printshop','border-top-width','1',0,''),(602406,189490,'1713774291.799772','printshop','border-left-width','1',0,''),(602407,189490,'1713774291.799772','printshop','border-right-width','1',0,''),(602408,189490,'1713774291.799772','printshop','border-bottom-width','1',0,''),(602409,189490,'1713774291.799772','printshop','border-top-color','$content-border-1',0,''),(602410,189490,'1713774291.799772','printshop','border-left-color','$content-border-1',0,''),(602411,189490,'1713774291.799772','printshop','border-right-color','$content-border-1',0,''),(602412,189490,'1713774291.799772','printshop','border-bottom-color','$content-border-1',0,''),(602413,189490,'1713774291.799772','printshop','style_class','account-content-top',0,''),(602414,189491,'1713774291.806860','printshop','block_type','1',0,''),(602415,189492,'1713774291.807965','printshop','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(602416,189492,'1713774291.807965','printshop','font-family','trueloaded',0,'3'),(602417,189492,'1713774291.807965','printshop','content','\\e920',0,'3'),(602418,189492,'1713774291.807965','printshop','color','#EE4225',0,'3'),(602419,189492,'1713774291.807965','printshop','font-size','30',0,'3'),(602420,189492,'1713774291.807965','printshop','text-align','center',0,'3'),(602421,189492,'1713774291.807965','printshop','margin-bottom','10',0,'3'),(602422,189492,'1713774291.807965','printshop','text-align','center',0,''),(602423,189492,'1713774291.807965','printshop','font-size','16',0,''),(602424,189492,'1713774291.807965','printshop','text-transform','uppercase',0,''),(602425,189492,'1713774291.807965','printshop','line-height','1',0,'3'),(602426,189492,'1713774291.807965','printshop','font-size','14',0,'5333'),(602427,189493,'1713774291.811922','printshop','font-family','$font-1',0,''),(602428,189493,'1713774291.811922','printshop','color','#EE4225',0,''),(602429,189493,'1713774291.811922','printshop','font-size','14',0,''),(602430,189493,'1713774291.811922','printshop','text-align','center',0,''),(602431,189494,'1713774291.821577','printshop','block_type','1',0,''),(602432,189495,'1713774291.822426','printshop','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(602433,189495,'1713774291.822426','printshop','font-family','trueloaded',0,'3'),(602434,189495,'1713774291.822426','printshop','content','\\e928',0,'3'),(602435,189495,'1713774291.822426','printshop','color','#EE4225',0,'3'),(602436,189495,'1713774291.822426','printshop','font-size','30',0,'3'),(602437,189495,'1713774291.822426','printshop','text-align','center',0,'3'),(602438,189495,'1713774291.822426','printshop','text-align','center',0,''),(602439,189495,'1713774291.822426','printshop','font-size','16',0,''),(602440,189495,'1713774291.822426','printshop','text-transform','uppercase',0,''),(602441,189495,'1713774291.822426','printshop','line-height','1',0,'3'),(602442,189495,'1713774291.822426','printshop','font-size','14',0,'5333'),(602443,189496,'1713774291.82580','printshop','font-family','$font-1',0,''),(602444,189496,'1713774291.82580','printshop','color','#EE4225',0,''),(602445,189496,'1713774291.82580','printshop','font-size','14',0,''),(602446,189496,'1713774291.82580','printshop','text-align','center',0,''),(602447,189497,'1713774291.82723','printshop','link','download_orders',0,''),(602448,189497,'1713774291.82723','printshop','text','TEXT_DOWNLOAD_ORDERS',0,''),(602449,189497,'1713774291.82723','printshop','hide_link','orders',0,''),(602450,189497,'1713774291.82723','printshop','text-align','center',0,''),(602451,189497,'1713774291.82723','printshop','popup','2',0,''),(602452,189497,'1713774291.82723','printshop','font-size','14',0,''),(602453,189498,'1713774291.829143','printshop','block_type','1',0,''),(602454,189499,'1713774291.829944','printshop','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(602455,189499,'1713774291.829944','printshop','font-family','trueloaded',0,'3'),(602456,189499,'1713774291.829944','printshop','content','\\e922',0,'3'),(602457,189499,'1713774291.829944','printshop','color','#EE4225',0,'3'),(602458,189499,'1713774291.829944','printshop','font-size','30',0,'3'),(602459,189499,'1713774291.829944','printshop','line-height','1',0,'3'),(602460,189499,'1713774291.829944','printshop','font-size','16',0,''),(602461,189499,'1713774291.829944','printshop','text-align','center',0,''),(602462,189499,'1713774291.829944','printshop','text-transform','uppercase',0,''),(602463,189499,'1713774291.829944','printshop','font-size','14',0,'5333'),(602464,189500,'1713774291.833740','printshop','font-family','$font-1',0,''),(602465,189500,'1713774291.833740','printshop','color','#EE4225',0,''),(602466,189500,'1713774291.833740','printshop','line-height','1',0,''),(602467,189500,'1713774291.833740','printshop','text-align','center',0,''),(602468,189500,'1713774291.833740','printshop','font-size','14',0,''),(602469,189501,'1713774291.836366','printshop','block_type','1',0,''),(602470,189502,'1713774291.837352','printshop','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(602471,189502,'1713774291.837352','printshop','content','\\e994',0,'3'),(602472,189502,'1713774291.837352','printshop','font-family','trueloaded',0,'3'),(602473,189502,'1713774291.837352','printshop','color','#EE4225',0,'3'),(602474,189502,'1713774291.837352','printshop','font-size','30',0,'3'),(602475,189502,'1713774291.837352','printshop','line-height','1',0,'3'),(602476,189502,'1713774291.837352','printshop','font-size','16',0,''),(602477,189502,'1713774291.837352','printshop','text-align','center',0,''),(602478,189502,'1713774291.837352','printshop','text-transform','uppercase',0,''),(602479,189502,'1713774291.837352','printshop','font-size','14',0,'5333'),(602480,189503,'1713774291.840267','printshop','font-family','$font-1',0,''),(602481,189503,'1713774291.840267','printshop','color','#EE4225',0,''),(602482,189503,'1713774291.840267','printshop','font-size','14',0,''),(602483,189503,'1713774291.840267','printshop','text-align','center',0,''),(602484,189504,'1713774291.841825','printshop','link','Gift Certificate',0,''),(602485,189504,'1713774291.841825','printshop','text','GIFT_CERTIFICATE',0,''),(602486,189504,'1713774291.841825','printshop','popup','1',0,''),(602487,189504,'1713774291.841825','printshop','text-align','center',0,''),(602488,189504,'1713774291.841825','printshop','font-size','14',0,''),(602489,189505,'1713774291.843244','printshop','block_type','1',0,''),(602490,189506,'1713774291.844151','printshop','text','TEXT_VIEW_HISTORY',0,''),(602491,189506,'1713774291.844151','printshop','popup','1',0,''),(602492,189506,'1713774291.844151','printshop','text-align','center',0,''),(602493,189506,'1713774291.844151','printshop','link','Points Earnt History',0,''),(602494,189506,'1713774291.844151','printshop','font-size','14',0,''),(602495,189507,'1713774291.84543','printshop','font-family','$font-1',0,''),(602496,189507,'1713774291.84543','printshop','color','#EE4225',0,''),(602497,189507,'1713774291.84543','printshop','font-size','14',0,''),(602498,189507,'1713774291.84543','printshop','text-align','center',0,''),(602499,189508,'1713774291.846868','printshop','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(602500,189508,'1713774291.846868','printshop','content','\\e990',0,'3'),(602501,189508,'1713774291.846868','printshop','font-family','trueloaded',0,'3'),(602502,189508,'1713774291.846868','printshop','font-size','30',0,'3'),(602503,189508,'1713774291.846868','printshop','text-align','center',0,'3'),(602504,189508,'1713774291.846868','printshop','line-height','1',0,'3'),(602505,189508,'1713774291.846868','printshop','color','#EE4225',0,'3'),(602506,189508,'1713774291.846868','printshop','font-size','16',0,''),(602507,189508,'1713774291.846868','printshop','text-align','center',0,''),(602508,189508,'1713774291.846868','printshop','text-transform','uppercase',0,''),(602509,189508,'1713774291.846868','printshop','font-size','14',0,'5333'),(602510,189509,'1713774291.849925','printshop','block_type','1',0,''),(602511,189509,'1713774291.849925','printshop','from_file','account-2.zip',0,''),(602512,189510,'1713774291.850917','printshop','block_type','6',0,''),(602513,189510,'1713774291.850917','printshop','schema','6-3',0,'5342'),(602514,189511,'1713774291.851973','printshop','aria_name','account-menu',0,''),(602515,189512,'73374','printshop','block_type','1',0,''),(602516,189512,'73374','printshop','padding-top','70',0,''),(602517,189512,'73374','printshop','padding-right','30',0,''),(602518,189512,'73374','printshop','padding-bottom','30',0,''),(602519,189512,'73374','printshop','padding-top','0',0,'5342'),(602520,189512,'73374','printshop','padding-left','0',0,'5342'),(602521,189512,'73374','printshop','padding-right','0',0,'5342'),(602522,189512,'73374','printshop','padding-bottom','0',0,'5342'),(602565,189531,'1713774292.245647','printshop','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(602566,189532,'1713774292.247937','printshop','margin-bottom','20',0,''),(602567,189533,'1713774292.252957','printshop','block_type','1',0,''),(602568,189533,'1713774292.252957','printshop','style_class','account-order-history-info',0,''),(602569,189533,'1713774292.252957','printshop','from_file','account-2.zip',0,''),(602570,189534,'1713774292.285450','printshop','block_type','6',0,''),(602571,189534,'1713774292.285450','printshop','schema','6-3',0,'5342'),(602572,189535,'1713774292.286894','printshop','aria_name','account-menu',0,''),(602573,189536,'73374','printshop','block_type','1',0,''),(602574,189536,'73374','printshop','padding-top','70',0,''),(602575,189536,'73374','printshop','padding-right','30',0,''),(602576,189536,'73374','printshop','padding-bottom','30',0,''),(602577,189536,'73374','printshop','padding-top','0',0,'5342'),(602578,189536,'73374','printshop','padding-left','0',0,'5342'),(602579,189536,'73374','printshop','padding-right','0',0,'5342'),(602580,189536,'73374','printshop','padding-bottom','0',0,'5342'),(602623,189555,'1713774292.692796','printshop','float','right',0,''),(602624,189555,'1713774292.692796','printshop','clear','none',0,''),(602625,189555,'1713774292.692796','printshop','margin-left','20',0,''),(602626,189557,'1713774292.69476','printshop','float','right',0,''),(602627,189557,'1713774292.69476','printshop','clear','none',0,''),(602628,189557,'1713774292.69476','printshop','like_button','2',0,''),(602629,189557,'1713774292.69476','printshop','link','Order pay',0,''),(602630,189558,'1713774292.695987','printshop','block_type','2',0,''),(602631,189558,'1713774292.695987','printshop','padding-top','20',0,''),(602632,189558,'1713774292.695987','printshop','margin-bottom','20',0,''),(602633,189559,'1713774292.697287','printshop','like_button','1',0,''),(602634,189559,'1713774292.697287','printshop','text','IMAGE_BUTTON_BACK',0,''),(602635,189559,'1713774292.697287','printshop','link','Order History',0,''),(602636,189560,'1713774292.698396','printshop','text-align','right',0,''),(602637,189561,'1713774292.699239','printshop','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(602638,189563,'1713774292.702227','printshop','float','right',0,''),(602639,189563,'1713774292.702227','printshop','clear','none',0,''),(602640,189563,'1713774292.702227','printshop','margin-left','20',0,''),(602641,189565,'1713774292.70446','printshop','float','right',0,''),(602642,189566,'1713774292.707596','printshop','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(602643,189568,'1713774292.71080','printshop','float','left',0,''),(602644,189569,'1713774292.711955','printshop','block_type','3',0,''),(602645,189569,'1713774292.711955','printshop','clear','both',0,''),(602646,189569,'1713774292.711955','printshop','padding-top','20',0,''),(602647,189569,'1713774292.711955','printshop','schema','3-4',0,'5333'),(602648,189570,'1713774292.713627','printshop','block_type','1',0,''),(602649,189570,'1713774292.713627','printshop','margin-bottom','20',0,''),(602650,189570,'1713774292.713627','printshop','padding-right','20',0,''),(602651,189571,'1713774292.71538','printshop','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(602652,189572,'1713774292.717332','printshop','padding-left','30',0,''),(602653,189572,'1713774292.717332','printshop','orders_data','telephone',0,''),(602654,189572,'1713774292.717332','printshop','hide_parents','2',0,''),(602655,189573,'1713774292.718650','printshop','block_type','1',0,''),(602656,189573,'1713774292.718650','printshop','padding-right','20',0,''),(602657,189573,'1713774292.718650','printshop','padding-bottom','20',0,''),(602658,189574,'1713774292.719949','printshop','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(602659,189575,'1713774292.724311','printshop','orders_data','name',0,''),(602660,189575,'1713774292.724311','printshop','padding-left','30',0,''),(602661,189576,'1713774292.725380','printshop','block_type','1',0,''),(602662,189576,'1713774292.725380','printshop','padding-right','20',0,''),(602663,189576,'1713774292.725380','printshop','margin-bottom','20',0,''),(602664,189577,'1713774292.726372','printshop','short_view','1',0,''),(602665,189577,'1713774292.726372','printshop','hide_parents','2',0,''),(602666,189578,'1713774292.727511','printshop','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(602667,189579,'1713774292.729492','printshop','link','Tracking numbers',0,''),(602668,189579,'1713774292.729492','printshop','text','MORE_TRACKING_NUMBER',0,''),(602669,189579,'1713774292.729492','printshop','popup','1',0,''),(602670,189579,'1713774292.729492','printshop','order_id','1',0,''),(602671,189579,'1713774292.729492','printshop','popup_class','tracking-numbers-popup',0,''),(602672,189579,'1713774292.729492','printshop','font-weight','700',0,''),(602673,189579,'1713774292.729492','printshop','font-size','18',0,''),(602674,189580,'1713774292.731181','printshop','block_type','1',0,''),(602675,189580,'1713774292.731181','printshop','padding-right','20',0,''),(602676,189581,'1713774292.73246','printshop','orders_data','shipping_method',0,''),(602677,189581,'1713774292.73246','printshop','padding-left','30',0,''),(602678,189582,'1713774292.733650','printshop','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(602679,189583,'1713774292.735925','printshop','block_type','1',0,''),(602680,189583,'1713774292.735925','printshop','padding-right','20',0,''),(602681,189583,'1713774292.735925','printshop','padding-bottom','20',0,''),(602682,189584,'1713774292.737241','printshop','orders_data','delivery_address',0,''),(602683,189584,'1713774292.737241','printshop','padding-left','30',0,''),(602684,189585,'1713774292.73836','printshop','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(602685,189586,'1713774292.740656','printshop','block_type','1',0,''),(602686,189587,'1713774292.741632','printshop','orders_data','payment_method',0,''),(602687,189587,'1713774292.741632','printshop','padding-left','30',0,''),(602688,189588,'1713774292.742836','printshop','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(602689,189589,'1713774292.744670','printshop','block_type','1',0,''),(602690,189589,'1713774292.744670','printshop','padding-bottom','20',0,''),(602691,189590,'1713774292.745537','printshop','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(602692,189591,'1713774292.747421','printshop','orders_data','billing_address',0,''),(602693,189591,'1713774292.747421','printshop','padding-left','30',0,''),(602694,189592,'1713774292.748453','printshop','block_type','1',0,''),(602695,189592,'1713774292.748453','printshop','style_class','account-address-book',0,''),(602696,189592,'1713774292.748453','printshop','from_file','account-2.zip',0,''),(602697,189593,'1713774292.749515','printshop','block_type','6',0,''),(602698,189593,'1713774292.749515','printshop','schema','6-3',0,'5342'),(602699,189594,'1713774292.750418','printshop','aria_name','account-menu',0,''),(602700,189595,'73374','printshop','block_type','1',0,''),(602701,189595,'73374','printshop','padding-top','70',0,''),(602702,189595,'73374','printshop','padding-right','30',0,''),(602703,189595,'73374','printshop','padding-bottom','30',0,''),(602704,189595,'73374','printshop','padding-top','0',0,'5342'),(602705,189595,'73374','printshop','padding-left','0',0,'5342'),(602706,189595,'73374','printshop','padding-right','0',0,'5342'),(602707,189595,'73374','printshop','padding-bottom','0',0,'5342'),(602750,189614,'1713774293.082159','printshop','padding-top','15',0,''),(602751,189614,'1713774293.082159','printshop','padding-bottom','15',0,''),(602752,189614,'1713774293.082159','printshop','link','Address Book Process',0,''),(602753,189614,'1713774293.082159','printshop','text','EDIT',0,''),(602754,189614,'1713774293.082159','printshop','link_add','Address Book Process',0,''),(602755,189614,'1713774293.082159','printshop','like_button_add','2',0,''),(602756,189614,'1713774293.082159','printshop','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(602757,189615,'1713774293.096223','printshop','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(602758,189616,'1713774293.098979','printshop','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(602759,189617,'1713774293.102593','printshop','block_type','1',0,''),(602760,189617,'1713774293.102593','printshop','style_class','account-edit-wrap',0,''),(602761,189617,'1713774293.102593','printshop','from_file','account-2.zip',0,''),(602762,189618,'1713774293.10637','printshop','block_type','6',0,''),(602763,189618,'1713774293.10637','printshop','schema','6-3',0,'5342'),(602764,189619,'1713774293.107979','printshop','aria_name','account-menu',0,''),(602765,189620,'73374','printshop','block_type','1',0,''),(602766,189620,'73374','printshop','padding-top','70',0,''),(602767,189620,'73374','printshop','padding-right','30',0,''),(602768,189620,'73374','printshop','padding-bottom','30',0,''),(602769,189620,'73374','printshop','padding-top','0',0,'5342'),(602770,189620,'73374','printshop','padding-left','0',0,'5342'),(602771,189620,'73374','printshop','padding-right','0',0,'5342'),(602772,189620,'73374','printshop','padding-bottom','0',0,'5342'),(602815,189640,'1713774293.507399','printshop','text','<h1>##HEADING_TITLE##</h1>',0,''),(602816,189641,'1713774293.523882','printshop','block_type','1',0,''),(602817,189641,'1713774293.523882','printshop','style_class','account-order-history',0,''),(602818,189641,'1713774293.523882','printshop','from_file','account-2.zip',0,''),(602819,189642,'1713774293.577891','printshop','block_type','6',0,''),(602820,189642,'1713774293.577891','printshop','schema','6-3',0,'5342'),(602821,189643,'1713774293.579253','printshop','aria_name','account-menu',0,''),(602822,189644,'73374','printshop','block_type','1',0,''),(602823,189644,'73374','printshop','padding-top','70',0,''),(602824,189644,'73374','printshop','padding-right','30',0,''),(602825,189644,'73374','printshop','padding-bottom','30',0,''),(602826,189644,'73374','printshop','padding-top','0',0,'5342'),(602827,189644,'73374','printshop','padding-left','0',0,'5342'),(602828,189644,'73374','printshop','padding-right','0',0,'5342'),(602829,189644,'73374','printshop','padding-bottom','0',0,'5342'),(602872,189663,'1713774293.893565','printshop','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(602873,189664,'1713774293.895793','printshop','link','Order History Info',0,''),(602874,189664,'1713774293.895793','printshop','text','TEXT_VIEW',0,''),(602875,189664,'1713774293.895793','printshop','show_pagenation','1',0,''),(602876,189664,'1713774293.895793','printshop','link_pay','Order pay',0,''),(602877,189664,'1713774293.895793','printshop','margin-bottom','20',0,''),(602878,189665,'1713774293.897327','printshop','block_type','1',0,''),(602879,189665,'1713774293.897327','printshop','style_class','account-address-book-process',0,''),(602880,189665,'1713774293.897327','printshop','from_file','account-2.zip',0,''),(602881,189666,'1713774293.900863','printshop','block_type','6',0,''),(602882,189666,'1713774293.900863','printshop','schema','6-3',0,'5342'),(602883,189667,'1713774293.90289','printshop','aria_name','account-menu',0,''),(602884,189668,'73374','printshop','block_type','1',0,''),(602885,189668,'73374','printshop','padding-top','70',0,''),(602886,189668,'73374','printshop','padding-right','30',0,''),(602887,189668,'73374','printshop','padding-bottom','30',0,''),(602888,189668,'73374','printshop','padding-top','0',0,'5342'),(602889,189668,'73374','printshop','padding-left','0',0,'5342'),(602890,189668,'73374','printshop','padding-right','0',0,'5342'),(602891,189668,'73374','printshop','padding-bottom','0',0,'5342'),(602892,189669,'73375','printshop','block_type','1',0,''),(602893,189669,'73375','printshop','style_class','account-menu',0,''),(602894,189670,'73376','printshop','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(602895,189670,'73376','printshop','style_class','heading-settings',0,''),(602896,189671,'73377','printshop','link','logoff',0,''),(602897,189672,'73378','printshop','link','delete',0,''),(602898,189672,'73378','printshop','text','DELETE_ACCOUNT',0,''),(602899,189673,'73379','printshop','text','TEXT_DASHBOARD',0,''),(602900,189673,'73379','printshop','font-family','$font-1',0,''),(602901,189673,'73379','printshop','font-size','18',0,''),(602902,189673,'73379','printshop','text-transform','uppercase',0,''),(602903,189674,'73380','printshop','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(602904,189674,'73380','printshop','style_class','heading-saved-lists',0,''),(602905,189675,'73381','printshop','link','Personal Catalog',0,''),(602906,189675,'73381','printshop','text','TEXT_PERSONAL_CATALOG',0,''),(602907,189675,'73381','printshop','hide_link','personal_catalog',0,''),(602908,189676,'73382','printshop','link','Order History',0,''),(602909,189676,'73382','printshop','text','HEADING_ORDER_HISTORY',0,''),(602910,189676,'73382','printshop','active_link','Order History Info,Order pay',0,''),(602911,189677,'73383','printshop','link','Address Book',0,''),(602912,189677,'73383','printshop','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(602913,189678,'73384','printshop','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(602914,189678,'73384','printshop','style_class','heading-ordered-items',0,''),(602915,189679,'73385','printshop','link','Wishlist',0,''),(602916,189679,'73385','printshop','hide_link','wishlist',0,''),(602917,189679,'73385','printshop','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(602918,189680,'73386','printshop','link','My password',0,''),(602919,189680,'73386','printshop','text','TEXT_MY_PASSWORD',0,''),(602920,189681,'73387','printshop','link','Samples',0,''),(602921,189681,'73387','printshop','text','TEXT_HEADING_SAMPLE_CART',0,''),(602922,189681,'73387','printshop','hide_link','samples',0,''),(602923,189682,'73388','printshop','link','Review',0,''),(602924,189682,'73388','printshop','text','REVIEWS',0,''),(602925,189683,'73389','printshop','link','Quotations',0,''),(602926,189683,'73389','printshop','hide_link','quotations',0,''),(602927,189683,'73389','printshop','text','TEXT_HEADING_QUOTE_CART',0,''),(602928,189684,'73390','printshop','link','Account edit',0,''),(602929,189684,'73390','printshop','text','ACCOUNT_EDIT',0,''),(602930,189685,'73391','printshop','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(602931,189685,'73391','printshop','style_class','heading-settings',0,''),(602932,189686,'73392','printshop','link','trade_form',0,''),(602933,189686,'73392','printshop','text','TRADE_FORM',0,''),(602934,189687,'1713774294.238947','printshop','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(602935,189689,'1713774302.070365','deals','block_type','1',0,''),(602936,189689,'1713774302.070365','deals','style_class','account-index',0,''),(602937,189689,'1713774302.070365','deals','from_file','account-2.zip',0,''),(602938,189690,'1713774302.241660','deals','block_type','6',0,''),(602939,189690,'1713774302.241660','deals','schema','6-3',0,'5639'),(602940,189691,'1713774302.243252','deals','aria_name','account-menu',0,''),(602941,189692,'73374','deals','block_type','1',0,''),(602942,189692,'73374','deals','padding-top','70',0,''),(602943,189692,'73374','deals','padding-right','30',0,''),(602944,189692,'73374','deals','padding-bottom','30',0,''),(602945,189692,'73374','deals','padding-top','0',0,'5639'),(602946,189692,'73374','deals','padding-left','0',0,'5639'),(602947,189692,'73374','deals','padding-right','0',0,'5639'),(602948,189692,'73374','deals','padding-bottom','0',0,'5639'),(602991,189711,'1713774302.55728','deals','block_type','1',0,''),(602992,189712,'1713774302.558125','deals','link','Order History Info',0,''),(602993,189712,'1713774302.558125','deals','text','TEXT_VIEW',0,''),(602994,189712,'1713774302.558125','deals','max_orders','3',0,''),(602995,189712,'1713774302.558125','deals','link_pay','Order pay',0,''),(602996,189712,'1713774302.558125','deals','margin-bottom','30',0,''),(602997,189712,'1713774302.558125','deals','text_pay','ORDER_PAY',0,''),(602998,189713,'1713774302.559810','deals','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(602999,189714,'1713774302.562282','deals','text','<h1>##HEADING_TITLE##</h1>',0,''),(603000,189715,'1713774302.575318','deals','block_type','1',0,''),(603001,189715,'1713774302.575318','deals','padding-top','20',0,''),(603002,189715,'1713774302.575318','deals','padding-left','20',0,''),(603003,189715,'1713774302.575318','deals','padding-right','20',0,''),(603004,189715,'1713774302.575318','deals','padding-bottom','20',0,''),(603005,189715,'1713774302.575318','deals','margin-bottom','30',0,''),(603006,189715,'1713774302.575318','deals','border-top-width','1',0,''),(603007,189715,'1713774302.575318','deals','border-left-width','1',0,''),(603008,189715,'1713774302.575318','deals','border-right-width','1',0,''),(603009,189715,'1713774302.575318','deals','border-bottom-width','1',0,''),(603010,189715,'1713774302.575318','deals','border-top-color','$content-border-1',0,''),(603011,189715,'1713774302.575318','deals','border-left-color','$content-border-1',0,''),(603012,189715,'1713774302.575318','deals','border-right-color','$content-border-1',0,''),(603013,189715,'1713774302.575318','deals','border-bottom-color','$content-border-1',0,''),(603014,189715,'1713774302.575318','deals','style_class','account-content-top',0,''),(603015,189716,'1713774302.583346','deals','block_type','1',0,''),(603016,189717,'1713774302.584585','deals','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(603017,189717,'1713774302.584585','deals','font-family','trueloaded',0,'3'),(603018,189717,'1713774302.584585','deals','content','\\e920',0,'3'),(603019,189717,'1713774302.584585','deals','color','#EE4225',0,'3'),(603020,189717,'1713774302.584585','deals','font-size','30',0,'3'),(603021,189717,'1713774302.584585','deals','text-align','center',0,'3'),(603022,189717,'1713774302.584585','deals','margin-bottom','10',0,'3'),(603023,189717,'1713774302.584585','deals','text-align','center',0,''),(603024,189717,'1713774302.584585','deals','font-size','16',0,''),(603025,189717,'1713774302.584585','deals','text-transform','uppercase',0,''),(603026,189717,'1713774302.584585','deals','line-height','1',0,'3'),(603027,189717,'1713774302.584585','deals','font-size','14',0,'5630'),(603028,189718,'1713774302.588956','deals','font-family','$font-1',0,''),(603029,189718,'1713774302.588956','deals','color','#EE4225',0,''),(603030,189718,'1713774302.588956','deals','font-size','14',0,''),(603031,189718,'1713774302.588956','deals','text-align','center',0,''),(603032,189719,'1713774302.599185','deals','block_type','1',0,''),(603033,189720,'1713774302.600332','deals','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(603034,189720,'1713774302.600332','deals','font-family','trueloaded',0,'3'),(603035,189720,'1713774302.600332','deals','content','\\e928',0,'3'),(603036,189720,'1713774302.600332','deals','color','#EE4225',0,'3'),(603037,189720,'1713774302.600332','deals','font-size','30',0,'3'),(603038,189720,'1713774302.600332','deals','text-align','center',0,'3'),(603039,189720,'1713774302.600332','deals','text-align','center',0,''),(603040,189720,'1713774302.600332','deals','font-size','16',0,''),(603041,189720,'1713774302.600332','deals','text-transform','uppercase',0,''),(603042,189720,'1713774302.600332','deals','line-height','1',0,'3'),(603043,189720,'1713774302.600332','deals','font-size','14',0,'5630'),(603044,189721,'1713774302.604146','deals','font-family','$font-1',0,''),(603045,189721,'1713774302.604146','deals','color','#EE4225',0,''),(603046,189721,'1713774302.604146','deals','font-size','14',0,''),(603047,189721,'1713774302.604146','deals','text-align','center',0,''),(603048,189722,'1713774302.605686','deals','link','download_orders',0,''),(603049,189722,'1713774302.605686','deals','text','TEXT_DOWNLOAD_ORDERS',0,''),(603050,189722,'1713774302.605686','deals','hide_link','orders',0,''),(603051,189722,'1713774302.605686','deals','text-align','center',0,''),(603052,189722,'1713774302.605686','deals','popup','2',0,''),(603053,189722,'1713774302.605686','deals','font-size','14',0,''),(603054,189723,'1713774302.607525','deals','block_type','1',0,''),(603055,189724,'1713774302.608552','deals','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(603056,189724,'1713774302.608552','deals','font-family','trueloaded',0,'3'),(603057,189724,'1713774302.608552','deals','content','\\e922',0,'3'),(603058,189724,'1713774302.608552','deals','color','#EE4225',0,'3'),(603059,189724,'1713774302.608552','deals','font-size','30',0,'3'),(603060,189724,'1713774302.608552','deals','line-height','1',0,'3'),(603061,189724,'1713774302.608552','deals','font-size','16',0,''),(603062,189724,'1713774302.608552','deals','text-align','center',0,''),(603063,189724,'1713774302.608552','deals','text-transform','uppercase',0,''),(603064,189724,'1713774302.608552','deals','font-size','14',0,'5630'),(603065,189725,'1713774302.611730','deals','font-family','$font-1',0,''),(603066,189725,'1713774302.611730','deals','color','#EE4225',0,''),(603067,189725,'1713774302.611730','deals','line-height','1',0,''),(603068,189725,'1713774302.611730','deals','text-align','center',0,''),(603069,189725,'1713774302.611730','deals','font-size','14',0,''),(603070,189726,'1713774302.613318','deals','block_type','1',0,''),(603071,189727,'1713774302.614257','deals','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(603072,189727,'1713774302.614257','deals','content','\\e994',0,'3'),(603073,189727,'1713774302.614257','deals','font-family','trueloaded',0,'3'),(603074,189727,'1713774302.614257','deals','color','#EE4225',0,'3'),(603075,189727,'1713774302.614257','deals','font-size','30',0,'3'),(603076,189727,'1713774302.614257','deals','line-height','1',0,'3'),(603077,189727,'1713774302.614257','deals','font-size','16',0,''),(603078,189727,'1713774302.614257','deals','text-align','center',0,''),(603079,189727,'1713774302.614257','deals','text-transform','uppercase',0,''),(603080,189727,'1713774302.614257','deals','font-size','14',0,'5630'),(603081,189728,'1713774302.618189','deals','font-family','$font-1',0,''),(603082,189728,'1713774302.618189','deals','color','#EE4225',0,''),(603083,189728,'1713774302.618189','deals','font-size','14',0,''),(603084,189728,'1713774302.618189','deals','text-align','center',0,''),(603085,189729,'1713774302.619664','deals','link','Gift Certificate',0,''),(603086,189729,'1713774302.619664','deals','text','GIFT_CERTIFICATE',0,''),(603087,189729,'1713774302.619664','deals','popup','1',0,''),(603088,189729,'1713774302.619664','deals','text-align','center',0,''),(603089,189729,'1713774302.619664','deals','font-size','14',0,''),(603090,189730,'1713774302.620964','deals','block_type','1',0,''),(603091,189731,'1713774302.62216','deals','text','TEXT_VIEW_HISTORY',0,''),(603092,189731,'1713774302.62216','deals','popup','1',0,''),(603093,189731,'1713774302.62216','deals','text-align','center',0,''),(603094,189731,'1713774302.62216','deals','link','Points Earnt History',0,''),(603095,189731,'1713774302.62216','deals','font-size','14',0,''),(603096,189732,'1713774302.623592','deals','font-family','$font-1',0,''),(603097,189732,'1713774302.623592','deals','color','#EE4225',0,''),(603098,189732,'1713774302.623592','deals','font-size','14',0,''),(603099,189732,'1713774302.623592','deals','text-align','center',0,''),(603100,189733,'1713774302.625189','deals','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(603101,189733,'1713774302.625189','deals','content','\\e990',0,'3'),(603102,189733,'1713774302.625189','deals','font-family','trueloaded',0,'3'),(603103,189733,'1713774302.625189','deals','font-size','30',0,'3'),(603104,189733,'1713774302.625189','deals','text-align','center',0,'3'),(603105,189733,'1713774302.625189','deals','line-height','1',0,'3'),(603106,189733,'1713774302.625189','deals','color','#EE4225',0,'3'),(603107,189733,'1713774302.625189','deals','font-size','16',0,''),(603108,189733,'1713774302.625189','deals','text-align','center',0,''),(603109,189733,'1713774302.625189','deals','text-transform','uppercase',0,''),(603110,189733,'1713774302.625189','deals','font-size','14',0,'5630'),(603111,189734,'1713774302.628368','deals','block_type','1',0,''),(603112,189734,'1713774302.628368','deals','from_file','account-2.zip',0,''),(603113,189735,'1713774302.629597','deals','block_type','6',0,''),(603114,189735,'1713774302.629597','deals','schema','6-3',0,'5639'),(603115,189736,'1713774302.630510','deals','aria_name','account-menu',0,''),(603116,189737,'73374','deals','block_type','1',0,''),(603117,189737,'73374','deals','padding-top','70',0,''),(603118,189737,'73374','deals','padding-right','30',0,''),(603119,189737,'73374','deals','padding-bottom','30',0,''),(603120,189737,'73374','deals','padding-top','0',0,'5639'),(603121,189737,'73374','deals','padding-left','0',0,'5639'),(603122,189737,'73374','deals','padding-right','0',0,'5639'),(603123,189737,'73374','deals','padding-bottom','0',0,'5639'),(603166,189756,'1713774302.942945','deals','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(603167,189757,'1713774302.94546','deals','margin-bottom','20',0,''),(603168,189758,'1713774302.951148','deals','block_type','1',0,''),(603169,189758,'1713774302.951148','deals','style_class','account-order-history-info',0,''),(603170,189758,'1713774302.951148','deals','from_file','account-2.zip',0,''),(603171,189759,'1713774302.98691','deals','block_type','6',0,''),(603172,189759,'1713774302.98691','deals','schema','6-3',0,'5639'),(603173,189760,'1713774302.987797','deals','aria_name','account-menu',0,''),(603174,189761,'73374','deals','block_type','1',0,''),(603175,189761,'73374','deals','padding-top','70',0,''),(603176,189761,'73374','deals','padding-right','30',0,''),(603177,189761,'73374','deals','padding-bottom','30',0,''),(603178,189761,'73374','deals','padding-top','0',0,'5639'),(603179,189761,'73374','deals','padding-left','0',0,'5639'),(603180,189761,'73374','deals','padding-right','0',0,'5639'),(603181,189761,'73374','deals','padding-bottom','0',0,'5639'),(603224,189780,'1713774303.355589','deals','float','right',0,''),(603225,189780,'1713774303.355589','deals','clear','none',0,''),(603226,189780,'1713774303.355589','deals','margin-left','20',0,''),(603227,189782,'1713774303.357736','deals','float','right',0,''),(603228,189782,'1713774303.357736','deals','clear','none',0,''),(603229,189782,'1713774303.357736','deals','like_button','2',0,''),(603230,189782,'1713774303.357736','deals','link','Order pay',0,''),(603231,189783,'1713774303.358932','deals','block_type','2',0,''),(603232,189783,'1713774303.358932','deals','padding-top','20',0,''),(603233,189783,'1713774303.358932','deals','margin-bottom','20',0,''),(603234,189784,'1713774303.362185','deals','like_button','1',0,''),(603235,189784,'1713774303.362185','deals','text','IMAGE_BUTTON_BACK',0,''),(603236,189784,'1713774303.362185','deals','link','Order History',0,''),(603237,189785,'1713774303.365122','deals','text-align','right',0,''),(603238,189786,'1713774303.366232','deals','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(603239,189788,'1713774303.36967','deals','float','right',0,''),(603240,189788,'1713774303.36967','deals','clear','none',0,''),(603241,189788,'1713774303.36967','deals','margin-left','20',0,''),(603242,189790,'1713774303.372180','deals','float','right',0,''),(603243,189791,'1713774303.374982','deals','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(603244,189793,'1713774303.378529','deals','float','left',0,''),(603245,189794,'1713774303.379873','deals','block_type','3',0,''),(603246,189794,'1713774303.379873','deals','clear','both',0,''),(603247,189794,'1713774303.379873','deals','padding-top','20',0,''),(603248,189794,'1713774303.379873','deals','schema','3-4',0,'5630'),(603249,189795,'1713774303.38143','deals','block_type','1',0,''),(603250,189795,'1713774303.38143','deals','margin-bottom','20',0,''),(603251,189795,'1713774303.38143','deals','padding-right','20',0,''),(603252,189796,'1713774303.383169','deals','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(603253,189797,'1713774303.385376','deals','padding-left','30',0,''),(603254,189797,'1713774303.385376','deals','orders_data','telephone',0,''),(603255,189797,'1713774303.385376','deals','hide_parents','2',0,''),(603256,189798,'1713774303.386781','deals','block_type','1',0,''),(603257,189798,'1713774303.386781','deals','padding-right','20',0,''),(603258,189798,'1713774303.386781','deals','padding-bottom','20',0,''),(603259,189799,'1713774303.387715','deals','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(603260,189800,'1713774303.392348','deals','orders_data','name',0,''),(603261,189800,'1713774303.392348','deals','padding-left','30',0,''),(603262,189801,'1713774303.393461','deals','block_type','1',0,''),(603263,189801,'1713774303.393461','deals','padding-right','20',0,''),(603264,189801,'1713774303.393461','deals','margin-bottom','20',0,''),(603265,189802,'1713774303.394715','deals','short_view','1',0,''),(603266,189802,'1713774303.394715','deals','hide_parents','2',0,''),(603267,189803,'1713774303.3963','deals','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(603268,189804,'1713774303.39839','deals','link','Tracking numbers',0,''),(603269,189804,'1713774303.39839','deals','text','MORE_TRACKING_NUMBER',0,''),(603270,189804,'1713774303.39839','deals','popup','1',0,''),(603271,189804,'1713774303.39839','deals','order_id','1',0,''),(603272,189804,'1713774303.39839','deals','popup_class','tracking-numbers-popup',0,''),(603273,189804,'1713774303.39839','deals','font-weight','700',0,''),(603274,189804,'1713774303.39839','deals','font-size','18',0,''),(603275,189805,'1713774303.479','deals','block_type','1',0,''),(603276,189805,'1713774303.479','deals','padding-right','20',0,''),(603277,189806,'1713774303.401260','deals','orders_data','shipping_method',0,''),(603278,189806,'1713774303.401260','deals','padding-left','30',0,''),(603279,189807,'1713774303.402194','deals','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(603280,189808,'1713774303.403789','deals','block_type','1',0,''),(603281,189808,'1713774303.403789','deals','padding-right','20',0,''),(603282,189808,'1713774303.403789','deals','padding-bottom','20',0,''),(603283,189809,'1713774303.404787','deals','orders_data','delivery_address',0,''),(603284,189809,'1713774303.404787','deals','padding-left','30',0,''),(603285,189810,'1713774303.405697','deals','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(603286,189811,'1713774303.407397','deals','block_type','1',0,''),(603287,189812,'1713774303.408152','deals','orders_data','payment_method',0,''),(603288,189812,'1713774303.408152','deals','padding-left','30',0,''),(603289,189813,'1713774303.409138','deals','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(603290,189814,'1713774303.41090','deals','block_type','1',0,''),(603291,189814,'1713774303.41090','deals','padding-bottom','20',0,''),(603292,189815,'1713774303.411821','deals','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(603293,189816,'1713774303.413853','deals','orders_data','billing_address',0,''),(603294,189816,'1713774303.413853','deals','padding-left','30',0,''),(603295,189817,'1713774303.414793','deals','block_type','1',0,''),(603296,189817,'1713774303.414793','deals','style_class','account-address-book',0,''),(603297,189817,'1713774303.414793','deals','from_file','account-2.zip',0,''),(603298,189818,'1713774303.415755','deals','block_type','6',0,''),(603299,189818,'1713774303.415755','deals','schema','6-3',0,'5639'),(603300,189819,'1713774303.416744','deals','aria_name','account-menu',0,''),(603301,189820,'73374','deals','block_type','1',0,''),(603302,189820,'73374','deals','padding-top','70',0,''),(603303,189820,'73374','deals','padding-right','30',0,''),(603304,189820,'73374','deals','padding-bottom','30',0,''),(603305,189820,'73374','deals','padding-top','0',0,'5639'),(603306,189820,'73374','deals','padding-left','0',0,'5639'),(603307,189820,'73374','deals','padding-right','0',0,'5639'),(603308,189820,'73374','deals','padding-bottom','0',0,'5639'),(603351,189839,'1713774303.748485','deals','padding-top','15',0,''),(603352,189839,'1713774303.748485','deals','padding-bottom','15',0,''),(603353,189839,'1713774303.748485','deals','link','Address Book Process',0,''),(603354,189839,'1713774303.748485','deals','text','EDIT',0,''),(603355,189839,'1713774303.748485','deals','link_add','Address Book Process',0,''),(603356,189839,'1713774303.748485','deals','like_button_add','2',0,''),(603357,189839,'1713774303.748485','deals','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(603358,189840,'1713774303.759421','deals','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(603359,189841,'1713774303.7624','deals','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(603360,189842,'1713774303.76450','deals','block_type','1',0,''),(603361,189842,'1713774303.76450','deals','style_class','account-edit-wrap',0,''),(603362,189842,'1713774303.76450','deals','from_file','account-2.zip',0,''),(603363,189843,'1713774303.768552','deals','block_type','6',0,''),(603364,189843,'1713774303.768552','deals','schema','6-3',0,'5639'),(603365,189844,'1713774303.770899','deals','aria_name','account-menu',0,''),(603366,189845,'73374','deals','block_type','1',0,''),(603367,189845,'73374','deals','padding-top','70',0,''),(603368,189845,'73374','deals','padding-right','30',0,''),(603369,189845,'73374','deals','padding-bottom','30',0,''),(603370,189845,'73374','deals','padding-top','0',0,'5639'),(603371,189845,'73374','deals','padding-left','0',0,'5639'),(603372,189845,'73374','deals','padding-right','0',0,'5639'),(603373,189845,'73374','deals','padding-bottom','0',0,'5639'),(603416,189865,'1713774304.061861','deals','text','<h1>##HEADING_TITLE##</h1>',0,''),(603417,189866,'1713774304.077962','deals','block_type','1',0,''),(603418,189866,'1713774304.077962','deals','style_class','account-order-history',0,''),(603419,189866,'1713774304.077962','deals','from_file','account-2.zip',0,''),(603420,189867,'1713774304.184488','deals','block_type','6',0,''),(603421,189867,'1713774304.184488','deals','schema','6-3',0,'5639'),(603422,189868,'1713774304.186275','deals','aria_name','account-menu',0,''),(603423,189869,'73374','deals','block_type','1',0,''),(603424,189869,'73374','deals','padding-top','70',0,''),(603425,189869,'73374','deals','padding-right','30',0,''),(603426,189869,'73374','deals','padding-bottom','30',0,''),(603427,189869,'73374','deals','padding-top','0',0,'5639'),(603428,189869,'73374','deals','padding-left','0',0,'5639'),(603429,189869,'73374','deals','padding-right','0',0,'5639'),(603430,189869,'73374','deals','padding-bottom','0',0,'5639'),(603473,189888,'1713774304.463836','deals','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(603474,189889,'1713774304.465929','deals','link','Order History Info',0,''),(603475,189889,'1713774304.465929','deals','text','TEXT_VIEW',0,''),(603476,189889,'1713774304.465929','deals','show_pagenation','1',0,''),(603477,189889,'1713774304.465929','deals','link_pay','Order pay',0,''),(603478,189889,'1713774304.465929','deals','margin-bottom','20',0,''),(603479,189890,'1713774304.467962','deals','block_type','1',0,''),(603480,189890,'1713774304.467962','deals','style_class','account-address-book-process',0,''),(603481,189890,'1713774304.467962','deals','from_file','account-2.zip',0,''),(603482,189891,'1713774304.471135','deals','block_type','6',0,''),(603483,189891,'1713774304.471135','deals','schema','6-3',0,'5639'),(603484,189892,'1713774304.472570','deals','aria_name','account-menu',0,''),(603485,189893,'73374','deals','block_type','1',0,''),(603486,189893,'73374','deals','padding-top','70',0,''),(603487,189893,'73374','deals','padding-right','30',0,''),(603488,189893,'73374','deals','padding-bottom','30',0,''),(603489,189893,'73374','deals','padding-top','0',0,'5639'),(603490,189893,'73374','deals','padding-left','0',0,'5639'),(603491,189893,'73374','deals','padding-right','0',0,'5639'),(603492,189893,'73374','deals','padding-bottom','0',0,'5639'),(603493,189894,'73375','deals','block_type','1',0,''),(603494,189894,'73375','deals','style_class','account-menu',0,''),(603495,189895,'73376','deals','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(603496,189895,'73376','deals','style_class','heading-settings',0,''),(603497,189896,'73377','deals','link','logoff',0,''),(603498,189897,'73378','deals','link','delete',0,''),(603499,189897,'73378','deals','text','DELETE_ACCOUNT',0,''),(603500,189898,'73379','deals','text','TEXT_DASHBOARD',0,''),(603501,189898,'73379','deals','font-family','$font-1',0,''),(603502,189898,'73379','deals','font-size','18',0,''),(603503,189898,'73379','deals','text-transform','uppercase',0,''),(603504,189899,'73380','deals','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(603505,189899,'73380','deals','style_class','heading-saved-lists',0,''),(603506,189900,'73381','deals','link','Personal Catalog',0,''),(603507,189900,'73381','deals','text','TEXT_PERSONAL_CATALOG',0,''),(603508,189900,'73381','deals','hide_link','personal_catalog',0,''),(603509,189901,'73382','deals','link','Order History',0,''),(603510,189901,'73382','deals','text','HEADING_ORDER_HISTORY',0,''),(603511,189901,'73382','deals','active_link','Order History Info,Order pay',0,''),(603512,189902,'73383','deals','link','Address Book',0,''),(603513,189902,'73383','deals','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(603514,189903,'73384','deals','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(603515,189903,'73384','deals','style_class','heading-ordered-items',0,''),(603516,189904,'73385','deals','link','Wishlist',0,''),(603517,189904,'73385','deals','hide_link','wishlist',0,''),(603518,189904,'73385','deals','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(603519,189905,'73386','deals','link','My password',0,''),(603520,189905,'73386','deals','text','TEXT_MY_PASSWORD',0,''),(603521,189906,'73387','deals','link','Samples',0,''),(603522,189906,'73387','deals','text','TEXT_HEADING_SAMPLE_CART',0,''),(603523,189906,'73387','deals','hide_link','samples',0,''),(603524,189907,'73388','deals','link','Review',0,''),(603525,189907,'73388','deals','text','REVIEWS',0,''),(603526,189908,'73389','deals','link','Quotations',0,''),(603527,189908,'73389','deals','hide_link','quotations',0,''),(603528,189908,'73389','deals','text','TEXT_HEADING_QUOTE_CART',0,''),(603529,189909,'73390','deals','link','Account edit',0,''),(603530,189909,'73390','deals','text','ACCOUNT_EDIT',0,''),(603531,189910,'73391','deals','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(603532,189910,'73391','deals','style_class','heading-settings',0,''),(603533,189911,'73392','deals','link','trade_form',0,''),(603534,189911,'73392','deals','text','TRADE_FORM',0,''),(603535,189912,'1713774304.752267','deals','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(603536,189914,'73349','origin','text','##TEXT_PAGE_NOT_FOUND##',0,''),(603537,189914,'73349','origin','text-align','center',0,''),(603538,189914,'73349','origin','padding-top','100',0,''),(603539,189914,'73349','origin','padding-bottom','100',0,''),(603540,189915,'73350','origin','block_type','1',0,''),(603541,189915,'73350','origin','style_class','account-index',0,''),(603542,189916,'73351','origin','block_type','6',0,''),(603543,189916,'73351','origin','schema','6-3',0,'8356'),(603544,189917,'73352','origin','aria_name','account-menu',0,''),(603545,189918,'73374','origin','block_type','1',0,''),(603546,189918,'73374','origin','padding-top','70',0,''),(603547,189918,'73374','origin','padding-right','30',0,''),(603548,189918,'73374','origin','padding-bottom','30',0,''),(603549,189918,'73374','origin','padding-top','0',0,'8356'),(603550,189918,'73374','origin','padding-left','0',0,'8356'),(603551,189918,'73374','origin','padding-right','0',0,'8356'),(603552,189918,'73374','origin','padding-bottom','0',0,'8356'),(603595,189937,'1704978704.8413','origin','block_type','1',0,''),(603596,189938,'73353','origin','link','Order History Info',0,''),(603597,189938,'73353','origin','text','TEXT_VIEW',0,''),(603598,189938,'73353','origin','max_orders','3',0,''),(603599,189938,'73353','origin','link_pay','Order pay',0,''),(603600,189938,'73353','origin','margin-bottom','30',0,''),(603601,189938,'73353','origin','text_pay','ORDER_PAY',0,''),(603602,189939,'73354','origin','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(603603,189940,'73357','origin','text','<h1>##HEADING_TITLE##</h1>',0,''),(603604,189941,'1705060269.3517','origin','block_type','1',0,''),(603605,189941,'1705060269.3517','origin','padding-top','20',0,''),(603606,189941,'1705060269.3517','origin','padding-left','20',0,''),(603607,189941,'1705060269.3517','origin','padding-right','20',0,''),(603608,189941,'1705060269.3517','origin','padding-bottom','20',0,''),(603609,189941,'1705060269.3517','origin','margin-bottom','30',0,''),(603610,189941,'1705060269.3517','origin','border-top-width','1',0,''),(603611,189941,'1705060269.3517','origin','border-left-width','1',0,''),(603612,189941,'1705060269.3517','origin','border-right-width','1',0,''),(603613,189941,'1705060269.3517','origin','border-bottom-width','1',0,''),(603614,189941,'1705060269.3517','origin','border-top-color','$content-border-1',0,''),(603615,189941,'1705060269.3517','origin','border-left-color','$content-border-1',0,''),(603616,189941,'1705060269.3517','origin','border-right-color','$content-border-1',0,''),(603617,189941,'1705060269.3517','origin','border-bottom-color','$content-border-1',0,''),(603618,189941,'1705060269.3517','origin','style_class','account-content-top',0,''),(603619,189942,'1705060551.6998','origin','block_type','1',0,''),(603620,189943,'73361','origin','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(603621,189943,'73361','origin','font-family','trueloaded',0,'3'),(603622,189943,'73361','origin','content','\\e920',0,'3'),(603623,189943,'73361','origin','color','$highlight-color-3',0,'3'),(603624,189943,'73361','origin','font-size','30',0,'3'),(603625,189943,'73361','origin','text-align','center',0,'3'),(603626,189943,'73361','origin','margin-bottom','10',0,'3'),(603627,189943,'73361','origin','text-align','center',0,''),(603628,189943,'73361','origin','font-size','16',0,''),(603629,189943,'73361','origin','text-transform','uppercase',0,''),(603630,189943,'73361','origin','line-height','1',0,'3'),(603631,189943,'73361','origin','font-size','14',0,'8349'),(603632,189944,'73362','origin','font-family','$font-1',0,''),(603633,189944,'73362','origin','color','$highlight-color-3',0,''),(603634,189944,'73362','origin','font-size','14',0,''),(603635,189944,'73362','origin','text-align','center',0,''),(603636,189945,'1705060566.121','origin','block_type','1',0,''),(603637,189946,'73363','origin','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(603638,189946,'73363','origin','font-family','trueloaded',0,'3'),(603639,189946,'73363','origin','content','\\e928',0,'3'),(603640,189946,'73363','origin','color','$highlight-color-3',0,'3'),(603641,189946,'73363','origin','font-size','30',0,'3'),(603642,189946,'73363','origin','text-align','center',0,'3'),(603643,189946,'73363','origin','text-align','center',0,''),(603644,189946,'73363','origin','font-size','16',0,''),(603645,189946,'73363','origin','text-transform','uppercase',0,''),(603646,189946,'73363','origin','line-height','1',0,'3'),(603647,189946,'73363','origin','font-size','14',0,'8349'),(603648,189947,'73364','origin','font-family','$font-1',0,''),(603649,189947,'73364','origin','color','$highlight-color-3',0,''),(603650,189947,'73364','origin','font-size','14',0,''),(603651,189947,'73364','origin','text-align','center',0,''),(603652,189948,'73365','origin','link','download_orders',0,''),(603653,189948,'73365','origin','text','TEXT_DOWNLOAD_ORDERS',0,''),(603654,189948,'73365','origin','hide_link','orders',0,''),(603655,189948,'73365','origin','text-align','center',0,''),(603656,189948,'73365','origin','popup','2',0,''),(603657,189948,'73365','origin','font-size','14',0,''),(603658,189949,'1705060582.9285','origin','block_type','1',0,''),(603659,189950,'73366','origin','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(603660,189950,'73366','origin','font-family','trueloaded',0,'3'),(603661,189950,'73366','origin','content','\\e922',0,'3'),(603662,189950,'73366','origin','color','$highlight-color-3',0,'3'),(603663,189950,'73366','origin','font-size','30',0,'3'),(603664,189950,'73366','origin','line-height','1',0,'3'),(603665,189950,'73366','origin','font-size','16',0,''),(603666,189950,'73366','origin','text-align','center',0,''),(603667,189950,'73366','origin','text-transform','uppercase',0,''),(603668,189950,'73366','origin','font-size','14',0,'8349'),(603669,189951,'73367','origin','font-family','$font-1',0,''),(603670,189951,'73367','origin','color','$highlight-color-3',0,''),(603671,189951,'73367','origin','line-height','1',0,''),(603672,189951,'73367','origin','text-align','center',0,''),(603673,189951,'73367','origin','font-size','14',0,''),(603674,189952,'1705060591.4402','origin','block_type','1',0,''),(603675,189953,'73368','origin','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(603676,189953,'73368','origin','content','\\e994',0,'3'),(603677,189953,'73368','origin','font-family','trueloaded',0,'3'),(603678,189953,'73368','origin','color','$highlight-color-3',0,'3'),(603679,189953,'73368','origin','font-size','30',0,'3'),(603680,189953,'73368','origin','line-height','1',0,'3'),(603681,189953,'73368','origin','font-size','16',0,''),(603682,189953,'73368','origin','text-align','center',0,''),(603683,189953,'73368','origin','text-transform','uppercase',0,''),(603684,189953,'73368','origin','font-size','14',0,'8349'),(603685,189954,'73369','origin','font-family','$font-1',0,''),(603686,189954,'73369','origin','color','$highlight-color-3',0,''),(603687,189954,'73369','origin','font-size','14',0,''),(603688,189954,'73369','origin','text-align','center',0,''),(603689,189955,'73370','origin','link','Gift Certificate',0,''),(603690,189955,'73370','origin','text','GIFT_CERTIFICATE',0,''),(603691,189955,'73370','origin','popup','1',0,''),(603692,189955,'73370','origin','text-align','center',0,''),(603693,189955,'73370','origin','font-size','14',0,''),(603694,189956,'1705060602.1936','origin','block_type','1',0,''),(603695,189957,'73371','origin','text','TEXT_VIEW_HISTORY',0,''),(603696,189957,'73371','origin','popup','1',0,''),(603697,189957,'73371','origin','text-align','center',0,''),(603698,189957,'73371','origin','link','Points Earnt History',0,''),(603699,189957,'73371','origin','font-size','14',0,''),(603700,189958,'73372','origin','font-family','$font-1',0,''),(603701,189958,'73372','origin','color','$highlight-color-3',0,''),(603702,189958,'73372','origin','font-size','14',0,''),(603703,189958,'73372','origin','text-align','center',0,''),(603704,189959,'73373','origin','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(603705,189959,'73373','origin','content','\\e990',0,'3'),(603706,189959,'73373','origin','font-family','trueloaded',0,'3'),(603707,189959,'73373','origin','font-size','30',0,'3'),(603708,189959,'73373','origin','text-align','center',0,'3'),(603709,189959,'73373','origin','line-height','1',0,'3'),(603710,189959,'73373','origin','color','$highlight-color-3',0,'3'),(603711,189959,'73373','origin','font-size','16',0,''),(603712,189959,'73373','origin','text-align','center',0,''),(603713,189959,'73373','origin','text-transform','uppercase',0,''),(603714,189959,'73373','origin','font-size','14',0,'8349'),(603715,189960,'73374','origin','block_type','1',0,''),(603716,189960,'73374','origin','padding-top','70',0,''),(603717,189960,'73374','origin','padding-right','30',0,''),(603718,189960,'73374','origin','padding-bottom','30',0,''),(603719,189960,'73374','origin','padding-top','0',0,'8356'),(603720,189960,'73374','origin','padding-left','0',0,'8356'),(603721,189960,'73374','origin','padding-right','0',0,'8356'),(603722,189960,'73374','origin','padding-bottom','0',0,'8356'),(603765,189979,'73393','origin','block_type','1',0,''),(603766,189979,'73393','origin','style_class','account-edit-wrap',0,''),(603767,189980,'73394','origin','block_type','6',0,''),(603768,189980,'73394','origin','schema','6-3',0,'8356'),(603769,189981,'73395','origin','aria_name','account-menu',0,''),(603770,189982,'73374','origin','block_type','1',0,''),(603771,189982,'73374','origin','padding-top','70',0,''),(603772,189982,'73374','origin','padding-right','30',0,''),(603773,189982,'73374','origin','padding-bottom','30',0,''),(603774,189982,'73374','origin','padding-top','0',0,'8356'),(603775,189982,'73374','origin','padding-left','0',0,'8356'),(603776,189982,'73374','origin','padding-right','0',0,'8356'),(603777,189982,'73374','origin','padding-bottom','0',0,'8356'),(603820,190002,'73397','origin','text','<h1>##HEADING_TITLE##</h1>',0,''),(603821,190003,'73398','origin','block_type','1',0,''),(603822,190003,'73398','origin','style_class','account-address-book',0,''),(603823,190004,'73399','origin','block_type','6',0,''),(603824,190004,'73399','origin','schema','6-3',0,'8356'),(603825,190005,'73400','origin','aria_name','account-menu',0,''),(603826,190006,'73374','origin','block_type','1',0,''),(603827,190006,'73374','origin','padding-top','70',0,''),(603828,190006,'73374','origin','padding-right','30',0,''),(603829,190006,'73374','origin','padding-bottom','30',0,''),(603830,190006,'73374','origin','padding-top','0',0,'8356'),(603831,190006,'73374','origin','padding-left','0',0,'8356'),(603832,190006,'73374','origin','padding-right','0',0,'8356'),(603833,190006,'73374','origin','padding-bottom','0',0,'8356'),(603876,190025,'73401','origin','padding-top','15',0,''),(603877,190025,'73401','origin','padding-bottom','15',0,''),(603878,190025,'73401','origin','link','Address Book Process',0,''),(603879,190025,'73401','origin','text','EDIT',0,''),(603880,190025,'73401','origin','link_add','Address Book Process',0,''),(603881,190025,'73401','origin','like_button_add','2',0,''),(603882,190025,'73401','origin','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(603883,190026,'73402','origin','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(603884,190027,'73403','origin','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(603885,190028,'73404','origin','block_type','1',0,''),(603886,190028,'73404','origin','style_class','account-address-book-process',0,''),(603887,190029,'73405','origin','block_type','6',0,''),(603888,190029,'73405','origin','schema','6-3',0,'8356'),(603889,190030,'73406','origin','aria_name','account-menu',0,''),(603890,190031,'73374','origin','block_type','1',0,''),(603891,190031,'73374','origin','padding-top','70',0,''),(603892,190031,'73374','origin','padding-right','30',0,''),(603893,190031,'73374','origin','padding-bottom','30',0,''),(603894,190031,'73374','origin','padding-top','0',0,'8356'),(603895,190031,'73374','origin','padding-left','0',0,'8356'),(603896,190031,'73374','origin','padding-right','0',0,'8356'),(603897,190031,'73374','origin','padding-bottom','0',0,'8356'),(603940,190050,'73407','origin','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(603941,190052,'73409','origin','block_type','1',0,''),(603942,190052,'73409','origin','style_class','item-holder',0,''),(603943,190052,'73409','origin','padding-top','25',0,''),(603944,190052,'73409','origin','padding-bottom','25',0,''),(603945,190052,'73409','origin','text-align','left',0,''),(603946,190052,'73409','origin','border-top-color','$content-border-1',0,''),(603947,190052,'73409','origin','border-top-width','1',0,''),(603948,190053,'73410','origin','block_type','6',0,''),(603949,190054,'73411','origin','padding-right','20',0,''),(603950,190055,'73412','origin','description_characters','200',0,''),(603951,190055,'73412','origin','clear','none',0,''),(603952,190055,'73412','origin','padding-right','20',0,''),(603953,190056,'73413','origin','clear','none',0,''),(603954,190058,'73415','origin','block_type','4',0,''),(603955,190059,'73416','origin','block_type','2',0,''),(603956,190060,'73417','origin','margin-bottom','7',0,''),(603957,190061,'73418','origin','clear','none',0,''),(603958,190062,'73419','origin','margin-bottom','20',0,''),(603959,190062,'73419','origin','text-align','right',0,''),(603960,190063,'73420','origin','padding-right','20',0,''),(603961,190064,'73421','origin','block_type','2',0,''),(603962,190065,'73422','origin','clear','none',0,''),(603963,190067,'76000','origin','block_type','1',0,''),(603964,190067,'76000','origin','style_class','item-holder',0,''),(603965,190067,'76000','origin','padding-top','25',0,''),(603966,190067,'76000','origin','padding-left','25',0,''),(603967,190067,'76000','origin','padding-right','25',0,''),(603968,190067,'76000','origin','padding-bottom','25',0,''),(603969,190067,'76000','origin','text-align','left',0,''),(603970,190069,'76002','origin','margin-bottom','7',0,''),(603971,190070,'76003','origin','clear','both',0,''),(603972,190073,'76006','origin','block_type','1',0,''),(603973,190073,'76006','origin','style_class','item-holder',0,''),(603974,190073,'76006','origin','padding-top','25',0,''),(603975,190073,'76006','origin','padding-left','25',0,''),(603976,190073,'76006','origin','padding-right','25',0,''),(603977,190073,'76006','origin','padding-bottom','25',0,''),(603978,190073,'76006','origin','text-align','left',0,''),(603979,190074,'76007','origin','block_type','5',0,''),(603980,190077,'76010','origin','margin-bottom','7',0,''),(603981,190078,'76011','origin','clear','both',0,''),(603982,190079,'76012','origin','block_type','1',0,''),(603983,190080,'76013','origin','block_type','6',0,''),(603984,190080,'76013','origin','font-weight','400',0,''),(603985,190080,'76013','origin','schema','6-2',0,'8377'),(603986,190080,'76013','origin','schema','6-2',0,'8356'),(603987,190081,'76014','origin','font-weight','400',0,''),(603988,190081,'76014','origin','padding-right','40',0,''),(603989,190081,'76014','origin','padding-right','0',0,'8377'),(603990,190081,'76014','origin','padding-right','0',0,'8356'),(603991,190082,'76015','origin','block_type','5',0,''),(603992,190082,'76015','origin','padding-top','10',0,''),(603993,190082,'76015','origin','padding-bottom','10',0,''),(603994,190082,'76015','origin','schema','5-2',0,'8377'),(603995,190082,'76015','origin','border-top-color','$content-border-1',0,''),(603996,190082,'76015','origin','border-top-width','1',0,''),(603997,190084,'76017','origin','float','right',0,''),(603998,190086,'76019','origin','col_in_row','3',0,''),(603999,190086,'76019','origin','products_align','left',0,''),(604000,190086,'76019','origin','font-weight','400',0,''),(604001,190086,'76019','origin','show_qty_input','0',0,''),(604002,190086,'76019','origin','listing_type','productListing',0,''),(604003,190086,'76019','origin','listing_type_rows','no',0,''),(604004,190086,'76019','origin','show_buy_button_b2b','on',0,''),(604005,190086,'76019','origin','show_wishlist_button_b2b','1',0,''),(604006,190086,'76019','origin','show_compare_b2b','1',0,''),(604007,190086,'76019','origin','show_stock','0',0,''),(604008,190086,'76019','origin','show_description','0',0,''),(604009,190086,'76019','origin','show_model','0',0,''),(604010,190086,'76019','origin','show_properties','0',0,''),(604011,190086,'76019','origin','show_rating','0',0,''),(604012,190086,'76019','origin','show_rating_counts','0',0,''),(604013,190086,'76019','origin','show_price','0',0,''),(604014,190086,'76019','origin','show_buy_button','0',0,''),(604015,190086,'76019','origin','show_view_button','0',0,''),(604016,190086,'76019','origin','show_wishlist_button','0',0,''),(604017,190086,'76019','origin','show_compare','0',0,''),(604018,190086,'76019','origin','show_name_rows','0',0,''),(604019,190086,'76019','origin','show_image_rows','0',0,''),(604020,190086,'76019','origin','show_stock_rows','0',0,''),(604021,190086,'76019','origin','show_description_rows','0',0,''),(604022,190086,'76019','origin','show_model_rows','0',0,''),(604023,190086,'76019','origin','show_properties_rows','0',0,''),(604024,190086,'76019','origin','show_rating_rows','0',0,''),(604025,190086,'76019','origin','show_rating_counts_rows','0',0,''),(604026,190086,'76019','origin','show_price_rows','0',0,''),(604027,190086,'76019','origin','show_buy_button_rows','0',0,''),(604028,190086,'76019','origin','show_qty_input_rows','0',0,''),(604029,190086,'76019','origin','show_view_button_rows','0',0,''),(604030,190086,'76019','origin','show_wishlist_button_rows','0',0,''),(604031,190086,'76019','origin','show_compare_rows','0',0,''),(604032,190086,'76019','origin','show_name_b2b','0',0,''),(604033,190086,'76019','origin','show_image_b2b','0',0,''),(604034,190086,'76019','origin','show_stock_b2b','0',0,''),(604035,190086,'76019','origin','show_description_b2b','0',0,''),(604036,190086,'76019','origin','show_model_b2b','0',0,''),(604037,190086,'76019','origin','show_properties_b2b','0',0,''),(604038,190086,'76019','origin','show_rating_b2b','0',0,''),(604039,190086,'76019','origin','show_rating_counts_b2b','0',0,''),(604040,190086,'76019','origin','show_price_b2b','0',0,''),(604041,190086,'76019','origin','show_qty_input_b2b','0',0,''),(604042,190086,'76019','origin','show_view_button_b2b','0',0,''),(604043,190086,'76019','origin','show_attributes_b2b','0',0,''),(604044,190086,'76019','origin','items_on_page','9',0,''),(604045,190086,'76019','origin','col_in_row','2',0,'8356'),(604046,190086,'76019','origin','col_in_row','1',0,'8377'),(604047,190086,'76019','origin','product_names_teg','h2',0,''),(604048,190087,'76020','origin','listing_type','productListing',0,''),(604049,190088,'76021','origin','block_type','1',0,''),(604050,190088,'76021','origin','padding-top','10',0,''),(604051,190088,'76021','origin','padding-bottom','10',0,''),(604052,190088,'76021','origin','border-bottom-width','1',0,''),(604053,190088,'76021','origin','border-bottom-color','$content-border-1',0,''),(604054,190088,'76021','origin','margin-left','0',0,''),(604055,190088,'76021','origin','margin-right','0',0,''),(604056,190089,'76022','origin','float','right',0,''),(604057,190089,'76022','origin','display','none',0,'8377'),(604058,190090,'76023','origin','margin-right','20',0,''),(604059,190090,'76023','origin','float','right',0,''),(604060,190090,'76023','origin','clear','none',0,''),(604061,190090,'76023','origin','display','none',0,'8356'),(604062,190091,'76024','origin','float','left',0,''),(604063,190091,'76024','origin','clear','none',0,''),(604064,190091,'76024','origin','margin-left','20',0,''),(604065,190091,'76024','origin','display','none',0,'8377'),(604066,190092,'76025','origin','float','left',0,''),(604067,190092,'76025','origin','clear','none',0,''),(604068,190092,'76025','origin','sort_pos_3','1',0,''),(604069,190092,'76025','origin','sort_pos_4','2',0,''),(604070,190092,'76025','origin','sort_pos_10','3',0,''),(604071,190092,'76025','origin','sort_pos_9','4',0,''),(604072,190092,'76025','origin','sort_pos_11','5',0,''),(604073,190092,'76025','origin','sort_pos_12','6',0,''),(604074,190092,'76025','origin','sort_pos_14','7',0,''),(604075,190092,'76025','origin','sort_pos_13','8',0,''),(604076,190092,'76025','origin','sort_pos_8','9',0,''),(604077,190092,'76025','origin','sort_pos_7','10',0,''),(604078,190092,'76025','origin','sort_pos_2','11',0,''),(604079,190092,'76025','origin','sort_pos_1','12',0,''),(604080,190092,'76025','origin','sort_pos_6','13',0,''),(604081,190092,'76025','origin','sort_pos_5','14',0,''),(604082,190092,'76025','origin','sort_pos_0','15',0,''),(604083,190092,'76025','origin','sort_hide_10','1',0,''),(604084,190092,'76025','origin','sort_hide_9','1',0,''),(604085,190092,'76025','origin','hide_icons','1',0,''),(604086,190092,'76025','origin','sort_hide_16','1',0,''),(604087,190092,'76025','origin','sort_hide_15','1',0,''),(604088,190092,'76025','origin','sort_hide_3','0',0,''),(604089,190092,'76025','origin','sort_hide_4','0',0,''),(604090,190092,'76025','origin','sort_hide_11','1',0,''),(604091,190092,'76025','origin','sort_hide_12','1',0,''),(604092,190092,'76025','origin','sort_hide_14','1',0,''),(604093,190092,'76025','origin','sort_hide_13','1',0,''),(604094,190092,'76025','origin','sort_hide_8','0',0,''),(604095,190092,'76025','origin','sort_hide_7','0',0,''),(604096,190092,'76025','origin','sort_hide_2','1',0,''),(604097,190092,'76025','origin','sort_hide_1','1',0,''),(604098,190092,'76025','origin','sort_hide_6','1',0,''),(604099,190092,'76025','origin','sort_hide_5','1',0,''),(604100,190092,'76025','origin','sort_hide_0','1',0,''),(604101,190095,'1683124632.767746','origin','block_type','1',0,''),(604102,190095,'1683124632.767746','origin','font-weight','normal',0,''),(604103,190095,'1683124632.767746','origin','padding-top','20',0,''),(604104,190095,'1683124632.767746','origin','background-color','$content-bg-2',0,''),(604105,190095,'1683124632.767746','origin','style_class','shopping-cart-index',0,''),(604106,190095,'1683124632.767746','origin','color','$content-color-2',0,''),(604107,190096,'1683124632.80670','origin','block_type','4',0,''),(604108,190096,'1683124632.80670','origin','schema','4-1',0,'8361'),(604109,190096,'1683124632.80670','origin','schema','4-2',0,'8356'),(604110,190097,'1683124632.809680','origin','block_type','1',0,''),(604111,190097,'1683124632.809680','origin','background-color','$content-bg-1',0,''),(604112,190097,'1683124632.809680','origin','padding-top','20',0,''),(604113,190097,'1683124632.809680','origin','padding-bottom','20',0,''),(604114,190097,'1683124632.809680','origin','padding-left','25',0,''),(604115,190097,'1683124632.809680','origin','padding-right','25',0,''),(604116,190097,'1683124632.809680','origin','margin-bottom','30',0,''),(604117,190097,'1683124632.809680','origin','color','$content-color-1',0,''),(604118,190098,'1683124632.816335','origin','block_type','1',0,''),(604119,190098,'1683124632.816335','origin','background-color','$content-bg-1',0,''),(604120,190098,'1683124632.816335','origin','margin-bottom','30',0,''),(604121,190098,'1683124632.816335','origin','color','$content-color-1',0,''),(604122,190099,'1683124632.817623','origin','padding-top','20',0,''),(604123,190099,'1683124632.817623','origin','padding-left','25',0,''),(604124,190099,'1683124632.817623','origin','padding-right','25',0,''),(604125,190099,'1683124632.817623','origin','padding-bottom','20',0,''),(604126,190100,'1683124632.818551','origin','block_type','2',0,''),(604127,190100,'1683124632.818551','origin','padding-bottom','20',0,''),(604128,190100,'1683124632.818551','origin','padding-top','20',0,''),(604129,190100,'1683124632.818551','origin','padding-left','25',0,''),(604130,190100,'1683124632.818551','origin','padding-right','25',0,''),(604131,190100,'1683124632.818551','origin','border-bottom-color','#e0e0e0',0,''),(604132,190100,'1683124632.818551','origin','border-bottom-width','1',0,''),(604133,190100,'1683124632.818551','origin','schema','2-2',0,'8356'),(604134,190101,'1683124632.820317','origin','float','left',0,''),(604135,190102,'1683124632.820914','origin','text-align','right',0,''),(604136,190102,'1683124632.820914','origin','clear','none',0,''),(604137,190102,'1683124632.820914','origin','float','right',0,''),(604138,190102,'1683124632.820914','origin','padding-top','22',0,''),(604139,190103,'1683124632.822588','origin','float','right',0,''),(604140,190103,'1683124632.822588','origin','padding-top','26',0,''),(604141,190104,'1683124632.823175','origin','block_type','3',0,''),(604142,190104,'1683124632.823175','origin','font-weight','400',0,''),(604143,190104,'1683124632.823175','origin','schema','2-2',0,'8349'),(604144,190104,'1683124632.823175','origin','style_class','closeable-content',0,''),(604145,190104,'1683124632.823175','origin','padding-top','10',0,''),(604146,190104,'1683124632.823175','origin','padding-left','25',0,''),(604147,190104,'1683124632.823175','origin','padding-right','25',0,''),(604148,190104,'1683124632.823175','origin','padding-bottom','20',0,''),(604149,190107,'1683124632.82683','origin','block_type','1',0,''),(604150,190107,'1683124632.82683','origin','padding-top','20',0,''),(604151,190107,'1683124632.82683','origin','padding-bottom','20',0,''),(604152,190107,'1683124632.82683','origin','padding-left','25',0,''),(604153,190107,'1683124632.82683','origin','padding-right','25',0,''),(604154,190107,'1683124632.82683','origin','background-color','$content-bg-1',0,''),(604155,190107,'1683124632.82683','origin','margin-bottom','30',0,''),(604156,190107,'1683124632.82683','origin','color','$content-color-1',0,''),(604157,190108,'1683124632.827413','origin','hide_parents','2',0,''),(604158,190109,'1683124632.828374','origin','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(604159,190110,'1683124632.829840','origin','block_type','1',0,''),(604160,190110,'1683124632.829840','origin','background-color','$content-bg-1',0,''),(604161,190110,'1683124632.829840','origin','padding-top','20',0,''),(604162,190110,'1683124632.829840','origin','padding-left','25',0,''),(604163,190110,'1683124632.829840','origin','padding-right','25',0,''),(604164,190110,'1683124632.829840','origin','padding-bottom','20',0,''),(604165,190110,'1683124632.829840','origin','margin-bottom','30',0,''),(604166,190110,'1683124632.829840','origin','style_class','closeable-box',0,''),(604167,190110,'1683124632.829840','origin','display','none',0,'8356'),(604168,190111,'1683124632.831459','origin','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(604169,190111,'1683124632.831459','origin','style_class','shipping-ico closeable-heading closeable-event',0,''),(604170,190112,'1683124632.832592','origin','font-weight','normal',0,''),(604171,190112,'1683124632.832592','origin','style_class','closeable-content',0,''),(604172,190112,'1683124632.832592','origin','padding-top','10',0,''),(604173,190112,'1683124632.832592','origin','hide_parents','2',0,''),(604174,190113,'1683124632.833353','origin','style_class','order-summary',0,''),(604175,190113,'1683124632.833353','origin','block_type','1',0,''),(604176,190113,'1683124632.833353','origin','margin-left','30',0,''),(604177,190113,'1683124632.833353','origin','margin-left','0',0,'8356'),(604178,190113,'1683124632.833353','origin','margin-bottom','30',0,'8356'),(604179,190114,'1683124632.834715','origin','block_type','1',0,''),(604180,190114,'1683124632.834715','origin','padding-left','20',0,''),(604181,190114,'1683124632.834715','origin','padding-right','20',0,''),(604182,190114,'1683124632.834715','origin','padding-bottom','20',0,''),(604183,190115,'1683124632.835884','origin','font-weight','400',0,''),(604184,190115,'1683124632.835884','origin','padding-top','12',0,'8349'),(604185,190115,'1683124632.835884','origin','padding-left','0',0,'8349'),(604186,190116,'1683124632.836532','origin','font-weight','400',0,''),(604187,190116,'1683124632.836532','origin','logo','themes/origin/img/themes/basic/img/payment.png',1,''),(604188,190116,'1683124632.836532','origin','padding-top','20',0,''),(604189,190116,'1683124632.836532','origin','padding-bottom','10',0,''),(604190,190116,'1683124632.836532','origin','logo','themes/origin/img/themes/basic/img/payment.png',0,''),(604191,190117,'1683124632.844829','origin','font-weight','400',0,''),(604192,190117,'1683124632.844829','origin','box_align','4',0,''),(604193,190117,'1683124632.844829','origin','text-align','center',0,'8349'),(604194,190117,'1683124632.844829','origin','float','none',0,'8349'),(604195,190117,'1683124632.844829','origin','width','100',0,'8349'),(604196,190117,'1683124632.844829','origin','width_measure','%',0,'8349'),(604197,190118,'1683124632.84681','origin','style_class','bottom-totals',0,''),(604198,190119,'1683124632.846538','origin','style_class','top-totals',0,''),(604199,190120,'1683124632.84726','origin','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(604200,190121,'94658','origin','block_type','1',0,''),(604201,190121,'94658','origin','font-weight','normal',0,''),(604202,190121,'94658','origin','padding-top','20',0,''),(604203,190121,'94658','origin','background-color','$content-bg-2',0,''),(604204,190123,'94660','origin','block_type','4',0,''),(604205,190123,'94660','origin','schema','4-1',0,'8361'),(604206,190123,'94660','origin','schema','4-2',0,'8356'),(604207,190124,'94661','origin','block_type','1',0,''),(604208,190124,'94661','origin','background-color','$content-bg-1',0,''),(604209,190124,'94661','origin','padding-top','20',0,''),(604210,190124,'94661','origin','padding-bottom','20',0,''),(604211,190124,'94661','origin','padding-left','25',0,''),(604212,190124,'94661','origin','padding-right','25',0,''),(604213,190124,'94661','origin','margin-bottom','30',0,''),(604214,190125,'94662','origin','col_in_row','3',0,''),(604215,190125,'94662','origin','show_description','1',0,''),(604216,190125,'94662','origin','show_model','1',0,''),(604217,190125,'94662','origin','show_properties','1',0,''),(604218,190125,'94662','origin','show_rating','1',0,''),(604219,190125,'94662','origin','show_rating_counts','1',0,''),(604220,190125,'94662','origin','show_qty_input','1',0,''),(604221,190125,'94662','origin','show_view_button','1',0,''),(604222,190125,'94662','origin','show_wishlist_button','1',0,''),(604223,190125,'94662','origin','show_compare','1',0,''),(604224,190125,'94662','origin','view_as','carousel',0,''),(604225,190125,'94662','origin','hide_parents','2',0,''),(604226,190126,'94663','origin','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(604227,190126,'94663','origin','style_class','bell-ico',0,''),(604228,190127,'94664','origin','block_type','1',0,''),(604229,190127,'94664','origin','background-color','$content-bg-1',0,''),(604230,190127,'94664','origin','margin-bottom','30',0,''),(604231,190128,'94665','origin','padding-top','20',0,''),(604232,190128,'94665','origin','padding-left','25',0,''),(604233,190128,'94665','origin','padding-right','25',0,''),(604234,190128,'94665','origin','padding-bottom','20',0,''),(604235,190129,'94666','origin','block_type','2',0,''),(604236,190129,'94666','origin','padding-bottom','20',0,''),(604237,190129,'94666','origin','padding-top','20',0,''),(604238,190129,'94666','origin','padding-left','25',0,''),(604239,190129,'94666','origin','padding-right','25',0,''),(604240,190129,'94666','origin','border-bottom-color','$content-border-1',0,''),(604241,190129,'94666','origin','border-bottom-width','1',0,''),(604242,190129,'94666','origin','schema','2-2',0,'8356'),(604243,190130,'94667','origin','float','left',0,''),(604244,190131,'94668','origin','text-align','right',0,''),(604245,190131,'94668','origin','clear','none',0,''),(604246,190131,'94668','origin','float','right',0,''),(604247,190131,'94668','origin','padding-top','22',0,''),(604248,190132,'94669','origin','float','right',0,''),(604249,190132,'94669','origin','padding-top','26',0,''),(604250,190133,'94670','origin','block_type','1',0,''),(604251,190133,'94670','origin','padding-top','20',0,''),(604252,190133,'94670','origin','padding-bottom','20',0,''),(604253,190133,'94670','origin','padding-left','25',0,''),(604254,190133,'94670','origin','padding-right','25',0,''),(604255,190133,'94670','origin','background-color','$content-bg-1',0,''),(604256,190133,'94670','origin','margin-bottom','30',0,''),(604257,190134,'94671','origin','hide_parents','2',0,''),(604258,190135,'94672','origin','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(604259,190136,'94673','origin','block_type','1',0,''),(604260,190136,'94673','origin','background-color','$content-bg-1',0,''),(604261,190136,'94673','origin','padding-top','20',0,''),(604262,190136,'94673','origin','padding-bottom','20',0,''),(604263,190136,'94673','origin','padding-left','25',0,''),(604264,190136,'94673','origin','padding-right','25',0,''),(604265,190136,'94673','origin','margin-bottom','30',0,''),(604266,190136,'94673','origin','style_class','closeable-box',0,''),(604267,190137,'94674','origin','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(604268,190137,'94674','origin','style_class','savings-ico closeable-heading closeable-event',0,''),(604269,190138,'94675','origin','block_type','3',0,''),(604270,190138,'94675','origin','font-weight','400',0,''),(604271,190138,'94675','origin','schema','2-2',0,'8349'),(604272,190138,'94675','origin','style_class','closeable-content',0,''),(604273,190138,'94675','origin','padding-top','10',0,''),(604274,190139,'94676','origin','font-weight','400',0,''),(604275,190139,'94676','origin','padding-top','12',0,'8349'),(604276,190139,'94676','origin','padding-left','0',0,'8349'),(604277,190142,'94679','origin','block_type','1',0,''),(604278,190142,'94679','origin','background-color','$content-bg-1',0,''),(604279,190142,'94679','origin','padding-top','20',0,''),(604280,190142,'94679','origin','padding-left','25',0,''),(604281,190142,'94679','origin','padding-right','25',0,''),(604282,190142,'94679','origin','padding-bottom','20',0,''),(604283,190142,'94679','origin','margin-bottom','30',0,''),(604284,190142,'94679','origin','style_class','closeable-box',0,''),(604285,190142,'94679','origin','display','none',0,'8356'),(604286,190143,'94680','origin','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(604287,190143,'94680','origin','style_class','shipping-ico closeable-heading closeable-event',0,''),(604288,190144,'94681','origin','font-weight','normal',0,''),(604289,190144,'94681','origin','style_class','closeable-content',0,''),(604290,190144,'94681','origin','padding-top','10',0,''),(604291,190144,'94681','origin','hide_parents','2',0,''),(604292,190145,'94682','origin','style_class','order-summary',0,''),(604293,190145,'94682','origin','block_type','1',0,''),(604294,190145,'94682','origin','margin-left','30',0,''),(604295,190145,'94682','origin','margin-left','0',0,'8356'),(604296,190145,'94682','origin','margin-bottom','30',0,'8356'),(604297,190146,'94683','origin','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(604298,190147,'94684','origin','block_type','1',0,''),(604299,190147,'94684','origin','padding-left','20',0,''),(604300,190147,'94684','origin','padding-right','20',0,''),(604301,190147,'94684','origin','padding-bottom','20',0,''),(604302,190148,'94685','origin','font-weight','400',0,''),(604303,190148,'94685','origin','logo','themes/origin/img/themes/basic/img/payment.png',1,''),(604304,190148,'94685','origin','padding-top','20',0,''),(604305,190148,'94685','origin','padding-bottom','10',0,''),(604306,190148,'94685','origin','logo','themes/origin/img/themes/basic/img/payment.png',0,''),(604307,190149,'94686','origin','font-weight','400',0,''),(604308,190149,'94686','origin','box_align','4',0,''),(604309,190149,'94686','origin','text-align','center',0,'8349'),(604310,190149,'94686','origin','float','none',0,'8349'),(604311,190149,'94686','origin','width','100',0,'8349'),(604312,190149,'94686','origin','width_measure','%',0,'8349'),(604313,190151,'73462','origin','block_type','1',0,''),(604314,190152,'73463','origin','block_type','6',0,''),(604315,190152,'73463','origin','font-weight','400',0,''),(604316,190152,'73463','origin','schema','6-2',0,'8377'),(604317,190152,'73463','origin','schema','6-2',0,'8356'),(604318,190153,'73464','origin','font-weight','400',0,''),(604319,190153,'73464','origin','padding-right','40',0,''),(604320,190153,'73464','origin','padding-right','0',0,'8377'),(604321,190153,'73464','origin','padding-right','0',0,'8356'),(604322,190154,'73465','origin','col_in_row','3',0,''),(604323,190154,'73465','origin','products_align','left',0,''),(604324,190154,'73465','origin','font-weight','400',0,''),(604325,190154,'73465','origin','show_qty_input','0',0,''),(604326,190154,'73465','origin','listing_type','productListing',0,''),(604327,190154,'73465','origin','listing_type_rows','Rows',0,''),(604328,190154,'73465','origin','show_buy_button_b2b','on',0,''),(604329,190154,'73465','origin','show_wishlist_button_b2b','1',0,''),(604330,190154,'73465','origin','show_compare_b2b','1',0,''),(604331,190154,'73465','origin','show_stock','0',0,''),(604332,190154,'73465','origin','show_description','0',0,''),(604333,190154,'73465','origin','show_model','0',0,''),(604334,190154,'73465','origin','show_properties','0',0,''),(604335,190154,'73465','origin','show_rating','0',0,''),(604336,190154,'73465','origin','show_rating_counts','0',0,''),(604337,190154,'73465','origin','show_price','0',0,''),(604338,190154,'73465','origin','show_buy_button','0',0,''),(604339,190154,'73465','origin','show_view_button','0',0,''),(604340,190154,'73465','origin','show_wishlist_button','0',0,''),(604341,190154,'73465','origin','show_compare','0',0,''),(604342,190154,'73465','origin','show_name_rows','0',0,''),(604343,190154,'73465','origin','show_image_rows','0',0,''),(604344,190154,'73465','origin','show_stock_rows','0',0,''),(604345,190154,'73465','origin','show_description_rows','0',0,''),(604346,190154,'73465','origin','show_model_rows','0',0,''),(604347,190154,'73465','origin','show_properties_rows','0',0,''),(604348,190154,'73465','origin','show_rating_rows','0',0,''),(604349,190154,'73465','origin','show_rating_counts_rows','0',0,''),(604350,190154,'73465','origin','show_price_rows','0',0,''),(604351,190154,'73465','origin','show_buy_button_rows','0',0,''),(604352,190154,'73465','origin','show_qty_input_rows','0',0,''),(604353,190154,'73465','origin','show_view_button_rows','0',0,''),(604354,190154,'73465','origin','show_wishlist_button_rows','0',0,''),(604355,190154,'73465','origin','show_compare_rows','0',0,''),(604356,190154,'73465','origin','show_name_b2b','0',0,''),(604357,190154,'73465','origin','show_image_b2b','0',0,''),(604358,190154,'73465','origin','show_stock_b2b','0',0,''),(604359,190154,'73465','origin','show_description_b2b','0',0,''),(604360,190154,'73465','origin','show_model_b2b','0',0,''),(604361,190154,'73465','origin','show_properties_b2b','0',0,''),(604362,190154,'73465','origin','show_rating_b2b','0',0,''),(604363,190154,'73465','origin','show_rating_counts_b2b','0',0,''),(604364,190154,'73465','origin','show_price_b2b','0',0,''),(604365,190154,'73465','origin','show_qty_input_b2b','0',0,''),(604366,190154,'73465','origin','show_view_button_b2b','0',0,''),(604367,190154,'73465','origin','show_attributes_b2b','0',0,''),(604368,190154,'73465','origin','items_on_page','9',0,''),(604369,190154,'73465','origin','col_in_row','2',0,'8356'),(604370,190154,'73465','origin','col_in_row','1',0,'8377'),(604371,190154,'73465','origin','product_names_teg','h2',0,''),(604372,190156,'73467','origin','block_type','5',0,''),(604373,190156,'73467','origin','padding-top','10',0,''),(604374,190156,'73467','origin','padding-bottom','10',0,''),(604375,190156,'73467','origin','schema','5-2',0,'8377'),(604376,190156,'73467','origin','border-top-color','$content-border-1',0,''),(604377,190156,'73467','origin','border-top-width','1',0,''),(604378,190158,'73469','origin','float','right',0,''),(604379,190159,'73470','origin','listing_type','productListing',0,''),(604380,190161,'73472','origin','block_type','1',0,''),(604381,190161,'73472','origin','padding-top','10',0,''),(604382,190161,'73472','origin','padding-bottom','10',0,''),(604383,190161,'73472','origin','border-bottom-width','1',0,''),(604384,190161,'73472','origin','border-bottom-color','$content-border-1',0,''),(604385,190161,'73472','origin','margin-left','0',0,''),(604386,190161,'73472','origin','margin-right','0',0,''),(604387,190162,'73473','origin','float','right',0,''),(604388,190162,'73473','origin','display','none',0,'8377'),(604389,190163,'73474','origin','margin-right','20',0,''),(604390,190163,'73474','origin','float','right',0,''),(604391,190163,'73474','origin','clear','none',0,''),(604392,190163,'73474','origin','display','none',0,'8356'),(604393,190164,'73475','origin','float','left',0,''),(604394,190164,'73475','origin','clear','none',0,''),(604395,190164,'73475','origin','margin-left','20',0,''),(604396,190164,'73475','origin','display','none',0,'8377'),(604397,190165,'73476','origin','float','left',0,''),(604398,190165,'73476','origin','clear','none',0,''),(604399,190165,'73476','origin','sort_pos_3','2',0,''),(604400,190165,'73476','origin','sort_pos_4','3',0,''),(604401,190165,'73476','origin','sort_pos_10','11',0,''),(604402,190165,'73476','origin','sort_pos_9','10',0,''),(604403,190165,'73476','origin','sort_pos_11','12',0,''),(604404,190165,'73476','origin','sort_pos_12','13',0,''),(604405,190165,'73476','origin','sort_pos_14','15',0,''),(604406,190165,'73476','origin','sort_pos_13','14',0,''),(604407,190165,'73476','origin','sort_pos_8','4',0,''),(604408,190165,'73476','origin','sort_pos_7','5',0,''),(604409,190165,'73476','origin','sort_pos_2','7',0,''),(604410,190165,'73476','origin','sort_pos_1','6',0,''),(604411,190165,'73476','origin','sort_pos_6','9',0,''),(604412,190165,'73476','origin','sort_pos_5','8',0,''),(604413,190165,'73476','origin','sort_pos_0','1',0,''),(604414,190165,'73476','origin','sort_hide_10','1',0,''),(604415,190165,'73476','origin','sort_hide_9','1',0,''),(604416,190165,'73476','origin','hide_icons','1',0,''),(604417,190165,'73476','origin','sort_hide_16','1',0,''),(604418,190165,'73476','origin','sort_hide_15','1',0,''),(604419,190165,'73476','origin','sort_hide_3','0',0,''),(604420,190165,'73476','origin','sort_hide_4','0',0,''),(604421,190165,'73476','origin','sort_hide_11','1',0,''),(604422,190165,'73476','origin','sort_hide_12','1',0,''),(604423,190165,'73476','origin','sort_hide_14','1',0,''),(604424,190165,'73476','origin','sort_hide_13','1',0,''),(604425,190165,'73476','origin','sort_hide_8','0',0,''),(604426,190165,'73476','origin','sort_hide_7','0',0,''),(604427,190165,'73476','origin','sort_hide_2','1',0,''),(604428,190165,'73476','origin','sort_hide_1','1',0,''),(604429,190165,'73476','origin','sort_hide_6','1',0,''),(604430,190165,'73476','origin','sort_hide_5','1',0,''),(604431,190165,'73476','origin','sort_hide_0','0',0,''),(604432,190165,'73476','origin','sort_pos_15','16',0,''),(604433,190165,'73476','origin','sort_pos_16','17',0,''),(604434,190172,'94688','origin','block_type','1',0,''),(604435,190174,'94690','origin','block_type','6',0,''),(604436,190174,'94690','origin','font-weight','400',0,''),(604437,190174,'94690','origin','schema','6-2',0,'8377'),(604438,190174,'94690','origin','schema','6-2',0,'8356'),(604439,190175,'94691','origin','font-weight','400',0,''),(604440,190175,'94691','origin','padding-right','40',0,''),(604441,190175,'94691','origin','padding-right','0',0,'8377'),(604442,190175,'94691','origin','padding-right','0',0,'8356'),(604443,190177,'94693','origin','col_in_row','3',0,''),(604444,190177,'94693','origin','products_align','left',0,''),(604445,190177,'94693','origin','font-weight','400',0,''),(604446,190177,'94693','origin','show_qty_input','0',0,''),(604447,190177,'94693','origin','listing_type','productListing',0,''),(604448,190177,'94693','origin','listing_type_rows','no',0,''),(604449,190177,'94693','origin','show_buy_button_b2b','on',0,''),(604450,190177,'94693','origin','show_wishlist_button_b2b','1',0,''),(604451,190177,'94693','origin','show_compare_b2b','1',0,''),(604452,190177,'94693','origin','show_stock','0',0,''),(604453,190177,'94693','origin','show_description','0',0,''),(604454,190177,'94693','origin','show_model','0',0,''),(604455,190177,'94693','origin','show_properties','0',0,''),(604456,190177,'94693','origin','show_rating','0',0,''),(604457,190177,'94693','origin','show_rating_counts','0',0,''),(604458,190177,'94693','origin','show_price','0',0,''),(604459,190177,'94693','origin','show_buy_button','0',0,''),(604460,190177,'94693','origin','show_view_button','0',0,''),(604461,190177,'94693','origin','show_wishlist_button','0',0,''),(604462,190177,'94693','origin','show_compare','0',0,''),(604463,190177,'94693','origin','show_name_rows','0',0,''),(604464,190177,'94693','origin','show_image_rows','0',0,''),(604465,190177,'94693','origin','show_stock_rows','0',0,''),(604466,190177,'94693','origin','show_description_rows','0',0,''),(604467,190177,'94693','origin','show_model_rows','0',0,''),(604468,190177,'94693','origin','show_properties_rows','0',0,''),(604469,190177,'94693','origin','show_rating_rows','0',0,''),(604470,190177,'94693','origin','show_rating_counts_rows','0',0,''),(604471,190177,'94693','origin','show_price_rows','0',0,''),(604472,190177,'94693','origin','show_buy_button_rows','0',0,''),(604473,190177,'94693','origin','show_qty_input_rows','0',0,''),(604474,190177,'94693','origin','show_view_button_rows','0',0,''),(604475,190177,'94693','origin','show_wishlist_button_rows','0',0,''),(604476,190177,'94693','origin','show_compare_rows','0',0,''),(604477,190177,'94693','origin','show_name_b2b','0',0,''),(604478,190177,'94693','origin','show_image_b2b','0',0,''),(604479,190177,'94693','origin','show_stock_b2b','0',0,''),(604480,190177,'94693','origin','show_description_b2b','0',0,''),(604481,190177,'94693','origin','show_model_b2b','0',0,''),(604482,190177,'94693','origin','show_properties_b2b','0',0,''),(604483,190177,'94693','origin','show_rating_b2b','0',0,''),(604484,190177,'94693','origin','show_rating_counts_b2b','0',0,''),(604485,190177,'94693','origin','show_price_b2b','0',0,''),(604486,190177,'94693','origin','show_qty_input_b2b','0',0,''),(604487,190177,'94693','origin','show_view_button_b2b','0',0,''),(604488,190177,'94693','origin','show_attributes_b2b','0',0,''),(604489,190177,'94693','origin','items_on_page','9',0,''),(604490,190177,'94693','origin','col_in_row','2',0,'8356'),(604491,190177,'94693','origin','col_in_row','1',0,'8377'),(604492,190177,'94693','origin','product_names_teg','h2',0,''),(604493,190178,'94694','origin','block_type','1',0,''),(604494,190178,'94694','origin','padding-top','10',0,''),(604495,190178,'94694','origin','padding-bottom','10',0,''),(604496,190178,'94694','origin','border-bottom-width','1',0,''),(604497,190178,'94694','origin','border-bottom-color','$content-border-1',0,''),(604498,190178,'94694','origin','margin-left','0',0,''),(604499,190178,'94694','origin','margin-right','0',0,''),(604500,190179,'94695','origin','float','left',0,''),(604501,190179,'94695','origin','clear','none',0,''),(604502,190179,'94695','origin','sort_pos_3','1',0,''),(604503,190179,'94695','origin','sort_pos_4','2',0,''),(604504,190179,'94695','origin','sort_pos_10','3',0,''),(604505,190179,'94695','origin','sort_pos_9','4',0,''),(604506,190179,'94695','origin','sort_pos_11','5',0,''),(604507,190179,'94695','origin','sort_pos_12','6',0,''),(604508,190179,'94695','origin','sort_pos_14','7',0,''),(604509,190179,'94695','origin','sort_pos_13','8',0,''),(604510,190179,'94695','origin','sort_pos_8','9',0,''),(604511,190179,'94695','origin','sort_pos_7','10',0,''),(604512,190179,'94695','origin','sort_pos_2','11',0,''),(604513,190179,'94695','origin','sort_pos_1','12',0,''),(604514,190179,'94695','origin','sort_pos_6','13',0,''),(604515,190179,'94695','origin','sort_pos_5','14',0,''),(604516,190179,'94695','origin','sort_pos_0','15',0,''),(604517,190179,'94695','origin','sort_hide_10','1',0,''),(604518,190179,'94695','origin','sort_hide_9','1',0,''),(604519,190179,'94695','origin','hide_icons','1',0,''),(604520,190179,'94695','origin','sort_hide_16','1',0,''),(604521,190179,'94695','origin','sort_hide_15','1',0,''),(604522,190179,'94695','origin','sort_hide_3','0',0,''),(604523,190179,'94695','origin','sort_hide_4','0',0,''),(604524,190179,'94695','origin','sort_hide_11','1',0,''),(604525,190179,'94695','origin','sort_hide_12','1',0,''),(604526,190179,'94695','origin','sort_hide_14','1',0,''),(604527,190179,'94695','origin','sort_hide_13','1',0,''),(604528,190179,'94695','origin','sort_hide_8','0',0,''),(604529,190179,'94695','origin','sort_hide_7','0',0,''),(604530,190179,'94695','origin','sort_hide_2','1',0,''),(604531,190179,'94695','origin','sort_hide_1','1',0,''),(604532,190179,'94695','origin','sort_hide_6','1',0,''),(604533,190179,'94695','origin','sort_hide_5','1',0,''),(604534,190179,'94695','origin','sort_hide_0','1',0,''),(604535,190180,'94696','origin','float','left',0,''),(604536,190180,'94696','origin','clear','none',0,''),(604537,190180,'94696','origin','margin-left','20',0,''),(604538,190180,'94696','origin','display','none',0,'8377'),(604539,190181,'94697','origin','margin-right','20',0,''),(604540,190181,'94697','origin','float','right',0,''),(604541,190181,'94697','origin','clear','none',0,''),(604542,190181,'94697','origin','display','none',0,'8356'),(604543,190182,'94698','origin','float','right',0,''),(604544,190182,'94698','origin','display','none',0,'8377'),(604545,190183,'94699','origin','listing_type','productListing',0,''),(604546,190185,'94701','origin','block_type','5',0,''),(604547,190185,'94701','origin','padding-top','10',0,''),(604548,190185,'94701','origin','padding-bottom','10',0,''),(604549,190185,'94701','origin','schema','5-2',0,'8377'),(604550,190185,'94701','origin','border-top-color','$content-border-1',0,''),(604551,190185,'94701','origin','border-top-width','1',0,''),(604552,190187,'94703','origin','float','right',0,''),(604553,190188,'73483','origin','block_type','1',0,''),(604554,190191,'73486','origin','block_type','1',0,''),(604555,190191,'73486','origin','padding-top','10',0,''),(604556,190191,'73486','origin','padding-bottom','10',0,''),(604557,190191,'73486','origin','border-bottom-width','1',0,''),(604558,190191,'73486','origin','border-bottom-color','$content-border-1',0,''),(604559,190191,'73486','origin','margin-left','0',0,''),(604560,190191,'73486','origin','margin-right','0',0,''),(604561,190192,'73487','origin','float','left',0,''),(604562,190192,'73487','origin','clear','none',0,''),(604563,190192,'73487','origin','margin-left','20',0,''),(604564,190192,'73487','origin','display','none',0,'8377'),(604565,190193,'73488','origin','float','left',0,''),(604566,190193,'73488','origin','clear','none',0,''),(604567,190193,'73488','origin','sort_pos_3','2',0,''),(604568,190193,'73488','origin','sort_pos_4','3',0,''),(604569,190193,'73488','origin','sort_pos_10','11',0,''),(604570,190193,'73488','origin','sort_pos_9','10',0,''),(604571,190193,'73488','origin','sort_pos_11','12',0,''),(604572,190193,'73488','origin','sort_pos_12','13',0,''),(604573,190193,'73488','origin','sort_pos_14','15',0,''),(604574,190193,'73488','origin','sort_pos_13','14',0,''),(604575,190193,'73488','origin','sort_pos_8','4',0,''),(604576,190193,'73488','origin','sort_pos_7','5',0,''),(604577,190193,'73488','origin','sort_pos_2','7',0,''),(604578,190193,'73488','origin','sort_pos_1','6',0,''),(604579,190193,'73488','origin','sort_pos_6','9',0,''),(604580,190193,'73488','origin','sort_pos_5','8',0,''),(604581,190193,'73488','origin','sort_pos_0','1',0,''),(604582,190193,'73488','origin','sort_hide_10','1',0,''),(604583,190193,'73488','origin','sort_hide_9','1',0,''),(604584,190193,'73488','origin','hide_icons','1',0,''),(604585,190193,'73488','origin','sort_hide_16','1',0,''),(604586,190193,'73488','origin','sort_hide_15','1',0,''),(604587,190193,'73488','origin','sort_hide_3','0',0,''),(604588,190193,'73488','origin','sort_hide_4','0',0,''),(604589,190193,'73488','origin','sort_hide_11','1',0,''),(604590,190193,'73488','origin','sort_hide_12','1',0,''),(604591,190193,'73488','origin','sort_hide_14','1',0,''),(604592,190193,'73488','origin','sort_hide_13','1',0,''),(604593,190193,'73488','origin','sort_hide_8','0',0,''),(604594,190193,'73488','origin','sort_hide_7','0',0,''),(604595,190193,'73488','origin','sort_hide_2','1',0,''),(604596,190193,'73488','origin','sort_hide_1','1',0,''),(604597,190193,'73488','origin','sort_hide_6','1',0,''),(604598,190193,'73488','origin','sort_hide_5','1',0,''),(604599,190193,'73488','origin','sort_hide_0','0',0,''),(604600,190193,'73488','origin','sort_pos_15','16',0,''),(604601,190193,'73488','origin','sort_pos_16','17',0,''),(604602,190194,'73489','origin','margin-right','20',0,''),(604603,190194,'73489','origin','float','right',0,''),(604604,190194,'73489','origin','clear','none',0,''),(604605,190194,'73489','origin','display','none',0,'8356'),(604606,190195,'73490','origin','float','right',0,''),(604607,190195,'73490','origin','display','none',0,'8377'),(604608,190196,'73491','origin','clear','none',0,''),(604609,190196,'73491','origin','float','left',0,''),(604610,190196,'73491','origin','padding-top','3',0,''),(604611,190196,'73491','origin','padding-left','20',0,''),(604612,190197,'73492','origin','block_type','5',0,''),(604613,190197,'73492','origin','padding-top','10',0,''),(604614,190197,'73492','origin','padding-bottom','10',0,''),(604615,190197,'73492','origin','schema','5-2',0,'8377'),(604616,190197,'73492','origin','border-top-color','$content-border-1',0,''),(604617,190197,'73492','origin','border-top-width','1',0,''),(604618,190199,'73494','origin','float','right',0,''),(604619,190200,'73495','origin','col_in_row','4',0,''),(604620,190200,'73495','origin','products_align','left',0,''),(604621,190200,'73495','origin','font-weight','400',0,''),(604622,190200,'73495','origin','show_qty_input','0',0,''),(604623,190200,'73495','origin','listing_type','productListing',0,''),(604624,190200,'73495','origin','listing_type_rows','Rows',0,''),(604625,190200,'73495','origin','show_buy_button_b2b','on',0,''),(604626,190200,'73495','origin','show_wishlist_button_b2b','1',0,''),(604627,190200,'73495','origin','show_compare_b2b','1',0,''),(604628,190200,'73495','origin','show_image','0',0,''),(604629,190200,'73495','origin','show_stock','0',0,''),(604630,190200,'73495','origin','show_description','0',0,''),(604631,190200,'73495','origin','show_model','0',0,''),(604632,190200,'73495','origin','show_properties','0',0,''),(604633,190200,'73495','origin','show_rating','0',0,''),(604634,190200,'73495','origin','show_rating_counts','0',0,''),(604635,190200,'73495','origin','show_price','0',0,''),(604636,190200,'73495','origin','show_buy_button','0',0,''),(604637,190200,'73495','origin','show_view_button','0',0,''),(604638,190200,'73495','origin','show_wishlist_button','0',0,''),(604639,190200,'73495','origin','show_compare','0',0,''),(604640,190200,'73495','origin','show_name_rows','0',0,''),(604641,190200,'73495','origin','show_image_rows','0',0,''),(604642,190200,'73495','origin','show_stock_rows','0',0,''),(604643,190200,'73495','origin','show_description_rows','0',0,''),(604644,190200,'73495','origin','show_model_rows','0',0,''),(604645,190200,'73495','origin','show_properties_rows','0',0,''),(604646,190200,'73495','origin','show_rating_rows','0',0,''),(604647,190200,'73495','origin','show_rating_counts_rows','0',0,''),(604648,190200,'73495','origin','show_price_rows','0',0,''),(604649,190200,'73495','origin','show_buy_button_rows','0',0,''),(604650,190200,'73495','origin','show_qty_input_rows','0',0,''),(604651,190200,'73495','origin','show_view_button_rows','0',0,''),(604652,190200,'73495','origin','show_wishlist_button_rows','0',0,''),(604653,190200,'73495','origin','show_compare_rows','0',0,''),(604654,190200,'73495','origin','show_name_b2b','0',0,''),(604655,190200,'73495','origin','show_image_b2b','0',0,''),(604656,190200,'73495','origin','show_stock_b2b','0',0,''),(604657,190200,'73495','origin','show_description_b2b','0',0,''),(604658,190200,'73495','origin','show_model_b2b','0',0,''),(604659,190200,'73495','origin','show_properties_b2b','0',0,''),(604660,190200,'73495','origin','show_rating_b2b','0',0,''),(604661,190200,'73495','origin','show_rating_counts_b2b','0',0,''),(604662,190200,'73495','origin','show_price_b2b','0',0,''),(604663,190200,'73495','origin','show_qty_input_b2b','0',0,''),(604664,190200,'73495','origin','show_view_button_b2b','0',0,''),(604665,190200,'73495','origin','show_attributes_b2b','0',0,''),(604666,190200,'73495','origin','items_on_page','12',0,''),(604667,190200,'73495','origin','col_in_row','2',0,'8356'),(604668,190200,'73495','origin','col_in_row','1',0,'8377'),(604669,190200,'73495','origin','product_names_teg','h2',0,''),(604670,190203,'1683125852.345798','origin','block_type','1',0,''),(604671,190203,'1683125852.345798','origin','background-color','$content-bg-2',0,''),(604672,190203,'1683125852.345798','origin','padding-top','30',0,''),(604673,190203,'1683125852.345798','origin','padding-bottom','30',0,''),(604674,190203,'1683125852.345798','origin','style_class','checkout-index-wrap',0,''),(604675,190203,'1683125852.345798','origin','color','$content-color-2',0,''),(604676,190204,'1683125852.356555','origin','block_type','4',0,''),(604677,190204,'1683125852.356555','origin','schema','4-2',0,'8356'),(604678,190204,'1683125852.356555','origin','style_class','checkoutDoubleBox',0,''),(604679,190205,'1683125852.358412','origin','block_type','1',0,''),(604680,190205,'1683125852.358412','origin','padding-right','40',0,''),(604681,190205,'1683125852.358412','origin','padding-right','0',0,'8356'),(604682,190206,'1683125852.35982','origin','block_type','1',0,''),(604683,190206,'1683125852.35982','origin','background-color','$content-bg-1',0,''),(604684,190206,'1683125852.35982','origin','padding-top','30',0,''),(604685,190206,'1683125852.35982','origin','padding-left','30',0,''),(604686,190206,'1683125852.35982','origin','padding-right','30',0,''),(604687,190206,'1683125852.35982','origin','padding-bottom','30',0,''),(604688,190206,'1683125852.35982','origin','margin-bottom','20',0,''),(604689,190206,'1683125852.35982','origin','style_class','hiding-box closeable-box',0,''),(604690,190206,'1683125852.35982','origin','color','$content-color-1',0,''),(604691,190207,'1683125852.361569','origin','style_class','closeable-content',0,''),(604692,190207,'1683125852.361569','origin','padding-bottom','20',0,''),(604693,190208,'1683125852.362847','origin','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(604694,190208,'1683125852.362847','origin','style_class','closeable-heading closeable-event closed',0,''),(604695,190209,'1683125852.36485','origin','block_type','1',0,''),(604696,190209,'1683125852.36485','origin','padding-top','30',0,''),(604697,190209,'1683125852.36485','origin','padding-left','30',0,''),(604698,190209,'1683125852.36485','origin','padding-right','30',0,''),(604699,190209,'1683125852.36485','origin','padding-bottom','30',0,''),(604700,190209,'1683125852.36485','origin','margin-bottom','20',0,''),(604701,190209,'1683125852.36485','origin','background-color','$content-bg-1',0,''),(604702,190209,'1683125852.36485','origin','style_class','hiding-box closeable-box',0,''),(604703,190209,'1683125852.36485','origin','color','$content-color-1',0,''),(604704,190210,'1683125852.366422','origin','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(604705,190210,'1683125852.366422','origin','style_class','closeable-heading closeable-event closed',0,''),(604706,190211,'1683125852.367732','origin','block_type','2',0,''),(604707,190211,'1683125852.367732','origin','style_class','closeable-content',0,''),(604708,190211,'1683125852.367732','origin','schema','2-2',0,'8356'),(604709,190212,'1683125852.36968','origin','padding-right','20',0,''),(604710,190212,'1683125852.36968','origin','padding-bottom','20',0,''),(604711,190212,'1683125852.36968','origin','padding-right','0',0,'8356'),(604712,190213,'1683125852.369745','origin','padding-left','20',0,''),(604713,190213,'1683125852.369745','origin','padding-bottom','20',0,''),(604714,190213,'1683125852.369745','origin','padding-left','0',0,'8356'),(604715,190214,'1683125852.37045','origin','padding-left','20',0,''),(604716,190214,'1683125852.37045','origin','padding-bottom','20',0,''),(604717,190214,'1683125852.37045','origin','padding-left','0',0,'8356'),(604718,190215,'1683125852.371233','origin','background-color','$content-bg-1',0,''),(604719,190215,'1683125852.371233','origin','block_type','1',0,''),(604720,190215,'1683125852.371233','origin','padding-top','30',0,''),(604721,190215,'1683125852.371233','origin','padding-left','30',0,''),(604722,190215,'1683125852.371233','origin','padding-right','30',0,''),(604723,190215,'1683125852.371233','origin','padding-bottom','30',0,''),(604724,190215,'1683125852.371233','origin','margin-bottom','20',0,''),(604725,190215,'1683125852.371233','origin','style_class','hiding-box',0,''),(604726,190215,'1683125852.371233','origin','color','$content-color-1',0,''),(604727,190216,'1683125852.37350','origin','block_type','1',0,''),(604728,190216,'1683125852.37350','origin','content','\\_',0,'3'),(604729,190216,'1683125852.37350','origin','border-top-width','1',0,'3'),(604730,190216,'1683125852.37350','origin','border-top-color','#e0e0e0',0,'3'),(604731,190216,'1683125852.37350','origin','display','block',0,'3'),(604732,190216,'1683125852.37350','origin','position','absolute',0,'3'),(604733,190216,'1683125852.37350','origin','top','19',0,'3'),(604734,190216,'1683125852.37350','origin','left','0',0,'3'),(604735,190216,'1683125852.37350','origin','right','0',0,'3'),(604736,190216,'1683125852.37350','origin','margin-top','-2',0,'3'),(604737,190216,'1683125852.37350','origin','position','relative',0,''),(604738,190217,'1683125852.374899','origin','box_align','2',0,''),(604739,190217,'1683125852.374899','origin','margin-bottom','10',0,''),(604740,190217,'1683125852.374899','origin','background-color','$content-bg-1',0,''),(604741,190217,'1683125852.374899','origin','position','relative',0,''),(604742,190218,'1683125852.375685','origin','background-color','$content-bg-2',0,''),(604743,190218,'1683125852.375685','origin','padding-top','10',0,''),(604744,190218,'1683125852.375685','origin','padding-left','10',0,''),(604745,190218,'1683125852.375685','origin','padding-right','10',0,''),(604746,190218,'1683125852.375685','origin','padding-bottom','10',0,''),(604747,190218,'1683125852.375685','origin','margin-top','10',0,''),(604748,190219,'1683125852.376557','origin','block_type','2',0,''),(604749,190219,'1683125852.376557','origin','schema','2-2',0,'8356'),(604750,190220,'1683125852.377637','origin','block_type','1',0,''),(604751,190220,'1683125852.377637','origin','padding-right','20',0,''),(604752,190220,'1683125852.377637','origin','padding-left','0',0,'8356'),(604753,190220,'1683125852.377637','origin','margin-bottom','20',0,'8356'),(604754,190220,'1683125852.377637','origin','padding-right','0',0,'8356'),(604755,190221,'1683125852.378829','origin','address_in','popup',0,''),(604756,190222,'1683125852.379375','origin','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(604757,190225,'1683125852.381183','origin','block_type','1',0,''),(604758,190225,'1683125852.381183','origin','padding-left','20',0,''),(604759,190225,'1683125852.381183','origin','padding-left','0',0,'8356'),(604760,190227,'1683125852.382635','origin','border-top-width','1',0,''),(604761,190227,'1683125852.382635','origin','border-top-color','#e0e0e0',0,''),(604762,190227,'1683125852.382635','origin','padding-top','13',0,''),(604763,190227,'1683125852.382635','origin','padding-bottom','10',0,''),(604764,190228,'1683125852.383516','origin','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(604765,190229,'1683125852.385278','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(604766,190230,'1683125852.386397','origin','margin-bottom','20',0,''),(604767,190230,'1683125852.386397','origin','style_class','hiding-box',0,''),(604768,190231,'1683125852.386970','origin','padding-top','30',0,''),(604769,190231,'1683125852.386970','origin','padding-left','30',0,''),(604770,190231,'1683125852.386970','origin','padding-right','30',0,''),(604771,190231,'1683125852.386970','origin','margin-top','20',0,''),(604772,190231,'1683125852.386970','origin','background-color','$content-bg-1',0,''),(604773,190231,'1683125852.386970','origin','padding-bottom','30',0,''),(604774,190231,'1683125852.386970','origin','margin-bottom','20',0,''),(604775,190231,'1683125852.386970','origin','color','$content-color-1',0,''),(604776,190232,'1683125852.38820','origin','block_type','1',0,''),(604777,190232,'1683125852.38820','origin','padding-top','30',0,''),(604778,190232,'1683125852.38820','origin','padding-left','30',0,''),(604779,190232,'1683125852.38820','origin','padding-right','30',0,''),(604780,190232,'1683125852.38820','origin','padding-bottom','23',0,''),(604781,190232,'1683125852.38820','origin','margin-bottom','20',0,''),(604782,190232,'1683125852.38820','origin','background-color','$content-bg-1',0,''),(604783,190232,'1683125852.38820','origin','style_class','hiding-box',0,''),(604784,190232,'1683125852.38820','origin','color','$content-color-1',0,''),(604785,190233,'1683125852.390244','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(604786,190234,'1683125852.391810','origin','block_type','2',0,''),(604787,190234,'1683125852.391810','origin','schema','2-2',0,'8356'),(604788,190235,'1683125852.393320','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(604789,190236,'1683125852.394747','origin','padding-right','20',0,''),(604790,190236,'1683125852.394747','origin','padding-right','0',0,'8356'),(604791,190236,'1683125852.394747','origin','padding-bottom','20',0,'8356'),(604792,190236,'1683125852.394747','origin','address_in','popup',0,''),(604793,190237,'1683125852.395767','origin','block_type','1',0,''),(604794,190237,'1683125852.395767','origin','padding-left','20',0,''),(604795,190237,'1683125852.395767','origin','padding-left','0',0,'8356'),(604796,190239,'1683125852.398588','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(604797,190240,'1683125852.400291','origin','block_type','1',0,''),(604798,190240,'1683125852.400291','origin','padding-top','30',0,''),(604799,190240,'1683125852.400291','origin','padding-left','30',0,''),(604800,190240,'1683125852.400291','origin','padding-right','30',0,''),(604801,190240,'1683125852.400291','origin','padding-bottom','30',0,''),(604802,190240,'1683125852.400291','origin','margin-bottom','20',0,''),(604803,190240,'1683125852.400291','origin','background-color','$content-bg-1',0,''),(604804,190240,'1683125852.400291','origin','color','$content-color-1',0,''),(604805,190243,'1683125852.403563','origin','block_type','1',0,''),(604806,190243,'1683125852.403563','origin','padding-top','20',0,''),(604807,190243,'1683125852.403563','origin','padding-left','20',0,''),(604808,190243,'1683125852.403563','origin','padding-right','20',0,''),(604809,190243,'1683125852.403563','origin','padding-bottom','20',0,''),(604810,190243,'1683125852.403563','origin','background-color','$content-bg-1',0,''),(604811,190243,'1683125852.403563','origin','style_class','order-summary',0,''),(604812,190243,'1683125852.403563','origin','color','$content-color-1',0,''),(604813,190244,'1683125852.405625','origin','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(604814,190244,'1683125852.405625','origin','text-align','center',0,''),(604815,190244,'1683125852.405625','origin','font-size','14',0,''),(604816,190244,'1683125852.405625','origin','color','$fade-color-1',0,''),(604817,190244,'1683125852.405625','origin','padding-top','10',0,''),(604818,190245,'1683125852.407666','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(604819,190246,'1683125852.40885','origin','hide_page','1',0,''),(604820,190246,'1683125852.40885','origin','hide_continue_button','1',0,''),(604821,190247,'1683125852.409688','origin','margin-bottom','10',0,''),(604822,190250,'73542','origin','block_type','1',0,''),(604823,190251,'73543','origin','margin-top','20',0,''),(604824,190252,'73544','origin','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(604825,190253,'73545','origin','link','products',0,''),(604826,190253,'73545','origin','margin-top','-33',0,''),(604827,190253,'73545','origin','float','right',0,''),(604828,190254,'73546','origin','block_type','2',0,''),(604829,190254,'73546','origin','margin-bottom','20',0,''),(604830,190254,'73546','origin','schema','2-2',0,'8349'),(604831,190255,'73547','origin','block_type','1',0,''),(604832,190255,'73547','origin','padding-right','20',0,''),(604833,190255,'73547','origin','padding-right','0',0,'8349'),(604834,190256,'73548','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(604835,190256,'73548','origin','clear','none',0,''),(604836,190258,'73550','origin','padding-left','20',0,''),(604837,190258,'73550','origin','block_type','1',0,''),(604838,190258,'73550','origin','padding-left','0',0,'8349'),(604839,190260,'73552','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(604840,190260,'73552','origin','clear','none',0,''),(604841,190261,'73553','origin','text-align','right',0,''),(604842,190261,'73553','origin','margin-bottom','20',0,''),(604843,190261,'73553','origin','margin-top','20',0,''),(604844,190262,'73554','origin','block_type','2',0,''),(604845,190262,'73554','origin','margin-bottom','20',0,''),(604846,190262,'73554','origin','schema','2-2',0,'8349'),(604847,190263,'73555','origin','block_type','1',0,''),(604848,190263,'73555','origin','padding-right','20',0,''),(604849,190263,'73555','origin','padding-right','0',0,'8349'),(604850,190265,'73557','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(604851,190265,'73557','origin','clear','none',0,''),(604852,190266,'73558','origin','block_type','1',0,''),(604853,190266,'73558','origin','padding-left','20',0,''),(604854,190266,'73558','origin','padding-left','0',0,'8349'),(604855,190267,'73559','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(604856,190267,'73559','origin','clear','none',0,''),(604857,190269,'73561','origin','margin-bottom','20',0,''),(604858,190269,'73561','origin','text-align','right',0,''),(604859,190271,'73576','origin','block_type','1',0,''),(604860,190272,'73577','origin','text-align','right',0,''),(604861,190272,'73577','origin','margin-bottom','20',0,''),(604862,190273,'73578','origin','block_type','2',0,''),(604863,190273,'73578','origin','margin-bottom','20',0,''),(604864,190273,'73578','origin','schema','2-2',0,'8349'),(604865,190274,'73579','origin','block_type','1',0,''),(604866,190274,'73579','origin','padding-right','20',0,''),(604867,190274,'73579','origin','padding-right','0',0,'8349'),(604868,190275,'73580','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(604869,190275,'73580','origin','clear','none',0,''),(604870,190277,'73582','origin','block_type','1',0,''),(604871,190277,'73582','origin','padding-left','20',0,''),(604872,190277,'73582','origin','padding-left','0',0,'8349'),(604873,190278,'73583','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(604874,190278,'73583','origin','clear','none',0,''),(604875,190280,'73585','origin','margin-bottom','20',0,''),(604876,190280,'73585','origin','text-align','right',0,''),(604877,190283,'73588','origin','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(604878,190284,'73563','origin','block_type','1',0,''),(604879,190285,'73564','origin','margin-bottom','20',0,''),(604880,190286,'73565','origin','margin-bottom','20',0,''),(604881,190286,'73565','origin','text-align','right',0,''),(604882,190287,'73566','origin','text-align','right',0,''),(604883,190287,'73566','origin','margin-bottom','20',0,''),(604884,190288,'73567','origin','block_type','2',0,''),(604885,190288,'73567','origin','margin-bottom','20',0,''),(604886,190288,'73567','origin','schema','2-2',0,'8349'),(604887,190289,'73568','origin','block_type','1',0,''),(604888,190289,'73568','origin','padding-right','20',0,''),(604889,190289,'73568','origin','padding-right','0',0,'8349'),(604890,190291,'73570','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(604891,190291,'73570','origin','clear','none',0,''),(604892,190292,'73571','origin','block_type','1',0,''),(604893,190292,'73571','origin','padding-left','20',0,''),(604894,190292,'73571','origin','padding-left','0',0,'8349'),(604895,190294,'73573','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(604896,190294,'73573','origin','clear','none',0,''),(604897,190295,'73574','origin','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(604898,190296,'73575','origin','margin-bottom','20',0,''),(604899,190297,'73589','origin','block_type','1',0,''),(604900,190298,'73590','origin','block_type','2',0,''),(604901,190298,'73590','origin','margin-bottom','20',0,''),(604902,190298,'73590','origin','schema','2-2',0,'8349'),(604903,190299,'73591','origin','block_type','1',0,''),(604904,190299,'73591','origin','padding-right','20',0,''),(604905,190299,'73591','origin','padding-right','0',0,'8349'),(604906,190301,'73593','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(604907,190301,'73593','origin','clear','none',0,''),(604908,190302,'73594','origin','block_type','1',0,''),(604909,190302,'73594','origin','padding-left','20',0,''),(604910,190302,'73594','origin','padding-left','0',0,'8349'),(604911,190304,'73596','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(604912,190304,'73596','origin','clear','none',0,''),(604913,190305,'73597','origin','margin-bottom','20',0,''),(604914,190306,'73598','origin','margin-bottom','20',0,''),(604915,190307,'73599','origin','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(604916,190308,'73600','origin','link','products',0,''),(604917,190308,'73600','origin','margin-top','-33',0,''),(604918,190308,'73600','origin','float','right',0,''),(604919,190309,'73601','origin','text-align','right',0,''),(604920,190309,'73601','origin','margin-bottom','20',0,''),(604921,190310,'73602','origin','margin-bottom','20',0,''),(604922,190310,'73602','origin','text-align','right',0,''),(604923,190311,'73603','origin','block_type','2',0,''),(604924,190311,'73603','origin','margin-bottom','20',0,''),(604925,190311,'73603','origin','schema','2-2',0,'8349'),(604926,190312,'73604','origin','block_type','1',0,''),(604927,190312,'73604','origin','padding-right','20',0,''),(604928,190312,'73604','origin','padding-right','0',0,'8349'),(604929,190313,'73605','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(604930,190313,'73605','origin','clear','none',0,''),(604931,190315,'73607','origin','padding-left','20',0,''),(604932,190315,'73607','origin','block_type','1',0,''),(604933,190315,'73607','origin','padding-left','0',0,'8349'),(604934,190316,'73608','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(604935,190316,'73608','origin','clear','none',0,''),(604936,190318,'73610','origin','text','##TEXT_CONFIRMATION##',0,''),(604937,190319,'73611','origin','text','##TEXT_CONFIRMATION##',0,''),(604938,190320,'73613','origin','text','##TEXT_CONFIRMATION##',0,''),(604939,190321,'73612','origin','text','##TEXT_CONFIRMATION##',0,''),(604940,190322,'73614','origin','text','##TEXT_CONFIRMATION##',0,''),(604941,190323,'73615','origin','text','##TEXT_CONFIRMATION##',0,''),(604942,190324,'73616','origin','block_type','2',0,''),(604943,190325,'73617','origin','block_type','1',0,''),(604944,190325,'73617','origin','padding-right','20',0,''),(604945,190326,'73618','origin','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(604946,190328,'73620','origin','block_type','1',0,''),(604947,190328,'73620','origin','padding-left','20',0,''),(604948,190328,'73620','origin','padding-left','0',0,'8356'),(604949,190329,'73621','origin','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(604950,190331,'73623','origin','block_type','4',0,''),(604951,190331,'73623','origin','schema','4-2',0,'8377'),(604952,190331,'73623','origin','padding-top','20',0,''),(604953,190332,'73624','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(604954,190332,'73624','origin','text-align','right',0,''),(604955,190332,'73624','origin','padding-top','10',0,''),(604956,190332,'73624','origin','font_size_measure','em',0,''),(604957,190332,'73624','origin','font-size','1.2',0,''),(604958,190333,'73625','origin','text-align','right',0,''),(604959,190334,'73626','origin','block_type','2',0,''),(604960,190335,'73627','origin','block_type','1',0,''),(604961,190335,'73627','origin','padding-right','20',0,''),(604962,190335,'73627','origin','padding-right','0',0,'8356'),(604963,190336,'73628','origin','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(604964,190338,'73630','origin','block_type','1',0,''),(604965,190338,'73630','origin','padding-right','0',0,'8356'),(604966,190338,'73630','origin','padding-left','20',0,''),(604967,190341,'73633','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(604968,190343,'73635','origin','block_type','2',0,''),(604969,190344,'73636','origin','block_type','1',0,''),(604970,190344,'73636','origin','padding-right','20',0,''),(604971,190346,'73638','origin','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(604972,190347,'73639','origin','block_type','1',0,''),(604973,190347,'73639','origin','padding-left','20',0,''),(604974,190347,'73639','origin','padding-left','0',0,'8356'),(604975,190348,'73640','origin','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(604976,190350,'73642','origin','block_type','4',0,''),(604977,190350,'73642','origin','schema','4-2',0,'8377'),(604978,190351,'73643','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(604979,190351,'73643','origin','text-align','right',0,''),(604980,190351,'73643','origin','padding-top','10',0,''),(604981,190351,'73643','origin','font_size_measure','em',0,''),(604982,190351,'73643','origin','font-size','1.2',0,''),(604983,190352,'73644','origin','text-align','right',0,''),(604984,190353,'73645','origin','block_type','2',0,''),(604985,190354,'73646','origin','block_type','1',0,''),(604986,190354,'73646','origin','padding-right','20',0,''),(604987,190354,'73646','origin','padding-right','0',0,'8356'),(604988,190356,'73648','origin','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(604989,190357,'73649','origin','block_type','1',0,''),(604990,190357,'73649','origin','padding-right','0',0,'8356'),(604991,190357,'73649','origin','padding-left','20',0,''),(604992,190359,'73651','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(604993,190362,'73654','origin','block_type','4',0,''),(604994,190362,'73654','origin','schema','4-2',0,'8377'),(604995,190363,'73655','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(604996,190363,'73655','origin','text-align','right',0,''),(604997,190363,'73655','origin','padding-top','10',0,''),(604998,190363,'73655','origin','font_size_measure','em',0,''),(604999,190363,'73655','origin','font-size','1.2',0,''),(605000,190364,'73656','origin','text-align','right',0,''),(605001,190365,'73657','origin','block_type','2',0,''),(605002,190366,'73658','origin','block_type','1',0,''),(605003,190366,'73658','origin','padding-right','20',0,''),(605004,190368,'73660','origin','block_type','1',0,''),(605005,190368,'73660','origin','padding-left','20',0,''),(605006,190368,'73660','origin','padding-left','0',0,'8356'),(605007,190369,'73661','origin','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605008,190371,'73663','origin','block_type','4',0,''),(605009,190371,'73663','origin','schema','4-2',0,'8377'),(605010,190372,'73664','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(605011,190372,'73664','origin','text-align','right',0,''),(605012,190372,'73664','origin','padding-top','10',0,''),(605013,190372,'73664','origin','font_size_measure','em',0,''),(605014,190372,'73664','origin','font-size','1.2',0,''),(605015,190373,'73665','origin','text-align','right',0,''),(605016,190374,'73666','origin','block_type','2',0,''),(605017,190375,'73667','origin','block_type','1',0,''),(605018,190375,'73667','origin','padding-right','20',0,''),(605019,190377,'73669','origin','block_type','1',0,''),(605020,190377,'73669','origin','padding-left','20',0,''),(605021,190377,'73669','origin','padding-left','0',0,'8356'),(605022,190379,'73671','origin','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605023,190380,'73672','origin','text','##DELIVERY_DETAILS##',0,''),(605024,190381,'73673','origin','text','##DELIVERY_DETAILS##',0,''),(605025,190382,'73675','origin','text','##CONTACT_INFORMATION##',0,''),(605026,190383,'73674','origin','text','##CONTACT_INFORMATION##',0,''),(605027,190384,'73676','origin','text','##DELIVERY_DETAILS##',0,''),(605028,190385,'73677','origin','text','##DELIVERY_DETAILS##',0,''),(605029,190386,'73678','origin','block_type','1',0,''),(605030,190386,'73678','origin','background-color','$content-bg-2',0,''),(605031,190386,'73678','origin','padding-top','30',0,''),(605032,190386,'73678','origin','padding-bottom','30',0,''),(605033,190387,'73679','origin','block_type','4',0,''),(605034,190387,'73679','origin','schema','4-2',0,'8356'),(605035,190388,'73680','origin','block_type','1',0,''),(605036,190388,'73680','origin','padding-right','40',0,''),(605037,190388,'73680','origin','padding-right','0',0,'8356'),(605038,190389,'73682','origin','block_type','1',0,''),(605039,190389,'73682','origin','background-color','$content-bg-1',0,''),(605040,190389,'73682','origin','padding-top','30',0,''),(605041,190389,'73682','origin','padding-left','30',0,''),(605042,190389,'73682','origin','padding-right','30',0,''),(605043,190389,'73682','origin','padding-bottom','30',0,''),(605044,190389,'73682','origin','margin-bottom','20',0,''),(605045,190389,'73682','origin','style_class','hiding-box',0,''),(605046,190390,'73683','origin','margin-bottom','20',0,''),(605047,190391,'73684','origin','padding-top','10',0,''),(605048,190391,'73684','origin','padding-left','20',0,''),(605049,190391,'73684','origin','padding-right','20',0,''),(605050,190391,'73684','origin','margin-top','20',0,''),(605051,190391,'73684','origin','background-color','$content-bg-2',0,''),(605052,190391,'73684','origin','padding-bottom','8',0,''),(605053,190392,'73685','origin','block_type','1',0,''),(605054,190392,'73685','origin','background-color','$content-bg-1',0,''),(605055,190392,'73685','origin','padding-top','30',0,''),(605056,190392,'73685','origin','padding-left','30',0,''),(605057,190392,'73685','origin','padding-right','30',0,''),(605058,190392,'73685','origin','padding-bottom','14',0,''),(605059,190392,'73685','origin','margin-bottom','20',0,''),(605060,190392,'73685','origin','style_class','hiding-box closeable-box',0,''),(605061,190393,'73686','origin','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(605062,190393,'73686','origin','style_class','closeable-heading closeable-event closed',0,''),(605063,190394,'73687','origin','style_class','closeable-content',0,''),(605064,190394,'73687','origin','padding-bottom','20',0,''),(605065,190395,'73688','origin','background-color','$content-bg-1',0,''),(605066,190395,'73688','origin','block_type','1',0,''),(605067,190395,'73688','origin','padding-top','30',0,''),(605068,190395,'73688','origin','padding-left','30',0,''),(605069,190395,'73688','origin','padding-right','30',0,''),(605070,190395,'73688','origin','padding-bottom','30',0,''),(605071,190395,'73688','origin','margin-bottom','20',0,''),(605072,190395,'73688','origin','style_class','hiding-box',0,''),(605073,190396,'73689','origin','block_type','1',0,''),(605074,190396,'73689','origin','content','\\_',0,'3'),(605075,190396,'73689','origin','border-top-width','1',0,'3'),(605076,190396,'73689','origin','border-top-color','$content-border-1',0,'3'),(605077,190396,'73689','origin','display','block',0,'3'),(605078,190396,'73689','origin','position','absolute',0,'3'),(605079,190396,'73689','origin','top','19',0,'3'),(605080,190396,'73689','origin','left','0',0,'3'),(605081,190396,'73689','origin','right','0',0,'3'),(605082,190396,'73689','origin','margin-top','-2',0,'3'),(605083,190396,'73689','origin','position','relative',0,''),(605084,190397,'73690','origin','box_align','2',0,''),(605085,190397,'73690','origin','margin-bottom','10',0,''),(605086,190397,'73690','origin','background-color','$content-bg-1',0,''),(605087,190397,'73690','origin','position','relative',0,''),(605088,190398,'73691','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(605089,190399,'73692','origin','block_type','2',0,''),(605090,190399,'73692','origin','schema','2-2',0,'8356'),(605091,190400,'73693','origin','block_type','1',0,''),(605092,190400,'73693','origin','padding-right','20',0,''),(605093,190400,'73693','origin','padding-left','0',0,'8356'),(605094,190400,'73693','origin','margin-bottom','20',0,'8356'),(605095,190403,'73696','origin','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(605096,190404,'73697','origin','block_type','1',0,''),(605097,190404,'73697','origin','padding-left','20',0,''),(605098,190404,'73697','origin','padding-left','0',0,'8356'),(605099,190405,'73698','origin','border-top-width','1',0,''),(605100,190405,'73698','origin','border-top-color','$content-border-1',0,''),(605101,190405,'73698','origin','padding-top','13',0,''),(605102,190405,'73698','origin','padding-bottom','10',0,''),(605103,190406,'73699','origin','background-color','$content-bg-2',0,''),(605104,190406,'73699','origin','padding-top','10',0,''),(605105,190406,'73699','origin','padding-left','10',0,''),(605106,190406,'73699','origin','padding-right','10',0,''),(605107,190406,'73699','origin','padding-bottom','10',0,''),(605108,190406,'73699','origin','margin-top','10',0,''),(605109,190407,'73700','origin','block_type','1',0,''),(605110,190407,'73700','origin','padding-top','20',0,''),(605111,190407,'73700','origin','padding-left','20',0,''),(605112,190407,'73700','origin','padding-right','20',0,''),(605113,190407,'73700','origin','padding-bottom','20',0,''),(605114,190407,'73700','origin','background-color','$content-bg-1',0,''),(605115,190407,'73700','origin','style_class','order-summary',0,''),(605116,190408,'73701','origin','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(605117,190408,'73701','origin','text-align','center',0,''),(605118,190408,'73701','origin','font-size','14',0,''),(605119,190408,'73701','origin','color','$fade-color-1',0,''),(605120,190408,'73701','origin','padding-top','10',0,''),(605121,190410,'115999','origin','hide_continue_button','1',0,''),(605122,190411,'73703','origin','block_type','1',0,''),(605123,190411,'73703','origin','background-color','$content-bg-2',0,''),(605124,190411,'73703','origin','padding-top','30',0,''),(605125,190411,'73703','origin','padding-bottom','30',0,''),(605126,190411,'73703','origin','color','$content-color-2',0,''),(605127,190412,'73704','origin','block_type','4',0,''),(605128,190413,'73705','origin','block_type','1',0,''),(605129,190413,'73705','origin','padding-right','40',0,''),(605130,190414,'73706','origin','block_type','1',0,''),(605131,190414,'73706','origin','background-color','$content-bg-1',0,''),(605132,190414,'73706','origin','padding-top','30',0,''),(605133,190414,'73706','origin','padding-left','30',0,''),(605134,190414,'73706','origin','padding-right','30',0,''),(605135,190414,'73706','origin','padding-bottom','30',0,''),(605136,190414,'73706','origin','margin-bottom','20',0,''),(605137,190414,'73706','origin','style_class','hiding-box',0,''),(605138,190414,'73706','origin','color','$content-color-1',0,''),(605139,190415,'73707','origin','padding-top','10',0,''),(605140,190415,'73707','origin','padding-left','20',0,''),(605141,190415,'73707','origin','padding-right','20',0,''),(605142,190415,'73707','origin','margin-top','20',0,''),(605143,190415,'73707','origin','background-color','$content-bg-2',0,''),(605144,190415,'73707','origin','padding-bottom','8',0,''),(605145,190415,'73707','origin','color','$content-color-2',0,''),(605146,190416,'73708','origin','margin-bottom','20',0,''),(605147,190417,'73709','origin','block_type','1',0,''),(605148,190417,'73709','origin','padding-top','30',0,''),(605149,190417,'73709','origin','padding-left','30',0,''),(605150,190417,'73709','origin','padding-right','30',0,''),(605151,190417,'73709','origin','padding-bottom','23',0,''),(605152,190417,'73709','origin','margin-bottom','20',0,''),(605153,190417,'73709','origin','background-color','$content-bg-1',0,''),(605154,190417,'73709','origin','style_class','hiding-box',0,''),(605155,190417,'73709','origin','color','$content-color-1',0,''),(605156,190418,'73710','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(605157,190419,'73711','origin','block_type','2',0,''),(605158,190420,'73712','origin','padding-right','20',0,''),(605159,190421,'73713','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605160,190422,'73714','origin','block_type','1',0,''),(605161,190422,'73714','origin','padding-left','20',0,''),(605162,190423,'73715','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605163,190425,'73717','origin','block_type','1',0,''),(605164,190425,'73717','origin','padding-top','30',0,''),(605165,190425,'73717','origin','padding-left','30',0,''),(605166,190425,'73717','origin','padding-right','30',0,''),(605167,190425,'73717','origin','padding-bottom','14',0,''),(605168,190425,'73717','origin','margin-bottom','20',0,''),(605169,190425,'73717','origin','background-color','$content-bg-1',0,''),(605170,190425,'73717','origin','style_class','hiding-box closeable-box',0,''),(605171,190425,'73717','origin','color','$content-color-1',0,''),(605172,190426,'73718','origin','block_type','2',0,''),(605173,190426,'73718','origin','style_class','closeable-content',0,''),(605174,190427,'73719','origin','padding-right','20',0,''),(605175,190427,'73719','origin','padding-bottom','20',0,''),(605176,190428,'73720','origin','padding-left','20',0,''),(605177,190428,'73720','origin','padding-bottom','20',0,''),(605178,190429,'73721','origin','padding-left','20',0,''),(605179,190429,'73721','origin','padding-bottom','20',0,''),(605180,190430,'73722','origin','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(605181,190430,'73722','origin','style_class','closeable-heading closeable-event closed',0,''),(605182,190431,'73723','origin','block_type','1',0,''),(605183,190431,'73723','origin','background-color','$content-bg-1',0,''),(605184,190431,'73723','origin','padding-top','30',0,''),(605185,190431,'73723','origin','padding-left','30',0,''),(605186,190431,'73723','origin','padding-right','30',0,''),(605187,190431,'73723','origin','padding-bottom','14',0,''),(605188,190431,'73723','origin','margin-bottom','20',0,''),(605189,190431,'73723','origin','style_class','hiding-box closeable-box',0,''),(605190,190431,'73723','origin','color','$content-color-1',0,''),(605191,190432,'73724','origin','style_class','closeable-content',0,''),(605192,190432,'73724','origin','padding-bottom','20',0,''),(605193,190433,'73725','origin','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(605194,190433,'73725','origin','style_class','closeable-heading closeable-event closed',0,''),(605195,190434,'73726','origin','block_type','1',0,''),(605196,190434,'73726','origin','padding-top','20',0,''),(605197,190434,'73726','origin','padding-left','20',0,''),(605198,190434,'73726','origin','padding-right','20',0,''),(605199,190434,'73726','origin','padding-bottom','20',0,''),(605200,190434,'73726','origin','background-color','$content-bg-1',0,''),(605201,190434,'73726','origin','style_class','order-summary hiding-box',0,''),(605202,190434,'73726','origin','color','$content-color-1',0,''),(605203,190435,'73727','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(605204,190436,'73728','origin','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(605205,190436,'73728','origin','text-align','center',0,''),(605206,190436,'73728','origin','font-size','14',0,''),(605207,190436,'73728','origin','color','$fade-color-1',0,''),(605208,190436,'73728','origin','padding-top','10',0,''),(605209,190437,'73729','origin','margin-bottom','10',0,''),(605210,190439,'73731','origin','hide_page','1',0,''),(605211,190439,'73731','origin','hide_continue_button','1',0,''),(605212,190440,'73732','origin','block_type','1',0,''),(605213,190442,'73734','origin','block_type','4',0,''),(605214,190442,'73734','origin','schema','4-2',0,'8377'),(605215,190443,'73735','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(605216,190443,'73735','origin','text-align','right',0,''),(605217,190443,'73735','origin','padding-top','10',0,''),(605218,190443,'73735','origin','font_size_measure','em',0,''),(605219,190443,'73735','origin','font-size','1.2',0,''),(605220,190444,'73736','origin','text-align','right',0,''),(605221,190445,'73737','origin','block_type','2',0,''),(605222,190445,'73737','origin','schema','2-2',0,'8356'),(605223,190446,'73738','origin','block_type','1',0,''),(605224,190446,'73738','origin','padding-right','20',0,''),(605225,190446,'73738','origin','padding-right','0',0,'8356'),(605226,190448,'73740','origin','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(605227,190449,'73741','origin','block_type','1',0,''),(605228,190449,'73741','origin','padding-left','20',0,''),(605229,190449,'73741','origin','padding-left','0',0,'8356'),(605230,190451,'73743','origin','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605231,190452,'73744','origin','block_type','2',0,''),(605232,190452,'73744','origin','schema','2-2',0,'8356'),(605233,190453,'73745','origin','block_type','1',0,''),(605234,190453,'73745','origin','padding-right','20',0,''),(605235,190453,'73745','origin','padding-right','0',0,'8356'),(605236,190454,'73746','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605237,190456,'73748','origin','block_type','1',0,''),(605238,190456,'73748','origin','padding-left','20',0,''),(605239,190456,'73748','origin','padding-left','0',0,'8356'),(605240,190461,'73753','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605241,190462,'73754','origin','margin-bottom','20',0,''),(605242,190463,'73755','origin','block_type','1',0,''),(605243,190463,'73755','origin','background-color','$content-bg-2',0,''),(605244,190463,'73755','origin','padding-top','30',0,''),(605245,190463,'73755','origin','padding-bottom','30',0,''),(605246,190464,'73756','origin','block_type','4',0,''),(605247,190464,'73756','origin','schema','4-2',0,'8356'),(605248,190465,'73757','origin','block_type','1',0,''),(605249,190465,'73757','origin','padding-right','40',0,''),(605250,190465,'73757','origin','padding-right','0',0,'8356'),(605251,190466,'73758','origin','background-color','$content-bg-1',0,''),(605252,190466,'73758','origin','padding-top','30',0,''),(605253,190466,'73758','origin','padding-left','30',0,''),(605254,190466,'73758','origin','padding-right','30',0,''),(605255,190466,'73758','origin','padding-bottom','30',0,''),(605256,190466,'73758','origin','margin-bottom','20',0,''),(605257,190467,'73759','origin','block_type','1',0,''),(605258,190467,'73759','origin','background-color','$content-bg-1',0,''),(605259,190467,'73759','origin','padding-top','30',0,''),(605260,190467,'73759','origin','padding-left','30',0,''),(605261,190467,'73759','origin','padding-right','30',0,''),(605262,190467,'73759','origin','padding-bottom','14',0,''),(605263,190467,'73759','origin','margin-bottom','20',0,''),(605264,190467,'73759','origin','style_class','hiding-box closeable-box',0,''),(605265,190468,'73760','origin','style_class','closeable-content',0,''),(605266,190468,'73760','origin','padding-bottom','20',0,''),(605267,190469,'73761','origin','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(605268,190469,'73761','origin','style_class','closeable-heading closeable-event closed',0,''),(605269,190470,'73762','origin','block_type','1',0,''),(605270,190470,'73762','origin','background-color','$content-bg-1',0,''),(605271,190470,'73762','origin','padding-top','30',0,''),(605272,190470,'73762','origin','padding-left','30',0,''),(605273,190470,'73762','origin','padding-right','30',0,''),(605274,190470,'73762','origin','padding-bottom','30',0,''),(605275,190470,'73762','origin','margin-bottom','20',0,''),(605276,190470,'73762','origin','style_class','hiding-box',0,''),(605277,190471,'73763','origin','padding-top','10',0,''),(605278,190471,'73763','origin','padding-left','20',0,''),(605279,190471,'73763','origin','padding-right','20',0,''),(605280,190471,'73763','origin','margin-top','20',0,''),(605281,190471,'73763','origin','background-color','$content-bg-2',0,''),(605282,190471,'73763','origin','padding-bottom','8',0,''),(605283,190472,'73764','origin','margin-bottom','20',0,''),(605284,190473,'73765','origin','block_type','1',0,''),(605285,190473,'73765','origin','padding-top','30',0,''),(605286,190473,'73765','origin','padding-left','30',0,''),(605287,190473,'73765','origin','padding-right','30',0,''),(605288,190473,'73765','origin','padding-bottom','23',0,''),(605289,190473,'73765','origin','margin-bottom','20',0,''),(605290,190473,'73765','origin','background-color','$content-bg-1',0,''),(605291,190473,'73765','origin','style_class','hiding-box',0,''),(605292,190474,'73766','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(605293,190475,'73767','origin','block_type','2',0,''),(605294,190475,'73767','origin','schema','2-2',0,'8356'),(605295,190476,'73768','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605296,190477,'73769','origin','padding-right','20',0,''),(605297,190477,'73769','origin','padding-right','0',0,'8356'),(605298,190477,'73769','origin','padding-bottom','20',0,'8356'),(605299,190478,'73770','origin','block_type','1',0,''),(605300,190478,'73770','origin','padding-left','20',0,''),(605301,190478,'73770','origin','padding-left','0',0,'8356'),(605302,190480,'73772','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605303,190481,'73773','origin','block_type','1',0,''),(605304,190481,'73773','origin','padding-top','20',0,''),(605305,190481,'73773','origin','padding-left','20',0,''),(605306,190481,'73773','origin','padding-right','20',0,''),(605307,190481,'73773','origin','padding-bottom','20',0,''),(605308,190481,'73773','origin','background-color','$content-bg-1',0,''),(605309,190481,'73773','origin','style_class','order-summary',0,''),(605310,190483,'73775','origin','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(605311,190483,'73775','origin','text-align','center',0,''),(605312,190483,'73775','origin','font-size','14',0,''),(605313,190483,'73775','origin','color','$fade-color-1',0,''),(605314,190483,'73775','origin','padding-top','10',0,''),(605315,190484,'73776','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(605316,190485,'73777','origin','margin-bottom','10',0,''),(605317,190486,'73778','origin','block_type','2',0,''),(605318,190487,'73779','origin','block_type','1',0,''),(605319,190487,'73779','origin','padding-left','0',0,'8356'),(605320,190487,'73779','origin','padding-right','20',0,''),(605321,190489,'73781','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605322,190490,'73782','origin','block_type','1',0,''),(605323,190490,'73782','origin','padding-left','20',0,''),(605324,190490,'73782','origin','padding-left','0',0,'8356'),(605325,190495,'73787','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605326,190496,'73788','origin','block_type','4',0,''),(605327,190496,'73788','origin','schema','4-2',0,'8377'),(605328,190496,'73788','origin','padding-top','20',0,''),(605329,190497,'73789','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(605330,190497,'73789','origin','text-align','right',0,''),(605331,190497,'73789','origin','padding-top','10',0,''),(605332,190497,'73789','origin','font_size_measure','em',0,''),(605333,190497,'73789','origin','font-size','1.2',0,''),(605334,190498,'73790','origin','text-align','right',0,''),(605335,190499,'73791','origin','block_type','2',0,''),(605336,190500,'73792','origin','block_type','1',0,''),(605337,190500,'73792','origin','padding-left','0',0,'8356'),(605338,190500,'73792','origin','padding-right','20',0,''),(605339,190502,'73794','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605340,190503,'73795','origin','block_type','1',0,''),(605341,190503,'73795','origin','padding-left','20',0,''),(605342,190503,'73795','origin','padding-left','0',0,'8356'),(605343,190505,'73797','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605344,190509,'73801','origin','block_type','4',0,''),(605345,190509,'73801','origin','schema','4-2',0,'8377'),(605346,190510,'73802','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(605347,190510,'73802','origin','text-align','right',0,''),(605348,190510,'73802','origin','padding-top','10',0,''),(605349,190510,'73802','origin','font_size_measure','em',0,''),(605350,190510,'73802','origin','font-size','1.2',0,''),(605351,190511,'73803','origin','text-align','right',0,''),(605352,190512,'73804','origin','block_type','4',0,''),(605353,190512,'73804','origin','schema','4-2',0,'8377'),(605354,190513,'73805','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(605355,190513,'73805','origin','text-align','right',0,''),(605356,190513,'73805','origin','padding-top','10',0,''),(605357,190513,'73805','origin','font_size_measure','em',0,''),(605358,190513,'73805','origin','font-size','1.2',0,''),(605359,190514,'73806','origin','text-align','right',0,''),(605360,190515,'73807','origin','block_type','2',0,''),(605361,190516,'73808','origin','block_type','1',0,''),(605362,190516,'73808','origin','padding-left','0',0,'8356'),(605363,190516,'73808','origin','padding-right','20',0,''),(605364,190517,'73809','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605365,190519,'73811','origin','block_type','1',0,''),(605366,190519,'73811','origin','padding-left','20',0,''),(605367,190519,'73811','origin','padding-left','0',0,'8356'),(605368,190524,'73816','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605369,190525,'73817','origin','block_type','4',0,''),(605370,190525,'73817','origin','schema','4-2',0,'8377'),(605371,190526,'73818','origin','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(605372,190526,'73818','origin','text-align','right',0,''),(605373,190526,'73818','origin','padding-top','10',0,''),(605374,190526,'73818','origin','font_size_measure','em',0,''),(605375,190526,'73818','origin','font-size','1.2',0,''),(605376,190527,'73819','origin','text-align','right',0,''),(605377,190528,'73820','origin','block_type','2',0,''),(605378,190529,'73821','origin','block_type','1',0,''),(605379,190529,'73821','origin','padding-left','0',0,'8356'),(605380,190529,'73821','origin','padding-right','20',0,''),(605381,190531,'73823','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605382,190532,'73824','origin','block_type','1',0,''),(605383,190532,'73824','origin','padding-left','20',0,''),(605384,190532,'73824','origin','padding-left','0',0,'8356'),(605385,190536,'73828','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605386,190538,'73830','origin','text','##PAYMENT_DETAILS##',0,''),(605387,190539,'73831','origin','text','##PAYMENT_DETAILS##',0,''),(605388,190540,'73832','origin','text','##PAYMENT_DETAILS##',0,''),(605389,190541,'73833','origin','text','##PAYMENT_DETAILS##',0,''),(605390,190542,'73834','origin','text','##PAYMENT_DETAILS##',0,''),(605391,190543,'73835','origin','text','##PAYMENT_DETAILS##',0,''),(605392,190544,'73836','origin','block_type','1',0,''),(605393,190544,'73836','origin','background-color','$content-bg-2',0,''),(605394,190544,'73836','origin','padding-top','30',0,''),(605395,190544,'73836','origin','padding-bottom','30',0,''),(605396,190545,'73837','origin','block_type','4',0,''),(605397,190545,'73837','origin','schema','4-2',0,'8356'),(605398,190546,'73838','origin','block_type','1',0,''),(605399,190546,'73838','origin','padding-right','40',0,''),(605400,190546,'73838','origin','padding-right','0',0,'8356'),(605401,190547,'73839','origin','block_type','1',0,''),(605402,190547,'73839','origin','background-color','$content-bg-1',0,''),(605403,190547,'73839','origin','padding-top','30',0,''),(605404,190547,'73839','origin','padding-left','30',0,''),(605405,190547,'73839','origin','padding-right','30',0,''),(605406,190547,'73839','origin','padding-bottom','30',0,''),(605407,190547,'73839','origin','margin-bottom','20',0,''),(605408,190547,'73839','origin','style_class','hiding-box',0,''),(605409,190548,'73840','origin','padding-top','10',0,''),(605410,190548,'73840','origin','padding-left','20',0,''),(605411,190548,'73840','origin','padding-right','20',0,''),(605412,190548,'73840','origin','margin-top','20',0,''),(605413,190548,'73840','origin','background-color','$content-bg-2',0,''),(605414,190548,'73840','origin','padding-bottom','8',0,''),(605415,190549,'73841','origin','margin-bottom','20',0,''),(605416,190550,'73842','origin','background-color','$content-bg-1',0,''),(605417,190550,'73842','origin','block_type','1',0,''),(605418,190550,'73842','origin','padding-top','30',0,''),(605419,190550,'73842','origin','padding-left','30',0,''),(605420,190550,'73842','origin','padding-right','30',0,''),(605421,190550,'73842','origin','padding-bottom','30',0,''),(605422,190550,'73842','origin','margin-bottom','20',0,''),(605423,190550,'73842','origin','style_class','hiding-box',0,''),(605424,190551,'73843','origin','block_type','1',0,''),(605425,190551,'73843','origin','content','\\_',0,'3'),(605426,190551,'73843','origin','border-top-width','1',0,'3'),(605427,190551,'73843','origin','border-top-color','$content-border-1',0,'3'),(605428,190551,'73843','origin','display','block',0,'3'),(605429,190551,'73843','origin','position','absolute',0,'3'),(605430,190551,'73843','origin','top','19',0,'3'),(605431,190551,'73843','origin','left','0',0,'3'),(605432,190551,'73843','origin','right','0',0,'3'),(605433,190551,'73843','origin','margin-top','-2',0,'3'),(605434,190551,'73843','origin','position','relative',0,''),(605435,190552,'73844','origin','box_align','2',0,''),(605436,190552,'73844','origin','margin-bottom','10',0,''),(605437,190552,'73844','origin','background-color','$content-bg-1',0,''),(605438,190552,'73844','origin','position','relative',0,''),(605439,190553,'73845','origin','background-color','$content-bg-2',0,''),(605440,190553,'73845','origin','padding-top','10',0,''),(605441,190553,'73845','origin','padding-left','10',0,''),(605442,190553,'73845','origin','padding-right','10',0,''),(605443,190553,'73845','origin','padding-bottom','10',0,''),(605444,190553,'73845','origin','margin-top','10',0,''),(605445,190554,'73846','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(605446,190555,'73847','origin','block_type','2',0,''),(605447,190555,'73847','origin','schema','2-2',0,'8356'),(605448,190556,'73848','origin','block_type','1',0,''),(605449,190556,'73848','origin','padding-right','20',0,''),(605450,190556,'73848','origin','padding-left','0',0,'8356'),(605451,190556,'73848','origin','margin-bottom','20',0,'8356'),(605452,190559,'73851','origin','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(605453,190560,'73852','origin','block_type','1',0,''),(605454,190560,'73852','origin','padding-left','20',0,''),(605455,190560,'73852','origin','padding-left','0',0,'8356'),(605456,190562,'73854','origin','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(605457,190563,'73855','origin','border-top-width','1',0,''),(605458,190563,'73855','origin','border-top-color','$content-border-1',0,''),(605459,190563,'73855','origin','padding-top','13',0,''),(605460,190563,'73855','origin','padding-bottom','10',0,''),(605461,190564,'73856','origin','block_type','1',0,''),(605462,190564,'73856','origin','background-color','$content-bg-1',0,''),(605463,190564,'73856','origin','padding-top','30',0,''),(605464,190564,'73856','origin','padding-left','30',0,''),(605465,190564,'73856','origin','padding-right','30',0,''),(605466,190564,'73856','origin','padding-bottom','14',0,''),(605467,190564,'73856','origin','margin-bottom','20',0,''),(605468,190564,'73856','origin','style_class','hiding-box closeable-box',0,''),(605469,190565,'73857','origin','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(605470,190565,'73857','origin','style_class','closeable-heading closeable-event closed',0,''),(605471,190566,'73858','origin','style_class','closeable-content',0,''),(605472,190566,'73858','origin','padding-bottom','20',0,''),(605473,190567,'73860','origin','block_type','1',0,''),(605474,190567,'73860','origin','padding-top','30',0,''),(605475,190567,'73860','origin','padding-left','30',0,''),(605476,190567,'73860','origin','padding-right','30',0,''),(605477,190567,'73860','origin','padding-bottom','23',0,''),(605478,190567,'73860','origin','margin-bottom','20',0,''),(605479,190567,'73860','origin','background-color','$content-bg-1',0,''),(605480,190567,'73860','origin','style_class','hiding-box',0,''),(605481,190568,'73861','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(605482,190569,'73862','origin','block_type','2',0,''),(605483,190569,'73862','origin','schema','2-2',0,'8356'),(605484,190570,'73863','origin','padding-right','20',0,''),(605485,190570,'73863','origin','padding-right','0',0,'8356'),(605486,190570,'73863','origin','padding-bottom','20',0,'8356'),(605487,190571,'73864','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605488,190572,'73865','origin','block_type','1',0,''),(605489,190572,'73865','origin','padding-left','20',0,''),(605490,190572,'73865','origin','padding-left','0',0,'8356'),(605491,190574,'73867','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605492,190575,'73868','origin','block_type','1',0,''),(605493,190575,'73868','origin','padding-top','20',0,''),(605494,190575,'73868','origin','padding-left','20',0,''),(605495,190575,'73868','origin','padding-right','20',0,''),(605496,190575,'73868','origin','padding-bottom','20',0,''),(605497,190575,'73868','origin','background-color','$content-bg-1',0,''),(605498,190575,'73868','origin','style_class','order-summary',0,''),(605499,190576,'73869','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(605500,190577,'73870','origin','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(605501,190577,'73870','origin','text-align','center',0,''),(605502,190577,'73870','origin','font-size','14',0,''),(605503,190577,'73870','origin','color','$fade-color-1',0,''),(605504,190577,'73870','origin','padding-top','10',0,''),(605505,190578,'73871','origin','margin-bottom','10',0,''),(605506,190580,'115996','origin','hide_continue_button','1',0,''),(605507,190581,'73873','origin','block_type','1',0,''),(605508,190581,'73873','origin','background-color','$content-bg-2',0,''),(605509,190581,'73873','origin','padding-top','30',0,''),(605510,190581,'73873','origin','padding-bottom','30',0,''),(605511,190582,'73874','origin','block_type','4',0,''),(605512,190582,'73874','origin','schema','4-2',0,'8356'),(605513,190583,'73875','origin','block_type','1',0,''),(605514,190583,'73875','origin','padding-right','40',0,''),(605515,190583,'73875','origin','padding-right','0',0,'8356'),(605516,190584,'73876','origin','background-color','$content-bg-1',0,''),(605517,190584,'73876','origin','padding-top','30',0,''),(605518,190584,'73876','origin','padding-left','30',0,''),(605519,190584,'73876','origin','padding-right','30',0,''),(605520,190584,'73876','origin','padding-bottom','30',0,''),(605521,190584,'73876','origin','margin-bottom','20',0,''),(605522,190585,'73877','origin','block_type','1',0,''),(605523,190585,'73877','origin','background-color','$content-bg-1',0,''),(605524,190585,'73877','origin','padding-top','30',0,''),(605525,190585,'73877','origin','padding-left','30',0,''),(605526,190585,'73877','origin','padding-right','30',0,''),(605527,190585,'73877','origin','padding-bottom','30',0,''),(605528,190585,'73877','origin','margin-bottom','20',0,''),(605529,190585,'73877','origin','style_class','hiding-box',0,''),(605530,190586,'73878','origin','margin-bottom','20',0,''),(605531,190587,'73879','origin','padding-top','10',0,''),(605532,190587,'73879','origin','padding-left','20',0,''),(605533,190587,'73879','origin','padding-right','20',0,''),(605534,190587,'73879','origin','margin-top','20',0,''),(605535,190587,'73879','origin','background-color','$content-bg-2',0,''),(605536,190587,'73879','origin','padding-bottom','8',0,''),(605537,190588,'73880','origin','background-color','$content-bg-1',0,''),(605538,190588,'73880','origin','block_type','1',0,''),(605539,190588,'73880','origin','padding-top','30',0,''),(605540,190588,'73880','origin','padding-left','30',0,''),(605541,190588,'73880','origin','padding-right','30',0,''),(605542,190588,'73880','origin','padding-bottom','30',0,''),(605543,190588,'73880','origin','margin-bottom','20',0,''),(605544,190588,'73880','origin','style_class','hiding-box',0,''),(605545,190589,'73881','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(605546,190590,'73882','origin','background-color','$content-bg-2',0,''),(605547,190590,'73882','origin','padding-top','10',0,''),(605548,190590,'73882','origin','padding-left','10',0,''),(605549,190590,'73882','origin','padding-right','10',0,''),(605550,190590,'73882','origin','padding-bottom','10',0,''),(605551,190590,'73882','origin','margin-top','10',0,''),(605552,190591,'73883','origin','block_type','1',0,''),(605553,190591,'73883','origin','content','\\_',0,'3'),(605554,190591,'73883','origin','border-top-width','1',0,'3'),(605555,190591,'73883','origin','border-top-color','$content-border-1',0,'3'),(605556,190591,'73883','origin','display','block',0,'3'),(605557,190591,'73883','origin','position','absolute',0,'3'),(605558,190591,'73883','origin','top','19',0,'3'),(605559,190591,'73883','origin','left','0',0,'3'),(605560,190591,'73883','origin','right','0',0,'3'),(605561,190591,'73883','origin','margin-top','-2',0,'3'),(605562,190591,'73883','origin','position','relative',0,''),(605563,190592,'73884','origin','box_align','2',0,''),(605564,190592,'73884','origin','margin-bottom','10',0,''),(605565,190592,'73884','origin','background-color','$content-bg-1',0,''),(605566,190592,'73884','origin','position','relative',0,''),(605567,190593,'73885','origin','block_type','2',0,''),(605568,190593,'73885','origin','schema','2-2',0,'8356'),(605569,190594,'73886','origin','block_type','1',0,''),(605570,190594,'73886','origin','padding-right','20',0,''),(605571,190594,'73886','origin','padding-left','0',0,'8356'),(605572,190594,'73886','origin','margin-bottom','20',0,'8356'),(605573,190597,'73889','origin','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(605574,190598,'73890','origin','block_type','1',0,''),(605575,190598,'73890','origin','padding-left','20',0,''),(605576,190598,'73890','origin','padding-left','0',0,'8356'),(605577,190600,'73892','origin','border-top-width','1',0,''),(605578,190600,'73892','origin','border-top-color','$content-border-1',0,''),(605579,190600,'73892','origin','padding-top','13',0,''),(605580,190600,'73892','origin','padding-bottom','10',0,''),(605581,190601,'73893','origin','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(605582,190602,'73894','origin','block_type','1',0,''),(605583,190602,'73894','origin','padding-top','30',0,''),(605584,190602,'73894','origin','padding-left','30',0,''),(605585,190602,'73894','origin','padding-right','30',0,''),(605586,190602,'73894','origin','padding-bottom','23',0,''),(605587,190602,'73894','origin','margin-bottom','20',0,''),(605588,190602,'73894','origin','background-color','$content-bg-1',0,''),(605589,190602,'73894','origin','style_class','hiding-box',0,''),(605590,190603,'73895','origin','block_type','2',0,''),(605591,190603,'73895','origin','schema','2-2',0,'8356'),(605592,190604,'73896','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605593,190605,'73897','origin','padding-right','20',0,''),(605594,190605,'73897','origin','padding-right','0',0,'8356'),(605595,190605,'73897','origin','padding-bottom','20',0,'8356'),(605596,190606,'73898','origin','block_type','1',0,''),(605597,190606,'73898','origin','padding-left','20',0,''),(605598,190606,'73898','origin','padding-left','0',0,'8356'),(605599,190607,'73899','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605600,190609,'73901','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(605601,190610,'73902','origin','block_type','1',0,''),(605602,190610,'73902','origin','background-color','$content-bg-1',0,''),(605603,190610,'73902','origin','padding-top','30',0,''),(605604,190610,'73902','origin','padding-left','30',0,''),(605605,190610,'73902','origin','padding-right','30',0,''),(605606,190610,'73902','origin','padding-bottom','14',0,''),(605607,190610,'73902','origin','margin-bottom','20',0,''),(605608,190610,'73902','origin','style_class','hiding-box closeable-box',0,''),(605609,190611,'73903','origin','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(605610,190611,'73903','origin','style_class','closeable-heading closeable-event closed',0,''),(605611,190612,'73904','origin','style_class','closeable-content',0,''),(605612,190612,'73904','origin','padding-bottom','20',0,''),(605613,190613,'73905','origin','block_type','1',0,''),(605614,190613,'73905','origin','padding-top','30',0,''),(605615,190613,'73905','origin','padding-left','30',0,''),(605616,190613,'73905','origin','padding-right','30',0,''),(605617,190613,'73905','origin','padding-bottom','14',0,''),(605618,190613,'73905','origin','margin-bottom','20',0,''),(605619,190613,'73905','origin','background-color','$content-bg-1',0,''),(605620,190613,'73905','origin','style_class','hiding-box closeable-box',0,''),(605621,190614,'73906','origin','block_type','2',0,''),(605622,190614,'73906','origin','style_class','closeable-content',0,''),(605623,190614,'73906','origin','schema','2-2',0,'8356'),(605624,190615,'73907','origin','padding-right','20',0,''),(605625,190615,'73907','origin','padding-bottom','20',0,''),(605626,190615,'73907','origin','padding-right','0',0,'8356'),(605627,190616,'73908','origin','padding-left','20',0,''),(605628,190616,'73908','origin','padding-bottom','20',0,''),(605629,190616,'73908','origin','padding-left','0',0,'8356'),(605630,190617,'73909','origin','padding-left','20',0,''),(605631,190617,'73909','origin','padding-bottom','20',0,''),(605632,190617,'73909','origin','padding-left','0',0,'8356'),(605633,190618,'73910','origin','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(605634,190618,'73910','origin','style_class','closeable-heading closeable-event closed',0,''),(605635,190619,'73911','origin','block_type','1',0,''),(605636,190619,'73911','origin','padding-top','20',0,''),(605637,190619,'73911','origin','padding-left','20',0,''),(605638,190619,'73911','origin','padding-right','20',0,''),(605639,190619,'73911','origin','padding-bottom','20',0,''),(605640,190619,'73911','origin','background-color','$content-bg-1',0,''),(605641,190619,'73911','origin','style_class','order-summary',0,''),(605642,190620,'73912','origin','margin-bottom','10',0,''),(605643,190621,'73913','origin','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(605644,190621,'73913','origin','text-align','center',0,''),(605645,190621,'73913','origin','font-size','14',0,''),(605646,190621,'73913','origin','color','$fade-color-1',0,''),(605647,190621,'73913','origin','padding-top','10',0,''),(605648,190622,'73914','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(605649,190624,'115998','origin','hide_continue_button','1',0,''),(605650,190625,'73916','origin','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(605651,190630,'73921','origin','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(605652,190631,'73923','origin','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(605653,190632,'73924','origin','style_class','order-summary',0,''),(605654,190632,'73924','origin','box_align','3',0,''),(605655,190632,'73924','origin','width','400',0,''),(605656,190634,'73922','origin','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(605657,190637,'73928','origin','block_type','1',0,''),(605658,190638,'73929','origin','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(605659,190639,'73930','origin','float','right',0,''),(605660,190639,'73930','origin','position','relative',0,''),(605661,190639,'73930','origin','z-index','1',0,''),(605662,190639,'73930','origin','top','30',0,''),(605663,190639,'73930','origin','margin-bottom','-20',0,''),(605664,190640,'73931','origin','margin-bottom','30',0,''),(605665,190641,'94704','origin','block_type','1',0,''),(605666,190642,'94705','origin','listing_type','Compare Products',0,''),(605667,190643,'94706','origin','block_type','1',0,''),(605668,190643,'94706','origin','style_class','item-holder',0,''),(605669,190643,'94706','origin','padding-top','10',0,''),(605670,190643,'94706','origin','padding-left','20',0,''),(605671,190643,'94706','origin','padding-right','20',0,''),(605672,190643,'94706','origin','padding-bottom','10',0,''),(605673,190643,'94706','origin','text-align','left',0,''),(605674,190646,'94709','origin','margin-bottom','10',0,''),(605675,190647,'94710','origin','block_type','5',0,''),(605676,190649,'94712','origin','clear','both',0,''),(605677,190650,'94713','origin','block_type','2',0,''),(605678,190651,'94714','origin','margin-bottom','7',0,''),(605679,190652,'94715','origin','text-align','right',0,''),(605680,190652,'94715','origin','margin-bottom','10',0,''),(605681,190652,'94715','origin','float','right',0,''),(605682,190653,'73932','origin','block_type','1',0,''),(605683,190653,'73932','origin','background-color','$content-bg-2',0,''),(605684,190653,'73932','origin','padding-bottom','30',0,''),(605685,190653,'73932','origin','color','$content-color-2',0,''),(605686,190654,'73933','origin','block_type','4',0,''),(605687,190654,'73933','origin','schema','4-2',0,'8356'),(605688,190655,'73934','origin','block_type','1',0,''),(605689,190655,'73934','origin','padding-right','40',0,''),(605690,190655,'73934','origin','padding-right','0',0,'8356'),(605691,190656,'73935','origin','block_type','1',0,''),(605692,190656,'73935','origin','padding-right','30',0,''),(605693,190656,'73935','origin','background-color','$content-bg-1',0,''),(605694,190656,'73935','origin','padding-top','20',0,''),(605695,190656,'73935','origin','padding-left','30',0,''),(605696,190656,'73935','origin','padding-bottom','20',0,''),(605697,190656,'73935','origin','padding-left','20',0,'8356'),(605698,190656,'73935','origin','padding-right','20',0,'8356'),(605699,190656,'73935','origin','color','$content-color-1',0,''),(605700,190657,'73936','origin','link','products',0,''),(605701,190657,'73936','origin','float','right',0,''),(605702,190657,'73936','origin','margin-top','-37',0,''),(605703,190659,'73938','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(605704,190660,'73939','origin','block_type','1',0,''),(605705,190660,'73939','origin','background-color','$content-bg-1',0,''),(605706,190660,'73939','origin','padding-top','20',0,''),(605707,190660,'73939','origin','padding-bottom','20',0,''),(605708,190660,'73939','origin','padding-left','30',0,''),(605709,190660,'73939','origin','padding-right','30',0,''),(605710,190660,'73939','origin','margin-bottom','20',0,''),(605711,190660,'73939','origin','color','$content-color-1',0,''),(605712,190661,'73940','origin','float','right',0,''),(605713,190661,'73940','origin','margin-top','-37',0,''),(605714,190661,'73940','origin','link','comments',0,''),(605715,190662,'73941','origin','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605716,190663,'73942','origin','hide_parents','2',0,''),(605717,190664,'73943','origin','block_type','2',0,''),(605718,190664,'73943','origin','margin-bottom','20',0,''),(605719,190664,'73943','origin','schema','2-2',0,'8349'),(605720,190664,'73943','origin','background-color','$content-bg-1',0,''),(605721,190664,'73943','origin','color','$content-color-1',0,''),(605722,190665,'73944','origin','block_type','1',0,''),(605723,190665,'73944','origin','border-right-width','20',0,''),(605724,190665,'73944','origin','border-right-color','$content-bg-2',0,''),(605725,190665,'73944','origin','margin-right','-10',0,''),(605726,190665,'73944','origin','padding-right','30',0,''),(605727,190665,'73944','origin','padding-top','20',0,''),(605728,190665,'73944','origin','padding-left','30',0,''),(605729,190665,'73944','origin','padding-bottom','20',0,''),(605730,190665,'73944','origin','border-right-width','0',0,'8356'),(605731,190665,'73944','origin','margin-right','0',0,'8356'),(605732,190665,'73944','origin','margin-bottom','20',0,'8356'),(605733,190665,'73944','origin','padding-left','20',0,'8356'),(605734,190665,'73944','origin','padding-right','20',0,'8356'),(605735,190666,'73945','origin','link','shipping_method',0,''),(605736,190666,'73945','origin','float','right',0,''),(605737,190666,'73945','origin','margin-top','-31',0,''),(605738,190668,'73947','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(605739,190668,'73947','origin','padding-top','20',0,''),(605740,190669,'73948','origin','link','contact_information',0,''),(605741,190669,'73948','origin','margin-top','-31',0,''),(605742,190669,'73948','origin','float','right',0,''),(605743,190670,'73949','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(605744,190670,'73949','origin','clear','none',0,''),(605745,190672,'73951','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(605746,190673,'73952','origin','link','shipping_address',0,''),(605747,190673,'73952','origin','float','right',0,''),(605748,190673,'73952','origin','margin-top','-31',0,''),(605749,190675,'73954','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(605750,190675,'73954','origin','clear','none',0,''),(605751,190676,'73955','origin','margin-bottom','20',0,''),(605752,190677,'73956','origin','block_type','1',0,''),(605753,190677,'73956','origin','padding-left','30',0,''),(605754,190677,'73956','origin','border-left-width','20',0,''),(605755,190677,'73956','origin','border-left-color','$content-bg-2',0,''),(605756,190677,'73956','origin','margin-left','-10',0,''),(605757,190677,'73956','origin','padding-right','30',0,''),(605758,190677,'73956','origin','padding-top','20',0,''),(605759,190677,'73956','origin','padding-bottom','20',0,''),(605760,190677,'73956','origin','border-left-width','0',0,'8356'),(605761,190678,'73957','origin','link','payment_method',0,''),(605762,190678,'73957','origin','float','right',0,''),(605763,190678,'73957','origin','margin-top','-31',0,''),(605764,190679,'73958','origin','link','billing_address',0,''),(605765,190679,'73958','origin','float','right',0,''),(605766,190679,'73958','origin','margin-top','-31',0,''),(605767,190681,'73960','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605768,190681,'73960','origin','clear','none',0,''),(605769,190682,'73961','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(605770,190683,'73962','origin','margin-bottom','20',0,''),(605771,190684,'73963','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605772,190684,'73963','origin','clear','none',0,''),(605773,190686,'73965','origin','block_type','1',0,''),(605774,190686,'73965','origin','padding-top','20',0,''),(605775,190686,'73965','origin','padding-left','20',0,''),(605776,190686,'73965','origin','padding-right','20',0,''),(605777,190686,'73965','origin','padding-bottom','20',0,''),(605778,190686,'73965','origin','background-color','$content-bg-1',0,''),(605779,190686,'73965','origin','style_class','order-summary2 hiding-box',0,''),(605780,190686,'73965','origin','color','$content-color-1',0,''),(605781,190687,'73966','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(605782,190688,'73967','origin','margin-bottom','20',0,''),(605783,190688,'73967','origin','text-align','right',0,''),(605784,190690,'73969','origin','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(605785,190691,'73970','origin','block_type','1',0,''),(605786,190691,'73970','origin','background-color','$content-bg-2',0,''),(605787,190691,'73970','origin','padding-bottom','30',0,''),(605788,190692,'73971','origin','block_type','4',0,''),(605789,190692,'73971','origin','schema','4-2',0,'8356'),(605790,190693,'73972','origin','block_type','1',0,''),(605791,190693,'73972','origin','padding-right','40',0,''),(605792,190693,'73972','origin','padding-right','0',0,'8356'),(605793,190694,'73973','origin','block_type','1',0,''),(605794,190694,'73973','origin','background-color','$content-bg-1',0,''),(605795,190694,'73973','origin','padding-top','20',0,''),(605796,190694,'73973','origin','padding-bottom','20',0,''),(605797,190694,'73973','origin','padding-left','30',0,''),(605798,190694,'73973','origin','padding-right','30',0,''),(605799,190694,'73973','origin','margin-bottom','20',0,''),(605800,190695,'73974','origin','hide_parents','2',0,''),(605801,190696,'73975','origin','float','right',0,''),(605802,190696,'73975','origin','margin-top','-37',0,''),(605803,190696,'73975','origin','link','comments',0,''),(605804,190697,'73976','origin','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605805,190698,'73977','origin','block_type','1',0,''),(605806,190698,'73977','origin','padding-right','30',0,''),(605807,190698,'73977','origin','background-color','$content-bg-1',0,''),(605808,190698,'73977','origin','padding-top','20',0,''),(605809,190698,'73977','origin','padding-left','30',0,''),(605810,190698,'73977','origin','padding-bottom','20',0,''),(605811,190698,'73977','origin','padding-left','20',0,'8356'),(605812,190698,'73977','origin','padding-right','20',0,'8356'),(605813,190699,'73978','origin','link','products',0,''),(605814,190699,'73978','origin','float','right',0,''),(605815,190699,'73978','origin','margin-top','-37',0,''),(605816,190700,'73979','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(605817,190702,'73981','origin','block_type','2',0,''),(605818,190702,'73981','origin','margin-bottom','20',0,''),(605819,190702,'73981','origin','schema','2-2',0,'8349'),(605820,190702,'73981','origin','background-color','$content-bg-1',0,''),(605821,190703,'73982','origin','block_type','1',0,''),(605822,190703,'73982','origin','border-right-width','20',0,''),(605823,190703,'73982','origin','border-right-color','$content-border-1',0,''),(605824,190703,'73982','origin','margin-right','-10',0,''),(605825,190703,'73982','origin','padding-right','30',0,''),(605826,190703,'73982','origin','padding-top','20',0,''),(605827,190703,'73982','origin','padding-left','30',0,''),(605828,190703,'73982','origin','padding-bottom','20',0,''),(605829,190703,'73982','origin','border-right-width','0',0,'8356'),(605830,190703,'73982','origin','margin-right','0',0,'8356'),(605831,190703,'73982','origin','margin-bottom','20',0,'8356'),(605832,190703,'73982','origin','padding-left','20',0,'8356'),(605833,190703,'73982','origin','padding-right','20',0,'8356'),(605834,190704,'73983','origin','link','shipping_address',0,''),(605835,190704,'73983','origin','float','right',0,''),(605836,190704,'73983','origin','margin-top','-31',0,''),(605837,190706,'73985','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(605838,190706,'73985','origin','clear','none',0,''),(605839,190707,'73986','origin','link','shipping_method',0,''),(605840,190707,'73986','origin','float','right',0,''),(605841,190707,'73986','origin','margin-top','-31',0,''),(605842,190708,'73987','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(605843,190708,'73987','origin','clear','none',0,''),(605844,190709,'73988','origin','margin-bottom','20',0,''),(605845,190710,'73989','origin','block_type','1',0,''),(605846,190710,'73989','origin','padding-left','30',0,''),(605847,190710,'73989','origin','border-left-width','20',0,''),(605848,190710,'73989','origin','border-left-color','$content-border-1',0,''),(605849,190710,'73989','origin','margin-left','-10',0,''),(605850,190710,'73989','origin','padding-right','30',0,''),(605851,190710,'73989','origin','padding-top','20',0,''),(605852,190710,'73989','origin','padding-bottom','20',0,''),(605853,190710,'73989','origin','border-left-width','0',0,'8356'),(605854,190713,'73992','origin','link','contact_information',0,''),(605855,190713,'73992','origin','margin-top','-31',0,''),(605856,190713,'73992','origin','float','right',0,''),(605857,190714,'73993','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(605858,190715,'73994','origin','block_type','1',0,''),(605859,190715,'73994','origin','padding-top','20',0,''),(605860,190715,'73994','origin','padding-left','20',0,''),(605861,190715,'73994','origin','padding-right','20',0,''),(605862,190715,'73994','origin','padding-bottom','20',0,''),(605863,190715,'73994','origin','background-color','$content-bg-1',0,''),(605864,190715,'73994','origin','style_class','order-summary',0,''),(605865,190716,'73995','origin','margin-bottom','20',0,''),(605866,190716,'73995','origin','text-align','right',0,''),(605867,190717,'73996','origin','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(605868,190718,'73997','origin','block_type','1',0,''),(605869,190718,'73997','origin','background-color','$content-bg-2',0,''),(605870,190718,'73997','origin','padding-bottom','30',0,''),(605871,190718,'73997','origin','color','$content-color-2',0,''),(605872,190719,'73998','origin','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(605873,190720,'73999','origin','block_type','4',0,''),(605874,190721,'74000','origin','block_type','1',0,''),(605875,190721,'74000','origin','padding-right','40',0,''),(605876,190722,'74001','origin','block_type','2',0,''),(605877,190722,'74001','origin','margin-bottom','20',0,''),(605878,190722,'74001','origin','schema','2-2',0,'8349'),(605879,190722,'74001','origin','background-color','$content-bg-1',0,''),(605880,190722,'74001','origin','color','$content-color-1',0,''),(605881,190723,'74002','origin','block_type','1',0,''),(605882,190723,'74002','origin','padding-right','0',0,'8349'),(605883,190723,'74002','origin','border-right-width','20',0,''),(605884,190723,'74002','origin','border-right-color','$content-bg-2',0,''),(605885,190723,'74002','origin','margin-right','-10',0,''),(605886,190723,'74002','origin','padding-right','30',0,''),(605887,190723,'74002','origin','padding-top','20',0,''),(605888,190723,'74002','origin','padding-left','30',0,''),(605889,190723,'74002','origin','padding-bottom','20',0,''),(605890,190724,'74003','origin','link','contact_information',0,''),(605891,190724,'74003','origin','margin-top','-37',0,''),(605892,190724,'74003','origin','float','right',0,''),(605893,190725,'74004','origin','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(605894,190725,'74004','origin','padding-top','20',0,''),(605895,190727,'74006','origin','block_type','1',0,''),(605896,190727,'74006','origin','padding-left','30',0,''),(605897,190727,'74006','origin','padding-left','0',0,'8349'),(605898,190727,'74006','origin','border-left-width','20',0,''),(605899,190727,'74006','origin','border-left-color','$content-bg-2',0,''),(605900,190727,'74006','origin','margin-left','-10',0,''),(605901,190727,'74006','origin','padding-right','30',0,''),(605902,190727,'74006','origin','padding-top','20',0,''),(605903,190727,'74006','origin','padding-bottom','20',0,''),(605904,190729,'74008','origin','link','payment_method',0,''),(605905,190729,'74008','origin','float','right',0,''),(605906,190729,'74008','origin','margin-top','-31',0,''),(605907,190730,'74009','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605908,190730,'74009','origin','clear','none',0,''),(605909,190731,'74010','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(605910,190732,'74011','origin','link','billing_address',0,''),(605911,190732,'74011','origin','float','right',0,''),(605912,190732,'74011','origin','margin-top','-31',0,''),(605913,190733,'74012','origin','margin-bottom','20',0,''),(605914,190734,'74013','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(605915,190734,'74013','origin','clear','none',0,''),(605916,190735,'74014','origin','block_type','1',0,''),(605917,190735,'74014','origin','background-color','$content-bg-1',0,''),(605918,190735,'74014','origin','padding-top','20',0,''),(605919,190735,'74014','origin','padding-bottom','20',0,''),(605920,190735,'74014','origin','padding-left','30',0,''),(605921,190735,'74014','origin','padding-right','30',0,''),(605922,190735,'74014','origin','margin-bottom','20',0,''),(605923,190735,'74014','origin','color','$content-color-1',0,''),(605924,190736,'74015','origin','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605925,190737,'74016','origin','hide_parents','2',0,''),(605926,190738,'74017','origin','float','right',0,''),(605927,190738,'74017','origin','margin-top','-37',0,''),(605928,190738,'74017','origin','link','comments',0,''),(605929,190739,'74018','origin','block_type','1',0,''),(605930,190739,'74018','origin','padding-right','30',0,''),(605931,190739,'74018','origin','padding-right','0',0,'8349'),(605932,190739,'74018','origin','background-color','$content-bg-1',0,''),(605933,190739,'74018','origin','padding-top','20',0,''),(605934,190739,'74018','origin','padding-left','30',0,''),(605935,190739,'74018','origin','padding-bottom','20',0,''),(605936,190739,'74018','origin','color','$content-color-1',0,''),(605937,190740,'74019','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(605938,190741,'74020','origin','link','products',0,''),(605939,190741,'74020','origin','float','right',0,''),(605940,190741,'74020','origin','margin-top','-37',0,''),(605941,190743,'74022','origin','block_type','1',0,''),(605942,190743,'74022','origin','padding-top','20',0,''),(605943,190743,'74022','origin','padding-left','20',0,''),(605944,190743,'74022','origin','padding-right','20',0,''),(605945,190743,'74022','origin','padding-bottom','20',0,''),(605946,190743,'74022','origin','background-color','$content-bg-1',0,''),(605947,190743,'74022','origin','style_class','order-summary2 hiding-box',0,''),(605948,190743,'74022','origin','color','$content-color-1',0,''),(605949,190744,'74023','origin','margin-bottom','20',0,''),(605950,190744,'74023','origin','text-align','right',0,''),(605951,190745,'74024','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(605952,190747,'74026','origin','block_type','1',0,''),(605953,190747,'74026','origin','background-color','$content-bg-2',0,''),(605954,190747,'74026','origin','padding-bottom','30',0,''),(605955,190748,'74027','origin','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(605956,190749,'74028','origin','block_type','4',0,''),(605957,190749,'74028','origin','schema','4-2',0,'8356'),(605958,190750,'74029','origin','block_type','1',0,''),(605959,190750,'74029','origin','padding-right','40',0,''),(605960,190750,'74029','origin','padding-right','0',0,'8356'),(605961,190751,'74030','origin','block_type','1',0,''),(605962,190751,'74030','origin','background-color','$content-bg-1',0,''),(605963,190751,'74030','origin','padding-top','20',0,''),(605964,190751,'74030','origin','padding-bottom','20',0,''),(605965,190751,'74030','origin','padding-left','30',0,''),(605966,190751,'74030','origin','padding-right','30',0,''),(605967,190751,'74030','origin','margin-bottom','20',0,''),(605968,190752,'74031','origin','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(605969,190753,'74032','origin','hide_parents','2',0,''),(605970,190754,'74033','origin','float','right',0,''),(605971,190754,'74033','origin','margin-top','-37',0,''),(605972,190754,'74033','origin','link','comments',0,''),(605973,190755,'74034','origin','block_type','2',0,''),(605974,190755,'74034','origin','margin-bottom','20',0,''),(605975,190755,'74034','origin','schema','2-2',0,'8349'),(605976,190755,'74034','origin','background-color','$content-bg-1',0,''),(605977,190756,'74035','origin','block_type','1',0,''),(605978,190756,'74035','origin','border-right-width','20',0,''),(605979,190756,'74035','origin','border-right-color','$content-border-1',0,''),(605980,190756,'74035','origin','margin-right','-10',0,''),(605981,190756,'74035','origin','padding-right','30',0,''),(605982,190756,'74035','origin','padding-top','20',0,''),(605983,190756,'74035','origin','padding-left','30',0,''),(605984,190756,'74035','origin','padding-bottom','20',0,''),(605985,190756,'74035','origin','border-right-width','0',0,'8356'),(605986,190756,'74035','origin','margin-right','0',0,'8356'),(605987,190756,'74035','origin','margin-bottom','20',0,'8356'),(605988,190756,'74035','origin','padding-left','20',0,'8356'),(605989,190756,'74035','origin','padding-right','20',0,'8356'),(605990,190757,'74036','origin','link','contact_information',0,''),(605991,190757,'74036','origin','margin-top','-31',0,''),(605992,190757,'74036','origin','float','right',0,''),(605993,190760,'74039','origin','link','payment_method',0,''),(605994,190760,'74039','origin','float','right',0,''),(605995,190760,'74039','origin','margin-top','-31',0,''),(605996,190761,'74040','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(605997,190761,'74040','origin','padding-top','20',0,''),(605998,190762,'74041','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(605999,190762,'74041','origin','clear','none',0,''),(606000,190763,'74042','origin','block_type','1',0,''),(606001,190763,'74042','origin','padding-left','30',0,''),(606002,190763,'74042','origin','border-left-width','20',0,''),(606003,190763,'74042','origin','border-left-color','$content-border-1',0,''),(606004,190763,'74042','origin','margin-left','-10',0,''),(606005,190763,'74042','origin','padding-right','30',0,''),(606006,190763,'74042','origin','padding-top','20',0,''),(606007,190763,'74042','origin','padding-bottom','20',0,''),(606008,190763,'74042','origin','border-left-width','0',0,'8356'),(606009,190764,'74043','origin','margin-bottom','20',0,''),(606010,190765,'74044','origin','link','billing_address',0,''),(606011,190765,'74044','origin','float','right',0,''),(606012,190765,'74044','origin','margin-top','-31',0,''),(606013,190766,'74045','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(606014,190766,'74045','origin','clear','none',0,''),(606015,190767,'74046','origin','block_type','1',0,''),(606016,190767,'74046','origin','padding-right','30',0,''),(606017,190767,'74046','origin','background-color','$content-bg-1',0,''),(606018,190767,'74046','origin','padding-top','20',0,''),(606019,190767,'74046','origin','padding-left','30',0,''),(606020,190767,'74046','origin','padding-bottom','20',0,''),(606021,190767,'74046','origin','padding-left','20',0,'8356'),(606022,190767,'74046','origin','padding-right','20',0,'8356'),(606023,190768,'74047','origin','link','products',0,''),(606024,190768,'74047','origin','float','right',0,''),(606025,190768,'74047','origin','margin-top','-37',0,''),(606026,190769,'74048','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(606027,190770,'74049','origin','margin-bottom','20',0,''),(606028,190771,'74050','origin','block_type','1',0,''),(606029,190771,'74050','origin','padding-top','20',0,''),(606030,190771,'74050','origin','padding-left','20',0,''),(606031,190771,'74050','origin','padding-right','20',0,''),(606032,190771,'74050','origin','padding-bottom','20',0,''),(606033,190771,'74050','origin','background-color','$content-bg-1',0,''),(606034,190771,'74050','origin','style_class','order-summary',0,''),(606035,190772,'74051','origin','margin-bottom','20',0,''),(606036,190772,'74051','origin','text-align','right',0,''),(606037,190774,'74053','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(606038,190775,'74054','origin','block_type','1',0,''),(606039,190775,'74054','origin','background-color','$content-bg-2',0,''),(606040,190775,'74054','origin','padding-bottom','30',0,''),(606041,190776,'74055','origin','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(606042,190777,'74056','origin','block_type','4',0,''),(606043,190777,'74056','origin','schema','4-2',0,'8356'),(606044,190778,'74057','origin','block_type','1',0,''),(606045,190778,'74057','origin','padding-right','40',0,''),(606046,190778,'74057','origin','padding-right','0',0,'8356'),(606047,190779,'74058','origin','block_type','1',0,''),(606048,190779,'74058','origin','padding-right','30',0,''),(606049,190779,'74058','origin','background-color','$content-bg-1',0,''),(606050,190779,'74058','origin','padding-top','20',0,''),(606051,190779,'74058','origin','padding-left','30',0,''),(606052,190779,'74058','origin','padding-bottom','20',0,''),(606053,190779,'74058','origin','padding-left','20',0,'8356'),(606054,190779,'74058','origin','padding-right','20',0,'8356'),(606055,190781,'74060','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(606056,190782,'74061','origin','link','products',0,''),(606057,190782,'74061','origin','float','right',0,''),(606058,190782,'74061','origin','margin-top','-37',0,''),(606059,190783,'74062','origin','block_type','2',0,''),(606060,190783,'74062','origin','margin-bottom','20',0,''),(606061,190783,'74062','origin','schema','2-2',0,'8349'),(606062,190783,'74062','origin','background-color','$content-bg-1',0,''),(606063,190784,'74063','origin','block_type','1',0,''),(606064,190784,'74063','origin','border-right-width','20',0,''),(606065,190784,'74063','origin','border-right-color','$content-border-1',0,''),(606066,190784,'74063','origin','margin-right','-10',0,''),(606067,190784,'74063','origin','padding-right','30',0,''),(606068,190784,'74063','origin','padding-top','20',0,''),(606069,190784,'74063','origin','padding-left','30',0,''),(606070,190784,'74063','origin','padding-bottom','20',0,''),(606071,190784,'74063','origin','border-right-width','0',0,'8356'),(606072,190784,'74063','origin','margin-right','0',0,'8356'),(606073,190784,'74063','origin','margin-bottom','20',0,'8356'),(606074,190784,'74063','origin','padding-left','20',0,'8356'),(606075,190784,'74063','origin','padding-right','20',0,'8356'),(606076,190785,'74064','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(606077,190786,'74065','origin','link','contact_information',0,''),(606078,190786,'74065','origin','margin-top','-31',0,''),(606079,190786,'74065','origin','float','right',0,''),(606080,190787,'74066','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(606081,190787,'74066','origin','clear','none',0,''),(606082,190789,'74068','origin','margin-bottom','20',0,''),(606083,190791,'74070','origin','link','shipping_address',0,''),(606084,190791,'74070','origin','float','right',0,''),(606085,190791,'74070','origin','margin-top','-31',0,''),(606086,190793,'74072','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(606087,190793,'74072','origin','padding-top','20',0,''),(606088,190794,'74073','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(606089,190794,'74073','origin','clear','none',0,''),(606090,190795,'74074','origin','link','shipping_method',0,''),(606091,190795,'74074','origin','float','right',0,''),(606092,190795,'74074','origin','margin-top','-31',0,''),(606093,190796,'74075','origin','block_type','1',0,''),(606094,190796,'74075','origin','padding-left','30',0,''),(606095,190796,'74075','origin','border-left-width','20',0,''),(606096,190796,'74075','origin','border-left-color','$content-border-1',0,''),(606097,190796,'74075','origin','margin-left','-10',0,''),(606098,190796,'74075','origin','padding-right','30',0,''),(606099,190796,'74075','origin','padding-top','20',0,''),(606100,190796,'74075','origin','padding-bottom','20',0,''),(606101,190796,'74075','origin','border-left-width','0',0,'8356'),(606102,190797,'74076','origin','link','billing_address',0,''),(606103,190797,'74076','origin','float','right',0,''),(606104,190797,'74076','origin','margin-top','-31',0,''),(606105,190798,'74077','origin','margin-bottom','20',0,''),(606106,190800,'74079','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(606107,190801,'74080','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(606108,190801,'74080','origin','clear','none',0,''),(606109,190802,'74081','origin','link','payment_method',0,''),(606110,190802,'74081','origin','float','right',0,''),(606111,190802,'74081','origin','margin-top','-31',0,''),(606112,190803,'74082','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(606113,190803,'74082','origin','clear','none',0,''),(606114,190804,'74083','origin','block_type','1',0,''),(606115,190804,'74083','origin','background-color','$content-bg-1',0,''),(606116,190804,'74083','origin','padding-top','20',0,''),(606117,190804,'74083','origin','padding-bottom','20',0,''),(606118,190804,'74083','origin','padding-left','30',0,''),(606119,190804,'74083','origin','padding-right','30',0,''),(606120,190804,'74083','origin','margin-bottom','20',0,''),(606121,190805,'74084','origin','hide_parents','2',0,''),(606122,190806,'74085','origin','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(606123,190807,'74086','origin','float','right',0,''),(606124,190807,'74086','origin','margin-top','-37',0,''),(606125,190807,'74086','origin','link','comments',0,''),(606126,190808,'74087','origin','block_type','1',0,''),(606127,190808,'74087','origin','padding-top','20',0,''),(606128,190808,'74087','origin','padding-left','20',0,''),(606129,190808,'74087','origin','padding-right','20',0,''),(606130,190808,'74087','origin','padding-bottom','20',0,''),(606131,190808,'74087','origin','background-color','$content-bg-1',0,''),(606132,190808,'74087','origin','style_class','order-summary',0,''),(606133,190809,'74088','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(606134,190811,'74090','origin','margin-bottom','20',0,''),(606135,190811,'74090','origin','text-align','right',0,''),(606136,190812,'74091','origin','block_type','1',0,''),(606137,190812,'74091','origin','background-color','$content-bg-2',0,''),(606138,190812,'74091','origin','padding-bottom','30',0,''),(606139,190813,'74092','origin','block_type','4',0,''),(606140,190813,'74092','origin','schema','4-2',0,'8356'),(606141,190814,'74093','origin','block_type','1',0,''),(606142,190814,'74093','origin','padding-right','40',0,''),(606143,190814,'74093','origin','padding-right','0',0,'8356'),(606144,190815,'74094','origin','block_type','2',0,''),(606145,190815,'74094','origin','margin-bottom','20',0,''),(606146,190815,'74094','origin','schema','2-2',0,'8349'),(606147,190815,'74094','origin','background-color','$content-bg-1',0,''),(606148,190816,'74095','origin','block_type','1',0,''),(606149,190816,'74095','origin','border-right-width','20',0,''),(606150,190816,'74095','origin','border-right-color','$content-border-1',0,''),(606151,190816,'74095','origin','margin-right','-10',0,''),(606152,190816,'74095','origin','padding-right','30',0,''),(606153,190816,'74095','origin','padding-top','20',0,''),(606154,190816,'74095','origin','padding-left','30',0,''),(606155,190816,'74095','origin','padding-bottom','20',0,''),(606156,190816,'74095','origin','border-right-width','0',0,'8356'),(606157,190816,'74095','origin','margin-right','0',0,'8356'),(606158,190816,'74095','origin','margin-bottom','20',0,'8356'),(606159,190816,'74095','origin','padding-left','20',0,'8356'),(606160,190816,'74095','origin','padding-right','20',0,'8356'),(606161,190817,'74096','origin','margin-bottom','20',0,''),(606162,190818,'74097','origin','link','shipping_address',0,''),(606163,190818,'74097','origin','float','right',0,''),(606164,190818,'74097','origin','margin-top','-31',0,''),(606165,190819,'74098','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(606166,190819,'74098','origin','clear','none',0,''),(606167,190822,'74101','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(606168,190823,'74102','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(606169,190823,'74102','origin','clear','none',0,''),(606170,190824,'74103','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(606171,190824,'74103','origin','padding-top','20',0,''),(606172,190826,'74105','origin','link','shipping_method',0,''),(606173,190826,'74105','origin','float','right',0,''),(606174,190826,'74105','origin','margin-top','-31',0,''),(606175,190827,'74106','origin','link','contact_information',0,''),(606176,190827,'74106','origin','margin-top','-31',0,''),(606177,190827,'74106','origin','float','right',0,''),(606178,190828,'74107','origin','block_type','1',0,''),(606179,190828,'74107','origin','padding-left','30',0,''),(606180,190828,'74107','origin','border-left-width','20',0,''),(606181,190828,'74107','origin','border-left-color','$content-border-1',0,''),(606182,190828,'74107','origin','margin-left','-10',0,''),(606183,190828,'74107','origin','padding-right','30',0,''),(606184,190828,'74107','origin','padding-top','20',0,''),(606185,190828,'74107','origin','padding-bottom','20',0,''),(606186,190828,'74107','origin','border-left-width','0',0,'8356'),(606187,190829,'74108','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(606188,190829,'74108','origin','clear','none',0,''),(606189,190830,'74109','origin','margin-bottom','20',0,''),(606190,190831,'74110','origin','link','billing_address',0,''),(606191,190831,'74110','origin','float','right',0,''),(606192,190831,'74110','origin','margin-top','-31',0,''),(606193,190833,'74112','origin','link','payment_method',0,''),(606194,190833,'74112','origin','float','right',0,''),(606195,190833,'74112','origin','margin-top','-31',0,''),(606196,190834,'74113','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(606197,190835,'74114','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(606198,190835,'74114','origin','clear','none',0,''),(606199,190836,'74115','origin','block_type','1',0,''),(606200,190836,'74115','origin','padding-right','30',0,''),(606201,190836,'74115','origin','background-color','$content-bg-1',0,''),(606202,190836,'74115','origin','padding-top','20',0,''),(606203,190836,'74115','origin','padding-left','30',0,''),(606204,190836,'74115','origin','padding-bottom','20',0,''),(606205,190836,'74115','origin','padding-left','20',0,'8356'),(606206,190836,'74115','origin','padding-right','20',0,'8356'),(606207,190837,'74116','origin','link','products',0,''),(606208,190837,'74116','origin','float','right',0,''),(606209,190837,'74116','origin','margin-top','-37',0,''),(606210,190838,'74117','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(606211,190840,'74119','origin','block_type','1',0,''),(606212,190840,'74119','origin','background-color','$content-bg-1',0,''),(606213,190840,'74119','origin','padding-top','20',0,''),(606214,190840,'74119','origin','padding-bottom','20',0,''),(606215,190840,'74119','origin','padding-left','30',0,''),(606216,190840,'74119','origin','padding-right','30',0,''),(606217,190840,'74119','origin','margin-bottom','20',0,''),(606218,190841,'74120','origin','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(606219,190842,'74121','origin','float','right',0,''),(606220,190842,'74121','origin','margin-top','-37',0,''),(606221,190842,'74121','origin','link','comments',0,''),(606222,190843,'74122','origin','hide_parents','2',0,''),(606223,190844,'74123','origin','block_type','1',0,''),(606224,190844,'74123','origin','padding-top','20',0,''),(606225,190844,'74123','origin','padding-left','20',0,''),(606226,190844,'74123','origin','padding-right','20',0,''),(606227,190844,'74123','origin','padding-bottom','20',0,''),(606228,190844,'74123','origin','background-color','$content-bg-1',0,''),(606229,190844,'74123','origin','style_class','order-summary',0,''),(606230,190846,'74125','origin','margin-bottom','20',0,''),(606231,190846,'74125','origin','text-align','right',0,''),(606232,190847,'74126','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(606233,190848,'74127','origin','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(606234,190849,'74128','origin','block_type','1',0,''),(606235,190851,'74133','origin','block_type','2',0,''),(606236,190851,'74133','origin','font-weight','400',0,''),(606237,190851,'74133','origin','padding-bottom','20',0,''),(606238,190851,'74133','origin','schema','2-2',0,'8356'),(606239,190852,'74134','origin','show_captcha','on',0,''),(606240,190853,'74135','origin','font-weight','400',0,''),(606241,190853,'74135','origin','padding-left','40',0,''),(606242,190853,'74135','origin','time_format','24',0,''),(606243,190853,'74135','origin','show_icons','on',0,''),(606244,190853,'74135','origin','padding-left','0',0,'8356'),(606245,190854,'74136','origin','block_type','1',0,''),(606246,190855,'74137','origin','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(606247,190856,'74138','origin','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(606248,190856,'74138','origin','margin-bottom','40',0,''),(606249,190857,'74139','origin','width','680',0,''),(606250,190857,'74139','origin','font-weight','normal',0,''),(606251,190857,'74139','origin','font-size','12',0,''),(606252,190857,'74139','origin','padding-top','20',0,''),(606253,190857,'74139','origin','padding-bottom','20',0,''),(606254,190857,'74139','origin','color','$content-color-1',0,''),(606255,190858,'74140','origin','block_type','3',0,''),(606256,190858,'74140','origin','font-weight','normal',0,''),(606257,190858,'74140','origin','padding-top','20',0,''),(606258,190859,'74141','origin','font-size','12',0,''),(606259,190860,'74142','origin','text','<p>If undelivered please return to:</p>',1,''),(606260,190860,'74142','origin','font-size','12',0,''),(606261,190860,'74142','origin','font-weight','bold',0,''),(606262,190860,'74142','origin','text','<p>If undelivered please return to:</p>',0,''),(606263,190861,'74143','origin','text','<p>Thank you for your order</p>',1,''),(606264,190861,'74143','origin','color','$color-8',0,''),(606265,190861,'74143','origin','font-size','13',0,''),(606266,190861,'74143','origin','font-weight','bold',0,''),(606267,190861,'74143','origin','padding-top','5',0,''),(606268,190861,'74143','origin','text-align','center',0,''),(606269,190861,'74143','origin','text','<p>Thank you for your order</p>',0,''),(606270,190862,'74144','origin','font-weight','400',0,''),(606271,190862,'74144','origin','text-align','center',0,''),(606272,190862,'74144','origin','padding-top','0',0,''),(606273,190862,'74144','origin','padding-left','20',0,''),(606274,190862,'74144','origin','padding-right','20',0,''),(606275,190863,'74145','origin','text','<p>If something has gone wrong please contact us at:</p>',1,''),(606276,190863,'74145','origin','font-size','12',0,''),(606277,190863,'74145','origin','font-weight','bold',0,''),(606278,190863,'74145','origin','text-align','right',0,''),(606279,190863,'74145','origin','text','<p>If something has gone wrong please contact us at:</p>',0,''),(606280,190864,'74146','origin','block_type','6',0,''),(606281,190864,'74146','origin','font-weight','normal',0,''),(606282,190864,'74146','origin','font-size','16',0,''),(606283,190865,'74147','origin','text','<p>Email:</p>',1,''),(606284,190865,'74147','origin','font-weight','normal',0,''),(606285,190865,'74147','origin','text-align','right',0,''),(606286,190865,'74147','origin','font-size','12',0,''),(606287,190865,'74147','origin','text','<p>Email:</p>',0,''),(606288,190866,'74148','origin','font-weight','normal',0,''),(606289,190866,'74148','origin','text-align','right',0,''),(606290,190866,'74148','origin','font-size','12',0,''),(606291,190867,'74149','origin','block_type','6',0,''),(606292,190867,'74149','origin','font-weight','normal',0,''),(606293,190867,'74149','origin','font-size','16',0,''),(606294,190868,'74150','origin','text','<p>Phone:</p>',1,''),(606295,190868,'74150','origin','font-weight','normal',0,''),(606296,190868,'74150','origin','text-align','right',0,''),(606297,190868,'74150','origin','font-size','12',0,''),(606298,190868,'74150','origin','text','<p>Phone:</p>',0,''),(606299,190869,'74151','origin','font-weight','normal',0,''),(606300,190869,'74151','origin','text-align','right',0,''),(606301,190869,'74151','origin','font-size','12',0,''),(606302,190870,'74152','origin','font-weight','400',0,''),(606303,190870,'74152','origin','padding-top','20',0,''),(606304,190870,'74152','origin','padding-bottom','0',0,''),(606305,190870,'74152','origin','font-size','12',0,''),(606306,190871,'74153','origin','block_type','2',0,''),(606307,190871,'74153','origin','font-weight','normal',0,''),(606308,190871,'74153','origin','padding-bottom','20',0,''),(606309,190872,'74154','origin','font-weight','400',0,''),(606310,190872,'74154','origin','padding-top','20',0,''),(606311,190873,'74155','origin','block_type','11',0,''),(606312,190873,'74155','origin','font-weight','normal',0,''),(606313,190874,'74156','origin','text','<p>Web:</p>',1,''),(606314,190874,'74156','origin','font-weight','normal',0,''),(606315,190874,'74156','origin','text-align','right',0,''),(606316,190874,'74156','origin','text','<p>Web:</p>',0,''),(606317,190875,'74157','origin','font-weight','normal',0,''),(606318,190875,'74157','origin','text-align','right',0,''),(606319,190876,'74158','origin','block_type','11',0,''),(606320,190876,'74158','origin','font-weight','normal',0,''),(606321,190877,'74159','origin','text','<p>Phone:</p>',1,''),(606322,190877,'74159','origin','font-weight','normal',0,''),(606323,190877,'74159','origin','text-align','right',0,''),(606324,190877,'74159','origin','text','<p>Phone:</p>',0,''),(606325,190878,'74160','origin','font-weight','normal',0,''),(606326,190878,'74160','origin','text-align','right',0,''),(606327,190879,'74161','origin','block_type','11',0,''),(606328,190879,'74161','origin','font-weight','normal',0,''),(606329,190880,'74162','origin','text','<p>Email:</p>',1,''),(606330,190880,'74162','origin','font-weight','normal',0,''),(606331,190880,'74162','origin','text-align','right',0,''),(606332,190880,'74162','origin','text','<p>Email:</p>',0,''),(606333,190881,'74163','origin','font-weight','normal',0,''),(606334,190881,'74163','origin','text-align','right',0,''),(606335,190882,'74164','origin','block_type','1',0,''),(606336,190883,'74165','origin','font-weight','normal',0,''),(606337,190883,'74165','origin','text-align','right',0,''),(606338,190883,'74165','origin','padding-bottom','10',0,''),(606339,190883,'74165','origin','address_spacer',',',0,''),(606340,190883,'74165','origin','font-size','12',0,''),(606341,190884,'74166','origin','block_type','5',0,''),(606342,190884,'74166','origin','font-weight','normal',0,''),(606343,190884,'74166','origin','border-bottom-width','1',0,''),(606344,190884,'74166','origin','border-bottom-color','$content-border-1',0,''),(606345,190884,'74166','origin','border-top-width','1',0,''),(606346,190884,'74166','origin','border-top-color','$content-border-1',0,''),(606347,190884,'74166','origin','border-left-color','$content-border-1',0,''),(606348,190884,'74166','origin','border-left-width','1',0,''),(606349,190885,'74167','origin','block_type','1',0,''),(606350,190885,'74167','origin','font-weight','normal',0,''),(606351,190885,'74167','origin','padding-top','10',0,''),(606352,190885,'74167','origin','padding-left','10',0,''),(606353,190885,'74167','origin','padding-right','10',0,''),(606354,190886,'74168','origin','font-weight','400',0,''),(606355,190886,'74168','origin','line-height','120',0,''),(606356,190886,'74168','origin','line_height_measure','%',0,''),(606357,190886,'74168','origin','font-size','12',0,''),(606358,190887,'74169','origin','text','<p>SHIPPING ADDRESS:</p>',1,''),(606359,190887,'74169','origin','font-size','14',0,''),(606360,190887,'74169','origin','font-weight','bold',0,''),(606361,190887,'74169','origin','padding-bottom','10',0,''),(606362,190887,'74169','origin','text','<p>SHIPPING ADDRESS:</p>',0,''),(606363,190888,'74170','origin','block_type','1',0,''),(606364,190888,'74170','origin','background-color','$content-bg-2',0,''),(606365,190888,'74170','origin','padding-top','20',0,''),(606366,190888,'74170','origin','padding-left','10',0,''),(606367,190888,'74170','origin','padding-right','10',0,''),(606368,190888,'74170','origin','padding-bottom','20',0,''),(606369,190888,'74170','origin','font-size','14',0,''),(606370,190889,'74171','origin','block_type','4',0,''),(606371,190889,'74171','origin','font-weight','normal',0,''),(606372,190889,'74171','origin','border-top-width','1',0,''),(606373,190889,'74171','origin','border-top-color','$content-border-1',0,''),(606374,190889,'74171','origin','border-left-width','1',0,''),(606375,190889,'74171','origin','border-left-color','$content-border-1',0,''),(606376,190889,'74171','origin','border-right-width','1',0,''),(606377,190889,'74171','origin','border-right-color','$content-border-1',0,''),(606378,190889,'74171','origin','border-bottom-width','1',0,''),(606379,190889,'74171','origin','border-bottom-color','$content-border-1',0,''),(606380,190890,'74172','origin','block_type','2',0,''),(606381,190890,'74172','origin','font-weight','normal',0,''),(606382,190890,'74172','origin','border-right-width','1',0,''),(606383,190890,'74172','origin','border-right-color','$content-border-1',0,''),(606384,190891,'74173','origin','block_type','1',0,''),(606385,190891,'74173','origin','font-weight','400',0,''),(606386,190891,'74173','origin','background-color','$content-bg-2',0,''),(606387,190891,'74173','origin','padding-top','10',0,''),(606388,190891,'74173','origin','padding-left','10',0,''),(606389,190891,'74173','origin','padding-right','10',0,''),(606390,190891,'74173','origin','padding-bottom','30',0,''),(606391,190892,'74174','origin','text','<p>INVOICE ADDRESS:</p>',1,''),(606392,190892,'74174','origin','font-size','14',0,''),(606393,190892,'74174','origin','font-weight','bold',0,''),(606394,190892,'74174','origin','text','<p>INVOICE ADDRESS:</p>',0,''),(606395,190893,'74175','origin','font-size','12',0,''),(606396,190894,'74176','origin','block_type','1',0,''),(606397,190894,'74176','origin','font-weight','normal',0,''),(606398,190894,'74176','origin','padding-top','10',0,''),(606399,190894,'74176','origin','padding-left','10',0,''),(606400,190894,'74176','origin','padding-right','10',0,''),(606401,190894,'74176','origin','padding-bottom','10',0,''),(606402,190895,'74177','origin','font-weight','normal',0,''),(606403,190896,'74178','origin','text','<p>CUSTOMER:</p>',1,''),(606404,190896,'74178','origin','font-size','13',0,''),(606405,190896,'74178','origin','font-weight','bold',0,''),(606406,190896,'74178','origin','text','<p>CUSTOMER:</p>',0,''),(606407,190897,'74179','origin','text','<p>PHONE NUMBER:</p>',1,''),(606408,190897,'74179','origin','font-size','14',0,''),(606409,190897,'74179','origin','font-weight','bold',0,''),(606410,190897,'74179','origin','padding-top','10',0,''),(606411,190897,'74179','origin','text','<p>PHONE NUMBER:</p>',0,''),(606412,190898,'74180','origin','font-weight','normal',0,''),(606413,190900,'74182','origin','text','<p>E-MAIL ADDRESS:</p>',1,''),(606414,190900,'74182','origin','font-weight','bold',0,''),(606415,190900,'74182','origin','font-size','14',0,''),(606416,190900,'74182','origin','padding-top','10',0,''),(606417,190900,'74182','origin','text','<p>E-MAIL ADDRESS:</p>',0,''),(606418,190901,'74183','origin','block_type','2',0,''),(606419,190901,'74183','origin','font-weight','normal',0,''),(606420,190901,'74183','origin','border-top-width','1',0,''),(606421,190901,'74183','origin','border-top-color','$content-border-1',0,''),(606422,190901,'74183','origin','border-right-width','1',0,''),(606423,190901,'74183','origin','border-right-color','$content-border-1',0,''),(606424,190902,'74184','origin','block_type','1',0,''),(606425,190902,'74184','origin','font-weight','normal',0,''),(606426,190902,'74184','origin','padding-top','10',0,''),(606427,190902,'74184','origin','padding-left','10',0,''),(606428,190902,'74184','origin','padding-right','10',0,''),(606429,190902,'74184','origin','padding-bottom','10',0,''),(606430,190902,'74184','origin','border-right-width','1',0,''),(606431,190902,'74184','origin','border-right-color','$content-border-1',0,''),(606432,190904,'74186','origin','text','<p>Shipping via</p>',1,''),(606433,190904,'74186','origin','font-weight','bold',0,''),(606434,190904,'74186','origin','font-size','14',0,''),(606435,190904,'74186','origin','text','<p>Shipping via</p>',0,''),(606436,190905,'74187','origin','block_type','1',0,''),(606437,190905,'74187','origin','font-weight','normal',0,''),(606438,190905,'74187','origin','padding-top','10',0,''),(606439,190905,'74187','origin','padding-left','10',0,''),(606440,190905,'74187','origin','padding-right','10',0,''),(606441,190905,'74187','origin','padding-bottom','10',0,''),(606442,190906,'74188','origin','text','<p>Shipping service</p>',1,''),(606443,190906,'74188','origin','font-weight','bold',0,''),(606444,190906,'74188','origin','font-size','14',0,''),(606445,190906,'74188','origin','text','<p>Shipping service</p>',0,''),(606446,190908,'74190','origin','font-size','14',0,''),(606447,190908,'74190','origin','font-weight','bold',0,''),(606448,190908,'74190','origin','text-align','center',0,''),(606449,190908,'74190','origin','padding-bottom','10',0,''),(606450,190908,'74190','origin','padding-top','10',0,''),(606451,190909,'74191','origin','text','<p>Payment date:</p>',1,''),(606452,190909,'74191','origin','font-weight','bold',0,''),(606453,190909,'74191','origin','text-align','center',0,''),(606454,190909,'74191','origin','font-size','12',0,''),(606455,190909,'74191','origin','text','<p>Payment date:</p>',0,''),(606456,190910,'74192','origin','font-weight','normal',0,''),(606457,190910,'74192','origin','text-align','center',0,''),(606458,190910,'74192','origin','padding-bottom','10',0,''),(606459,190917,'74199','origin','text-align','center',0,''),(606460,190917,'74199','origin','padding-top','10',0,''),(606461,190919,'74201','origin','heading_type','h1',0,''),(606462,190922,'94718','origin','text-align','center',0,''),(606463,190922,'94718','origin','padding-top','10',0,''),(606464,190927,'74202','origin','block_type','1',0,''),(606465,190928,'74203','origin','block_type','1',0,''),(606466,190928,'74203','origin','max-width','800',0,''),(606467,190928,'74203','origin','margin','0 auto',0,''),(606468,190928,'74203','origin','background-color','$content-bg-1',0,''),(606469,190929,'74204','origin','color','$content-color-1',0,''),(606470,190929,'74204','origin','font-size','12',0,''),(606471,190929,'74204','origin','padding-top','20',0,''),(606472,190929,'74204','origin','padding-bottom','20',0,''),(606473,190929,'74204','origin','border-top-width','1',0,''),(606474,190929,'74204','origin','border-top-color','$content-border-1',0,''),(606475,190930,'74205','origin','font-weight','normal',0,''),(606476,190930,'74205','origin','padding-top','20',0,''),(606477,190930,'74205','origin','padding-left','10',0,''),(606478,190930,'74205','origin','padding-right','10',0,''),(606479,190930,'74205','origin','padding-bottom','20',0,''),(606480,190930,'74205','origin','color','$content-color-1',0,''),(606481,190930,'74205','origin','font-size','14',0,''),(606482,190931,'74206','origin','block_type','7',0,''),(606483,190931,'74206','origin','font-weight','normal',0,''),(606484,190931,'74206','origin','background-color','$highlight-box-bg-1',0,''),(606485,190931,'74206','origin','padding-top','5',0,''),(606486,190931,'74206','origin','padding-left','10',0,''),(606487,190931,'74206','origin','padding-right','10',0,''),(606488,190931,'74206','origin','padding-bottom','5',0,''),(606489,190932,'74207','origin','color','$highlight-box-color-1',0,''),(606490,190932,'74207','origin','font-size','14',0,''),(606491,190932,'74207','origin','font-weight','normal',0,''),(606492,190933,'74208','origin','font-weight','normal',0,''),(606493,190933,'74208','origin','text-align','right',0,''),(606494,190933,'74208','origin','color','$highlight-box-color-1',0,''),(606495,190933,'74208','origin','font-size','12',0,''),(606496,190934,'74209','origin','font-weight','normal',0,''),(606497,190934,'74209','origin','padding-bottom','10',0,''),(606498,190934,'74209','origin','padding-top','10',0,''),(606499,190934,'74209','origin','logo_from','theme',0,''),(606500,190935,'74210','origin','block_type','1',0,''),(606501,190936,'74211','origin','block_type','1',0,''),(606502,190936,'74211','origin','max-width','800',0,''),(606503,190936,'74211','origin','margin','0 auto',0,''),(606504,190936,'74211','origin','background-color','$content-bg-1',0,''),(606505,190937,'74212','origin','color','$content-color-1',0,''),(606506,190937,'74212','origin','font-size','12',0,''),(606507,190937,'74212','origin','padding-top','20',0,''),(606508,190937,'74212','origin','padding-bottom','20',0,''),(606509,190937,'74212','origin','border-top-width','1',0,''),(606510,190937,'74212','origin','border-top-color','$content-border-1',0,''),(606511,190938,'74213','origin','font-weight','normal',0,''),(606512,190938,'74213','origin','padding-bottom','10',0,''),(606513,190938,'74213','origin','background-color','$highlight-box-bg-1',0,''),(606514,190938,'74213','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',1,''),(606515,190938,'74213','origin','padding-left','20',0,''),(606516,190938,'74213','origin','padding-top','10',0,''),(606517,190938,'74213','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',0,''),(606518,190939,'74214','origin','font-weight','normal',0,''),(606519,190939,'74214','origin','padding-top','20',0,''),(606520,190939,'74214','origin','padding-left','10',0,''),(606521,190939,'74214','origin','padding-right','10',0,''),(606522,190939,'74214','origin','padding-bottom','20',0,''),(606523,190939,'74214','origin','color','$content-color-1',0,''),(606524,190939,'74214','origin','font-size','14',0,''),(606525,190940,'74215','origin','block_type','7',0,''),(606526,190940,'74215','origin','font-weight','normal',0,''),(606527,190940,'74215','origin','background-color','$highlight-box-bg-1',0,''),(606528,190940,'74215','origin','padding-top','5',0,''),(606529,190940,'74215','origin','padding-left','10',0,''),(606530,190940,'74215','origin','padding-right','10',0,''),(606531,190940,'74215','origin','padding-bottom','5',0,''),(606532,190941,'74216','origin','color','$highlight-box-color-1',0,''),(606533,190941,'74216','origin','font-size','15',0,''),(606534,190941,'74216','origin','font-weight','700',0,''),(606535,190942,'74217','origin','font-weight','normal',0,''),(606536,190942,'74217','origin','text-align','right',0,''),(606537,190942,'74217','origin','color','$highlight-box-color-1',0,''),(606538,190942,'74217','origin','font-size','12',0,''),(606539,190943,'74218','origin','block_type','1',0,''),(606540,190943,'74218','origin','background-color','$content-bg-2',0,''),(606541,190944,'74219','origin','block_type','1',0,''),(606542,190944,'74219','origin','max-width','800',0,''),(606543,190944,'74219','origin','margin','0 auto',0,''),(606544,190945,'74220','origin','block_type','1',0,''),(606545,190945,'74220','origin','background-color','$content-bg-1',0,''),(606546,190945,'74220','origin','padding-top','20',0,''),(606547,190945,'74220','origin','padding-left','20',0,''),(606548,190945,'74220','origin','padding-right','20',0,''),(606549,190945,'74220','origin','padding-bottom','20',0,''),(606550,190946,'74221','origin','font-weight','normal',0,''),(606551,190946,'74221','origin','padding-top','20',0,''),(606552,190946,'74221','origin','padding-bottom','20',0,''),(606553,190946,'74221','origin','color','$content-color-1',0,''),(606554,190946,'74221','origin','font-size','14',0,''),(606555,190947,'74222','origin','block_type','7',0,''),(606556,190947,'74222','origin','font-weight','normal',0,''),(606557,190947,'74222','origin','padding-left','10',0,''),(606558,190947,'74222','origin','padding-right','10',0,''),(606559,190947,'74222','origin','padding-bottom','15',0,''),(606560,190947,'74222','origin','border-bottom-width','1',0,''),(606561,190947,'74222','origin','border-bottom-color','$content-border-1',0,''),(606562,190948,'74223','origin','color','$content-color-1',0,''),(606563,190948,'74223','origin','font-size','14',0,''),(606564,190948,'74223','origin','font-weight','700',0,''),(606565,190949,'74224','origin','font-weight','normal',0,''),(606566,190949,'74224','origin','text-align','right',0,''),(606567,190949,'74224','origin','color','$fade-color-1',0,''),(606568,190949,'74224','origin','font-size','11',0,''),(606569,190949,'74224','origin','text-transform','uppercase',0,''),(606570,190950,'74225','origin','color','$fade-color-1',0,''),(606571,190950,'74225','origin','font-size','12',0,''),(606572,190950,'74225','origin','padding-top','20',0,''),(606573,190950,'74225','origin','padding-bottom','20',0,''),(606574,190950,'74225','origin','text-align','center',0,''),(606575,190951,'74226','origin','font-weight','normal',0,''),(606576,190951,'74226','origin','padding-bottom','10',0,''),(606577,190951,'74226','origin','padding-top','10',0,''),(606578,190951,'74226','origin','text-align','center',0,''),(606579,190951,'74226','origin','logo_from','theme',0,''),(606580,190952,'74227','origin','block_type','1',0,''),(606581,190952,'74227','origin','background-color','$content-bg-2',0,''),(606582,190952,'74227','origin','padding-top','20',0,''),(606583,190952,'74227','origin','padding-bottom','20',0,''),(606584,190953,'74228','origin','block_type','1',0,''),(606585,190953,'74228','origin','max-width','800',0,''),(606586,190953,'74228','origin','margin','0 auto',0,''),(606587,190954,'74229','origin','color','$fade-color-1',0,''),(606588,190954,'74229','origin','font-size','12',0,''),(606589,190954,'74229','origin','padding-top','20',0,''),(606590,190954,'74229','origin','padding-bottom','20',0,''),(606591,190954,'74229','origin','text-align','left',0,''),(606592,190955,'74230','origin','block_type','1',0,''),(606593,190955,'74230','origin','background-color','$content-bg-1',0,''),(606594,190955,'74230','origin','padding-top','20',0,''),(606595,190955,'74230','origin','padding-left','20',0,''),(606596,190955,'74230','origin','padding-right','20',0,''),(606597,190955,'74230','origin','padding-bottom','20',0,''),(606598,190955,'74230','origin','border-top-width','1',0,''),(606599,190955,'74230','origin','border-left-width','1',0,''),(606600,190955,'74230','origin','border-right-width','1',0,''),(606601,190955,'74230','origin','border-bottom-width','1',0,''),(606602,190955,'74230','origin','border-top-color','$content-border-1',0,''),(606603,190955,'74230','origin','border-left-color','$content-border-1',0,''),(606604,190955,'74230','origin','border-bottom-color','$content-border-1',0,''),(606605,190955,'74230','origin','border-right-color','$content-border-1',0,''),(606606,190956,'74231','origin','block_type','2',0,''),(606607,190957,'74232','origin','font-weight','normal',0,''),(606608,190957,'74232','origin','padding-bottom','10',0,''),(606609,190957,'74232','origin','padding-top','10',0,''),(606610,190957,'74232','origin','logo_from','theme',0,''),(606611,190958,'74233','origin','font-weight','normal',0,''),(606612,190958,'74233','origin','text-align','right',0,''),(606613,190958,'74233','origin','color','$fade-color-1',0,''),(606614,190958,'74233','origin','font-size','11',0,''),(606615,190958,'74233','origin','text-transform','uppercase',0,''),(606616,190959,'74234','origin','color','$content-color-1',0,''),(606617,190959,'74234','origin','font-size','14',0,''),(606618,190959,'74234','origin','font-weight','700',0,''),(606619,190959,'74234','origin','text-align','right',0,''),(606620,190960,'74235','origin','font-weight','normal',0,''),(606621,190960,'74235','origin','padding-top','20',0,''),(606622,190960,'74235','origin','padding-bottom','20',0,''),(606623,190960,'74235','origin','color','$content-color-1',0,''),(606624,190960,'74235','origin','font-size','14',0,''),(606625,190961,'74236','origin','block_type','1',0,''),(606626,190961,'74236','origin','font-weight','normal',0,''),(606627,190961,'74236','origin','padding-top','20',0,''),(606628,190961,'74236','origin','background-color','$footer-bg-1',0,''),(606629,190961,'74236','origin','color','$footer-color-1',0,''),(606630,190962,'74237','origin','block_type','14',0,''),(606631,190962,'74237','origin','margin-bottom','15',0,''),(606632,190962,'74237','origin','schema','14-2',0,'8356'),(606633,190962,'74237','origin','schema','14-3',0,'8349'),(606634,190962,'74237','origin','style_class','preFooter',0,''),(606635,190962,'74237','origin','visibility_checkout','1',0,''),(606636,190963,'74238','origin','block_type','1',0,''),(606637,190964,'74239','origin','class','menu-style-2',0,''),(606638,190965,'1695906739.5696','origin','text','##NAVBAR_TITLE_ACCOUNT##',0,''),(606639,190965,'1695906739.5696','origin','style_class','footerTitle',0,''),(606640,190965,'1695906739.5696','origin','font-family','$font-1',0,''),(606641,190965,'1695906739.5696','origin','font-size','20',0,''),(606642,190965,'1695906739.5696','origin','text-transform','uppercase',0,''),(606643,190966,'74241','origin','block_type','1',0,''),(606644,190967,'74243','origin','class','menu-style-2',0,''),(606645,190968,'1695906751.0591','origin','text','##TEXT_PRODUCTS##',0,''),(606646,190968,'1695906751.0591','origin','font-family','$font-1',0,''),(606647,190968,'1695906751.0591','origin','font-size','20',0,''),(606648,190968,'1695906751.0591','origin','text-transform','uppercase',0,''),(606649,190968,'1695906751.0591','origin','style_class','footerTitle',0,''),(606650,190969,'74244','origin','block_type','1',0,''),(606651,190970,'74246','origin','class','menu-style-2',0,''),(606652,190971,'1695906756.0887','origin','text','##TEXT_SHOP##',0,''),(606653,190971,'1695906756.0887','origin','style_class','footerTitle',0,''),(606654,190971,'1695906756.0887','origin','font-family','$font-1',0,''),(606655,190971,'1695906756.0887','origin','font-size','20',0,''),(606656,190971,'1695906756.0887','origin','text-transform','uppercase',0,''),(606657,190972,'74247','origin','block_type','1',0,''),(606658,190973,'74248','origin','view_item','phone_number',0,''),(606659,190974,'74249','origin','view_item','address',0,''),(606660,190974,'74249','origin','address_spacer',',<span> </span>',0,''),(606661,190975,'1695906761.6568','origin','text','##TEXT_CONTACT##',0,''),(606662,190975,'1695906761.6568','origin','font-family','$font-1',0,''),(606663,190975,'1695906761.6568','origin','font-size','20',0,''),(606664,190975,'1695906761.6568','origin','text-transform','uppercase',0,''),(606665,190975,'1695906761.6568','origin','style_class','footerTitle',0,''),(606666,190976,'74256','origin','block_type','2',0,''),(606667,190976,'74256','origin','font-weight','400',0,''),(606668,190976,'74256','origin','padding-top','20',0,''),(606669,190976,'74256','origin','padding-bottom','20',0,''),(606670,190976,'74256','origin','schema','2-2',0,''),(606671,190976,'74256','origin','schema','2-3',0,'8356'),(606672,190978,'74258','origin','address_spacer',', ',0,''),(606673,190978,'74258','origin','font-weight','400',0,''),(606674,190978,'74258','origin','padding-bottom','10',0,'8356'),(606675,190978,'74258','origin','margin-bottom','10',0,'8356'),(606676,190978,'74258','origin','border-bottom-width','1',0,'8356'),(606677,190978,'74258','origin','border-bottom-color','$content-border-1',0,'8356'),(606678,190979,'94723','origin','block_type','5',0,''),(606679,190980,'94724','origin','text','##TEXT_LANGUAGE##',0,''),(606680,190982,'94726','origin','block_type','5',0,''),(606681,190983,'94727','origin','text','##TEXT_CURRENCY##',0,''),(606682,190985,'74263','origin','block_type','1',0,''),(606683,190985,'74263','origin','font-weight','normal',0,''),(606684,190986,'74264','origin','block_type','2',0,''),(606685,190986,'74264','origin','font-weight','normal',0,''),(606686,190986,'74264','origin','padding-bottom','20',0,''),(606687,190987,'74265','origin','block_type','1',0,''),(606688,190987,'74265','origin','margin-right','20',0,''),(606689,190990,'74268','origin','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(606690,190990,'74268','origin','font-weight','normal',0,''),(606691,190990,'74268','origin','padding-bottom','20',0,''),(606692,190990,'74268','origin','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',0,''),(606693,190992,'74270','origin','block_type','1',0,''),(606694,190992,'74270','origin','font-weight','normal',0,''),(606695,190992,'74270','origin','style_class','gift-card-view',0,''),(606696,190992,'74270','origin','text-align','center',0,''),(606697,190992,'74270','origin','padding-bottom','20',0,''),(606698,190992,'74270','origin','background-color','$highlight-box-bg-1',0,''),(606699,190992,'74270','origin','padding-left','20',0,''),(606700,190992,'74270','origin','padding-right','20',0,''),(606701,190992,'74270','origin','color','$highlight-box-color-1',0,''),(606702,190993,'74271','origin','block_type','1',0,''),(606703,190993,'74271','origin','font-weight','normal',0,''),(606704,190993,'74271','origin','padding-top','10',0,''),(606705,190994,'74272','origin','font-size','12',0,''),(606706,190994,'74272','origin','font-weight','bold',0,''),(606707,190994,'74272','origin','text-align','center',0,''),(606708,190994,'74272','origin','style_class','email',0,''),(606709,190995,'74273','origin','text','<p>If you require further assistance please contact us</p>',1,''),(606710,190995,'74273','origin','font-weight','normal',0,''),(606711,190995,'74273','origin','text-align','center',0,''),(606712,190995,'74273','origin','font-size','12',0,''),(606713,190995,'74273','origin','padding-top','10',0,''),(606714,190995,'74273','origin','padding-bottom','5',0,''),(606715,190995,'74273','origin','border-top-width','1',0,''),(606716,190995,'74273','origin','border-top-color','$content-border-3',0,''),(606717,190995,'74273','origin','text','<p>If you require further assistance please contact us</p>',0,''),(606718,190996,'74274','origin','font-size','12',0,''),(606719,190996,'74274','origin','font-weight','bold',0,''),(606720,190996,'74274','origin','text-align','center',0,''),(606721,190996,'74274','origin','style_class','phone',0,''),(606722,190996,'74274','origin','padding-bottom','5',0,''),(606723,190997,'74275','origin','text','<p>WHAT TO DO NEXT:</p>',1,''),(606724,190997,'74275','origin','font-weight','normal',0,''),(606725,190997,'74275','origin','text-align','center',0,''),(606726,190997,'74275','origin','padding-top','20',0,''),(606727,190997,'74275','origin','padding-bottom','10',0,''),(606728,190997,'74275','origin','style_class','question-ico',0,''),(606729,190997,'74275','origin','border-top-width','1',0,''),(606730,190997,'74275','origin','border-top-color','$content-border-3',0,''),(606731,190997,'74275','origin','font-size','18',0,''),(606732,190997,'74275','origin','text','<p>WHAT TO DO NEXT:</p>',0,''),(606733,190998,'74276','origin','text','<p>osCommerce</p>\n',1,''),(606734,190998,'74276','origin','font-family','$font-1',0,''),(606735,190998,'74276','origin','font-size','24',0,''),(606736,190998,'74276','origin','font-weight','normal',0,''),(606737,190998,'74276','origin','text-align','center',0,''),(606738,190998,'74276','origin','padding-top','10',0,''),(606739,190998,'74276','origin','padding-bottom','20',0,''),(606740,190998,'74276','origin','text','<p>osCommerce</p>\n',0,''),(606741,190999,'74277','origin','block_type','4',0,''),(606742,190999,'74277','origin','color','$highlight-box-color-2',0,''),(606743,190999,'74277','origin','font-size','30',0,''),(606744,190999,'74277','origin','font-weight','normal',0,''),(606745,190999,'74277','origin','background-color','$highlight-box-bg-2',0,''),(606746,190999,'74277','origin','padding-top','5',0,''),(606747,190999,'74277','origin','padding-left','10',0,''),(606748,190999,'74277','origin','padding-right','10',0,''),(606749,190999,'74277','origin','padding-bottom','5',0,''),(606750,191000,'74278','origin','text','<p>Your code is:</p>',1,''),(606751,191000,'74278','origin','font-weight','normal',0,''),(606752,191000,'74278','origin','text','<p>Your code is:</p>',0,''),(606753,191002,'74280','origin','font-weight','normal',0,''),(606754,191002,'74280','origin','text-align','center',0,''),(606755,191002,'74280','origin','padding-bottom','20',0,''),(606756,191003,'74281','origin','font-size','60',0,''),(606757,191003,'74281','origin','font-weight','bold',0,''),(606758,191003,'74281','origin','text-align','center',0,''),(606759,191003,'74281','origin','line-height','100',0,''),(606760,191003,'74281','origin','padding-bottom','20',0,''),(606761,191003,'74281','origin','line_height_measure','px',0,''),(606762,191004,'74282','origin','text','<p>PERSONAL MESSAGE</p>',1,''),(606763,191004,'74282','origin','font-size','18',0,''),(606764,191004,'74282','origin','font-weight','normal',0,''),(606765,191004,'74282','origin','text-align','center',0,''),(606766,191004,'74282','origin','padding-top','20',0,''),(606767,191004,'74282','origin','padding-bottom','10',0,''),(606768,191004,'74282','origin','border-top-width','1',0,''),(606769,191004,'74282','origin','border-top-color','$content-border-3',0,''),(606770,191004,'74282','origin','text','<p>PERSONAL MESSAGE</p>',0,''),(606771,191005,'74284','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',1,''),(606772,191005,'74284','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',0,''),(606773,191005,'74284','origin','text-align','center',0,''),(606774,191005,'74284','origin','padding-top','20',0,''),(606775,191005,'74284','origin','logo_from','theme',0,''),(606776,191006,'74285','origin','text','<p>GIFT CARD</p>',1,''),(606777,191006,'74285','origin','font-size','30',0,''),(606778,191006,'74285','origin','font-weight','normal',0,''),(606779,191006,'74285','origin','border-top-width','1',0,''),(606780,191006,'74285','origin','border-top-color','$content-border-3',0,''),(606781,191006,'74285','origin','style_class','gift-ico',0,''),(606782,191006,'74285','origin','text-align','center',0,''),(606783,191006,'74285','origin','padding-top','15',0,''),(606784,191006,'74285','origin','text','<p>GIFT CARD</p>',0,''),(606785,191007,'74286','origin','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(606786,191007,'74286','origin','font-weight','normal',0,''),(606787,191007,'74286','origin','text-align','center',0,''),(606788,191007,'74286','origin','padding-bottom','10',0,''),(606789,191007,'74286','origin','font-size','14',0,''),(606790,191007,'74286','origin','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',0,''),(606791,191008,'74287','origin','block_type','1',0,''),(606792,191008,'74287','origin','font-weight','normal',0,''),(606793,191008,'74287','origin','style_class','gift-card-view',0,''),(606794,191008,'74287','origin','text-align','center',0,''),(606795,191008,'74287','origin','padding-bottom','20',0,''),(606796,191008,'74287','origin','background-color','$content-bg-2',0,''),(606797,191008,'74287','origin','padding-left','20',0,''),(606798,191008,'74287','origin','padding-right','20',0,''),(606799,191008,'74287','origin','color','$fade-color-2',0,''),(606800,191009,'74288','origin','font-size','60',0,''),(606801,191009,'74288','origin','font-weight','bold',0,''),(606802,191009,'74288','origin','text-align','center',0,''),(606803,191009,'74288','origin','line-height','100',0,''),(606804,191009,'74288','origin','padding-bottom','20',0,''),(606805,191009,'74288','origin','line_height_measure','px',0,''),(606806,191010,'74289','origin','block_type','4',0,''),(606807,191010,'74289','origin','color','$highlight-box-color-2',0,''),(606808,191010,'74289','origin','font-size','30',0,''),(606809,191010,'74289','origin','font-weight','normal',0,''),(606810,191010,'74289','origin','background-color','$highlight-box-bg-2',0,''),(606811,191010,'74289','origin','padding-top','5',0,''),(606812,191010,'74289','origin','padding-left','10',0,''),(606813,191010,'74289','origin','padding-right','10',0,''),(606814,191010,'74289','origin','padding-bottom','5',0,''),(606815,191011,'74290','origin','text','<p>Your code is:</p>',1,''),(606816,191011,'74290','origin','font-weight','normal',0,''),(606817,191011,'74290','origin','text','<p>Your code is:</p>',0,''),(606818,191013,'74292','origin','block_type','1',0,''),(606819,191013,'74292','origin','font-weight','normal',0,''),(606820,191013,'74292','origin','padding-top','10',0,''),(606821,191014,'74293','origin','font-size','12',0,''),(606822,191014,'74293','origin','font-weight','bold',0,''),(606823,191014,'74293','origin','text-align','center',0,''),(606824,191014,'74293','origin','style_class','email',0,''),(606825,191015,'74294','origin','text','<p>If you require further assistance please contact us</p>',1,''),(606826,191015,'74294','origin','font-weight','normal',0,''),(606827,191015,'74294','origin','text-align','center',0,''),(606828,191015,'74294','origin','font-size','12',0,''),(606829,191015,'74294','origin','padding-top','10',0,''),(606830,191015,'74294','origin','padding-bottom','5',0,''),(606831,191015,'74294','origin','border-top-width','1',0,''),(606832,191015,'74294','origin','border-top-color','$content-border-3',0,''),(606833,191015,'74294','origin','text','<p>If you require further assistance please contact us</p>',0,''),(606834,191016,'74295','origin','font-size','12',0,''),(606835,191016,'74295','origin','font-weight','bold',0,''),(606836,191016,'74295','origin','text-align','center',0,''),(606837,191016,'74295','origin','style_class','phone',0,''),(606838,191016,'74295','origin','padding-bottom','5',0,''),(606839,191017,'74296','origin','font-weight','normal',0,''),(606840,191017,'74296','origin','text-align','center',0,''),(606841,191017,'74296','origin','padding-bottom','20',0,''),(606842,191018,'74297','origin','text','<p>PERSONAL MESSAGE</p>',1,''),(606843,191018,'74297','origin','font-size','18',0,''),(606844,191018,'74297','origin','font-weight','normal',0,''),(606845,191018,'74297','origin','text-align','center',0,''),(606846,191018,'74297','origin','padding-top','20',0,''),(606847,191018,'74297','origin','padding-bottom','10',0,''),(606848,191018,'74297','origin','border-top-width','1',0,''),(606849,191018,'74297','origin','border-top-color','$content-border-3',0,''),(606850,191018,'74297','origin','text','<p>PERSONAL MESSAGE</p>',0,''),(606851,191019,'74298','origin','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(606852,191019,'74298','origin','font-weight','normal',0,''),(606853,191019,'74298','origin','text-align','center',0,''),(606854,191019,'74298','origin','padding-bottom','10',0,''),(606855,191019,'74298','origin','font-size','14',0,''),(606856,191019,'74298','origin','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',0,''),(606857,191020,'74299','origin','text','<p>GIFT CARD</p>',1,''),(606858,191020,'74299','origin','font-size','30',0,''),(606859,191020,'74299','origin','font-weight','normal',0,''),(606860,191020,'74299','origin','border-top-width','1',0,''),(606861,191020,'74299','origin','border-top-color','$content-border-3',0,''),(606862,191020,'74299','origin','style_class','gift-ico',0,''),(606863,191020,'74299','origin','text-align','center',0,''),(606864,191020,'74299','origin','padding-top','15',0,''),(606865,191020,'74299','origin','text','<p>GIFT CARD</p>',0,''),(606866,191021,'74300','origin','text','<p>WHAT TO DO NEXT:</p>',1,''),(606867,191021,'74300','origin','font-weight','normal',0,''),(606868,191021,'74300','origin','text-align','center',0,''),(606869,191021,'74300','origin','padding-top','20',0,''),(606870,191021,'74300','origin','padding-bottom','10',0,''),(606871,191021,'74300','origin','style_class','question-ico',0,''),(606872,191021,'74300','origin','border-top-width','1',0,''),(606873,191021,'74300','origin','border-top-color','$content-border-3',0,''),(606874,191021,'74300','origin','font-size','18',0,''),(606875,191021,'74300','origin','text','<p>WHAT TO DO NEXT:</p>',0,''),(606876,191022,'74301','origin','text','<p>HOLBI</p>',1,''),(606877,191022,'74301','origin','font-family','$font-1',0,''),(606878,191022,'74301','origin','font-size','24',0,''),(606879,191022,'74301','origin','font-weight','normal',0,''),(606880,191022,'74301','origin','text-align','center',0,''),(606881,191022,'74301','origin','padding-top','10',0,''),(606882,191022,'74301','origin','padding-bottom','20',0,''),(606883,191022,'74301','origin','text','<p>HOLBI</p>',0,''),(606884,191023,'94729','origin','block_type','1',0,''),(606885,191023,'94729','origin','font-weight','normal',0,''),(606886,191023,'94729','origin','style_class','gift-card-view',0,''),(606887,191023,'94729','origin','text-align','center',0,''),(606888,191023,'94729','origin','padding-bottom','20',0,''),(606889,191023,'94729','origin','background-color','$content-bg-2',0,''),(606890,191023,'94729','origin','padding-left','20',0,''),(606891,191023,'94729','origin','padding-right','20',0,''),(606892,191024,'94730','origin','block_type','1',0,''),(606893,191024,'94730','origin','font-weight','normal',0,''),(606894,191024,'94730','origin','padding-top','10',0,''),(606895,191025,'94731','origin','font-size','12',0,''),(606896,191025,'94731','origin','font-weight','bold',0,''),(606897,191025,'94731','origin','text-align','center',0,''),(606898,191025,'94731','origin','style_class','email',0,''),(606899,191026,'94732','origin','font-size','12',0,''),(606900,191026,'94732','origin','font-weight','bold',0,''),(606901,191026,'94732','origin','text-align','center',0,''),(606902,191026,'94732','origin','style_class','phone',0,''),(606903,191026,'94732','origin','padding-bottom','5',0,''),(606904,191027,'94733','origin','text','If you require further assistance please contact us',0,''),(606905,191027,'94733','origin','font-size','12',0,''),(606906,191027,'94733','origin','text-align','center',0,''),(606907,191027,'94733','origin','padding-top','10',0,''),(606908,191028,'94734','origin','block_type','4',0,''),(606909,191028,'94734','origin','color','$highlight-box-color-2',0,''),(606910,191028,'94734','origin','font-size','30',0,''),(606911,191028,'94734','origin','font-weight','normal',0,''),(606912,191028,'94734','origin','background-color','$highlight-box-bg-2',0,''),(606913,191028,'94734','origin','padding-top','5',0,''),(606914,191028,'94734','origin','padding-left','10',0,''),(606915,191028,'94734','origin','padding-right','10',0,''),(606916,191028,'94734','origin','padding-bottom','5',0,''),(606917,191029,'94735','origin','text','Your code is:',0,''),(606918,191029,'94735','origin','font-size','30',0,''),(606919,191029,'94735','origin','color','$highlight-box-color-2',0,''),(606920,191030,'94736','origin','color','$highlight-box-color-2',0,''),(606921,191030,'94736','origin','font-size','30',0,''),(606922,191031,'94737','origin','block_type','1',0,''),(606923,191032,'94738','origin','text','<p>PERSONAL MESSAGE</p>',1,''),(606924,191032,'94738','origin','font-size','18',0,''),(606925,191032,'94738','origin','font-weight','normal',0,''),(606926,191032,'94738','origin','text-align','center',0,''),(606927,191032,'94738','origin','padding-top','20',0,''),(606928,191032,'94738','origin','padding-bottom','10',0,''),(606929,191032,'94738','origin','border-top-width','1',0,''),(606930,191032,'94738','origin','border-top-color','$content-border-3',0,''),(606931,191032,'94738','origin','text','<p>PERSONAL MESSAGE</p>',0,''),(606932,191033,'94739','origin','text','HOLBI',0,''),(606933,191033,'94739','origin','font-size','24',0,''),(606934,191033,'94739','origin','padding-top','20',0,''),(606935,191033,'94739','origin','text-align','center',0,''),(606936,191033,'94739','origin','padding-bottom','20',0,''),(606937,191034,'94740','origin','border-top-color','$content-border-3',0,''),(606938,191034,'94740','origin','border-top-width','1',0,''),(606939,191034,'94740','origin','padding-top','20',0,''),(606940,191034,'94740','origin','font-size','30',0,''),(606941,191034,'94740','origin','text-align','center',0,''),(606942,191034,'94740','origin','text','GIFT CARD',0,''),(606943,191035,'94741','origin','text-align','center',0,''),(606944,191035,'94741','origin','font-weight','bold',0,''),(606945,191035,'94741','origin','font-size','60',0,''),(606946,191036,'94742','origin','font-size','20',0,''),(606947,191036,'94742','origin','text-align','center',0,''),(606948,191036,'94742','origin','padding-top','20',0,''),(606949,191036,'94742','origin','padding-bottom','20',0,''),(606950,191037,'94743','origin','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(606951,191037,'94743','origin','text-align','center',0,''),(606952,191037,'94743','origin','font-size','14',0,''),(606953,191037,'94743','origin','padding-bottom','20',0,''),(606954,191038,'94744','origin','text','WHAT TO DO NEXT:',0,''),(606955,191038,'94744','origin','font-size','18',0,''),(606956,191038,'94744','origin','text-align','center',0,''),(606957,191038,'94744','origin','padding-top','20',0,''),(606958,191038,'94744','origin','padding-bottom','10',0,''),(606959,191038,'94744','origin','border-top-width','1',0,''),(606960,191038,'94744','origin','border-top-color','$content-border-3',0,''),(606961,191039,'94746','origin','block_type','1',0,''),(606962,191039,'94746','origin','font-weight','normal',0,''),(606963,191039,'94746','origin','style_class','gift-card-view',0,''),(606964,191039,'94746','origin','text-align','center',0,''),(606965,191039,'94746','origin','padding-bottom','20',0,''),(606966,191039,'94746','origin','background-color','$highlight-box-bg-1',0,''),(606967,191039,'94746','origin','padding-left','20',0,''),(606968,191039,'94746','origin','padding-right','20',0,''),(606969,191039,'94746','origin','color','$highlight-box-color-1',0,''),(606970,191040,'94747','origin','block_type','1',0,''),(606971,191040,'94747','origin','font-weight','normal',0,''),(606972,191040,'94747','origin','padding-top','10',0,''),(606973,191041,'94748','origin','font-size','12',0,''),(606974,191041,'94748','origin','font-weight','bold',0,''),(606975,191041,'94748','origin','text-align','center',0,''),(606976,191041,'94748','origin','style_class','email',0,''),(606977,191041,'94748','origin','color','$highlight-box-color-1',0,''),(606978,191042,'94749','origin','font-size','12',0,''),(606979,191042,'94749','origin','font-weight','bold',0,''),(606980,191042,'94749','origin','text-align','center',0,''),(606981,191042,'94749','origin','style_class','phone',0,''),(606982,191042,'94749','origin','padding-bottom','5',0,''),(606983,191042,'94749','origin','color','$highlight-box-color-1',0,''),(606984,191043,'94750','origin','text','If you require further assistance please contact us',0,''),(606985,191043,'94750','origin','font-size','12',0,''),(606986,191043,'94750','origin','color','$highlight-box-color-1',0,''),(606987,191043,'94750','origin','text-align','center',0,''),(606988,191043,'94750','origin','padding-top','10',0,''),(606989,191044,'94751','origin','block_type','4',0,''),(606990,191044,'94751','origin','color','$highlight-box-color-2',0,''),(606991,191044,'94751','origin','font-size','30',0,''),(606992,191044,'94751','origin','font-weight','normal',0,''),(606993,191044,'94751','origin','background-color','$highlight-box-bg-2',0,''),(606994,191044,'94751','origin','padding-top','5',0,''),(606995,191044,'94751','origin','padding-left','10',0,''),(606996,191044,'94751','origin','padding-right','10',0,''),(606997,191044,'94751','origin','padding-bottom','5',0,''),(606998,191045,'94752','origin','text','Your code is:',0,''),(606999,191045,'94752','origin','font-size','30',0,''),(607000,191045,'94752','origin','color','$highlight-box-color-2',0,''),(607001,191046,'94753','origin','color','$highlight-box-color-2',0,''),(607002,191046,'94753','origin','font-size','30',0,''),(607003,191047,'94754','origin','block_type','1',0,''),(607004,191048,'94755','origin','text','<p>PERSONAL MESSAGE</p>',1,''),(607005,191048,'94755','origin','font-size','18',0,''),(607006,191048,'94755','origin','font-weight','normal',0,''),(607007,191048,'94755','origin','text-align','center',0,''),(607008,191048,'94755','origin','padding-top','20',0,''),(607009,191048,'94755','origin','padding-bottom','10',0,''),(607010,191048,'94755','origin','border-top-width','1',0,''),(607011,191048,'94755','origin','border-top-color','$content-border-3',0,''),(607012,191048,'94755','origin','text','<p>PERSONAL MESSAGE</p>',0,''),(607013,191049,'94757','origin','border-top-color','$content-border-3',0,''),(607014,191049,'94757','origin','border-top-width','1',0,''),(607015,191049,'94757','origin','padding-top','20',0,''),(607016,191049,'94757','origin','font-size','30',0,''),(607017,191049,'94757','origin','text-align','center',0,''),(607018,191049,'94757','origin','color','$highlight-box-color-1',0,''),(607019,191049,'94757','origin','text','GIFT CARD',0,''),(607020,191050,'94758','origin','text-align','center',0,''),(607021,191050,'94758','origin','font-weight','bold',0,''),(607022,191050,'94758','origin','font-size','60',0,''),(607023,191050,'94758','origin','color','$highlight-box-color-1',0,''),(607024,191051,'94759','origin','font-size','20',0,''),(607025,191051,'94759','origin','text-align','center',0,''),(607026,191051,'94759','origin','color','$highlight-box-color-1',0,''),(607027,191051,'94759','origin','padding-top','20',0,''),(607028,191051,'94759','origin','padding-bottom','20',0,''),(607029,191052,'94760','origin','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(607030,191052,'94760','origin','text-align','center',0,''),(607031,191052,'94760','origin','color','$highlight-box-color-1',0,''),(607032,191052,'94760','origin','font-size','14',0,''),(607033,191052,'94760','origin','padding-bottom','20',0,''),(607034,191053,'94761','origin','text','WHAT TO DO NEXT:',0,''),(607035,191053,'94761','origin','font-size','18',0,''),(607036,191053,'94761','origin','text-align','center',0,''),(607037,191053,'94761','origin','padding-top','20',0,''),(607038,191053,'94761','origin','padding-bottom','10',0,''),(607039,191053,'94761','origin','border-top-width','1',0,''),(607040,191053,'94761','origin','border-top-color','$content-border-3',0,''),(607041,191054,'1707902674.2595','origin','logo_from','theme',0,''),(607042,191054,'1707902674.2595','origin','text-align','center',0,''),(607043,191054,'1707902674.2595','origin','padding-top','20',0,''),(607044,191056,'74302','origin','block_type','1',0,''),(607045,191058,'74304','origin','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(607046,191058,'74304','origin','text-align','center',0,''),(607047,191059,'74305','origin','block_type','1',0,''),(607048,191059,'74305','origin','font-weight','normal',0,''),(607049,191059,'74305','origin','style_class','gift-card-view',0,''),(607050,191059,'74305','origin','text-align','center',0,''),(607051,191059,'74305','origin','padding-bottom','20',0,''),(607052,191059,'74305','origin','background-color','$highlight-box-bg-3',0,''),(607053,191059,'74305','origin','padding-left','20',0,''),(607054,191059,'74305','origin','padding-right','20',0,''),(607055,191059,'74305','origin','color','$highlight-box-color-3',0,''),(607056,191060,'74306','origin','block_type','4',0,''),(607057,191060,'74306','origin','color','$highlight-box-color-2',0,''),(607058,191060,'74306','origin','font-size','30',0,''),(607059,191060,'74306','origin','font-weight','normal',0,''),(607060,191060,'74306','origin','background-color','$highlight-box-bg-2',0,''),(607061,191060,'74306','origin','padding-top','5',0,''),(607062,191060,'74306','origin','padding-left','10',0,''),(607063,191060,'74306','origin','padding-right','10',0,''),(607064,191060,'74306','origin','padding-bottom','5',0,''),(607065,191061,'74307','origin','text','<p>Your code is:</p>',1,''),(607066,191061,'74307','origin','font-weight','normal',0,''),(607067,191061,'74307','origin','text','<p>Your code is:</p>',0,''),(607068,191063,'74309','origin','text','<p>WHAT TO DO NEXT:</p>',1,''),(607069,191063,'74309','origin','font-weight','normal',0,''),(607070,191063,'74309','origin','text-align','center',0,''),(607071,191063,'74309','origin','padding-top','20',0,''),(607072,191063,'74309','origin','padding-bottom','10',0,''),(607073,191063,'74309','origin','style_class','question-ico',0,''),(607074,191063,'74309','origin','border-top-width','1',0,''),(607075,191063,'74309','origin','border-top-color','$content-border-3',0,''),(607076,191063,'74309','origin','font-size','18',0,''),(607077,191063,'74309','origin','text','<p>WHAT TO DO NEXT:</p>',0,''),(607078,191064,'74310','origin','text','<p>osCommerce</p>\n',1,''),(607079,191064,'74310','origin','font-family','$font-1',0,''),(607080,191064,'74310','origin','font-size','24',0,''),(607081,191064,'74310','origin','font-weight','normal',0,''),(607082,191064,'74310','origin','text-align','center',0,''),(607083,191064,'74310','origin','padding-top','10',0,''),(607084,191064,'74310','origin','padding-bottom','20',0,''),(607085,191064,'74310','origin','text','<p>osCommerce</p>\n',0,''),(607086,191065,'74311','origin','block_type','1',0,''),(607087,191065,'74311','origin','font-weight','normal',0,''),(607088,191065,'74311','origin','padding-top','10',0,''),(607089,191066,'74312','origin','text','<p>If you require further assistance please contact us</p>',1,''),(607090,191066,'74312','origin','font-weight','normal',0,''),(607091,191066,'74312','origin','text-align','center',0,''),(607092,191066,'74312','origin','font-size','12',0,''),(607093,191066,'74312','origin','padding-top','10',0,''),(607094,191066,'74312','origin','padding-bottom','5',0,''),(607095,191066,'74312','origin','border-top-width','1',0,''),(607096,191066,'74312','origin','border-top-color','$content-border-3',0,''),(607097,191066,'74312','origin','text','<p>If you require further assistance please contact us</p>',0,''),(607098,191067,'74313','origin','font-size','12',0,''),(607099,191067,'74313','origin','font-weight','bold',0,''),(607100,191067,'74313','origin','text-align','center',0,''),(607101,191067,'74313','origin','style_class','email',0,''),(607102,191068,'74314','origin','font-size','12',0,''),(607103,191068,'74314','origin','font-weight','bold',0,''),(607104,191068,'74314','origin','text-align','center',0,''),(607105,191068,'74314','origin','style_class','phone',0,''),(607106,191068,'74314','origin','padding-bottom','5',0,''),(607107,191069,'74315','origin','font-weight','normal',0,''),(607108,191069,'74315','origin','text-align','center',0,''),(607109,191069,'74315','origin','padding-bottom','20',0,''),(607110,191070,'74316','origin','text','<p>GIFT CARD</p>',1,''),(607111,191070,'74316','origin','font-size','30',0,''),(607112,191070,'74316','origin','font-weight','normal',0,''),(607113,191070,'74316','origin','border-top-width','1',0,''),(607114,191070,'74316','origin','border-top-color','$content-border-3',0,''),(607115,191070,'74316','origin','style_class','gift-ico',0,''),(607116,191070,'74316','origin','text-align','center',0,''),(607117,191070,'74316','origin','padding-top','15',0,''),(607118,191070,'74316','origin','text','<p>GIFT CARD</p>',0,''),(607119,191071,'74317','origin','text','<p>PERSONAL MESSAGE</p>',1,''),(607120,191071,'74317','origin','font-size','18',0,''),(607121,191071,'74317','origin','font-weight','normal',0,''),(607122,191071,'74317','origin','text-align','center',0,''),(607123,191071,'74317','origin','padding-top','20',0,''),(607124,191071,'74317','origin','padding-bottom','10',0,''),(607125,191071,'74317','origin','border-top-width','1',0,''),(607126,191071,'74317','origin','border-top-color','$content-border-3',0,''),(607127,191071,'74317','origin','text','<p>PERSONAL MESSAGE</p>',0,''),(607128,191072,'74318','origin','font-size','60',0,''),(607129,191072,'74318','origin','font-weight','bold',0,''),(607130,191072,'74318','origin','text-align','center',0,''),(607131,191072,'74318','origin','line-height','100',0,''),(607132,191072,'74318','origin','padding-bottom','20',0,''),(607133,191072,'74318','origin','line_height_measure','px',0,''),(607134,191073,'74319','origin','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(607135,191073,'74319','origin','font-weight','normal',0,''),(607136,191073,'74319','origin','text-align','center',0,''),(607137,191073,'74319','origin','padding-bottom','10',0,''),(607138,191073,'74319','origin','font-size','14',0,''),(607139,191073,'74319','origin','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',0,''),(607140,191074,'94763','origin','block_type','1',0,''),(607141,191074,'94763','origin','font-weight','normal',0,''),(607142,191074,'94763','origin','style_class','gift-card-view',0,''),(607143,191074,'94763','origin','text-align','center',0,''),(607144,191074,'94763','origin','padding-bottom','20',0,''),(607145,191074,'94763','origin','background-color','$highlight-box-bg-3',0,''),(607146,191074,'94763','origin','padding-left','20',0,''),(607147,191074,'94763','origin','padding-right','20',0,''),(607148,191074,'94763','origin','color','$highlight-box-color-3',0,''),(607149,191075,'94764','origin','block_type','1',0,''),(607150,191075,'94764','origin','font-weight','normal',0,''),(607151,191075,'94764','origin','padding-top','10',0,''),(607152,191076,'94765','origin','font-size','12',0,''),(607153,191076,'94765','origin','font-weight','bold',0,''),(607154,191076,'94765','origin','text-align','center',0,''),(607155,191076,'94765','origin','style_class','email',0,''),(607156,191077,'94766','origin','font-size','12',0,''),(607157,191077,'94766','origin','font-weight','bold',0,''),(607158,191077,'94766','origin','text-align','center',0,''),(607159,191077,'94766','origin','style_class','phone',0,''),(607160,191077,'94766','origin','padding-bottom','5',0,''),(607161,191078,'94767','origin','text','If you require further assistance please contact us',0,''),(607162,191078,'94767','origin','font-size','12',0,''),(607163,191078,'94767','origin','text-align','center',0,''),(607164,191078,'94767','origin','padding-top','10',0,''),(607165,191079,'94768','origin','block_type','4',0,''),(607166,191079,'94768','origin','color','$highlight-box-color-2',0,''),(607167,191079,'94768','origin','font-size','30',0,''),(607168,191079,'94768','origin','font-weight','normal',0,''),(607169,191079,'94768','origin','background-color','$highlight-box-bg-2',0,''),(607170,191079,'94768','origin','padding-top','5',0,''),(607171,191079,'94768','origin','padding-left','10',0,''),(607172,191079,'94768','origin','padding-right','10',0,''),(607173,191079,'94768','origin','padding-bottom','5',0,''),(607174,191080,'94769','origin','text','Your code is:',0,''),(607175,191080,'94769','origin','font-size','30',0,''),(607176,191080,'94769','origin','color','$highlight-box-color-2',0,''),(607177,191081,'94770','origin','color','$highlight-box-color-2',0,''),(607178,191081,'94770','origin','font-size','30',0,''),(607179,191082,'94771','origin','block_type','1',0,''),(607180,191083,'94772','origin','text','<p>PERSONAL MESSAGE</p>',1,''),(607181,191083,'94772','origin','font-size','18',0,''),(607182,191083,'94772','origin','font-weight','normal',0,''),(607183,191083,'94772','origin','text-align','center',0,''),(607184,191083,'94772','origin','padding-top','20',0,''),(607185,191083,'94772','origin','padding-bottom','10',0,''),(607186,191083,'94772','origin','border-top-width','1',0,''),(607187,191083,'94772','origin','border-top-color','$content-border-3',0,''),(607188,191083,'94772','origin','text','<p>PERSONAL MESSAGE</p>',0,''),(607189,191084,'94773','origin','text','HOLBI',0,''),(607190,191084,'94773','origin','color','$highlight-box-color-3',0,''),(607191,191084,'94773','origin','font-size','24',0,''),(607192,191084,'94773','origin','padding-top','20',0,''),(607193,191084,'94773','origin','text-align','center',0,''),(607194,191084,'94773','origin','padding-bottom','20',0,''),(607195,191085,'94774','origin','border-top-color','$content-border-3',0,''),(607196,191085,'94774','origin','border-top-width','1',0,''),(607197,191085,'94774','origin','padding-top','20',0,''),(607198,191085,'94774','origin','font-size','30',0,''),(607199,191085,'94774','origin','text-align','center',0,''),(607200,191085,'94774','origin','color','$highlight-box-color-3',0,''),(607201,191085,'94774','origin','text','GIFT CARD',0,''),(607202,191086,'94775','origin','text-align','center',0,''),(607203,191086,'94775','origin','font-weight','bold',0,''),(607204,191086,'94775','origin','font-size','60',0,''),(607205,191086,'94775','origin','color','$highlight-box-color-3',0,''),(607206,191087,'94776','origin','font-size','20',0,''),(607207,191087,'94776','origin','text-align','center',0,''),(607208,191087,'94776','origin','padding-top','20',0,''),(607209,191087,'94776','origin','padding-bottom','20',0,''),(607210,191088,'94777','origin','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(607211,191088,'94777','origin','text-align','center',0,''),(607212,191088,'94777','origin','font-size','14',0,''),(607213,191088,'94777','origin','padding-bottom','20',0,''),(607214,191089,'94778','origin','text','WHAT TO DO NEXT:',0,''),(607215,191089,'94778','origin','font-size','18',0,''),(607216,191089,'94778','origin','text-align','center',0,''),(607217,191089,'94778','origin','padding-top','20',0,''),(607218,191089,'94778','origin','padding-bottom','10',0,''),(607219,191089,'94778','origin','border-top-width','1',0,''),(607220,191089,'94778','origin','border-top-color','$content-border-3',0,''),(607221,191090,'1713770938.449798','origin','from_file','header_1.zip',0,''),(607222,191091,'1713770938.464587','origin','block_type','1',0,''),(607223,191091,'1713770938.464587','origin','border-bottom-width','1',0,''),(607224,191091,'1713770938.464587','origin','border-bottom-color','$header-border-1',0,''),(607225,191091,'1713770938.464587','origin','font-weight','normal',0,''),(607226,191091,'1713770938.464587','origin','visibility_checkout','1',0,''),(607227,191091,'1713770938.464587','origin','background-color','$header-bg-1',0,''),(607228,191091,'1713770938.464587','origin','color','$header-color-1',0,''),(607229,191091,'1713770938.464587','origin','from_file','header_1.zip',0,''),(607230,191092,'1713770938.467593','origin','block_type','5',0,''),(607231,191092,'1713770938.467593','origin','font-weight','400',0,''),(607232,191092,'1713770938.467593','origin','schema','2-2',0,''),(607233,191092,'1713770938.467593','origin','schema','5-2',0,'8356'),(607234,191092,'1713770938.467593','origin','schema','5-1',0,'8377'),(607235,191093,'1713770938.470248','origin','class','menu-horizontal',0,''),(607236,191093,'1713770938.470248','origin','box_align','1',0,''),(607237,191093,'1713770938.470248','origin','font-weight','400',0,''),(607238,191093,'1713770938.470248','origin','border-top-width','1',0,'8356'),(607239,191093,'1713770938.470248','origin','border-top-color','$content-border-1',0,'8356'),(607240,191093,'1713770938.470248','origin','display','none',0,'8356'),(607241,191094,'1713770938.51635','origin','block_type','1',0,''),(607242,191095,'1713770938.51828','origin','font-weight','400',0,''),(607243,191095,'1713770938.51828','origin','box_align','3',0,''),(607244,191095,'1713770938.51828','origin','show_products','dropdown',0,''),(607245,191095,'1713770938.51828','origin','only_icon','on',0,''),(607246,191096,'1713770938.573998','origin','font-weight','normal',0,''),(607247,191096,'1713770938.573998','origin','box_align','3',0,''),(607248,191096,'1713770938.573998','origin','border-left-width','1',0,''),(607249,191096,'1713770938.573998','origin','border-left-color','$header-border-1',0,''),(607250,191096,'1713770938.573998','origin','only_icon','on',0,''),(607251,191097,'1713770938.61982','origin','box_align','3',0,''),(607252,191097,'1713770938.61982','origin','font-weight','normal',0,''),(607253,191097,'1713770938.61982','origin','padding-top','0',0,'8356'),(607254,191097,'1713770938.61982','origin','padding-right','0',0,'8356'),(607255,191097,'1713770938.61982','origin','padding-bottom','0',0,'8356'),(607256,191097,'1713770938.61982','origin','padding-left','0',0,'8356'),(607257,191097,'1713770938.61982','origin','show_symbol_left','1',0,''),(607258,191097,'1713770938.61982','origin','show_symbol_right','1',0,''),(607259,191098,'1713770938.663457','origin','box_align','3',0,''),(607260,191098,'1713770938.663457','origin','font-weight','normal',0,''),(607261,191098,'1713770938.663457','origin','border-left-width','1',0,''),(607262,191098,'1713770938.663457','origin','border-left-color','$header-border-1',0,''),(607263,191098,'1713770938.663457','origin','padding-top','0',0,'8356'),(607264,191098,'1713770938.663457','origin','padding-right','0',0,'8356'),(607265,191098,'1713770938.663457','origin','padding-bottom','0',0,'8356'),(607266,191098,'1713770938.663457','origin','padding-left','0',0,'8356'),(607267,191098,'1713770938.663457','origin','show_title','1',0,''),(607268,191099,'1713770938.697915','origin','block_type','1',0,''),(607269,191099,'1713770938.697915','origin','padding-top','20',0,''),(607270,191099,'1713770938.697915','origin','padding-bottom','20',0,''),(607271,191099,'1713770938.697915','origin','style_class','header-content',0,''),(607272,191099,'1713770938.697915','origin','color','$header-color-1',0,''),(607273,191099,'1713770938.697915','origin','background-color','$header-bg-1',0,''),(607274,191099,'1713770938.697915','origin','from_file','header_1.zip',0,''),(607275,191099,'1713770938.697915','origin','padding-top','12',0,'8349'),(607276,191099,'1713770938.697915','origin','padding-bottom','12',0,'8349'),(607277,191100,'1713770938.706821','origin','font-weight','400',0,''),(607278,191100,'1713770938.706821','origin','box_align','1',0,''),(607279,191100,'1713770938.706821','origin','text-align','center',0,'8377'),(607280,191100,'1713770938.706821','origin','width','100',0,'8377'),(607281,191100,'1713770938.706821','origin','width_measure','%',0,'8377'),(607282,191100,'1713770938.706821','origin','logo_from','theme',0,''),(607283,191100,'1713770938.706821','origin','padding-right','20',0,''),(607284,191101,'1713770938.709156','origin','visibility_checkout','1',0,''),(607285,191101,'1713770938.709156','origin','search_history','1',0,''),(607286,191101,'1713770938.709156','origin','history_items','5',0,''),(607287,191101,'1713770938.709156','origin','margin-left','20',0,''),(607288,191102,'1713770938.773998','origin','text','<p class=\"customer-service\">Customer service <b>08000112569</b></p>',1,''),(607289,191102,'1713770938.773998','origin','float','right',0,''),(607290,191102,'1713770938.773998','origin','display_none','1',0,'8377'),(607291,191102,'1713770938.773998','origin','text','<p class=\"customer-service\">Customer service <b>08000112569</b></p>',0,''),(607292,191102,'1713770938.773998','origin','display','none',0,'8356'),(607293,191102,'1713770938.773998','origin','margin-left','20',0,''),(607294,191103,'1713770938.811953','origin','block_type','1',0,''),(607295,191103,'1713770938.811953','origin','font-weight','400',0,''),(607296,191103,'1713770938.811953','origin','background-color','$header-menu-bg-1',0,''),(607297,191103,'1713770938.811953','origin','visibility_checkout','1',0,''),(607298,191103,'1713770938.811953','origin','color','$header-menu-color-1',0,''),(607299,191103,'1713770938.811953','origin','from_file','header_1.zip',0,''),(607300,191103,'1713770938.811953','origin','style_class','header-menu-holder',0,''),(607301,191104,'1713770938.81834','origin','class','menu-style-1',0,''),(607302,191104,'1713770938.81834','origin','box_align','4',0,''),(607303,191104,'1713770938.81834','origin','font-weight','400',0,''),(607304,191104,'1713770938.81834','origin','hide_menu','on',0,''),(607305,191104,'1713770938.81834','origin','color','$header-menu-color-1',0,''),(607306,191104,'1713770938.81834','origin','hide_menu','1',0,'8356'),(607307,191104,'1713770938.81834','origin','show_new','1',0,''),(607308,191104,'1713770938.81834','origin','style_class','header-menu',0,''),(607309,191104,'1713770938.81834','origin','type','builder',0,''),(607310,191104,'1713770938.81834','origin','position','horizontal_center',0,'8422'),(607311,191104,'1713770938.81834','origin','style','1',0,'8422'),(607312,191104,'1713770938.81834','origin','lev2_vis','over',0,'8422'),(607313,191104,'1713770938.81834','origin','lev2_display','down',0,'8422'),(607314,191104,'1713770938.81834','origin','lev3_vis','over',0,'8422'),(607315,191104,'1713770938.81834','origin','lev4_vis','over',0,'8422'),(607316,191104,'1713770938.81834','origin','lev5_vis','over',0,'8422'),(607317,191104,'1713770938.81834','origin','lev6_vis','over',0,'8422'),(607318,191104,'1713770938.81834','origin','lev3_display','lra',0,'8422'),(607319,191104,'1713770938.81834','origin','lev4_display','lra',0,'8422'),(607320,191104,'1713770938.81834','origin','lev5_display','lra',0,'8422'),(607321,191104,'1713770938.81834','origin','lev6_display','lra',0,'8422'),(607322,191104,'1713770938.81834','origin','style','2',0,'8356'),(607323,191104,'1713770938.81834','origin','burger_icon','1',0,'8356'),(607324,191104,'1713770938.81834','origin','open_from','top',0,'8356'),(607325,191104,'1713770938.81834','origin','lev2_vis','click',0,'8356'),(607326,191104,'1713770938.81834','origin','lev3_vis','click',0,'8356'),(607327,191104,'1713770938.81834','origin','lev4_vis','click',0,'8356'),(607328,191104,'1713770938.81834','origin','lev5_vis','click',0,'8356'),(607329,191104,'1713770938.81834','origin','lev6_vis','click',0,'8356'),(607330,191104,'1713770938.81834','origin','from_file','menu_1.zip',0,''),(607331,191105,'74346','origin','block_type','1',0,''),(607332,191110,'74351','origin','width','680',0,''),(607333,191110,'74351','origin','font-weight','normal',0,''),(607334,191110,'74351','origin','font-size','12',0,''),(607335,191110,'74351','origin','padding-top','20',0,''),(607336,191110,'74351','origin','padding-bottom','20',0,''),(607337,191110,'74351','origin','color','$content-color-1',0,''),(607338,191111,'74352','origin','block_type','4',0,''),(607339,191111,'74352','origin','font-weight','normal',0,''),(607340,191111,'74352','origin','border-top-width','1',0,''),(607341,191111,'74352','origin','border-top-color','$content-border-1',0,''),(607342,191111,'74352','origin','border-left-width','1',0,''),(607343,191111,'74352','origin','border-left-color','$content-border-1',0,''),(607344,191111,'74352','origin','border-right-width','1',0,''),(607345,191111,'74352','origin','border-right-color','$content-border-1',0,''),(607346,191111,'74352','origin','border-bottom-width','1',0,''),(607347,191111,'74352','origin','border-bottom-color','$content-border-1',0,''),(607348,191112,'74353','origin','block_type','2',0,''),(607349,191112,'74353','origin','font-weight','normal',0,''),(607350,191112,'74353','origin','border-top-width','1',0,''),(607351,191112,'74353','origin','border-top-color','$content-border-1',0,''),(607352,191112,'74353','origin','border-right-width','1',0,''),(607353,191112,'74353','origin','border-right-color','$content-border-1',0,''),(607354,191113,'74354','origin','block_type','1',0,''),(607355,191113,'74354','origin','font-weight','normal',0,''),(607356,191113,'74354','origin','padding-top','10',0,''),(607357,191113,'74354','origin','padding-left','10',0,''),(607358,191113,'74354','origin','padding-right','10',0,''),(607359,191113,'74354','origin','padding-bottom','10',0,''),(607360,191113,'74354','origin','border-right-width','1',0,''),(607361,191113,'74354','origin','border-right-color','$content-border-1',0,''),(607362,191115,'74356','origin','text','<p>Shipping via</p>',1,''),(607363,191115,'74356','origin','font-weight','bold',0,''),(607364,191115,'74356','origin','font-size','14',0,''),(607365,191115,'74356','origin','text','<p>Shipping via</p>',0,''),(607366,191116,'74357','origin','block_type','1',0,''),(607367,191116,'74357','origin','font-weight','normal',0,''),(607368,191116,'74357','origin','padding-top','10',0,''),(607369,191116,'74357','origin','padding-left','10',0,''),(607370,191116,'74357','origin','padding-right','10',0,''),(607371,191116,'74357','origin','padding-bottom','10',0,''),(607372,191117,'74358','origin','text','<p>Shipping service</p>',1,''),(607373,191117,'74358','origin','font-weight','bold',0,''),(607374,191117,'74358','origin','font-size','14',0,''),(607375,191117,'74358','origin','text','<p>Shipping service</p>',0,''),(607376,191119,'74360','origin','block_type','2',0,''),(607377,191119,'74360','origin','font-weight','normal',0,''),(607378,191119,'74360','origin','border-right-width','1',0,''),(607379,191119,'74360','origin','border-right-color','$content-border-1',0,''),(607380,191120,'74361','origin','block_type','1',0,''),(607381,191120,'74361','origin','font-weight','400',0,''),(607382,191120,'74361','origin','background-color','$content-bg-2',0,''),(607383,191120,'74361','origin','padding-top','10',0,''),(607384,191120,'74361','origin','padding-left','10',0,''),(607385,191120,'74361','origin','padding-right','10',0,''),(607386,191120,'74361','origin','padding-bottom','30',0,''),(607387,191121,'74362','origin','text','<p>INVOICE ADDRESS:</p>',1,''),(607388,191121,'74362','origin','font-size','14',0,''),(607389,191121,'74362','origin','font-weight','bold',0,''),(607390,191121,'74362','origin','text','<p>INVOICE ADDRESS:</p>',0,''),(607391,191122,'74363','origin','font-size','12',0,''),(607392,191123,'74364','origin','block_type','1',0,''),(607393,191123,'74364','origin','font-weight','normal',0,''),(607394,191123,'74364','origin','padding-top','10',0,''),(607395,191123,'74364','origin','padding-left','10',0,''),(607396,191123,'74364','origin','padding-right','10',0,''),(607397,191123,'74364','origin','padding-bottom','10',0,''),(607398,191124,'74365','origin','text','<p>E-MAIL ADDRESS:</p>',1,''),(607399,191124,'74365','origin','font-weight','bold',0,''),(607400,191124,'74365','origin','font-size','14',0,''),(607401,191124,'74365','origin','padding-top','10',0,''),(607402,191124,'74365','origin','text','<p>E-MAIL ADDRESS:</p>',0,''),(607403,191125,'74366','origin','font-weight','normal',0,''),(607404,191126,'74367','origin','font-weight','normal',0,''),(607405,191127,'74368','origin','text','<p>CUSTOMER:</p>',1,''),(607406,191127,'74368','origin','font-size','13',0,''),(607407,191127,'74368','origin','font-weight','bold',0,''),(607408,191127,'74368','origin','text','<p>CUSTOMER:</p>',0,''),(607409,191128,'74369','origin','text','<p>PHONE NUMBER:</p>',1,''),(607410,191128,'74369','origin','font-size','14',0,''),(607411,191128,'74369','origin','font-weight','bold',0,''),(607412,191128,'74369','origin','padding-top','10',0,''),(607413,191128,'74369','origin','text','<p>PHONE NUMBER:</p>',0,''),(607414,191130,'74371','origin','font-weight','normal',0,''),(607415,191130,'74371','origin','text-align','center',0,''),(607416,191130,'74371','origin','padding-bottom','20',0,''),(607417,191131,'74372','origin','text','<p>Payment Method:</p>',1,''),(607418,191131,'74372','origin','font-weight','bold',0,''),(607419,191131,'74372','origin','text-align','center',0,''),(607420,191131,'74372','origin','text','<p>Payment Method:</p>',0,''),(607421,191132,'74373','origin','text','<p>Payment date:</p>',1,''),(607422,191132,'74373','origin','font-weight','bold',0,''),(607423,191132,'74373','origin','text-align','center',0,''),(607424,191132,'74373','origin','font-size','12',0,''),(607425,191132,'74373','origin','text','<p>Payment date:</p>',0,''),(607426,191133,'74374','origin','font-size','14',0,''),(607427,191133,'74374','origin','font-weight','bold',0,''),(607428,191133,'74374','origin','text-align','center',0,''),(607429,191133,'74374','origin','padding-bottom','10',0,''),(607430,191133,'74374','origin','padding-top','10',0,''),(607431,191134,'74375','origin','font-weight','normal',0,''),(607432,191134,'74375','origin','text-align','center',0,''),(607433,191134,'74375','origin','padding-bottom','10',0,''),(607434,191135,'74376','origin','font-weight','normal',0,''),(607435,191135,'74376','origin','text-align','center',0,''),(607436,191136,'74377','origin','block_type','3',0,''),(607437,191136,'74377','origin','font-weight','normal',0,''),(607438,191136,'74377','origin','padding-top','20',0,''),(607439,191137,'74378','origin','font-size','12',0,''),(607440,191138,'74379','origin','text','<p>If undelivered please return to:</p>',1,''),(607441,191138,'74379','origin','font-size','12',0,''),(607442,191138,'74379','origin','font-weight','bold',0,''),(607443,191138,'74379','origin','text','<p>If undelivered please return to:</p>',0,''),(607444,191139,'74380','origin','text','<p>Thank you for your order</p>',1,''),(607445,191139,'74380','origin','color','$color-8',0,''),(607446,191139,'74380','origin','font-size','13',0,''),(607447,191139,'74380','origin','font-weight','bold',0,''),(607448,191139,'74380','origin','padding-top','5',0,''),(607449,191139,'74380','origin','text-align','center',0,''),(607450,191139,'74380','origin','text','<p>Thank you for your order</p>',0,''),(607451,191140,'74381','origin','font-weight','400',0,''),(607452,191140,'74381','origin','text-align','center',0,''),(607453,191140,'74381','origin','padding-top','0',0,''),(607454,191140,'74381','origin','padding-left','20',0,''),(607455,191140,'74381','origin','padding-right','20',0,''),(607456,191140,'74381','origin','logo_from','theme',0,''),(607457,191141,'74382','origin','block_type','6',0,''),(607458,191141,'74382','origin','font-weight','normal',0,''),(607459,191141,'74382','origin','font-size','16',0,''),(607460,191142,'74383','origin','text','<p>Email:</p>',1,''),(607461,191142,'74383','origin','font-weight','normal',0,''),(607462,191142,'74383','origin','text-align','right',0,''),(607463,191142,'74383','origin','font-size','12',0,''),(607464,191142,'74383','origin','text','<p>Email:</p>',0,''),(607465,191143,'74384','origin','font-weight','normal',0,''),(607466,191143,'74384','origin','text-align','right',0,''),(607467,191143,'74384','origin','font-size','12',0,''),(607468,191144,'74385','origin','block_type','6',0,''),(607469,191144,'74385','origin','font-weight','normal',0,''),(607470,191144,'74385','origin','font-size','16',0,''),(607471,191145,'74386','origin','text','<p>Phone:</p>',1,''),(607472,191145,'74386','origin','font-weight','normal',0,''),(607473,191145,'74386','origin','text-align','right',0,''),(607474,191145,'74386','origin','font-size','12',0,''),(607475,191145,'74386','origin','text','<p>Phone:</p>',0,''),(607476,191146,'74387','origin','font-weight','normal',0,''),(607477,191146,'74387','origin','text-align','right',0,''),(607478,191146,'74387','origin','font-size','12',0,''),(607479,191147,'74388','origin','text','<p>If something has gone wrong please contact us at:</p>',1,''),(607480,191147,'74388','origin','font-size','12',0,''),(607481,191147,'74388','origin','font-weight','bold',0,''),(607482,191147,'74388','origin','text-align','right',0,''),(607483,191147,'74388','origin','text','<p>If something has gone wrong please contact us at:</p>',0,''),(607484,191148,'74389','origin','font-weight','400',0,''),(607485,191148,'74389','origin','padding-top','20',0,''),(607486,191148,'74389','origin','padding-bottom','0',0,''),(607487,191148,'74389','origin','font-size','12',0,''),(607488,191149,'74390','origin','block_type','5',0,''),(607489,191149,'74390','origin','font-weight','normal',0,''),(607490,191149,'74390','origin','border-bottom-width','1',0,''),(607491,191149,'74390','origin','border-bottom-color','$content-border-1',0,''),(607492,191149,'74390','origin','border-top-width','1',0,''),(607493,191149,'74390','origin','border-top-color','$content-border-1',0,''),(607494,191149,'74390','origin','border-left-color','$content-border-1',0,''),(607495,191149,'74390','origin','border-left-width','1',0,''),(607496,191150,'74391','origin','block_type','1',0,''),(607497,191150,'74391','origin','font-weight','normal',0,''),(607498,191150,'74391','origin','padding-top','10',0,''),(607499,191150,'74391','origin','padding-left','10',0,''),(607500,191150,'74391','origin','padding-right','10',0,''),(607501,191151,'74392','origin','font-weight','400',0,''),(607502,191151,'74392','origin','line-height','120',0,''),(607503,191151,'74392','origin','line_height_measure','%',0,''),(607504,191151,'74392','origin','font-size','12',0,''),(607505,191152,'74393','origin','text','<p>SHIPPING ADDRESS:</p>',1,''),(607506,191152,'74393','origin','font-size','14',0,''),(607507,191152,'74393','origin','font-weight','bold',0,''),(607508,191152,'74393','origin','padding-bottom','10',0,''),(607509,191152,'74393','origin','text','<p>SHIPPING ADDRESS:</p>',0,''),(607510,191153,'74394','origin','block_type','1',0,''),(607511,191153,'74394','origin','background-color','$content-bg-2',0,''),(607512,191153,'74394','origin','padding-top','20',0,''),(607513,191153,'74394','origin','padding-left','10',0,''),(607514,191153,'74394','origin','padding-right','10',0,''),(607515,191153,'74394','origin','padding-bottom','20',0,''),(607516,191153,'74394','origin','font-size','14',0,''),(607517,191154,'74395','origin','font-weight','normal',0,''),(607518,191154,'74395','origin','text-align','right',0,''),(607519,191154,'74395','origin','font-size','14',0,''),(607520,191154,'74395','origin','box_align','3',0,''),(607521,191155,'74396','origin','block_type','2',0,''),(607522,191155,'74396','origin','font-weight','normal',0,''),(607523,191155,'74396','origin','padding-bottom','20',0,''),(607524,191156,'74397','origin','font-weight','400',0,''),(607525,191156,'74397','origin','padding-top','20',0,''),(607526,191156,'74397','origin','logo_from','theme',0,''),(607527,191157,'74398','origin','block_type','11',0,''),(607528,191157,'74398','origin','font-weight','normal',0,''),(607529,191158,'74399','origin','text','<p>Web:</p>',1,''),(607530,191158,'74399','origin','font-weight','normal',0,''),(607531,191158,'74399','origin','text-align','right',0,''),(607532,191158,'74399','origin','text','<p>Web:</p>',0,''),(607533,191159,'74400','origin','font-weight','normal',0,''),(607534,191159,'74400','origin','text-align','right',0,''),(607535,191160,'74401','origin','block_type','11',0,''),(607536,191160,'74401','origin','font-weight','normal',0,''),(607537,191161,'74402','origin','text','<p>Email:</p>',1,''),(607538,191161,'74402','origin','font-weight','normal',0,''),(607539,191161,'74402','origin','text-align','right',0,''),(607540,191161,'74402','origin','text','<p>Email:</p>',0,''),(607541,191162,'74403','origin','font-weight','normal',0,''),(607542,191162,'74403','origin','text-align','right',0,''),(607543,191163,'74404','origin','block_type','1',0,''),(607544,191164,'74405','origin','font-weight','normal',0,''),(607545,191164,'74405','origin','text-align','right',0,''),(607546,191164,'74405','origin','padding-bottom','10',0,''),(607547,191164,'74405','origin','address_spacer',',',0,''),(607548,191164,'74405','origin','font-size','12',0,''),(607549,191165,'74406','origin','block_type','11',0,''),(607550,191165,'74406','origin','font-weight','normal',0,''),(607551,191166,'74407','origin','text','<p>Phone:</p>',1,''),(607552,191166,'74407','origin','font-weight','normal',0,''),(607553,191166,'74407','origin','text-align','right',0,''),(607554,191166,'74407','origin','text','<p>Phone:</p>',0,''),(607555,191167,'74408','origin','font-weight','normal',0,''),(607556,191167,'74408','origin','text-align','right',0,''),(607557,191168,'74409','origin','block_type','1',0,''),(607558,191168,'74409','origin','padding-top','20',0,''),(607559,191169,'74410','origin','tab_1','RETURNING CUSTOMER',1,''),(607560,191169,'74410','origin','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(607561,191169,'74410','origin','tab_1','RETURNING CUSTOMER',0,''),(607562,191169,'74410','origin','tab_2','REGISTER TO SAVE YOUR DETAILS',0,''),(607563,191171,'74412','origin','block_type','8',0,''),(607564,191172,'74413','origin','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(607565,191173,'74414','origin','block_type','1',0,''),(607566,191173,'74414','origin','padding-left','20',0,''),(607567,191173,'74414','origin','padding-right','20',0,''),(607568,191174,'74415','origin','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(607569,191176,'74417','origin','block_type','1',0,''),(607570,191177,'74418','origin','text','##TEXT_OR##',0,''),(607571,191177,'74418','origin','font-size','18',0,''),(607572,191177,'74418','origin','font-weight','700',0,''),(607573,191177,'74418','origin','padding-top','15',0,''),(607574,191177,'74418','origin','text-align','center',0,''),(607575,191177,'74418','origin','content','\\_',0,'3'),(607576,191177,'74418','origin','height','5',0,'3'),(607577,191177,'74418','origin','width','70',0,'3'),(607578,191177,'74418','origin','display','inline-block',0,'3'),(607579,191177,'74418','origin','border-top-width','1',0,'3'),(607580,191177,'74418','origin','border-top-color','$content-border-1',0,'3'),(607581,191177,'74418','origin','margin-left','10',0,'3'),(607582,191177,'74418','origin','margin-right','10',0,'3'),(607583,191177,'74418','origin','content','\\_',0,'4'),(607584,191177,'74418','origin','display','inline-block',0,'4'),(607585,191177,'74418','origin','width','70',0,'4'),(607586,191177,'74418','origin','height','5',0,'4'),(607587,191177,'74418','origin','border-top-width','1',0,'4'),(607588,191177,'74418','origin','border-top-color','$content-border-1',0,'4'),(607589,191177,'74418','origin','margin-left','10',0,'4'),(607590,191177,'74418','origin','margin-right','10',0,'4'),(607591,191177,'74418','origin','position','relative',0,''),(607592,191177,'74418','origin','top','-10',0,''),(607593,191178,'74419','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607594,191178,'74419','origin','font-size','26',0,''),(607595,191178,'74419','origin','font-family','$font-1',0,''),(607596,191178,'74419','origin','padding-top','15',0,''),(607597,191178,'74419','origin','padding-bottom','15',0,''),(607598,191178,'74419','origin','text-align','center',0,''),(607599,191179,'74420','origin','text-align','center',0,''),(607600,191179,'74420','origin','hide_parents','2',0,''),(607601,191180,'74421','origin','block_type','1',0,''),(607602,191180,'74421','origin','padding-top','40',0,''),(607603,191180,'74421','origin','background-color','$content-bg-2',0,''),(607604,191180,'74421','origin','padding-bottom','40',0,''),(607605,191180,'74421','origin','style_class','checkout-login-wrap',0,''),(607606,191180,'74421','origin','color','$content-color-2',0,''),(607607,191181,'74422','origin','block_type','2',0,''),(607608,191181,'74422','origin','background-color','$content-bg-1',0,''),(607609,191181,'74422','origin','max-width','830',0,''),(607610,191181,'74422','origin','margin_left_measure','auto',0,''),(607611,191181,'74422','origin','margin_right_measure','auto',0,''),(607612,191181,'74422','origin','padding-top','40',0,''),(607613,191181,'74422','origin','padding-bottom','40',0,''),(607614,191181,'74422','origin','schema','2-3',0,'8356'),(607615,191181,'74422','origin','color','$content-color-1',0,''),(607616,191182,'74423','origin','text-align','center',0,''),(607617,191182,'74423','origin','margin-bottom','40',0,''),(607618,191183,'74424','origin','text-align','center',0,''),(607619,191184,'74425','origin','text','##TEXT_OR##',0,''),(607620,191184,'74425','origin','font-size','18',0,''),(607621,191184,'74425','origin','font-weight','700',0,''),(607622,191184,'74425','origin','text-align','center',0,''),(607623,191184,'74425','origin','content','\\_',0,'3'),(607624,191184,'74425','origin','height','5',0,'3'),(607625,191184,'74425','origin','width','70',0,'3'),(607626,191184,'74425','origin','display','inline-block',0,'3'),(607627,191184,'74425','origin','border-top-width','1',0,'3'),(607628,191184,'74425','origin','border-top-color','$content-border-1',0,'3'),(607629,191184,'74425','origin','margin-left','10',0,'3'),(607630,191184,'74425','origin','margin-right','10',0,'3'),(607631,191184,'74425','origin','content','\\_',0,'4'),(607632,191184,'74425','origin','display','inline-block',0,'4'),(607633,191184,'74425','origin','width','70',0,'4'),(607634,191184,'74425','origin','height','5',0,'4'),(607635,191184,'74425','origin','border-top-width','1',0,'4'),(607636,191184,'74425','origin','border-top-color','$content-border-1',0,'4'),(607637,191184,'74425','origin','margin-left','10',0,'4'),(607638,191184,'74425','origin','margin-right','10',0,'4'),(607639,191184,'74425','origin','position','relative',0,''),(607640,191184,'74425','origin','padding-top','10',0,''),(607641,191184,'74425','origin','padding-bottom','10',0,''),(607642,191185,'74426','origin','block_type','1',0,''),(607643,191186,'74427','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607644,191186,'74427','origin','font-size','18',0,''),(607645,191186,'74427','origin','font-family','$font-1',0,''),(607646,191186,'74427','origin','padding-top','15',0,''),(607647,191186,'74427','origin','padding-bottom','15',0,''),(607648,191186,'74427','origin','text-align','center',0,''),(607649,191186,'74427','origin','text-transform','uppercase',0,''),(607650,191187,'74428','origin','text-align','center',0,''),(607651,191187,'74428','origin','hide_parents','2',0,''),(607652,191188,'74429','origin','text','##NEW_CUSTOMER##',0,''),(607653,191188,'74429','origin','font-size','18',0,''),(607654,191188,'74429','origin','font-family','$font-1',0,''),(607655,191188,'74429','origin','text-align','center',0,''),(607656,191188,'74429','origin','text-transform','uppercase',0,''),(607657,191188,'74429','origin','margin-bottom','10',0,''),(607658,191189,'74430','origin','max-width','230',0,''),(607659,191189,'74430','origin','margin_left_measure','auto',0,''),(607660,191189,'74430','origin','margin_right_measure','auto',0,''),(607661,191190,'74431','origin','text','##RETURNING_CUSTOMER##',0,''),(607662,191190,'74431','origin','font-size','18',0,''),(607663,191190,'74431','origin','font-family','$font-1',0,''),(607664,191190,'74431','origin','text-transform','uppercase',0,''),(607665,191190,'74431','origin','text-align','center',0,''),(607666,191191,'74432','origin','block_type','1',0,''),(607667,191191,'74432','origin','padding-top','20',0,''),(607668,191192,'74433','origin','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(607669,191192,'74433','origin','tab_2','RETURNING CUSTOMER',1,''),(607670,191192,'74433','origin','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(607671,191192,'74433','origin','tab_1','GUEST – SINGLE USE ACCOUNT',0,''),(607672,191192,'74433','origin','tab_2','RETURNING CUSTOMER',0,''),(607673,191192,'74433','origin','tab_3','REGISTER TO SAVE YOUR DETAILS',0,''),(607674,191193,'74434','origin','block_type','8',0,''),(607675,191194,'74435','origin','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(607676,191195,'74436','origin','block_type','1',0,''),(607677,191195,'74436','origin','padding-left','20',0,''),(607678,191195,'74436','origin','padding-right','20',0,''),(607679,191197,'74438','origin','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(607680,191197,'74438','origin','border-top-width','1',0,''),(607681,191197,'74438','origin','border-top-color','$content-border-1',0,'');
INSERT INTO `design_boxes_settings_tmp` VALUES (607682,191199,'74440','origin','block_type','8',0,''),(607683,191200,'74441','origin','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(607684,191201,'74442','origin','block_type','1',0,''),(607685,191201,'74442','origin','padding-left','20',0,''),(607686,191201,'74442','origin','padding-right','20',0,''),(607687,191202,'74443','origin','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(607688,191204,'74445','origin','text-align','center',0,''),(607689,191205,'74446','origin','text','##TEXT_OR##',0,''),(607690,191205,'74446','origin','font-size','18',0,''),(607691,191205,'74446','origin','font-weight','700',0,''),(607692,191205,'74446','origin','padding-top','15',0,''),(607693,191205,'74446','origin','text-align','center',0,''),(607694,191205,'74446','origin','content','\\_',0,'3'),(607695,191205,'74446','origin','height','5',0,'3'),(607696,191205,'74446','origin','width','70',0,'3'),(607697,191205,'74446','origin','display','inline-block',0,'3'),(607698,191205,'74446','origin','border-top-width','1',0,'3'),(607699,191205,'74446','origin','border-top-color','$content-border-1',0,'3'),(607700,191205,'74446','origin','margin-left','10',0,'3'),(607701,191205,'74446','origin','margin-right','10',0,'3'),(607702,191205,'74446','origin','content','\\_',0,'4'),(607703,191205,'74446','origin','display','inline-block',0,'4'),(607704,191205,'74446','origin','width','70',0,'4'),(607705,191205,'74446','origin','height','5',0,'4'),(607706,191205,'74446','origin','border-top-width','1',0,'4'),(607707,191205,'74446','origin','border-top-color','$content-border-1',0,'4'),(607708,191205,'74446','origin','margin-left','10',0,'4'),(607709,191205,'74446','origin','margin-right','10',0,'4'),(607710,191205,'74446','origin','position','relative',0,''),(607711,191205,'74446','origin','top','-10',0,''),(607712,191206,'74447','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607713,191206,'74447','origin','font-size','26',0,''),(607714,191206,'74447','origin','font-family','$font-1',0,''),(607715,191206,'74447','origin','padding-top','15',0,''),(607716,191206,'74447','origin','padding-bottom','15',0,''),(607717,191206,'74447','origin','text-align','center',0,''),(607718,191207,'74448','origin','block_type','1',0,''),(607719,191207,'74448','origin','padding-top','20',0,''),(607720,191208,'74449','origin','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(607721,191208,'74449','origin','tab_2','RETURNING CUSTOMER',1,''),(607722,191208,'74449','origin','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(607723,191208,'74449','origin','tab_1','GUEST – SINGLE USE ACCOUNT',0,''),(607724,191208,'74449','origin','tab_2','RETURNING CUSTOMER',0,''),(607725,191208,'74449','origin','tab_3','REGISTER TO SAVE YOUR DETAILS',0,''),(607726,191209,'74450','origin','block_type','8',0,''),(607727,191210,'74451','origin','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(607728,191213,'74454','origin','block_type','8',0,''),(607729,191214,'74455','origin','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(607730,191216,'74457','origin','block_type','1',0,''),(607731,191216,'74457','origin','padding-left','20',0,''),(607732,191216,'74457','origin','padding-right','20',0,''),(607733,191218,'74459','origin','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(607734,191219,'74460','origin','text','##TEXT_OR##',0,''),(607735,191219,'74460','origin','font-size','18',0,''),(607736,191219,'74460','origin','font-weight','700',0,''),(607737,191219,'74460','origin','padding-top','15',0,''),(607738,191219,'74460','origin','text-align','center',0,''),(607739,191219,'74460','origin','content','\\_',0,'3'),(607740,191219,'74460','origin','height','5',0,'3'),(607741,191219,'74460','origin','width','70',0,'3'),(607742,191219,'74460','origin','display','inline-block',0,'3'),(607743,191219,'74460','origin','border-top-width','1',0,'3'),(607744,191219,'74460','origin','border-top-color','$content-border-1',0,'3'),(607745,191219,'74460','origin','margin-left','10',0,'3'),(607746,191219,'74460','origin','margin-right','10',0,'3'),(607747,191219,'74460','origin','content','\\_',0,'4'),(607748,191219,'74460','origin','display','inline-block',0,'4'),(607749,191219,'74460','origin','width','70',0,'4'),(607750,191219,'74460','origin','height','5',0,'4'),(607751,191219,'74460','origin','border-top-width','1',0,'4'),(607752,191219,'74460','origin','border-top-color','$content-border-1',0,'4'),(607753,191219,'74460','origin','margin-left','10',0,'4'),(607754,191219,'74460','origin','margin-right','10',0,'4'),(607755,191219,'74460','origin','position','relative',0,''),(607756,191219,'74460','origin','top','-10',0,''),(607757,191220,'74461','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607758,191220,'74461','origin','font-size','26',0,''),(607759,191220,'74461','origin','font-family','$font-1',0,''),(607760,191220,'74461','origin','padding-top','15',0,''),(607761,191220,'74461','origin','padding-bottom','15',0,''),(607762,191220,'74461','origin','text-align','center',0,''),(607763,191221,'74462','origin','text-align','center',0,''),(607764,191222,'74463','origin','block_type','1',0,''),(607765,191222,'74463','origin','padding-top','20',0,''),(607766,191223,'74464','origin','text-align','center',0,''),(607767,191224,'74465','origin','text','##TEXT_OR##',0,''),(607768,191224,'74465','origin','font-size','18',0,''),(607769,191224,'74465','origin','font-weight','700',0,''),(607770,191224,'74465','origin','padding-top','15',0,''),(607771,191224,'74465','origin','text-align','center',0,''),(607772,191224,'74465','origin','content','\\_',0,'3'),(607773,191224,'74465','origin','height','5',0,'3'),(607774,191224,'74465','origin','width','70',0,'3'),(607775,191224,'74465','origin','display','inline-block',0,'3'),(607776,191224,'74465','origin','border-top-width','1',0,'3'),(607777,191224,'74465','origin','border-top-color','$content-border-1',0,'3'),(607778,191224,'74465','origin','margin-left','10',0,'3'),(607779,191224,'74465','origin','margin-right','10',0,'3'),(607780,191224,'74465','origin','content','\\_',0,'4'),(607781,191224,'74465','origin','display','inline-block',0,'4'),(607782,191224,'74465','origin','width','70',0,'4'),(607783,191224,'74465','origin','height','5',0,'4'),(607784,191224,'74465','origin','border-top-width','1',0,'4'),(607785,191224,'74465','origin','border-top-color','$content-border-1',0,'4'),(607786,191224,'74465','origin','margin-left','10',0,'4'),(607787,191224,'74465','origin','margin-right','10',0,'4'),(607788,191224,'74465','origin','position','relative',0,''),(607789,191224,'74465','origin','top','-10',0,''),(607790,191225,'74466','origin','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(607791,191225,'74466','origin','tab_2','RETURNING CUSTOMER',1,''),(607792,191225,'74466','origin','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(607793,191225,'74466','origin','tab_1','GUEST – SINGLE USE ACCOUNT',0,''),(607794,191225,'74466','origin','tab_2','RETURNING CUSTOMER',0,''),(607795,191225,'74466','origin','tab_3','REGISTER TO SAVE YOUR DETAILS',0,''),(607796,191226,'74467','origin','block_type','8',0,''),(607797,191227,'74468','origin','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(607798,191230,'74471','origin','block_type','8',0,''),(607799,191231,'74472','origin','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(607800,191232,'74473','origin','block_type','1',0,''),(607801,191232,'74473','origin','padding-left','20',0,''),(607802,191232,'74473','origin','padding-right','20',0,''),(607803,191234,'74475','origin','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(607804,191235,'74476','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607805,191235,'74476','origin','font-size','26',0,''),(607806,191235,'74476','origin','font-family','$font-1',0,''),(607807,191235,'74476','origin','padding-top','15',0,''),(607808,191235,'74476','origin','padding-bottom','15',0,''),(607809,191235,'74476','origin','text-align','center',0,''),(607810,191236,'74477','origin','block_type','1',0,''),(607811,191236,'74477','origin','padding-top','40',0,''),(607812,191236,'74477','origin','background-color','$content-bg-2',0,''),(607813,191236,'74477','origin','padding-bottom','40',0,''),(607814,191237,'74478','origin','block_type','2',0,''),(607815,191237,'74478','origin','background-color','$content-bg-1',0,''),(607816,191237,'74478','origin','max-width','830',0,''),(607817,191237,'74478','origin','margin_left_measure','auto',0,''),(607818,191237,'74478','origin','margin_right_measure','auto',0,''),(607819,191237,'74478','origin','padding-top','40',0,''),(607820,191237,'74478','origin','padding-bottom','40',0,''),(607821,191238,'74479','origin','block_type','1',0,''),(607822,191239,'74480','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607823,191239,'74480','origin','font-size','18',0,''),(607824,191239,'74480','origin','font-family','$font-1',0,''),(607825,191239,'74480','origin','padding-top','15',0,''),(607826,191239,'74480','origin','padding-bottom','15',0,''),(607827,191239,'74480','origin','text-align','center',0,''),(607828,191239,'74480','origin','text-transform','uppercase',0,''),(607829,191240,'74481','origin','text-align','center',0,''),(607830,191240,'74481','origin','hide_parents','2',0,''),(607831,191241,'74482','origin','text-align','center',0,''),(607832,191242,'74483','origin','text-align','center',0,''),(607833,191242,'74483','origin','margin-bottom','40',0,''),(607834,191243,'74484','origin','text','##TEXT_OR##',0,''),(607835,191243,'74484','origin','font-size','18',0,''),(607836,191243,'74484','origin','font-weight','700',0,''),(607837,191243,'74484','origin','text-align','center',0,''),(607838,191243,'74484','origin','content','\\_',0,'3'),(607839,191243,'74484','origin','height','5',0,'3'),(607840,191243,'74484','origin','width','70',0,'3'),(607841,191243,'74484','origin','display','inline-block',0,'3'),(607842,191243,'74484','origin','border-top-width','1',0,'3'),(607843,191243,'74484','origin','border-top-color','$content-border-1',0,'3'),(607844,191243,'74484','origin','margin-left','10',0,'3'),(607845,191243,'74484','origin','margin-right','10',0,'3'),(607846,191243,'74484','origin','content','\\_',0,'4'),(607847,191243,'74484','origin','display','inline-block',0,'4'),(607848,191243,'74484','origin','width','70',0,'4'),(607849,191243,'74484','origin','height','5',0,'4'),(607850,191243,'74484','origin','border-top-width','1',0,'4'),(607851,191243,'74484','origin','border-top-color','$content-border-1',0,'4'),(607852,191243,'74484','origin','margin-left','10',0,'4'),(607853,191243,'74484','origin','margin-right','10',0,'4'),(607854,191243,'74484','origin','position','relative',0,''),(607855,191243,'74484','origin','padding-top','10',0,''),(607856,191243,'74484','origin','padding-bottom','10',0,''),(607857,191244,'74485','origin','text','##NEW_CUSTOMER##',0,''),(607858,191244,'74485','origin','font-size','18',0,''),(607859,191244,'74485','origin','font-family','$font-1',0,''),(607860,191244,'74485','origin','text-align','center',0,''),(607861,191244,'74485','origin','text-transform','uppercase',0,''),(607862,191244,'74485','origin','margin-bottom','10',0,''),(607863,191245,'74486','origin','text','##RETURNING_CUSTOMER##',0,''),(607864,191245,'74486','origin','font-size','18',0,''),(607865,191245,'74486','origin','font-family','$font-1',0,''),(607866,191245,'74486','origin','text-transform','uppercase',0,''),(607867,191245,'74486','origin','text-align','center',0,''),(607868,191246,'74487','origin','max-width','230',0,''),(607869,191246,'74487','origin','margin_left_measure','auto',0,''),(607870,191246,'74487','origin','margin_right_measure','auto',0,''),(607871,191247,'74488','origin','block_type','1',0,''),(607872,191247,'74488','origin','padding-top','40',0,''),(607873,191247,'74488','origin','background-color','$content-bg-2',0,''),(607874,191247,'74488','origin','padding-bottom','40',0,''),(607875,191248,'74489','origin','block_type','2',0,''),(607876,191248,'74489','origin','background-color','$content-bg-1',0,''),(607877,191248,'74489','origin','max-width','830',0,''),(607878,191248,'74489','origin','margin_left_measure','auto',0,''),(607879,191248,'74489','origin','margin_right_measure','auto',0,''),(607880,191248,'74489','origin','padding-top','40',0,''),(607881,191248,'74489','origin','padding-bottom','40',0,''),(607882,191249,'74490','origin','text','##NEW_CUSTOMER##',0,''),(607883,191249,'74490','origin','font-size','18',0,''),(607884,191249,'74490','origin','font-family','$font-1',0,''),(607885,191249,'74490','origin','text-align','center',0,''),(607886,191249,'74490','origin','text-transform','uppercase',0,''),(607887,191249,'74490','origin','margin-bottom','10',0,''),(607888,191250,'74491','origin','text-align','center',0,''),(607889,191251,'74492','origin','text-align','center',0,''),(607890,191251,'74492','origin','margin-bottom','40',0,''),(607891,191252,'74493','origin','text','##TEXT_OR##',0,''),(607892,191252,'74493','origin','font-size','18',0,''),(607893,191252,'74493','origin','font-weight','700',0,''),(607894,191252,'74493','origin','text-align','center',0,''),(607895,191252,'74493','origin','content','\\_',0,'3'),(607896,191252,'74493','origin','height','5',0,'3'),(607897,191252,'74493','origin','width','70',0,'3'),(607898,191252,'74493','origin','display','inline-block',0,'3'),(607899,191252,'74493','origin','border-top-width','1',0,'3'),(607900,191252,'74493','origin','border-top-color','$content-border-1',0,'3'),(607901,191252,'74493','origin','margin-left','10',0,'3'),(607902,191252,'74493','origin','margin-right','10',0,'3'),(607903,191252,'74493','origin','content','\\_',0,'4'),(607904,191252,'74493','origin','display','inline-block',0,'4'),(607905,191252,'74493','origin','width','70',0,'4'),(607906,191252,'74493','origin','height','5',0,'4'),(607907,191252,'74493','origin','border-top-width','1',0,'4'),(607908,191252,'74493','origin','border-top-color','$content-border-1',0,'4'),(607909,191252,'74493','origin','margin-left','10',0,'4'),(607910,191252,'74493','origin','margin-right','10',0,'4'),(607911,191252,'74493','origin','position','relative',0,''),(607912,191252,'74493','origin','padding-top','10',0,''),(607913,191252,'74493','origin','padding-bottom','10',0,''),(607914,191253,'74494','origin','block_type','1',0,''),(607915,191254,'74495','origin','text','##LOGIN_WITH_SOCIAL##',0,''),(607916,191254,'74495','origin','font-size','18',0,''),(607917,191254,'74495','origin','font-family','$font-1',0,''),(607918,191254,'74495','origin','padding-top','15',0,''),(607919,191254,'74495','origin','padding-bottom','15',0,''),(607920,191254,'74495','origin','text-align','center',0,''),(607921,191254,'74495','origin','text-transform','uppercase',0,''),(607922,191255,'74496','origin','text-align','center',0,''),(607923,191255,'74496','origin','hide_parents','2',0,''),(607924,191256,'74497','origin','text','##RETURNING_CUSTOMER##',0,''),(607925,191256,'74497','origin','font-size','18',0,''),(607926,191256,'74497','origin','font-family','$font-1',0,''),(607927,191256,'74497','origin','text-transform','uppercase',0,''),(607928,191256,'74497','origin','text-align','center',0,''),(607929,191257,'74498','origin','max-width','230',0,''),(607930,191257,'74498','origin','margin_left_measure','auto',0,''),(607931,191257,'74498','origin','margin_right_measure','auto',0,''),(607932,191258,'74499','origin','block_type','1',0,''),(607933,191259,'74500','origin','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(607934,191259,'74500','origin','margin-bottom','30',0,''),(607935,191260,'74501','origin','block_type','1',0,''),(607936,191261,'74502','origin','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(607937,191261,'74502','origin','margin-bottom','30',0,''),(607938,191262,'74503','origin','block_type','1',0,''),(607939,191262,'74503','origin','background-color','$best-sellers-bg-1',0,''),(607940,191262,'74503','origin','padding-top','20',0,''),(607941,191262,'74503','origin','padding-bottom','20',0,''),(607942,191262,'74503','origin','font-weight','400',0,''),(607943,191262,'74503','origin','visibility_product','1',0,''),(607944,191262,'74503','origin','visibility_catalog','1',0,''),(607945,191262,'74503','origin','visibility_info','1',0,''),(607946,191262,'74503','origin','visibility_cart','1',0,''),(607947,191262,'74503','origin','visibility_checkout','1',0,''),(607948,191262,'74503','origin','visibility_success','1',0,''),(607949,191262,'74503','origin','visibility_account','1',0,''),(607950,191262,'74503','origin','visibility_login','1',0,''),(607951,191262,'74503','origin','visibility_other','1',0,''),(607952,191262,'74503','origin','margin-bottom','20',0,''),(607953,191262,'74503','origin','display_none','on',0,'8356'),(607954,191263,'74504','origin','block_type','2',0,''),(607955,191263,'74504','origin','font-weight','normal',0,''),(607956,191264,'74505','origin','font-weight','400',0,''),(607957,191264,'74505','origin','visibility_product','1',0,''),(607958,191264,'74505','origin','show_name','0',0,''),(607959,191264,'74505','origin','show_stock','1',0,''),(607960,191264,'74505','origin','show_description','1',0,''),(607961,191264,'74505','origin','show_model','1',0,''),(607962,191264,'74505','origin','show_rating','1',0,''),(607963,191264,'74505','origin','show_rating_counts','1',0,''),(607964,191264,'74505','origin','show_qty_input','1',0,''),(607965,191264,'74505','origin','show_view_button','1',0,''),(607966,191264,'74505','origin','show_wishlist_button','1',0,''),(607967,191264,'74505','origin','show_compare','1',0,''),(607968,191264,'74505','origin','listing_type','productListing',0,''),(607969,191264,'74505','origin','show_properties','1',0,''),(607970,191264,'74505','origin','col_in_row','2',0,''),(607971,191264,'74505','origin','show_bonus_points','1',0,''),(607972,191264,'74505','origin','show_buy_button','1',0,''),(607973,191264,'74505','origin','show_attributes','1',0,''),(607974,191265,'74506','origin','font-weight','normal',0,''),(607975,191265,'74506','origin','visibility_product','1',0,''),(607976,191266,'74507','origin','font-weight','400',0,''),(607977,191266,'74507','origin','visibility_product','1',0,''),(607978,191266,'74507','origin','visibility_catalog','1',0,''),(607979,191266,'74507','origin','visibility_info','1',0,''),(607980,191266,'74507','origin','visibility_cart','1',0,''),(607981,191266,'74507','origin','visibility_checkout','1',0,''),(607982,191266,'74507','origin','visibility_success','1',0,''),(607983,191266,'74507','origin','visibility_account','1',0,''),(607984,191266,'74507','origin','visibility_login','1',0,''),(607985,191266,'74507','origin','visibility_other','1',0,''),(607986,191266,'74507','origin','banners_group','home',0,''),(607987,191266,'74507','origin','banners_type','single',0,''),(607988,191266,'74507','origin','lazy_load','1',0,''),(607989,191266,'74507','origin','template','1',0,''),(607990,191266,'74507','origin','ban_id','41',0,''),(607991,191267,'74508','origin','block_type','1',0,''),(607992,191267,'74508','origin','font-weight','normal',0,''),(607993,191268,'74510','origin','tab_1','##NEW_PRODUCTS##',0,''),(607994,191268,'74510','origin','tab_2','##SPECIALS_PRODUCTS##',0,''),(607995,191268,'74510','origin','tab_3','##FEATURED_PRODUCTS##',0,''),(607996,191269,'74511','origin','col_in_row','4',0,''),(607997,191269,'74511','origin','view_as','carousel',0,''),(607998,191269,'74511','origin','show_attributes','1',0,''),(607999,191269,'74511','origin','col_in_row','3',0,'8356'),(608000,191269,'74511','origin','col_in_row','2',0,'8349'),(608001,191269,'74511','origin','col_in_row','1',0,'8377'),(608002,191269,'74511','origin','listing_type','productListing',0,''),(608003,191269,'74511','origin','show_qty_input','1',0,''),(608004,191269,'74511','origin','show_compare','1',0,''),(608005,191269,'74511','origin','lazy_load','1',0,''),(608006,191270,'74512','origin','font-weight','400',0,''),(608007,191270,'74512','origin','show_compare','1',0,''),(608008,191270,'74512','origin','listing_type','productListing',0,''),(608009,191270,'74512','origin','show_model','1',0,''),(608010,191270,'74512','origin','show_properties','1',0,''),(608011,191270,'74512','origin','col_in_row','4',0,''),(608012,191270,'74512','origin','show_name','0',0,''),(608013,191270,'74512','origin','show_image','0',0,''),(608014,191270,'74512','origin','show_stock','0',0,''),(608015,191270,'74512','origin','show_description','0',0,''),(608016,191270,'74512','origin','show_rating','0',0,''),(608017,191270,'74512','origin','show_rating_counts','0',0,''),(608018,191270,'74512','origin','show_price','0',0,''),(608019,191270,'74512','origin','show_buy_button','0',0,''),(608020,191270,'74512','origin','show_qty_input','0',0,''),(608021,191270,'74512','origin','show_view_button','0',0,''),(608022,191270,'74512','origin','show_wishlist_button','0',0,''),(608023,191270,'74512','origin','col_in_row','2',0,'8356'),(608024,191270,'74512','origin','col_in_row','1',0,'8377'),(608025,191270,'74512','origin','view_as','carousel',0,''),(608026,191270,'74512','origin','product_names_teg','h2',0,''),(608027,191270,'74512','origin','show_attributes','1',0,''),(608028,191271,'74513','origin','font-weight','400',0,''),(608029,191271,'74513','origin','listing_type','productListing',0,''),(608030,191271,'74513','origin','col_in_row','4',0,''),(608031,191271,'74513','origin','show_image','0',0,''),(608032,191271,'74513','origin','show_stock','0',0,''),(608033,191271,'74513','origin','show_description','0',0,''),(608034,191271,'74513','origin','show_rating','0',0,''),(608035,191271,'74513','origin','show_rating_counts','0',0,''),(608036,191271,'74513','origin','show_price','0',0,''),(608037,191271,'74513','origin','show_buy_button','0',0,''),(608038,191271,'74513','origin','show_qty_input','0',0,''),(608039,191271,'74513','origin','show_view_button','0',0,''),(608040,191271,'74513','origin','show_wishlist_button','0',0,''),(608041,191271,'74513','origin','col_in_row','2',0,'8356'),(608042,191271,'74513','origin','col_in_row','1',0,'8377'),(608043,191271,'74513','origin','view_as','carousel',0,''),(608044,191271,'74513','origin','col_in_row','2',0,'8349'),(608045,191271,'74513','origin','featured_type_id','0',0,''),(608046,191273,'74515','origin','heading_type','h1',0,''),(608047,191275,'74516','origin','block_type','1',0,''),(608048,191276,'74517','origin','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(608049,191278,'74519','origin','block_type','1',0,''),(608050,191278,'74519','origin','padding-top','40',0,''),(608051,191278,'74519','origin','padding-bottom','80',0,''),(608052,191279,'74520','origin','block_type','6',0,''),(608053,191280,'74521','origin','block_type','1',0,''),(608054,191280,'74521','origin','padding-top','20',0,''),(608055,191280,'74521','origin','padding-left','20',0,''),(608056,191280,'74521','origin','padding-right','20',0,''),(608057,191280,'74521','origin','padding-bottom','20',0,''),(608058,191280,'74521','origin','border-top-width','1',0,''),(608059,191280,'74521','origin','border-left-width','1',0,''),(608060,191280,'74521','origin','border-right-width','1',0,''),(608061,191280,'74521','origin','border-bottom-width','1',0,''),(608062,191280,'74521','origin','border-top-color','$content-border-1',0,''),(608063,191280,'74521','origin','border-left-color','$content-border-1',0,''),(608064,191280,'74521','origin','border-right-color','$content-border-1',0,''),(608065,191280,'74521','origin','border-bottom-color','$content-border-1',0,''),(608066,191280,'74521','origin','margin-right','20',0,''),(608067,191283,'74524','origin','block_type','1',0,''),(608068,191283,'74524','origin','padding-top','20',0,''),(608069,191284,'74525','origin','block_type','6',0,''),(608070,191285,'74526','origin','padding-right','20',0,''),(608071,191287,'74528','origin','block_type','1',0,''),(608072,191287,'74528','origin','padding-top','20',0,''),(608073,191288,'74529','origin','block_type','6',0,''),(608074,191289,'74530','origin','padding-right','20',0,''),(608075,191291,'74532','origin','block_type','1',0,''),(608076,191291,'74532','origin','style_class','account-password-wrap',0,''),(608077,191292,'74533','origin','block_type','6',0,''),(608078,191292,'74533','origin','schema','6-3',0,'8356'),(608079,191293,'74534','origin','aria_name','account-menu',0,''),(608080,191294,'73374','origin','block_type','1',0,''),(608081,191294,'73374','origin','padding-top','70',0,''),(608082,191294,'73374','origin','padding-right','30',0,''),(608083,191294,'73374','origin','padding-bottom','30',0,''),(608084,191294,'73374','origin','padding-top','0',0,'8356'),(608085,191294,'73374','origin','padding-left','0',0,'8356'),(608086,191294,'73374','origin','padding-right','0',0,'8356'),(608087,191294,'73374','origin','padding-bottom','0',0,'8356'),(608130,191314,'74536','origin','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(608131,191315,'74537','origin','block_type','1',0,''),(608132,191315,'74537','origin','padding-top','20',0,''),(608133,191316,'74538','origin','tab_1','RETURNING CUSTOMER',1,''),(608134,191316,'74538','origin','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(608135,191316,'74538','origin','tab_1','RETURNING CUSTOMER',0,''),(608136,191316,'74538','origin','tab_2','REGISTER TO SAVE YOUR DETAILS',0,''),(608137,191318,'74540','origin','block_type','8',0,''),(608138,191319,'74541','origin','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(608139,191320,'74542','origin','block_type','1',0,''),(608140,191320,'74542','origin','padding-left','20',0,''),(608141,191320,'74542','origin','padding-right','20',0,''),(608142,191322,'74544','origin','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(608143,191323,'74545','origin','block_type','1',0,''),(608144,191324,'74546','origin','block_type','1',0,''),(608145,191325,'74547','origin','margin_left_measure','auto',0,''),(608146,191325,'74547','origin','margin_right_measure','auto',0,''),(608147,191325,'74547','origin','max-width','560',0,''),(608148,191326,'74548','origin','margin-bottom','30',0,''),(608149,191327,'74549','origin','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(608150,191328,'94779','origin','block_type','1',0,''),(608151,191330,'94781','origin','block_type','6',0,''),(608152,191330,'94781','origin','font-weight','400',0,''),(608153,191330,'94781','origin','schema','6-2',0,'8377'),(608154,191330,'94781','origin','schema','6-2',0,'8356'),(608155,191331,'94782','origin','font-weight','400',0,''),(608156,191331,'94782','origin','padding-right','40',0,''),(608157,191331,'94782','origin','padding-right','0',0,'8377'),(608158,191331,'94782','origin','padding-right','0',0,'8356'),(608159,191332,'94783','origin','col_in_row','3',0,''),(608160,191332,'94783','origin','products_align','left',0,''),(608161,191332,'94783','origin','font-weight','400',0,''),(608162,191332,'94783','origin','show_qty_input','0',0,''),(608163,191332,'94783','origin','listing_type','productListing',0,''),(608164,191332,'94783','origin','listing_type_rows','no',0,''),(608165,191332,'94783','origin','show_buy_button_b2b','on',0,''),(608166,191332,'94783','origin','show_wishlist_button_b2b','1',0,''),(608167,191332,'94783','origin','show_compare_b2b','1',0,''),(608168,191332,'94783','origin','show_stock','0',0,''),(608169,191332,'94783','origin','show_description','0',0,''),(608170,191332,'94783','origin','show_model','0',0,''),(608171,191332,'94783','origin','show_properties','0',0,''),(608172,191332,'94783','origin','show_rating','0',0,''),(608173,191332,'94783','origin','show_rating_counts','0',0,''),(608174,191332,'94783','origin','show_price','0',0,''),(608175,191332,'94783','origin','show_buy_button','0',0,''),(608176,191332,'94783','origin','show_view_button','0',0,''),(608177,191332,'94783','origin','show_wishlist_button','0',0,''),(608178,191332,'94783','origin','show_compare','0',0,''),(608179,191332,'94783','origin','show_name_rows','0',0,''),(608180,191332,'94783','origin','show_image_rows','0',0,''),(608181,191332,'94783','origin','show_stock_rows','0',0,''),(608182,191332,'94783','origin','show_description_rows','0',0,''),(608183,191332,'94783','origin','show_model_rows','0',0,''),(608184,191332,'94783','origin','show_properties_rows','0',0,''),(608185,191332,'94783','origin','show_rating_rows','0',0,''),(608186,191332,'94783','origin','show_rating_counts_rows','0',0,''),(608187,191332,'94783','origin','show_price_rows','0',0,''),(608188,191332,'94783','origin','show_buy_button_rows','0',0,''),(608189,191332,'94783','origin','show_qty_input_rows','0',0,''),(608190,191332,'94783','origin','show_view_button_rows','0',0,''),(608191,191332,'94783','origin','show_wishlist_button_rows','0',0,''),(608192,191332,'94783','origin','show_compare_rows','0',0,''),(608193,191332,'94783','origin','show_name_b2b','0',0,''),(608194,191332,'94783','origin','show_image_b2b','0',0,''),(608195,191332,'94783','origin','show_stock_b2b','0',0,''),(608196,191332,'94783','origin','show_description_b2b','0',0,''),(608197,191332,'94783','origin','show_model_b2b','0',0,''),(608198,191332,'94783','origin','show_properties_b2b','0',0,''),(608199,191332,'94783','origin','show_rating_b2b','0',0,''),(608200,191332,'94783','origin','show_rating_counts_b2b','0',0,''),(608201,191332,'94783','origin','show_price_b2b','0',0,''),(608202,191332,'94783','origin','show_qty_input_b2b','0',0,''),(608203,191332,'94783','origin','show_view_button_b2b','0',0,''),(608204,191332,'94783','origin','show_attributes_b2b','0',0,''),(608205,191332,'94783','origin','items_on_page','9',0,''),(608206,191332,'94783','origin','col_in_row','2',0,'8356'),(608207,191332,'94783','origin','col_in_row','1',0,'8377'),(608208,191332,'94783','origin','product_names_teg','h2',0,''),(608209,191334,'94785','origin','block_type','5',0,''),(608210,191334,'94785','origin','padding-top','10',0,''),(608211,191334,'94785','origin','padding-bottom','10',0,''),(608212,191334,'94785','origin','schema','5-2',0,'8377'),(608213,191334,'94785','origin','border-top-color','$content-border-1',0,''),(608214,191334,'94785','origin','border-top-width','1',0,''),(608215,191336,'94787','origin','float','right',0,''),(608216,191337,'94788','origin','listing_type','productListing',0,''),(608217,191339,'94790','origin','block_type','1',0,''),(608218,191339,'94790','origin','padding-top','10',0,''),(608219,191339,'94790','origin','padding-bottom','10',0,''),(608220,191339,'94790','origin','border-bottom-width','1',0,''),(608221,191339,'94790','origin','border-bottom-color','$content-border-1',0,''),(608222,191339,'94790','origin','margin-left','0',0,''),(608223,191339,'94790','origin','margin-right','0',0,''),(608224,191340,'94791','origin','float','right',0,''),(608225,191340,'94791','origin','display','none',0,'8377'),(608226,191341,'94792','origin','float','left',0,''),(608227,191341,'94792','origin','clear','none',0,''),(608228,191341,'94792','origin','margin-left','20',0,''),(608229,191341,'94792','origin','display','none',0,'8377'),(608230,191342,'94793','origin','margin-right','20',0,''),(608231,191342,'94793','origin','float','right',0,''),(608232,191342,'94793','origin','clear','none',0,''),(608233,191342,'94793','origin','display','none',0,'8356'),(608234,191343,'94794','origin','float','left',0,''),(608235,191343,'94794','origin','clear','none',0,''),(608236,191343,'94794','origin','sort_pos_3','1',0,''),(608237,191343,'94794','origin','sort_pos_4','2',0,''),(608238,191343,'94794','origin','sort_pos_10','3',0,''),(608239,191343,'94794','origin','sort_pos_9','4',0,''),(608240,191343,'94794','origin','sort_pos_11','5',0,''),(608241,191343,'94794','origin','sort_pos_12','6',0,''),(608242,191343,'94794','origin','sort_pos_14','7',0,''),(608243,191343,'94794','origin','sort_pos_13','8',0,''),(608244,191343,'94794','origin','sort_pos_8','9',0,''),(608245,191343,'94794','origin','sort_pos_7','10',0,''),(608246,191343,'94794','origin','sort_pos_2','11',0,''),(608247,191343,'94794','origin','sort_pos_1','12',0,''),(608248,191343,'94794','origin','sort_pos_6','13',0,''),(608249,191343,'94794','origin','sort_pos_5','14',0,''),(608250,191343,'94794','origin','sort_pos_0','15',0,''),(608251,191343,'94794','origin','sort_hide_10','1',0,''),(608252,191343,'94794','origin','sort_hide_9','1',0,''),(608253,191343,'94794','origin','hide_icons','1',0,''),(608254,191343,'94794','origin','sort_hide_16','1',0,''),(608255,191343,'94794','origin','sort_hide_15','1',0,''),(608256,191343,'94794','origin','sort_hide_3','0',0,''),(608257,191343,'94794','origin','sort_hide_4','0',0,''),(608258,191343,'94794','origin','sort_hide_11','1',0,''),(608259,191343,'94794','origin','sort_hide_12','1',0,''),(608260,191343,'94794','origin','sort_hide_14','1',0,''),(608261,191343,'94794','origin','sort_hide_13','1',0,''),(608262,191343,'94794','origin','sort_hide_8','0',0,''),(608263,191343,'94794','origin','sort_hide_7','0',0,''),(608264,191343,'94794','origin','sort_hide_2','1',0,''),(608265,191343,'94794','origin','sort_hide_1','1',0,''),(608266,191343,'94794','origin','sort_hide_6','1',0,''),(608267,191343,'94794','origin','sort_hide_5','1',0,''),(608268,191343,'94794','origin','sort_hide_0','1',0,''),(608269,191344,'74550','origin','block_type','1',0,''),(608270,191345,'74551','origin','margin-bottom','30',0,''),(608271,191346,'74552','origin','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(608272,191347,'74553','origin','block_type','1',0,''),(608273,191348,'74554','origin','block_type','5',0,''),(608274,191348,'74554','origin','padding-top','10',0,''),(608275,191348,'74554','origin','padding-bottom','10',0,''),(608276,191348,'74554','origin','schema','5-2',0,'8377'),(608277,191348,'74554','origin','border-top-color','$content-border-1',0,''),(608278,191348,'74554','origin','border-top-width','1',0,''),(608279,191349,'74555','origin','padding-top','3',0,''),(608280,191350,'74556','origin','float','right',0,''),(608281,191350,'74556','origin','height','31',0,''),(608282,191351,'74557','origin','col_in_row','4',0,''),(608283,191351,'74557','origin','products_align','left',0,''),(608284,191351,'74557','origin','font-weight','400',0,''),(608285,191351,'74557','origin','listing_type','productListing',0,''),(608286,191351,'74557','origin','listing_type_rows','Rows',0,''),(608287,191351,'74557','origin','show_buy_button_b2b','on',0,''),(608288,191351,'74557','origin','show_wishlist_button_b2b','1',0,''),(608289,191351,'74557','origin','show_compare_b2b','1',0,''),(608290,191351,'74557','origin','show_image','0',0,''),(608291,191351,'74557','origin','show_stock','0',0,''),(608292,191351,'74557','origin','show_description','0',0,''),(608293,191351,'74557','origin','show_model','0',0,''),(608294,191351,'74557','origin','show_properties','0',0,''),(608295,191351,'74557','origin','show_rating','0',0,''),(608296,191351,'74557','origin','show_rating_counts','0',0,''),(608297,191351,'74557','origin','show_price','0',0,''),(608298,191351,'74557','origin','show_buy_button','0',0,''),(608299,191351,'74557','origin','show_view_button','0',0,''),(608300,191351,'74557','origin','show_wishlist_button','0',0,''),(608301,191351,'74557','origin','show_compare','0',0,''),(608302,191351,'74557','origin','show_name_rows','0',0,''),(608303,191351,'74557','origin','show_image_rows','0',0,''),(608304,191351,'74557','origin','show_stock_rows','0',0,''),(608305,191351,'74557','origin','show_description_rows','0',0,''),(608306,191351,'74557','origin','show_model_rows','0',0,''),(608307,191351,'74557','origin','show_properties_rows','0',0,''),(608308,191351,'74557','origin','show_rating_rows','0',0,''),(608309,191351,'74557','origin','show_rating_counts_rows','0',0,''),(608310,191351,'74557','origin','show_price_rows','0',0,''),(608311,191351,'74557','origin','show_buy_button_rows','0',0,''),(608312,191351,'74557','origin','show_qty_input_rows','0',0,''),(608313,191351,'74557','origin','show_view_button_rows','0',0,''),(608314,191351,'74557','origin','show_wishlist_button_rows','0',0,''),(608315,191351,'74557','origin','show_compare_rows','0',0,''),(608316,191351,'74557','origin','show_name_b2b','0',0,''),(608317,191351,'74557','origin','show_image_b2b','0',0,''),(608318,191351,'74557','origin','show_stock_b2b','0',0,''),(608319,191351,'74557','origin','show_description_b2b','0',0,''),(608320,191351,'74557','origin','show_model_b2b','0',0,''),(608321,191351,'74557','origin','show_properties_b2b','0',0,''),(608322,191351,'74557','origin','show_rating_b2b','0',0,''),(608323,191351,'74557','origin','show_rating_counts_b2b','0',0,''),(608324,191351,'74557','origin','show_price_b2b','0',0,''),(608325,191351,'74557','origin','show_qty_input_b2b','0',0,''),(608326,191351,'74557','origin','show_view_button_b2b','0',0,''),(608327,191351,'74557','origin','show_attributes_b2b','0',0,''),(608328,191351,'74557','origin','items_on_page','12',0,''),(608329,191351,'74557','origin','col_in_row','2',0,'8356'),(608330,191351,'74557','origin','col_in_row','1',0,'8377'),(608331,191351,'74557','origin','product_names_teg','h2',0,''),(608332,191354,'74560','origin','block_type','1',0,''),(608333,191355,'74561','origin','block_type','1',0,''),(608334,191355,'74561','origin','padding-top','10',0,''),(608335,191355,'74561','origin','padding-bottom','10',0,''),(608336,191355,'74561','origin','border-bottom-width','1',0,''),(608337,191355,'74561','origin','border-bottom-color','$content-border-1',0,''),(608338,191355,'74561','origin','margin-left','0',0,''),(608339,191355,'74561','origin','margin-right','0',0,''),(608340,191356,'74562','origin','clear','none',0,''),(608341,191356,'74562','origin','float','left',0,''),(608342,191356,'74562','origin','padding-top','3',0,''),(608343,191356,'74562','origin','margin-left','20',0,''),(608344,191357,'74563','origin','float','right',0,''),(608345,191357,'74563','origin','display','none',0,'8377'),(608346,191358,'74564','origin','margin-right','20',0,''),(608347,191358,'74564','origin','float','right',0,''),(608348,191358,'74564','origin','clear','none',0,''),(608349,191358,'74564','origin','display','none',0,'8356'),(608350,191359,'74565','origin','float','left',0,''),(608351,191359,'74565','origin','clear','none',0,''),(608352,191359,'74565','origin','margin-left','20',0,''),(608353,191359,'74565','origin','display','none',0,'8377'),(608354,191360,'74566','origin','float','left',0,''),(608355,191360,'74566','origin','clear','none',0,''),(608356,191360,'74566','origin','sort_pos_3','2',0,''),(608357,191360,'74566','origin','sort_pos_4','3',0,''),(608358,191360,'74566','origin','sort_pos_10','11',0,''),(608359,191360,'74566','origin','sort_pos_9','10',0,''),(608360,191360,'74566','origin','sort_pos_11','12',0,''),(608361,191360,'74566','origin','sort_pos_12','13',0,''),(608362,191360,'74566','origin','sort_pos_14','15',0,''),(608363,191360,'74566','origin','sort_pos_13','14',0,''),(608364,191360,'74566','origin','sort_pos_8','4',0,''),(608365,191360,'74566','origin','sort_pos_7','5',0,''),(608366,191360,'74566','origin','sort_pos_2','7',0,''),(608367,191360,'74566','origin','sort_pos_1','6',0,''),(608368,191360,'74566','origin','sort_pos_6','9',0,''),(608369,191360,'74566','origin','sort_pos_5','8',0,''),(608370,191360,'74566','origin','sort_pos_0','1',0,''),(608371,191360,'74566','origin','sort_hide_10','1',0,''),(608372,191360,'74566','origin','sort_hide_9','1',0,''),(608373,191360,'74566','origin','sort_pos_15','16',0,''),(608374,191360,'74566','origin','sort_pos_16','17',0,''),(608375,191360,'74566','origin','sort_hide_4','0',0,''),(608376,191360,'74566','origin','sort_hide_3','0',0,''),(608377,191360,'74566','origin','sort_hide_16','1',0,''),(608378,191360,'74566','origin','sort_hide_15','1',0,''),(608379,191360,'74566','origin','sort_hide_11','1',0,''),(608380,191360,'74566','origin','sort_hide_12','1',0,''),(608381,191360,'74566','origin','sort_hide_14','1',0,''),(608382,191360,'74566','origin','sort_hide_13','1',0,''),(608383,191360,'74566','origin','sort_hide_8','0',0,''),(608384,191360,'74566','origin','sort_hide_7','0',0,''),(608385,191360,'74566','origin','sort_hide_2','1',0,''),(608386,191360,'74566','origin','sort_hide_1','1',0,''),(608387,191360,'74566','origin','sort_hide_6','1',0,''),(608388,191360,'74566','origin','sort_hide_5','1',0,''),(608389,191360,'74566','origin','sort_hide_0','0',0,''),(608390,191360,'74566','origin','hide_icons','1',0,''),(608391,191361,'74567','origin','margin-bottom','20',0,''),(608392,191362,'74568','origin','block_type','1',0,''),(608393,191362,'74568','origin','style_class','account-order-history',0,''),(608394,191363,'74569','origin','block_type','6',0,''),(608395,191363,'74569','origin','schema','6-3',0,'8356'),(608396,191364,'74570','origin','aria_name','account-menu',0,''),(608397,191365,'73374','origin','block_type','1',0,''),(608398,191365,'73374','origin','padding-top','70',0,''),(608399,191365,'73374','origin','padding-right','30',0,''),(608400,191365,'73374','origin','padding-bottom','30',0,''),(608401,191365,'73374','origin','padding-top','0',0,'8356'),(608402,191365,'73374','origin','padding-left','0',0,'8356'),(608403,191365,'73374','origin','padding-right','0',0,'8356'),(608404,191365,'73374','origin','padding-bottom','0',0,'8356'),(608447,191384,'74571','origin','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(608448,191385,'74572','origin','link','Order History Info',0,''),(608449,191385,'74572','origin','text','TEXT_VIEW',0,''),(608450,191385,'74572','origin','show_pagenation','1',0,''),(608451,191385,'74572','origin','link_pay','Order pay',0,''),(608452,191385,'74572','origin','margin-bottom','20',0,''),(608453,191386,'74573','origin','block_type','1',0,''),(608454,191386,'74573','origin','style_class','account-order-history-info',0,''),(608455,191387,'74574','origin','block_type','6',0,''),(608456,191387,'74574','origin','schema','6-3',0,'8356'),(608457,191388,'74575','origin','aria_name','account-menu',0,''),(608458,191389,'73374','origin','block_type','1',0,''),(608459,191389,'73374','origin','padding-top','70',0,''),(608460,191389,'73374','origin','padding-right','30',0,''),(608461,191389,'73374','origin','padding-bottom','30',0,''),(608462,191389,'73374','origin','padding-top','0',0,'8356'),(608463,191389,'73374','origin','padding-left','0',0,'8356'),(608464,191389,'73374','origin','padding-right','0',0,'8356'),(608465,191389,'73374','origin','padding-bottom','0',0,'8356'),(608508,191408,'74576','origin','float','right',0,''),(608509,191408,'74576','origin','clear','none',0,''),(608510,191408,'74576','origin','margin-left','20',0,''),(608511,191410,'74578','origin','float','right',0,''),(608512,191410,'74578','origin','clear','none',0,''),(608513,191410,'74578','origin','like_button','2',0,''),(608514,191410,'74578','origin','link','Order pay',0,''),(608515,191411,'74579','origin','block_type','2',0,''),(608516,191411,'74579','origin','padding-top','20',0,''),(608517,191411,'74579','origin','margin-bottom','20',0,''),(608518,191412,'74580','origin','like_button','1',0,''),(608519,191412,'74580','origin','text','IMAGE_BUTTON_BACK',0,''),(608520,191412,'74580','origin','link','Order History',0,''),(608521,191413,'74581','origin','text-align','right',0,''),(608522,191414,'74582','origin','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(608523,191416,'74584','origin','float','right',0,''),(608524,191416,'74584','origin','clear','none',0,''),(608525,191416,'74584','origin','margin-left','20',0,''),(608526,191418,'74586','origin','float','right',0,''),(608527,191419,'74587','origin','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(608528,191421,'74589','origin','float','left',0,''),(608529,191422,'74590','origin','block_type','3',0,''),(608530,191422,'74590','origin','clear','both',0,''),(608531,191422,'74590','origin','padding-top','20',0,''),(608532,191422,'74590','origin','schema','3-4',0,'8349'),(608533,191423,'74591','origin','block_type','1',0,''),(608534,191423,'74591','origin','margin-bottom','20',0,''),(608535,191423,'74591','origin','padding-right','0',0,'8349'),(608536,191423,'74591','origin','padding-right','20',0,''),(608537,191424,'74592','origin','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(608538,191425,'74593','origin','padding-left','30',0,''),(608539,191425,'74593','origin','orders_data','telephone',0,''),(608540,191425,'74593','origin','hide_parents','2',0,''),(608541,191426,'74594','origin','block_type','1',0,''),(608542,191426,'74594','origin','padding-right','20',0,''),(608543,191426,'74594','origin','padding-bottom','20',0,''),(608544,191426,'74594','origin','padding-right','0',0,'8349'),(608545,191427,'74595','origin','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(608546,191428,'74596','origin','orders_data','name',0,''),(608547,191428,'74596','origin','padding-left','30',0,''),(608548,191429,'74597','origin','block_type','1',0,''),(608549,191429,'74597','origin','padding-right','20',0,''),(608550,191429,'74597','origin','margin-bottom','20',0,''),(608551,191429,'74597','origin','padding-right','0',0,'8349'),(608552,191430,'74598','origin','short_view','1',0,''),(608553,191430,'74598','origin','hide_parents','2',0,''),(608554,191431,'74599','origin','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(608555,191432,'74600','origin','link','Tracking numbers',0,''),(608556,191432,'74600','origin','text','MORE_TRACKING_NUMBER',0,''),(608557,191432,'74600','origin','popup','1',0,''),(608558,191432,'74600','origin','order_id','1',0,''),(608559,191432,'74600','origin','popup_class','tracking-numbers-popup',0,''),(608560,191432,'74600','origin','font-weight','700',0,''),(608561,191432,'74600','origin','font-size','18',0,''),(608562,191433,'74601','origin','block_type','1',0,''),(608563,191433,'74601','origin','padding-right','20',0,''),(608564,191433,'74601','origin','padding-right','0',0,'8349'),(608565,191434,'74602','origin','orders_data','shipping_method',0,''),(608566,191434,'74602','origin','padding-left','30',0,''),(608567,191435,'74603','origin','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(608568,191436,'74604','origin','block_type','1',0,''),(608569,191436,'74604','origin','padding-right','20',0,''),(608570,191436,'74604','origin','padding-bottom','20',0,''),(608571,191436,'74604','origin','padding-right','0',0,'8349'),(608572,191437,'74605','origin','orders_data','delivery_address',0,''),(608573,191437,'74605','origin','padding-left','30',0,''),(608574,191438,'74606','origin','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(608575,191439,'74607','origin','block_type','1',0,''),(608576,191440,'74608','origin','orders_data','payment_method',0,''),(608577,191440,'74608','origin','padding-left','30',0,''),(608578,191441,'74609','origin','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(608579,191442,'74610','origin','block_type','1',0,''),(608580,191442,'74610','origin','padding-bottom','20',0,''),(608581,191443,'74611','origin','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(608582,191444,'74612','origin','orders_data','billing_address',0,''),(608583,191444,'74612','origin','padding-left','30',0,''),(608584,191445,'74613','origin','block_type','1',0,''),(608585,191445,'74613','origin','style_class','account-order-pay',0,''),(608586,191446,'74614','origin','block_type','6',0,''),(608587,191446,'74614','origin','schema','6-3',0,'8356'),(608588,191447,'74615','origin','aria_name','account-menu',0,''),(608589,191448,'73374','origin','block_type','1',0,''),(608590,191448,'73374','origin','padding-top','70',0,''),(608591,191448,'73374','origin','padding-right','30',0,''),(608592,191448,'73374','origin','padding-bottom','30',0,''),(608593,191448,'73374','origin','padding-top','0',0,'8356'),(608594,191448,'73374','origin','padding-left','0',0,'8356'),(608595,191448,'73374','origin','padding-right','0',0,'8356'),(608596,191448,'73374','origin','padding-bottom','0',0,'8356'),(608639,191468,'74617','origin','block_type','3',0,''),(608640,191469,'74618','origin','block_type','1',0,''),(608641,191469,'74618','origin','padding-right','20',0,''),(608642,191469,'74618','origin','padding-bottom','20',0,''),(608643,191470,'74619','origin','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(608644,191471,'74620','origin','orders_data','name',0,''),(608645,191471,'74620','origin','padding-left','30',0,''),(608646,191472,'74621','origin','block_type','1',0,''),(608647,191473,'74622','origin','padding-left','30',0,''),(608648,191474,'74623','origin','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(608649,191475,'74624','origin','block_type','1',0,''),(608650,191475,'74624','origin','padding-right','20',0,''),(608651,191475,'74624','origin','padding-bottom','20',0,''),(608652,191476,'74625','origin','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(608653,191477,'74626','origin','orders_data','delivery_address',0,''),(608654,191477,'74626','origin','padding-left','30',0,''),(608655,191478,'74627','origin','block_type','1',0,''),(608656,191478,'74627','origin','padding-right','20',0,''),(608657,191479,'74628','origin','orders_data','shipping_method',0,''),(608658,191479,'74628','origin','padding-left','30',0,''),(608659,191480,'74629','origin','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(608660,191481,'74630','origin','block_type','1',0,''),(608661,191482,'74631','origin','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(608662,191483,'74632','origin','orders_data','payment_method',0,''),(608663,191483,'74632','origin','padding-left','30',0,''),(608664,191484,'74633','origin','block_type','1',0,''),(608665,191484,'74633','origin','padding-bottom','20',0,''),(608666,191485,'74634','origin','orders_data','billing_address',0,''),(608667,191485,'74634','origin','padding-left','30',0,''),(608668,191486,'74635','origin','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(608669,191487,'74636','origin','margin-bottom','20',0,''),(608670,191488,'74637','origin','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(608671,191491,'74640','origin','width','680',0,''),(608672,191491,'74640','origin','font-weight','400',0,''),(608673,191491,'74640','origin','font-size','12',0,''),(608674,191491,'74640','origin','padding-top','20',0,''),(608675,191491,'74640','origin','padding-bottom','20',0,''),(608676,191492,'74641','origin','block_type','2',0,''),(608677,191492,'74641','origin','font-weight','normal',0,''),(608678,191492,'74641','origin','padding-bottom','20',0,''),(608679,191493,'74642','origin','font-weight','400',0,''),(608680,191493,'74642','origin','text-align','center',0,''),(608681,191493,'74642','origin','padding-top','10',0,''),(608682,191493,'74642','origin','logo_from','theme',0,''),(608683,191494,'74643','origin','block_type','11',0,''),(608684,191494,'74643','origin','font-weight','normal',0,''),(608685,191495,'74644','origin','text','<p>Email:</p>',1,''),(608686,191495,'74644','origin','font-weight','normal',0,''),(608687,191495,'74644','origin','text-align','right',0,''),(608688,191495,'74644','origin','text','<p>Email:</p>',0,''),(608689,191496,'74645','origin','font-weight','normal',0,''),(608690,191496,'74645','origin','text-align','right',0,''),(608691,191497,'74646','origin','block_type','11',0,''),(608692,191497,'74646','origin','font-weight','normal',0,''),(608693,191498,'74647','origin','text','<p>Phone:</p>',1,''),(608694,191498,'74647','origin','font-weight','normal',0,''),(608695,191498,'74647','origin','text-align','right',0,''),(608696,191498,'74647','origin','text','<p>Phone:</p>',0,''),(608697,191499,'74648','origin','font-weight','normal',0,''),(608698,191499,'74648','origin','text-align','right',0,''),(608699,191500,'74649','origin','block_type','1',0,''),(608700,191501,'74650','origin','font-weight','400',0,''),(608701,191501,'74650','origin','text-align','right',0,''),(608702,191501,'74650','origin','padding-bottom','10',0,''),(608703,191501,'74650','origin','address_spacer',',',0,''),(608704,191501,'74650','origin','font-size','12',0,''),(608705,191502,'74651','origin','block_type','11',0,''),(608706,191502,'74651','origin','font-weight','400',0,''),(608707,191503,'74652','origin','text','<p>Web:</p>',1,''),(608708,191503,'74652','origin','font-weight','400',0,''),(608709,191503,'74652','origin','text-align','right',0,''),(608710,191503,'74652','origin','text','<p>Web:</p>',0,''),(608711,191504,'74653','origin','font-weight','normal',0,''),(608712,191504,'74653','origin','text-align','right',0,''),(608713,191505,'74654','origin','font-weight','normal',0,''),(608714,191505,'74654','origin','padding-top','20',0,''),(608715,191505,'74654','origin','font-size','12',0,''),(608716,191506,'74655','origin','block_type','1',0,''),(608717,191506,'74655','origin','font-weight','normal',0,''),(608718,191506,'74655','origin','padding-top','10',0,''),(608719,191506,'74655','origin','padding-bottom','10',0,''),(608720,191508,'74657','origin','text','<p>If undelivered please return to:</p>',1,''),(608721,191508,'74657','origin','font-weight','bold',0,''),(608722,191508,'74657','origin','text','<p>If undelivered please return to:</p>',0,''),(608723,191509,'74658','origin','block_type','4',0,''),(608724,191509,'74658','origin','font-weight','400',0,''),(608725,191509,'74658','origin','border-top-width','1',0,''),(608726,191509,'74658','origin','border-top-color','$content-border-1',0,''),(608727,191509,'74658','origin','border-left-width','1',0,''),(608728,191509,'74658','origin','border-left-color','$content-border-1',0,''),(608729,191509,'74658','origin','border-right-width','1',0,''),(608730,191509,'74658','origin','border-right-color','$content-border-1',0,''),(608731,191509,'74658','origin','border-bottom-width','1',0,''),(608732,191509,'74658','origin','border-bottom-color','$content-border-1',0,''),(608733,191510,'74659','origin','block_type','2',0,''),(608734,191510,'74659','origin','font-weight','normal',0,''),(608735,191510,'74659','origin','border-right-width','1',0,''),(608736,191510,'74659','origin','border-right-color','$content-border-1',0,''),(608737,191511,'74660','origin','block_type','1',0,''),(608738,191511,'74660','origin','font-weight','normal',0,''),(608739,191511,'74660','origin','border-right-width','1',0,''),(608740,191511,'74660','origin','border-right-color','$content-border-1',0,''),(608741,191511,'74660','origin','background-color','$content-bg-2',0,''),(608742,191511,'74660','origin','padding-top','10',0,''),(608743,191511,'74660','origin','padding-left','10',0,''),(608744,191511,'74660','origin','padding-right','10',0,''),(608745,191511,'74660','origin','padding-bottom','10',0,''),(608746,191512,'74661','origin','font-size','12',0,''),(608747,191512,'74661','origin','font-weight','normal',0,''),(608748,191513,'74662','origin','text','<p>SHIPPING ADDRESS:</p>',1,''),(608749,191513,'74662','origin','font-size','13',0,''),(608750,191513,'74662','origin','font-weight','bold',0,''),(608751,191513,'74662','origin','padding-bottom','10',0,''),(608752,191513,'74662','origin','text','<p>SHIPPING ADDRESS:</p>',0,''),(608753,191514,'74663','origin','block_type','1',0,''),(608754,191514,'74663','origin','font-weight','normal',0,''),(608755,191514,'74663','origin','padding-top','10',0,''),(608756,191514,'74663','origin','padding-left','10',0,''),(608757,191514,'74663','origin','padding-right','10',0,''),(608758,191514,'74663','origin','padding-bottom','10',0,''),(608759,191515,'74664','origin','text','<p>CUSTOMER:</p>',1,''),(608760,191515,'74664','origin','font-size','13',0,''),(608761,191515,'74664','origin','font-weight','bold',0,''),(608762,191515,'74664','origin','text','<p>CUSTOMER:</p>',0,''),(608763,191516,'74665','origin','font-size','12',0,''),(608764,191518,'74667','origin','text','<p>PHONE NUMBER:</p>',1,''),(608765,191518,'74667','origin','font-size','13',0,''),(608766,191518,'74667','origin','font-weight','bold',0,''),(608767,191518,'74667','origin','padding-top','10',0,''),(608768,191518,'74667','origin','text','<p>PHONE NUMBER:</p>',0,''),(608769,191519,'74668','origin','font-size','12',0,''),(608770,191520,'74669','origin','text','<p>E-MAIL ADDRESS:</p>',1,''),(608771,191520,'74669','origin','font-size','13',0,''),(608772,191520,'74669','origin','font-weight','bold',0,''),(608773,191520,'74669','origin','padding-top','10',0,''),(608774,191520,'74669','origin','text','<p>E-MAIL ADDRESS:</p>',0,''),(608775,191521,'74670','origin','block_type','2',0,''),(608776,191521,'74670','origin','font-weight','normal',0,''),(608777,191521,'74670','origin','border-right-width','1',0,''),(608778,191521,'74670','origin','border-right-color','$content-border-1',0,''),(608779,191521,'74670','origin','border-top-width','1',0,''),(608780,191521,'74670','origin','border-top-color','$content-border-1',0,''),(608781,191522,'74671','origin','block_type','1',0,''),(608782,191522,'74671','origin','font-weight','normal',0,''),(608783,191522,'74671','origin','padding-top','10',0,''),(608784,191522,'74671','origin','padding-left','10',0,''),(608785,191522,'74671','origin','padding-right','10',0,''),(608786,191522,'74671','origin','padding-bottom','10',0,''),(608787,191522,'74671','origin','border-right-width','1',0,''),(608788,191522,'74671','origin','border-right-color','$content-border-1',0,''),(608789,191524,'74673','origin','text','<p>Shipping via</p>',1,''),(608790,191524,'74673','origin','font-weight','bold',0,''),(608791,191524,'74673','origin','text','<p>Shipping via</p>',0,''),(608792,191525,'74674','origin','block_type','1',0,''),(608793,191525,'74674','origin','font-weight','normal',0,''),(608794,191525,'74674','origin','padding-top','10',0,''),(608795,191525,'74674','origin','padding-left','10',0,''),(608796,191525,'74674','origin','padding-right','10',0,''),(608797,191525,'74674','origin','padding-bottom','10',0,''),(608798,191527,'74676','origin','text','<p>Shipping service</p>',1,''),(608799,191527,'74676','origin','font-weight','bold',0,''),(608800,191527,'74676','origin','text','<p>Shipping service</p>',0,''),(608801,191528,'74677','origin','font-weight','normal',0,''),(608802,191528,'74677','origin','text-align','center',0,''),(608803,191528,'74677','origin','padding-top','40',0,''),(608804,191529,'74678','origin','block_type','1',0,''),(608805,191530,'74679','origin','block_type','8',0,''),(608806,191531,'74680','origin','text','##TEXT_MAIN##',0,''),(608807,191531,'74680','origin','margin-bottom','20',0,''),(608808,191531,'74680','origin','text-align','center',0,''),(608809,191532,'74681','origin','margin-bottom','20',0,''),(608810,191533,'74682','origin','text','<h1>##HEADING_TITLE##</h1>',0,''),(608811,191535,'74684','origin','block_type','2',0,''),(608812,191536,'74685','origin','block_type','1',0,''),(608813,191536,'74685','origin','style_class','product',0,''),(608814,191536,'74685','origin','padding-right','10',0,''),(608815,191536,'74685','origin','padding-bottom','20',0,''),(608816,191537,'74686','origin','block_type','1',0,''),(608817,191538,'74687','origin','product_element','products_name',0,''),(608818,191538,'74687','origin','font-family','$font-1',0,''),(608819,191538,'74687','origin','padding-bottom','10',0,''),(608820,191538,'74687','origin','font-size','16',0,''),(608821,191539,'74688','origin','block_type','2',0,''),(608822,191540,'74689','origin','product_element','image',0,''),(608823,191540,'74689','origin','padding-right','10',0,''),(608824,191541,'74690','origin','product_element','products_price_old',0,''),(608825,191541,'74690','origin','font-family','$font-1',0,''),(608826,191541,'74690','origin','font-size','14',0,''),(608827,191541,'74690','origin','text-decoration','line-through',0,''),(608828,191542,'74691','origin','product_element','products_price',0,''),(608829,191542,'74691','origin','font-family','$font-1',0,''),(608830,191542,'74691','origin','font-size','20',0,''),(608831,191542,'74691','origin','padding-top','20',0,''),(608832,191543,'74692','origin','block_type','1',0,''),(608833,191543,'74692','origin','style_class','product',0,''),(608834,191543,'74692','origin','padding-left','10',0,''),(608835,191543,'74692','origin','padding-bottom','20',0,''),(608836,191544,'74693','origin','block_type','2',0,''),(608837,191545,'74694','origin','product_element','image',0,''),(608838,191545,'74694','origin','padding-right','10',0,''),(608839,191546,'74695','origin','font-size','14',0,''),(608840,191546,'74695','origin','font-family','$font-1',0,''),(608841,191546,'74695','origin','text-decoration','line-through',0,''),(608842,191546,'74695','origin','product_element','products_price_old',0,''),(608843,191547,'74696','origin','product_element','products_price',0,''),(608844,191547,'74696','origin','font-family','$font-1',0,''),(608845,191547,'74696','origin','font-size','20',0,''),(608846,191547,'74696','origin','padding-top','20',0,''),(608847,191548,'74697','origin','block_type','1',0,''),(608848,191549,'74698','origin','product_element','products_name',0,''),(608849,191549,'74698','origin','font-family','$font-1',0,''),(608850,191549,'74698','origin','font-size','16',0,''),(608851,191549,'74698','origin','padding-bottom','10',0,''),(608852,191550,'74699','origin','font-size','30',0,''),(608853,191550,'74699','origin','font-family','$font-1',0,''),(608854,191550,'74699','origin','text-align','center',0,''),(608855,191550,'74699','origin','padding-bottom','50',0,''),(608856,191551,'74700','origin','padding-bottom','20',0,''),(608857,191551,'74700','origin','text-align','center',0,''),(608858,191552,'74701','origin','width','680',0,''),(608859,191553,'74702','origin','padding-top','200',0,''),(608860,191553,'74702','origin','padding-left','200',0,''),(608861,191553,'74702','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',1,''),(608862,191553,'74702','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',0,''),(608863,191554,'74703','origin','text','osCommerce 4',1,''),(608864,191554,'74703','origin','font-family','$font-1',0,''),(608865,191554,'74703','origin','font-size','40',0,''),(608866,191554,'74703','origin','padding-top','50',0,''),(608867,191554,'74703','origin','text-align','center',0,''),(608868,191554,'74703','origin','text','osCommerce 4',0,''),(608869,191555,'74704','origin','block_type','2',0,''),(608870,191555,'74704','origin','border-top-width','1',0,''),(608871,191555,'74704','origin','border-top-color','$content-border-1',0,''),(608872,191556,'74705','origin','text-align','right',0,''),(608873,191556,'74705','origin','padding-top','15',0,''),(608874,191556,'74705','origin','padding-bottom','15',0,''),(608875,191556,'74705','origin','font-size','14',0,''),(608876,191557,'74706','origin','font-family','$font-1',0,''),(608877,191557,'74706','origin','text-align','center',0,''),(608878,191557,'74706','origin','font-size','20',0,''),(608879,191557,'74706','origin','color','$highlight-color-1',0,''),(608880,191557,'74706','origin','border-bottom-width','1',0,''),(608881,191557,'74706','origin','border-bottom-color','$content-border-1',0,''),(608882,191557,'74706','origin','padding-top','10',0,''),(608883,191557,'74706','origin','padding-bottom','10',0,''),(608884,191558,'74707','origin','block_type','1',0,''),(608885,191559,'74708','origin','block_type','6',0,''),(608886,191559,'74708','origin','schema','6-3',0,'8356'),(608887,191560,'74709','origin','aria_name','account-menu',0,''),(608888,191561,'73374','origin','block_type','1',0,''),(608889,191561,'73374','origin','padding-top','70',0,''),(608890,191561,'73374','origin','padding-right','30',0,''),(608891,191561,'73374','origin','padding-bottom','30',0,''),(608892,191561,'73374','origin','padding-top','0',0,'8356'),(608893,191561,'73374','origin','padding-left','0',0,'8356'),(608894,191561,'73374','origin','padding-right','0',0,'8356'),(608895,191561,'73374','origin','padding-bottom','0',0,'8356'),(608938,191580,'74710','origin','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(608939,191581,'74711','origin','like_button','1',0,''),(608940,191581,'74711','origin','link','personal_catalog',0,''),(608941,191581,'74711','origin','text','BOX_INFORMATION_ALLPRODS',0,''),(608942,191581,'74711','origin','text-align','center',0,''),(608943,191581,'74711','origin','padding-top','20',0,''),(608944,191581,'74711','origin','padding-bottom','20',0,''),(608945,191582,'74712','origin','max_items','10',0,''),(608946,191583,'74713','origin','block_type','1',0,''),(608947,191583,'74713','origin','padding-top','20',0,''),(608948,191583,'74713','origin','padding-left','20',0,''),(608949,191583,'74713','origin','padding-right','20',0,''),(608950,191583,'74713','origin','padding-bottom','20',0,''),(608951,191584,'74714','origin','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(608952,191586,'74716','origin','block_type','1',0,''),(608953,191587,'74717','origin','margin_left_measure','auto',0,''),(608954,191587,'74717','origin','margin_right_measure','auto',0,''),(608955,191587,'74717','origin','max-width','560',0,''),(608956,191588,'74718','origin','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(608957,191589,'74719','origin','margin-bottom','30',0,''),(608958,191590,'74720','origin','block_type','1',0,''),(608959,191590,'74720','origin','style_class','catalog-product-wrap',0,''),(608960,191592,'74722','origin','block_type','2',0,''),(608961,191592,'74722','origin','font-weight','400',0,''),(608962,191592,'74722','origin','padding-bottom','20',0,''),(608963,191592,'74722','origin','schema','2-2',0,'8377'),(608964,191593,'74724','origin','font-weight','400',0,''),(608965,191593,'74724','origin','padding-top','20',0,''),(608966,191593,'74724','origin','padding-right','20',0,''),(608967,191593,'74724','origin','box_align','4',0,''),(608968,191593,'74724','origin','margin-bottom','50',0,''),(608969,191593,'74724','origin','align_position','horizontal',0,''),(608970,191596,'74727','origin','block_type','12',0,''),(608971,191596,'74727','origin','padding-top','15',0,''),(608972,191596,'74727','origin','padding-bottom','5',0,''),(608973,191596,'74727','origin','border-top-width','1',0,''),(608974,191596,'74727','origin','border-top-color','$content-border-1',0,''),(608975,191596,'74727','origin','schema','2-2',0,'8349'),(608976,191596,'74727','origin','margin-bottom','15',0,''),(608977,191596,'74727','origin','border-bottom-width','1',0,''),(608978,191596,'74727','origin','border-bottom-color','$content-border-1',0,''),(608979,191596,'74727','origin','schema','12-2',0,'8356'),(608980,191597,'74728','origin','padding-top','10',0,''),(608981,191597,'74728','origin','padding-bottom','10',0,''),(608982,191598,'74729','origin','block_type','2',0,''),(608983,191598,'74729','origin','schema','2-1',0,'8356'),(608984,191599,'74730','origin','font-size','30',0,''),(608985,191599,'74730','origin','font-weight','400',0,''),(608986,191599,'74730','origin','line-height','35',0,''),(608987,191599,'74730','origin','font-family','$font-1',0,''),(608988,191599,'74730','origin','line_height_measure','px',0,''),(608989,191599,'74730','origin','padding-top','5',0,''),(608990,191600,'74731','origin','box_align','4',0,''),(608991,191600,'74731','origin','margin-bottom','15',0,'8356'),(608992,191600,'74731','origin','text-align','right',0,'8356'),(608993,191600,'74731','origin','padding-top','5',0,''),(608994,191600,'74731','origin','text-align','left',0,''),(608995,191601,'74732','origin','margin-bottom','15',0,''),(608996,191601,'74732','origin','padding-top','15',0,''),(608997,191602,'1694165842.4776','origin','padding-top','10',0,''),(608998,191603,'74733','origin','text-align','right',0,''),(608999,191603,'74733','origin','width','100',0,'8349'),(609000,191603,'74733','origin','width_measure','%',0,'8349'),(609001,191603,'74733','origin','float','none',0,'8349'),(609002,191603,'74733','origin','hide_additional_buttons','1',0,''),(609003,191604,'74734','origin','text-align','right',0,''),(609004,191605,'74735','origin','cat_description','on',0,''),(609005,191605,'74735','origin','length_description','250',0,''),(609006,191605,'74735','origin','padding-bottom','20',0,''),(609007,191606,'74737','origin','document_types_id','4',0,''),(609008,191607,'74738','origin','show_address','1',0,''),(609009,191607,'74738','origin','show_time','1',0,''),(609010,191607,'74738','origin','show_qty','1',0,''),(609011,191607,'74738','origin','show_qty_level1','500',0,''),(609012,191607,'74738','origin','show_qty_level2','2000',0,''),(609013,191607,'74738','origin','text-align','right',0,''),(609014,191607,'74738','origin','margin-bottom','10',0,''),(609015,191608,'74739','origin','block_type','2',0,''),(609016,191612,'74745','origin','font-weight','400',0,''),(609017,191616,'74750','origin','font-weight','normal',0,''),(609018,191616,'74750','origin','padding-top','10',0,''),(609019,191616,'74750','origin','padding-bottom','10',0,''),(609020,191616,'74750','origin','box_align','4',0,''),(609021,191617,'74752','origin','tab_1','Description',1,''),(609022,191617,'74752','origin','tab_2','Reviews',1,''),(609023,191617,'74752','origin','font-weight','400',0,''),(609024,191617,'74752','origin','tab_1','Description',0,''),(609025,191617,'74752','origin','tab_2','Reviews',0,''),(609026,191618,'74753','origin','hTagsInline','block',0,''),(609027,191619,'74754','origin','margin-bottom','20',0,''),(609028,191619,'74754','origin','max-width','500',0,''),(609029,191620,'74755','origin','padding-bottom','10',0,''),(609030,191620,'74755','origin','padding-top','5',0,''),(609031,191621,'74757','origin','font-weight','normal',0,''),(609032,191621,'74757','origin','padding-bottom','20',0,''),(609033,191622,'74758','origin','font-weight','normal',0,''),(609034,191622,'74758','origin','padding-bottom','20',0,''),(609035,191623,'1694166186.2638','origin','block_type','1',0,''),(609036,191624,'74751','origin','font-weight','400',0,''),(609037,191624,'74751','origin','padding-bottom','20',0,''),(609038,191624,'74751','origin','show_qty_input','1',0,''),(609039,191624,'74751','origin','show_compare','1',0,''),(609040,191624,'74751','origin','listing_type','productListing',0,''),(609041,191624,'74751','origin','view_as','carousel',0,''),(609042,191624,'74751','origin','show_name','0',0,''),(609043,191624,'74751','origin','show_image','0',0,''),(609044,191624,'74751','origin','show_stock','0',0,''),(609045,191624,'74751','origin','show_description','0',0,''),(609046,191624,'74751','origin','show_model','0',0,''),(609047,191624,'74751','origin','show_properties','0',0,''),(609048,191624,'74751','origin','show_rating','0',0,''),(609049,191624,'74751','origin','show_rating_counts','0',0,''),(609050,191624,'74751','origin','show_price','0',0,''),(609051,191624,'74751','origin','show_buy_button','0',0,''),(609052,191624,'74751','origin','show_view_button','0',0,''),(609053,191624,'74751','origin','show_wishlist_button','0',0,''),(609054,191624,'74751','origin','display','none',0,'8356'),(609055,191624,'74751','origin','product_names_teg','h2',0,''),(609056,191624,'74751','origin','show_attributes','1',0,''),(609057,191624,'74751','origin','col_in_row','4',0,''),(609058,191624,'74751','origin','hide_parents','2',0,''),(609059,191625,'1694166209.3278','origin','text','<div class=\"heading-3\">##PRODUCT_ALSO_PURCHASED##</div>',0,''),(609060,191626,'1694166191.5684','origin','block_type','1',0,''),(609061,191627,'74747','origin','font-weight','400',0,''),(609062,191627,'74747','origin','padding-bottom','20',0,''),(609063,191627,'74747','origin','show_compare','1',0,''),(609064,191627,'74747','origin','show_name','0',0,''),(609065,191627,'74747','origin','show_image','0',0,''),(609066,191627,'74747','origin','show_stock','0',0,''),(609067,191627,'74747','origin','show_description','0',0,''),(609068,191627,'74747','origin','show_model','0',0,''),(609069,191627,'74747','origin','show_properties','0',0,''),(609070,191627,'74747','origin','show_rating','0',0,''),(609071,191627,'74747','origin','show_rating_counts','0',0,''),(609072,191627,'74747','origin','show_price','0',0,''),(609073,191627,'74747','origin','show_buy_button','0',0,''),(609074,191627,'74747','origin','show_view_button','0',0,''),(609075,191627,'74747','origin','show_wishlist_button','0',0,''),(609076,191627,'74747','origin','listing_type','productListing',0,''),(609077,191627,'74747','origin','col_in_row','2',0,'8356'),(609078,191627,'74747','origin','col_in_row','1',0,'8377'),(609079,191627,'74747','origin','col_in_row','4',0,''),(609080,191627,'74747','origin','hide_parents','2',0,''),(609081,191628,'1694166222.3382','origin','text','<div class=\"heading-3\">##VIEWED_PRODUCTS##</div>',0,''),(609082,191639,'74771','origin','block_type','1',0,''),(609083,191639,'74771','origin','style_class','item-holder',0,''),(609084,191639,'74771','origin','padding-top','25',0,''),(609085,191639,'74771','origin','padding-left','25',0,''),(609086,191639,'74771','origin','padding-right','25',0,''),(609087,191639,'74771','origin','padding-bottom','25',0,''),(609088,191639,'74771','origin','text-align','left',0,''),(609089,191642,'74775','origin','description_characters','90',0,''),(609090,191643,'74776','origin','text-align','right',0,''),(609091,191643,'74776','origin','margin-bottom','10',0,''),(609092,191644,'74777','origin','text-align','right',0,''),(609093,191644,'74777','origin','clear','none',0,''),(609094,191644,'74777','origin','float','left',0,''),(609095,191646,'74779','origin','block_type','2',0,''),(609096,191647,'74780','origin','margin-bottom','7',0,''),(609097,191648,'74781','origin','margin-bottom','10',0,''),(609098,191648,'74781','origin','text-align','right',0,''),(609099,191648,'74781','origin','float','right',0,''),(609100,191649,'74782','origin','clear','both',0,''),(609101,191650,'74783','origin','float','left',0,''),(609102,191650,'74783','origin','margin-right','20',0,''),(609103,191650,'74783','origin','margin-bottom','5',0,''),(609104,191652,'74785','origin','block_type','1',0,''),(609105,191653,'74786','origin','block_type','6',0,''),(609106,191653,'74786','origin','font-weight','400',0,''),(609107,191653,'74786','origin','schema','6-2',0,'8377'),(609108,191653,'74786','origin','schema','6-2',0,'8356'),(609109,191654,'74787','origin','font-weight','400',0,''),(609110,191654,'74787','origin','padding-right','40',0,''),(609111,191654,'74787','origin','padding-right','0',0,'8377'),(609112,191654,'74787','origin','padding-right','0',0,'8356'),(609113,191654,'74787','origin','margin-bottom','20',0,''),(609114,191655,'74788','origin','margin-bottom','20',0,''),(609115,191657,'74790','origin','block_type','1',0,''),(609116,191657,'74790','origin','padding-top','10',0,''),(609117,191657,'74790','origin','padding-bottom','10',0,''),(609118,191657,'74790','origin','border-bottom-width','1',0,''),(609119,191657,'74790','origin','border-bottom-color','$content-border-1',0,''),(609120,191657,'74790','origin','margin-left','0',0,''),(609121,191657,'74790','origin','margin-right','0',0,''),(609122,191658,'74791','origin','float','left',0,''),(609123,191658,'74791','origin','clear','none',0,''),(609124,191658,'74791','origin','sort_pos_3','2',0,''),(609125,191658,'74791','origin','sort_pos_4','3',0,''),(609126,191658,'74791','origin','sort_pos_10','11',0,''),(609127,191658,'74791','origin','sort_pos_9','10',0,''),(609128,191658,'74791','origin','sort_pos_11','12',0,''),(609129,191658,'74791','origin','sort_pos_12','13',0,''),(609130,191658,'74791','origin','sort_pos_14','15',0,''),(609131,191658,'74791','origin','sort_pos_13','14',0,''),(609132,191658,'74791','origin','sort_pos_8','4',0,''),(609133,191658,'74791','origin','sort_pos_7','5',0,''),(609134,191658,'74791','origin','sort_pos_2','7',0,''),(609135,191658,'74791','origin','sort_pos_1','6',0,''),(609136,191658,'74791','origin','sort_pos_6','9',0,''),(609137,191658,'74791','origin','sort_pos_5','8',0,''),(609138,191658,'74791','origin','sort_pos_0','1',0,''),(609139,191658,'74791','origin','sort_hide_10','1',0,''),(609140,191658,'74791','origin','sort_hide_9','1',0,''),(609141,191658,'74791','origin','sort_pos_15','16',0,''),(609142,191658,'74791','origin','sort_pos_16','17',0,''),(609143,191658,'74791','origin','sort_hide_4','0',0,''),(609144,191658,'74791','origin','sort_hide_3','0',0,''),(609145,191658,'74791','origin','sort_hide_16','1',0,''),(609146,191658,'74791','origin','sort_hide_15','1',0,''),(609147,191658,'74791','origin','sort_hide_11','1',0,''),(609148,191658,'74791','origin','sort_hide_12','1',0,''),(609149,191658,'74791','origin','sort_hide_14','1',0,''),(609150,191658,'74791','origin','sort_hide_13','1',0,''),(609151,191658,'74791','origin','sort_hide_8','0',0,''),(609152,191658,'74791','origin','sort_hide_7','0',0,''),(609153,191658,'74791','origin','sort_hide_2','1',0,''),(609154,191658,'74791','origin','sort_hide_1','1',0,''),(609155,191658,'74791','origin','sort_hide_6','1',0,''),(609156,191658,'74791','origin','sort_hide_5','1',0,''),(609157,191658,'74791','origin','sort_hide_0','0',0,''),(609158,191658,'74791','origin','hide_icons','1',0,''),(609159,191659,'74792','origin','float','right',0,''),(609160,191659,'74792','origin','display','none',0,'8377'),(609161,191660,'74793','origin','float','left',0,''),(609162,191660,'74793','origin','clear','none',0,''),(609163,191660,'74793','origin','margin-left','20',0,''),(609164,191660,'74793','origin','display','none',0,'8377'),(609165,191661,'74794','origin','margin-right','20',0,''),(609166,191661,'74794','origin','float','right',0,''),(609167,191661,'74794','origin','clear','none',0,''),(609168,191661,'74794','origin','display','none',0,'8356'),(609169,191662,'74795','origin','block_type','5',0,''),(609170,191662,'74795','origin','padding-top','10',0,''),(609171,191662,'74795','origin','padding-bottom','10',0,''),(609172,191662,'74795','origin','schema','5-2',0,'8377'),(609173,191662,'74795','origin','border-top-color','$content-border-1',0,''),(609174,191662,'74795','origin','border-top-width','1',0,''),(609175,191663,'74796','origin','padding-top','3',0,''),(609176,191664,'74797','origin','float','right',0,''),(609177,191664,'74797','origin','height','31',0,''),(609178,191665,'74798','origin','col_in_row','3',0,''),(609179,191665,'74798','origin','products_align','left',0,''),(609180,191665,'74798','origin','font-weight','400',0,''),(609181,191665,'74798','origin','listing_type','productListing',0,''),(609182,191665,'74798','origin','listing_type_rows','Rows',0,''),(609183,191665,'74798','origin','show_buy_button_b2b','on',0,''),(609184,191665,'74798','origin','show_wishlist_button_b2b','1',0,''),(609185,191665,'74798','origin','show_compare_b2b','1',0,''),(609186,191665,'74798','origin','show_image','0',0,''),(609187,191665,'74798','origin','show_stock','0',0,''),(609188,191665,'74798','origin','show_description','0',0,''),(609189,191665,'74798','origin','show_model','0',0,''),(609190,191665,'74798','origin','show_properties','0',0,''),(609191,191665,'74798','origin','show_rating','0',0,''),(609192,191665,'74798','origin','show_rating_counts','0',0,''),(609193,191665,'74798','origin','show_price','0',0,''),(609194,191665,'74798','origin','show_buy_button','0',0,''),(609195,191665,'74798','origin','show_view_button','0',0,''),(609196,191665,'74798','origin','show_wishlist_button','0',0,''),(609197,191665,'74798','origin','show_compare','0',0,''),(609198,191665,'74798','origin','show_name_rows','0',0,''),(609199,191665,'74798','origin','show_image_rows','0',0,''),(609200,191665,'74798','origin','show_stock_rows','0',0,''),(609201,191665,'74798','origin','show_description_rows','0',0,''),(609202,191665,'74798','origin','show_model_rows','0',0,''),(609203,191665,'74798','origin','show_properties_rows','0',0,''),(609204,191665,'74798','origin','show_rating_rows','0',0,''),(609205,191665,'74798','origin','show_rating_counts_rows','0',0,''),(609206,191665,'74798','origin','show_price_rows','0',0,''),(609207,191665,'74798','origin','show_buy_button_rows','0',0,''),(609208,191665,'74798','origin','show_qty_input_rows','0',0,''),(609209,191665,'74798','origin','show_view_button_rows','0',0,''),(609210,191665,'74798','origin','show_wishlist_button_rows','0',0,''),(609211,191665,'74798','origin','show_compare_rows','0',0,''),(609212,191665,'74798','origin','show_name_b2b','0',0,''),(609213,191665,'74798','origin','show_image_b2b','0',0,''),(609214,191665,'74798','origin','show_stock_b2b','0',0,''),(609215,191665,'74798','origin','show_description_b2b','0',0,''),(609216,191665,'74798','origin','show_model_b2b','0',0,''),(609217,191665,'74798','origin','show_properties_b2b','0',0,''),(609218,191665,'74798','origin','show_rating_b2b','0',0,''),(609219,191665,'74798','origin','show_rating_counts_b2b','0',0,''),(609220,191665,'74798','origin','show_price_b2b','0',0,''),(609221,191665,'74798','origin','show_qty_input_b2b','0',0,''),(609222,191665,'74798','origin','show_view_button_b2b','0',0,''),(609223,191665,'74798','origin','show_attributes_b2b','0',0,''),(609224,191665,'74798','origin','items_on_page','9',0,''),(609225,191665,'74798','origin','col_in_row','2',0,'8356'),(609226,191665,'74798','origin','col_in_row','1',0,'8377'),(609227,191665,'74798','origin','product_names_teg','h2',0,''),(609228,191667,'74800','origin','block_type','1',0,''),(609229,191668,'74801','origin','margin-bottom','20',0,''),(609230,191670,'74802','origin','block_type','1',0,''),(609231,191672,'74804','origin','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(609232,191673,'74805','origin','width','680',0,''),(609233,191673,'74805','origin','font-weight','normal',0,''),(609234,191673,'74805','origin','font-size','12',0,''),(609235,191673,'74805','origin','padding-top','20',0,''),(609236,191673,'74805','origin','padding-bottom','20',0,''),(609237,191673,'74805','origin','color','$content-color-1',0,''),(609238,191674,'74806','origin','font-weight','400',0,''),(609239,191674,'74806','origin','padding-top','20',0,''),(609240,191674,'74806','origin','padding-bottom','0',0,''),(609241,191674,'74806','origin','font-size','12',0,''),(609242,191675,'74807','origin','block_type','3',0,''),(609243,191675,'74807','origin','font-weight','normal',0,''),(609244,191675,'74807','origin','padding-top','20',0,''),(609245,191676,'74808','origin','text','<p>If undelivered please return to:</p>',1,''),(609246,191676,'74808','origin','font-size','12',0,''),(609247,191676,'74808','origin','font-weight','bold',0,''),(609248,191676,'74808','origin','text','<p>If undelivered please return to:</p>',0,''),(609249,191677,'74809','origin','font-size','12',0,''),(609250,191678,'74810','origin','text','<p>Thank you for your order</p>',1,''),(609251,191678,'74810','origin','color','$color-8',0,''),(609252,191678,'74810','origin','font-size','13',0,''),(609253,191678,'74810','origin','font-weight','bold',0,''),(609254,191678,'74810','origin','padding-top','5',0,''),(609255,191678,'74810','origin','text-align','center',0,''),(609256,191678,'74810','origin','text','<p>Thank you for your order</p>',0,''),(609257,191679,'74811','origin','font-weight','400',0,''),(609258,191679,'74811','origin','text-align','center',0,''),(609259,191679,'74811','origin','padding-top','0',0,''),(609260,191679,'74811','origin','padding-left','20',0,''),(609261,191679,'74811','origin','padding-right','20',0,''),(609262,191680,'74812','origin','block_type','6',0,''),(609263,191680,'74812','origin','font-weight','normal',0,''),(609264,191680,'74812','origin','font-size','16',0,''),(609265,191681,'74813','origin','text','<p>Email:</p>',1,''),(609266,191681,'74813','origin','font-weight','normal',0,''),(609267,191681,'74813','origin','text-align','right',0,''),(609268,191681,'74813','origin','font-size','12',0,''),(609269,191681,'74813','origin','text','<p>Email:</p>',0,''),(609270,191682,'74814','origin','font-weight','normal',0,''),(609271,191682,'74814','origin','text-align','right',0,''),(609272,191682,'74814','origin','font-size','12',0,''),(609273,191683,'74815','origin','text','<p>If something has gone wrong please contact us at:</p>',1,''),(609274,191683,'74815','origin','font-size','12',0,''),(609275,191683,'74815','origin','font-weight','bold',0,''),(609276,191683,'74815','origin','text-align','right',0,''),(609277,191683,'74815','origin','text','<p>If something has gone wrong please contact us at:</p>',0,''),(609278,191684,'74816','origin','block_type','6',0,''),(609279,191684,'74816','origin','font-weight','normal',0,''),(609280,191684,'74816','origin','font-size','16',0,''),(609281,191685,'74817','origin','text','<p>Phone:</p>',1,''),(609282,191685,'74817','origin','font-weight','normal',0,''),(609283,191685,'74817','origin','text-align','right',0,''),(609284,191685,'74817','origin','font-size','12',0,''),(609285,191685,'74817','origin','text','<p>Phone:</p>',0,''),(609286,191686,'74818','origin','font-weight','normal',0,''),(609287,191686,'74818','origin','text-align','right',0,''),(609288,191686,'74818','origin','font-size','12',0,''),(609289,191687,'74819','origin','block_type','2',0,''),(609290,191687,'74819','origin','font-weight','normal',0,''),(609291,191687,'74819','origin','padding-bottom','20',0,''),(609292,191688,'74820','origin','font-weight','400',0,''),(609293,191688,'74820','origin','padding-top','20',0,''),(609294,191689,'74821','origin','block_type','11',0,''),(609295,191689,'74821','origin','font-weight','normal',0,''),(609296,191690,'74822','origin','text','<p>Phone:</p>',1,''),(609297,191690,'74822','origin','font-weight','normal',0,''),(609298,191690,'74822','origin','text-align','right',0,''),(609299,191690,'74822','origin','text','<p>Phone:</p>',0,''),(609300,191691,'74823','origin','font-weight','normal',0,''),(609301,191691,'74823','origin','text-align','right',0,''),(609302,191692,'74824','origin','block_type','11',0,''),(609303,191692,'74824','origin','font-weight','normal',0,''),(609304,191693,'74825','origin','text','<p>Web:</p>',1,''),(609305,191693,'74825','origin','font-weight','normal',0,''),(609306,191693,'74825','origin','text-align','right',0,''),(609307,191693,'74825','origin','text','<p>Web:</p>',0,''),(609308,191694,'74826','origin','font-weight','normal',0,''),(609309,191694,'74826','origin','text-align','right',0,''),(609310,191695,'74827','origin','block_type','1',0,''),(609311,191696,'74828','origin','font-weight','normal',0,''),(609312,191696,'74828','origin','text-align','right',0,''),(609313,191696,'74828','origin','padding-bottom','10',0,''),(609314,191696,'74828','origin','address_spacer',',',0,''),(609315,191696,'74828','origin','font-size','12',0,''),(609316,191697,'74829','origin','block_type','11',0,''),(609317,191697,'74829','origin','font-weight','normal',0,''),(609318,191698,'74830','origin','text','<p>Email:</p>',1,''),(609319,191698,'74830','origin','font-weight','normal',0,''),(609320,191698,'74830','origin','text-align','right',0,''),(609321,191698,'74830','origin','text','<p>Email:</p>',0,''),(609322,191699,'74831','origin','font-weight','normal',0,''),(609323,191699,'74831','origin','text-align','right',0,''),(609324,191700,'74832','origin','block_type','4',0,''),(609325,191700,'74832','origin','font-weight','normal',0,''),(609326,191700,'74832','origin','border-top-width','1',0,''),(609327,191700,'74832','origin','border-top-color','$content-border-1',0,''),(609328,191700,'74832','origin','border-left-width','1',0,''),(609329,191700,'74832','origin','border-left-color','$content-border-1',0,''),(609330,191700,'74832','origin','border-right-width','1',0,''),(609331,191700,'74832','origin','border-right-color','$content-border-1',0,''),(609332,191700,'74832','origin','border-bottom-width','1',0,''),(609333,191700,'74832','origin','border-bottom-color','$content-border-1',0,''),(609334,191701,'74833','origin','block_type','2',0,''),(609335,191701,'74833','origin','font-weight','normal',0,''),(609336,191701,'74833','origin','border-right-width','1',0,''),(609337,191701,'74833','origin','border-right-color','$content-border-1',0,''),(609338,191702,'74834','origin','block_type','1',0,''),(609339,191702,'74834','origin','font-weight','400',0,''),(609340,191702,'74834','origin','background-color','$content-bg-2',0,''),(609341,191702,'74834','origin','padding-top','10',0,''),(609342,191702,'74834','origin','padding-left','10',0,''),(609343,191702,'74834','origin','padding-right','10',0,''),(609344,191702,'74834','origin','padding-bottom','30',0,''),(609345,191703,'74835','origin','font-size','12',0,''),(609346,191704,'74836','origin','text','<p>ADDRESS:</p>\n',1,''),(609347,191704,'74836','origin','font-size','14',0,''),(609348,191704,'74836','origin','font-weight','bold',0,''),(609349,191704,'74836','origin','text','<p>ADDRESS:</p>\n',0,''),(609350,191705,'74837','origin','block_type','1',0,''),(609351,191705,'74837','origin','font-weight','normal',0,''),(609352,191705,'74837','origin','padding-top','10',0,''),(609353,191705,'74837','origin','padding-left','10',0,''),(609354,191705,'74837','origin','padding-right','10',0,''),(609355,191705,'74837','origin','padding-bottom','10',0,''),(609356,191707,'74839','origin','text','<p>E-MAIL ADDRESS:</p>',1,''),(609357,191707,'74839','origin','font-weight','bold',0,''),(609358,191707,'74839','origin','font-size','14',0,''),(609359,191707,'74839','origin','padding-top','10',0,''),(609360,191707,'74839','origin','text','<p>E-MAIL ADDRESS:</p>',0,''),(609361,191708,'74840','origin','font-weight','normal',0,''),(609362,191709,'74841','origin','font-weight','normal',0,''),(609363,191710,'74842','origin','text','<p>PHONE NUMBER:</p>',1,''),(609364,191710,'74842','origin','font-size','14',0,''),(609365,191710,'74842','origin','font-weight','bold',0,''),(609366,191710,'74842','origin','padding-top','10',0,''),(609367,191710,'74842','origin','text','<p>PHONE NUMBER:</p>',0,''),(609368,191711,'74843','origin','text','<p>CUSTOMER:</p>',1,''),(609369,191711,'74843','origin','font-size','13',0,''),(609370,191711,'74843','origin','font-weight','bold',0,''),(609371,191711,'74843','origin','text','<p>CUSTOMER:</p>',0,''),(609372,191712,'74844','origin','font-size','14',0,''),(609373,191712,'74844','origin','font-weight','bold',0,''),(609374,191712,'74844','origin','text-align','center',0,''),(609375,191712,'74844','origin','padding-bottom','10',0,''),(609376,191712,'74844','origin','padding-top','10',0,''),(609377,191713,'74845','origin','text','<p>Order date:</p>\n',1,''),(609378,191713,'74845','origin','font-weight','bold',0,''),(609379,191713,'74845','origin','text-align','center',0,''),(609380,191713,'74845','origin','font-size','12',0,''),(609381,191713,'74845','origin','text','<p>Order date:</p>\n',0,''),(609382,191714,'74846','origin','font-weight','normal',0,''),(609383,191714,'74846','origin','text-align','center',0,''),(609384,191714,'74846','origin','padding-bottom','10',0,''),(609385,191715,'74847','origin','block_type','5',0,''),(609386,191715,'74847','origin','font-weight','normal',0,''),(609387,191715,'74847','origin','border-bottom-width','1',0,''),(609388,191715,'74847','origin','border-bottom-color','$content-border-1',0,''),(609389,191715,'74847','origin','border-top-width','1',0,''),(609390,191715,'74847','origin','border-top-color','$content-border-1',0,''),(609391,191715,'74847','origin','border-left-color','$content-border-1',0,''),(609392,191715,'74847','origin','border-left-width','1',0,''),(609393,191716,'74848','origin','block_type','1',0,''),(609394,191716,'74848','origin','font-weight','normal',0,''),(609395,191716,'74848','origin','padding-top','10',0,''),(609396,191716,'74848','origin','padding-left','10',0,''),(609397,191716,'74848','origin','padding-right','10',0,''),(609398,191717,'74849','origin','font-weight','400',0,''),(609399,191717,'74849','origin','line-height','120',0,''),(609400,191717,'74849','origin','line_height_measure','%',0,''),(609401,191717,'74849','origin','font-size','12',0,''),(609402,191718,'74850','origin','text','<p>SHIPPING ADDRESS:</p>',1,''),(609403,191718,'74850','origin','font-size','14',0,''),(609404,191718,'74850','origin','font-weight','bold',0,''),(609405,191718,'74850','origin','padding-bottom','10',0,''),(609406,191718,'74850','origin','text','<p>SHIPPING ADDRESS:</p>',0,''),(609407,191719,'74851','origin','block_type','1',0,''),(609408,191720,'74852','origin','block_type','6',0,''),(609409,191721,'74853','origin','aria_name','account-menu',0,''),(609410,191722,'73374','origin','block_type','1',0,''),(609411,191722,'73374','origin','padding-top','70',0,''),(609412,191722,'73374','origin','padding-right','30',0,''),(609413,191722,'73374','origin','padding-bottom','30',0,''),(609414,191722,'73374','origin','padding-top','0',0,'8356'),(609415,191722,'73374','origin','padding-left','0',0,'8356'),(609416,191722,'73374','origin','padding-right','0',0,'8356'),(609417,191722,'73374','origin','padding-bottom','0',0,'8356'),(609460,191741,'74854','origin','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(609461,191742,'74855','origin','link','Quotation Info',0,''),(609462,191742,'74855','origin','margin-bottom','20',0,''),(609463,191743,'74856','origin','block_type','1',0,''),(609464,191744,'74857','origin','block_type','6',0,''),(609465,191744,'74857','origin','schema','6-3',0,'8356'),(609466,191745,'74858','origin','aria_name','account-menu',0,''),(609467,191746,'73374','origin','block_type','1',0,''),(609468,191746,'73374','origin','padding-top','70',0,''),(609469,191746,'73374','origin','padding-right','30',0,''),(609470,191746,'73374','origin','padding-bottom','30',0,''),(609471,191746,'73374','origin','padding-top','0',0,'8356'),(609472,191746,'73374','origin','padding-left','0',0,'8356'),(609473,191746,'73374','origin','padding-right','0',0,'8356'),(609474,191746,'73374','origin','padding-bottom','0',0,'8356'),(609517,191765,'74859','origin','block_type','3',0,''),(609518,191766,'74860','origin','block_type','1',0,''),(609519,191766,'74860','origin','padding-right','20',0,''),(609520,191766,'74860','origin','padding-bottom','20',0,''),(609521,191767,'74861','origin','orders_data','name',0,''),(609522,191768,'74862','origin','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(609523,191769,'74863','origin','block_type','1',0,''),(609524,191769,'74863','origin','padding-right','20',0,''),(609525,191769,'74863','origin','padding-bottom','20',0,''),(609526,191770,'74864','origin','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(609527,191771,'74865','origin','orders_data','telephone',0,''),(609528,191772,'74866','origin','block_type','1',0,''),(609529,191772,'74866','origin','padding-right','20',0,''),(609530,191773,'74867','origin','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(609531,191774,'74868','origin','orders_data','shipping_method',0,''),(609532,191775,'74869','origin','block_type','1',0,''),(609533,191775,'74869','origin','padding-right','20',0,''),(609534,191775,'74869','origin','padding-bottom','20',0,''),(609535,191776,'74870','origin','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(609536,191777,'74871','origin','orders_data','delivery_address',0,''),(609537,191778,'74872','origin','block_type','1',0,''),(609538,191778,'74872','origin','padding-bottom','20',0,''),(609539,191779,'74873','origin','orders_data','billing_address',0,''),(609540,191780,'74874','origin','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(609541,191781,'74875','origin','block_type','1',0,''),(609542,191782,'74876','origin','orders_data','payment_method',0,''),(609543,191783,'74877','origin','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(609544,191784,'74878','origin','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(609545,191786,'74880','origin','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(609546,191789,'74883','origin','block_type','2',0,''),(609547,191789,'74883','origin','padding-top','20',0,''),(609548,191789,'74883','origin','margin-bottom','20',0,''),(609549,191790,'74884','origin','like_button','1',0,''),(609550,191790,'74884','origin','text','IMAGE_BUTTON_BACK',0,''),(609551,191790,'74884','origin','link','Quotations',0,''),(609552,191791,'74885','origin','text','<h1>##HEADING_TITLE##</h1>',0,''),(609553,191792,'74886','origin','padding-top','20',0,''),(609554,191792,'74886','origin','padding-bottom','20',0,''),(609555,191792,'74886','origin','block_type','1',0,''),(609556,191792,'74886','origin','background-color','$content-bg-2',0,''),(609557,191794,'74888','origin','block_type','4',0,''),(609558,191795,'74889','origin','background-color','$content-bg-1',0,''),(609559,191796,'74890','origin','block_type','1',0,''),(609560,191796,'74890','origin','style_class','order-summary',0,''),(609561,191796,'74890','origin','margin-left','30',0,''),(609562,191797,'74891','origin','block_type','1',0,''),(609563,191797,'74891','origin','padding-left','20',0,''),(609564,191797,'74891','origin','padding-right','20',0,''),(609565,191797,'74891','origin','padding-bottom','30',0,''),(609566,191800,'74894','origin','block_type','1',0,''),(609567,191801,'74895','origin','block_type','6',0,''),(609568,191801,'74895','origin','schema','6-3',0,'8356'),(609569,191802,'74896','origin','aria_name','account-menu',0,''),(609570,191803,'73374','origin','block_type','1',0,''),(609571,191803,'73374','origin','padding-top','70',0,''),(609572,191803,'73374','origin','padding-right','30',0,''),(609573,191803,'73374','origin','padding-bottom','30',0,''),(609574,191803,'73374','origin','padding-top','0',0,'8356'),(609575,191803,'73374','origin','padding-left','0',0,'8356'),(609576,191803,'73374','origin','padding-right','0',0,'8356'),(609577,191803,'73374','origin','padding-bottom','0',0,'8356'),(609620,191822,'74897','origin','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(609621,191823,'74898','origin','margin-bottom','20',0,''),(609622,191824,'74899','origin','block_type','1',0,''),(609623,191826,'74901','origin','pagination','bottom',0,''),(609624,191827,'74902','origin','width','800',0,''),(609625,191828,'74903','origin','block_type','11',0,''),(609626,191828,'74903','origin','border-top-width','1',0,''),(609627,191828,'74903','origin','border-left-width','1',0,''),(609628,191828,'74903','origin','border-right-width','1',0,''),(609629,191828,'74903','origin','border-bottom-width','1',0,''),(609630,191828,'74903','origin','border-top-color','$content-border-1',0,''),(609631,191828,'74903','origin','border-left-color','$content-border-1',0,''),(609632,191828,'74903','origin','border-right-color','$content-border-1',0,''),(609633,191828,'74903','origin','border-bottom-color','$content-border-1',0,''),(609634,191829,'74904','origin','block_type','1',0,''),(609635,191829,'74904','origin','border-right-width','1',0,''),(609636,191829,'74904','origin','border-right-color','$content-border-1',0,''),(609637,191829,'74904','origin','padding-top','10',0,''),(609638,191829,'74904','origin','padding-right','10',0,''),(609639,191829,'74904','origin','padding-bottom','10',0,''),(609640,191830,'74905','origin','block_type','9',0,''),(609641,191831,'74906','origin','text','1.',0,''),(609642,191831,'74906','origin','font-size','12',0,''),(609643,191831,'74906','origin','text-align','right',0,''),(609644,191831,'74906','origin','padding-right','5',0,''),(609645,191832,'74907','origin','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(609646,191832,'74907','origin','font-size','12',0,''),(609647,191832,'74907','origin','padding-bottom','5',0,''),(609648,191833,'74908','origin','block_type','9',0,''),(609649,191834,'74909','origin','text','4.',0,''),(609650,191834,'74909','origin','font-size','12',0,''),(609651,191834,'74909','origin','text-align','right',0,''),(609652,191834,'74909','origin','margin-right','5',0,''),(609653,191835,'74910','origin','text','Our Replacement Department will process your request.',0,''),(609654,191835,'74910','origin','font-size','12',0,''),(609655,191835,'74910','origin','padding-bottom','5',0,''),(609656,191836,'74911','origin','block_type','9',0,''),(609657,191837,'74912','origin','text','3.',0,''),(609658,191837,'74912','origin','font-size','12',0,''),(609659,191837,'74912','origin','text-align','right',0,''),(609660,191837,'74912','origin','margin-right','5',0,''),(609661,191838,'74913','origin','text','Return the authorized item(s) per shipping instructions.',0,''),(609662,191838,'74913','origin','font-size','12',0,''),(609663,191838,'74913','origin','padding-bottom','5',0,''),(609664,191839,'74914','origin','block_type','9',0,''),(609665,191840,'74915','origin','text','2.',0,''),(609666,191840,'74915','origin','font-size','12',0,''),(609667,191840,'74915','origin','text-align','right',0,''),(609668,191840,'74915','origin','margin-right','5',0,''),(609669,191841,'74916','origin','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(609670,191841,'74916','origin','font-size','12',0,''),(609671,191841,'74916','origin','padding-bottom','5',0,''),(609672,191842,'74917','origin','block_type','1',0,''),(609673,191842,'74917','origin','padding-left','15',0,''),(609674,191843,'74918','origin','text','Replacement Policy:',0,''),(609675,191843,'74918','origin','font-size','14',0,''),(609676,191843,'74918','origin','padding-bottom','5',0,''),(609677,191843,'74918','origin','font-weight','bold',0,''),(609678,191844,'74919','origin','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(609679,191844,'74919','origin','font-size','11',0,''),(609680,191844,'74919','origin','font-style','italic',0,''),(609681,191844,'74919','origin','padding-bottom','5',0,''),(609682,191845,'74920','origin','block_type','1',0,''),(609683,191845,'74920','origin','border-bottom-width','1',0,''),(609684,191845,'74920','origin','border-bottom-color','$content-border-1',0,''),(609685,191846,'74921','origin','text','Return Material Authorization (RMA) Form',0,''),(609686,191846,'74921','origin','text-align','center',0,''),(609687,191846,'74921','origin','font-size','16',0,''),(609688,191846,'74921','origin','font-weight','bold',0,''),(609689,191847,'74922','origin','text-align','center',0,''),(609690,191847,'74922','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',1,''),(609691,191847,'74922','origin','padding-top','10',0,''),(609692,191847,'74922','origin','padding-bottom','10',0,''),(609693,191847,'74922','origin','logo','themes/origin/img/themes/basic/img/oscommerce_logo.png',0,''),(609694,191848,'74923','origin','block_type','1',0,''),(609695,191848,'74923','origin','padding-top','10',0,''),(609696,191848,'74923','origin','padding-left','10',0,''),(609697,191848,'74923','origin','padding-right','10',0,''),(609698,191848,'74923','origin','padding-bottom','20',0,''),(609699,191849,'74924','origin','block_type','2',0,''),(609700,191849,'74924','origin','padding-top','5',0,''),(609701,191850,'74925','origin','block_type','11',0,''),(609702,191851,'74926','origin','text','Email:',0,''),(609703,191851,'74926','origin','font-size','12',0,''),(609704,191852,'74927','origin','data','rrDelivery_email_address',0,''),(609705,191852,'74927','origin','font-size','12',0,''),(609706,191853,'74928','origin','block_type','11',0,''),(609707,191854,'74929','origin','text','Phone:',0,''),(609708,191854,'74929','origin','font-size','12',0,''),(609709,191855,'74930','origin','data','rrDelivery_telephone',0,''),(609710,191855,'74930','origin','font-size','12',0,''),(609711,191856,'74931','origin','block_type','2',0,''),(609712,191856,'74931','origin','padding-top','5',0,''),(609713,191857,'74932','origin','block_type','11',0,''),(609714,191858,'74933','origin','text','Country:',0,''),(609715,191858,'74933','origin','font-size','12',0,''),(609716,191859,'74934','origin','data','rrDelivery_country',0,''),(609717,191859,'74934','origin','font-size','12',0,''),(609718,191860,'74935','origin','block_type','11',0,''),(609719,191861,'74936','origin','text','Postcode:',0,''),(609720,191861,'74936','origin','font-size','12',0,''),(609721,191862,'74937','origin','data','rrDelivery_postcode',0,''),(609722,191862,'74937','origin','font-size','12',0,''),(609723,191863,'74938','origin','block_type','2',0,''),(609724,191863,'74938','origin','padding-top','5',0,''),(609725,191864,'74939','origin','block_type','11',0,''),(609726,191865,'74940','origin','text','City:',0,''),(609727,191865,'74940','origin','font-size','12',0,''),(609728,191866,'74941','origin','data','rrDelivery_city',0,''),(609729,191866,'74941','origin','font-size','12',0,''),(609730,191867,'74942','origin','block_type','11',0,''),(609731,191868,'74943','origin','text','State:',0,''),(609732,191868,'74943','origin','font-size','12',0,''),(609733,191869,'74944','origin','data','rrDelivery_state',0,''),(609734,191869,'74944','origin','font-size','12',0,''),(609735,191870,'74945','origin','block_type','9',0,''),(609736,191870,'74945','origin','padding-top','5',0,''),(609737,191871,'74946','origin','text','Address:',0,''),(609738,191871,'74946','origin','font-size','12',0,''),(609739,191872,'74947','origin','data','rrDelivery_street_address',0,''),(609740,191872,'74947','origin','font-size','12',0,''),(609741,191873,'74948','origin','block_type','2',0,''),(609742,191874,'74949','origin','block_type','11',0,''),(609743,191875,'74950','origin','text','Company:',0,''),(609744,191875,'74950','origin','font-size','12',0,''),(609745,191876,'74951','origin','data','rrDelivery_company',0,''),(609746,191876,'74951','origin','font-size','12',0,''),(609747,191877,'74952','origin','block_type','2',0,''),(609748,191878,'74953','origin','text','Contact Name:',0,''),(609749,191878,'74953','origin','font-size','12',0,''),(609750,191879,'74954','origin','data','rrDelivery_name',0,''),(609751,191879,'74954','origin','font-size','12',0,''),(609752,191880,'74955','origin','block_type','2',0,''),(609753,191880,'74955','origin','padding-left','10',0,''),(609754,191880,'74955','origin','padding-top','20',0,''),(609755,191880,'74955','origin','padding-right','10',0,''),(609756,191881,'74956','origin','block_type','5',0,''),(609757,191882,'74957','origin','text','RMA No:',0,''),(609758,191882,'74957','origin','font-size','12',0,''),(609759,191882,'74957','origin','font-weight','bold',0,''),(609760,191883,'74958','origin','data','rrNumber',0,''),(609761,191883,'74958','origin','font-size','12',0,''),(609762,191883,'74958','origin','font-weight','bold',0,''),(609763,191884,'74959','origin','block_type','2',0,''),(609764,191885,'74960','origin','text','Date Issued:',0,''),(609765,191885,'74960','origin','font-size','12',0,''),(609766,191885,'74960','origin','font-weight','bold',0,''),(609767,191886,'74961','origin','data','rrDateCreate',0,''),(609768,191886,'74961','origin','font-size','12',0,''),(609769,191886,'74961','origin','font-weight','bold',0,''),(609770,191887,'74962','origin','block_type','1',0,''),(609771,191888,'74963','origin','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(609772,191888,'74963','origin','font-size','12',0,''),(609773,191888,'74963','origin','font-style','italic',0,''),(609774,191888,'74963','origin','padding-bottom','20',0,''),(609775,191890,'74965','origin','block_type','1',0,''),(609776,191890,'74965','origin','border-top-width','1',0,''),(609777,191890,'74965','origin','border-left-width','1',0,''),(609778,191890,'74965','origin','border-right-width','1',0,''),(609779,191890,'74965','origin','border-bottom-width','1',0,''),(609780,191890,'74965','origin','border-top-color','$content-border-1',0,''),(609781,191890,'74965','origin','border-left-color','$content-border-1',0,''),(609782,191890,'74965','origin','border-right-color','$content-border-1',0,''),(609783,191890,'74965','origin','border-bottom-color','$content-border-1',0,''),(609784,191891,'74966','origin','block_type','11',0,''),(609785,191892,'74967','origin','block_type','1',0,''),(609786,191892,'74967','origin','padding-top','10',0,''),(609787,191892,'74967','origin','padding-right','10',0,''),(609788,191892,'74967','origin','padding-bottom','10',0,''),(609789,191892,'74967','origin','border-right-width','1',0,''),(609790,191892,'74967','origin','border-right-color','$content-border-1',0,''),(609791,191893,'74968','origin','block_type','9',0,''),(609792,191894,'74969','origin','text','4.',0,''),(609793,191894,'74969','origin','font-size','12',0,''),(609794,191894,'74969','origin','text-align','right',0,''),(609795,191894,'74969','origin','padding-right','5',0,''),(609796,191895,'74970','origin','font-size','11',0,''),(609797,191895,'74970','origin','font-style','italic',0,''),(609798,191895,'74970','origin','padding-bottom','5',0,''),(609799,191896,'74971','origin','text','Ship returned items to:',0,''),(609800,191896,'74971','origin','font-size','12',0,''),(609801,191896,'74971','origin','padding-bottom','5',0,''),(609802,191897,'74972','origin','block_type','9',0,''),(609803,191898,'74973','origin','text','3.',0,''),(609804,191898,'74973','origin','font-size','12',0,''),(609805,191898,'74973','origin','text-align','right',0,''),(609806,191898,'74973','origin','padding-right','5',0,''),(609807,191899,'74974','origin','text','Ship only the items that are authorized.',0,''),(609808,191899,'74974','origin','font-size','12',0,''),(609809,191899,'74974','origin','padding-bottom','10',0,''),(609810,191900,'74975','origin','block_type','9',0,''),(609811,191901,'74976','origin','text','1.',0,''),(609812,191901,'74976','origin','font-size','12',0,''),(609813,191901,'74976','origin','text-align','right',0,''),(609814,191901,'74976','origin','padding-right','5',0,''),(609815,191902,'74977','origin','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(609816,191902,'74977','origin','font-size','12',0,''),(609817,191902,'74977','origin','padding-bottom','10',0,''),(609818,191903,'74978','origin','block_type','1',0,''),(609819,191904,'74979','origin','text','Shipping Instructions:',0,''),(609820,191904,'74979','origin','font-weight','bold',0,''),(609821,191904,'74979','origin','font-size','14',0,''),(609822,191904,'74979','origin','padding-bottom','5',0,''),(609823,191904,'74979','origin','padding-left','10',0,''),(609824,191905,'74980','origin','block_type','9',0,''),(609825,191906,'74981','origin','text','2.',0,''),(609826,191906,'74981','origin','font-size','12',0,''),(609827,191906,'74981','origin','text-align','right',0,''),(609828,191906,'74981','origin','padding-right','5',0,''),(609829,191907,'74982','origin','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(609830,191907,'74982','origin','font-size','12',0,''),(609831,191907,'74982','origin','padding-bottom','10',0,''),(609832,191908,'74983','origin','block_type','1',0,''),(609833,191908,'74983','origin','padding-left','10',0,''),(609834,191908,'74983','origin','padding-right','10',0,''),(609835,191908,'74983','origin','padding-bottom','10',0,''),(609836,191909,'74984','origin','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(609837,191909,'74984','origin','font-size','11',0,''),(609838,191909,'74984','origin','font-style','italic',0,''),(609839,191910,'74985','origin','block_type','1',0,''),(609840,191910,'74985','origin','padding-top','10',0,''),(609841,191910,'74985','origin','padding-left','40',0,''),(609842,191910,'74985','origin','padding-right','40',0,''),(609843,191910,'74985','origin','padding-bottom','10',0,''),(609844,191911,'74986','origin','block_type','1',0,''),(609845,191911,'74986','origin','padding-top','10',0,''),(609846,191911,'74986','origin','padding-left','10',0,''),(609847,191911,'74986','origin','padding-right','10',0,''),(609848,191911,'74986','origin','padding-bottom','10',0,''),(609849,191911,'74986','origin','border-top-width','1',0,''),(609850,191911,'74986','origin','border-left-width','1',0,''),(609851,191911,'74986','origin','border-right-width','1',0,''),(609852,191911,'74986','origin','border-bottom-width','1',0,''),(609853,191911,'74986','origin','border-top-color','$content-border-1',0,''),(609854,191911,'74986','origin','border-left-color','$content-border-1',0,''),(609855,191911,'74986','origin','border-right-color','$content-border-1',0,''),(609856,191911,'74986','origin','border-bottom-color','$content-border-1',0,''),(609857,191912,'74987','origin','block_type','3',0,''),(609858,191913,'74988','origin','data','rrDelivery_name',0,''),(609859,191913,'74988','origin','font-size','9',0,''),(609860,191914,'74989','origin','block_type','2',0,''),(609861,191915,'74990','origin','text','RMA#:',0,''),(609862,191915,'74990','origin','font-size','10',0,''),(609863,191916,'74991','origin','data','rrNumber',0,''),(609864,191916,'74991','origin','font-size','9',0,''),(609865,191917,'74992','origin','block_type','5',0,''),(609866,191918,'74993','origin','font-size','9',0,''),(609867,191919,'74994','origin','block_type','1',0,''),(609868,191919,'74994','origin','padding-left','10',0,''),(609869,191919,'74994','origin','padding-right','10',0,''),(609870,191919,'74994','origin','padding-bottom','10',0,''),(609871,191920,'74995','origin','text','Use this space for additional Comments:',0,''),(609872,191920,'74995','origin','font-size','11',0,''),(609873,191920,'74995','origin','font-style','italic',0,''),(609874,191921,'74996','origin','text','&nbsp;',0,''),(609875,191921,'74996','origin','border-bottom-width','1',0,''),(609876,191921,'74996','origin','border-bottom-color','$content-border-1',0,''),(609877,191922,'74997','origin','text','&nbsp;',0,''),(609878,191922,'74997','origin','border-bottom-width','1',0,''),(609879,191922,'74997','origin','border-bottom-color','$content-border-1',0,''),(609880,191922,'74997','origin','padding-top','5',0,''),(609881,191923,'74998','origin','text','&nbsp;',0,''),(609882,191923,'74998','origin','border-bottom-width','1',0,''),(609883,191923,'74998','origin','border-bottom-color','$content-border-1',0,''),(609884,191923,'74998','origin','padding-top','5',0,''),(609885,191924,'74999','origin','text','&nbsp;',0,''),(609886,191924,'74999','origin','border-bottom-width','1',0,''),(609887,191924,'74999','origin','border-bottom-color','$content-border-1',0,''),(609888,191924,'74999','origin','padding-top','5',0,''),(609889,191925,'75000','origin','block_type','3',0,''),(609890,191925,'75000','origin','padding-top','10',0,''),(609891,191925,'75000','origin','padding-bottom','10',0,''),(609892,191925,'75000','origin','padding-right','10',0,''),(609893,191926,'75001','origin','font-size','11',0,''),(609894,191926,'75001','origin','font-weight','bold',0,''),(609895,191926,'75001','origin','text','Return Approval:',0,''),(609896,191926,'75001','origin','padding-top','5',0,''),(609897,191926,'75001','origin','padding-left','10',0,''),(609898,191927,'75002','origin','border-bottom-width','1',0,''),(609899,191927,'75002','origin','border-bottom-color','$content-border-1',0,''),(609900,191927,'75002','origin','text','&nbsp;',0,''),(609901,191928,'75003','origin','block_type','5',0,''),(609902,191929,'75004','origin','text','Date:',0,''),(609903,191929,'75004','origin','padding-top','5',0,''),(609904,191929,'75004','origin','font-size','11',0,''),(609905,191929,'75004','origin','font-weight','bold',0,''),(609906,191929,'75004','origin','padding-left','5',0,''),(609907,191930,'75005','origin','text','&nbsp;',0,''),(609908,191930,'75005','origin','border-bottom-width','1',0,''),(609909,191930,'75005','origin','border-bottom-color','$content-border-1',0,''),(609910,191931,'75006','origin','block_type','3',0,''),(609911,191931,'75006','origin','padding-right','10',0,''),(609912,191932,'75007','origin','text','Customer Signature:',0,''),(609913,191932,'75007','origin','font-weight','bold',0,''),(609914,191932,'75007','origin','font-size','11',0,''),(609915,191932,'75007','origin','padding-top','5',0,''),(609916,191932,'75007','origin','padding-left','10',0,''),(609917,191933,'75008','origin','text','&nbsp;',0,''),(609918,191933,'75008','origin','border-bottom-width','1',0,''),(609919,191933,'75008','origin','border-bottom-color','$content-border-1',0,''),(609920,191934,'75009','origin','block_type','5',0,''),(609921,191935,'75010','origin','text','Date:',0,''),(609922,191935,'75010','origin','padding-top','5',0,''),(609923,191935,'75010','origin','font-size','11',0,''),(609924,191935,'75010','origin','font-weight','bold',0,''),(609925,191935,'75010','origin','padding-left','5',0,''),(609926,191936,'75011','origin','text','&nbsp;',0,''),(609927,191936,'75011','origin','border-bottom-width','1',0,''),(609928,191936,'75011','origin','border-bottom-color','$content-border-1',0,''),(609929,191937,'75012','origin','block_type','1',0,''),(609930,191937,'75012','origin','style_class','item-holder',0,''),(609931,191937,'75012','origin','padding-top','25',0,''),(609932,191937,'75012','origin','padding-bottom','25',0,''),(609933,191937,'75012','origin','text-align','left',0,''),(609934,191937,'75012','origin','border-top-width','1',0,''),(609935,191937,'75012','origin','border-top-color','$content-border-1',0,''),(609936,191938,'75013','origin','block_type','7',0,''),(609937,191938,'75013','origin','schema','7-2',0,'8356'),(609938,191939,'75014','origin','block_type','5',0,''),(609939,191939,'75014','origin','schema','5-2',0,'8356'),(609940,191940,'75015','origin','clear','none',0,''),(609941,191940,'75015','origin','padding-right','20',0,''),(609942,191941,'75016','origin','padding-right','20',0,''),(609943,191941,'75016','origin','max-width','300',0,'8356'),(609944,191941,'75016','origin','margin_left_measure','auto',0,'8356'),(609945,191941,'75016','origin','margin_right_measure','auto',0,'8356'),(609946,191942,'75017','origin','block_type','1',0,''),(609947,191943,'75018','origin','text-align','right',0,''),(609948,191943,'75018','origin','margin-top','4',0,''),(609949,191943,'75018','origin','margin-bottom','7',0,''),(609950,191943,'75018','origin','float','left',0,''),(609951,191944,'75019','origin','padding-top','6',0,''),(609952,191944,'75019','origin','padding-left','5',0,''),(609953,191944,'75019','origin','float','left',0,''),(609954,191944,'75019','origin','clear','none',0,''),(609955,191945,'75020','origin','padding-right','20',0,''),(609956,191946,'75021','origin','description_characters','200',0,''),(609957,191946,'75021','origin','clear','none',0,''),(609958,191946,'75021','origin','padding-right','20',0,''),(609959,191947,'75022','origin','clear','none',0,''),(609960,191948,'75023','origin','margin-bottom','20',0,''),(609961,191949,'75024','origin','block_type','1',0,''),(609962,191949,'75024','origin','padding-left','40',0,''),(609963,191949,'75024','origin','style_class','right-aria',0,''),(609964,191949,'75024','origin','padding-left','0',0,'8356'),(609965,191950,'75025','origin','margin-bottom','15',0,''),(609966,191950,'75025','origin','text-align','right',0,''),(609967,191951,'75026','origin','margin-bottom','10',0,''),(609968,191951,'75026','origin','text-align','right',0,''),(609969,191952,'75027','origin','margin-bottom','10',0,''),(609970,191953,'75028','origin','text-align','right',0,''),(609971,191953,'75028','origin','margin-bottom','15',0,''),(609972,191954,'75030','origin','text-align','right',0,''),(609973,191954,'75030','origin','margin-bottom','10',0,''),(609974,191955,'75031','origin','block_type','1',0,''),(609975,191955,'75031','origin','padding-top','20',0,''),(609976,191955,'75031','origin','padding-bottom','20',0,''),(609977,191955,'75031','origin','background-color','$content-bg-2',0,''),(609978,191957,'75033','origin','block_type','4',0,''),(609979,191958,'75034','origin','padding-bottom','20',0,''),(609980,191958,'75034','origin','background-color','$content-bg-1',0,''),(609981,191959,'75035','origin','style_class','order-summary',0,''),(609982,191959,'75035','origin','padding-left','30',0,''),(609983,191959,'75035','origin','block_type','1',0,''),(609984,191960,'75036','origin','block_type','1',0,''),(609985,191960,'75036','origin','padding-left','20',0,''),(609986,191960,'75036','origin','padding-right','20',0,''),(609987,191960,'75036','origin','padding-bottom','20',0,''),(609988,191960,'75036','origin','padding-top','20',0,''),(609989,191961,'75037','origin','margin-bottom','40',0,''),(609990,191962,'75038','origin','block_type','1',0,''),(609991,191962,'75038','origin','style_class','account-samples',0,''),(609992,191963,'75039','origin','block_type','6',0,''),(609993,191963,'75039','origin','schema','6-3',0,'8356'),(609994,191964,'75040','origin','aria_name','account-menu',0,''),(609995,191965,'73374','origin','block_type','1',0,''),(609996,191965,'73374','origin','padding-top','70',0,''),(609997,191965,'73374','origin','padding-right','30',0,''),(609998,191965,'73374','origin','padding-bottom','30',0,''),(609999,191965,'73374','origin','padding-top','0',0,'8356'),(610000,191965,'73374','origin','padding-left','0',0,'8356'),(610001,191965,'73374','origin','padding-right','0',0,'8356'),(610002,191965,'73374','origin','padding-bottom','0',0,'8356'),(610045,191984,'75041','origin','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(610046,191985,'75042','origin','show_pagenation','1',0,''),(610047,191985,'75042','origin','link','Sample Info',0,''),(610048,191985,'75042','origin','margin-bottom','20',0,''),(610049,191986,'75043','origin','block_type','1',0,''),(610050,191986,'75043','origin','style_class','account-sample-info',0,''),(610051,191987,'75044','origin','block_type','6',0,''),(610052,191988,'75045','origin','aria_name','account-menu',0,''),(610053,191989,'73374','origin','block_type','1',0,''),(610054,191989,'73374','origin','padding-top','70',0,''),(610055,191989,'73374','origin','padding-right','30',0,''),(610056,191989,'73374','origin','padding-bottom','30',0,''),(610057,191989,'73374','origin','padding-top','0',0,'8356'),(610058,191989,'73374','origin','padding-left','0',0,'8356'),(610059,191989,'73374','origin','padding-right','0',0,'8356'),(610060,191989,'73374','origin','padding-bottom','0',0,'8356'),(610103,192008,'75046','origin','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(610104,192009,'75047','origin','block_type','2',0,''),(610105,192009,'75047','origin','padding-top','20',0,''),(610106,192009,'75047','origin','margin-bottom','20',0,''),(610107,192010,'75048','origin','like_button','1',0,''),(610108,192010,'75048','origin','text','IMAGE_BUTTON_BACK',0,''),(610109,192010,'75048','origin','link','Samples',0,''),(610110,192012,'75050','origin','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(610111,192015,'75053','origin','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(610112,192016,'75054','origin','block_type','3',0,''),(610113,192017,'75055','origin','block_type','1',0,''),(610114,192017,'75055','origin','padding-right','20',0,''),(610115,192017,'75055','origin','padding-bottom','20',0,''),(610116,192018,'75056','origin','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(610117,192019,'75057','origin','orders_data','telephone',0,''),(610118,192020,'75058','origin','block_type','1',0,''),(610119,192020,'75058','origin','padding-right','20',0,''),(610120,192020,'75058','origin','padding-bottom','20',0,''),(610121,192021,'75059','origin','orders_data','name',0,''),(610122,192022,'75060','origin','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(610123,192023,'75061','origin','block_type','1',0,''),(610124,192023,'75061','origin','padding-right','20',0,''),(610125,192024,'75062','origin','orders_data','shipping_method',0,''),(610126,192025,'75063','origin','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(610127,192026,'75064','origin','block_type','1',0,''),(610128,192026,'75064','origin','padding-right','20',0,''),(610129,192026,'75064','origin','padding-bottom','20',0,''),(610130,192027,'75065','origin','orders_data','delivery_address',0,''),(610131,192028,'75066','origin','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(610132,192029,'75067','origin','block_type','1',0,''),(610133,192030,'75068','origin','orders_data','payment_method',0,''),(610134,192031,'75069','origin','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(610135,192032,'75070','origin','block_type','1',0,''),(610136,192032,'75070','origin','padding-bottom','20',0,''),(610137,192033,'75071','origin','orders_data','billing_address',0,''),(610138,192034,'75072','origin','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(610139,192035,'75073','origin','block_type','1',0,''),(610140,192036,'75074','origin','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(610141,192037,'75075','origin','block_type','6',0,''),(610142,192038,'75076','origin','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(610143,192039,'75077','origin','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(610144,192040,'75078','origin','text','<div class=\"heading-4\">Categories</div>',0,''),(610145,192043,'75081','origin','class','menu-simple',0,''),(610146,192045,'75083','origin','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(610147,192046,'75084','origin','block_type','1',0,''),(610148,192047,'75085','origin','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(610149,192047,'75085','origin','style_class','middle-form',0,''),(610150,192048,'75086','origin','style_class','middle-form',0,''),(610151,192049,'75087','origin','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(610152,192050,'75088','origin','style_class','middle-form',0,''),(610153,192050,'75088','origin','margin-bottom','30',0,''),(610154,192051,'75089','origin','block_type','1',0,''),(610155,192052,'75090','origin','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(610156,192052,'75090','origin','padding-top','100',0,''),(610157,192052,'75090','origin','margin-bottom','100',0,''),(610158,192052,'75090','origin','text-align','center',0,''),(610159,192052,'75090','origin','font-size','20',0,''),(610160,192053,'94795','origin','block_type','1',0,''),(610161,192054,'94796','origin','block_type','6',0,''),(610162,192054,'94796','origin','schema','6-3',0,'8356'),(610163,192055,'94797','origin','aria_name','account-menu',0,''),(610164,192056,'73374','origin','block_type','1',0,''),(610165,192056,'73374','origin','padding-top','70',0,''),(610166,192056,'73374','origin','padding-right','30',0,''),(610167,192056,'73374','origin','padding-bottom','30',0,''),(610168,192056,'73374','origin','padding-top','0',0,'8356'),(610169,192056,'73374','origin','padding-left','0',0,'8356'),(610170,192056,'73374','origin','padding-right','0',0,'8356'),(610171,192056,'73374','origin','padding-bottom','0',0,'8356'),(610214,192075,'94798','origin','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(610215,192076,'94799','origin','text','##SUBSCRIPTION_TEXT##',0,''),(610216,192078,'1694099590.22143','origin','block_type','1',0,''),(610217,192078,'1694099590.22143','origin','background-color','$content-bg-2',0,''),(610218,192078,'1694099590.22143','origin','padding-bottom','30',0,''),(610219,192078,'1694099590.22143','origin','style_class','success-page',0,''),(610220,192078,'1694099590.22143','origin','color','$content-color-2',0,''),(610221,192079,'1694099590.340695','origin','block_type','12',0,''),(610222,192079,'1694099590.340695','origin','schema','4-2',0,'8356'),(610223,192080,'1694099590.343733','origin','block_type','1',0,''),(610224,192080,'1694099590.343733','origin','padding-right','40',0,''),(610225,192080,'1694099590.343733','origin','padding-right','0',0,'8356'),(610226,192081,'1694099590.345212','origin','block_type','2',0,''),(610227,192081,'1694099590.345212','origin','margin-bottom','20',0,''),(610228,192081,'1694099590.345212','origin','schema','2-2',0,'8349'),(610229,192081,'1694099590.345212','origin','background-color','$content-bg-1',0,''),(610230,192081,'1694099590.345212','origin','color','$content-color-1',0,''),(610231,192082,'1694099590.34749','origin','block_type','1',0,''),(610232,192082,'1694099590.34749','origin','border-right-width','20',0,''),(610233,192082,'1694099590.34749','origin','border-right-color','$content-bg-2',0,''),(610234,192082,'1694099590.34749','origin','margin-right','-10',0,''),(610235,192082,'1694099590.34749','origin','padding-right','30',0,''),(610236,192082,'1694099590.34749','origin','padding-top','20',0,''),(610237,192082,'1694099590.34749','origin','padding-left','30',0,''),(610238,192082,'1694099590.34749','origin','padding-bottom','20',0,''),(610239,192082,'1694099590.34749','origin','border-right-width','0',0,'8356'),(610240,192082,'1694099590.34749','origin','margin-right','0',0,'8356'),(610241,192082,'1694099590.34749','origin','margin-bottom','20',0,'8356'),(610242,192082,'1694099590.34749','origin','padding-left','20',0,'8356'),(610243,192082,'1694099590.34749','origin','padding-right','20',0,'8356'),(610244,192084,'1694099590.351567','origin','margin-bottom','20',0,''),(610245,192085,'1694099590.35337','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(610246,192085,'1694099590.35337','origin','padding-top','20',0,''),(610247,192086,'1694099590.360420','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(610248,192086,'1694099590.360420','origin','clear','none',0,''),(610249,192087,'1694099590.362714','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(610250,192089,'1694099590.365625','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(610251,192089,'1694099590.365625','origin','clear','none',0,''),(610252,192090,'1694099590.367789','origin','block_type','1',0,''),(610253,192090,'1694099590.367789','origin','padding-left','30',0,''),(610254,192090,'1694099590.367789','origin','border-left-width','20',0,''),(610255,192090,'1694099590.367789','origin','border-left-color','$content-bg-2',0,''),(610256,192090,'1694099590.367789','origin','margin-left','-10',0,''),(610257,192090,'1694099590.367789','origin','padding-right','30',0,''),(610258,192090,'1694099590.367789','origin','padding-top','20',0,''),(610259,192090,'1694099590.367789','origin','padding-bottom','20',0,''),(610260,192090,'1694099590.367789','origin','border-left-width','0',0,'8356'),(610261,192092,'1694099590.370690','origin','margin-bottom','20',0,''),(610262,192093,'1694099590.371953','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(610263,192093,'1694099590.371953','origin','clear','none',0,''),(610264,192094,'1694099590.373633','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(610265,192095,'1694099590.37590','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(610266,192095,'1694099590.37590','origin','clear','none',0,''),(610267,192096,'1694099590.376747','origin','text','<div class=\"page-success\">\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>',0,''),(610268,192096,'1694099590.376747','origin','background-color','$content-bg-1',0,''),(610269,192096,'1694099590.376747','origin','margin-bottom','30',0,''),(610270,192096,'1694099590.376747','origin','padding-top','30',0,''),(610271,192096,'1694099590.376747','origin','padding-bottom','30',0,''),(610272,192096,'1694099590.376747','origin','padding-left','30',0,''),(610273,192096,'1694099590.376747','origin','padding-right','30',0,''),(610274,192096,'1694099590.376747','origin','color','$content-color-1',0,''),(610275,192097,'1694099590.38020','origin','block_type','1',0,''),(610276,192097,'1694099590.38020','origin','style_class','order-summary2 hiding-box',0,''),(610277,192098,'1694099590.381373','origin','text-align','center',0,''),(610278,192098,'1694099590.381373','origin','margin-bottom','20',0,''),(610279,192099,'1694099590.382864','origin','text-align','center',0,''),(610280,192102,'1694099590.386683','origin','block_type','12',0,''),(610281,192103,'1694099590.387673','origin','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n</div>\n',0,''),(610282,192103,'1694099590.387673','origin','margin-bottom','20',0,''),(610283,192104,'1694099590.389337','origin','text-align','center',0,''),(610284,192104,'1694099590.389337','origin','padding-top','40',0,''),(610285,192105,'75097','origin','block_type','1',0,''),(610286,192106,'75098','origin','block_type','1',0,''),(610287,192106,'75098','origin','font-weight','normal',0,''),(610288,192107,'75099','origin','block_type','1',0,''),(610289,192107,'75099','origin','text-align','center',0,''),(610290,192107,'75099','origin','padding-top','30',0,''),(610291,192107,'75099','origin','margin-bottom','200',0,''),(610292,192108,'75100','origin','display','inline-block',0,''),(610293,192108,'75100','origin','clear','none',0,''),(610294,192108,'75100','origin','margin-left','20',0,''),(610295,192109,'75101','origin','display','inline-block',0,''),(610296,192110,'75102','origin','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(610297,192111,'75107','origin','width','680',0,''),(610298,192111,'75107','origin','font-weight','normal',0,''),(610299,192111,'75107','origin','font-size','12',0,''),(610300,192111,'75107','origin','padding-top','20',0,''),(610301,192111,'75107','origin','padding-bottom','20',0,''),(610302,192111,'75107','origin','color','$content-color-1',0,''),(610303,192112,'75108','origin','block_type','5',0,''),(610304,192112,'75108','origin','font-weight','normal',0,''),(610305,192112,'75108','origin','border-bottom-width','1',0,''),(610306,192112,'75108','origin','border-bottom-color','$content-border-1',0,''),(610307,192112,'75108','origin','border-top-width','1',0,''),(610308,192112,'75108','origin','border-top-color','$content-border-1',0,''),(610309,192112,'75108','origin','border-left-color','$content-border-1',0,''),(610310,192112,'75108','origin','border-left-width','1',0,''),(610311,192113,'75109','origin','block_type','1',0,''),(610312,192113,'75109','origin','font-weight','normal',0,''),(610313,192113,'75109','origin','padding-top','10',0,''),(610314,192113,'75109','origin','padding-left','10',0,''),(610315,192113,'75109','origin','padding-right','10',0,''),(610316,192114,'75110','origin','font-weight','400',0,''),(610317,192114,'75110','origin','line-height','120',0,''),(610318,192114,'75110','origin','line_height_measure','%',0,''),(610319,192114,'75110','origin','font-size','12',0,''),(610320,192115,'75111','origin','text','<p>SHIPPING ADDRESS:</p>',1,''),(610321,192115,'75111','origin','font-size','14',0,''),(610322,192115,'75111','origin','font-weight','bold',0,''),(610323,192115,'75111','origin','padding-bottom','10',0,''),(610324,192115,'75111','origin','text','<p>SHIPPING ADDRESS:</p>',0,''),(610325,192116,'75112','origin','block_type','1',0,''),(610326,192116,'75112','origin','background-color','$content-bg-2',0,''),(610327,192116,'75112','origin','padding-top','20',0,''),(610328,192116,'75112','origin','padding-left','10',0,''),(610329,192116,'75112','origin','padding-right','10',0,''),(610330,192116,'75112','origin','padding-bottom','20',0,''),(610331,192116,'75112','origin','font-size','14',0,''),(610332,192117,'75113','origin','font-weight','normal',0,''),(610333,192117,'75113','origin','text-align','right',0,''),(610334,192117,'75113','origin','font-size','14',0,''),(610335,192117,'75113','origin','box_align','3',0,''),(610336,192118,'75114','origin','block_type','3',0,''),(610337,192118,'75114','origin','font-weight','normal',0,''),(610338,192118,'75114','origin','padding-top','20',0,''),(610339,192119,'75115','origin','text','<p>If undelivered please return to:</p>',1,''),(610340,192119,'75115','origin','font-size','12',0,''),(610341,192119,'75115','origin','font-weight','bold',0,''),(610342,192119,'75115','origin','text','<p>If undelivered please return to:</p>',0,''),(610343,192120,'75116','origin','font-size','12',0,''),(610344,192121,'75117','origin','font-weight','400',0,''),(610345,192121,'75117','origin','text-align','center',0,''),(610346,192121,'75117','origin','padding-top','0',0,''),(610347,192121,'75117','origin','padding-left','20',0,''),(610348,192121,'75117','origin','padding-right','20',0,''),(610349,192122,'75118','origin','text','<p>Thank you for your order</p>',1,''),(610350,192122,'75118','origin','color','$color-8',0,''),(610351,192122,'75118','origin','font-size','13',0,''),(610352,192122,'75118','origin','font-weight','bold',0,''),(610353,192122,'75118','origin','padding-top','5',0,''),(610354,192122,'75118','origin','text-align','center',0,''),(610355,192122,'75118','origin','text','<p>Thank you for your order</p>',0,''),(610356,192123,'75119','origin','text','<p>If something has gone wrong please contact us at:</p>',1,''),(610357,192123,'75119','origin','font-size','12',0,''),(610358,192123,'75119','origin','font-weight','bold',0,''),(610359,192123,'75119','origin','text-align','right',0,''),(610360,192123,'75119','origin','text','<p>If something has gone wrong please contact us at:</p>',0,''),(610361,192124,'75120','origin','block_type','6',0,''),(610362,192124,'75120','origin','font-weight','normal',0,''),(610363,192124,'75120','origin','font-size','16',0,''),(610364,192125,'75121','origin','text','<p>Email:</p>',1,''),(610365,192125,'75121','origin','font-weight','normal',0,''),(610366,192125,'75121','origin','text-align','right',0,''),(610367,192125,'75121','origin','font-size','12',0,''),(610368,192125,'75121','origin','text','<p>Email:</p>',0,''),(610369,192126,'75122','origin','font-weight','normal',0,''),(610370,192126,'75122','origin','text-align','right',0,''),(610371,192126,'75122','origin','font-size','12',0,''),(610372,192127,'75123','origin','block_type','6',0,''),(610373,192127,'75123','origin','font-weight','normal',0,''),(610374,192127,'75123','origin','font-size','16',0,''),(610375,192128,'75124','origin','text','<p>Phone:</p>',1,''),(610376,192128,'75124','origin','font-weight','normal',0,''),(610377,192128,'75124','origin','text-align','right',0,''),(610378,192128,'75124','origin','font-size','12',0,''),(610379,192128,'75124','origin','text','<p>Phone:</p>',0,''),(610380,192129,'75125','origin','font-weight','normal',0,''),(610381,192129,'75125','origin','text-align','right',0,''),(610382,192129,'75125','origin','font-size','12',0,''),(610383,192130,'75126','origin','font-weight','400',0,''),(610384,192130,'75126','origin','padding-top','20',0,''),(610385,192130,'75126','origin','padding-bottom','0',0,''),(610386,192130,'75126','origin','font-size','12',0,''),(610387,192131,'75127','origin','block_type','2',0,''),(610388,192131,'75127','origin','font-weight','normal',0,''),(610389,192131,'75127','origin','padding-bottom','20',0,''),(610390,192132,'75128','origin','block_type','11',0,''),(610391,192132,'75128','origin','font-weight','normal',0,''),(610392,192133,'75129','origin','text','<p>Email:</p>',1,''),(610393,192133,'75129','origin','font-weight','normal',0,''),(610394,192133,'75129','origin','text-align','right',0,''),(610395,192133,'75129','origin','text','<p>Email:</p>',0,''),(610396,192134,'75130','origin','font-weight','normal',0,''),(610397,192134,'75130','origin','text-align','right',0,''),(610398,192135,'75131','origin','block_type','11',0,''),(610399,192135,'75131','origin','font-weight','normal',0,''),(610400,192136,'75132','origin','text','<p>Web:</p>',1,''),(610401,192136,'75132','origin','font-weight','normal',0,''),(610402,192136,'75132','origin','text-align','right',0,''),(610403,192136,'75132','origin','text','<p>Web:</p>',0,''),(610404,192137,'75133','origin','font-weight','normal',0,''),(610405,192137,'75133','origin','text-align','right',0,''),(610406,192138,'75134','origin','block_type','1',0,''),(610407,192139,'75135','origin','font-weight','normal',0,''),(610408,192139,'75135','origin','text-align','right',0,''),(610409,192139,'75135','origin','padding-bottom','10',0,''),(610410,192139,'75135','origin','address_spacer',',',0,''),(610411,192139,'75135','origin','font-size','12',0,''),(610412,192140,'75136','origin','block_type','11',0,''),(610413,192140,'75136','origin','font-weight','normal',0,''),(610414,192141,'75137','origin','text','<p>Phone:</p>',1,''),(610415,192141,'75137','origin','font-weight','normal',0,''),(610416,192141,'75137','origin','text-align','right',0,''),(610417,192141,'75137','origin','text','<p>Phone:</p>',0,''),(610418,192142,'75138','origin','font-weight','normal',0,''),(610419,192142,'75138','origin','text-align','right',0,''),(610420,192143,'75139','origin','block_type','4',0,''),(610421,192143,'75139','origin','font-weight','normal',0,''),(610422,192143,'75139','origin','border-top-width','1',0,''),(610423,192143,'75139','origin','border-top-color','$content-border-1',0,''),(610424,192143,'75139','origin','border-left-width','1',0,''),(610425,192143,'75139','origin','border-left-color','$content-border-1',0,''),(610426,192143,'75139','origin','border-right-width','1',0,''),(610427,192143,'75139','origin','border-right-color','$content-border-1',0,''),(610428,192143,'75139','origin','border-bottom-width','1',0,''),(610429,192143,'75139','origin','border-bottom-color','$content-border-1',0,''),(610430,192144,'75140','origin','block_type','2',0,''),(610431,192144,'75140','origin','font-weight','normal',0,''),(610432,192144,'75140','origin','border-top-width','1',0,''),(610433,192144,'75140','origin','border-top-color','$content-border-1',0,''),(610434,192144,'75140','origin','border-right-width','1',0,''),(610435,192144,'75140','origin','border-right-color','$content-border-1',0,''),(610436,192145,'75141','origin','block_type','1',0,''),(610437,192145,'75141','origin','font-weight','normal',0,''),(610438,192145,'75141','origin','padding-top','10',0,''),(610439,192145,'75141','origin','padding-left','10',0,''),(610440,192145,'75141','origin','padding-right','10',0,''),(610441,192145,'75141','origin','padding-bottom','10',0,''),(610442,192145,'75141','origin','border-right-width','1',0,''),(610443,192145,'75141','origin','border-right-color','$content-border-1',0,''),(610444,192146,'75142','origin','text','<p>Shipping via</p>',1,''),(610445,192146,'75142','origin','font-weight','bold',0,''),(610446,192146,'75142','origin','font-size','14',0,''),(610447,192146,'75142','origin','text','<p>Shipping via</p>',0,''),(610448,192148,'75144','origin','block_type','1',0,''),(610449,192148,'75144','origin','font-weight','normal',0,''),(610450,192148,'75144','origin','padding-top','10',0,''),(610451,192148,'75144','origin','padding-left','10',0,''),(610452,192148,'75144','origin','padding-right','10',0,''),(610453,192148,'75144','origin','padding-bottom','10',0,''),(610454,192149,'75145','origin','text','<p>Shipping service</p>',1,''),(610455,192149,'75145','origin','font-weight','bold',0,''),(610456,192149,'75145','origin','font-size','14',0,''),(610457,192149,'75145','origin','text','<p>Shipping service</p>',0,''),(610458,192151,'75147','origin','block_type','2',0,''),(610459,192151,'75147','origin','font-weight','normal',0,''),(610460,192151,'75147','origin','border-right-width','1',0,''),(610461,192151,'75147','origin','border-right-color','$content-border-1',0,''),(610462,192152,'75148','origin','block_type','1',0,''),(610463,192152,'75148','origin','font-weight','400',0,''),(610464,192152,'75148','origin','background-color','$content-bg-2',0,''),(610465,192152,'75148','origin','padding-top','10',0,''),(610466,192152,'75148','origin','padding-left','10',0,''),(610467,192152,'75148','origin','padding-right','10',0,''),(610468,192152,'75148','origin','padding-bottom','30',0,''),(610469,192153,'75149','origin','font-size','12',0,''),(610470,192154,'75150','origin','text','<p>INVOICE ADDRESS:</p>',1,''),(610471,192154,'75150','origin','font-size','14',0,''),(610472,192154,'75150','origin','font-weight','bold',0,''),(610473,192154,'75150','origin','text','<p>INVOICE ADDRESS:</p>',0,''),(610474,192155,'75151','origin','block_type','1',0,''),(610475,192155,'75151','origin','font-weight','normal',0,''),(610476,192155,'75151','origin','padding-top','10',0,''),(610477,192155,'75151','origin','padding-left','10',0,''),(610478,192155,'75151','origin','padding-right','10',0,''),(610479,192155,'75151','origin','padding-bottom','10',0,''),(610480,192156,'75152','origin','font-weight','normal',0,''),(610481,192157,'75153','origin','text','<p>PHONE NUMBER:</p>',1,''),(610482,192157,'75153','origin','font-size','14',0,''),(610483,192157,'75153','origin','font-weight','bold',0,''),(610484,192157,'75153','origin','padding-top','10',0,''),(610485,192157,'75153','origin','text','<p>PHONE NUMBER:</p>',0,''),(610486,192159,'75155','origin','font-weight','normal',0,''),(610487,192160,'75156','origin','text','<p>E-MAIL ADDRESS:</p>',1,''),(610488,192160,'75156','origin','font-weight','bold',0,''),(610489,192160,'75156','origin','font-size','14',0,''),(610490,192160,'75156','origin','padding-top','10',0,''),(610491,192160,'75156','origin','text','<p>E-MAIL ADDRESS:</p>',0,''),(610492,192161,'75157','origin','text','<p>CUSTOMER:</p>',1,''),(610493,192161,'75157','origin','font-size','13',0,''),(610494,192161,'75157','origin','font-weight','bold',0,''),(610495,192161,'75157','origin','text','<p>CUSTOMER:</p>',0,''),(610496,192162,'75158','origin','font-weight','normal',0,''),(610497,192162,'75158','origin','text-align','center',0,''),(610498,192162,'75158','origin','padding-bottom','10',0,''),(610499,192163,'75159','origin','text','<p>Payment date:</p>',1,''),(610500,192163,'75159','origin','font-weight','bold',0,''),(610501,192163,'75159','origin','text-align','center',0,''),(610502,192163,'75159','origin','font-size','12',0,''),(610503,192163,'75159','origin','text','<p>Payment date:</p>',0,''),(610504,192164,'75160','origin','text','<p>Payment Method:</p>',1,''),(610505,192164,'75160','origin','font-weight','bold',0,''),(610506,192164,'75160','origin','text-align','center',0,''),(610507,192164,'75160','origin','text','<p>Payment Method:</p>',0,''),(610508,192165,'75161','origin','font-size','14',0,''),(610509,192165,'75161','origin','font-weight','bold',0,''),(610510,192165,'75161','origin','text-align','center',0,''),(610511,192165,'75161','origin','padding-bottom','10',0,''),(610512,192165,'75161','origin','padding-top','10',0,''),(610513,192166,'75162','origin','font-weight','normal',0,''),(610514,192166,'75162','origin','text-align','center',0,''),(610515,192166,'75162','origin','padding-bottom','20',0,''),(610516,192167,'75163','origin','font-weight','normal',0,''),(610517,192167,'75163','origin','text-align','center',0,''),(610518,192168,'75194','origin','block_type','1',0,''),(610519,192169,'75195','origin','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(610520,192171,'75418','origin','block_type','1',0,''),(610521,192172,'75419','origin','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(610522,192172,'75419','origin','padding-top','100',0,''),(610523,192172,'75419','origin','margin-bottom','100',0,''),(610524,192172,'75419','origin','text-align','center',0,''),(610525,192172,'75419','origin','font-size','20',0,''),(610526,192173,'75420','origin','block_type','1',0,''),(610527,192173,'75420','origin','background-color','$content-bg-2',0,''),(610528,192173,'75420','origin','padding-bottom','30',0,''),(610529,192174,'75421','origin','block_type','4',0,''),(610530,192174,'75421','origin','schema','4-2',0,'8356'),(610531,192175,'75422','origin','block_type','1',0,''),(610532,192175,'75422','origin','padding-right','40',0,''),(610533,192175,'75422','origin','padding-right','0',0,'8356'),(610534,192176,'75423','origin','block_type','2',0,''),(610535,192176,'75423','origin','margin-bottom','20',0,''),(610536,192176,'75423','origin','schema','2-2',0,'8349'),(610537,192176,'75423','origin','background-color','$content-bg-1',0,''),(610538,192177,'75424','origin','block_type','1',0,''),(610539,192177,'75424','origin','border-right-width','20',0,''),(610540,192177,'75424','origin','border-right-color','$content-border-1',0,''),(610541,192177,'75424','origin','margin-right','-10',0,''),(610542,192177,'75424','origin','padding-right','30',0,''),(610543,192177,'75424','origin','padding-top','20',0,''),(610544,192177,'75424','origin','padding-left','30',0,''),(610545,192177,'75424','origin','padding-bottom','20',0,''),(610546,192177,'75424','origin','border-right-width','0',0,'8356'),(610547,192177,'75424','origin','margin-right','0',0,'8356'),(610548,192177,'75424','origin','margin-bottom','20',0,'8356'),(610549,192177,'75424','origin','padding-left','20',0,'8356'),(610550,192177,'75424','origin','padding-right','20',0,'8356'),(610551,192179,'75426','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(610552,192179,'75426','origin','clear','none',0,''),(610553,192180,'75427','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(610554,192180,'75427','origin','clear','none',0,''),(610555,192181,'75428','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(610556,192183,'75430','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(610557,192183,'75430','origin','padding-top','20',0,''),(610558,192186,'75433','origin','margin-bottom','20',0,''),(610559,192187,'75434','origin','block_type','1',0,''),(610560,192187,'75434','origin','padding-left','30',0,''),(610561,192187,'75434','origin','border-left-width','20',0,''),(610562,192187,'75434','origin','border-left-color','$content-border-1',0,''),(610563,192187,'75434','origin','margin-left','-10',0,''),(610564,192187,'75434','origin','padding-right','30',0,''),(610565,192187,'75434','origin','padding-top','20',0,''),(610566,192187,'75434','origin','padding-bottom','20',0,''),(610567,192187,'75434','origin','border-left-width','0',0,'8356'),(610568,192188,'75435','origin','margin-bottom','20',0,''),(610569,192190,'75437','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(610570,192191,'75438','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(610571,192191,'75438','origin','clear','none',0,''),(610572,192192,'75439','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(610573,192192,'75439','origin','clear','none',0,''),(610574,192193,'75440','origin','block_type','1',0,''),(610575,192193,'75440','origin','padding-right','30',0,''),(610576,192193,'75440','origin','background-color','$content-bg-1',0,''),(610577,192193,'75440','origin','padding-top','20',0,''),(610578,192193,'75440','origin','padding-left','30',0,''),(610579,192193,'75440','origin','padding-bottom','20',0,''),(610580,192193,'75440','origin','padding-left','20',0,'8356'),(610581,192193,'75440','origin','padding-right','20',0,'8356'),(610582,192195,'75442','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(610583,192196,'75443','origin','block_type','1',0,''),(610584,192196,'75443','origin','padding-top','20',0,''),(610585,192196,'75443','origin','padding-left','20',0,''),(610586,192196,'75443','origin','padding-right','20',0,''),(610587,192196,'75443','origin','padding-bottom','20',0,''),(610588,192196,'75443','origin','background-color','$content-bg-1',0,''),(610589,192196,'75443','origin','style_class','order-summary',0,''),(610590,192197,'75444','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(610591,192201,'75448','origin','block_type','1',0,''),(610592,192201,'75448','origin','background-color','$content-bg-2',0,''),(610593,192201,'75448','origin','padding-bottom','30',0,''),(610594,192202,'75449','origin','block_type','4',0,''),(610595,192202,'75449','origin','schema','4-2',0,'8356'),(610596,192203,'75450','origin','block_type','1',0,''),(610597,192203,'75450','origin','padding-right','40',0,''),(610598,192203,'75450','origin','padding-right','0',0,'8356'),(610599,192204,'75451','origin','block_type','2',0,''),(610600,192204,'75451','origin','margin-bottom','20',0,''),(610601,192204,'75451','origin','schema','2-2',0,'8349'),(610602,192204,'75451','origin','background-color','$content-bg-1',0,''),(610603,192205,'75452','origin','block_type','1',0,''),(610604,192205,'75452','origin','border-right-width','20',0,''),(610605,192205,'75452','origin','border-right-color','$content-border-1',0,''),(610606,192205,'75452','origin','margin-right','-10',0,''),(610607,192205,'75452','origin','padding-right','30',0,''),(610608,192205,'75452','origin','padding-top','20',0,''),(610609,192205,'75452','origin','padding-left','30',0,''),(610610,192205,'75452','origin','padding-bottom','20',0,''),(610611,192205,'75452','origin','border-right-width','0',0,'8356'),(610612,192205,'75452','origin','margin-right','0',0,'8356'),(610613,192205,'75452','origin','margin-bottom','20',0,'8356'),(610614,192205,'75452','origin','padding-left','20',0,'8356'),(610615,192205,'75452','origin','padding-right','20',0,'8356'),(610616,192206,'75453','origin','margin-bottom','20',0,''),(610617,192209,'75456','origin','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(610618,192209,'75456','origin','padding-top','20',0,''),(610619,192211,'75458','origin','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(610620,192211,'75458','origin','clear','none',0,''),(610621,192213,'75460','origin','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(610622,192214,'75461','origin','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(610623,192214,'75461','origin','clear','none',0,''),(610624,192215,'75462','origin','block_type','1',0,''),(610625,192215,'75462','origin','padding-left','30',0,''),(610626,192215,'75462','origin','border-left-width','20',0,''),(610627,192215,'75462','origin','border-left-color','$content-border-1',0,''),(610628,192215,'75462','origin','margin-left','-10',0,''),(610629,192215,'75462','origin','padding-right','30',0,''),(610630,192215,'75462','origin','padding-top','20',0,''),(610631,192215,'75462','origin','padding-bottom','20',0,''),(610632,192215,'75462','origin','border-left-width','0',0,'8356'),(610633,192216,'75463','origin','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(610634,192217,'75464','origin','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(610635,192217,'75464','origin','clear','none',0,''),(610636,192218,'75465','origin','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(610637,192218,'75465','origin','clear','none',0,''),(610638,192219,'75466','origin','margin-bottom','20',0,''),(610639,192221,'75468','origin','block_type','1',0,''),(610640,192221,'75468','origin','padding-right','30',0,''),(610641,192221,'75468','origin','background-color','$content-bg-1',0,''),(610642,192221,'75468','origin','padding-top','20',0,''),(610643,192221,'75468','origin','padding-left','30',0,''),(610644,192221,'75468','origin','padding-bottom','20',0,''),(610645,192221,'75468','origin','padding-left','20',0,'8356'),(610646,192221,'75468','origin','padding-right','20',0,'8356'),(610647,192222,'75469','origin','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(610648,192224,'75471','origin','block_type','1',0,''),(610649,192224,'75471','origin','padding-top','20',0,''),(610650,192224,'75471','origin','padding-left','20',0,''),(610651,192224,'75471','origin','padding-right','20',0,''),(610652,192224,'75471','origin','padding-bottom','20',0,''),(610653,192224,'75471','origin','background-color','$content-bg-1',0,''),(610654,192224,'75471','origin','style_class','order-summary',0,''),(610655,192227,'75474','origin','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(610656,192229,'75540','origin','block_type','1',0,''),(610657,192230,'75541','origin','block_type','6',0,''),(610658,192230,'75541','origin','schema','6-3',0,'8356'),(610659,192231,'75542','origin','aria_name','account-menu',0,''),(610660,192232,'73374','origin','block_type','1',0,''),(610661,192232,'73374','origin','padding-top','70',0,''),(610662,192232,'73374','origin','padding-right','30',0,''),(610663,192232,'73374','origin','padding-bottom','30',0,''),(610664,192232,'73374','origin','padding-top','0',0,'8356'),(610665,192232,'73374','origin','padding-left','0',0,'8356'),(610666,192232,'73374','origin','padding-right','0',0,'8356'),(610667,192232,'73374','origin','padding-bottom','0',0,'8356'),(610668,192233,'73375','origin','block_type','1',0,''),(610669,192233,'73375','origin','style_class','account-menu',0,''),(610670,192234,'73376','origin','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(610671,192234,'73376','origin','style_class','heading-settings',0,''),(610672,192235,'73377','origin','link','logoff',0,''),(610673,192236,'73378','origin','link','delete',0,''),(610674,192236,'73378','origin','text','DELETE_ACCOUNT',0,''),(610675,192237,'73379','origin','text','TEXT_DASHBOARD',0,''),(610676,192237,'73379','origin','font-family','$font-1',0,''),(610677,192237,'73379','origin','font-size','18',0,''),(610678,192237,'73379','origin','text-transform','uppercase',0,''),(610679,192238,'73380','origin','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(610680,192238,'73380','origin','style_class','heading-saved-lists',0,''),(610681,192239,'73381','origin','link','Personal Catalog',0,''),(610682,192239,'73381','origin','text','TEXT_PERSONAL_CATALOG',0,''),(610683,192239,'73381','origin','hide_link','personal_catalog',0,''),(610684,192240,'73382','origin','link','Order History',0,''),(610685,192240,'73382','origin','text','HEADING_ORDER_HISTORY',0,''),(610686,192240,'73382','origin','active_link','Order History Info,Order pay',0,''),(610687,192241,'73383','origin','link','Address Book',0,''),(610688,192241,'73383','origin','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(610689,192242,'73384','origin','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(610690,192242,'73384','origin','style_class','heading-ordered-items',0,''),(610691,192243,'73385','origin','link','Wishlist',0,''),(610692,192243,'73385','origin','hide_link','wishlist',0,''),(610693,192243,'73385','origin','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(610694,192244,'73386','origin','link','My password',0,''),(610695,192244,'73386','origin','text','TEXT_MY_PASSWORD',0,''),(610696,192245,'73387','origin','link','Samples',0,''),(610697,192245,'73387','origin','text','TEXT_HEADING_SAMPLE_CART',0,''),(610698,192245,'73387','origin','hide_link','samples',0,''),(610699,192246,'73388','origin','link','Review',0,''),(610700,192246,'73388','origin','text','REVIEWS',0,''),(610701,192247,'73389','origin','link','Quotations',0,''),(610702,192247,'73389','origin','hide_link','quotations',0,''),(610703,192247,'73389','origin','text','TEXT_HEADING_QUOTE_CART',0,''),(610704,192248,'73390','origin','link','Account edit',0,''),(610705,192248,'73390','origin','text','ACCOUNT_EDIT',0,''),(610706,192249,'73391','origin','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(610707,192249,'73391','origin','style_class','heading-settings',0,''),(610708,192250,'73392','origin','link','trade_form',0,''),(610709,192250,'73392','origin','text','TRADE_FORM',0,''),(610710,192251,'75543','origin','margin-bottom','20',0,''),(610711,192252,'75544','origin','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(610712,192253,'75545','origin','block_type','1',0,''),(610713,192253,'75545','origin','padding-top','20',0,''),(610714,192253,'75545','origin','padding-bottom','20',0,''),(610715,192255,'75547','origin','padding-top','20',0,''),(610716,192255,'75547','origin','padding-bottom','20',0,''),(610717,192256,'73349','new_theme','text','##TEXT_PAGE_NOT_FOUND##',0,''),(610718,192256,'73349','new_theme','text-align','center',0,''),(610719,192256,'73349','new_theme','padding-top','100',0,''),(610720,192256,'73349','new_theme','padding-bottom','100',0,''),(610721,192257,'73350','new_theme','block_type','1',0,''),(610722,192257,'73350','new_theme','style_class','account-index',0,''),(610723,192258,'73351','new_theme','block_type','6',0,''),(610724,192258,'73351','new_theme','schema','6-3',0,'8451'),(610725,192259,'73352','new_theme','aria_name','account-menu',0,''),(610726,192260,'73374','new_theme','block_type','1',0,''),(610727,192260,'73374','new_theme','padding-top','70',0,''),(610728,192260,'73374','new_theme','padding-right','30',0,''),(610729,192260,'73374','new_theme','padding-bottom','30',0,''),(610730,192260,'73374','new_theme','padding-top','0',0,'8451'),(610731,192260,'73374','new_theme','padding-left','0',0,'8451'),(610732,192260,'73374','new_theme','padding-right','0',0,'8451'),(610733,192260,'73374','new_theme','padding-bottom','0',0,'8451'),(610776,192279,'1704978704.8413','new_theme','block_type','1',0,''),(610777,192280,'73353','new_theme','link','Order History Info',0,''),(610778,192280,'73353','new_theme','text','TEXT_VIEW',0,''),(610779,192280,'73353','new_theme','max_orders','3',0,''),(610780,192280,'73353','new_theme','link_pay','Order pay',0,''),(610781,192280,'73353','new_theme','margin-bottom','30',0,''),(610782,192280,'73353','new_theme','text_pay','ORDER_PAY',0,''),(610783,192281,'73354','new_theme','text','<div class=\"heading-3\">##HEADER_ORDER_OVERVIEW##</div>',0,''),(610784,192282,'73357','new_theme','text','<h1>##HEADING_TITLE##</h1>',0,''),(610785,192283,'1705060269.3517','new_theme','block_type','1',0,''),(610786,192283,'1705060269.3517','new_theme','padding-top','20',0,''),(610787,192283,'1705060269.3517','new_theme','padding-left','20',0,''),(610788,192283,'1705060269.3517','new_theme','padding-right','20',0,''),(610789,192283,'1705060269.3517','new_theme','padding-bottom','20',0,''),(610790,192283,'1705060269.3517','new_theme','margin-bottom','30',0,''),(610791,192283,'1705060269.3517','new_theme','border-top-width','1',0,''),(610792,192283,'1705060269.3517','new_theme','border-left-width','1',0,''),(610793,192283,'1705060269.3517','new_theme','border-right-width','1',0,''),(610794,192283,'1705060269.3517','new_theme','border-bottom-width','1',0,''),(610795,192283,'1705060269.3517','new_theme','border-top-color','$content-border-1',0,''),(610796,192283,'1705060269.3517','new_theme','border-left-color','$content-border-1',0,''),(610797,192283,'1705060269.3517','new_theme','border-right-color','$content-border-1',0,''),(610798,192283,'1705060269.3517','new_theme','border-bottom-color','$content-border-1',0,''),(610799,192283,'1705060269.3517','new_theme','style_class','account-content-top',0,''),(610800,192284,'1705060551.6998','new_theme','block_type','1',0,''),(610801,192285,'73361','new_theme','text','<div class=\"account_title order_count\">##DATE_LAST_ORDERED##</div>',0,''),(610802,192285,'73361','new_theme','font-family','trueloaded',0,'3'),(610803,192285,'73361','new_theme','content','\\e920',0,'3'),(610804,192285,'73361','new_theme','color','$highlight-color-3',0,'3'),(610805,192285,'73361','new_theme','font-size','30',0,'3'),(610806,192285,'73361','new_theme','text-align','center',0,'3'),(610807,192285,'73361','new_theme','margin-bottom','10',0,'3'),(610808,192285,'73361','new_theme','text-align','center',0,''),(610809,192285,'73361','new_theme','font-size','16',0,''),(610810,192285,'73361','new_theme','text-transform','uppercase',0,''),(610811,192285,'73361','new_theme','line-height','1',0,'3'),(610812,192285,'73361','new_theme','font-size','14',0,'8444'),(610813,192286,'73362','new_theme','font-family','$font-1',0,''),(610814,192286,'73362','new_theme','color','$highlight-color-3',0,''),(610815,192286,'73362','new_theme','font-size','14',0,''),(610816,192286,'73362','new_theme','text-align','center',0,''),(610817,192287,'1705060566.121','new_theme','block_type','1',0,''),(610818,192288,'73363','new_theme','text','<div class=\"account_title order_count\">##ORDER_COUNT##</div>',0,''),(610819,192288,'73363','new_theme','font-family','trueloaded',0,'3'),(610820,192288,'73363','new_theme','content','\\e928',0,'3'),(610821,192288,'73363','new_theme','color','$highlight-color-3',0,'3'),(610822,192288,'73363','new_theme','font-size','30',0,'3'),(610823,192288,'73363','new_theme','text-align','center',0,'3'),(610824,192288,'73363','new_theme','text-align','center',0,''),(610825,192288,'73363','new_theme','font-size','16',0,''),(610826,192288,'73363','new_theme','text-transform','uppercase',0,''),(610827,192288,'73363','new_theme','line-height','1',0,'3'),(610828,192288,'73363','new_theme','font-size','14',0,'8444'),(610829,192289,'73364','new_theme','font-family','$font-1',0,''),(610830,192289,'73364','new_theme','color','$highlight-color-3',0,''),(610831,192289,'73364','new_theme','font-size','14',0,''),(610832,192289,'73364','new_theme','text-align','center',0,''),(610833,192290,'73365','new_theme','link','download_orders',0,''),(610834,192290,'73365','new_theme','text','TEXT_DOWNLOAD_ORDERS',0,''),(610835,192290,'73365','new_theme','hide_link','orders',0,''),(610836,192290,'73365','new_theme','text-align','center',0,''),(610837,192290,'73365','new_theme','popup','2',0,''),(610838,192290,'73365','new_theme','font-size','14',0,''),(610839,192291,'1705060582.9285','new_theme','block_type','1',0,''),(610840,192292,'73366','new_theme','text','<div class=\"account_title total_ordered\">##TOTAL_ORDERED##</div>',0,''),(610841,192292,'73366','new_theme','font-family','trueloaded',0,'3'),(610842,192292,'73366','new_theme','content','\\e922',0,'3'),(610843,192292,'73366','new_theme','color','$highlight-color-3',0,'3'),(610844,192292,'73366','new_theme','font-size','30',0,'3'),(610845,192292,'73366','new_theme','line-height','1',0,'3'),(610846,192292,'73366','new_theme','font-size','16',0,''),(610847,192292,'73366','new_theme','text-align','center',0,''),(610848,192292,'73366','new_theme','text-transform','uppercase',0,''),(610849,192292,'73366','new_theme','font-size','14',0,'8444'),(610850,192293,'73367','new_theme','font-family','$font-1',0,''),(610851,192293,'73367','new_theme','color','$highlight-color-3',0,''),(610852,192293,'73367','new_theme','line-height','1',0,''),(610853,192293,'73367','new_theme','text-align','center',0,''),(610854,192293,'73367','new_theme','font-size','14',0,''),(610855,192294,'1705060591.4402','new_theme','block_type','1',0,''),(610856,192295,'73368','new_theme','text','<div class=\"account_title cred_amount\">##CREDIT_AMOUNT##</div>',0,''),(610857,192295,'73368','new_theme','content','\\e994',0,'3'),(610858,192295,'73368','new_theme','font-family','trueloaded',0,'3'),(610859,192295,'73368','new_theme','color','$highlight-color-3',0,'3'),(610860,192295,'73368','new_theme','font-size','30',0,'3'),(610861,192295,'73368','new_theme','line-height','1',0,'3'),(610862,192295,'73368','new_theme','font-size','16',0,''),(610863,192295,'73368','new_theme','text-align','center',0,''),(610864,192295,'73368','new_theme','text-transform','uppercase',0,''),(610865,192295,'73368','new_theme','font-size','14',0,'8444'),(610866,192296,'73369','new_theme','font-family','$font-1',0,''),(610867,192296,'73369','new_theme','color','$highlight-color-3',0,''),(610868,192296,'73369','new_theme','font-size','14',0,''),(610869,192296,'73369','new_theme','text-align','center',0,''),(610870,192297,'73370','new_theme','link','Gift Certificate',0,''),(610871,192297,'73370','new_theme','text','GIFT_CERTIFICATE',0,''),(610872,192297,'73370','new_theme','popup','1',0,''),(610873,192297,'73370','new_theme','text-align','center',0,''),(610874,192297,'73370','new_theme','font-size','14',0,''),(610875,192298,'1705060602.1936','new_theme','block_type','1',0,''),(610876,192299,'73371','new_theme','text','TEXT_VIEW_HISTORY',0,''),(610877,192299,'73371','new_theme','popup','1',0,''),(610878,192299,'73371','new_theme','text-align','center',0,''),(610879,192299,'73371','new_theme','link','Points Earnt History',0,''),(610880,192299,'73371','new_theme','font-size','14',0,''),(610881,192300,'73372','new_theme','font-family','$font-1',0,''),(610882,192300,'73372','new_theme','color','$highlight-color-3',0,''),(610883,192300,'73372','new_theme','font-size','14',0,''),(610884,192300,'73372','new_theme','text-align','center',0,''),(610885,192301,'73373','new_theme','text','<div class=\"account_title points_earnt\">##TEXT_POINTS_EARNT##</div>',0,''),(610886,192301,'73373','new_theme','content','\\e990',0,'3'),(610887,192301,'73373','new_theme','font-family','trueloaded',0,'3'),(610888,192301,'73373','new_theme','font-size','30',0,'3'),(610889,192301,'73373','new_theme','text-align','center',0,'3'),(610890,192301,'73373','new_theme','line-height','1',0,'3'),(610891,192301,'73373','new_theme','color','$highlight-color-3',0,'3'),(610892,192301,'73373','new_theme','font-size','16',0,''),(610893,192301,'73373','new_theme','text-align','center',0,''),(610894,192301,'73373','new_theme','text-transform','uppercase',0,''),(610895,192301,'73373','new_theme','font-size','14',0,'8444'),(610896,192302,'73374','new_theme','block_type','1',0,''),(610897,192302,'73374','new_theme','padding-top','70',0,''),(610898,192302,'73374','new_theme','padding-right','30',0,''),(610899,192302,'73374','new_theme','padding-bottom','30',0,''),(610900,192302,'73374','new_theme','padding-top','0',0,'8451'),(610901,192302,'73374','new_theme','padding-left','0',0,'8451'),(610902,192302,'73374','new_theme','padding-right','0',0,'8451'),(610903,192302,'73374','new_theme','padding-bottom','0',0,'8451'),(610946,192321,'73393','new_theme','block_type','1',0,''),(610947,192321,'73393','new_theme','style_class','account-edit-wrap',0,''),(610948,192322,'73394','new_theme','block_type','6',0,''),(610949,192322,'73394','new_theme','schema','6-3',0,'8451'),(610950,192323,'73395','new_theme','aria_name','account-menu',0,''),(610951,192324,'73374','new_theme','block_type','1',0,''),(610952,192324,'73374','new_theme','padding-top','70',0,''),(610953,192324,'73374','new_theme','padding-right','30',0,''),(610954,192324,'73374','new_theme','padding-bottom','30',0,''),(610955,192324,'73374','new_theme','padding-top','0',0,'8451'),(610956,192324,'73374','new_theme','padding-left','0',0,'8451'),(610957,192324,'73374','new_theme','padding-right','0',0,'8451'),(610958,192324,'73374','new_theme','padding-bottom','0',0,'8451'),(611001,192344,'73397','new_theme','text','<h1>##HEADING_TITLE##</h1>',0,''),(611002,192345,'73398','new_theme','block_type','1',0,''),(611003,192345,'73398','new_theme','style_class','account-address-book',0,''),(611004,192346,'73399','new_theme','block_type','6',0,''),(611005,192346,'73399','new_theme','schema','6-3',0,'8451'),(611006,192347,'73400','new_theme','aria_name','account-menu',0,''),(611007,192348,'73374','new_theme','block_type','1',0,''),(611008,192348,'73374','new_theme','padding-top','70',0,''),(611009,192348,'73374','new_theme','padding-right','30',0,''),(611010,192348,'73374','new_theme','padding-bottom','30',0,''),(611011,192348,'73374','new_theme','padding-top','0',0,'8451'),(611012,192348,'73374','new_theme','padding-left','0',0,'8451'),(611013,192348,'73374','new_theme','padding-right','0',0,'8451'),(611014,192348,'73374','new_theme','padding-bottom','0',0,'8451'),(611057,192367,'73401','new_theme','padding-top','15',0,''),(611058,192367,'73401','new_theme','padding-bottom','15',0,''),(611059,192367,'73401','new_theme','link','Address Book Process',0,''),(611060,192367,'73401','new_theme','text','EDIT',0,''),(611061,192367,'73401','new_theme','link_add','Address Book Process',0,''),(611062,192367,'73401','new_theme','like_button_add','2',0,''),(611063,192367,'73401','new_theme','text_add','IMAGE_BUTTON_ADD_ADDRESS',0,''),(611064,192368,'73402','new_theme','text','<h1>##TEXT_HEADING_ADDRESS_BOOK##</h1>',0,''),(611065,192369,'73403','new_theme','text','<div class=\"topInfo after\">\n	<div class=\"leftMes\">\n <div>##PRIMARY_ADDRESS##</div>\n <ul><li>##PRIMARY_ADDRESS_DESCRIPTION##</li></ul>\n	</div>\n	<div class=\"rightMes\"><ul><li>##TEXT_MAXIMUM_ENTRIES%MAX_ADDRESS_BOOK_ENTRIES##</li></ul></div>\n</div>',0,''),(611066,192370,'73404','new_theme','block_type','1',0,''),(611067,192370,'73404','new_theme','style_class','account-address-book-process',0,''),(611068,192371,'73405','new_theme','block_type','6',0,''),(611069,192371,'73405','new_theme','schema','6-3',0,'8451'),(611070,192372,'73406','new_theme','aria_name','account-menu',0,''),(611071,192373,'73374','new_theme','block_type','1',0,''),(611072,192373,'73374','new_theme','padding-top','70',0,''),(611073,192373,'73374','new_theme','padding-right','30',0,''),(611074,192373,'73374','new_theme','padding-bottom','30',0,''),(611075,192373,'73374','new_theme','padding-top','0',0,'8451'),(611076,192373,'73374','new_theme','padding-left','0',0,'8451'),(611077,192373,'73374','new_theme','padding-right','0',0,'8451'),(611078,192373,'73374','new_theme','padding-bottom','0',0,'8451'),(611121,192392,'73407','new_theme','text','<h1>##TEXT_HEADING_ADDRESS_BOOK_PROCESS##</h1>',0,''),(611122,192394,'73409','new_theme','block_type','1',0,''),(611123,192394,'73409','new_theme','style_class','item-holder',0,''),(611124,192394,'73409','new_theme','padding-top','25',0,''),(611125,192394,'73409','new_theme','padding-bottom','25',0,''),(611126,192394,'73409','new_theme','text-align','left',0,''),(611127,192394,'73409','new_theme','border-top-color','$content-border-1',0,''),(611128,192394,'73409','new_theme','border-top-width','1',0,''),(611129,192395,'73410','new_theme','block_type','6',0,''),(611130,192396,'73411','new_theme','padding-right','20',0,''),(611131,192397,'73412','new_theme','description_characters','200',0,''),(611132,192397,'73412','new_theme','clear','none',0,''),(611133,192397,'73412','new_theme','padding-right','20',0,''),(611134,192398,'73413','new_theme','clear','none',0,''),(611135,192400,'73415','new_theme','block_type','4',0,''),(611136,192401,'73416','new_theme','block_type','2',0,''),(611137,192402,'73417','new_theme','margin-bottom','7',0,''),(611138,192403,'73418','new_theme','clear','none',0,''),(611139,192404,'73419','new_theme','margin-bottom','20',0,''),(611140,192404,'73419','new_theme','text-align','right',0,''),(611141,192405,'73420','new_theme','padding-right','20',0,''),(611142,192406,'73421','new_theme','block_type','2',0,''),(611143,192407,'73422','new_theme','clear','none',0,''),(611144,192409,'76000','new_theme','block_type','1',0,''),(611145,192409,'76000','new_theme','style_class','item-holder',0,''),(611146,192409,'76000','new_theme','padding-top','25',0,''),(611147,192409,'76000','new_theme','padding-left','25',0,''),(611148,192409,'76000','new_theme','padding-right','25',0,''),(611149,192409,'76000','new_theme','padding-bottom','25',0,''),(611150,192409,'76000','new_theme','text-align','left',0,''),(611151,192411,'76002','new_theme','margin-bottom','7',0,''),(611152,192412,'76003','new_theme','clear','both',0,''),(611153,192415,'76006','new_theme','block_type','1',0,''),(611154,192415,'76006','new_theme','style_class','item-holder',0,''),(611155,192415,'76006','new_theme','padding-top','25',0,''),(611156,192415,'76006','new_theme','padding-left','25',0,''),(611157,192415,'76006','new_theme','padding-right','25',0,''),(611158,192415,'76006','new_theme','padding-bottom','25',0,''),(611159,192415,'76006','new_theme','text-align','left',0,''),(611160,192416,'76007','new_theme','block_type','5',0,''),(611161,192419,'76010','new_theme','margin-bottom','7',0,''),(611162,192420,'76011','new_theme','clear','both',0,''),(611163,192421,'76012','new_theme','block_type','1',0,''),(611164,192422,'76013','new_theme','block_type','6',0,''),(611165,192422,'76013','new_theme','font-weight','400',0,''),(611166,192422,'76013','new_theme','schema','6-2',0,'8472'),(611167,192422,'76013','new_theme','schema','6-2',0,'8451'),(611168,192423,'76014','new_theme','font-weight','400',0,''),(611169,192423,'76014','new_theme','padding-right','40',0,''),(611170,192423,'76014','new_theme','padding-right','0',0,'8472'),(611171,192423,'76014','new_theme','padding-right','0',0,'8451'),(611172,192424,'76015','new_theme','block_type','5',0,''),(611173,192424,'76015','new_theme','padding-top','10',0,''),(611174,192424,'76015','new_theme','padding-bottom','10',0,''),(611175,192424,'76015','new_theme','schema','5-2',0,'8472'),(611176,192424,'76015','new_theme','border-top-color','$content-border-1',0,''),(611177,192424,'76015','new_theme','border-top-width','1',0,''),(611178,192426,'76017','new_theme','float','right',0,''),(611179,192428,'76019','new_theme','col_in_row','3',0,''),(611180,192428,'76019','new_theme','products_align','left',0,''),(611181,192428,'76019','new_theme','font-weight','400',0,''),(611182,192428,'76019','new_theme','show_qty_input','0',0,''),(611183,192428,'76019','new_theme','listing_type','productListing',0,''),(611184,192428,'76019','new_theme','listing_type_rows','no',0,''),(611185,192428,'76019','new_theme','show_buy_button_b2b','on',0,''),(611186,192428,'76019','new_theme','show_wishlist_button_b2b','1',0,''),(611187,192428,'76019','new_theme','show_compare_b2b','1',0,''),(611188,192428,'76019','new_theme','show_stock','0',0,''),(611189,192428,'76019','new_theme','show_description','0',0,''),(611190,192428,'76019','new_theme','show_model','0',0,''),(611191,192428,'76019','new_theme','show_properties','0',0,''),(611192,192428,'76019','new_theme','show_rating','0',0,''),(611193,192428,'76019','new_theme','show_rating_counts','0',0,''),(611194,192428,'76019','new_theme','show_price','0',0,''),(611195,192428,'76019','new_theme','show_buy_button','0',0,''),(611196,192428,'76019','new_theme','show_view_button','0',0,''),(611197,192428,'76019','new_theme','show_wishlist_button','0',0,''),(611198,192428,'76019','new_theme','show_compare','0',0,''),(611199,192428,'76019','new_theme','show_name_rows','0',0,''),(611200,192428,'76019','new_theme','show_image_rows','0',0,''),(611201,192428,'76019','new_theme','show_stock_rows','0',0,''),(611202,192428,'76019','new_theme','show_description_rows','0',0,''),(611203,192428,'76019','new_theme','show_model_rows','0',0,''),(611204,192428,'76019','new_theme','show_properties_rows','0',0,''),(611205,192428,'76019','new_theme','show_rating_rows','0',0,''),(611206,192428,'76019','new_theme','show_rating_counts_rows','0',0,''),(611207,192428,'76019','new_theme','show_price_rows','0',0,''),(611208,192428,'76019','new_theme','show_buy_button_rows','0',0,''),(611209,192428,'76019','new_theme','show_qty_input_rows','0',0,''),(611210,192428,'76019','new_theme','show_view_button_rows','0',0,''),(611211,192428,'76019','new_theme','show_wishlist_button_rows','0',0,''),(611212,192428,'76019','new_theme','show_compare_rows','0',0,''),(611213,192428,'76019','new_theme','show_name_b2b','0',0,''),(611214,192428,'76019','new_theme','show_image_b2b','0',0,''),(611215,192428,'76019','new_theme','show_stock_b2b','0',0,''),(611216,192428,'76019','new_theme','show_description_b2b','0',0,''),(611217,192428,'76019','new_theme','show_model_b2b','0',0,''),(611218,192428,'76019','new_theme','show_properties_b2b','0',0,''),(611219,192428,'76019','new_theme','show_rating_b2b','0',0,''),(611220,192428,'76019','new_theme','show_rating_counts_b2b','0',0,''),(611221,192428,'76019','new_theme','show_price_b2b','0',0,''),(611222,192428,'76019','new_theme','show_qty_input_b2b','0',0,''),(611223,192428,'76019','new_theme','show_view_button_b2b','0',0,''),(611224,192428,'76019','new_theme','show_attributes_b2b','0',0,''),(611225,192428,'76019','new_theme','items_on_page','9',0,''),(611226,192428,'76019','new_theme','col_in_row','2',0,'8451'),(611227,192428,'76019','new_theme','col_in_row','1',0,'8472'),(611228,192428,'76019','new_theme','product_names_teg','h2',0,''),(611229,192429,'76020','new_theme','listing_type','productListing',0,''),(611230,192430,'76021','new_theme','block_type','1',0,''),(611231,192430,'76021','new_theme','padding-top','10',0,''),(611232,192430,'76021','new_theme','padding-bottom','10',0,''),(611233,192430,'76021','new_theme','border-bottom-width','1',0,''),(611234,192430,'76021','new_theme','border-bottom-color','$content-border-1',0,''),(611235,192430,'76021','new_theme','margin-left','0',0,''),(611236,192430,'76021','new_theme','margin-right','0',0,''),(611237,192431,'76022','new_theme','float','right',0,''),(611238,192431,'76022','new_theme','display','none',0,'8472'),(611239,192432,'76023','new_theme','margin-right','20',0,''),(611240,192432,'76023','new_theme','float','right',0,''),(611241,192432,'76023','new_theme','clear','none',0,''),(611242,192432,'76023','new_theme','display','none',0,'8451'),(611243,192433,'76024','new_theme','float','left',0,''),(611244,192433,'76024','new_theme','clear','none',0,''),(611245,192433,'76024','new_theme','margin-left','20',0,''),(611246,192433,'76024','new_theme','display','none',0,'8472'),(611247,192434,'76025','new_theme','float','left',0,''),(611248,192434,'76025','new_theme','clear','none',0,''),(611249,192434,'76025','new_theme','sort_pos_3','1',0,''),(611250,192434,'76025','new_theme','sort_pos_4','2',0,''),(611251,192434,'76025','new_theme','sort_pos_10','3',0,''),(611252,192434,'76025','new_theme','sort_pos_9','4',0,''),(611253,192434,'76025','new_theme','sort_pos_11','5',0,''),(611254,192434,'76025','new_theme','sort_pos_12','6',0,''),(611255,192434,'76025','new_theme','sort_pos_14','7',0,''),(611256,192434,'76025','new_theme','sort_pos_13','8',0,''),(611257,192434,'76025','new_theme','sort_pos_8','9',0,''),(611258,192434,'76025','new_theme','sort_pos_7','10',0,''),(611259,192434,'76025','new_theme','sort_pos_2','11',0,''),(611260,192434,'76025','new_theme','sort_pos_1','12',0,''),(611261,192434,'76025','new_theme','sort_pos_6','13',0,''),(611262,192434,'76025','new_theme','sort_pos_5','14',0,''),(611263,192434,'76025','new_theme','sort_pos_0','15',0,''),(611264,192434,'76025','new_theme','sort_hide_10','1',0,''),(611265,192434,'76025','new_theme','sort_hide_9','1',0,''),(611266,192434,'76025','new_theme','hide_icons','1',0,''),(611267,192434,'76025','new_theme','sort_hide_16','1',0,''),(611268,192434,'76025','new_theme','sort_hide_15','1',0,''),(611269,192434,'76025','new_theme','sort_hide_3','0',0,''),(611270,192434,'76025','new_theme','sort_hide_4','0',0,''),(611271,192434,'76025','new_theme','sort_hide_11','1',0,''),(611272,192434,'76025','new_theme','sort_hide_12','1',0,''),(611273,192434,'76025','new_theme','sort_hide_14','1',0,''),(611274,192434,'76025','new_theme','sort_hide_13','1',0,''),(611275,192434,'76025','new_theme','sort_hide_8','0',0,''),(611276,192434,'76025','new_theme','sort_hide_7','0',0,''),(611277,192434,'76025','new_theme','sort_hide_2','1',0,''),(611278,192434,'76025','new_theme','sort_hide_1','1',0,''),(611279,192434,'76025','new_theme','sort_hide_6','1',0,''),(611280,192434,'76025','new_theme','sort_hide_5','1',0,''),(611281,192434,'76025','new_theme','sort_hide_0','1',0,''),(611282,192437,'1683124632.767746','new_theme','block_type','1',0,''),(611283,192437,'1683124632.767746','new_theme','font-weight','normal',0,''),(611284,192437,'1683124632.767746','new_theme','padding-top','20',0,''),(611285,192437,'1683124632.767746','new_theme','background-color','$content-bg-2',0,''),(611286,192437,'1683124632.767746','new_theme','style_class','shopping-cart-index',0,''),(611287,192437,'1683124632.767746','new_theme','color','$content-color-2',0,''),(611288,192438,'1683124632.80670','new_theme','block_type','4',0,''),(611289,192438,'1683124632.80670','new_theme','schema','4-1',0,'8456'),(611290,192438,'1683124632.80670','new_theme','schema','4-2',0,'8451'),(611291,192439,'1683124632.809680','new_theme','block_type','1',0,''),(611292,192439,'1683124632.809680','new_theme','background-color','$content-bg-1',0,''),(611293,192439,'1683124632.809680','new_theme','padding-top','20',0,''),(611294,192439,'1683124632.809680','new_theme','padding-bottom','20',0,''),(611295,192439,'1683124632.809680','new_theme','padding-left','25',0,''),(611296,192439,'1683124632.809680','new_theme','padding-right','25',0,''),(611297,192439,'1683124632.809680','new_theme','margin-bottom','30',0,''),(611298,192439,'1683124632.809680','new_theme','color','$content-color-1',0,''),(611299,192440,'1683124632.816335','new_theme','block_type','1',0,''),(611300,192440,'1683124632.816335','new_theme','background-color','$content-bg-1',0,''),(611301,192440,'1683124632.816335','new_theme','margin-bottom','30',0,''),(611302,192440,'1683124632.816335','new_theme','color','$content-color-1',0,''),(611303,192441,'1683124632.817623','new_theme','padding-top','20',0,''),(611304,192441,'1683124632.817623','new_theme','padding-left','25',0,''),(611305,192441,'1683124632.817623','new_theme','padding-right','25',0,''),(611306,192441,'1683124632.817623','new_theme','padding-bottom','20',0,''),(611307,192442,'1683124632.818551','new_theme','block_type','2',0,''),(611308,192442,'1683124632.818551','new_theme','padding-bottom','20',0,''),(611309,192442,'1683124632.818551','new_theme','padding-top','20',0,''),(611310,192442,'1683124632.818551','new_theme','padding-left','25',0,''),(611311,192442,'1683124632.818551','new_theme','padding-right','25',0,''),(611312,192442,'1683124632.818551','new_theme','border-bottom-color','#e0e0e0',0,''),(611313,192442,'1683124632.818551','new_theme','border-bottom-width','1',0,''),(611314,192442,'1683124632.818551','new_theme','schema','2-2',0,'8451'),(611315,192443,'1683124632.820317','new_theme','float','left',0,''),(611316,192444,'1683124632.820914','new_theme','text-align','right',0,''),(611317,192444,'1683124632.820914','new_theme','clear','none',0,''),(611318,192444,'1683124632.820914','new_theme','float','right',0,''),(611319,192444,'1683124632.820914','new_theme','padding-top','22',0,''),(611320,192445,'1683124632.822588','new_theme','float','right',0,''),(611321,192445,'1683124632.822588','new_theme','padding-top','26',0,''),(611322,192446,'1683124632.823175','new_theme','block_type','3',0,''),(611323,192446,'1683124632.823175','new_theme','font-weight','400',0,''),(611324,192446,'1683124632.823175','new_theme','schema','2-2',0,'8444'),(611325,192446,'1683124632.823175','new_theme','style_class','closeable-content',0,''),(611326,192446,'1683124632.823175','new_theme','padding-top','10',0,''),(611327,192446,'1683124632.823175','new_theme','padding-left','25',0,''),(611328,192446,'1683124632.823175','new_theme','padding-right','25',0,''),(611329,192446,'1683124632.823175','new_theme','padding-bottom','20',0,''),(611330,192449,'1683124632.82683','new_theme','block_type','1',0,''),(611331,192449,'1683124632.82683','new_theme','padding-top','20',0,''),(611332,192449,'1683124632.82683','new_theme','padding-bottom','20',0,''),(611333,192449,'1683124632.82683','new_theme','padding-left','25',0,''),(611334,192449,'1683124632.82683','new_theme','padding-right','25',0,''),(611335,192449,'1683124632.82683','new_theme','background-color','$content-bg-1',0,''),(611336,192449,'1683124632.82683','new_theme','margin-bottom','30',0,''),(611337,192449,'1683124632.82683','new_theme','color','$content-color-1',0,''),(611338,192450,'1683124632.827413','new_theme','hide_parents','2',0,''),(611339,192451,'1683124632.828374','new_theme','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(611340,192452,'1683124632.829840','new_theme','block_type','1',0,''),(611341,192452,'1683124632.829840','new_theme','background-color','$content-bg-1',0,''),(611342,192452,'1683124632.829840','new_theme','padding-top','20',0,''),(611343,192452,'1683124632.829840','new_theme','padding-left','25',0,''),(611344,192452,'1683124632.829840','new_theme','padding-right','25',0,''),(611345,192452,'1683124632.829840','new_theme','padding-bottom','20',0,''),(611346,192452,'1683124632.829840','new_theme','margin-bottom','30',0,''),(611347,192452,'1683124632.829840','new_theme','style_class','closeable-box',0,''),(611348,192452,'1683124632.829840','new_theme','display','none',0,'8451'),(611349,192453,'1683124632.831459','new_theme','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(611350,192453,'1683124632.831459','new_theme','style_class','shipping-ico closeable-heading closeable-event',0,''),(611351,192454,'1683124632.832592','new_theme','font-weight','normal',0,''),(611352,192454,'1683124632.832592','new_theme','style_class','closeable-content',0,''),(611353,192454,'1683124632.832592','new_theme','padding-top','10',0,''),(611354,192454,'1683124632.832592','new_theme','hide_parents','2',0,''),(611355,192455,'1683124632.833353','new_theme','style_class','order-summary',0,''),(611356,192455,'1683124632.833353','new_theme','block_type','1',0,''),(611357,192455,'1683124632.833353','new_theme','margin-left','30',0,''),(611358,192455,'1683124632.833353','new_theme','margin-left','0',0,'8451'),(611359,192455,'1683124632.833353','new_theme','margin-bottom','30',0,'8451'),(611360,192456,'1683124632.834715','new_theme','block_type','1',0,''),(611361,192456,'1683124632.834715','new_theme','padding-left','20',0,''),(611362,192456,'1683124632.834715','new_theme','padding-right','20',0,''),(611363,192456,'1683124632.834715','new_theme','padding-bottom','20',0,''),(611364,192457,'1683124632.835884','new_theme','font-weight','400',0,''),(611365,192457,'1683124632.835884','new_theme','padding-top','12',0,'8444'),(611366,192457,'1683124632.835884','new_theme','padding-left','0',0,'8444'),(611367,192458,'1683124632.836532','new_theme','font-weight','400',0,''),(611368,192458,'1683124632.836532','new_theme','logo','themes/new_theme/img/themes/basic/img/payment.png',1,''),(611369,192458,'1683124632.836532','new_theme','padding-top','20',0,''),(611370,192458,'1683124632.836532','new_theme','padding-bottom','10',0,''),(611371,192458,'1683124632.836532','new_theme','logo','themes/new_theme/img/themes/basic/img/payment.png',0,''),(611372,192459,'1683124632.844829','new_theme','font-weight','400',0,''),(611373,192459,'1683124632.844829','new_theme','box_align','4',0,''),(611374,192459,'1683124632.844829','new_theme','text-align','center',0,'8444'),(611375,192459,'1683124632.844829','new_theme','float','none',0,'8444'),(611376,192459,'1683124632.844829','new_theme','width','100',0,'8444'),(611377,192459,'1683124632.844829','new_theme','width_measure','%',0,'8444'),(611378,192460,'1683124632.84681','new_theme','style_class','bottom-totals',0,''),(611379,192461,'1683124632.846538','new_theme','style_class','top-totals',0,''),(611380,192462,'1683124632.84726','new_theme','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(611381,192463,'94658','new_theme','block_type','1',0,''),(611382,192463,'94658','new_theme','font-weight','normal',0,''),(611383,192463,'94658','new_theme','padding-top','20',0,''),(611384,192463,'94658','new_theme','background-color','$content-bg-2',0,''),(611385,192465,'94660','new_theme','block_type','4',0,''),(611386,192465,'94660','new_theme','schema','4-1',0,'8456'),(611387,192465,'94660','new_theme','schema','4-2',0,'8451'),(611388,192466,'94661','new_theme','block_type','1',0,''),(611389,192466,'94661','new_theme','background-color','$content-bg-1',0,''),(611390,192466,'94661','new_theme','padding-top','20',0,''),(611391,192466,'94661','new_theme','padding-bottom','20',0,''),(611392,192466,'94661','new_theme','padding-left','25',0,''),(611393,192466,'94661','new_theme','padding-right','25',0,''),(611394,192466,'94661','new_theme','margin-bottom','30',0,''),(611395,192467,'94662','new_theme','col_in_row','3',0,''),(611396,192467,'94662','new_theme','show_description','1',0,''),(611397,192467,'94662','new_theme','show_model','1',0,''),(611398,192467,'94662','new_theme','show_properties','1',0,''),(611399,192467,'94662','new_theme','show_rating','1',0,''),(611400,192467,'94662','new_theme','show_rating_counts','1',0,''),(611401,192467,'94662','new_theme','show_qty_input','1',0,''),(611402,192467,'94662','new_theme','show_view_button','1',0,''),(611403,192467,'94662','new_theme','show_wishlist_button','1',0,''),(611404,192467,'94662','new_theme','show_compare','1',0,''),(611405,192467,'94662','new_theme','view_as','carousel',0,''),(611406,192467,'94662','new_theme','hide_parents','2',0,''),(611407,192468,'94663','new_theme','text','<div class=\"heading-2\">##TEXT_ALSO_INTERESTED##</div>',0,''),(611408,192468,'94663','new_theme','style_class','bell-ico',0,''),(611409,192469,'94664','new_theme','block_type','1',0,''),(611410,192469,'94664','new_theme','background-color','$content-bg-1',0,''),(611411,192469,'94664','new_theme','margin-bottom','30',0,''),(611412,192470,'94665','new_theme','padding-top','20',0,''),(611413,192470,'94665','new_theme','padding-left','25',0,''),(611414,192470,'94665','new_theme','padding-right','25',0,''),(611415,192470,'94665','new_theme','padding-bottom','20',0,''),(611416,192471,'94666','new_theme','block_type','2',0,''),(611417,192471,'94666','new_theme','padding-bottom','20',0,''),(611418,192471,'94666','new_theme','padding-top','20',0,''),(611419,192471,'94666','new_theme','padding-left','25',0,''),(611420,192471,'94666','new_theme','padding-right','25',0,''),(611421,192471,'94666','new_theme','border-bottom-color','$content-border-1',0,''),(611422,192471,'94666','new_theme','border-bottom-width','1',0,''),(611423,192471,'94666','new_theme','schema','2-2',0,'8451'),(611424,192472,'94667','new_theme','float','left',0,''),(611425,192473,'94668','new_theme','text-align','right',0,''),(611426,192473,'94668','new_theme','clear','none',0,''),(611427,192473,'94668','new_theme','float','right',0,''),(611428,192473,'94668','new_theme','padding-top','22',0,''),(611429,192474,'94669','new_theme','float','right',0,''),(611430,192474,'94669','new_theme','padding-top','26',0,''),(611431,192475,'94670','new_theme','block_type','1',0,''),(611432,192475,'94670','new_theme','padding-top','20',0,''),(611433,192475,'94670','new_theme','padding-bottom','20',0,''),(611434,192475,'94670','new_theme','padding-left','25',0,''),(611435,192475,'94670','new_theme','padding-right','25',0,''),(611436,192475,'94670','new_theme','background-color','$content-bg-1',0,''),(611437,192475,'94670','new_theme','margin-bottom','30',0,''),(611438,192476,'94671','new_theme','hide_parents','2',0,''),(611439,192477,'94672','new_theme','text','<div class=\"heading-2\">##TEXT_GA_PRODUCTS##</div>',0,''),(611440,192478,'94673','new_theme','block_type','1',0,''),(611441,192478,'94673','new_theme','background-color','$content-bg-1',0,''),(611442,192478,'94673','new_theme','padding-top','20',0,''),(611443,192478,'94673','new_theme','padding-bottom','20',0,''),(611444,192478,'94673','new_theme','padding-left','25',0,''),(611445,192478,'94673','new_theme','padding-right','25',0,''),(611446,192478,'94673','new_theme','margin-bottom','30',0,''),(611447,192478,'94673','new_theme','style_class','closeable-box',0,''),(611448,192479,'94674','new_theme','text','<div class=\"heading-2\">##TEXT_SAVINGS##</div>',0,''),(611449,192479,'94674','new_theme','style_class','savings-ico closeable-heading closeable-event',0,''),(611450,192480,'94675','new_theme','block_type','3',0,''),(611451,192480,'94675','new_theme','font-weight','400',0,''),(611452,192480,'94675','new_theme','schema','2-2',0,'8444'),(611453,192480,'94675','new_theme','style_class','closeable-content',0,''),(611454,192480,'94675','new_theme','padding-top','10',0,''),(611455,192481,'94676','new_theme','font-weight','400',0,''),(611456,192481,'94676','new_theme','padding-top','12',0,'8444'),(611457,192481,'94676','new_theme','padding-left','0',0,'8444'),(611458,192484,'94679','new_theme','block_type','1',0,''),(611459,192484,'94679','new_theme','background-color','$content-bg-1',0,''),(611460,192484,'94679','new_theme','padding-top','20',0,''),(611461,192484,'94679','new_theme','padding-left','25',0,''),(611462,192484,'94679','new_theme','padding-right','25',0,''),(611463,192484,'94679','new_theme','padding-bottom','20',0,''),(611464,192484,'94679','new_theme','margin-bottom','30',0,''),(611465,192484,'94679','new_theme','style_class','closeable-box',0,''),(611466,192484,'94679','new_theme','display','none',0,'8451'),(611467,192485,'94680','new_theme','text','<div class=\"heading-2\">##TEXT_SHIPPING##</div>',0,''),(611468,192485,'94680','new_theme','style_class','shipping-ico closeable-heading closeable-event',0,''),(611469,192486,'94681','new_theme','font-weight','normal',0,''),(611470,192486,'94681','new_theme','style_class','closeable-content',0,''),(611471,192486,'94681','new_theme','padding-top','10',0,''),(611472,192486,'94681','new_theme','hide_parents','2',0,''),(611473,192487,'94682','new_theme','style_class','order-summary',0,''),(611474,192487,'94682','new_theme','block_type','1',0,''),(611475,192487,'94682','new_theme','margin-left','30',0,''),(611476,192487,'94682','new_theme','margin-left','0',0,'8451'),(611477,192487,'94682','new_theme','margin-bottom','30',0,'8451'),(611478,192488,'94683','new_theme','text','<div class=\"heading-2\">##ORDER_SUMMARY##</div>',0,''),(611479,192489,'94684','new_theme','block_type','1',0,''),(611480,192489,'94684','new_theme','padding-left','20',0,''),(611481,192489,'94684','new_theme','padding-right','20',0,''),(611482,192489,'94684','new_theme','padding-bottom','20',0,''),(611483,192490,'94685','new_theme','font-weight','400',0,''),(611484,192490,'94685','new_theme','logo','themes/new_theme/img/themes/basic/img/payment.png',1,''),(611485,192490,'94685','new_theme','padding-top','20',0,''),(611486,192490,'94685','new_theme','padding-bottom','10',0,''),(611487,192490,'94685','new_theme','logo','themes/new_theme/img/themes/basic/img/payment.png',0,''),(611488,192491,'94686','new_theme','font-weight','400',0,''),(611489,192491,'94686','new_theme','box_align','4',0,''),(611490,192491,'94686','new_theme','text-align','center',0,'8444'),(611491,192491,'94686','new_theme','float','none',0,'8444'),(611492,192491,'94686','new_theme','width','100',0,'8444'),(611493,192491,'94686','new_theme','width_measure','%',0,'8444'),(611494,192493,'73462','new_theme','block_type','1',0,''),(611495,192494,'73463','new_theme','block_type','6',0,''),(611496,192494,'73463','new_theme','font-weight','400',0,''),(611497,192494,'73463','new_theme','schema','6-2',0,'8472'),(611498,192494,'73463','new_theme','schema','6-2',0,'8451'),(611499,192495,'73464','new_theme','font-weight','400',0,''),(611500,192495,'73464','new_theme','padding-right','40',0,''),(611501,192495,'73464','new_theme','padding-right','0',0,'8472'),(611502,192495,'73464','new_theme','padding-right','0',0,'8451'),(611503,192496,'73465','new_theme','col_in_row','3',0,''),(611504,192496,'73465','new_theme','products_align','left',0,''),(611505,192496,'73465','new_theme','font-weight','400',0,''),(611506,192496,'73465','new_theme','show_qty_input','0',0,''),(611507,192496,'73465','new_theme','listing_type','productListing',0,''),(611508,192496,'73465','new_theme','listing_type_rows','Rows',0,''),(611509,192496,'73465','new_theme','show_buy_button_b2b','on',0,''),(611510,192496,'73465','new_theme','show_wishlist_button_b2b','1',0,''),(611511,192496,'73465','new_theme','show_compare_b2b','1',0,''),(611512,192496,'73465','new_theme','show_stock','0',0,''),(611513,192496,'73465','new_theme','show_description','0',0,''),(611514,192496,'73465','new_theme','show_model','0',0,''),(611515,192496,'73465','new_theme','show_properties','0',0,''),(611516,192496,'73465','new_theme','show_rating','0',0,''),(611517,192496,'73465','new_theme','show_rating_counts','0',0,''),(611518,192496,'73465','new_theme','show_price','0',0,''),(611519,192496,'73465','new_theme','show_buy_button','0',0,''),(611520,192496,'73465','new_theme','show_view_button','0',0,''),(611521,192496,'73465','new_theme','show_wishlist_button','0',0,''),(611522,192496,'73465','new_theme','show_compare','0',0,''),(611523,192496,'73465','new_theme','show_name_rows','0',0,''),(611524,192496,'73465','new_theme','show_image_rows','0',0,''),(611525,192496,'73465','new_theme','show_stock_rows','0',0,''),(611526,192496,'73465','new_theme','show_description_rows','0',0,''),(611527,192496,'73465','new_theme','show_model_rows','0',0,''),(611528,192496,'73465','new_theme','show_properties_rows','0',0,''),(611529,192496,'73465','new_theme','show_rating_rows','0',0,''),(611530,192496,'73465','new_theme','show_rating_counts_rows','0',0,''),(611531,192496,'73465','new_theme','show_price_rows','0',0,''),(611532,192496,'73465','new_theme','show_buy_button_rows','0',0,''),(611533,192496,'73465','new_theme','show_qty_input_rows','0',0,''),(611534,192496,'73465','new_theme','show_view_button_rows','0',0,''),(611535,192496,'73465','new_theme','show_wishlist_button_rows','0',0,''),(611536,192496,'73465','new_theme','show_compare_rows','0',0,''),(611537,192496,'73465','new_theme','show_name_b2b','0',0,''),(611538,192496,'73465','new_theme','show_image_b2b','0',0,''),(611539,192496,'73465','new_theme','show_stock_b2b','0',0,''),(611540,192496,'73465','new_theme','show_description_b2b','0',0,''),(611541,192496,'73465','new_theme','show_model_b2b','0',0,''),(611542,192496,'73465','new_theme','show_properties_b2b','0',0,''),(611543,192496,'73465','new_theme','show_rating_b2b','0',0,''),(611544,192496,'73465','new_theme','show_rating_counts_b2b','0',0,''),(611545,192496,'73465','new_theme','show_price_b2b','0',0,''),(611546,192496,'73465','new_theme','show_qty_input_b2b','0',0,''),(611547,192496,'73465','new_theme','show_view_button_b2b','0',0,''),(611548,192496,'73465','new_theme','show_attributes_b2b','0',0,''),(611549,192496,'73465','new_theme','items_on_page','9',0,''),(611550,192496,'73465','new_theme','col_in_row','2',0,'8451'),(611551,192496,'73465','new_theme','col_in_row','1',0,'8472'),(611552,192496,'73465','new_theme','product_names_teg','h2',0,''),(611553,192498,'73467','new_theme','block_type','5',0,''),(611554,192498,'73467','new_theme','padding-top','10',0,''),(611555,192498,'73467','new_theme','padding-bottom','10',0,''),(611556,192498,'73467','new_theme','schema','5-2',0,'8472'),(611557,192498,'73467','new_theme','border-top-color','$content-border-1',0,''),(611558,192498,'73467','new_theme','border-top-width','1',0,''),(611559,192500,'73469','new_theme','float','right',0,''),(611560,192501,'73470','new_theme','listing_type','productListing',0,''),(611561,192503,'73472','new_theme','block_type','1',0,''),(611562,192503,'73472','new_theme','padding-top','10',0,''),(611563,192503,'73472','new_theme','padding-bottom','10',0,''),(611564,192503,'73472','new_theme','border-bottom-width','1',0,''),(611565,192503,'73472','new_theme','border-bottom-color','$content-border-1',0,''),(611566,192503,'73472','new_theme','margin-left','0',0,''),(611567,192503,'73472','new_theme','margin-right','0',0,''),(611568,192504,'73473','new_theme','float','right',0,''),(611569,192504,'73473','new_theme','display','none',0,'8472'),(611570,192505,'73474','new_theme','margin-right','20',0,''),(611571,192505,'73474','new_theme','float','right',0,''),(611572,192505,'73474','new_theme','clear','none',0,''),(611573,192505,'73474','new_theme','display','none',0,'8451'),(611574,192506,'73475','new_theme','float','left',0,''),(611575,192506,'73475','new_theme','clear','none',0,''),(611576,192506,'73475','new_theme','margin-left','20',0,''),(611577,192506,'73475','new_theme','display','none',0,'8472'),(611578,192507,'73476','new_theme','float','left',0,''),(611579,192507,'73476','new_theme','clear','none',0,''),(611580,192507,'73476','new_theme','sort_pos_3','2',0,''),(611581,192507,'73476','new_theme','sort_pos_4','3',0,''),(611582,192507,'73476','new_theme','sort_pos_10','11',0,''),(611583,192507,'73476','new_theme','sort_pos_9','10',0,''),(611584,192507,'73476','new_theme','sort_pos_11','12',0,''),(611585,192507,'73476','new_theme','sort_pos_12','13',0,''),(611586,192507,'73476','new_theme','sort_pos_14','15',0,''),(611587,192507,'73476','new_theme','sort_pos_13','14',0,''),(611588,192507,'73476','new_theme','sort_pos_8','4',0,''),(611589,192507,'73476','new_theme','sort_pos_7','5',0,''),(611590,192507,'73476','new_theme','sort_pos_2','7',0,''),(611591,192507,'73476','new_theme','sort_pos_1','6',0,''),(611592,192507,'73476','new_theme','sort_pos_6','9',0,''),(611593,192507,'73476','new_theme','sort_pos_5','8',0,''),(611594,192507,'73476','new_theme','sort_pos_0','1',0,''),(611595,192507,'73476','new_theme','sort_hide_10','1',0,''),(611596,192507,'73476','new_theme','sort_hide_9','1',0,''),(611597,192507,'73476','new_theme','hide_icons','1',0,''),(611598,192507,'73476','new_theme','sort_hide_16','1',0,''),(611599,192507,'73476','new_theme','sort_hide_15','1',0,''),(611600,192507,'73476','new_theme','sort_hide_3','0',0,''),(611601,192507,'73476','new_theme','sort_hide_4','0',0,''),(611602,192507,'73476','new_theme','sort_hide_11','1',0,''),(611603,192507,'73476','new_theme','sort_hide_12','1',0,''),(611604,192507,'73476','new_theme','sort_hide_14','1',0,''),(611605,192507,'73476','new_theme','sort_hide_13','1',0,''),(611606,192507,'73476','new_theme','sort_hide_8','0',0,''),(611607,192507,'73476','new_theme','sort_hide_7','0',0,''),(611608,192507,'73476','new_theme','sort_hide_2','1',0,''),(611609,192507,'73476','new_theme','sort_hide_1','1',0,''),(611610,192507,'73476','new_theme','sort_hide_6','1',0,''),(611611,192507,'73476','new_theme','sort_hide_5','1',0,''),(611612,192507,'73476','new_theme','sort_hide_0','0',0,''),(611613,192507,'73476','new_theme','sort_pos_15','16',0,''),(611614,192507,'73476','new_theme','sort_pos_16','17',0,''),(611615,192514,'94688','new_theme','block_type','1',0,''),(611616,192516,'94690','new_theme','block_type','6',0,''),(611617,192516,'94690','new_theme','font-weight','400',0,''),(611618,192516,'94690','new_theme','schema','6-2',0,'8472'),(611619,192516,'94690','new_theme','schema','6-2',0,'8451'),(611620,192517,'94691','new_theme','font-weight','400',0,''),(611621,192517,'94691','new_theme','padding-right','40',0,''),(611622,192517,'94691','new_theme','padding-right','0',0,'8472'),(611623,192517,'94691','new_theme','padding-right','0',0,'8451'),(611624,192519,'94693','new_theme','col_in_row','3',0,''),(611625,192519,'94693','new_theme','products_align','left',0,''),(611626,192519,'94693','new_theme','font-weight','400',0,''),(611627,192519,'94693','new_theme','show_qty_input','0',0,''),(611628,192519,'94693','new_theme','listing_type','productListing',0,''),(611629,192519,'94693','new_theme','listing_type_rows','no',0,''),(611630,192519,'94693','new_theme','show_buy_button_b2b','on',0,''),(611631,192519,'94693','new_theme','show_wishlist_button_b2b','1',0,''),(611632,192519,'94693','new_theme','show_compare_b2b','1',0,''),(611633,192519,'94693','new_theme','show_stock','0',0,''),(611634,192519,'94693','new_theme','show_description','0',0,''),(611635,192519,'94693','new_theme','show_model','0',0,''),(611636,192519,'94693','new_theme','show_properties','0',0,''),(611637,192519,'94693','new_theme','show_rating','0',0,''),(611638,192519,'94693','new_theme','show_rating_counts','0',0,''),(611639,192519,'94693','new_theme','show_price','0',0,''),(611640,192519,'94693','new_theme','show_buy_button','0',0,''),(611641,192519,'94693','new_theme','show_view_button','0',0,''),(611642,192519,'94693','new_theme','show_wishlist_button','0',0,''),(611643,192519,'94693','new_theme','show_compare','0',0,''),(611644,192519,'94693','new_theme','show_name_rows','0',0,''),(611645,192519,'94693','new_theme','show_image_rows','0',0,''),(611646,192519,'94693','new_theme','show_stock_rows','0',0,''),(611647,192519,'94693','new_theme','show_description_rows','0',0,''),(611648,192519,'94693','new_theme','show_model_rows','0',0,''),(611649,192519,'94693','new_theme','show_properties_rows','0',0,''),(611650,192519,'94693','new_theme','show_rating_rows','0',0,''),(611651,192519,'94693','new_theme','show_rating_counts_rows','0',0,''),(611652,192519,'94693','new_theme','show_price_rows','0',0,''),(611653,192519,'94693','new_theme','show_buy_button_rows','0',0,''),(611654,192519,'94693','new_theme','show_qty_input_rows','0',0,''),(611655,192519,'94693','new_theme','show_view_button_rows','0',0,''),(611656,192519,'94693','new_theme','show_wishlist_button_rows','0',0,''),(611657,192519,'94693','new_theme','show_compare_rows','0',0,''),(611658,192519,'94693','new_theme','show_name_b2b','0',0,''),(611659,192519,'94693','new_theme','show_image_b2b','0',0,''),(611660,192519,'94693','new_theme','show_stock_b2b','0',0,''),(611661,192519,'94693','new_theme','show_description_b2b','0',0,''),(611662,192519,'94693','new_theme','show_model_b2b','0',0,''),(611663,192519,'94693','new_theme','show_properties_b2b','0',0,''),(611664,192519,'94693','new_theme','show_rating_b2b','0',0,''),(611665,192519,'94693','new_theme','show_rating_counts_b2b','0',0,''),(611666,192519,'94693','new_theme','show_price_b2b','0',0,''),(611667,192519,'94693','new_theme','show_qty_input_b2b','0',0,''),(611668,192519,'94693','new_theme','show_view_button_b2b','0',0,''),(611669,192519,'94693','new_theme','show_attributes_b2b','0',0,''),(611670,192519,'94693','new_theme','items_on_page','9',0,''),(611671,192519,'94693','new_theme','col_in_row','2',0,'8451'),(611672,192519,'94693','new_theme','col_in_row','1',0,'8472'),(611673,192519,'94693','new_theme','product_names_teg','h2',0,''),(611674,192520,'94694','new_theme','block_type','1',0,''),(611675,192520,'94694','new_theme','padding-top','10',0,''),(611676,192520,'94694','new_theme','padding-bottom','10',0,''),(611677,192520,'94694','new_theme','border-bottom-width','1',0,''),(611678,192520,'94694','new_theme','border-bottom-color','$content-border-1',0,''),(611679,192520,'94694','new_theme','margin-left','0',0,''),(611680,192520,'94694','new_theme','margin-right','0',0,''),(611681,192521,'94695','new_theme','float','left',0,''),(611682,192521,'94695','new_theme','clear','none',0,''),(611683,192521,'94695','new_theme','sort_pos_3','1',0,''),(611684,192521,'94695','new_theme','sort_pos_4','2',0,''),(611685,192521,'94695','new_theme','sort_pos_10','3',0,''),(611686,192521,'94695','new_theme','sort_pos_9','4',0,''),(611687,192521,'94695','new_theme','sort_pos_11','5',0,''),(611688,192521,'94695','new_theme','sort_pos_12','6',0,''),(611689,192521,'94695','new_theme','sort_pos_14','7',0,''),(611690,192521,'94695','new_theme','sort_pos_13','8',0,''),(611691,192521,'94695','new_theme','sort_pos_8','9',0,''),(611692,192521,'94695','new_theme','sort_pos_7','10',0,''),(611693,192521,'94695','new_theme','sort_pos_2','11',0,''),(611694,192521,'94695','new_theme','sort_pos_1','12',0,''),(611695,192521,'94695','new_theme','sort_pos_6','13',0,''),(611696,192521,'94695','new_theme','sort_pos_5','14',0,''),(611697,192521,'94695','new_theme','sort_pos_0','15',0,''),(611698,192521,'94695','new_theme','sort_hide_10','1',0,''),(611699,192521,'94695','new_theme','sort_hide_9','1',0,''),(611700,192521,'94695','new_theme','hide_icons','1',0,''),(611701,192521,'94695','new_theme','sort_hide_16','1',0,''),(611702,192521,'94695','new_theme','sort_hide_15','1',0,''),(611703,192521,'94695','new_theme','sort_hide_3','0',0,''),(611704,192521,'94695','new_theme','sort_hide_4','0',0,''),(611705,192521,'94695','new_theme','sort_hide_11','1',0,''),(611706,192521,'94695','new_theme','sort_hide_12','1',0,''),(611707,192521,'94695','new_theme','sort_hide_14','1',0,''),(611708,192521,'94695','new_theme','sort_hide_13','1',0,''),(611709,192521,'94695','new_theme','sort_hide_8','0',0,''),(611710,192521,'94695','new_theme','sort_hide_7','0',0,''),(611711,192521,'94695','new_theme','sort_hide_2','1',0,''),(611712,192521,'94695','new_theme','sort_hide_1','1',0,''),(611713,192521,'94695','new_theme','sort_hide_6','1',0,''),(611714,192521,'94695','new_theme','sort_hide_5','1',0,''),(611715,192521,'94695','new_theme','sort_hide_0','1',0,''),(611716,192522,'94696','new_theme','float','left',0,''),(611717,192522,'94696','new_theme','clear','none',0,''),(611718,192522,'94696','new_theme','margin-left','20',0,''),(611719,192522,'94696','new_theme','display','none',0,'8472'),(611720,192523,'94697','new_theme','margin-right','20',0,''),(611721,192523,'94697','new_theme','float','right',0,''),(611722,192523,'94697','new_theme','clear','none',0,''),(611723,192523,'94697','new_theme','display','none',0,'8451'),(611724,192524,'94698','new_theme','float','right',0,''),(611725,192524,'94698','new_theme','display','none',0,'8472'),(611726,192525,'94699','new_theme','listing_type','productListing',0,''),(611727,192527,'94701','new_theme','block_type','5',0,''),(611728,192527,'94701','new_theme','padding-top','10',0,''),(611729,192527,'94701','new_theme','padding-bottom','10',0,''),(611730,192527,'94701','new_theme','schema','5-2',0,'8472'),(611731,192527,'94701','new_theme','border-top-color','$content-border-1',0,''),(611732,192527,'94701','new_theme','border-top-width','1',0,''),(611733,192529,'94703','new_theme','float','right',0,''),(611734,192530,'73483','new_theme','block_type','1',0,''),(611735,192533,'73486','new_theme','block_type','1',0,''),(611736,192533,'73486','new_theme','padding-top','10',0,''),(611737,192533,'73486','new_theme','padding-bottom','10',0,''),(611738,192533,'73486','new_theme','border-bottom-width','1',0,''),(611739,192533,'73486','new_theme','border-bottom-color','$content-border-1',0,''),(611740,192533,'73486','new_theme','margin-left','0',0,''),(611741,192533,'73486','new_theme','margin-right','0',0,''),(611742,192534,'73487','new_theme','float','left',0,''),(611743,192534,'73487','new_theme','clear','none',0,''),(611744,192534,'73487','new_theme','margin-left','20',0,''),(611745,192534,'73487','new_theme','display','none',0,'8472'),(611746,192535,'73488','new_theme','float','left',0,''),(611747,192535,'73488','new_theme','clear','none',0,''),(611748,192535,'73488','new_theme','sort_pos_3','2',0,''),(611749,192535,'73488','new_theme','sort_pos_4','3',0,''),(611750,192535,'73488','new_theme','sort_pos_10','11',0,''),(611751,192535,'73488','new_theme','sort_pos_9','10',0,''),(611752,192535,'73488','new_theme','sort_pos_11','12',0,''),(611753,192535,'73488','new_theme','sort_pos_12','13',0,''),(611754,192535,'73488','new_theme','sort_pos_14','15',0,''),(611755,192535,'73488','new_theme','sort_pos_13','14',0,''),(611756,192535,'73488','new_theme','sort_pos_8','4',0,''),(611757,192535,'73488','new_theme','sort_pos_7','5',0,''),(611758,192535,'73488','new_theme','sort_pos_2','7',0,''),(611759,192535,'73488','new_theme','sort_pos_1','6',0,''),(611760,192535,'73488','new_theme','sort_pos_6','9',0,''),(611761,192535,'73488','new_theme','sort_pos_5','8',0,''),(611762,192535,'73488','new_theme','sort_pos_0','1',0,''),(611763,192535,'73488','new_theme','sort_hide_10','1',0,''),(611764,192535,'73488','new_theme','sort_hide_9','1',0,''),(611765,192535,'73488','new_theme','hide_icons','1',0,''),(611766,192535,'73488','new_theme','sort_hide_16','1',0,''),(611767,192535,'73488','new_theme','sort_hide_15','1',0,''),(611768,192535,'73488','new_theme','sort_hide_3','0',0,''),(611769,192535,'73488','new_theme','sort_hide_4','0',0,''),(611770,192535,'73488','new_theme','sort_hide_11','1',0,''),(611771,192535,'73488','new_theme','sort_hide_12','1',0,''),(611772,192535,'73488','new_theme','sort_hide_14','1',0,''),(611773,192535,'73488','new_theme','sort_hide_13','1',0,''),(611774,192535,'73488','new_theme','sort_hide_8','0',0,''),(611775,192535,'73488','new_theme','sort_hide_7','0',0,''),(611776,192535,'73488','new_theme','sort_hide_2','1',0,''),(611777,192535,'73488','new_theme','sort_hide_1','1',0,''),(611778,192535,'73488','new_theme','sort_hide_6','1',0,''),(611779,192535,'73488','new_theme','sort_hide_5','1',0,''),(611780,192535,'73488','new_theme','sort_hide_0','0',0,''),(611781,192535,'73488','new_theme','sort_pos_15','16',0,''),(611782,192535,'73488','new_theme','sort_pos_16','17',0,''),(611783,192536,'73489','new_theme','margin-right','20',0,''),(611784,192536,'73489','new_theme','float','right',0,''),(611785,192536,'73489','new_theme','clear','none',0,''),(611786,192536,'73489','new_theme','display','none',0,'8451'),(611787,192537,'73490','new_theme','float','right',0,''),(611788,192537,'73490','new_theme','display','none',0,'8472'),(611789,192538,'73491','new_theme','clear','none',0,''),(611790,192538,'73491','new_theme','float','left',0,''),(611791,192538,'73491','new_theme','padding-top','3',0,''),(611792,192538,'73491','new_theme','padding-left','20',0,''),(611793,192539,'73492','new_theme','block_type','5',0,''),(611794,192539,'73492','new_theme','padding-top','10',0,''),(611795,192539,'73492','new_theme','padding-bottom','10',0,''),(611796,192539,'73492','new_theme','schema','5-2',0,'8472'),(611797,192539,'73492','new_theme','border-top-color','$content-border-1',0,''),(611798,192539,'73492','new_theme','border-top-width','1',0,''),(611799,192541,'73494','new_theme','float','right',0,''),(611800,192542,'73495','new_theme','col_in_row','4',0,''),(611801,192542,'73495','new_theme','products_align','left',0,''),(611802,192542,'73495','new_theme','font-weight','400',0,''),(611803,192542,'73495','new_theme','show_qty_input','0',0,''),(611804,192542,'73495','new_theme','listing_type','productListing',0,''),(611805,192542,'73495','new_theme','listing_type_rows','Rows',0,''),(611806,192542,'73495','new_theme','show_buy_button_b2b','on',0,''),(611807,192542,'73495','new_theme','show_wishlist_button_b2b','1',0,''),(611808,192542,'73495','new_theme','show_compare_b2b','1',0,''),(611809,192542,'73495','new_theme','show_image','0',0,''),(611810,192542,'73495','new_theme','show_stock','0',0,''),(611811,192542,'73495','new_theme','show_description','0',0,''),(611812,192542,'73495','new_theme','show_model','0',0,''),(611813,192542,'73495','new_theme','show_properties','0',0,''),(611814,192542,'73495','new_theme','show_rating','0',0,''),(611815,192542,'73495','new_theme','show_rating_counts','0',0,''),(611816,192542,'73495','new_theme','show_price','0',0,''),(611817,192542,'73495','new_theme','show_buy_button','0',0,''),(611818,192542,'73495','new_theme','show_view_button','0',0,''),(611819,192542,'73495','new_theme','show_wishlist_button','0',0,''),(611820,192542,'73495','new_theme','show_compare','0',0,''),(611821,192542,'73495','new_theme','show_name_rows','0',0,''),(611822,192542,'73495','new_theme','show_image_rows','0',0,''),(611823,192542,'73495','new_theme','show_stock_rows','0',0,''),(611824,192542,'73495','new_theme','show_description_rows','0',0,''),(611825,192542,'73495','new_theme','show_model_rows','0',0,''),(611826,192542,'73495','new_theme','show_properties_rows','0',0,''),(611827,192542,'73495','new_theme','show_rating_rows','0',0,''),(611828,192542,'73495','new_theme','show_rating_counts_rows','0',0,''),(611829,192542,'73495','new_theme','show_price_rows','0',0,''),(611830,192542,'73495','new_theme','show_buy_button_rows','0',0,''),(611831,192542,'73495','new_theme','show_qty_input_rows','0',0,''),(611832,192542,'73495','new_theme','show_view_button_rows','0',0,''),(611833,192542,'73495','new_theme','show_wishlist_button_rows','0',0,''),(611834,192542,'73495','new_theme','show_compare_rows','0',0,''),(611835,192542,'73495','new_theme','show_name_b2b','0',0,''),(611836,192542,'73495','new_theme','show_image_b2b','0',0,''),(611837,192542,'73495','new_theme','show_stock_b2b','0',0,''),(611838,192542,'73495','new_theme','show_description_b2b','0',0,''),(611839,192542,'73495','new_theme','show_model_b2b','0',0,''),(611840,192542,'73495','new_theme','show_properties_b2b','0',0,''),(611841,192542,'73495','new_theme','show_rating_b2b','0',0,''),(611842,192542,'73495','new_theme','show_rating_counts_b2b','0',0,''),(611843,192542,'73495','new_theme','show_price_b2b','0',0,''),(611844,192542,'73495','new_theme','show_qty_input_b2b','0',0,''),(611845,192542,'73495','new_theme','show_view_button_b2b','0',0,''),(611846,192542,'73495','new_theme','show_attributes_b2b','0',0,''),(611847,192542,'73495','new_theme','items_on_page','12',0,''),(611848,192542,'73495','new_theme','col_in_row','2',0,'8451'),(611849,192542,'73495','new_theme','col_in_row','1',0,'8472'),(611850,192542,'73495','new_theme','product_names_teg','h2',0,''),(611851,192545,'1683125852.345798','new_theme','block_type','1',0,''),(611852,192545,'1683125852.345798','new_theme','background-color','$content-bg-2',0,''),(611853,192545,'1683125852.345798','new_theme','padding-top','30',0,''),(611854,192545,'1683125852.345798','new_theme','padding-bottom','30',0,''),(611855,192545,'1683125852.345798','new_theme','style_class','checkout-index-wrap',0,''),(611856,192545,'1683125852.345798','new_theme','color','$content-color-2',0,''),(611857,192546,'1683125852.356555','new_theme','block_type','4',0,''),(611858,192546,'1683125852.356555','new_theme','schema','4-2',0,'8451'),(611859,192546,'1683125852.356555','new_theme','style_class','checkoutDoubleBox',0,''),(611860,192547,'1683125852.358412','new_theme','block_type','1',0,''),(611861,192547,'1683125852.358412','new_theme','padding-right','40',0,''),(611862,192547,'1683125852.358412','new_theme','padding-right','0',0,'8451'),(611863,192548,'1683125852.35982','new_theme','block_type','1',0,''),(611864,192548,'1683125852.35982','new_theme','background-color','$content-bg-1',0,''),(611865,192548,'1683125852.35982','new_theme','padding-top','30',0,''),(611866,192548,'1683125852.35982','new_theme','padding-left','30',0,''),(611867,192548,'1683125852.35982','new_theme','padding-right','30',0,''),(611868,192548,'1683125852.35982','new_theme','padding-bottom','30',0,''),(611869,192548,'1683125852.35982','new_theme','margin-bottom','20',0,''),(611870,192548,'1683125852.35982','new_theme','style_class','hiding-box closeable-box',0,''),(611871,192548,'1683125852.35982','new_theme','color','$content-color-1',0,''),(611872,192549,'1683125852.361569','new_theme','style_class','closeable-content',0,''),(611873,192549,'1683125852.361569','new_theme','padding-bottom','20',0,''),(611874,192550,'1683125852.362847','new_theme','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(611875,192550,'1683125852.362847','new_theme','style_class','closeable-heading closeable-event closed',0,''),(611876,192551,'1683125852.36485','new_theme','block_type','1',0,''),(611877,192551,'1683125852.36485','new_theme','padding-top','30',0,''),(611878,192551,'1683125852.36485','new_theme','padding-left','30',0,''),(611879,192551,'1683125852.36485','new_theme','padding-right','30',0,''),(611880,192551,'1683125852.36485','new_theme','padding-bottom','30',0,''),(611881,192551,'1683125852.36485','new_theme','margin-bottom','20',0,''),(611882,192551,'1683125852.36485','new_theme','background-color','$content-bg-1',0,''),(611883,192551,'1683125852.36485','new_theme','style_class','hiding-box closeable-box',0,''),(611884,192551,'1683125852.36485','new_theme','color','$content-color-1',0,''),(611885,192552,'1683125852.366422','new_theme','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(611886,192552,'1683125852.366422','new_theme','style_class','closeable-heading closeable-event closed',0,''),(611887,192553,'1683125852.367732','new_theme','block_type','2',0,''),(611888,192553,'1683125852.367732','new_theme','style_class','closeable-content',0,''),(611889,192553,'1683125852.367732','new_theme','schema','2-2',0,'8451'),(611890,192554,'1683125852.36968','new_theme','padding-right','20',0,''),(611891,192554,'1683125852.36968','new_theme','padding-bottom','20',0,''),(611892,192554,'1683125852.36968','new_theme','padding-right','0',0,'8451'),(611893,192555,'1683125852.369745','new_theme','padding-left','20',0,''),(611894,192555,'1683125852.369745','new_theme','padding-bottom','20',0,''),(611895,192555,'1683125852.369745','new_theme','padding-left','0',0,'8451'),(611896,192556,'1683125852.37045','new_theme','padding-left','20',0,''),(611897,192556,'1683125852.37045','new_theme','padding-bottom','20',0,''),(611898,192556,'1683125852.37045','new_theme','padding-left','0',0,'8451'),(611899,192557,'1683125852.371233','new_theme','background-color','$content-bg-1',0,''),(611900,192557,'1683125852.371233','new_theme','block_type','1',0,''),(611901,192557,'1683125852.371233','new_theme','padding-top','30',0,''),(611902,192557,'1683125852.371233','new_theme','padding-left','30',0,''),(611903,192557,'1683125852.371233','new_theme','padding-right','30',0,''),(611904,192557,'1683125852.371233','new_theme','padding-bottom','30',0,''),(611905,192557,'1683125852.371233','new_theme','margin-bottom','20',0,''),(611906,192557,'1683125852.371233','new_theme','style_class','hiding-box',0,''),(611907,192557,'1683125852.371233','new_theme','color','$content-color-1',0,''),(611908,192558,'1683125852.37350','new_theme','block_type','1',0,''),(611909,192558,'1683125852.37350','new_theme','content','\\_',0,'3'),(611910,192558,'1683125852.37350','new_theme','border-top-width','1',0,'3'),(611911,192558,'1683125852.37350','new_theme','border-top-color','#e0e0e0',0,'3'),(611912,192558,'1683125852.37350','new_theme','display','block',0,'3'),(611913,192558,'1683125852.37350','new_theme','position','absolute',0,'3'),(611914,192558,'1683125852.37350','new_theme','top','19',0,'3'),(611915,192558,'1683125852.37350','new_theme','left','0',0,'3'),(611916,192558,'1683125852.37350','new_theme','right','0',0,'3'),(611917,192558,'1683125852.37350','new_theme','margin-top','-2',0,'3'),(611918,192558,'1683125852.37350','new_theme','position','relative',0,''),(611919,192559,'1683125852.374899','new_theme','box_align','2',0,''),(611920,192559,'1683125852.374899','new_theme','margin-bottom','10',0,''),(611921,192559,'1683125852.374899','new_theme','background-color','$content-bg-1',0,''),(611922,192559,'1683125852.374899','new_theme','position','relative',0,''),(611923,192560,'1683125852.375685','new_theme','background-color','$content-bg-2',0,''),(611924,192560,'1683125852.375685','new_theme','padding-top','10',0,''),(611925,192560,'1683125852.375685','new_theme','padding-left','10',0,''),(611926,192560,'1683125852.375685','new_theme','padding-right','10',0,''),(611927,192560,'1683125852.375685','new_theme','padding-bottom','10',0,''),(611928,192560,'1683125852.375685','new_theme','margin-top','10',0,''),(611929,192561,'1683125852.376557','new_theme','block_type','2',0,''),(611930,192561,'1683125852.376557','new_theme','schema','2-2',0,'8451'),(611931,192562,'1683125852.377637','new_theme','block_type','1',0,''),(611932,192562,'1683125852.377637','new_theme','padding-right','20',0,''),(611933,192562,'1683125852.377637','new_theme','padding-left','0',0,'8451'),(611934,192562,'1683125852.377637','new_theme','margin-bottom','20',0,'8451'),(611935,192562,'1683125852.377637','new_theme','padding-right','0',0,'8451'),(611936,192563,'1683125852.378829','new_theme','address_in','popup',0,''),(611937,192564,'1683125852.379375','new_theme','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(611938,192567,'1683125852.381183','new_theme','block_type','1',0,''),(611939,192567,'1683125852.381183','new_theme','padding-left','20',0,''),(611940,192567,'1683125852.381183','new_theme','padding-left','0',0,'8451'),(611941,192569,'1683125852.382635','new_theme','border-top-width','1',0,''),(611942,192569,'1683125852.382635','new_theme','border-top-color','#e0e0e0',0,''),(611943,192569,'1683125852.382635','new_theme','padding-top','13',0,''),(611944,192569,'1683125852.382635','new_theme','padding-bottom','10',0,''),(611945,192570,'1683125852.383516','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(611946,192571,'1683125852.385278','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(611947,192572,'1683125852.386397','new_theme','margin-bottom','20',0,''),(611948,192572,'1683125852.386397','new_theme','style_class','hiding-box',0,''),(611949,192573,'1683125852.386970','new_theme','padding-top','30',0,''),(611950,192573,'1683125852.386970','new_theme','padding-left','30',0,''),(611951,192573,'1683125852.386970','new_theme','padding-right','30',0,''),(611952,192573,'1683125852.386970','new_theme','margin-top','20',0,''),(611953,192573,'1683125852.386970','new_theme','background-color','$content-bg-1',0,''),(611954,192573,'1683125852.386970','new_theme','padding-bottom','30',0,''),(611955,192573,'1683125852.386970','new_theme','margin-bottom','20',0,''),(611956,192573,'1683125852.386970','new_theme','color','$content-color-1',0,''),(611957,192574,'1683125852.38820','new_theme','block_type','1',0,''),(611958,192574,'1683125852.38820','new_theme','padding-top','30',0,''),(611959,192574,'1683125852.38820','new_theme','padding-left','30',0,''),(611960,192574,'1683125852.38820','new_theme','padding-right','30',0,''),(611961,192574,'1683125852.38820','new_theme','padding-bottom','23',0,''),(611962,192574,'1683125852.38820','new_theme','margin-bottom','20',0,''),(611963,192574,'1683125852.38820','new_theme','background-color','$content-bg-1',0,''),(611964,192574,'1683125852.38820','new_theme','style_class','hiding-box',0,''),(611965,192574,'1683125852.38820','new_theme','color','$content-color-1',0,''),(611966,192575,'1683125852.390244','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(611967,192576,'1683125852.391810','new_theme','block_type','2',0,''),(611968,192576,'1683125852.391810','new_theme','schema','2-2',0,'8451'),(611969,192577,'1683125852.393320','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(611970,192578,'1683125852.394747','new_theme','padding-right','20',0,''),(611971,192578,'1683125852.394747','new_theme','padding-right','0',0,'8451'),(611972,192578,'1683125852.394747','new_theme','padding-bottom','20',0,'8451'),(611973,192578,'1683125852.394747','new_theme','address_in','popup',0,''),(611974,192579,'1683125852.395767','new_theme','block_type','1',0,''),(611975,192579,'1683125852.395767','new_theme','padding-left','20',0,''),(611976,192579,'1683125852.395767','new_theme','padding-left','0',0,'8451'),(611977,192581,'1683125852.398588','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(611978,192582,'1683125852.400291','new_theme','block_type','1',0,''),(611979,192582,'1683125852.400291','new_theme','padding-top','30',0,''),(611980,192582,'1683125852.400291','new_theme','padding-left','30',0,''),(611981,192582,'1683125852.400291','new_theme','padding-right','30',0,''),(611982,192582,'1683125852.400291','new_theme','padding-bottom','30',0,''),(611983,192582,'1683125852.400291','new_theme','margin-bottom','20',0,''),(611984,192582,'1683125852.400291','new_theme','background-color','$content-bg-1',0,''),(611985,192582,'1683125852.400291','new_theme','color','$content-color-1',0,''),(611986,192585,'1683125852.403563','new_theme','block_type','1',0,''),(611987,192585,'1683125852.403563','new_theme','padding-top','20',0,''),(611988,192585,'1683125852.403563','new_theme','padding-left','20',0,''),(611989,192585,'1683125852.403563','new_theme','padding-right','20',0,''),(611990,192585,'1683125852.403563','new_theme','padding-bottom','20',0,''),(611991,192585,'1683125852.403563','new_theme','background-color','$content-bg-1',0,''),(611992,192585,'1683125852.403563','new_theme','style_class','order-summary',0,''),(611993,192585,'1683125852.403563','new_theme','color','$content-color-1',0,''),(611994,192586,'1683125852.405625','new_theme','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(611995,192586,'1683125852.405625','new_theme','text-align','center',0,''),(611996,192586,'1683125852.405625','new_theme','font-size','14',0,''),(611997,192586,'1683125852.405625','new_theme','color','$fade-color-1',0,''),(611998,192586,'1683125852.405625','new_theme','padding-top','10',0,''),(611999,192587,'1683125852.407666','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(612000,192588,'1683125852.40885','new_theme','hide_page','1',0,''),(612001,192588,'1683125852.40885','new_theme','hide_continue_button','1',0,''),(612002,192589,'1683125852.409688','new_theme','margin-bottom','10',0,''),(612003,192592,'73542','new_theme','block_type','1',0,''),(612004,192593,'73543','new_theme','margin-top','20',0,''),(612005,192594,'73544','new_theme','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(612006,192595,'73545','new_theme','link','products',0,''),(612007,192595,'73545','new_theme','margin-top','-33',0,''),(612008,192595,'73545','new_theme','float','right',0,''),(612009,192596,'73546','new_theme','block_type','2',0,''),(612010,192596,'73546','new_theme','margin-bottom','20',0,''),(612011,192596,'73546','new_theme','schema','2-2',0,'8444'),(612012,192597,'73547','new_theme','block_type','1',0,''),(612013,192597,'73547','new_theme','padding-right','20',0,''),(612014,192597,'73547','new_theme','padding-right','0',0,'8444'),(612015,192598,'73548','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612016,192598,'73548','new_theme','clear','none',0,''),(612017,192600,'73550','new_theme','padding-left','20',0,''),(612018,192600,'73550','new_theme','block_type','1',0,''),(612019,192600,'73550','new_theme','padding-left','0',0,'8444'),(612020,192602,'73552','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612021,192602,'73552','new_theme','clear','none',0,''),(612022,192603,'73553','new_theme','text-align','right',0,''),(612023,192603,'73553','new_theme','margin-bottom','20',0,''),(612024,192603,'73553','new_theme','margin-top','20',0,''),(612025,192604,'73554','new_theme','block_type','2',0,''),(612026,192604,'73554','new_theme','margin-bottom','20',0,''),(612027,192604,'73554','new_theme','schema','2-2',0,'8444'),(612028,192605,'73555','new_theme','block_type','1',0,''),(612029,192605,'73555','new_theme','padding-right','20',0,''),(612030,192605,'73555','new_theme','padding-right','0',0,'8444'),(612031,192607,'73557','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(612032,192607,'73557','new_theme','clear','none',0,''),(612033,192608,'73558','new_theme','block_type','1',0,''),(612034,192608,'73558','new_theme','padding-left','20',0,''),(612035,192608,'73558','new_theme','padding-left','0',0,'8444'),(612036,192609,'73559','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612037,192609,'73559','new_theme','clear','none',0,''),(612038,192611,'73561','new_theme','margin-bottom','20',0,''),(612039,192611,'73561','new_theme','text-align','right',0,''),(612040,192613,'73576','new_theme','block_type','1',0,''),(612041,192614,'73577','new_theme','text-align','right',0,''),(612042,192614,'73577','new_theme','margin-bottom','20',0,''),(612043,192615,'73578','new_theme','block_type','2',0,''),(612044,192615,'73578','new_theme','margin-bottom','20',0,''),(612045,192615,'73578','new_theme','schema','2-2',0,'8444'),(612046,192616,'73579','new_theme','block_type','1',0,''),(612047,192616,'73579','new_theme','padding-right','20',0,''),(612048,192616,'73579','new_theme','padding-right','0',0,'8444'),(612049,192617,'73580','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612050,192617,'73580','new_theme','clear','none',0,''),(612051,192619,'73582','new_theme','block_type','1',0,''),(612052,192619,'73582','new_theme','padding-left','20',0,''),(612053,192619,'73582','new_theme','padding-left','0',0,'8444'),(612054,192620,'73583','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612055,192620,'73583','new_theme','clear','none',0,''),(612056,192622,'73585','new_theme','margin-bottom','20',0,''),(612057,192622,'73585','new_theme','text-align','right',0,''),(612058,192625,'73588','new_theme','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(612059,192626,'73563','new_theme','block_type','1',0,''),(612060,192627,'73564','new_theme','margin-bottom','20',0,''),(612061,192628,'73565','new_theme','margin-bottom','20',0,''),(612062,192628,'73565','new_theme','text-align','right',0,''),(612063,192629,'73566','new_theme','text-align','right',0,''),(612064,192629,'73566','new_theme','margin-bottom','20',0,''),(612065,192630,'73567','new_theme','block_type','2',0,''),(612066,192630,'73567','new_theme','margin-bottom','20',0,''),(612067,192630,'73567','new_theme','schema','2-2',0,'8444'),(612068,192631,'73568','new_theme','block_type','1',0,''),(612069,192631,'73568','new_theme','padding-right','20',0,''),(612070,192631,'73568','new_theme','padding-right','0',0,'8444'),(612071,192633,'73570','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612072,192633,'73570','new_theme','clear','none',0,''),(612073,192634,'73571','new_theme','block_type','1',0,''),(612074,192634,'73571','new_theme','padding-left','20',0,''),(612075,192634,'73571','new_theme','padding-left','0',0,'8444'),(612076,192636,'73573','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612077,192636,'73573','new_theme','clear','none',0,''),(612078,192637,'73574','new_theme','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(612079,192638,'73575','new_theme','margin-bottom','20',0,''),(612080,192639,'73589','new_theme','block_type','1',0,''),(612081,192640,'73590','new_theme','block_type','2',0,''),(612082,192640,'73590','new_theme','margin-bottom','20',0,''),(612083,192640,'73590','new_theme','schema','2-2',0,'8444'),(612084,192641,'73591','new_theme','block_type','1',0,''),(612085,192641,'73591','new_theme','padding-right','20',0,''),(612086,192641,'73591','new_theme','padding-right','0',0,'8444'),(612087,192643,'73593','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(612088,192643,'73593','new_theme','clear','none',0,''),(612089,192644,'73594','new_theme','block_type','1',0,''),(612090,192644,'73594','new_theme','padding-left','20',0,''),(612091,192644,'73594','new_theme','padding-left','0',0,'8444'),(612092,192646,'73596','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612093,192646,'73596','new_theme','clear','none',0,''),(612094,192647,'73597','new_theme','margin-bottom','20',0,''),(612095,192648,'73598','new_theme','margin-bottom','20',0,''),(612096,192649,'73599','new_theme','text','\n <div class=\"heading-4\">##PRODUCT_S##</div>',0,''),(612097,192650,'73600','new_theme','link','products',0,''),(612098,192650,'73600','new_theme','margin-top','-33',0,''),(612099,192650,'73600','new_theme','float','right',0,''),(612100,192651,'73601','new_theme','text-align','right',0,''),(612101,192651,'73601','new_theme','margin-bottom','20',0,''),(612102,192652,'73602','new_theme','margin-bottom','20',0,''),(612103,192652,'73602','new_theme','text-align','right',0,''),(612104,192653,'73603','new_theme','block_type','2',0,''),(612105,192653,'73603','new_theme','margin-bottom','20',0,''),(612106,192653,'73603','new_theme','schema','2-2',0,'8444'),(612107,192654,'73604','new_theme','block_type','1',0,''),(612108,192654,'73604','new_theme','padding-right','20',0,''),(612109,192654,'73604','new_theme','padding-right','0',0,'8444'),(612110,192655,'73605','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612111,192655,'73605','new_theme','clear','none',0,''),(612112,192657,'73607','new_theme','padding-left','20',0,''),(612113,192657,'73607','new_theme','block_type','1',0,''),(612114,192657,'73607','new_theme','padding-left','0',0,'8444'),(612115,192658,'73608','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612116,192658,'73608','new_theme','clear','none',0,''),(612117,192660,'73610','new_theme','text','##TEXT_CONFIRMATION##',0,''),(612118,192661,'73611','new_theme','text','##TEXT_CONFIRMATION##',0,''),(612119,192662,'73613','new_theme','text','##TEXT_CONFIRMATION##',0,''),(612120,192663,'73612','new_theme','text','##TEXT_CONFIRMATION##',0,''),(612121,192664,'73614','new_theme','text','##TEXT_CONFIRMATION##',0,''),(612122,192665,'73615','new_theme','text','##TEXT_CONFIRMATION##',0,''),(612123,192666,'73616','new_theme','block_type','2',0,''),(612124,192667,'73617','new_theme','block_type','1',0,''),(612125,192667,'73617','new_theme','padding-right','20',0,''),(612126,192668,'73618','new_theme','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(612127,192670,'73620','new_theme','block_type','1',0,''),(612128,192670,'73620','new_theme','padding-left','20',0,''),(612129,192670,'73620','new_theme','padding-left','0',0,'8451'),(612130,192671,'73621','new_theme','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612131,192673,'73623','new_theme','block_type','4',0,''),(612132,192673,'73623','new_theme','schema','4-2',0,'8472'),(612133,192673,'73623','new_theme','padding-top','20',0,''),(612134,192674,'73624','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612135,192674,'73624','new_theme','text-align','right',0,''),(612136,192674,'73624','new_theme','padding-top','10',0,''),(612137,192674,'73624','new_theme','font_size_measure','em',0,''),(612138,192674,'73624','new_theme','font-size','1.2',0,''),(612139,192675,'73625','new_theme','text-align','right',0,''),(612140,192676,'73626','new_theme','block_type','2',0,''),(612141,192677,'73627','new_theme','block_type','1',0,''),(612142,192677,'73627','new_theme','padding-right','20',0,''),(612143,192677,'73627','new_theme','padding-right','0',0,'8451'),(612144,192678,'73628','new_theme','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(612145,192680,'73630','new_theme','block_type','1',0,''),(612146,192680,'73630','new_theme','padding-right','0',0,'8451'),(612147,192680,'73630','new_theme','padding-left','20',0,''),(612148,192683,'73633','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612149,192685,'73635','new_theme','block_type','2',0,''),(612150,192686,'73636','new_theme','block_type','1',0,''),(612151,192686,'73636','new_theme','padding-right','20',0,''),(612152,192688,'73638','new_theme','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(612153,192689,'73639','new_theme','block_type','1',0,''),(612154,192689,'73639','new_theme','padding-left','20',0,''),(612155,192689,'73639','new_theme','padding-left','0',0,'8451'),(612156,192690,'73640','new_theme','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612157,192692,'73642','new_theme','block_type','4',0,''),(612158,192692,'73642','new_theme','schema','4-2',0,'8472'),(612159,192693,'73643','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612160,192693,'73643','new_theme','text-align','right',0,''),(612161,192693,'73643','new_theme','padding-top','10',0,''),(612162,192693,'73643','new_theme','font_size_measure','em',0,''),(612163,192693,'73643','new_theme','font-size','1.2',0,''),(612164,192694,'73644','new_theme','text-align','right',0,''),(612165,192695,'73645','new_theme','block_type','2',0,''),(612166,192696,'73646','new_theme','block_type','1',0,''),(612167,192696,'73646','new_theme','padding-right','20',0,''),(612168,192696,'73646','new_theme','padding-right','0',0,'8451'),(612169,192698,'73648','new_theme','text','<a name=\"shipping_address\"></a>\n<div class=\"heading-4\" id=\"shipping_address\">##SHIPPING_ADDRESS##</div>',0,''),(612170,192699,'73649','new_theme','block_type','1',0,''),(612171,192699,'73649','new_theme','padding-right','0',0,'8451'),(612172,192699,'73649','new_theme','padding-left','20',0,''),(612173,192701,'73651','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612174,192704,'73654','new_theme','block_type','4',0,''),(612175,192704,'73654','new_theme','schema','4-2',0,'8472'),(612176,192705,'73655','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612177,192705,'73655','new_theme','text-align','right',0,''),(612178,192705,'73655','new_theme','padding-top','10',0,''),(612179,192705,'73655','new_theme','font_size_measure','em',0,''),(612180,192705,'73655','new_theme','font-size','1.2',0,''),(612181,192706,'73656','new_theme','text-align','right',0,''),(612182,192707,'73657','new_theme','block_type','2',0,''),(612183,192708,'73658','new_theme','block_type','1',0,''),(612184,192708,'73658','new_theme','padding-right','20',0,''),(612185,192710,'73660','new_theme','block_type','1',0,''),(612186,192710,'73660','new_theme','padding-left','20',0,''),(612187,192710,'73660','new_theme','padding-left','0',0,'8451'),(612188,192711,'73661','new_theme','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612189,192713,'73663','new_theme','block_type','4',0,''),(612190,192713,'73663','new_theme','schema','4-2',0,'8472'),(612191,192714,'73664','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612192,192714,'73664','new_theme','text-align','right',0,''),(612193,192714,'73664','new_theme','padding-top','10',0,''),(612194,192714,'73664','new_theme','font_size_measure','em',0,''),(612195,192714,'73664','new_theme','font-size','1.2',0,''),(612196,192715,'73665','new_theme','text-align','right',0,''),(612197,192716,'73666','new_theme','block_type','2',0,''),(612198,192717,'73667','new_theme','block_type','1',0,''),(612199,192717,'73667','new_theme','padding-right','20',0,''),(612200,192719,'73669','new_theme','block_type','1',0,''),(612201,192719,'73669','new_theme','padding-left','20',0,''),(612202,192719,'73669','new_theme','padding-left','0',0,'8451'),(612203,192721,'73671','new_theme','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612204,192722,'73672','new_theme','text','##DELIVERY_DETAILS##',0,''),(612205,192723,'73673','new_theme','text','##DELIVERY_DETAILS##',0,''),(612206,192724,'73675','new_theme','text','##CONTACT_INFORMATION##',0,''),(612207,192725,'73674','new_theme','text','##CONTACT_INFORMATION##',0,''),(612208,192726,'73676','new_theme','text','##DELIVERY_DETAILS##',0,''),(612209,192727,'73677','new_theme','text','##DELIVERY_DETAILS##',0,''),(612210,192728,'73678','new_theme','block_type','1',0,''),(612211,192728,'73678','new_theme','background-color','$content-bg-2',0,''),(612212,192728,'73678','new_theme','padding-top','30',0,''),(612213,192728,'73678','new_theme','padding-bottom','30',0,''),(612214,192729,'73679','new_theme','block_type','4',0,''),(612215,192729,'73679','new_theme','schema','4-2',0,'8451'),(612216,192730,'73680','new_theme','block_type','1',0,''),(612217,192730,'73680','new_theme','padding-right','40',0,''),(612218,192730,'73680','new_theme','padding-right','0',0,'8451'),(612219,192731,'73682','new_theme','block_type','1',0,''),(612220,192731,'73682','new_theme','background-color','$content-bg-1',0,''),(612221,192731,'73682','new_theme','padding-top','30',0,''),(612222,192731,'73682','new_theme','padding-left','30',0,''),(612223,192731,'73682','new_theme','padding-right','30',0,''),(612224,192731,'73682','new_theme','padding-bottom','30',0,''),(612225,192731,'73682','new_theme','margin-bottom','20',0,''),(612226,192731,'73682','new_theme','style_class','hiding-box',0,''),(612227,192732,'73683','new_theme','margin-bottom','20',0,''),(612228,192733,'73684','new_theme','padding-top','10',0,''),(612229,192733,'73684','new_theme','padding-left','20',0,''),(612230,192733,'73684','new_theme','padding-right','20',0,''),(612231,192733,'73684','new_theme','margin-top','20',0,''),(612232,192733,'73684','new_theme','background-color','$content-bg-2',0,''),(612233,192733,'73684','new_theme','padding-bottom','8',0,''),(612234,192734,'73685','new_theme','block_type','1',0,''),(612235,192734,'73685','new_theme','background-color','$content-bg-1',0,''),(612236,192734,'73685','new_theme','padding-top','30',0,''),(612237,192734,'73685','new_theme','padding-left','30',0,''),(612238,192734,'73685','new_theme','padding-right','30',0,''),(612239,192734,'73685','new_theme','padding-bottom','14',0,''),(612240,192734,'73685','new_theme','margin-bottom','20',0,''),(612241,192734,'73685','new_theme','style_class','hiding-box closeable-box',0,''),(612242,192735,'73686','new_theme','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(612243,192735,'73686','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612244,192736,'73687','new_theme','style_class','closeable-content',0,''),(612245,192736,'73687','new_theme','padding-bottom','20',0,''),(612246,192737,'73688','new_theme','background-color','$content-bg-1',0,''),(612247,192737,'73688','new_theme','block_type','1',0,''),(612248,192737,'73688','new_theme','padding-top','30',0,''),(612249,192737,'73688','new_theme','padding-left','30',0,''),(612250,192737,'73688','new_theme','padding-right','30',0,''),(612251,192737,'73688','new_theme','padding-bottom','30',0,''),(612252,192737,'73688','new_theme','margin-bottom','20',0,''),(612253,192737,'73688','new_theme','style_class','hiding-box',0,''),(612254,192738,'73689','new_theme','block_type','1',0,''),(612255,192738,'73689','new_theme','content','\\_',0,'3'),(612256,192738,'73689','new_theme','border-top-width','1',0,'3'),(612257,192738,'73689','new_theme','border-top-color','$content-border-1',0,'3'),(612258,192738,'73689','new_theme','display','block',0,'3'),(612259,192738,'73689','new_theme','position','absolute',0,'3'),(612260,192738,'73689','new_theme','top','19',0,'3'),(612261,192738,'73689','new_theme','left','0',0,'3'),(612262,192738,'73689','new_theme','right','0',0,'3'),(612263,192738,'73689','new_theme','margin-top','-2',0,'3'),(612264,192738,'73689','new_theme','position','relative',0,''),(612265,192739,'73690','new_theme','box_align','2',0,''),(612266,192739,'73690','new_theme','margin-bottom','10',0,''),(612267,192739,'73690','new_theme','background-color','$content-bg-1',0,''),(612268,192739,'73690','new_theme','position','relative',0,''),(612269,192740,'73691','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(612270,192741,'73692','new_theme','block_type','2',0,''),(612271,192741,'73692','new_theme','schema','2-2',0,'8451'),(612272,192742,'73693','new_theme','block_type','1',0,''),(612273,192742,'73693','new_theme','padding-right','20',0,''),(612274,192742,'73693','new_theme','padding-left','0',0,'8451'),(612275,192742,'73693','new_theme','margin-bottom','20',0,'8451'),(612276,192745,'73696','new_theme','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(612277,192746,'73697','new_theme','block_type','1',0,''),(612278,192746,'73697','new_theme','padding-left','20',0,''),(612279,192746,'73697','new_theme','padding-left','0',0,'8451'),(612280,192747,'73698','new_theme','border-top-width','1',0,''),(612281,192747,'73698','new_theme','border-top-color','$content-border-1',0,''),(612282,192747,'73698','new_theme','padding-top','13',0,''),(612283,192747,'73698','new_theme','padding-bottom','10',0,''),(612284,192748,'73699','new_theme','background-color','$content-bg-2',0,''),(612285,192748,'73699','new_theme','padding-top','10',0,''),(612286,192748,'73699','new_theme','padding-left','10',0,''),(612287,192748,'73699','new_theme','padding-right','10',0,''),(612288,192748,'73699','new_theme','padding-bottom','10',0,''),(612289,192748,'73699','new_theme','margin-top','10',0,''),(612290,192749,'73700','new_theme','block_type','1',0,''),(612291,192749,'73700','new_theme','padding-top','20',0,''),(612292,192749,'73700','new_theme','padding-left','20',0,''),(612293,192749,'73700','new_theme','padding-right','20',0,''),(612294,192749,'73700','new_theme','padding-bottom','20',0,''),(612295,192749,'73700','new_theme','background-color','$content-bg-1',0,''),(612296,192749,'73700','new_theme','style_class','order-summary',0,''),(612297,192750,'73701','new_theme','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(612298,192750,'73701','new_theme','text-align','center',0,''),(612299,192750,'73701','new_theme','font-size','14',0,''),(612300,192750,'73701','new_theme','color','$fade-color-1',0,''),(612301,192750,'73701','new_theme','padding-top','10',0,''),(612302,192752,'115999','new_theme','hide_continue_button','1',0,''),(612303,192753,'73703','new_theme','block_type','1',0,''),(612304,192753,'73703','new_theme','background-color','$content-bg-2',0,''),(612305,192753,'73703','new_theme','padding-top','30',0,''),(612306,192753,'73703','new_theme','padding-bottom','30',0,''),(612307,192753,'73703','new_theme','color','$content-color-2',0,''),(612308,192754,'73704','new_theme','block_type','4',0,''),(612309,192755,'73705','new_theme','block_type','1',0,''),(612310,192755,'73705','new_theme','padding-right','40',0,''),(612311,192756,'73706','new_theme','block_type','1',0,''),(612312,192756,'73706','new_theme','background-color','$content-bg-1',0,''),(612313,192756,'73706','new_theme','padding-top','30',0,''),(612314,192756,'73706','new_theme','padding-left','30',0,''),(612315,192756,'73706','new_theme','padding-right','30',0,''),(612316,192756,'73706','new_theme','padding-bottom','30',0,''),(612317,192756,'73706','new_theme','margin-bottom','20',0,''),(612318,192756,'73706','new_theme','style_class','hiding-box',0,''),(612319,192756,'73706','new_theme','color','$content-color-1',0,''),(612320,192757,'73707','new_theme','padding-top','10',0,''),(612321,192757,'73707','new_theme','padding-left','20',0,''),(612322,192757,'73707','new_theme','padding-right','20',0,''),(612323,192757,'73707','new_theme','margin-top','20',0,''),(612324,192757,'73707','new_theme','background-color','$content-bg-2',0,''),(612325,192757,'73707','new_theme','padding-bottom','8',0,''),(612326,192757,'73707','new_theme','color','$content-color-2',0,''),(612327,192758,'73708','new_theme','margin-bottom','20',0,''),(612328,192759,'73709','new_theme','block_type','1',0,''),(612329,192759,'73709','new_theme','padding-top','30',0,''),(612330,192759,'73709','new_theme','padding-left','30',0,''),(612331,192759,'73709','new_theme','padding-right','30',0,''),(612332,192759,'73709','new_theme','padding-bottom','23',0,''),(612333,192759,'73709','new_theme','margin-bottom','20',0,''),(612334,192759,'73709','new_theme','background-color','$content-bg-1',0,''),(612335,192759,'73709','new_theme','style_class','hiding-box',0,''),(612336,192759,'73709','new_theme','color','$content-color-1',0,''),(612337,192760,'73710','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(612338,192761,'73711','new_theme','block_type','2',0,''),(612339,192762,'73712','new_theme','padding-right','20',0,''),(612340,192763,'73713','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612341,192764,'73714','new_theme','block_type','1',0,''),(612342,192764,'73714','new_theme','padding-left','20',0,''),(612343,192765,'73715','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612344,192767,'73717','new_theme','block_type','1',0,''),(612345,192767,'73717','new_theme','padding-top','30',0,''),(612346,192767,'73717','new_theme','padding-left','30',0,''),(612347,192767,'73717','new_theme','padding-right','30',0,''),(612348,192767,'73717','new_theme','padding-bottom','14',0,''),(612349,192767,'73717','new_theme','margin-bottom','20',0,''),(612350,192767,'73717','new_theme','background-color','$content-bg-1',0,''),(612351,192767,'73717','new_theme','style_class','hiding-box closeable-box',0,''),(612352,192767,'73717','new_theme','color','$content-color-1',0,''),(612353,192768,'73718','new_theme','block_type','2',0,''),(612354,192768,'73718','new_theme','style_class','closeable-content',0,''),(612355,192769,'73719','new_theme','padding-right','20',0,''),(612356,192769,'73719','new_theme','padding-bottom','20',0,''),(612357,192770,'73720','new_theme','padding-left','20',0,''),(612358,192770,'73720','new_theme','padding-bottom','20',0,''),(612359,192771,'73721','new_theme','padding-left','20',0,''),(612360,192771,'73721','new_theme','padding-bottom','20',0,''),(612361,192772,'73722','new_theme','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(612362,192772,'73722','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612363,192773,'73723','new_theme','block_type','1',0,''),(612364,192773,'73723','new_theme','background-color','$content-bg-1',0,''),(612365,192773,'73723','new_theme','padding-top','30',0,''),(612366,192773,'73723','new_theme','padding-left','30',0,''),(612367,192773,'73723','new_theme','padding-right','30',0,''),(612368,192773,'73723','new_theme','padding-bottom','14',0,''),(612369,192773,'73723','new_theme','margin-bottom','20',0,''),(612370,192773,'73723','new_theme','style_class','hiding-box closeable-box',0,''),(612371,192773,'73723','new_theme','color','$content-color-1',0,''),(612372,192774,'73724','new_theme','style_class','closeable-content',0,''),(612373,192774,'73724','new_theme','padding-bottom','20',0,''),(612374,192775,'73725','new_theme','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(612375,192775,'73725','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612376,192776,'73726','new_theme','block_type','1',0,''),(612377,192776,'73726','new_theme','padding-top','20',0,''),(612378,192776,'73726','new_theme','padding-left','20',0,''),(612379,192776,'73726','new_theme','padding-right','20',0,''),(612380,192776,'73726','new_theme','padding-bottom','20',0,''),(612381,192776,'73726','new_theme','background-color','$content-bg-1',0,''),(612382,192776,'73726','new_theme','style_class','order-summary hiding-box',0,''),(612383,192776,'73726','new_theme','color','$content-color-1',0,''),(612384,192777,'73727','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(612385,192778,'73728','new_theme','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(612386,192778,'73728','new_theme','text-align','center',0,''),(612387,192778,'73728','new_theme','font-size','14',0,''),(612388,192778,'73728','new_theme','color','$fade-color-1',0,''),(612389,192778,'73728','new_theme','padding-top','10',0,''),(612390,192779,'73729','new_theme','margin-bottom','10',0,''),(612391,192781,'73731','new_theme','hide_page','1',0,''),(612392,192781,'73731','new_theme','hide_continue_button','1',0,''),(612393,192782,'73732','new_theme','block_type','1',0,''),(612394,192784,'73734','new_theme','block_type','4',0,''),(612395,192784,'73734','new_theme','schema','4-2',0,'8472'),(612396,192785,'73735','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612397,192785,'73735','new_theme','text-align','right',0,''),(612398,192785,'73735','new_theme','padding-top','10',0,''),(612399,192785,'73735','new_theme','font_size_measure','em',0,''),(612400,192785,'73735','new_theme','font-size','1.2',0,''),(612401,192786,'73736','new_theme','text-align','right',0,''),(612402,192787,'73737','new_theme','block_type','2',0,''),(612403,192787,'73737','new_theme','schema','2-2',0,'8451'),(612404,192788,'73738','new_theme','block_type','1',0,''),(612405,192788,'73738','new_theme','padding-right','20',0,''),(612406,192788,'73738','new_theme','padding-right','0',0,'8451'),(612407,192790,'73740','new_theme','text','\n <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(612408,192791,'73741','new_theme','block_type','1',0,''),(612409,192791,'73741','new_theme','padding-left','20',0,''),(612410,192791,'73741','new_theme','padding-left','0',0,'8451'),(612411,192793,'73743','new_theme','text','\n <div class=\"heading-4\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612412,192794,'73744','new_theme','block_type','2',0,''),(612413,192794,'73744','new_theme','schema','2-2',0,'8451'),(612414,192795,'73745','new_theme','block_type','1',0,''),(612415,192795,'73745','new_theme','padding-right','20',0,''),(612416,192795,'73745','new_theme','padding-right','0',0,'8451'),(612417,192796,'73746','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612418,192798,'73748','new_theme','block_type','1',0,''),(612419,192798,'73748','new_theme','padding-left','20',0,''),(612420,192798,'73748','new_theme','padding-left','0',0,'8451'),(612421,192803,'73753','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612422,192804,'73754','new_theme','margin-bottom','20',0,''),(612423,192805,'73755','new_theme','block_type','1',0,''),(612424,192805,'73755','new_theme','background-color','$content-bg-2',0,''),(612425,192805,'73755','new_theme','padding-top','30',0,''),(612426,192805,'73755','new_theme','padding-bottom','30',0,''),(612427,192806,'73756','new_theme','block_type','4',0,''),(612428,192806,'73756','new_theme','schema','4-2',0,'8451'),(612429,192807,'73757','new_theme','block_type','1',0,''),(612430,192807,'73757','new_theme','padding-right','40',0,''),(612431,192807,'73757','new_theme','padding-right','0',0,'8451'),(612432,192808,'73758','new_theme','background-color','$content-bg-1',0,''),(612433,192808,'73758','new_theme','padding-top','30',0,''),(612434,192808,'73758','new_theme','padding-left','30',0,''),(612435,192808,'73758','new_theme','padding-right','30',0,''),(612436,192808,'73758','new_theme','padding-bottom','30',0,''),(612437,192808,'73758','new_theme','margin-bottom','20',0,''),(612438,192809,'73759','new_theme','block_type','1',0,''),(612439,192809,'73759','new_theme','background-color','$content-bg-1',0,''),(612440,192809,'73759','new_theme','padding-top','30',0,''),(612441,192809,'73759','new_theme','padding-left','30',0,''),(612442,192809,'73759','new_theme','padding-right','30',0,''),(612443,192809,'73759','new_theme','padding-bottom','14',0,''),(612444,192809,'73759','new_theme','margin-bottom','20',0,''),(612445,192809,'73759','new_theme','style_class','hiding-box closeable-box',0,''),(612446,192810,'73760','new_theme','style_class','closeable-content',0,''),(612447,192810,'73760','new_theme','padding-bottom','20',0,''),(612448,192811,'73761','new_theme','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(612449,192811,'73761','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612450,192812,'73762','new_theme','block_type','1',0,''),(612451,192812,'73762','new_theme','background-color','$content-bg-1',0,''),(612452,192812,'73762','new_theme','padding-top','30',0,''),(612453,192812,'73762','new_theme','padding-left','30',0,''),(612454,192812,'73762','new_theme','padding-right','30',0,''),(612455,192812,'73762','new_theme','padding-bottom','30',0,''),(612456,192812,'73762','new_theme','margin-bottom','20',0,''),(612457,192812,'73762','new_theme','style_class','hiding-box',0,''),(612458,192813,'73763','new_theme','padding-top','10',0,''),(612459,192813,'73763','new_theme','padding-left','20',0,''),(612460,192813,'73763','new_theme','padding-right','20',0,''),(612461,192813,'73763','new_theme','margin-top','20',0,''),(612462,192813,'73763','new_theme','background-color','$content-bg-2',0,''),(612463,192813,'73763','new_theme','padding-bottom','8',0,''),(612464,192814,'73764','new_theme','margin-bottom','20',0,''),(612465,192815,'73765','new_theme','block_type','1',0,''),(612466,192815,'73765','new_theme','padding-top','30',0,''),(612467,192815,'73765','new_theme','padding-left','30',0,''),(612468,192815,'73765','new_theme','padding-right','30',0,''),(612469,192815,'73765','new_theme','padding-bottom','23',0,''),(612470,192815,'73765','new_theme','margin-bottom','20',0,''),(612471,192815,'73765','new_theme','background-color','$content-bg-1',0,''),(612472,192815,'73765','new_theme','style_class','hiding-box',0,''),(612473,192816,'73766','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(612474,192817,'73767','new_theme','block_type','2',0,''),(612475,192817,'73767','new_theme','schema','2-2',0,'8451'),(612476,192818,'73768','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612477,192819,'73769','new_theme','padding-right','20',0,''),(612478,192819,'73769','new_theme','padding-right','0',0,'8451'),(612479,192819,'73769','new_theme','padding-bottom','20',0,'8451'),(612480,192820,'73770','new_theme','block_type','1',0,''),(612481,192820,'73770','new_theme','padding-left','20',0,''),(612482,192820,'73770','new_theme','padding-left','0',0,'8451'),(612483,192822,'73772','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612484,192823,'73773','new_theme','block_type','1',0,''),(612485,192823,'73773','new_theme','padding-top','20',0,''),(612486,192823,'73773','new_theme','padding-left','20',0,''),(612487,192823,'73773','new_theme','padding-right','20',0,''),(612488,192823,'73773','new_theme','padding-bottom','20',0,''),(612489,192823,'73773','new_theme','background-color','$content-bg-1',0,''),(612490,192823,'73773','new_theme','style_class','order-summary',0,''),(612491,192825,'73775','new_theme','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(612492,192825,'73775','new_theme','text-align','center',0,''),(612493,192825,'73775','new_theme','font-size','14',0,''),(612494,192825,'73775','new_theme','color','$fade-color-1',0,''),(612495,192825,'73775','new_theme','padding-top','10',0,''),(612496,192826,'73776','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(612497,192827,'73777','new_theme','margin-bottom','10',0,''),(612498,192828,'73778','new_theme','block_type','2',0,''),(612499,192829,'73779','new_theme','block_type','1',0,''),(612500,192829,'73779','new_theme','padding-left','0',0,'8451'),(612501,192829,'73779','new_theme','padding-right','20',0,''),(612502,192831,'73781','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612503,192832,'73782','new_theme','block_type','1',0,''),(612504,192832,'73782','new_theme','padding-left','20',0,''),(612505,192832,'73782','new_theme','padding-left','0',0,'8451'),(612506,192837,'73787','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612507,192838,'73788','new_theme','block_type','4',0,''),(612508,192838,'73788','new_theme','schema','4-2',0,'8472'),(612509,192838,'73788','new_theme','padding-top','20',0,''),(612510,192839,'73789','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612511,192839,'73789','new_theme','text-align','right',0,''),(612512,192839,'73789','new_theme','padding-top','10',0,''),(612513,192839,'73789','new_theme','font_size_measure','em',0,''),(612514,192839,'73789','new_theme','font-size','1.2',0,''),(612515,192840,'73790','new_theme','text-align','right',0,''),(612516,192841,'73791','new_theme','block_type','2',0,''),(612517,192842,'73792','new_theme','block_type','1',0,''),(612518,192842,'73792','new_theme','padding-left','0',0,'8451'),(612519,192842,'73792','new_theme','padding-right','20',0,''),(612520,192844,'73794','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612521,192845,'73795','new_theme','block_type','1',0,''),(612522,192845,'73795','new_theme','padding-left','20',0,''),(612523,192845,'73795','new_theme','padding-left','0',0,'8451'),(612524,192847,'73797','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612525,192851,'73801','new_theme','block_type','4',0,''),(612526,192851,'73801','new_theme','schema','4-2',0,'8472'),(612527,192852,'73802','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612528,192852,'73802','new_theme','text-align','right',0,''),(612529,192852,'73802','new_theme','padding-top','10',0,''),(612530,192852,'73802','new_theme','font_size_measure','em',0,''),(612531,192852,'73802','new_theme','font-size','1.2',0,''),(612532,192853,'73803','new_theme','text-align','right',0,''),(612533,192854,'73804','new_theme','block_type','4',0,''),(612534,192854,'73804','new_theme','schema','4-2',0,'8472'),(612535,192855,'73805','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612536,192855,'73805','new_theme','text-align','right',0,''),(612537,192855,'73805','new_theme','padding-top','10',0,''),(612538,192855,'73805','new_theme','font_size_measure','em',0,''),(612539,192855,'73805','new_theme','font-size','1.2',0,''),(612540,192856,'73806','new_theme','text-align','right',0,''),(612541,192857,'73807','new_theme','block_type','2',0,''),(612542,192858,'73808','new_theme','block_type','1',0,''),(612543,192858,'73808','new_theme','padding-left','0',0,'8451'),(612544,192858,'73808','new_theme','padding-right','20',0,''),(612545,192859,'73809','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612546,192861,'73811','new_theme','block_type','1',0,''),(612547,192861,'73811','new_theme','padding-left','20',0,''),(612548,192861,'73811','new_theme','padding-left','0',0,'8451'),(612549,192866,'73816','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612550,192867,'73817','new_theme','block_type','4',0,''),(612551,192867,'73817','new_theme','schema','4-2',0,'8472'),(612552,192868,'73818','new_theme','text','\n <span class=\"continue-text\">##CONTINUE_CHECKOUT_PROCEDURE##</span>',0,''),(612553,192868,'73818','new_theme','text-align','right',0,''),(612554,192868,'73818','new_theme','padding-top','10',0,''),(612555,192868,'73818','new_theme','font_size_measure','em',0,''),(612556,192868,'73818','new_theme','font-size','1.2',0,''),(612557,192869,'73819','new_theme','text-align','right',0,''),(612558,192870,'73820','new_theme','block_type','2',0,''),(612559,192871,'73821','new_theme','block_type','1',0,''),(612560,192871,'73821','new_theme','padding-left','0',0,'8451'),(612561,192871,'73821','new_theme','padding-right','20',0,''),(612562,192873,'73823','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612563,192874,'73824','new_theme','block_type','1',0,''),(612564,192874,'73824','new_theme','padding-left','20',0,''),(612565,192874,'73824','new_theme','padding-left','0',0,'8451'),(612566,192878,'73828','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612567,192880,'73830','new_theme','text','##PAYMENT_DETAILS##',0,''),(612568,192881,'73831','new_theme','text','##PAYMENT_DETAILS##',0,''),(612569,192882,'73832','new_theme','text','##PAYMENT_DETAILS##',0,''),(612570,192883,'73833','new_theme','text','##PAYMENT_DETAILS##',0,''),(612571,192884,'73834','new_theme','text','##PAYMENT_DETAILS##',0,''),(612572,192885,'73835','new_theme','text','##PAYMENT_DETAILS##',0,''),(612573,192886,'73836','new_theme','block_type','1',0,''),(612574,192886,'73836','new_theme','background-color','$content-bg-2',0,''),(612575,192886,'73836','new_theme','padding-top','30',0,''),(612576,192886,'73836','new_theme','padding-bottom','30',0,''),(612577,192887,'73837','new_theme','block_type','4',0,''),(612578,192887,'73837','new_theme','schema','4-2',0,'8451'),(612579,192888,'73838','new_theme','block_type','1',0,''),(612580,192888,'73838','new_theme','padding-right','40',0,''),(612581,192888,'73838','new_theme','padding-right','0',0,'8451'),(612582,192889,'73839','new_theme','block_type','1',0,''),(612583,192889,'73839','new_theme','background-color','$content-bg-1',0,''),(612584,192889,'73839','new_theme','padding-top','30',0,''),(612585,192889,'73839','new_theme','padding-left','30',0,''),(612586,192889,'73839','new_theme','padding-right','30',0,''),(612587,192889,'73839','new_theme','padding-bottom','30',0,''),(612588,192889,'73839','new_theme','margin-bottom','20',0,''),(612589,192889,'73839','new_theme','style_class','hiding-box',0,''),(612590,192890,'73840','new_theme','padding-top','10',0,''),(612591,192890,'73840','new_theme','padding-left','20',0,''),(612592,192890,'73840','new_theme','padding-right','20',0,''),(612593,192890,'73840','new_theme','margin-top','20',0,''),(612594,192890,'73840','new_theme','background-color','$content-bg-2',0,''),(612595,192890,'73840','new_theme','padding-bottom','8',0,''),(612596,192891,'73841','new_theme','margin-bottom','20',0,''),(612597,192892,'73842','new_theme','background-color','$content-bg-1',0,''),(612598,192892,'73842','new_theme','block_type','1',0,''),(612599,192892,'73842','new_theme','padding-top','30',0,''),(612600,192892,'73842','new_theme','padding-left','30',0,''),(612601,192892,'73842','new_theme','padding-right','30',0,''),(612602,192892,'73842','new_theme','padding-bottom','30',0,''),(612603,192892,'73842','new_theme','margin-bottom','20',0,''),(612604,192892,'73842','new_theme','style_class','hiding-box',0,''),(612605,192893,'73843','new_theme','block_type','1',0,''),(612606,192893,'73843','new_theme','content','\\_',0,'3'),(612607,192893,'73843','new_theme','border-top-width','1',0,'3'),(612608,192893,'73843','new_theme','border-top-color','$content-border-1',0,'3'),(612609,192893,'73843','new_theme','display','block',0,'3'),(612610,192893,'73843','new_theme','position','absolute',0,'3'),(612611,192893,'73843','new_theme','top','19',0,'3'),(612612,192893,'73843','new_theme','left','0',0,'3'),(612613,192893,'73843','new_theme','right','0',0,'3'),(612614,192893,'73843','new_theme','margin-top','-2',0,'3'),(612615,192893,'73843','new_theme','position','relative',0,''),(612616,192894,'73844','new_theme','box_align','2',0,''),(612617,192894,'73844','new_theme','margin-bottom','10',0,''),(612618,192894,'73844','new_theme','background-color','$content-bg-1',0,''),(612619,192894,'73844','new_theme','position','relative',0,''),(612620,192895,'73845','new_theme','background-color','$content-bg-2',0,''),(612621,192895,'73845','new_theme','padding-top','10',0,''),(612622,192895,'73845','new_theme','padding-left','10',0,''),(612623,192895,'73845','new_theme','padding-right','10',0,''),(612624,192895,'73845','new_theme','padding-bottom','10',0,''),(612625,192895,'73845','new_theme','margin-top','10',0,''),(612626,192896,'73846','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(612627,192897,'73847','new_theme','block_type','2',0,''),(612628,192897,'73847','new_theme','schema','2-2',0,'8451'),(612629,192898,'73848','new_theme','block_type','1',0,''),(612630,192898,'73848','new_theme','padding-right','20',0,''),(612631,192898,'73848','new_theme','padding-left','0',0,'8451'),(612632,192898,'73848','new_theme','margin-bottom','20',0,'8451'),(612633,192901,'73851','new_theme','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(612634,192902,'73852','new_theme','block_type','1',0,''),(612635,192902,'73852','new_theme','padding-left','20',0,''),(612636,192902,'73852','new_theme','padding-left','0',0,'8451'),(612637,192904,'73854','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612638,192905,'73855','new_theme','border-top-width','1',0,''),(612639,192905,'73855','new_theme','border-top-color','$content-border-1',0,''),(612640,192905,'73855','new_theme','padding-top','13',0,''),(612641,192905,'73855','new_theme','padding-bottom','10',0,''),(612642,192906,'73856','new_theme','block_type','1',0,''),(612643,192906,'73856','new_theme','background-color','$content-bg-1',0,''),(612644,192906,'73856','new_theme','padding-top','30',0,''),(612645,192906,'73856','new_theme','padding-left','30',0,''),(612646,192906,'73856','new_theme','padding-right','30',0,''),(612647,192906,'73856','new_theme','padding-bottom','14',0,''),(612648,192906,'73856','new_theme','margin-bottom','20',0,''),(612649,192906,'73856','new_theme','style_class','hiding-box closeable-box',0,''),(612650,192907,'73857','new_theme','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(612651,192907,'73857','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612652,192908,'73858','new_theme','style_class','closeable-content',0,''),(612653,192908,'73858','new_theme','padding-bottom','20',0,''),(612654,192909,'73860','new_theme','block_type','1',0,''),(612655,192909,'73860','new_theme','padding-top','30',0,''),(612656,192909,'73860','new_theme','padding-left','30',0,''),(612657,192909,'73860','new_theme','padding-right','30',0,''),(612658,192909,'73860','new_theme','padding-bottom','23',0,''),(612659,192909,'73860','new_theme','margin-bottom','20',0,''),(612660,192909,'73860','new_theme','background-color','$content-bg-1',0,''),(612661,192909,'73860','new_theme','style_class','hiding-box',0,''),(612662,192910,'73861','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(612663,192911,'73862','new_theme','block_type','2',0,''),(612664,192911,'73862','new_theme','schema','2-2',0,'8451'),(612665,192912,'73863','new_theme','padding-right','20',0,''),(612666,192912,'73863','new_theme','padding-right','0',0,'8451'),(612667,192912,'73863','new_theme','padding-bottom','20',0,'8451'),(612668,192913,'73864','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612669,192914,'73865','new_theme','block_type','1',0,''),(612670,192914,'73865','new_theme','padding-left','20',0,''),(612671,192914,'73865','new_theme','padding-left','0',0,'8451'),(612672,192916,'73867','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612673,192917,'73868','new_theme','block_type','1',0,''),(612674,192917,'73868','new_theme','padding-top','20',0,''),(612675,192917,'73868','new_theme','padding-left','20',0,''),(612676,192917,'73868','new_theme','padding-right','20',0,''),(612677,192917,'73868','new_theme','padding-bottom','20',0,''),(612678,192917,'73868','new_theme','background-color','$content-bg-1',0,''),(612679,192917,'73868','new_theme','style_class','order-summary',0,''),(612680,192918,'73869','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(612681,192919,'73870','new_theme','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(612682,192919,'73870','new_theme','text-align','center',0,''),(612683,192919,'73870','new_theme','font-size','14',0,''),(612684,192919,'73870','new_theme','color','$fade-color-1',0,''),(612685,192919,'73870','new_theme','padding-top','10',0,''),(612686,192920,'73871','new_theme','margin-bottom','10',0,''),(612687,192922,'115996','new_theme','hide_continue_button','1',0,''),(612688,192923,'73873','new_theme','block_type','1',0,''),(612689,192923,'73873','new_theme','background-color','$content-bg-2',0,''),(612690,192923,'73873','new_theme','padding-top','30',0,''),(612691,192923,'73873','new_theme','padding-bottom','30',0,''),(612692,192924,'73874','new_theme','block_type','4',0,''),(612693,192924,'73874','new_theme','schema','4-2',0,'8451'),(612694,192925,'73875','new_theme','block_type','1',0,''),(612695,192925,'73875','new_theme','padding-right','40',0,''),(612696,192925,'73875','new_theme','padding-right','0',0,'8451'),(612697,192926,'73876','new_theme','background-color','$content-bg-1',0,''),(612698,192926,'73876','new_theme','padding-top','30',0,''),(612699,192926,'73876','new_theme','padding-left','30',0,''),(612700,192926,'73876','new_theme','padding-right','30',0,''),(612701,192926,'73876','new_theme','padding-bottom','30',0,''),(612702,192926,'73876','new_theme','margin-bottom','20',0,''),(612703,192927,'73877','new_theme','block_type','1',0,''),(612704,192927,'73877','new_theme','background-color','$content-bg-1',0,''),(612705,192927,'73877','new_theme','padding-top','30',0,''),(612706,192927,'73877','new_theme','padding-left','30',0,''),(612707,192927,'73877','new_theme','padding-right','30',0,''),(612708,192927,'73877','new_theme','padding-bottom','30',0,''),(612709,192927,'73877','new_theme','margin-bottom','20',0,''),(612710,192927,'73877','new_theme','style_class','hiding-box',0,''),(612711,192928,'73878','new_theme','margin-bottom','20',0,''),(612712,192929,'73879','new_theme','padding-top','10',0,''),(612713,192929,'73879','new_theme','padding-left','20',0,''),(612714,192929,'73879','new_theme','padding-right','20',0,''),(612715,192929,'73879','new_theme','margin-top','20',0,''),(612716,192929,'73879','new_theme','background-color','$content-bg-2',0,''),(612717,192929,'73879','new_theme','padding-bottom','8',0,''),(612718,192930,'73880','new_theme','background-color','$content-bg-1',0,''),(612719,192930,'73880','new_theme','block_type','1',0,''),(612720,192930,'73880','new_theme','padding-top','30',0,''),(612721,192930,'73880','new_theme','padding-left','30',0,''),(612722,192930,'73880','new_theme','padding-right','30',0,''),(612723,192930,'73880','new_theme','padding-bottom','30',0,''),(612724,192930,'73880','new_theme','margin-bottom','20',0,''),(612725,192930,'73880','new_theme','style_class','hiding-box',0,''),(612726,192931,'73881','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(612727,192932,'73882','new_theme','background-color','$content-bg-2',0,''),(612728,192932,'73882','new_theme','padding-top','10',0,''),(612729,192932,'73882','new_theme','padding-left','10',0,''),(612730,192932,'73882','new_theme','padding-right','10',0,''),(612731,192932,'73882','new_theme','padding-bottom','10',0,''),(612732,192932,'73882','new_theme','margin-top','10',0,''),(612733,192933,'73883','new_theme','block_type','1',0,''),(612734,192933,'73883','new_theme','content','\\_',0,'3'),(612735,192933,'73883','new_theme','border-top-width','1',0,'3'),(612736,192933,'73883','new_theme','border-top-color','$content-border-1',0,'3'),(612737,192933,'73883','new_theme','display','block',0,'3'),(612738,192933,'73883','new_theme','position','absolute',0,'3'),(612739,192933,'73883','new_theme','top','19',0,'3'),(612740,192933,'73883','new_theme','left','0',0,'3'),(612741,192933,'73883','new_theme','right','0',0,'3'),(612742,192933,'73883','new_theme','margin-top','-2',0,'3'),(612743,192933,'73883','new_theme','position','relative',0,''),(612744,192934,'73884','new_theme','box_align','2',0,''),(612745,192934,'73884','new_theme','margin-bottom','10',0,''),(612746,192934,'73884','new_theme','background-color','$content-bg-1',0,''),(612747,192934,'73884','new_theme','position','relative',0,''),(612748,192935,'73885','new_theme','block_type','2',0,''),(612749,192935,'73885','new_theme','schema','2-2',0,'8451'),(612750,192936,'73886','new_theme','block_type','1',0,''),(612751,192936,'73886','new_theme','padding-right','20',0,''),(612752,192936,'73886','new_theme','padding-left','0',0,'8451'),(612753,192936,'73886','new_theme','margin-bottom','20',0,'8451'),(612754,192939,'73889','new_theme','text',' <div class=\"heading-4\" id=\"contact_information\">##CONTACT_INFORMATION##</div>',0,''),(612755,192940,'73890','new_theme','block_type','1',0,''),(612756,192940,'73890','new_theme','padding-left','20',0,''),(612757,192940,'73890','new_theme','padding-left','0',0,'8451'),(612758,192942,'73892','new_theme','border-top-width','1',0,''),(612759,192942,'73892','new_theme','border-top-color','$content-border-1',0,''),(612760,192942,'73892','new_theme','padding-top','13',0,''),(612761,192942,'73892','new_theme','padding-bottom','10',0,''),(612762,192943,'73893','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612763,192944,'73894','new_theme','block_type','1',0,''),(612764,192944,'73894','new_theme','padding-top','30',0,''),(612765,192944,'73894','new_theme','padding-left','30',0,''),(612766,192944,'73894','new_theme','padding-right','30',0,''),(612767,192944,'73894','new_theme','padding-bottom','23',0,''),(612768,192944,'73894','new_theme','margin-bottom','20',0,''),(612769,192944,'73894','new_theme','background-color','$content-bg-1',0,''),(612770,192944,'73894','new_theme','style_class','hiding-box',0,''),(612771,192945,'73895','new_theme','block_type','2',0,''),(612772,192945,'73895','new_theme','schema','2-2',0,'8451'),(612773,192946,'73896','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612774,192947,'73897','new_theme','padding-right','20',0,''),(612775,192947,'73897','new_theme','padding-right','0',0,'8451'),(612776,192947,'73897','new_theme','padding-bottom','20',0,'8451'),(612777,192948,'73898','new_theme','block_type','1',0,''),(612778,192948,'73898','new_theme','padding-left','20',0,''),(612779,192948,'73898','new_theme','padding-left','0',0,'8451'),(612780,192949,'73899','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612781,192951,'73901','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(612782,192952,'73902','new_theme','block_type','1',0,''),(612783,192952,'73902','new_theme','background-color','$content-bg-1',0,''),(612784,192952,'73902','new_theme','padding-top','30',0,''),(612785,192952,'73902','new_theme','padding-left','30',0,''),(612786,192952,'73902','new_theme','padding-right','30',0,''),(612787,192952,'73902','new_theme','padding-bottom','14',0,''),(612788,192952,'73902','new_theme','margin-bottom','20',0,''),(612789,192952,'73902','new_theme','style_class','hiding-box closeable-box',0,''),(612790,192953,'73903','new_theme','text','<div class=\"heading-2 comment-ico\" id=\"comments-anchor\">##COMMENTS_ABOUT_ORDER##</div>\n<script>\n tl(function(){\n if (window.location.hash === \'#comments-anchor\') {\n var heading = $(\'#comments-anchor\').closest(\'.closeable-heading\');\n if (heading.hasClass(\'closed\')) {\n setTimeout(function(){\n heading.trigger(\'click\')\n }, 100)\n }\n }\n })\n</script>',0,''),(612791,192953,'73903','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612792,192954,'73904','new_theme','style_class','closeable-content',0,''),(612793,192954,'73904','new_theme','padding-bottom','20',0,''),(612794,192955,'73905','new_theme','block_type','1',0,''),(612795,192955,'73905','new_theme','padding-top','30',0,''),(612796,192955,'73905','new_theme','padding-left','30',0,''),(612797,192955,'73905','new_theme','padding-right','30',0,''),(612798,192955,'73905','new_theme','padding-bottom','14',0,''),(612799,192955,'73905','new_theme','margin-bottom','20',0,''),(612800,192955,'73905','new_theme','background-color','$content-bg-1',0,''),(612801,192955,'73905','new_theme','style_class','hiding-box closeable-box',0,''),(612802,192956,'73906','new_theme','block_type','2',0,''),(612803,192956,'73906','new_theme','style_class','closeable-content',0,''),(612804,192956,'73906','new_theme','schema','2-2',0,'8451'),(612805,192957,'73907','new_theme','padding-right','20',0,''),(612806,192957,'73907','new_theme','padding-bottom','20',0,''),(612807,192957,'73907','new_theme','padding-right','0',0,'8451'),(612808,192958,'73908','new_theme','padding-left','20',0,''),(612809,192958,'73908','new_theme','padding-bottom','20',0,''),(612810,192958,'73908','new_theme','padding-left','0',0,'8451'),(612811,192959,'73909','new_theme','padding-left','20',0,''),(612812,192959,'73909','new_theme','padding-bottom','20',0,''),(612813,192959,'73909','new_theme','padding-left','0',0,'8451'),(612814,192960,'73910','new_theme','text','<div class=\"heading-2 discount-ico\">##DISCOUNT_COUPON_AND_CREDIT_AMOUNT##</div>',0,''),(612815,192960,'73910','new_theme','style_class','closeable-heading closeable-event closed',0,''),(612816,192961,'73911','new_theme','block_type','1',0,''),(612817,192961,'73911','new_theme','padding-top','20',0,''),(612818,192961,'73911','new_theme','padding-left','20',0,''),(612819,192961,'73911','new_theme','padding-right','20',0,''),(612820,192961,'73911','new_theme','padding-bottom','20',0,''),(612821,192961,'73911','new_theme','background-color','$content-bg-1',0,''),(612822,192961,'73911','new_theme','style_class','order-summary',0,''),(612823,192962,'73912','new_theme','margin-bottom','10',0,''),(612824,192963,'73913','new_theme','text','##CONTINUE_CHECKOUT_PROCEDURE##',0,''),(612825,192963,'73913','new_theme','text-align','center',0,''),(612826,192963,'73913','new_theme','font-size','14',0,''),(612827,192963,'73913','new_theme','color','$fade-color-1',0,''),(612828,192963,'73913','new_theme','padding-top','10',0,''),(612829,192964,'73914','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(612830,192966,'115998','new_theme','hide_continue_button','1',0,''),(612831,192967,'73916','new_theme','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(612832,192972,'73921','new_theme','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(612833,192973,'73923','new_theme','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_CART##</div>',0,''),(612834,192974,'73924','new_theme','style_class','order-summary',0,''),(612835,192974,'73924','new_theme','box_align','3',0,''),(612836,192974,'73924','new_theme','width','400',0,''),(612837,192976,'73922','new_theme','text',' <div class=\"heading-2\">##TEXT_ITEM_IN_YOUR_QUOTE##</div>',0,''),(612838,192979,'73928','new_theme','block_type','1',0,''),(612839,192980,'73929','new_theme','text','<h1>##TEXT_COMMUNICATION_TOPIC_LIST##</h1>',0,''),(612840,192981,'73930','new_theme','float','right',0,''),(612841,192981,'73930','new_theme','position','relative',0,''),(612842,192981,'73930','new_theme','z-index','1',0,''),(612843,192981,'73930','new_theme','top','30',0,''),(612844,192981,'73930','new_theme','margin-bottom','-20',0,''),(612845,192982,'73931','new_theme','margin-bottom','30',0,''),(612846,192983,'94704','new_theme','block_type','1',0,''),(612847,192984,'94705','new_theme','listing_type','Compare Products',0,''),(612848,192985,'94706','new_theme','block_type','1',0,''),(612849,192985,'94706','new_theme','style_class','item-holder',0,''),(612850,192985,'94706','new_theme','padding-top','10',0,''),(612851,192985,'94706','new_theme','padding-left','20',0,''),(612852,192985,'94706','new_theme','padding-right','20',0,''),(612853,192985,'94706','new_theme','padding-bottom','10',0,''),(612854,192985,'94706','new_theme','text-align','left',0,''),(612855,192988,'94709','new_theme','margin-bottom','10',0,''),(612856,192989,'94710','new_theme','block_type','5',0,''),(612857,192991,'94712','new_theme','clear','both',0,''),(612858,192992,'94713','new_theme','block_type','2',0,''),(612859,192993,'94714','new_theme','margin-bottom','7',0,''),(612860,192994,'94715','new_theme','text-align','right',0,''),(612861,192994,'94715','new_theme','margin-bottom','10',0,''),(612862,192994,'94715','new_theme','float','right',0,''),(612863,192995,'73932','new_theme','block_type','1',0,''),(612864,192995,'73932','new_theme','background-color','$content-bg-2',0,''),(612865,192995,'73932','new_theme','padding-bottom','30',0,''),(612866,192995,'73932','new_theme','color','$content-color-2',0,''),(612867,192996,'73933','new_theme','block_type','4',0,''),(612868,192996,'73933','new_theme','schema','4-2',0,'8451'),(612869,192997,'73934','new_theme','block_type','1',0,''),(612870,192997,'73934','new_theme','padding-right','40',0,''),(612871,192997,'73934','new_theme','padding-right','0',0,'8451'),(612872,192998,'73935','new_theme','block_type','1',0,''),(612873,192998,'73935','new_theme','padding-right','30',0,''),(612874,192998,'73935','new_theme','background-color','$content-bg-1',0,''),(612875,192998,'73935','new_theme','padding-top','20',0,''),(612876,192998,'73935','new_theme','padding-left','30',0,''),(612877,192998,'73935','new_theme','padding-bottom','20',0,''),(612878,192998,'73935','new_theme','padding-left','20',0,'8451'),(612879,192998,'73935','new_theme','padding-right','20',0,'8451'),(612880,192998,'73935','new_theme','color','$content-color-1',0,''),(612881,192999,'73936','new_theme','link','products',0,''),(612882,192999,'73936','new_theme','float','right',0,''),(612883,192999,'73936','new_theme','margin-top','-37',0,''),(612884,193001,'73938','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(612885,193002,'73939','new_theme','block_type','1',0,''),(612886,193002,'73939','new_theme','background-color','$content-bg-1',0,''),(612887,193002,'73939','new_theme','padding-top','20',0,''),(612888,193002,'73939','new_theme','padding-bottom','20',0,''),(612889,193002,'73939','new_theme','padding-left','30',0,''),(612890,193002,'73939','new_theme','padding-right','30',0,''),(612891,193002,'73939','new_theme','margin-bottom','20',0,''),(612892,193002,'73939','new_theme','color','$content-color-1',0,''),(612893,193003,'73940','new_theme','float','right',0,''),(612894,193003,'73940','new_theme','margin-top','-37',0,''),(612895,193003,'73940','new_theme','link','comments',0,''),(612896,193004,'73941','new_theme','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612897,193005,'73942','new_theme','hide_parents','2',0,''),(612898,193006,'73943','new_theme','block_type','2',0,''),(612899,193006,'73943','new_theme','margin-bottom','20',0,''),(612900,193006,'73943','new_theme','schema','2-2',0,'8444'),(612901,193006,'73943','new_theme','background-color','$content-bg-1',0,''),(612902,193006,'73943','new_theme','color','$content-color-1',0,''),(612903,193007,'73944','new_theme','block_type','1',0,''),(612904,193007,'73944','new_theme','border-right-width','20',0,''),(612905,193007,'73944','new_theme','border-right-color','$content-bg-2',0,''),(612906,193007,'73944','new_theme','margin-right','-10',0,''),(612907,193007,'73944','new_theme','padding-right','30',0,''),(612908,193007,'73944','new_theme','padding-top','20',0,''),(612909,193007,'73944','new_theme','padding-left','30',0,''),(612910,193007,'73944','new_theme','padding-bottom','20',0,''),(612911,193007,'73944','new_theme','border-right-width','0',0,'8451'),(612912,193007,'73944','new_theme','margin-right','0',0,'8451'),(612913,193007,'73944','new_theme','margin-bottom','20',0,'8451'),(612914,193007,'73944','new_theme','padding-left','20',0,'8451'),(612915,193007,'73944','new_theme','padding-right','20',0,'8451'),(612916,193008,'73945','new_theme','link','shipping_method',0,''),(612917,193008,'73945','new_theme','float','right',0,''),(612918,193008,'73945','new_theme','margin-top','-31',0,''),(612919,193010,'73947','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(612920,193010,'73947','new_theme','padding-top','20',0,''),(612921,193011,'73948','new_theme','link','contact_information',0,''),(612922,193011,'73948','new_theme','margin-top','-31',0,''),(612923,193011,'73948','new_theme','float','right',0,''),(612924,193012,'73949','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(612925,193012,'73949','new_theme','clear','none',0,''),(612926,193014,'73951','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(612927,193015,'73952','new_theme','link','shipping_address',0,''),(612928,193015,'73952','new_theme','float','right',0,''),(612929,193015,'73952','new_theme','margin-top','-31',0,''),(612930,193017,'73954','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(612931,193017,'73954','new_theme','clear','none',0,''),(612932,193018,'73955','new_theme','margin-bottom','20',0,''),(612933,193019,'73956','new_theme','block_type','1',0,''),(612934,193019,'73956','new_theme','padding-left','30',0,''),(612935,193019,'73956','new_theme','border-left-width','20',0,''),(612936,193019,'73956','new_theme','border-left-color','$content-bg-2',0,''),(612937,193019,'73956','new_theme','margin-left','-10',0,''),(612938,193019,'73956','new_theme','padding-right','30',0,''),(612939,193019,'73956','new_theme','padding-top','20',0,''),(612940,193019,'73956','new_theme','padding-bottom','20',0,''),(612941,193019,'73956','new_theme','border-left-width','0',0,'8451'),(612942,193020,'73957','new_theme','link','payment_method',0,''),(612943,193020,'73957','new_theme','float','right',0,''),(612944,193020,'73957','new_theme','margin-top','-31',0,''),(612945,193021,'73958','new_theme','link','billing_address',0,''),(612946,193021,'73958','new_theme','float','right',0,''),(612947,193021,'73958','new_theme','margin-top','-31',0,''),(612948,193023,'73960','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(612949,193023,'73960','new_theme','clear','none',0,''),(612950,193024,'73961','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(612951,193025,'73962','new_theme','margin-bottom','20',0,''),(612952,193026,'73963','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(612953,193026,'73963','new_theme','clear','none',0,''),(612954,193028,'73965','new_theme','block_type','1',0,''),(612955,193028,'73965','new_theme','padding-top','20',0,''),(612956,193028,'73965','new_theme','padding-left','20',0,''),(612957,193028,'73965','new_theme','padding-right','20',0,''),(612958,193028,'73965','new_theme','padding-bottom','20',0,''),(612959,193028,'73965','new_theme','background-color','$content-bg-1',0,''),(612960,193028,'73965','new_theme','style_class','order-summary2 hiding-box',0,''),(612961,193028,'73965','new_theme','color','$content-color-1',0,''),(612962,193029,'73966','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(612963,193030,'73967','new_theme','margin-bottom','20',0,''),(612964,193030,'73967','new_theme','text-align','right',0,''),(612965,193032,'73969','new_theme','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(612966,193033,'73970','new_theme','block_type','1',0,''),(612967,193033,'73970','new_theme','background-color','$content-bg-2',0,''),(612968,193033,'73970','new_theme','padding-bottom','30',0,''),(612969,193034,'73971','new_theme','block_type','4',0,''),(612970,193034,'73971','new_theme','schema','4-2',0,'8451'),(612971,193035,'73972','new_theme','block_type','1',0,''),(612972,193035,'73972','new_theme','padding-right','40',0,''),(612973,193035,'73972','new_theme','padding-right','0',0,'8451'),(612974,193036,'73973','new_theme','block_type','1',0,''),(612975,193036,'73973','new_theme','background-color','$content-bg-1',0,''),(612976,193036,'73973','new_theme','padding-top','20',0,''),(612977,193036,'73973','new_theme','padding-bottom','20',0,''),(612978,193036,'73973','new_theme','padding-left','30',0,''),(612979,193036,'73973','new_theme','padding-right','30',0,''),(612980,193036,'73973','new_theme','margin-bottom','20',0,''),(612981,193037,'73974','new_theme','hide_parents','2',0,''),(612982,193038,'73975','new_theme','float','right',0,''),(612983,193038,'73975','new_theme','margin-top','-37',0,''),(612984,193038,'73975','new_theme','link','comments',0,''),(612985,193039,'73976','new_theme','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(612986,193040,'73977','new_theme','block_type','1',0,''),(612987,193040,'73977','new_theme','padding-right','30',0,''),(612988,193040,'73977','new_theme','background-color','$content-bg-1',0,''),(612989,193040,'73977','new_theme','padding-top','20',0,''),(612990,193040,'73977','new_theme','padding-left','30',0,''),(612991,193040,'73977','new_theme','padding-bottom','20',0,''),(612992,193040,'73977','new_theme','padding-left','20',0,'8451'),(612993,193040,'73977','new_theme','padding-right','20',0,'8451'),(612994,193041,'73978','new_theme','link','products',0,''),(612995,193041,'73978','new_theme','float','right',0,''),(612996,193041,'73978','new_theme','margin-top','-37',0,''),(612997,193042,'73979','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(612998,193044,'73981','new_theme','block_type','2',0,''),(612999,193044,'73981','new_theme','margin-bottom','20',0,''),(613000,193044,'73981','new_theme','schema','2-2',0,'8444'),(613001,193044,'73981','new_theme','background-color','$content-bg-1',0,''),(613002,193045,'73982','new_theme','block_type','1',0,''),(613003,193045,'73982','new_theme','border-right-width','20',0,''),(613004,193045,'73982','new_theme','border-right-color','$content-border-1',0,''),(613005,193045,'73982','new_theme','margin-right','-10',0,''),(613006,193045,'73982','new_theme','padding-right','30',0,''),(613007,193045,'73982','new_theme','padding-top','20',0,''),(613008,193045,'73982','new_theme','padding-left','30',0,''),(613009,193045,'73982','new_theme','padding-bottom','20',0,''),(613010,193045,'73982','new_theme','border-right-width','0',0,'8451'),(613011,193045,'73982','new_theme','margin-right','0',0,'8451'),(613012,193045,'73982','new_theme','margin-bottom','20',0,'8451'),(613013,193045,'73982','new_theme','padding-left','20',0,'8451'),(613014,193045,'73982','new_theme','padding-right','20',0,'8451'),(613015,193046,'73983','new_theme','link','shipping_address',0,''),(613016,193046,'73983','new_theme','float','right',0,''),(613017,193046,'73983','new_theme','margin-top','-31',0,''),(613018,193048,'73985','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(613019,193048,'73985','new_theme','clear','none',0,''),(613020,193049,'73986','new_theme','link','shipping_method',0,''),(613021,193049,'73986','new_theme','float','right',0,''),(613022,193049,'73986','new_theme','margin-top','-31',0,''),(613023,193050,'73987','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(613024,193050,'73987','new_theme','clear','none',0,''),(613025,193051,'73988','new_theme','margin-bottom','20',0,''),(613026,193052,'73989','new_theme','block_type','1',0,''),(613027,193052,'73989','new_theme','padding-left','30',0,''),(613028,193052,'73989','new_theme','border-left-width','20',0,''),(613029,193052,'73989','new_theme','border-left-color','$content-border-1',0,''),(613030,193052,'73989','new_theme','margin-left','-10',0,''),(613031,193052,'73989','new_theme','padding-right','30',0,''),(613032,193052,'73989','new_theme','padding-top','20',0,''),(613033,193052,'73989','new_theme','padding-bottom','20',0,''),(613034,193052,'73989','new_theme','border-left-width','0',0,'8451'),(613035,193055,'73992','new_theme','link','contact_information',0,''),(613036,193055,'73992','new_theme','margin-top','-31',0,''),(613037,193055,'73992','new_theme','float','right',0,''),(613038,193056,'73993','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(613039,193057,'73994','new_theme','block_type','1',0,''),(613040,193057,'73994','new_theme','padding-top','20',0,''),(613041,193057,'73994','new_theme','padding-left','20',0,''),(613042,193057,'73994','new_theme','padding-right','20',0,''),(613043,193057,'73994','new_theme','padding-bottom','20',0,''),(613044,193057,'73994','new_theme','background-color','$content-bg-1',0,''),(613045,193057,'73994','new_theme','style_class','order-summary',0,''),(613046,193058,'73995','new_theme','margin-bottom','20',0,''),(613047,193058,'73995','new_theme','text-align','right',0,''),(613048,193059,'73996','new_theme','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(613049,193060,'73997','new_theme','block_type','1',0,''),(613050,193060,'73997','new_theme','background-color','$content-bg-2',0,''),(613051,193060,'73997','new_theme','padding-bottom','30',0,''),(613052,193060,'73997','new_theme','color','$content-color-2',0,''),(613053,193061,'73998','new_theme','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(613054,193062,'73999','new_theme','block_type','4',0,''),(613055,193063,'74000','new_theme','block_type','1',0,''),(613056,193063,'74000','new_theme','padding-right','40',0,''),(613057,193064,'74001','new_theme','block_type','2',0,''),(613058,193064,'74001','new_theme','margin-bottom','20',0,''),(613059,193064,'74001','new_theme','schema','2-2',0,'8444'),(613060,193064,'74001','new_theme','background-color','$content-bg-1',0,''),(613061,193064,'74001','new_theme','color','$content-color-1',0,''),(613062,193065,'74002','new_theme','block_type','1',0,''),(613063,193065,'74002','new_theme','padding-right','0',0,'8444'),(613064,193065,'74002','new_theme','border-right-width','20',0,''),(613065,193065,'74002','new_theme','border-right-color','$content-bg-2',0,''),(613066,193065,'74002','new_theme','margin-right','-10',0,''),(613067,193065,'74002','new_theme','padding-right','30',0,''),(613068,193065,'74002','new_theme','padding-top','20',0,''),(613069,193065,'74002','new_theme','padding-left','30',0,''),(613070,193065,'74002','new_theme','padding-bottom','20',0,''),(613071,193066,'74003','new_theme','link','contact_information',0,''),(613072,193066,'74003','new_theme','margin-top','-37',0,''),(613073,193066,'74003','new_theme','float','right',0,''),(613074,193067,'74004','new_theme','text',' <div class=\"heading-2\">##CONTACT_INFORMATION##</div>',0,''),(613075,193067,'74004','new_theme','padding-top','20',0,''),(613076,193069,'74006','new_theme','block_type','1',0,''),(613077,193069,'74006','new_theme','padding-left','30',0,''),(613078,193069,'74006','new_theme','padding-left','0',0,'8444'),(613079,193069,'74006','new_theme','border-left-width','20',0,''),(613080,193069,'74006','new_theme','border-left-color','$content-bg-2',0,''),(613081,193069,'74006','new_theme','margin-left','-10',0,''),(613082,193069,'74006','new_theme','padding-right','30',0,''),(613083,193069,'74006','new_theme','padding-top','20',0,''),(613084,193069,'74006','new_theme','padding-bottom','20',0,''),(613085,193071,'74008','new_theme','link','payment_method',0,''),(613086,193071,'74008','new_theme','float','right',0,''),(613087,193071,'74008','new_theme','margin-top','-31',0,''),(613088,193072,'74009','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(613089,193072,'74009','new_theme','clear','none',0,''),(613090,193073,'74010','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(613091,193074,'74011','new_theme','link','billing_address',0,''),(613092,193074,'74011','new_theme','float','right',0,''),(613093,193074,'74011','new_theme','margin-top','-31',0,''),(613094,193075,'74012','new_theme','margin-bottom','20',0,''),(613095,193076,'74013','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(613096,193076,'74013','new_theme','clear','none',0,''),(613097,193077,'74014','new_theme','block_type','1',0,''),(613098,193077,'74014','new_theme','background-color','$content-bg-1',0,''),(613099,193077,'74014','new_theme','padding-top','20',0,''),(613100,193077,'74014','new_theme','padding-bottom','20',0,''),(613101,193077,'74014','new_theme','padding-left','30',0,''),(613102,193077,'74014','new_theme','padding-right','30',0,''),(613103,193077,'74014','new_theme','margin-bottom','20',0,''),(613104,193077,'74014','new_theme','color','$content-color-1',0,''),(613105,193078,'74015','new_theme','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(613106,193079,'74016','new_theme','hide_parents','2',0,''),(613107,193080,'74017','new_theme','float','right',0,''),(613108,193080,'74017','new_theme','margin-top','-37',0,''),(613109,193080,'74017','new_theme','link','comments',0,''),(613110,193081,'74018','new_theme','block_type','1',0,''),(613111,193081,'74018','new_theme','padding-right','30',0,''),(613112,193081,'74018','new_theme','padding-right','0',0,'8444'),(613113,193081,'74018','new_theme','background-color','$content-bg-1',0,''),(613114,193081,'74018','new_theme','padding-top','20',0,''),(613115,193081,'74018','new_theme','padding-left','30',0,''),(613116,193081,'74018','new_theme','padding-bottom','20',0,''),(613117,193081,'74018','new_theme','color','$content-color-1',0,''),(613118,193082,'74019','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(613119,193083,'74020','new_theme','link','products',0,''),(613120,193083,'74020','new_theme','float','right',0,''),(613121,193083,'74020','new_theme','margin-top','-37',0,''),(613122,193085,'74022','new_theme','block_type','1',0,''),(613123,193085,'74022','new_theme','padding-top','20',0,''),(613124,193085,'74022','new_theme','padding-left','20',0,''),(613125,193085,'74022','new_theme','padding-right','20',0,''),(613126,193085,'74022','new_theme','padding-bottom','20',0,''),(613127,193085,'74022','new_theme','background-color','$content-bg-1',0,''),(613128,193085,'74022','new_theme','style_class','order-summary2 hiding-box',0,''),(613129,193085,'74022','new_theme','color','$content-color-1',0,''),(613130,193086,'74023','new_theme','margin-bottom','20',0,''),(613131,193086,'74023','new_theme','text-align','right',0,''),(613132,193087,'74024','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(613133,193089,'74026','new_theme','block_type','1',0,''),(613134,193089,'74026','new_theme','background-color','$content-bg-2',0,''),(613135,193089,'74026','new_theme','padding-bottom','30',0,''),(613136,193090,'74027','new_theme','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(613137,193091,'74028','new_theme','block_type','4',0,''),(613138,193091,'74028','new_theme','schema','4-2',0,'8451'),(613139,193092,'74029','new_theme','block_type','1',0,''),(613140,193092,'74029','new_theme','padding-right','40',0,''),(613141,193092,'74029','new_theme','padding-right','0',0,'8451'),(613142,193093,'74030','new_theme','block_type','1',0,''),(613143,193093,'74030','new_theme','background-color','$content-bg-1',0,''),(613144,193093,'74030','new_theme','padding-top','20',0,''),(613145,193093,'74030','new_theme','padding-bottom','20',0,''),(613146,193093,'74030','new_theme','padding-left','30',0,''),(613147,193093,'74030','new_theme','padding-right','30',0,''),(613148,193093,'74030','new_theme','margin-bottom','20',0,''),(613149,193094,'74031','new_theme','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(613150,193095,'74032','new_theme','hide_parents','2',0,''),(613151,193096,'74033','new_theme','float','right',0,''),(613152,193096,'74033','new_theme','margin-top','-37',0,''),(613153,193096,'74033','new_theme','link','comments',0,''),(613154,193097,'74034','new_theme','block_type','2',0,''),(613155,193097,'74034','new_theme','margin-bottom','20',0,''),(613156,193097,'74034','new_theme','schema','2-2',0,'8444'),(613157,193097,'74034','new_theme','background-color','$content-bg-1',0,''),(613158,193098,'74035','new_theme','block_type','1',0,''),(613159,193098,'74035','new_theme','border-right-width','20',0,''),(613160,193098,'74035','new_theme','border-right-color','$content-border-1',0,''),(613161,193098,'74035','new_theme','margin-right','-10',0,''),(613162,193098,'74035','new_theme','padding-right','30',0,''),(613163,193098,'74035','new_theme','padding-top','20',0,''),(613164,193098,'74035','new_theme','padding-left','30',0,''),(613165,193098,'74035','new_theme','padding-bottom','20',0,''),(613166,193098,'74035','new_theme','border-right-width','0',0,'8451'),(613167,193098,'74035','new_theme','margin-right','0',0,'8451'),(613168,193098,'74035','new_theme','margin-bottom','20',0,'8451'),(613169,193098,'74035','new_theme','padding-left','20',0,'8451'),(613170,193098,'74035','new_theme','padding-right','20',0,'8451'),(613171,193099,'74036','new_theme','link','contact_information',0,''),(613172,193099,'74036','new_theme','margin-top','-31',0,''),(613173,193099,'74036','new_theme','float','right',0,''),(613174,193102,'74039','new_theme','link','payment_method',0,''),(613175,193102,'74039','new_theme','float','right',0,''),(613176,193102,'74039','new_theme','margin-top','-31',0,''),(613177,193103,'74040','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(613178,193103,'74040','new_theme','padding-top','20',0,''),(613179,193104,'74041','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(613180,193104,'74041','new_theme','clear','none',0,''),(613181,193105,'74042','new_theme','block_type','1',0,''),(613182,193105,'74042','new_theme','padding-left','30',0,''),(613183,193105,'74042','new_theme','border-left-width','20',0,''),(613184,193105,'74042','new_theme','border-left-color','$content-border-1',0,''),(613185,193105,'74042','new_theme','margin-left','-10',0,''),(613186,193105,'74042','new_theme','padding-right','30',0,''),(613187,193105,'74042','new_theme','padding-top','20',0,''),(613188,193105,'74042','new_theme','padding-bottom','20',0,''),(613189,193105,'74042','new_theme','border-left-width','0',0,'8451'),(613190,193106,'74043','new_theme','margin-bottom','20',0,''),(613191,193107,'74044','new_theme','link','billing_address',0,''),(613192,193107,'74044','new_theme','float','right',0,''),(613193,193107,'74044','new_theme','margin-top','-31',0,''),(613194,193108,'74045','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(613195,193108,'74045','new_theme','clear','none',0,''),(613196,193109,'74046','new_theme','block_type','1',0,''),(613197,193109,'74046','new_theme','padding-right','30',0,''),(613198,193109,'74046','new_theme','background-color','$content-bg-1',0,''),(613199,193109,'74046','new_theme','padding-top','20',0,''),(613200,193109,'74046','new_theme','padding-left','30',0,''),(613201,193109,'74046','new_theme','padding-bottom','20',0,''),(613202,193109,'74046','new_theme','padding-left','20',0,'8451'),(613203,193109,'74046','new_theme','padding-right','20',0,'8451'),(613204,193110,'74047','new_theme','link','products',0,''),(613205,193110,'74047','new_theme','float','right',0,''),(613206,193110,'74047','new_theme','margin-top','-37',0,''),(613207,193111,'74048','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(613208,193112,'74049','new_theme','margin-bottom','20',0,''),(613209,193113,'74050','new_theme','block_type','1',0,''),(613210,193113,'74050','new_theme','padding-top','20',0,''),(613211,193113,'74050','new_theme','padding-left','20',0,''),(613212,193113,'74050','new_theme','padding-right','20',0,''),(613213,193113,'74050','new_theme','padding-bottom','20',0,''),(613214,193113,'74050','new_theme','background-color','$content-bg-1',0,''),(613215,193113,'74050','new_theme','style_class','order-summary',0,''),(613216,193114,'74051','new_theme','margin-bottom','20',0,''),(613217,193114,'74051','new_theme','text-align','right',0,''),(613218,193116,'74053','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(613219,193117,'74054','new_theme','block_type','1',0,''),(613220,193117,'74054','new_theme','background-color','$content-bg-2',0,''),(613221,193117,'74054','new_theme','padding-bottom','30',0,''),(613222,193118,'74055','new_theme','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(613223,193119,'74056','new_theme','block_type','4',0,''),(613224,193119,'74056','new_theme','schema','4-2',0,'8451'),(613225,193120,'74057','new_theme','block_type','1',0,''),(613226,193120,'74057','new_theme','padding-right','40',0,''),(613227,193120,'74057','new_theme','padding-right','0',0,'8451'),(613228,193121,'74058','new_theme','block_type','1',0,''),(613229,193121,'74058','new_theme','padding-right','30',0,''),(613230,193121,'74058','new_theme','background-color','$content-bg-1',0,''),(613231,193121,'74058','new_theme','padding-top','20',0,''),(613232,193121,'74058','new_theme','padding-left','30',0,''),(613233,193121,'74058','new_theme','padding-bottom','20',0,''),(613234,193121,'74058','new_theme','padding-left','20',0,'8451'),(613235,193121,'74058','new_theme','padding-right','20',0,'8451'),(613236,193123,'74060','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(613237,193124,'74061','new_theme','link','products',0,''),(613238,193124,'74061','new_theme','float','right',0,''),(613239,193124,'74061','new_theme','margin-top','-37',0,''),(613240,193125,'74062','new_theme','block_type','2',0,''),(613241,193125,'74062','new_theme','margin-bottom','20',0,''),(613242,193125,'74062','new_theme','schema','2-2',0,'8444'),(613243,193125,'74062','new_theme','background-color','$content-bg-1',0,''),(613244,193126,'74063','new_theme','block_type','1',0,''),(613245,193126,'74063','new_theme','border-right-width','20',0,''),(613246,193126,'74063','new_theme','border-right-color','$content-border-1',0,''),(613247,193126,'74063','new_theme','margin-right','-10',0,''),(613248,193126,'74063','new_theme','padding-right','30',0,''),(613249,193126,'74063','new_theme','padding-top','20',0,''),(613250,193126,'74063','new_theme','padding-left','30',0,''),(613251,193126,'74063','new_theme','padding-bottom','20',0,''),(613252,193126,'74063','new_theme','border-right-width','0',0,'8451'),(613253,193126,'74063','new_theme','margin-right','0',0,'8451'),(613254,193126,'74063','new_theme','margin-bottom','20',0,'8451'),(613255,193126,'74063','new_theme','padding-left','20',0,'8451'),(613256,193126,'74063','new_theme','padding-right','20',0,'8451'),(613257,193127,'74064','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(613258,193128,'74065','new_theme','link','contact_information',0,''),(613259,193128,'74065','new_theme','margin-top','-31',0,''),(613260,193128,'74065','new_theme','float','right',0,''),(613261,193129,'74066','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(613262,193129,'74066','new_theme','clear','none',0,''),(613263,193131,'74068','new_theme','margin-bottom','20',0,''),(613264,193133,'74070','new_theme','link','shipping_address',0,''),(613265,193133,'74070','new_theme','float','right',0,''),(613266,193133,'74070','new_theme','margin-top','-31',0,''),(613267,193135,'74072','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(613268,193135,'74072','new_theme','padding-top','20',0,''),(613269,193136,'74073','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(613270,193136,'74073','new_theme','clear','none',0,''),(613271,193137,'74074','new_theme','link','shipping_method',0,''),(613272,193137,'74074','new_theme','float','right',0,''),(613273,193137,'74074','new_theme','margin-top','-31',0,''),(613274,193138,'74075','new_theme','block_type','1',0,''),(613275,193138,'74075','new_theme','padding-left','30',0,''),(613276,193138,'74075','new_theme','border-left-width','20',0,''),(613277,193138,'74075','new_theme','border-left-color','$content-border-1',0,''),(613278,193138,'74075','new_theme','margin-left','-10',0,''),(613279,193138,'74075','new_theme','padding-right','30',0,''),(613280,193138,'74075','new_theme','padding-top','20',0,''),(613281,193138,'74075','new_theme','padding-bottom','20',0,''),(613282,193138,'74075','new_theme','border-left-width','0',0,'8451'),(613283,193139,'74076','new_theme','link','billing_address',0,''),(613284,193139,'74076','new_theme','float','right',0,''),(613285,193139,'74076','new_theme','margin-top','-31',0,''),(613286,193140,'74077','new_theme','margin-bottom','20',0,''),(613287,193142,'74079','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(613288,193143,'74080','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(613289,193143,'74080','new_theme','clear','none',0,''),(613290,193144,'74081','new_theme','link','payment_method',0,''),(613291,193144,'74081','new_theme','float','right',0,''),(613292,193144,'74081','new_theme','margin-top','-31',0,''),(613293,193145,'74082','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(613294,193145,'74082','new_theme','clear','none',0,''),(613295,193146,'74083','new_theme','block_type','1',0,''),(613296,193146,'74083','new_theme','background-color','$content-bg-1',0,''),(613297,193146,'74083','new_theme','padding-top','20',0,''),(613298,193146,'74083','new_theme','padding-bottom','20',0,''),(613299,193146,'74083','new_theme','padding-left','30',0,''),(613300,193146,'74083','new_theme','padding-right','30',0,''),(613301,193146,'74083','new_theme','margin-bottom','20',0,''),(613302,193147,'74084','new_theme','hide_parents','2',0,''),(613303,193148,'74085','new_theme','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(613304,193149,'74086','new_theme','float','right',0,''),(613305,193149,'74086','new_theme','margin-top','-37',0,''),(613306,193149,'74086','new_theme','link','comments',0,''),(613307,193150,'74087','new_theme','block_type','1',0,''),(613308,193150,'74087','new_theme','padding-top','20',0,''),(613309,193150,'74087','new_theme','padding-left','20',0,''),(613310,193150,'74087','new_theme','padding-right','20',0,''),(613311,193150,'74087','new_theme','padding-bottom','20',0,''),(613312,193150,'74087','new_theme','background-color','$content-bg-1',0,''),(613313,193150,'74087','new_theme','style_class','order-summary',0,''),(613314,193151,'74088','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(613315,193153,'74090','new_theme','margin-bottom','20',0,''),(613316,193153,'74090','new_theme','text-align','right',0,''),(613317,193154,'74091','new_theme','block_type','1',0,''),(613318,193154,'74091','new_theme','background-color','$content-bg-2',0,''),(613319,193154,'74091','new_theme','padding-bottom','30',0,''),(613320,193155,'74092','new_theme','block_type','4',0,''),(613321,193155,'74092','new_theme','schema','4-2',0,'8451'),(613322,193156,'74093','new_theme','block_type','1',0,''),(613323,193156,'74093','new_theme','padding-right','40',0,''),(613324,193156,'74093','new_theme','padding-right','0',0,'8451'),(613325,193157,'74094','new_theme','block_type','2',0,''),(613326,193157,'74094','new_theme','margin-bottom','20',0,''),(613327,193157,'74094','new_theme','schema','2-2',0,'8444'),(613328,193157,'74094','new_theme','background-color','$content-bg-1',0,''),(613329,193158,'74095','new_theme','block_type','1',0,''),(613330,193158,'74095','new_theme','border-right-width','20',0,''),(613331,193158,'74095','new_theme','border-right-color','$content-border-1',0,''),(613332,193158,'74095','new_theme','margin-right','-10',0,''),(613333,193158,'74095','new_theme','padding-right','30',0,''),(613334,193158,'74095','new_theme','padding-top','20',0,''),(613335,193158,'74095','new_theme','padding-left','30',0,''),(613336,193158,'74095','new_theme','padding-bottom','20',0,''),(613337,193158,'74095','new_theme','border-right-width','0',0,'8451'),(613338,193158,'74095','new_theme','margin-right','0',0,'8451'),(613339,193158,'74095','new_theme','margin-bottom','20',0,'8451'),(613340,193158,'74095','new_theme','padding-left','20',0,'8451'),(613341,193158,'74095','new_theme','padding-right','20',0,'8451'),(613342,193159,'74096','new_theme','margin-bottom','20',0,''),(613343,193160,'74097','new_theme','link','shipping_address',0,''),(613344,193160,'74097','new_theme','float','right',0,''),(613345,193160,'74097','new_theme','margin-top','-31',0,''),(613346,193161,'74098','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(613347,193161,'74098','new_theme','clear','none',0,''),(613348,193164,'74101','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(613349,193165,'74102','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(613350,193165,'74102','new_theme','clear','none',0,''),(613351,193166,'74103','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(613352,193166,'74103','new_theme','padding-top','20',0,''),(613353,193168,'74105','new_theme','link','shipping_method',0,''),(613354,193168,'74105','new_theme','float','right',0,''),(613355,193168,'74105','new_theme','margin-top','-31',0,''),(613356,193169,'74106','new_theme','link','contact_information',0,''),(613357,193169,'74106','new_theme','margin-top','-31',0,''),(613358,193169,'74106','new_theme','float','right',0,''),(613359,193170,'74107','new_theme','block_type','1',0,''),(613360,193170,'74107','new_theme','padding-left','30',0,''),(613361,193170,'74107','new_theme','border-left-width','20',0,''),(613362,193170,'74107','new_theme','border-left-color','$content-border-1',0,''),(613363,193170,'74107','new_theme','margin-left','-10',0,''),(613364,193170,'74107','new_theme','padding-right','30',0,''),(613365,193170,'74107','new_theme','padding-top','20',0,''),(613366,193170,'74107','new_theme','padding-bottom','20',0,''),(613367,193170,'74107','new_theme','border-left-width','0',0,'8451'),(613368,193171,'74108','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(613369,193171,'74108','new_theme','clear','none',0,''),(613370,193172,'74109','new_theme','margin-bottom','20',0,''),(613371,193173,'74110','new_theme','link','billing_address',0,''),(613372,193173,'74110','new_theme','float','right',0,''),(613373,193173,'74110','new_theme','margin-top','-31',0,''),(613374,193175,'74112','new_theme','link','payment_method',0,''),(613375,193175,'74112','new_theme','float','right',0,''),(613376,193175,'74112','new_theme','margin-top','-31',0,''),(613377,193176,'74113','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(613378,193177,'74114','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(613379,193177,'74114','new_theme','clear','none',0,''),(613380,193178,'74115','new_theme','block_type','1',0,''),(613381,193178,'74115','new_theme','padding-right','30',0,''),(613382,193178,'74115','new_theme','background-color','$content-bg-1',0,''),(613383,193178,'74115','new_theme','padding-top','20',0,''),(613384,193178,'74115','new_theme','padding-left','30',0,''),(613385,193178,'74115','new_theme','padding-bottom','20',0,''),(613386,193178,'74115','new_theme','padding-left','20',0,'8451'),(613387,193178,'74115','new_theme','padding-right','20',0,'8451'),(613388,193179,'74116','new_theme','link','products',0,''),(613389,193179,'74116','new_theme','float','right',0,''),(613390,193179,'74116','new_theme','margin-top','-37',0,''),(613391,193180,'74117','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(613392,193182,'74119','new_theme','block_type','1',0,''),(613393,193182,'74119','new_theme','background-color','$content-bg-1',0,''),(613394,193182,'74119','new_theme','padding-top','20',0,''),(613395,193182,'74119','new_theme','padding-bottom','20',0,''),(613396,193182,'74119','new_theme','padding-left','30',0,''),(613397,193182,'74119','new_theme','padding-right','30',0,''),(613398,193182,'74119','new_theme','margin-bottom','20',0,''),(613399,193183,'74120','new_theme','text',' <div class=\"heading-2 comment-ico\">##COMMENTS_ABOUT_ORDER##</div>',0,''),(613400,193184,'74121','new_theme','float','right',0,''),(613401,193184,'74121','new_theme','margin-top','-37',0,''),(613402,193184,'74121','new_theme','link','comments',0,''),(613403,193185,'74122','new_theme','hide_parents','2',0,''),(613404,193186,'74123','new_theme','block_type','1',0,''),(613405,193186,'74123','new_theme','padding-top','20',0,''),(613406,193186,'74123','new_theme','padding-left','20',0,''),(613407,193186,'74123','new_theme','padding-right','20',0,''),(613408,193186,'74123','new_theme','padding-bottom','20',0,''),(613409,193186,'74123','new_theme','background-color','$content-bg-1',0,''),(613410,193186,'74123','new_theme','style_class','order-summary',0,''),(613411,193188,'74125','new_theme','margin-bottom','20',0,''),(613412,193188,'74125','new_theme','text-align','right',0,''),(613413,193189,'74126','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(613414,193190,'74127','new_theme','text','\n <h1>##ORDER_CONFIRMATION##</h1>',0,''),(613415,193191,'74128','new_theme','block_type','1',0,''),(613416,193193,'74133','new_theme','block_type','2',0,''),(613417,193193,'74133','new_theme','font-weight','400',0,''),(613418,193193,'74133','new_theme','padding-bottom','20',0,''),(613419,193193,'74133','new_theme','schema','2-2',0,'8451'),(613420,193194,'74134','new_theme','show_captcha','on',0,''),(613421,193195,'74135','new_theme','font-weight','400',0,''),(613422,193195,'74135','new_theme','padding-left','40',0,''),(613423,193195,'74135','new_theme','time_format','24',0,''),(613424,193195,'74135','new_theme','show_icons','on',0,''),(613425,193195,'74135','new_theme','padding-left','0',0,'8451'),(613426,193196,'74136','new_theme','block_type','1',0,''),(613427,193197,'74137','new_theme','text','<h1>##YOUR_ACCOUNT_CREATED##</a>',0,''),(613428,193198,'74138','new_theme','text','Congratulations! Your new account has been successfully created!\nYou can now take advantage of member priviledges to enhance your online shopping\nexperience with us. If you have <small><b>ANY</b></small>\nquestions about the operation of this online shop, please email the \n<a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">store owner</a>.<br><br>\nA confirmation has been sent to the provided email address.\nIf you have not received it within the hour, please <a href=\"##URL##contact\">contact us</a>.',0,''),(613429,193198,'74138','new_theme','margin-bottom','40',0,''),(613430,193199,'74139','new_theme','width','680',0,''),(613431,193199,'74139','new_theme','font-weight','normal',0,''),(613432,193199,'74139','new_theme','font-size','12',0,''),(613433,193199,'74139','new_theme','padding-top','20',0,''),(613434,193199,'74139','new_theme','padding-bottom','20',0,''),(613435,193199,'74139','new_theme','color','$content-color-1',0,''),(613436,193200,'74140','new_theme','block_type','3',0,''),(613437,193200,'74140','new_theme','font-weight','normal',0,''),(613438,193200,'74140','new_theme','padding-top','20',0,''),(613439,193201,'74141','new_theme','font-size','12',0,''),(613440,193202,'74142','new_theme','text','<p>If undelivered please return to:</p>',1,''),(613441,193202,'74142','new_theme','font-size','12',0,''),(613442,193202,'74142','new_theme','font-weight','bold',0,''),(613443,193202,'74142','new_theme','text','<p>If undelivered please return to:</p>',0,''),(613444,193203,'74143','new_theme','text','<p>Thank you for your order</p>',1,''),(613445,193203,'74143','new_theme','color','$color-8',0,''),(613446,193203,'74143','new_theme','font-size','13',0,''),(613447,193203,'74143','new_theme','font-weight','bold',0,''),(613448,193203,'74143','new_theme','padding-top','5',0,''),(613449,193203,'74143','new_theme','text-align','center',0,''),(613450,193203,'74143','new_theme','text','<p>Thank you for your order</p>',0,''),(613451,193204,'74144','new_theme','font-weight','400',0,''),(613452,193204,'74144','new_theme','text-align','center',0,''),(613453,193204,'74144','new_theme','padding-top','0',0,''),(613454,193204,'74144','new_theme','padding-left','20',0,''),(613455,193204,'74144','new_theme','padding-right','20',0,''),(613456,193205,'74145','new_theme','text','<p>If something has gone wrong please contact us at:</p>',1,''),(613457,193205,'74145','new_theme','font-size','12',0,''),(613458,193205,'74145','new_theme','font-weight','bold',0,''),(613459,193205,'74145','new_theme','text-align','right',0,''),(613460,193205,'74145','new_theme','text','<p>If something has gone wrong please contact us at:</p>',0,''),(613461,193206,'74146','new_theme','block_type','6',0,''),(613462,193206,'74146','new_theme','font-weight','normal',0,''),(613463,193206,'74146','new_theme','font-size','16',0,''),(613464,193207,'74147','new_theme','text','<p>Email:</p>',1,''),(613465,193207,'74147','new_theme','font-weight','normal',0,''),(613466,193207,'74147','new_theme','text-align','right',0,''),(613467,193207,'74147','new_theme','font-size','12',0,''),(613468,193207,'74147','new_theme','text','<p>Email:</p>',0,''),(613469,193208,'74148','new_theme','font-weight','normal',0,''),(613470,193208,'74148','new_theme','text-align','right',0,''),(613471,193208,'74148','new_theme','font-size','12',0,''),(613472,193209,'74149','new_theme','block_type','6',0,''),(613473,193209,'74149','new_theme','font-weight','normal',0,''),(613474,193209,'74149','new_theme','font-size','16',0,''),(613475,193210,'74150','new_theme','text','<p>Phone:</p>',1,''),(613476,193210,'74150','new_theme','font-weight','normal',0,''),(613477,193210,'74150','new_theme','text-align','right',0,''),(613478,193210,'74150','new_theme','font-size','12',0,''),(613479,193210,'74150','new_theme','text','<p>Phone:</p>',0,''),(613480,193211,'74151','new_theme','font-weight','normal',0,''),(613481,193211,'74151','new_theme','text-align','right',0,''),(613482,193211,'74151','new_theme','font-size','12',0,''),(613483,193212,'74152','new_theme','font-weight','400',0,''),(613484,193212,'74152','new_theme','padding-top','20',0,''),(613485,193212,'74152','new_theme','padding-bottom','0',0,''),(613486,193212,'74152','new_theme','font-size','12',0,''),(613487,193213,'74153','new_theme','block_type','2',0,''),(613488,193213,'74153','new_theme','font-weight','normal',0,''),(613489,193213,'74153','new_theme','padding-bottom','20',0,''),(613490,193214,'74154','new_theme','font-weight','400',0,''),(613491,193214,'74154','new_theme','padding-top','20',0,''),(613492,193215,'74155','new_theme','block_type','11',0,''),(613493,193215,'74155','new_theme','font-weight','normal',0,''),(613494,193216,'74156','new_theme','text','<p>Web:</p>',1,''),(613495,193216,'74156','new_theme','font-weight','normal',0,''),(613496,193216,'74156','new_theme','text-align','right',0,''),(613497,193216,'74156','new_theme','text','<p>Web:</p>',0,''),(613498,193217,'74157','new_theme','font-weight','normal',0,''),(613499,193217,'74157','new_theme','text-align','right',0,''),(613500,193218,'74158','new_theme','block_type','11',0,''),(613501,193218,'74158','new_theme','font-weight','normal',0,''),(613502,193219,'74159','new_theme','text','<p>Phone:</p>',1,''),(613503,193219,'74159','new_theme','font-weight','normal',0,''),(613504,193219,'74159','new_theme','text-align','right',0,''),(613505,193219,'74159','new_theme','text','<p>Phone:</p>',0,''),(613506,193220,'74160','new_theme','font-weight','normal',0,''),(613507,193220,'74160','new_theme','text-align','right',0,''),(613508,193221,'74161','new_theme','block_type','11',0,''),(613509,193221,'74161','new_theme','font-weight','normal',0,''),(613510,193222,'74162','new_theme','text','<p>Email:</p>',1,''),(613511,193222,'74162','new_theme','font-weight','normal',0,''),(613512,193222,'74162','new_theme','text-align','right',0,''),(613513,193222,'74162','new_theme','text','<p>Email:</p>',0,''),(613514,193223,'74163','new_theme','font-weight','normal',0,''),(613515,193223,'74163','new_theme','text-align','right',0,''),(613516,193224,'74164','new_theme','block_type','1',0,''),(613517,193225,'74165','new_theme','font-weight','normal',0,''),(613518,193225,'74165','new_theme','text-align','right',0,''),(613519,193225,'74165','new_theme','padding-bottom','10',0,''),(613520,193225,'74165','new_theme','address_spacer',',',0,''),(613521,193225,'74165','new_theme','font-size','12',0,''),(613522,193226,'74166','new_theme','block_type','5',0,''),(613523,193226,'74166','new_theme','font-weight','normal',0,''),(613524,193226,'74166','new_theme','border-bottom-width','1',0,''),(613525,193226,'74166','new_theme','border-bottom-color','$content-border-1',0,''),(613526,193226,'74166','new_theme','border-top-width','1',0,''),(613527,193226,'74166','new_theme','border-top-color','$content-border-1',0,''),(613528,193226,'74166','new_theme','border-left-color','$content-border-1',0,''),(613529,193226,'74166','new_theme','border-left-width','1',0,''),(613530,193227,'74167','new_theme','block_type','1',0,''),(613531,193227,'74167','new_theme','font-weight','normal',0,''),(613532,193227,'74167','new_theme','padding-top','10',0,''),(613533,193227,'74167','new_theme','padding-left','10',0,''),(613534,193227,'74167','new_theme','padding-right','10',0,''),(613535,193228,'74168','new_theme','font-weight','400',0,''),(613536,193228,'74168','new_theme','line-height','120',0,''),(613537,193228,'74168','new_theme','line_height_measure','%',0,''),(613538,193228,'74168','new_theme','font-size','12',0,''),(613539,193229,'74169','new_theme','text','<p>SHIPPING ADDRESS:</p>',1,''),(613540,193229,'74169','new_theme','font-size','14',0,''),(613541,193229,'74169','new_theme','font-weight','bold',0,''),(613542,193229,'74169','new_theme','padding-bottom','10',0,''),(613543,193229,'74169','new_theme','text','<p>SHIPPING ADDRESS:</p>',0,''),(613544,193230,'74170','new_theme','block_type','1',0,''),(613545,193230,'74170','new_theme','background-color','$content-bg-2',0,''),(613546,193230,'74170','new_theme','padding-top','20',0,''),(613547,193230,'74170','new_theme','padding-left','10',0,''),(613548,193230,'74170','new_theme','padding-right','10',0,''),(613549,193230,'74170','new_theme','padding-bottom','20',0,''),(613550,193230,'74170','new_theme','font-size','14',0,''),(613551,193231,'74171','new_theme','block_type','4',0,''),(613552,193231,'74171','new_theme','font-weight','normal',0,''),(613553,193231,'74171','new_theme','border-top-width','1',0,''),(613554,193231,'74171','new_theme','border-top-color','$content-border-1',0,''),(613555,193231,'74171','new_theme','border-left-width','1',0,''),(613556,193231,'74171','new_theme','border-left-color','$content-border-1',0,''),(613557,193231,'74171','new_theme','border-right-width','1',0,''),(613558,193231,'74171','new_theme','border-right-color','$content-border-1',0,''),(613559,193231,'74171','new_theme','border-bottom-width','1',0,''),(613560,193231,'74171','new_theme','border-bottom-color','$content-border-1',0,''),(613561,193232,'74172','new_theme','block_type','2',0,''),(613562,193232,'74172','new_theme','font-weight','normal',0,''),(613563,193232,'74172','new_theme','border-right-width','1',0,''),(613564,193232,'74172','new_theme','border-right-color','$content-border-1',0,''),(613565,193233,'74173','new_theme','block_type','1',0,''),(613566,193233,'74173','new_theme','font-weight','400',0,''),(613567,193233,'74173','new_theme','background-color','$content-bg-2',0,''),(613568,193233,'74173','new_theme','padding-top','10',0,''),(613569,193233,'74173','new_theme','padding-left','10',0,''),(613570,193233,'74173','new_theme','padding-right','10',0,''),(613571,193233,'74173','new_theme','padding-bottom','30',0,''),(613572,193234,'74174','new_theme','text','<p>INVOICE ADDRESS:</p>',1,''),(613573,193234,'74174','new_theme','font-size','14',0,''),(613574,193234,'74174','new_theme','font-weight','bold',0,''),(613575,193234,'74174','new_theme','text','<p>INVOICE ADDRESS:</p>',0,''),(613576,193235,'74175','new_theme','font-size','12',0,''),(613577,193236,'74176','new_theme','block_type','1',0,''),(613578,193236,'74176','new_theme','font-weight','normal',0,''),(613579,193236,'74176','new_theme','padding-top','10',0,''),(613580,193236,'74176','new_theme','padding-left','10',0,''),(613581,193236,'74176','new_theme','padding-right','10',0,''),(613582,193236,'74176','new_theme','padding-bottom','10',0,''),(613583,193237,'74177','new_theme','font-weight','normal',0,''),(613584,193238,'74178','new_theme','text','<p>CUSTOMER:</p>',1,''),(613585,193238,'74178','new_theme','font-size','13',0,''),(613586,193238,'74178','new_theme','font-weight','bold',0,''),(613587,193238,'74178','new_theme','text','<p>CUSTOMER:</p>',0,''),(613588,193239,'74179','new_theme','text','<p>PHONE NUMBER:</p>',1,''),(613589,193239,'74179','new_theme','font-size','14',0,''),(613590,193239,'74179','new_theme','font-weight','bold',0,''),(613591,193239,'74179','new_theme','padding-top','10',0,''),(613592,193239,'74179','new_theme','text','<p>PHONE NUMBER:</p>',0,''),(613593,193240,'74180','new_theme','font-weight','normal',0,''),(613594,193242,'74182','new_theme','text','<p>E-MAIL ADDRESS:</p>',1,''),(613595,193242,'74182','new_theme','font-weight','bold',0,''),(613596,193242,'74182','new_theme','font-size','14',0,''),(613597,193242,'74182','new_theme','padding-top','10',0,''),(613598,193242,'74182','new_theme','text','<p>E-MAIL ADDRESS:</p>',0,''),(613599,193243,'74183','new_theme','block_type','2',0,''),(613600,193243,'74183','new_theme','font-weight','normal',0,''),(613601,193243,'74183','new_theme','border-top-width','1',0,''),(613602,193243,'74183','new_theme','border-top-color','$content-border-1',0,''),(613603,193243,'74183','new_theme','border-right-width','1',0,''),(613604,193243,'74183','new_theme','border-right-color','$content-border-1',0,''),(613605,193244,'74184','new_theme','block_type','1',0,''),(613606,193244,'74184','new_theme','font-weight','normal',0,''),(613607,193244,'74184','new_theme','padding-top','10',0,''),(613608,193244,'74184','new_theme','padding-left','10',0,''),(613609,193244,'74184','new_theme','padding-right','10',0,''),(613610,193244,'74184','new_theme','padding-bottom','10',0,''),(613611,193244,'74184','new_theme','border-right-width','1',0,''),(613612,193244,'74184','new_theme','border-right-color','$content-border-1',0,''),(613613,193246,'74186','new_theme','text','<p>Shipping via</p>',1,''),(613614,193246,'74186','new_theme','font-weight','bold',0,''),(613615,193246,'74186','new_theme','font-size','14',0,''),(613616,193246,'74186','new_theme','text','<p>Shipping via</p>',0,''),(613617,193247,'74187','new_theme','block_type','1',0,''),(613618,193247,'74187','new_theme','font-weight','normal',0,''),(613619,193247,'74187','new_theme','padding-top','10',0,''),(613620,193247,'74187','new_theme','padding-left','10',0,''),(613621,193247,'74187','new_theme','padding-right','10',0,''),(613622,193247,'74187','new_theme','padding-bottom','10',0,''),(613623,193248,'74188','new_theme','text','<p>Shipping service</p>',1,''),(613624,193248,'74188','new_theme','font-weight','bold',0,''),(613625,193248,'74188','new_theme','font-size','14',0,''),(613626,193248,'74188','new_theme','text','<p>Shipping service</p>',0,''),(613627,193250,'74190','new_theme','font-size','14',0,''),(613628,193250,'74190','new_theme','font-weight','bold',0,''),(613629,193250,'74190','new_theme','text-align','center',0,''),(613630,193250,'74190','new_theme','padding-bottom','10',0,''),(613631,193250,'74190','new_theme','padding-top','10',0,''),(613632,193251,'74191','new_theme','text','<p>Payment date:</p>',1,''),(613633,193251,'74191','new_theme','font-weight','bold',0,''),(613634,193251,'74191','new_theme','text-align','center',0,''),(613635,193251,'74191','new_theme','font-size','12',0,''),(613636,193251,'74191','new_theme','text','<p>Payment date:</p>',0,''),(613637,193252,'74192','new_theme','font-weight','normal',0,''),(613638,193252,'74192','new_theme','text-align','center',0,''),(613639,193252,'74192','new_theme','padding-bottom','10',0,''),(613640,193259,'74199','new_theme','text-align','center',0,''),(613641,193259,'74199','new_theme','padding-top','10',0,''),(613642,193261,'74201','new_theme','heading_type','h1',0,''),(613643,193264,'94718','new_theme','text-align','center',0,''),(613644,193264,'94718','new_theme','padding-top','10',0,''),(613645,193269,'74202','new_theme','block_type','1',0,''),(613646,193270,'74203','new_theme','block_type','1',0,''),(613647,193270,'74203','new_theme','max-width','800',0,''),(613648,193270,'74203','new_theme','margin','0 auto',0,''),(613649,193270,'74203','new_theme','background-color','$content-bg-1',0,''),(613650,193271,'74204','new_theme','color','$content-color-1',0,''),(613651,193271,'74204','new_theme','font-size','12',0,''),(613652,193271,'74204','new_theme','padding-top','20',0,''),(613653,193271,'74204','new_theme','padding-bottom','20',0,''),(613654,193271,'74204','new_theme','border-top-width','1',0,''),(613655,193271,'74204','new_theme','border-top-color','$content-border-1',0,''),(613656,193272,'74205','new_theme','font-weight','normal',0,''),(613657,193272,'74205','new_theme','padding-top','20',0,''),(613658,193272,'74205','new_theme','padding-left','10',0,''),(613659,193272,'74205','new_theme','padding-right','10',0,''),(613660,193272,'74205','new_theme','padding-bottom','20',0,''),(613661,193272,'74205','new_theme','color','$content-color-1',0,''),(613662,193272,'74205','new_theme','font-size','14',0,''),(613663,193273,'74206','new_theme','block_type','7',0,''),(613664,193273,'74206','new_theme','font-weight','normal',0,''),(613665,193273,'74206','new_theme','background-color','$highlight-box-bg-1',0,''),(613666,193273,'74206','new_theme','padding-top','5',0,''),(613667,193273,'74206','new_theme','padding-left','10',0,''),(613668,193273,'74206','new_theme','padding-right','10',0,''),(613669,193273,'74206','new_theme','padding-bottom','5',0,''),(613670,193274,'74207','new_theme','color','$highlight-box-color-1',0,''),(613671,193274,'74207','new_theme','font-size','14',0,''),(613672,193274,'74207','new_theme','font-weight','normal',0,''),(613673,193275,'74208','new_theme','font-weight','normal',0,''),(613674,193275,'74208','new_theme','text-align','right',0,''),(613675,193275,'74208','new_theme','color','$highlight-box-color-1',0,''),(613676,193275,'74208','new_theme','font-size','12',0,''),(613677,193276,'74209','new_theme','font-weight','normal',0,''),(613678,193276,'74209','new_theme','padding-bottom','10',0,''),(613679,193276,'74209','new_theme','padding-top','10',0,''),(613680,193276,'74209','new_theme','logo_from','theme',0,''),(613681,193277,'74210','new_theme','block_type','1',0,''),(613682,193278,'74211','new_theme','block_type','1',0,''),(613683,193278,'74211','new_theme','max-width','800',0,''),(613684,193278,'74211','new_theme','margin','0 auto',0,''),(613685,193278,'74211','new_theme','background-color','$content-bg-1',0,''),(613686,193279,'74212','new_theme','color','$content-color-1',0,''),(613687,193279,'74212','new_theme','font-size','12',0,''),(613688,193279,'74212','new_theme','padding-top','20',0,''),(613689,193279,'74212','new_theme','padding-bottom','20',0,''),(613690,193279,'74212','new_theme','border-top-width','1',0,''),(613691,193279,'74212','new_theme','border-top-color','$content-border-1',0,''),(613692,193280,'74213','new_theme','font-weight','normal',0,''),(613693,193280,'74213','new_theme','padding-bottom','10',0,''),(613694,193280,'74213','new_theme','background-color','$highlight-box-bg-1',0,''),(613695,193280,'74213','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',1,''),(613696,193280,'74213','new_theme','padding-left','20',0,''),(613697,193280,'74213','new_theme','padding-top','10',0,''),(613698,193280,'74213','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',0,''),(613699,193281,'74214','new_theme','font-weight','normal',0,''),(613700,193281,'74214','new_theme','padding-top','20',0,''),(613701,193281,'74214','new_theme','padding-left','10',0,''),(613702,193281,'74214','new_theme','padding-right','10',0,''),(613703,193281,'74214','new_theme','padding-bottom','20',0,''),(613704,193281,'74214','new_theme','color','$content-color-1',0,''),(613705,193281,'74214','new_theme','font-size','14',0,''),(613706,193282,'74215','new_theme','block_type','7',0,''),(613707,193282,'74215','new_theme','font-weight','normal',0,''),(613708,193282,'74215','new_theme','background-color','$highlight-box-bg-1',0,''),(613709,193282,'74215','new_theme','padding-top','5',0,''),(613710,193282,'74215','new_theme','padding-left','10',0,''),(613711,193282,'74215','new_theme','padding-right','10',0,''),(613712,193282,'74215','new_theme','padding-bottom','5',0,''),(613713,193283,'74216','new_theme','color','$highlight-box-color-1',0,''),(613714,193283,'74216','new_theme','font-size','15',0,''),(613715,193283,'74216','new_theme','font-weight','700',0,''),(613716,193284,'74217','new_theme','font-weight','normal',0,''),(613717,193284,'74217','new_theme','text-align','right',0,''),(613718,193284,'74217','new_theme','color','$highlight-box-color-1',0,''),(613719,193284,'74217','new_theme','font-size','12',0,''),(613720,193285,'74218','new_theme','block_type','1',0,''),(613721,193285,'74218','new_theme','background-color','$content-bg-2',0,''),(613722,193286,'74219','new_theme','block_type','1',0,''),(613723,193286,'74219','new_theme','max-width','800',0,''),(613724,193286,'74219','new_theme','margin','0 auto',0,''),(613725,193287,'74220','new_theme','block_type','1',0,''),(613726,193287,'74220','new_theme','background-color','$content-bg-1',0,''),(613727,193287,'74220','new_theme','padding-top','20',0,''),(613728,193287,'74220','new_theme','padding-left','20',0,''),(613729,193287,'74220','new_theme','padding-right','20',0,''),(613730,193287,'74220','new_theme','padding-bottom','20',0,''),(613731,193288,'74221','new_theme','font-weight','normal',0,''),(613732,193288,'74221','new_theme','padding-top','20',0,''),(613733,193288,'74221','new_theme','padding-bottom','20',0,''),(613734,193288,'74221','new_theme','color','$content-color-1',0,''),(613735,193288,'74221','new_theme','font-size','14',0,''),(613736,193289,'74222','new_theme','block_type','7',0,''),(613737,193289,'74222','new_theme','font-weight','normal',0,''),(613738,193289,'74222','new_theme','padding-left','10',0,''),(613739,193289,'74222','new_theme','padding-right','10',0,''),(613740,193289,'74222','new_theme','padding-bottom','15',0,''),(613741,193289,'74222','new_theme','border-bottom-width','1',0,''),(613742,193289,'74222','new_theme','border-bottom-color','$content-border-1',0,''),(613743,193290,'74223','new_theme','color','$content-color-1',0,''),(613744,193290,'74223','new_theme','font-size','14',0,''),(613745,193290,'74223','new_theme','font-weight','700',0,''),(613746,193291,'74224','new_theme','font-weight','normal',0,''),(613747,193291,'74224','new_theme','text-align','right',0,''),(613748,193291,'74224','new_theme','color','$fade-color-1',0,''),(613749,193291,'74224','new_theme','font-size','11',0,''),(613750,193291,'74224','new_theme','text-transform','uppercase',0,''),(613751,193292,'74225','new_theme','color','$fade-color-1',0,''),(613752,193292,'74225','new_theme','font-size','12',0,''),(613753,193292,'74225','new_theme','padding-top','20',0,''),(613754,193292,'74225','new_theme','padding-bottom','20',0,''),(613755,193292,'74225','new_theme','text-align','center',0,''),(613756,193293,'74226','new_theme','font-weight','normal',0,''),(613757,193293,'74226','new_theme','padding-bottom','10',0,''),(613758,193293,'74226','new_theme','padding-top','10',0,''),(613759,193293,'74226','new_theme','text-align','center',0,''),(613760,193293,'74226','new_theme','logo_from','theme',0,''),(613761,193294,'74227','new_theme','block_type','1',0,''),(613762,193294,'74227','new_theme','background-color','$content-bg-2',0,''),(613763,193294,'74227','new_theme','padding-top','20',0,''),(613764,193294,'74227','new_theme','padding-bottom','20',0,''),(613765,193295,'74228','new_theme','block_type','1',0,''),(613766,193295,'74228','new_theme','max-width','800',0,''),(613767,193295,'74228','new_theme','margin','0 auto',0,''),(613768,193296,'74229','new_theme','color','$fade-color-1',0,''),(613769,193296,'74229','new_theme','font-size','12',0,''),(613770,193296,'74229','new_theme','padding-top','20',0,''),(613771,193296,'74229','new_theme','padding-bottom','20',0,''),(613772,193296,'74229','new_theme','text-align','left',0,''),(613773,193297,'74230','new_theme','block_type','1',0,''),(613774,193297,'74230','new_theme','background-color','$content-bg-1',0,''),(613775,193297,'74230','new_theme','padding-top','20',0,''),(613776,193297,'74230','new_theme','padding-left','20',0,''),(613777,193297,'74230','new_theme','padding-right','20',0,''),(613778,193297,'74230','new_theme','padding-bottom','20',0,''),(613779,193297,'74230','new_theme','border-top-width','1',0,''),(613780,193297,'74230','new_theme','border-left-width','1',0,''),(613781,193297,'74230','new_theme','border-right-width','1',0,''),(613782,193297,'74230','new_theme','border-bottom-width','1',0,''),(613783,193297,'74230','new_theme','border-top-color','$content-border-1',0,''),(613784,193297,'74230','new_theme','border-left-color','$content-border-1',0,''),(613785,193297,'74230','new_theme','border-bottom-color','$content-border-1',0,''),(613786,193297,'74230','new_theme','border-right-color','$content-border-1',0,''),(613787,193298,'74231','new_theme','block_type','2',0,''),(613788,193299,'74232','new_theme','font-weight','normal',0,''),(613789,193299,'74232','new_theme','padding-bottom','10',0,''),(613790,193299,'74232','new_theme','padding-top','10',0,''),(613791,193299,'74232','new_theme','logo_from','theme',0,''),(613792,193300,'74233','new_theme','font-weight','normal',0,''),(613793,193300,'74233','new_theme','text-align','right',0,''),(613794,193300,'74233','new_theme','color','$fade-color-1',0,''),(613795,193300,'74233','new_theme','font-size','11',0,''),(613796,193300,'74233','new_theme','text-transform','uppercase',0,''),(613797,193301,'74234','new_theme','color','$content-color-1',0,''),(613798,193301,'74234','new_theme','font-size','14',0,''),(613799,193301,'74234','new_theme','font-weight','700',0,''),(613800,193301,'74234','new_theme','text-align','right',0,''),(613801,193302,'74235','new_theme','font-weight','normal',0,''),(613802,193302,'74235','new_theme','padding-top','20',0,''),(613803,193302,'74235','new_theme','padding-bottom','20',0,''),(613804,193302,'74235','new_theme','color','$content-color-1',0,''),(613805,193302,'74235','new_theme','font-size','14',0,''),(613806,193303,'74236','new_theme','block_type','1',0,''),(613807,193303,'74236','new_theme','font-weight','normal',0,''),(613808,193303,'74236','new_theme','padding-top','20',0,''),(613809,193303,'74236','new_theme','background-color','$footer-bg-1',0,''),(613810,193303,'74236','new_theme','color','$footer-color-1',0,''),(613811,193304,'74237','new_theme','block_type','14',0,''),(613812,193304,'74237','new_theme','margin-bottom','15',0,''),(613813,193304,'74237','new_theme','schema','14-2',0,'8451'),(613814,193304,'74237','new_theme','schema','14-3',0,'8444'),(613815,193304,'74237','new_theme','style_class','preFooter',0,''),(613816,193304,'74237','new_theme','visibility_checkout','1',0,''),(613817,193305,'74238','new_theme','block_type','1',0,''),(613818,193306,'74239','new_theme','class','menu-style-2',0,''),(613819,193307,'1695906739.5696','new_theme','text','##NAVBAR_TITLE_ACCOUNT##',0,''),(613820,193307,'1695906739.5696','new_theme','style_class','footerTitle',0,''),(613821,193307,'1695906739.5696','new_theme','font-family','$font-1',0,''),(613822,193307,'1695906739.5696','new_theme','font-size','20',0,''),(613823,193307,'1695906739.5696','new_theme','text-transform','uppercase',0,''),(613824,193308,'74241','new_theme','block_type','1',0,''),(613825,193309,'74243','new_theme','class','menu-style-2',0,''),(613826,193310,'1695906751.0591','new_theme','text','##TEXT_PRODUCTS##',0,''),(613827,193310,'1695906751.0591','new_theme','font-family','$font-1',0,''),(613828,193310,'1695906751.0591','new_theme','font-size','20',0,''),(613829,193310,'1695906751.0591','new_theme','text-transform','uppercase',0,''),(613830,193310,'1695906751.0591','new_theme','style_class','footerTitle',0,''),(613831,193311,'74244','new_theme','block_type','1',0,''),(613832,193312,'74246','new_theme','class','menu-style-2',0,''),(613833,193313,'1695906756.0887','new_theme','text','##TEXT_SHOP##',0,''),(613834,193313,'1695906756.0887','new_theme','style_class','footerTitle',0,''),(613835,193313,'1695906756.0887','new_theme','font-family','$font-1',0,''),(613836,193313,'1695906756.0887','new_theme','font-size','20',0,''),(613837,193313,'1695906756.0887','new_theme','text-transform','uppercase',0,''),(613838,193314,'74247','new_theme','block_type','1',0,''),(613839,193315,'74248','new_theme','view_item','phone_number',0,''),(613840,193316,'74249','new_theme','view_item','address',0,''),(613841,193316,'74249','new_theme','address_spacer',',<span> </span>',0,''),(613842,193317,'1695906761.6568','new_theme','text','##TEXT_CONTACT##',0,''),(613843,193317,'1695906761.6568','new_theme','font-family','$font-1',0,''),(613844,193317,'1695906761.6568','new_theme','font-size','20',0,''),(613845,193317,'1695906761.6568','new_theme','text-transform','uppercase',0,''),(613846,193317,'1695906761.6568','new_theme','style_class','footerTitle',0,''),(613847,193318,'74256','new_theme','block_type','2',0,''),(613848,193318,'74256','new_theme','font-weight','400',0,''),(613849,193318,'74256','new_theme','padding-top','20',0,''),(613850,193318,'74256','new_theme','padding-bottom','20',0,''),(613851,193318,'74256','new_theme','schema','2-2',0,''),(613852,193318,'74256','new_theme','schema','2-3',0,'8451'),(613853,193320,'74258','new_theme','address_spacer',', ',0,''),(613854,193320,'74258','new_theme','font-weight','400',0,''),(613855,193320,'74258','new_theme','padding-bottom','10',0,'8451'),(613856,193320,'74258','new_theme','margin-bottom','10',0,'8451'),(613857,193320,'74258','new_theme','border-bottom-width','1',0,'8451'),(613858,193320,'74258','new_theme','border-bottom-color','$content-border-1',0,'8451'),(613859,193321,'94723','new_theme','block_type','5',0,''),(613860,193322,'94724','new_theme','text','##TEXT_LANGUAGE##',0,''),(613861,193324,'94726','new_theme','block_type','5',0,''),(613862,193325,'94727','new_theme','text','##TEXT_CURRENCY##',0,''),(613863,193327,'74263','new_theme','block_type','1',0,''),(613864,193327,'74263','new_theme','font-weight','normal',0,''),(613865,193328,'74264','new_theme','block_type','2',0,''),(613866,193328,'74264','new_theme','font-weight','normal',0,''),(613867,193328,'74264','new_theme','padding-bottom','20',0,''),(613868,193329,'74265','new_theme','block_type','1',0,''),(613869,193329,'74265','new_theme','margin-right','20',0,''),(613870,193332,'74268','new_theme','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',1,''),(613871,193332,'74268','new_theme','font-weight','normal',0,''),(613872,193332,'74268','new_theme','padding-bottom','20',0,''),(613873,193332,'74268','new_theme','text','<p>Virtual Gift Cards will arrive directly into your recipient&#39;s inbox, or alternatively send it to yourself to print off. Please note that gift card must be redeem in full in a signle transaction.</p>',0,''),(613874,193334,'74270','new_theme','block_type','1',0,''),(613875,193334,'74270','new_theme','font-weight','normal',0,''),(613876,193334,'74270','new_theme','style_class','gift-card-view',0,''),(613877,193334,'74270','new_theme','text-align','center',0,''),(613878,193334,'74270','new_theme','padding-bottom','20',0,''),(613879,193334,'74270','new_theme','background-color','$highlight-box-bg-1',0,''),(613880,193334,'74270','new_theme','padding-left','20',0,''),(613881,193334,'74270','new_theme','padding-right','20',0,''),(613882,193334,'74270','new_theme','color','$highlight-box-color-1',0,''),(613883,193335,'74271','new_theme','block_type','1',0,''),(613884,193335,'74271','new_theme','font-weight','normal',0,''),(613885,193335,'74271','new_theme','padding-top','10',0,''),(613886,193336,'74272','new_theme','font-size','12',0,''),(613887,193336,'74272','new_theme','font-weight','bold',0,''),(613888,193336,'74272','new_theme','text-align','center',0,''),(613889,193336,'74272','new_theme','style_class','email',0,''),(613890,193337,'74273','new_theme','text','<p>If you require further assistance please contact us</p>',1,''),(613891,193337,'74273','new_theme','font-weight','normal',0,''),(613892,193337,'74273','new_theme','text-align','center',0,''),(613893,193337,'74273','new_theme','font-size','12',0,''),(613894,193337,'74273','new_theme','padding-top','10',0,''),(613895,193337,'74273','new_theme','padding-bottom','5',0,''),(613896,193337,'74273','new_theme','border-top-width','1',0,''),(613897,193337,'74273','new_theme','border-top-color','$content-border-3',0,''),(613898,193337,'74273','new_theme','text','<p>If you require further assistance please contact us</p>',0,''),(613899,193338,'74274','new_theme','font-size','12',0,''),(613900,193338,'74274','new_theme','font-weight','bold',0,''),(613901,193338,'74274','new_theme','text-align','center',0,''),(613902,193338,'74274','new_theme','style_class','phone',0,''),(613903,193338,'74274','new_theme','padding-bottom','5',0,''),(613904,193339,'74275','new_theme','text','<p>WHAT TO DO NEXT:</p>',1,''),(613905,193339,'74275','new_theme','font-weight','normal',0,''),(613906,193339,'74275','new_theme','text-align','center',0,''),(613907,193339,'74275','new_theme','padding-top','20',0,''),(613908,193339,'74275','new_theme','padding-bottom','10',0,''),(613909,193339,'74275','new_theme','style_class','question-ico',0,''),(613910,193339,'74275','new_theme','border-top-width','1',0,''),(613911,193339,'74275','new_theme','border-top-color','$content-border-3',0,''),(613912,193339,'74275','new_theme','font-size','18',0,''),(613913,193339,'74275','new_theme','text','<p>WHAT TO DO NEXT:</p>',0,''),(613914,193340,'74276','new_theme','text','<p>osCommerce</p>\n',1,''),(613915,193340,'74276','new_theme','font-family','$font-1',0,''),(613916,193340,'74276','new_theme','font-size','24',0,''),(613917,193340,'74276','new_theme','font-weight','normal',0,''),(613918,193340,'74276','new_theme','text-align','center',0,''),(613919,193340,'74276','new_theme','padding-top','10',0,''),(613920,193340,'74276','new_theme','padding-bottom','20',0,''),(613921,193340,'74276','new_theme','text','<p>osCommerce</p>\n',0,''),(613922,193341,'74277','new_theme','block_type','4',0,''),(613923,193341,'74277','new_theme','color','$highlight-box-color-2',0,''),(613924,193341,'74277','new_theme','font-size','30',0,''),(613925,193341,'74277','new_theme','font-weight','normal',0,''),(613926,193341,'74277','new_theme','background-color','$highlight-box-bg-2',0,''),(613927,193341,'74277','new_theme','padding-top','5',0,''),(613928,193341,'74277','new_theme','padding-left','10',0,''),(613929,193341,'74277','new_theme','padding-right','10',0,''),(613930,193341,'74277','new_theme','padding-bottom','5',0,''),(613931,193342,'74278','new_theme','text','<p>Your code is:</p>',1,''),(613932,193342,'74278','new_theme','font-weight','normal',0,''),(613933,193342,'74278','new_theme','text','<p>Your code is:</p>',0,''),(613934,193344,'74280','new_theme','font-weight','normal',0,''),(613935,193344,'74280','new_theme','text-align','center',0,''),(613936,193344,'74280','new_theme','padding-bottom','20',0,''),(613937,193345,'74281','new_theme','font-size','60',0,''),(613938,193345,'74281','new_theme','font-weight','bold',0,''),(613939,193345,'74281','new_theme','text-align','center',0,''),(613940,193345,'74281','new_theme','line-height','100',0,''),(613941,193345,'74281','new_theme','padding-bottom','20',0,''),(613942,193345,'74281','new_theme','line_height_measure','px',0,''),(613943,193346,'74282','new_theme','text','<p>PERSONAL MESSAGE</p>',1,''),(613944,193346,'74282','new_theme','font-size','18',0,''),(613945,193346,'74282','new_theme','font-weight','normal',0,''),(613946,193346,'74282','new_theme','text-align','center',0,''),(613947,193346,'74282','new_theme','padding-top','20',0,''),(613948,193346,'74282','new_theme','padding-bottom','10',0,''),(613949,193346,'74282','new_theme','border-top-width','1',0,''),(613950,193346,'74282','new_theme','border-top-color','$content-border-3',0,''),(613951,193346,'74282','new_theme','text','<p>PERSONAL MESSAGE</p>',0,''),(613952,193347,'74284','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',1,''),(613953,193347,'74284','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',0,''),(613954,193347,'74284','new_theme','text-align','center',0,''),(613955,193347,'74284','new_theme','padding-top','20',0,''),(613956,193347,'74284','new_theme','logo_from','theme',0,''),(613957,193348,'74285','new_theme','text','<p>GIFT CARD</p>',1,''),(613958,193348,'74285','new_theme','font-size','30',0,''),(613959,193348,'74285','new_theme','font-weight','normal',0,''),(613960,193348,'74285','new_theme','border-top-width','1',0,''),(613961,193348,'74285','new_theme','border-top-color','$content-border-3',0,''),(613962,193348,'74285','new_theme','style_class','gift-ico',0,''),(613963,193348,'74285','new_theme','text-align','center',0,''),(613964,193348,'74285','new_theme','padding-top','15',0,''),(613965,193348,'74285','new_theme','text','<p>GIFT CARD</p>',0,''),(613966,193349,'74286','new_theme','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(613967,193349,'74286','new_theme','font-weight','normal',0,''),(613968,193349,'74286','new_theme','text-align','center',0,''),(613969,193349,'74286','new_theme','padding-bottom','10',0,''),(613970,193349,'74286','new_theme','font-size','14',0,''),(613971,193349,'74286','new_theme','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',0,''),(613972,193350,'74287','new_theme','block_type','1',0,''),(613973,193350,'74287','new_theme','font-weight','normal',0,''),(613974,193350,'74287','new_theme','style_class','gift-card-view',0,''),(613975,193350,'74287','new_theme','text-align','center',0,''),(613976,193350,'74287','new_theme','padding-bottom','20',0,''),(613977,193350,'74287','new_theme','background-color','$content-bg-2',0,''),(613978,193350,'74287','new_theme','padding-left','20',0,''),(613979,193350,'74287','new_theme','padding-right','20',0,''),(613980,193350,'74287','new_theme','color','$fade-color-2',0,''),(613981,193351,'74288','new_theme','font-size','60',0,''),(613982,193351,'74288','new_theme','font-weight','bold',0,''),(613983,193351,'74288','new_theme','text-align','center',0,''),(613984,193351,'74288','new_theme','line-height','100',0,''),(613985,193351,'74288','new_theme','padding-bottom','20',0,''),(613986,193351,'74288','new_theme','line_height_measure','px',0,''),(613987,193352,'74289','new_theme','block_type','4',0,''),(613988,193352,'74289','new_theme','color','$highlight-box-color-2',0,''),(613989,193352,'74289','new_theme','font-size','30',0,''),(613990,193352,'74289','new_theme','font-weight','normal',0,''),(613991,193352,'74289','new_theme','background-color','$highlight-box-bg-2',0,''),(613992,193352,'74289','new_theme','padding-top','5',0,''),(613993,193352,'74289','new_theme','padding-left','10',0,''),(613994,193352,'74289','new_theme','padding-right','10',0,''),(613995,193352,'74289','new_theme','padding-bottom','5',0,''),(613996,193353,'74290','new_theme','text','<p>Your code is:</p>',1,''),(613997,193353,'74290','new_theme','font-weight','normal',0,''),(613998,193353,'74290','new_theme','text','<p>Your code is:</p>',0,''),(613999,193355,'74292','new_theme','block_type','1',0,''),(614000,193355,'74292','new_theme','font-weight','normal',0,''),(614001,193355,'74292','new_theme','padding-top','10',0,''),(614002,193356,'74293','new_theme','font-size','12',0,''),(614003,193356,'74293','new_theme','font-weight','bold',0,''),(614004,193356,'74293','new_theme','text-align','center',0,''),(614005,193356,'74293','new_theme','style_class','email',0,''),(614006,193357,'74294','new_theme','text','<p>If you require further assistance please contact us</p>',1,''),(614007,193357,'74294','new_theme','font-weight','normal',0,''),(614008,193357,'74294','new_theme','text-align','center',0,''),(614009,193357,'74294','new_theme','font-size','12',0,''),(614010,193357,'74294','new_theme','padding-top','10',0,''),(614011,193357,'74294','new_theme','padding-bottom','5',0,''),(614012,193357,'74294','new_theme','border-top-width','1',0,''),(614013,193357,'74294','new_theme','border-top-color','$content-border-3',0,''),(614014,193357,'74294','new_theme','text','<p>If you require further assistance please contact us</p>',0,''),(614015,193358,'74295','new_theme','font-size','12',0,''),(614016,193358,'74295','new_theme','font-weight','bold',0,''),(614017,193358,'74295','new_theme','text-align','center',0,''),(614018,193358,'74295','new_theme','style_class','phone',0,''),(614019,193358,'74295','new_theme','padding-bottom','5',0,''),(614020,193359,'74296','new_theme','font-weight','normal',0,''),(614021,193359,'74296','new_theme','text-align','center',0,''),(614022,193359,'74296','new_theme','padding-bottom','20',0,''),(614023,193360,'74297','new_theme','text','<p>PERSONAL MESSAGE</p>',1,''),(614024,193360,'74297','new_theme','font-size','18',0,''),(614025,193360,'74297','new_theme','font-weight','normal',0,''),(614026,193360,'74297','new_theme','text-align','center',0,''),(614027,193360,'74297','new_theme','padding-top','20',0,''),(614028,193360,'74297','new_theme','padding-bottom','10',0,''),(614029,193360,'74297','new_theme','border-top-width','1',0,''),(614030,193360,'74297','new_theme','border-top-color','$content-border-3',0,''),(614031,193360,'74297','new_theme','text','<p>PERSONAL MESSAGE</p>',0,''),(614032,193361,'74298','new_theme','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(614033,193361,'74298','new_theme','font-weight','normal',0,''),(614034,193361,'74298','new_theme','text-align','center',0,''),(614035,193361,'74298','new_theme','padding-bottom','10',0,''),(614036,193361,'74298','new_theme','font-size','14',0,''),(614037,193361,'74298','new_theme','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',0,''),(614038,193362,'74299','new_theme','text','<p>GIFT CARD</p>',1,''),(614039,193362,'74299','new_theme','font-size','30',0,''),(614040,193362,'74299','new_theme','font-weight','normal',0,''),(614041,193362,'74299','new_theme','border-top-width','1',0,''),(614042,193362,'74299','new_theme','border-top-color','$content-border-3',0,''),(614043,193362,'74299','new_theme','style_class','gift-ico',0,''),(614044,193362,'74299','new_theme','text-align','center',0,''),(614045,193362,'74299','new_theme','padding-top','15',0,''),(614046,193362,'74299','new_theme','text','<p>GIFT CARD</p>',0,''),(614047,193363,'74300','new_theme','text','<p>WHAT TO DO NEXT:</p>',1,''),(614048,193363,'74300','new_theme','font-weight','normal',0,''),(614049,193363,'74300','new_theme','text-align','center',0,''),(614050,193363,'74300','new_theme','padding-top','20',0,''),(614051,193363,'74300','new_theme','padding-bottom','10',0,''),(614052,193363,'74300','new_theme','style_class','question-ico',0,''),(614053,193363,'74300','new_theme','border-top-width','1',0,''),(614054,193363,'74300','new_theme','border-top-color','$content-border-3',0,''),(614055,193363,'74300','new_theme','font-size','18',0,''),(614056,193363,'74300','new_theme','text','<p>WHAT TO DO NEXT:</p>',0,''),(614057,193364,'74301','new_theme','text','<p>HOLBI</p>',1,''),(614058,193364,'74301','new_theme','font-family','$font-1',0,''),(614059,193364,'74301','new_theme','font-size','24',0,''),(614060,193364,'74301','new_theme','font-weight','normal',0,''),(614061,193364,'74301','new_theme','text-align','center',0,''),(614062,193364,'74301','new_theme','padding-top','10',0,''),(614063,193364,'74301','new_theme','padding-bottom','20',0,''),(614064,193364,'74301','new_theme','text','<p>HOLBI</p>',0,''),(614065,193365,'94729','new_theme','block_type','1',0,''),(614066,193365,'94729','new_theme','font-weight','normal',0,''),(614067,193365,'94729','new_theme','style_class','gift-card-view',0,''),(614068,193365,'94729','new_theme','text-align','center',0,''),(614069,193365,'94729','new_theme','padding-bottom','20',0,''),(614070,193365,'94729','new_theme','background-color','$content-bg-2',0,''),(614071,193365,'94729','new_theme','padding-left','20',0,''),(614072,193365,'94729','new_theme','padding-right','20',0,''),(614073,193366,'94730','new_theme','block_type','1',0,''),(614074,193366,'94730','new_theme','font-weight','normal',0,''),(614075,193366,'94730','new_theme','padding-top','10',0,''),(614076,193367,'94731','new_theme','font-size','12',0,''),(614077,193367,'94731','new_theme','font-weight','bold',0,''),(614078,193367,'94731','new_theme','text-align','center',0,''),(614079,193367,'94731','new_theme','style_class','email',0,''),(614080,193368,'94732','new_theme','font-size','12',0,''),(614081,193368,'94732','new_theme','font-weight','bold',0,''),(614082,193368,'94732','new_theme','text-align','center',0,''),(614083,193368,'94732','new_theme','style_class','phone',0,''),(614084,193368,'94732','new_theme','padding-bottom','5',0,''),(614085,193369,'94733','new_theme','text','If you require further assistance please contact us',0,''),(614086,193369,'94733','new_theme','font-size','12',0,''),(614087,193369,'94733','new_theme','text-align','center',0,''),(614088,193369,'94733','new_theme','padding-top','10',0,''),(614089,193370,'94734','new_theme','block_type','4',0,''),(614090,193370,'94734','new_theme','color','$highlight-box-color-2',0,''),(614091,193370,'94734','new_theme','font-size','30',0,''),(614092,193370,'94734','new_theme','font-weight','normal',0,''),(614093,193370,'94734','new_theme','background-color','$highlight-box-bg-2',0,''),(614094,193370,'94734','new_theme','padding-top','5',0,''),(614095,193370,'94734','new_theme','padding-left','10',0,''),(614096,193370,'94734','new_theme','padding-right','10',0,''),(614097,193370,'94734','new_theme','padding-bottom','5',0,''),(614098,193371,'94735','new_theme','text','Your code is:',0,''),(614099,193371,'94735','new_theme','font-size','30',0,''),(614100,193371,'94735','new_theme','color','$highlight-box-color-2',0,''),(614101,193372,'94736','new_theme','color','$highlight-box-color-2',0,''),(614102,193372,'94736','new_theme','font-size','30',0,''),(614103,193373,'94737','new_theme','block_type','1',0,''),(614104,193374,'94738','new_theme','text','<p>PERSONAL MESSAGE</p>',1,''),(614105,193374,'94738','new_theme','font-size','18',0,''),(614106,193374,'94738','new_theme','font-weight','normal',0,''),(614107,193374,'94738','new_theme','text-align','center',0,''),(614108,193374,'94738','new_theme','padding-top','20',0,''),(614109,193374,'94738','new_theme','padding-bottom','10',0,''),(614110,193374,'94738','new_theme','border-top-width','1',0,''),(614111,193374,'94738','new_theme','border-top-color','$content-border-3',0,''),(614112,193374,'94738','new_theme','text','<p>PERSONAL MESSAGE</p>',0,''),(614113,193375,'94739','new_theme','text','HOLBI',0,''),(614114,193375,'94739','new_theme','font-size','24',0,''),(614115,193375,'94739','new_theme','padding-top','20',0,''),(614116,193375,'94739','new_theme','text-align','center',0,''),(614117,193375,'94739','new_theme','padding-bottom','20',0,''),(614118,193376,'94740','new_theme','border-top-color','$content-border-3',0,''),(614119,193376,'94740','new_theme','border-top-width','1',0,''),(614120,193376,'94740','new_theme','padding-top','20',0,''),(614121,193376,'94740','new_theme','font-size','30',0,''),(614122,193376,'94740','new_theme','text-align','center',0,''),(614123,193376,'94740','new_theme','text','GIFT CARD',0,''),(614124,193377,'94741','new_theme','text-align','center',0,''),(614125,193377,'94741','new_theme','font-weight','bold',0,''),(614126,193377,'94741','new_theme','font-size','60',0,''),(614127,193378,'94742','new_theme','font-size','20',0,''),(614128,193378,'94742','new_theme','text-align','center',0,''),(614129,193378,'94742','new_theme','padding-top','20',0,''),(614130,193378,'94742','new_theme','padding-bottom','20',0,''),(614131,193379,'94743','new_theme','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(614132,193379,'94743','new_theme','text-align','center',0,''),(614133,193379,'94743','new_theme','font-size','14',0,''),(614134,193379,'94743','new_theme','padding-bottom','20',0,''),(614135,193380,'94744','new_theme','text','WHAT TO DO NEXT:',0,''),(614136,193380,'94744','new_theme','font-size','18',0,''),(614137,193380,'94744','new_theme','text-align','center',0,''),(614138,193380,'94744','new_theme','padding-top','20',0,''),(614139,193380,'94744','new_theme','padding-bottom','10',0,''),(614140,193380,'94744','new_theme','border-top-width','1',0,''),(614141,193380,'94744','new_theme','border-top-color','$content-border-3',0,''),(614142,193381,'94746','new_theme','block_type','1',0,''),(614143,193381,'94746','new_theme','font-weight','normal',0,''),(614144,193381,'94746','new_theme','style_class','gift-card-view',0,''),(614145,193381,'94746','new_theme','text-align','center',0,''),(614146,193381,'94746','new_theme','padding-bottom','20',0,''),(614147,193381,'94746','new_theme','background-color','$highlight-box-bg-1',0,''),(614148,193381,'94746','new_theme','padding-left','20',0,''),(614149,193381,'94746','new_theme','padding-right','20',0,''),(614150,193381,'94746','new_theme','color','$highlight-box-color-1',0,''),(614151,193382,'94747','new_theme','block_type','1',0,''),(614152,193382,'94747','new_theme','font-weight','normal',0,''),(614153,193382,'94747','new_theme','padding-top','10',0,''),(614154,193383,'94748','new_theme','font-size','12',0,''),(614155,193383,'94748','new_theme','font-weight','bold',0,''),(614156,193383,'94748','new_theme','text-align','center',0,''),(614157,193383,'94748','new_theme','style_class','email',0,''),(614158,193383,'94748','new_theme','color','$highlight-box-color-1',0,''),(614159,193384,'94749','new_theme','font-size','12',0,''),(614160,193384,'94749','new_theme','font-weight','bold',0,''),(614161,193384,'94749','new_theme','text-align','center',0,''),(614162,193384,'94749','new_theme','style_class','phone',0,''),(614163,193384,'94749','new_theme','padding-bottom','5',0,''),(614164,193384,'94749','new_theme','color','$highlight-box-color-1',0,''),(614165,193385,'94750','new_theme','text','If you require further assistance please contact us',0,''),(614166,193385,'94750','new_theme','font-size','12',0,''),(614167,193385,'94750','new_theme','color','$highlight-box-color-1',0,''),(614168,193385,'94750','new_theme','text-align','center',0,''),(614169,193385,'94750','new_theme','padding-top','10',0,''),(614170,193386,'94751','new_theme','block_type','4',0,''),(614171,193386,'94751','new_theme','color','$highlight-box-color-2',0,''),(614172,193386,'94751','new_theme','font-size','30',0,''),(614173,193386,'94751','new_theme','font-weight','normal',0,''),(614174,193386,'94751','new_theme','background-color','$highlight-box-bg-2',0,''),(614175,193386,'94751','new_theme','padding-top','5',0,''),(614176,193386,'94751','new_theme','padding-left','10',0,''),(614177,193386,'94751','new_theme','padding-right','10',0,''),(614178,193386,'94751','new_theme','padding-bottom','5',0,''),(614179,193387,'94752','new_theme','text','Your code is:',0,''),(614180,193387,'94752','new_theme','font-size','30',0,''),(614181,193387,'94752','new_theme','color','$highlight-box-color-2',0,''),(614182,193388,'94753','new_theme','color','$highlight-box-color-2',0,''),(614183,193388,'94753','new_theme','font-size','30',0,''),(614184,193389,'94754','new_theme','block_type','1',0,''),(614185,193390,'94755','new_theme','text','<p>PERSONAL MESSAGE</p>',1,''),(614186,193390,'94755','new_theme','font-size','18',0,''),(614187,193390,'94755','new_theme','font-weight','normal',0,''),(614188,193390,'94755','new_theme','text-align','center',0,''),(614189,193390,'94755','new_theme','padding-top','20',0,''),(614190,193390,'94755','new_theme','padding-bottom','10',0,''),(614191,193390,'94755','new_theme','border-top-width','1',0,''),(614192,193390,'94755','new_theme','border-top-color','$content-border-3',0,''),(614193,193390,'94755','new_theme','text','<p>PERSONAL MESSAGE</p>',0,''),(614194,193391,'94757','new_theme','border-top-color','$content-border-3',0,''),(614195,193391,'94757','new_theme','border-top-width','1',0,''),(614196,193391,'94757','new_theme','padding-top','20',0,''),(614197,193391,'94757','new_theme','font-size','30',0,''),(614198,193391,'94757','new_theme','text-align','center',0,''),(614199,193391,'94757','new_theme','color','$highlight-box-color-1',0,''),(614200,193391,'94757','new_theme','text','GIFT CARD',0,''),(614201,193392,'94758','new_theme','text-align','center',0,''),(614202,193392,'94758','new_theme','font-weight','bold',0,''),(614203,193392,'94758','new_theme','font-size','60',0,''),(614204,193392,'94758','new_theme','color','$highlight-box-color-1',0,''),(614205,193393,'94759','new_theme','font-size','20',0,''),(614206,193393,'94759','new_theme','text-align','center',0,''),(614207,193393,'94759','new_theme','color','$highlight-box-color-1',0,''),(614208,193393,'94759','new_theme','padding-top','20',0,''),(614209,193393,'94759','new_theme','padding-bottom','20',0,''),(614210,193394,'94760','new_theme','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(614211,193394,'94760','new_theme','text-align','center',0,''),(614212,193394,'94760','new_theme','color','$highlight-box-color-1',0,''),(614213,193394,'94760','new_theme','font-size','14',0,''),(614214,193394,'94760','new_theme','padding-bottom','20',0,''),(614215,193395,'94761','new_theme','text','WHAT TO DO NEXT:',0,''),(614216,193395,'94761','new_theme','font-size','18',0,''),(614217,193395,'94761','new_theme','text-align','center',0,''),(614218,193395,'94761','new_theme','padding-top','20',0,''),(614219,193395,'94761','new_theme','padding-bottom','10',0,''),(614220,193395,'94761','new_theme','border-top-width','1',0,''),(614221,193395,'94761','new_theme','border-top-color','$content-border-3',0,''),(614222,193396,'1707902674.2595','new_theme','logo_from','theme',0,''),(614223,193396,'1707902674.2595','new_theme','text-align','center',0,''),(614224,193396,'1707902674.2595','new_theme','padding-top','20',0,''),(614225,193398,'74302','new_theme','block_type','1',0,''),(614226,193400,'74304','new_theme','text','<h1>##GIFT_CERTIFICATE##</h1>\n<p>##ENTRY_GIFT_CERTIFICATE##</p>',0,''),(614227,193400,'74304','new_theme','text-align','center',0,''),(614228,193401,'74305','new_theme','block_type','1',0,''),(614229,193401,'74305','new_theme','font-weight','normal',0,''),(614230,193401,'74305','new_theme','style_class','gift-card-view',0,''),(614231,193401,'74305','new_theme','text-align','center',0,''),(614232,193401,'74305','new_theme','padding-bottom','20',0,''),(614233,193401,'74305','new_theme','background-color','$highlight-box-bg-3',0,''),(614234,193401,'74305','new_theme','padding-left','20',0,''),(614235,193401,'74305','new_theme','padding-right','20',0,''),(614236,193401,'74305','new_theme','color','$highlight-box-color-3',0,''),(614237,193402,'74306','new_theme','block_type','4',0,''),(614238,193402,'74306','new_theme','color','$highlight-box-color-2',0,''),(614239,193402,'74306','new_theme','font-size','30',0,''),(614240,193402,'74306','new_theme','font-weight','normal',0,''),(614241,193402,'74306','new_theme','background-color','$highlight-box-bg-2',0,''),(614242,193402,'74306','new_theme','padding-top','5',0,''),(614243,193402,'74306','new_theme','padding-left','10',0,''),(614244,193402,'74306','new_theme','padding-right','10',0,''),(614245,193402,'74306','new_theme','padding-bottom','5',0,''),(614246,193403,'74307','new_theme','text','<p>Your code is:</p>',1,''),(614247,193403,'74307','new_theme','font-weight','normal',0,''),(614248,193403,'74307','new_theme','text','<p>Your code is:</p>',0,''),(614249,193405,'74309','new_theme','text','<p>WHAT TO DO NEXT:</p>',1,''),(614250,193405,'74309','new_theme','font-weight','normal',0,''),(614251,193405,'74309','new_theme','text-align','center',0,''),(614252,193405,'74309','new_theme','padding-top','20',0,''),(614253,193405,'74309','new_theme','padding-bottom','10',0,''),(614254,193405,'74309','new_theme','style_class','question-ico',0,''),(614255,193405,'74309','new_theme','border-top-width','1',0,''),(614256,193405,'74309','new_theme','border-top-color','$content-border-3',0,''),(614257,193405,'74309','new_theme','font-size','18',0,''),(614258,193405,'74309','new_theme','text','<p>WHAT TO DO NEXT:</p>',0,''),(614259,193406,'74310','new_theme','text','<p>osCommerce</p>\n',1,''),(614260,193406,'74310','new_theme','font-family','$font-1',0,''),(614261,193406,'74310','new_theme','font-size','24',0,''),(614262,193406,'74310','new_theme','font-weight','normal',0,''),(614263,193406,'74310','new_theme','text-align','center',0,''),(614264,193406,'74310','new_theme','padding-top','10',0,''),(614265,193406,'74310','new_theme','padding-bottom','20',0,''),(614266,193406,'74310','new_theme','text','<p>osCommerce</p>\n',0,''),(614267,193407,'74311','new_theme','block_type','1',0,''),(614268,193407,'74311','new_theme','font-weight','normal',0,''),(614269,193407,'74311','new_theme','padding-top','10',0,''),(614270,193408,'74312','new_theme','text','<p>If you require further assistance please contact us</p>',1,''),(614271,193408,'74312','new_theme','font-weight','normal',0,''),(614272,193408,'74312','new_theme','text-align','center',0,''),(614273,193408,'74312','new_theme','font-size','12',0,''),(614274,193408,'74312','new_theme','padding-top','10',0,''),(614275,193408,'74312','new_theme','padding-bottom','5',0,''),(614276,193408,'74312','new_theme','border-top-width','1',0,''),(614277,193408,'74312','new_theme','border-top-color','$content-border-3',0,''),(614278,193408,'74312','new_theme','text','<p>If you require further assistance please contact us</p>',0,''),(614279,193409,'74313','new_theme','font-size','12',0,''),(614280,193409,'74313','new_theme','font-weight','bold',0,''),(614281,193409,'74313','new_theme','text-align','center',0,''),(614282,193409,'74313','new_theme','style_class','email',0,''),(614283,193410,'74314','new_theme','font-size','12',0,''),(614284,193410,'74314','new_theme','font-weight','bold',0,''),(614285,193410,'74314','new_theme','text-align','center',0,''),(614286,193410,'74314','new_theme','style_class','phone',0,''),(614287,193410,'74314','new_theme','padding-bottom','5',0,''),(614288,193411,'74315','new_theme','font-weight','normal',0,''),(614289,193411,'74315','new_theme','text-align','center',0,''),(614290,193411,'74315','new_theme','padding-bottom','20',0,''),(614291,193412,'74316','new_theme','text','<p>GIFT CARD</p>',1,''),(614292,193412,'74316','new_theme','font-size','30',0,''),(614293,193412,'74316','new_theme','font-weight','normal',0,''),(614294,193412,'74316','new_theme','border-top-width','1',0,''),(614295,193412,'74316','new_theme','border-top-color','$content-border-3',0,''),(614296,193412,'74316','new_theme','style_class','gift-ico',0,''),(614297,193412,'74316','new_theme','text-align','center',0,''),(614298,193412,'74316','new_theme','padding-top','15',0,''),(614299,193412,'74316','new_theme','text','<p>GIFT CARD</p>',0,''),(614300,193413,'74317','new_theme','text','<p>PERSONAL MESSAGE</p>',1,''),(614301,193413,'74317','new_theme','font-size','18',0,''),(614302,193413,'74317','new_theme','font-weight','normal',0,''),(614303,193413,'74317','new_theme','text-align','center',0,''),(614304,193413,'74317','new_theme','padding-top','20',0,''),(614305,193413,'74317','new_theme','padding-bottom','10',0,''),(614306,193413,'74317','new_theme','border-top-width','1',0,''),(614307,193413,'74317','new_theme','border-top-color','$content-border-3',0,''),(614308,193413,'74317','new_theme','text','<p>PERSONAL MESSAGE</p>',0,''),(614309,193414,'74318','new_theme','font-size','60',0,''),(614310,193414,'74318','new_theme','font-weight','bold',0,''),(614311,193414,'74318','new_theme','text-align','center',0,''),(614312,193414,'74318','new_theme','line-height','100',0,''),(614313,193414,'74318','new_theme','padding-bottom','20',0,''),(614314,193414,'74318','new_theme','line_height_measure','px',0,''),(614315,193415,'74319','new_theme','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',1,''),(614316,193415,'74319','new_theme','font-weight','normal',0,''),(614317,193415,'74319','new_theme','text-align','center',0,''),(614318,193415,'74319','new_theme','padding-bottom','10',0,''),(614319,193415,'74319','new_theme','font-size','14',0,''),(614320,193415,'74319','new_theme','text','<p>To activate, simply add this gift card code to your shopping cart at oscommerce.com</p>',0,''),(614321,193416,'94763','new_theme','block_type','1',0,''),(614322,193416,'94763','new_theme','font-weight','normal',0,''),(614323,193416,'94763','new_theme','style_class','gift-card-view',0,''),(614324,193416,'94763','new_theme','text-align','center',0,''),(614325,193416,'94763','new_theme','padding-bottom','20',0,''),(614326,193416,'94763','new_theme','background-color','$highlight-box-bg-3',0,''),(614327,193416,'94763','new_theme','padding-left','20',0,''),(614328,193416,'94763','new_theme','padding-right','20',0,''),(614329,193416,'94763','new_theme','color','$highlight-box-color-3',0,''),(614330,193417,'94764','new_theme','block_type','1',0,''),(614331,193417,'94764','new_theme','font-weight','normal',0,''),(614332,193417,'94764','new_theme','padding-top','10',0,''),(614333,193418,'94765','new_theme','font-size','12',0,''),(614334,193418,'94765','new_theme','font-weight','bold',0,''),(614335,193418,'94765','new_theme','text-align','center',0,''),(614336,193418,'94765','new_theme','style_class','email',0,''),(614337,193419,'94766','new_theme','font-size','12',0,''),(614338,193419,'94766','new_theme','font-weight','bold',0,''),(614339,193419,'94766','new_theme','text-align','center',0,''),(614340,193419,'94766','new_theme','style_class','phone',0,''),(614341,193419,'94766','new_theme','padding-bottom','5',0,''),(614342,193420,'94767','new_theme','text','If you require further assistance please contact us',0,''),(614343,193420,'94767','new_theme','font-size','12',0,''),(614344,193420,'94767','new_theme','text-align','center',0,''),(614345,193420,'94767','new_theme','padding-top','10',0,''),(614346,193421,'94768','new_theme','block_type','4',0,''),(614347,193421,'94768','new_theme','color','$highlight-box-color-2',0,''),(614348,193421,'94768','new_theme','font-size','30',0,''),(614349,193421,'94768','new_theme','font-weight','normal',0,''),(614350,193421,'94768','new_theme','background-color','$highlight-box-bg-2',0,''),(614351,193421,'94768','new_theme','padding-top','5',0,''),(614352,193421,'94768','new_theme','padding-left','10',0,''),(614353,193421,'94768','new_theme','padding-right','10',0,''),(614354,193421,'94768','new_theme','padding-bottom','5',0,''),(614355,193422,'94769','new_theme','text','Your code is:',0,''),(614356,193422,'94769','new_theme','font-size','30',0,''),(614357,193422,'94769','new_theme','color','$highlight-box-color-2',0,''),(614358,193423,'94770','new_theme','color','$highlight-box-color-2',0,''),(614359,193423,'94770','new_theme','font-size','30',0,''),(614360,193424,'94771','new_theme','block_type','1',0,''),(614361,193425,'94772','new_theme','text','<p>PERSONAL MESSAGE</p>',1,''),(614362,193425,'94772','new_theme','font-size','18',0,''),(614363,193425,'94772','new_theme','font-weight','normal',0,''),(614364,193425,'94772','new_theme','text-align','center',0,''),(614365,193425,'94772','new_theme','padding-top','20',0,''),(614366,193425,'94772','new_theme','padding-bottom','10',0,''),(614367,193425,'94772','new_theme','border-top-width','1',0,''),(614368,193425,'94772','new_theme','border-top-color','$content-border-3',0,''),(614369,193425,'94772','new_theme','text','<p>PERSONAL MESSAGE</p>',0,''),(614370,193426,'94773','new_theme','text','HOLBI',0,''),(614371,193426,'94773','new_theme','color','$highlight-box-color-3',0,''),(614372,193426,'94773','new_theme','font-size','24',0,''),(614373,193426,'94773','new_theme','padding-top','20',0,''),(614374,193426,'94773','new_theme','text-align','center',0,''),(614375,193426,'94773','new_theme','padding-bottom','20',0,''),(614376,193427,'94774','new_theme','border-top-color','$content-border-3',0,''),(614377,193427,'94774','new_theme','border-top-width','1',0,''),(614378,193427,'94774','new_theme','padding-top','20',0,''),(614379,193427,'94774','new_theme','font-size','30',0,''),(614380,193427,'94774','new_theme','text-align','center',0,''),(614381,193427,'94774','new_theme','color','$highlight-box-color-3',0,''),(614382,193427,'94774','new_theme','text','GIFT CARD',0,''),(614383,193428,'94775','new_theme','text-align','center',0,''),(614384,193428,'94775','new_theme','font-weight','bold',0,''),(614385,193428,'94775','new_theme','font-size','60',0,''),(614386,193428,'94775','new_theme','color','$highlight-box-color-3',0,''),(614387,193429,'94776','new_theme','font-size','20',0,''),(614388,193429,'94776','new_theme','text-align','center',0,''),(614389,193429,'94776','new_theme','padding-top','20',0,''),(614390,193429,'94776','new_theme','padding-bottom','20',0,''),(614391,193430,'94777','new_theme','text','To activate, simply add this gift card code to your shopping cart at trueloaded.co.uk',0,''),(614392,193430,'94777','new_theme','text-align','center',0,''),(614393,193430,'94777','new_theme','font-size','14',0,''),(614394,193430,'94777','new_theme','padding-bottom','20',0,''),(614395,193431,'94778','new_theme','text','WHAT TO DO NEXT:',0,''),(614396,193431,'94778','new_theme','font-size','18',0,''),(614397,193431,'94778','new_theme','text-align','center',0,''),(614398,193431,'94778','new_theme','padding-top','20',0,''),(614399,193431,'94778','new_theme','padding-bottom','10',0,''),(614400,193431,'94778','new_theme','border-top-width','1',0,''),(614401,193431,'94778','new_theme','border-top-color','$content-border-3',0,''),(614402,193432,'1713770938.449798','new_theme','from_file','header_1.zip',0,''),(614403,193433,'1713770938.464587','new_theme','block_type','1',0,''),(614404,193433,'1713770938.464587','new_theme','border-bottom-width','1',0,''),(614405,193433,'1713770938.464587','new_theme','border-bottom-color','$header-border-1',0,''),(614406,193433,'1713770938.464587','new_theme','font-weight','normal',0,''),(614407,193433,'1713770938.464587','new_theme','visibility_checkout','1',0,''),(614408,193433,'1713770938.464587','new_theme','background-color','$header-bg-1',0,''),(614409,193433,'1713770938.464587','new_theme','color','$header-color-1',0,''),(614410,193433,'1713770938.464587','new_theme','from_file','header_1.zip',0,''),(614411,193434,'1713770938.467593','new_theme','block_type','5',0,''),(614412,193434,'1713770938.467593','new_theme','font-weight','400',0,''),(614413,193434,'1713770938.467593','new_theme','schema','2-2',0,''),(614414,193434,'1713770938.467593','new_theme','schema','5-2',0,'8451'),(614415,193434,'1713770938.467593','new_theme','schema','5-1',0,'8472'),(614416,193435,'1713770938.470248','new_theme','class','menu-horizontal',0,''),(614417,193435,'1713770938.470248','new_theme','box_align','1',0,''),(614418,193435,'1713770938.470248','new_theme','font-weight','400',0,''),(614419,193435,'1713770938.470248','new_theme','border-top-width','1',0,'8451'),(614420,193435,'1713770938.470248','new_theme','border-top-color','$content-border-1',0,'8451'),(614421,193435,'1713770938.470248','new_theme','display','none',0,'8451'),(614422,193436,'1713770938.51635','new_theme','block_type','1',0,''),(614423,193437,'1713770938.51828','new_theme','font-weight','400',0,''),(614424,193437,'1713770938.51828','new_theme','box_align','3',0,''),(614425,193437,'1713770938.51828','new_theme','show_products','dropdown',0,''),(614426,193437,'1713770938.51828','new_theme','only_icon','on',0,''),(614427,193438,'1713770938.573998','new_theme','font-weight','normal',0,''),(614428,193438,'1713770938.573998','new_theme','box_align','3',0,''),(614429,193438,'1713770938.573998','new_theme','border-left-width','1',0,''),(614430,193438,'1713770938.573998','new_theme','border-left-color','$header-border-1',0,''),(614431,193438,'1713770938.573998','new_theme','only_icon','on',0,''),(614432,193439,'1713770938.61982','new_theme','box_align','3',0,''),(614433,193439,'1713770938.61982','new_theme','font-weight','normal',0,''),(614434,193439,'1713770938.61982','new_theme','padding-top','0',0,'8451'),(614435,193439,'1713770938.61982','new_theme','padding-right','0',0,'8451'),(614436,193439,'1713770938.61982','new_theme','padding-bottom','0',0,'8451'),(614437,193439,'1713770938.61982','new_theme','padding-left','0',0,'8451'),(614438,193439,'1713770938.61982','new_theme','show_symbol_left','1',0,''),(614439,193439,'1713770938.61982','new_theme','show_symbol_right','1',0,''),(614440,193440,'1713770938.663457','new_theme','box_align','3',0,''),(614441,193440,'1713770938.663457','new_theme','font-weight','normal',0,''),(614442,193440,'1713770938.663457','new_theme','border-left-width','1',0,''),(614443,193440,'1713770938.663457','new_theme','border-left-color','$header-border-1',0,''),(614444,193440,'1713770938.663457','new_theme','padding-top','0',0,'8451'),(614445,193440,'1713770938.663457','new_theme','padding-right','0',0,'8451'),(614446,193440,'1713770938.663457','new_theme','padding-bottom','0',0,'8451'),(614447,193440,'1713770938.663457','new_theme','padding-left','0',0,'8451'),(614448,193440,'1713770938.663457','new_theme','show_title','1',0,''),(614449,193441,'1713770938.697915','new_theme','block_type','1',0,''),(614450,193441,'1713770938.697915','new_theme','padding-top','20',0,''),(614451,193441,'1713770938.697915','new_theme','padding-bottom','20',0,''),(614452,193441,'1713770938.697915','new_theme','style_class','header-content',0,''),(614453,193441,'1713770938.697915','new_theme','color','$header-color-1',0,''),(614454,193441,'1713770938.697915','new_theme','background-color','$header-bg-1',0,''),(614455,193441,'1713770938.697915','new_theme','from_file','header_1.zip',0,''),(614456,193441,'1713770938.697915','new_theme','padding-top','12',0,'8444'),(614457,193441,'1713770938.697915','new_theme','padding-bottom','12',0,'8444'),(614458,193442,'1713770938.706821','new_theme','font-weight','400',0,''),(614459,193442,'1713770938.706821','new_theme','box_align','1',0,''),(614460,193442,'1713770938.706821','new_theme','text-align','center',0,'8472'),(614461,193442,'1713770938.706821','new_theme','width','100',0,'8472'),(614462,193442,'1713770938.706821','new_theme','width_measure','%',0,'8472'),(614463,193442,'1713770938.706821','new_theme','logo_from','theme',0,''),(614464,193442,'1713770938.706821','new_theme','padding-right','20',0,''),(614465,193443,'1713770938.709156','new_theme','visibility_checkout','1',0,''),(614466,193443,'1713770938.709156','new_theme','search_history','1',0,''),(614467,193443,'1713770938.709156','new_theme','history_items','5',0,''),(614468,193443,'1713770938.709156','new_theme','margin-left','20',0,''),(614469,193444,'1713770938.773998','new_theme','text','<p class=\"customer-service\">Customer service <b>08000112569</b></p>',1,''),(614470,193444,'1713770938.773998','new_theme','float','right',0,''),(614471,193444,'1713770938.773998','new_theme','display_none','1',0,'8472'),(614472,193444,'1713770938.773998','new_theme','text','<p class=\"customer-service\">Customer service <b>08000112569</b></p>',0,''),(614473,193444,'1713770938.773998','new_theme','display','none',0,'8451'),(614474,193444,'1713770938.773998','new_theme','margin-left','20',0,''),(614475,193445,'1713770938.811953','new_theme','block_type','1',0,''),(614476,193445,'1713770938.811953','new_theme','font-weight','400',0,''),(614477,193445,'1713770938.811953','new_theme','background-color','$header-menu-bg-1',0,''),(614478,193445,'1713770938.811953','new_theme','visibility_checkout','1',0,''),(614479,193445,'1713770938.811953','new_theme','color','$header-menu-color-1',0,''),(614480,193445,'1713770938.811953','new_theme','from_file','header_1.zip',0,''),(614481,193445,'1713770938.811953','new_theme','style_class','header-menu-holder',0,''),(614482,193446,'1713770938.81834','new_theme','class','menu-style-1',0,''),(614483,193446,'1713770938.81834','new_theme','box_align','4',0,''),(614484,193446,'1713770938.81834','new_theme','font-weight','400',0,''),(614485,193446,'1713770938.81834','new_theme','hide_menu','on',0,''),(614486,193446,'1713770938.81834','new_theme','color','$header-menu-color-1',0,''),(614487,193446,'1713770938.81834','new_theme','hide_menu','1',0,'8451'),(614488,193446,'1713770938.81834','new_theme','show_new','1',0,''),(614489,193446,'1713770938.81834','new_theme','style_class','header-menu',0,''),(614490,193446,'1713770938.81834','new_theme','type','builder',0,''),(614491,193446,'1713770938.81834','new_theme','position','horizontal_center',0,'8517'),(614492,193446,'1713770938.81834','new_theme','style','1',0,'8517'),(614493,193446,'1713770938.81834','new_theme','lev2_vis','over',0,'8517'),(614494,193446,'1713770938.81834','new_theme','lev2_display','down',0,'8517'),(614495,193446,'1713770938.81834','new_theme','lev3_vis','over',0,'8517'),(614496,193446,'1713770938.81834','new_theme','lev4_vis','over',0,'8517'),(614497,193446,'1713770938.81834','new_theme','lev5_vis','over',0,'8517'),(614498,193446,'1713770938.81834','new_theme','lev6_vis','over',0,'8517'),(614499,193446,'1713770938.81834','new_theme','lev3_display','lra',0,'8517'),(614500,193446,'1713770938.81834','new_theme','lev4_display','lra',0,'8517'),(614501,193446,'1713770938.81834','new_theme','lev5_display','lra',0,'8517'),(614502,193446,'1713770938.81834','new_theme','lev6_display','lra',0,'8517'),(614503,193446,'1713770938.81834','new_theme','style','2',0,'8451'),(614504,193446,'1713770938.81834','new_theme','burger_icon','1',0,'8451'),(614505,193446,'1713770938.81834','new_theme','open_from','top',0,'8451'),(614506,193446,'1713770938.81834','new_theme','lev2_vis','click',0,'8451'),(614507,193446,'1713770938.81834','new_theme','lev3_vis','click',0,'8451'),(614508,193446,'1713770938.81834','new_theme','lev4_vis','click',0,'8451'),(614509,193446,'1713770938.81834','new_theme','lev5_vis','click',0,'8451'),(614510,193446,'1713770938.81834','new_theme','lev6_vis','click',0,'8451'),(614511,193446,'1713770938.81834','new_theme','from_file','menu_1.zip',0,''),(614512,193447,'74346','new_theme','block_type','1',0,''),(614513,193452,'74351','new_theme','width','680',0,''),(614514,193452,'74351','new_theme','font-weight','normal',0,''),(614515,193452,'74351','new_theme','font-size','12',0,''),(614516,193452,'74351','new_theme','padding-top','20',0,''),(614517,193452,'74351','new_theme','padding-bottom','20',0,''),(614518,193452,'74351','new_theme','color','$content-color-1',0,''),(614519,193453,'74352','new_theme','block_type','4',0,''),(614520,193453,'74352','new_theme','font-weight','normal',0,''),(614521,193453,'74352','new_theme','border-top-width','1',0,''),(614522,193453,'74352','new_theme','border-top-color','$content-border-1',0,''),(614523,193453,'74352','new_theme','border-left-width','1',0,''),(614524,193453,'74352','new_theme','border-left-color','$content-border-1',0,''),(614525,193453,'74352','new_theme','border-right-width','1',0,''),(614526,193453,'74352','new_theme','border-right-color','$content-border-1',0,''),(614527,193453,'74352','new_theme','border-bottom-width','1',0,''),(614528,193453,'74352','new_theme','border-bottom-color','$content-border-1',0,''),(614529,193454,'74353','new_theme','block_type','2',0,''),(614530,193454,'74353','new_theme','font-weight','normal',0,''),(614531,193454,'74353','new_theme','border-top-width','1',0,''),(614532,193454,'74353','new_theme','border-top-color','$content-border-1',0,''),(614533,193454,'74353','new_theme','border-right-width','1',0,''),(614534,193454,'74353','new_theme','border-right-color','$content-border-1',0,''),(614535,193455,'74354','new_theme','block_type','1',0,''),(614536,193455,'74354','new_theme','font-weight','normal',0,''),(614537,193455,'74354','new_theme','padding-top','10',0,''),(614538,193455,'74354','new_theme','padding-left','10',0,''),(614539,193455,'74354','new_theme','padding-right','10',0,''),(614540,193455,'74354','new_theme','padding-bottom','10',0,''),(614541,193455,'74354','new_theme','border-right-width','1',0,''),(614542,193455,'74354','new_theme','border-right-color','$content-border-1',0,''),(614543,193457,'74356','new_theme','text','<p>Shipping via</p>',1,''),(614544,193457,'74356','new_theme','font-weight','bold',0,''),(614545,193457,'74356','new_theme','font-size','14',0,''),(614546,193457,'74356','new_theme','text','<p>Shipping via</p>',0,''),(614547,193458,'74357','new_theme','block_type','1',0,''),(614548,193458,'74357','new_theme','font-weight','normal',0,''),(614549,193458,'74357','new_theme','padding-top','10',0,''),(614550,193458,'74357','new_theme','padding-left','10',0,''),(614551,193458,'74357','new_theme','padding-right','10',0,''),(614552,193458,'74357','new_theme','padding-bottom','10',0,''),(614553,193459,'74358','new_theme','text','<p>Shipping service</p>',1,''),(614554,193459,'74358','new_theme','font-weight','bold',0,''),(614555,193459,'74358','new_theme','font-size','14',0,''),(614556,193459,'74358','new_theme','text','<p>Shipping service</p>',0,''),(614557,193461,'74360','new_theme','block_type','2',0,''),(614558,193461,'74360','new_theme','font-weight','normal',0,''),(614559,193461,'74360','new_theme','border-right-width','1',0,''),(614560,193461,'74360','new_theme','border-right-color','$content-border-1',0,''),(614561,193462,'74361','new_theme','block_type','1',0,''),(614562,193462,'74361','new_theme','font-weight','400',0,''),(614563,193462,'74361','new_theme','background-color','$content-bg-2',0,''),(614564,193462,'74361','new_theme','padding-top','10',0,''),(614565,193462,'74361','new_theme','padding-left','10',0,''),(614566,193462,'74361','new_theme','padding-right','10',0,''),(614567,193462,'74361','new_theme','padding-bottom','30',0,''),(614568,193463,'74362','new_theme','text','<p>INVOICE ADDRESS:</p>',1,''),(614569,193463,'74362','new_theme','font-size','14',0,''),(614570,193463,'74362','new_theme','font-weight','bold',0,''),(614571,193463,'74362','new_theme','text','<p>INVOICE ADDRESS:</p>',0,''),(614572,193464,'74363','new_theme','font-size','12',0,''),(614573,193465,'74364','new_theme','block_type','1',0,''),(614574,193465,'74364','new_theme','font-weight','normal',0,''),(614575,193465,'74364','new_theme','padding-top','10',0,''),(614576,193465,'74364','new_theme','padding-left','10',0,''),(614577,193465,'74364','new_theme','padding-right','10',0,''),(614578,193465,'74364','new_theme','padding-bottom','10',0,''),(614579,193466,'74365','new_theme','text','<p>E-MAIL ADDRESS:</p>',1,''),(614580,193466,'74365','new_theme','font-weight','bold',0,''),(614581,193466,'74365','new_theme','font-size','14',0,''),(614582,193466,'74365','new_theme','padding-top','10',0,''),(614583,193466,'74365','new_theme','text','<p>E-MAIL ADDRESS:</p>',0,''),(614584,193467,'74366','new_theme','font-weight','normal',0,''),(614585,193468,'74367','new_theme','font-weight','normal',0,''),(614586,193469,'74368','new_theme','text','<p>CUSTOMER:</p>',1,''),(614587,193469,'74368','new_theme','font-size','13',0,''),(614588,193469,'74368','new_theme','font-weight','bold',0,''),(614589,193469,'74368','new_theme','text','<p>CUSTOMER:</p>',0,''),(614590,193470,'74369','new_theme','text','<p>PHONE NUMBER:</p>',1,''),(614591,193470,'74369','new_theme','font-size','14',0,''),(614592,193470,'74369','new_theme','font-weight','bold',0,''),(614593,193470,'74369','new_theme','padding-top','10',0,''),(614594,193470,'74369','new_theme','text','<p>PHONE NUMBER:</p>',0,''),(614595,193472,'74371','new_theme','font-weight','normal',0,''),(614596,193472,'74371','new_theme','text-align','center',0,''),(614597,193472,'74371','new_theme','padding-bottom','20',0,''),(614598,193473,'74372','new_theme','text','<p>Payment Method:</p>',1,''),(614599,193473,'74372','new_theme','font-weight','bold',0,''),(614600,193473,'74372','new_theme','text-align','center',0,''),(614601,193473,'74372','new_theme','text','<p>Payment Method:</p>',0,''),(614602,193474,'74373','new_theme','text','<p>Payment date:</p>',1,''),(614603,193474,'74373','new_theme','font-weight','bold',0,''),(614604,193474,'74373','new_theme','text-align','center',0,''),(614605,193474,'74373','new_theme','font-size','12',0,''),(614606,193474,'74373','new_theme','text','<p>Payment date:</p>',0,''),(614607,193475,'74374','new_theme','font-size','14',0,''),(614608,193475,'74374','new_theme','font-weight','bold',0,''),(614609,193475,'74374','new_theme','text-align','center',0,''),(614610,193475,'74374','new_theme','padding-bottom','10',0,''),(614611,193475,'74374','new_theme','padding-top','10',0,''),(614612,193476,'74375','new_theme','font-weight','normal',0,''),(614613,193476,'74375','new_theme','text-align','center',0,''),(614614,193476,'74375','new_theme','padding-bottom','10',0,''),(614615,193477,'74376','new_theme','font-weight','normal',0,''),(614616,193477,'74376','new_theme','text-align','center',0,''),(614617,193478,'74377','new_theme','block_type','3',0,''),(614618,193478,'74377','new_theme','font-weight','normal',0,''),(614619,193478,'74377','new_theme','padding-top','20',0,''),(614620,193479,'74378','new_theme','font-size','12',0,''),(614621,193480,'74379','new_theme','text','<p>If undelivered please return to:</p>',1,''),(614622,193480,'74379','new_theme','font-size','12',0,''),(614623,193480,'74379','new_theme','font-weight','bold',0,''),(614624,193480,'74379','new_theme','text','<p>If undelivered please return to:</p>',0,''),(614625,193481,'74380','new_theme','text','<p>Thank you for your order</p>',1,''),(614626,193481,'74380','new_theme','color','$color-8',0,''),(614627,193481,'74380','new_theme','font-size','13',0,''),(614628,193481,'74380','new_theme','font-weight','bold',0,''),(614629,193481,'74380','new_theme','padding-top','5',0,''),(614630,193481,'74380','new_theme','text-align','center',0,''),(614631,193481,'74380','new_theme','text','<p>Thank you for your order</p>',0,''),(614632,193482,'74381','new_theme','font-weight','400',0,''),(614633,193482,'74381','new_theme','text-align','center',0,''),(614634,193482,'74381','new_theme','padding-top','0',0,''),(614635,193482,'74381','new_theme','padding-left','20',0,''),(614636,193482,'74381','new_theme','padding-right','20',0,''),(614637,193482,'74381','new_theme','logo_from','theme',0,''),(614638,193483,'74382','new_theme','block_type','6',0,''),(614639,193483,'74382','new_theme','font-weight','normal',0,''),(614640,193483,'74382','new_theme','font-size','16',0,''),(614641,193484,'74383','new_theme','text','<p>Email:</p>',1,''),(614642,193484,'74383','new_theme','font-weight','normal',0,''),(614643,193484,'74383','new_theme','text-align','right',0,''),(614644,193484,'74383','new_theme','font-size','12',0,''),(614645,193484,'74383','new_theme','text','<p>Email:</p>',0,''),(614646,193485,'74384','new_theme','font-weight','normal',0,''),(614647,193485,'74384','new_theme','text-align','right',0,''),(614648,193485,'74384','new_theme','font-size','12',0,''),(614649,193486,'74385','new_theme','block_type','6',0,''),(614650,193486,'74385','new_theme','font-weight','normal',0,''),(614651,193486,'74385','new_theme','font-size','16',0,''),(614652,193487,'74386','new_theme','text','<p>Phone:</p>',1,''),(614653,193487,'74386','new_theme','font-weight','normal',0,''),(614654,193487,'74386','new_theme','text-align','right',0,''),(614655,193487,'74386','new_theme','font-size','12',0,''),(614656,193487,'74386','new_theme','text','<p>Phone:</p>',0,''),(614657,193488,'74387','new_theme','font-weight','normal',0,''),(614658,193488,'74387','new_theme','text-align','right',0,''),(614659,193488,'74387','new_theme','font-size','12',0,''),(614660,193489,'74388','new_theme','text','<p>If something has gone wrong please contact us at:</p>',1,''),(614661,193489,'74388','new_theme','font-size','12',0,''),(614662,193489,'74388','new_theme','font-weight','bold',0,''),(614663,193489,'74388','new_theme','text-align','right',0,''),(614664,193489,'74388','new_theme','text','<p>If something has gone wrong please contact us at:</p>',0,''),(614665,193490,'74389','new_theme','font-weight','400',0,''),(614666,193490,'74389','new_theme','padding-top','20',0,''),(614667,193490,'74389','new_theme','padding-bottom','0',0,''),(614668,193490,'74389','new_theme','font-size','12',0,''),(614669,193491,'74390','new_theme','block_type','5',0,''),(614670,193491,'74390','new_theme','font-weight','normal',0,''),(614671,193491,'74390','new_theme','border-bottom-width','1',0,''),(614672,193491,'74390','new_theme','border-bottom-color','$content-border-1',0,''),(614673,193491,'74390','new_theme','border-top-width','1',0,''),(614674,193491,'74390','new_theme','border-top-color','$content-border-1',0,''),(614675,193491,'74390','new_theme','border-left-color','$content-border-1',0,''),(614676,193491,'74390','new_theme','border-left-width','1',0,''),(614677,193492,'74391','new_theme','block_type','1',0,''),(614678,193492,'74391','new_theme','font-weight','normal',0,''),(614679,193492,'74391','new_theme','padding-top','10',0,''),(614680,193492,'74391','new_theme','padding-left','10',0,''),(614681,193492,'74391','new_theme','padding-right','10',0,''),(614682,193493,'74392','new_theme','font-weight','400',0,''),(614683,193493,'74392','new_theme','line-height','120',0,''),(614684,193493,'74392','new_theme','line_height_measure','%',0,''),(614685,193493,'74392','new_theme','font-size','12',0,''),(614686,193494,'74393','new_theme','text','<p>SHIPPING ADDRESS:</p>',1,''),(614687,193494,'74393','new_theme','font-size','14',0,''),(614688,193494,'74393','new_theme','font-weight','bold',0,''),(614689,193494,'74393','new_theme','padding-bottom','10',0,''),(614690,193494,'74393','new_theme','text','<p>SHIPPING ADDRESS:</p>',0,''),(614691,193495,'74394','new_theme','block_type','1',0,''),(614692,193495,'74394','new_theme','background-color','$content-bg-2',0,''),(614693,193495,'74394','new_theme','padding-top','20',0,''),(614694,193495,'74394','new_theme','padding-left','10',0,''),(614695,193495,'74394','new_theme','padding-right','10',0,''),(614696,193495,'74394','new_theme','padding-bottom','20',0,''),(614697,193495,'74394','new_theme','font-size','14',0,''),(614698,193496,'74395','new_theme','font-weight','normal',0,''),(614699,193496,'74395','new_theme','text-align','right',0,''),(614700,193496,'74395','new_theme','font-size','14',0,''),(614701,193496,'74395','new_theme','box_align','3',0,''),(614702,193497,'74396','new_theme','block_type','2',0,''),(614703,193497,'74396','new_theme','font-weight','normal',0,''),(614704,193497,'74396','new_theme','padding-bottom','20',0,''),(614705,193498,'74397','new_theme','font-weight','400',0,''),(614706,193498,'74397','new_theme','padding-top','20',0,''),(614707,193498,'74397','new_theme','logo_from','theme',0,''),(614708,193499,'74398','new_theme','block_type','11',0,''),(614709,193499,'74398','new_theme','font-weight','normal',0,''),(614710,193500,'74399','new_theme','text','<p>Web:</p>',1,''),(614711,193500,'74399','new_theme','font-weight','normal',0,''),(614712,193500,'74399','new_theme','text-align','right',0,''),(614713,193500,'74399','new_theme','text','<p>Web:</p>',0,''),(614714,193501,'74400','new_theme','font-weight','normal',0,''),(614715,193501,'74400','new_theme','text-align','right',0,''),(614716,193502,'74401','new_theme','block_type','11',0,''),(614717,193502,'74401','new_theme','font-weight','normal',0,''),(614718,193503,'74402','new_theme','text','<p>Email:</p>',1,''),(614719,193503,'74402','new_theme','font-weight','normal',0,''),(614720,193503,'74402','new_theme','text-align','right',0,''),(614721,193503,'74402','new_theme','text','<p>Email:</p>',0,''),(614722,193504,'74403','new_theme','font-weight','normal',0,''),(614723,193504,'74403','new_theme','text-align','right',0,''),(614724,193505,'74404','new_theme','block_type','1',0,''),(614725,193506,'74405','new_theme','font-weight','normal',0,''),(614726,193506,'74405','new_theme','text-align','right',0,''),(614727,193506,'74405','new_theme','padding-bottom','10',0,''),(614728,193506,'74405','new_theme','address_spacer',',',0,''),(614729,193506,'74405','new_theme','font-size','12',0,''),(614730,193507,'74406','new_theme','block_type','11',0,''),(614731,193507,'74406','new_theme','font-weight','normal',0,''),(614732,193508,'74407','new_theme','text','<p>Phone:</p>',1,''),(614733,193508,'74407','new_theme','font-weight','normal',0,''),(614734,193508,'74407','new_theme','text-align','right',0,''),(614735,193508,'74407','new_theme','text','<p>Phone:</p>',0,''),(614736,193509,'74408','new_theme','font-weight','normal',0,''),(614737,193509,'74408','new_theme','text-align','right',0,''),(614738,193510,'74409','new_theme','block_type','1',0,''),(614739,193510,'74409','new_theme','padding-top','20',0,''),(614740,193511,'74410','new_theme','tab_1','RETURNING CUSTOMER',1,''),(614741,193511,'74410','new_theme','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(614742,193511,'74410','new_theme','tab_1','RETURNING CUSTOMER',0,''),(614743,193511,'74410','new_theme','tab_2','REGISTER TO SAVE YOUR DETAILS',0,''),(614744,193513,'74412','new_theme','block_type','8',0,''),(614745,193514,'74413','new_theme','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(614746,193515,'74414','new_theme','block_type','1',0,''),(614747,193515,'74414','new_theme','padding-left','20',0,''),(614748,193515,'74414','new_theme','padding-right','20',0,''),(614749,193516,'74415','new_theme','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(614750,193518,'74417','new_theme','block_type','1',0,''),(614751,193519,'74418','new_theme','text','##TEXT_OR##',0,''),(614752,193519,'74418','new_theme','font-size','18',0,''),(614753,193519,'74418','new_theme','font-weight','700',0,''),(614754,193519,'74418','new_theme','padding-top','15',0,''),(614755,193519,'74418','new_theme','text-align','center',0,''),(614756,193519,'74418','new_theme','content','\\_',0,'3'),(614757,193519,'74418','new_theme','height','5',0,'3'),(614758,193519,'74418','new_theme','width','70',0,'3'),(614759,193519,'74418','new_theme','display','inline-block',0,'3'),(614760,193519,'74418','new_theme','border-top-width','1',0,'3'),(614761,193519,'74418','new_theme','border-top-color','$content-border-1',0,'3'),(614762,193519,'74418','new_theme','margin-left','10',0,'3'),(614763,193519,'74418','new_theme','margin-right','10',0,'3'),(614764,193519,'74418','new_theme','content','\\_',0,'4'),(614765,193519,'74418','new_theme','display','inline-block',0,'4'),(614766,193519,'74418','new_theme','width','70',0,'4'),(614767,193519,'74418','new_theme','height','5',0,'4'),(614768,193519,'74418','new_theme','border-top-width','1',0,'4'),(614769,193519,'74418','new_theme','border-top-color','$content-border-1',0,'4'),(614770,193519,'74418','new_theme','margin-left','10',0,'4'),(614771,193519,'74418','new_theme','margin-right','10',0,'4'),(614772,193519,'74418','new_theme','position','relative',0,''),(614773,193519,'74418','new_theme','top','-10',0,''),(614774,193520,'74419','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(614775,193520,'74419','new_theme','font-size','26',0,''),(614776,193520,'74419','new_theme','font-family','$font-1',0,''),(614777,193520,'74419','new_theme','padding-top','15',0,''),(614778,193520,'74419','new_theme','padding-bottom','15',0,''),(614779,193520,'74419','new_theme','text-align','center',0,''),(614780,193521,'74420','new_theme','text-align','center',0,''),(614781,193521,'74420','new_theme','hide_parents','2',0,''),(614782,193522,'74421','new_theme','block_type','1',0,''),(614783,193522,'74421','new_theme','padding-top','40',0,''),(614784,193522,'74421','new_theme','background-color','$content-bg-2',0,''),(614785,193522,'74421','new_theme','padding-bottom','40',0,''),(614786,193522,'74421','new_theme','style_class','checkout-login-wrap',0,''),(614787,193522,'74421','new_theme','color','$content-color-2',0,''),(614788,193523,'74422','new_theme','block_type','2',0,''),(614789,193523,'74422','new_theme','background-color','$content-bg-1',0,''),(614790,193523,'74422','new_theme','max-width','830',0,''),(614791,193523,'74422','new_theme','margin_left_measure','auto',0,''),(614792,193523,'74422','new_theme','margin_right_measure','auto',0,''),(614793,193523,'74422','new_theme','padding-top','40',0,''),(614794,193523,'74422','new_theme','padding-bottom','40',0,''),(614795,193523,'74422','new_theme','schema','2-3',0,'8451'),(614796,193523,'74422','new_theme','color','$content-color-1',0,''),(614797,193524,'74423','new_theme','text-align','center',0,''),(614798,193524,'74423','new_theme','margin-bottom','40',0,''),(614799,193525,'74424','new_theme','text-align','center',0,''),(614800,193526,'74425','new_theme','text','##TEXT_OR##',0,''),(614801,193526,'74425','new_theme','font-size','18',0,''),(614802,193526,'74425','new_theme','font-weight','700',0,''),(614803,193526,'74425','new_theme','text-align','center',0,''),(614804,193526,'74425','new_theme','content','\\_',0,'3'),(614805,193526,'74425','new_theme','height','5',0,'3'),(614806,193526,'74425','new_theme','width','70',0,'3'),(614807,193526,'74425','new_theme','display','inline-block',0,'3'),(614808,193526,'74425','new_theme','border-top-width','1',0,'3'),(614809,193526,'74425','new_theme','border-top-color','$content-border-1',0,'3'),(614810,193526,'74425','new_theme','margin-left','10',0,'3'),(614811,193526,'74425','new_theme','margin-right','10',0,'3'),(614812,193526,'74425','new_theme','content','\\_',0,'4'),(614813,193526,'74425','new_theme','display','inline-block',0,'4'),(614814,193526,'74425','new_theme','width','70',0,'4'),(614815,193526,'74425','new_theme','height','5',0,'4'),(614816,193526,'74425','new_theme','border-top-width','1',0,'4'),(614817,193526,'74425','new_theme','border-top-color','$content-border-1',0,'4'),(614818,193526,'74425','new_theme','margin-left','10',0,'4'),(614819,193526,'74425','new_theme','margin-right','10',0,'4'),(614820,193526,'74425','new_theme','position','relative',0,''),(614821,193526,'74425','new_theme','padding-top','10',0,''),(614822,193526,'74425','new_theme','padding-bottom','10',0,''),(614823,193527,'74426','new_theme','block_type','1',0,''),(614824,193528,'74427','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(614825,193528,'74427','new_theme','font-size','18',0,''),(614826,193528,'74427','new_theme','font-family','$font-1',0,''),(614827,193528,'74427','new_theme','padding-top','15',0,''),(614828,193528,'74427','new_theme','padding-bottom','15',0,''),(614829,193528,'74427','new_theme','text-align','center',0,''),(614830,193528,'74427','new_theme','text-transform','uppercase',0,''),(614831,193529,'74428','new_theme','text-align','center',0,''),(614832,193529,'74428','new_theme','hide_parents','2',0,''),(614833,193530,'74429','new_theme','text','##NEW_CUSTOMER##',0,''),(614834,193530,'74429','new_theme','font-size','18',0,''),(614835,193530,'74429','new_theme','font-family','$font-1',0,''),(614836,193530,'74429','new_theme','text-align','center',0,''),(614837,193530,'74429','new_theme','text-transform','uppercase',0,''),(614838,193530,'74429','new_theme','margin-bottom','10',0,''),(614839,193531,'74430','new_theme','max-width','230',0,''),(614840,193531,'74430','new_theme','margin_left_measure','auto',0,''),(614841,193531,'74430','new_theme','margin_right_measure','auto',0,''),(614842,193532,'74431','new_theme','text','##RETURNING_CUSTOMER##',0,''),(614843,193532,'74431','new_theme','font-size','18',0,''),(614844,193532,'74431','new_theme','font-family','$font-1',0,''),(614845,193532,'74431','new_theme','text-transform','uppercase',0,''),(614846,193532,'74431','new_theme','text-align','center',0,''),(614847,193533,'74432','new_theme','block_type','1',0,''),(614848,193533,'74432','new_theme','padding-top','20',0,''),(614849,193534,'74433','new_theme','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(614850,193534,'74433','new_theme','tab_2','RETURNING CUSTOMER',1,''),(614851,193534,'74433','new_theme','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(614852,193534,'74433','new_theme','tab_1','GUEST – SINGLE USE ACCOUNT',0,''),(614853,193534,'74433','new_theme','tab_2','RETURNING CUSTOMER',0,''),(614854,193534,'74433','new_theme','tab_3','REGISTER TO SAVE YOUR DETAILS',0,''),(614855,193535,'74434','new_theme','block_type','8',0,''),(614856,193536,'74435','new_theme','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(614857,193537,'74436','new_theme','block_type','1',0,''),(614858,193537,'74436','new_theme','padding-left','20',0,''),(614859,193537,'74436','new_theme','padding-right','20',0,''),(614860,193539,'74438','new_theme','text','<div class=\"info\">##CAN_CREATE##</div>',0,''),(614861,193539,'74438','new_theme','border-top-width','1',0,''),(614862,193539,'74438','new_theme','border-top-color','$content-border-1',0,''),(614863,193541,'74440','new_theme','block_type','8',0,''),(614864,193542,'74441','new_theme','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(614865,193543,'74442','new_theme','block_type','1',0,''),(614866,193543,'74442','new_theme','padding-left','20',0,''),(614867,193543,'74442','new_theme','padding-right','20',0,''),(614868,193544,'74443','new_theme','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(614869,193546,'74445','new_theme','text-align','center',0,''),(614870,193547,'74446','new_theme','text','##TEXT_OR##',0,''),(614871,193547,'74446','new_theme','font-size','18',0,''),(614872,193547,'74446','new_theme','font-weight','700',0,''),(614873,193547,'74446','new_theme','padding-top','15',0,''),(614874,193547,'74446','new_theme','text-align','center',0,''),(614875,193547,'74446','new_theme','content','\\_',0,'3'),(614876,193547,'74446','new_theme','height','5',0,'3'),(614877,193547,'74446','new_theme','width','70',0,'3'),(614878,193547,'74446','new_theme','display','inline-block',0,'3'),(614879,193547,'74446','new_theme','border-top-width','1',0,'3'),(614880,193547,'74446','new_theme','border-top-color','$content-border-1',0,'3'),(614881,193547,'74446','new_theme','margin-left','10',0,'3'),(614882,193547,'74446','new_theme','margin-right','10',0,'3'),(614883,193547,'74446','new_theme','content','\\_',0,'4'),(614884,193547,'74446','new_theme','display','inline-block',0,'4'),(614885,193547,'74446','new_theme','width','70',0,'4'),(614886,193547,'74446','new_theme','height','5',0,'4'),(614887,193547,'74446','new_theme','border-top-width','1',0,'4'),(614888,193547,'74446','new_theme','border-top-color','$content-border-1',0,'4'),(614889,193547,'74446','new_theme','margin-left','10',0,'4'),(614890,193547,'74446','new_theme','margin-right','10',0,'4'),(614891,193547,'74446','new_theme','position','relative',0,''),(614892,193547,'74446','new_theme','top','-10',0,''),(614893,193548,'74447','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(614894,193548,'74447','new_theme','font-size','26',0,''),(614895,193548,'74447','new_theme','font-family','$font-1',0,''),(614896,193548,'74447','new_theme','padding-top','15',0,''),(614897,193548,'74447','new_theme','padding-bottom','15',0,''),(614898,193548,'74447','new_theme','text-align','center',0,''),(614899,193549,'74448','new_theme','block_type','1',0,''),(614900,193549,'74448','new_theme','padding-top','20',0,''),(614901,193550,'74449','new_theme','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(614902,193550,'74449','new_theme','tab_2','RETURNING CUSTOMER',1,''),(614903,193550,'74449','new_theme','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(614904,193550,'74449','new_theme','tab_1','GUEST – SINGLE USE ACCOUNT',0,''),(614905,193550,'74449','new_theme','tab_2','RETURNING CUSTOMER',0,''),(614906,193550,'74449','new_theme','tab_3','REGISTER TO SAVE YOUR DETAILS',0,''),(614907,193551,'74450','new_theme','block_type','8',0,''),(614908,193552,'74451','new_theme','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(614909,193555,'74454','new_theme','block_type','8',0,''),(614910,193556,'74455','new_theme','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(614911,193558,'74457','new_theme','block_type','1',0,''),(614912,193558,'74457','new_theme','padding-left','20',0,''),(614913,193558,'74457','new_theme','padding-right','20',0,''),(614914,193560,'74459','new_theme','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(614915,193561,'74460','new_theme','text','##TEXT_OR##',0,''),(614916,193561,'74460','new_theme','font-size','18',0,''),(614917,193561,'74460','new_theme','font-weight','700',0,''),(614918,193561,'74460','new_theme','padding-top','15',0,''),(614919,193561,'74460','new_theme','text-align','center',0,''),(614920,193561,'74460','new_theme','content','\\_',0,'3'),(614921,193561,'74460','new_theme','height','5',0,'3'),(614922,193561,'74460','new_theme','width','70',0,'3'),(614923,193561,'74460','new_theme','display','inline-block',0,'3'),(614924,193561,'74460','new_theme','border-top-width','1',0,'3'),(614925,193561,'74460','new_theme','border-top-color','$content-border-1',0,'3'),(614926,193561,'74460','new_theme','margin-left','10',0,'3'),(614927,193561,'74460','new_theme','margin-right','10',0,'3'),(614928,193561,'74460','new_theme','content','\\_',0,'4'),(614929,193561,'74460','new_theme','display','inline-block',0,'4'),(614930,193561,'74460','new_theme','width','70',0,'4'),(614931,193561,'74460','new_theme','height','5',0,'4'),(614932,193561,'74460','new_theme','border-top-width','1',0,'4'),(614933,193561,'74460','new_theme','border-top-color','$content-border-1',0,'4'),(614934,193561,'74460','new_theme','margin-left','10',0,'4'),(614935,193561,'74460','new_theme','margin-right','10',0,'4'),(614936,193561,'74460','new_theme','position','relative',0,''),(614937,193561,'74460','new_theme','top','-10',0,''),(614938,193562,'74461','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(614939,193562,'74461','new_theme','font-size','26',0,''),(614940,193562,'74461','new_theme','font-family','$font-1',0,''),(614941,193562,'74461','new_theme','padding-top','15',0,''),(614942,193562,'74461','new_theme','padding-bottom','15',0,''),(614943,193562,'74461','new_theme','text-align','center',0,''),(614944,193563,'74462','new_theme','text-align','center',0,''),(614945,193564,'74463','new_theme','block_type','1',0,''),(614946,193564,'74463','new_theme','padding-top','20',0,''),(614947,193565,'74464','new_theme','text-align','center',0,''),(614948,193566,'74465','new_theme','text','##TEXT_OR##',0,''),(614949,193566,'74465','new_theme','font-size','18',0,''),(614950,193566,'74465','new_theme','font-weight','700',0,''),(614951,193566,'74465','new_theme','padding-top','15',0,''),(614952,193566,'74465','new_theme','text-align','center',0,''),(614953,193566,'74465','new_theme','content','\\_',0,'3'),(614954,193566,'74465','new_theme','height','5',0,'3'),(614955,193566,'74465','new_theme','width','70',0,'3'),(614956,193566,'74465','new_theme','display','inline-block',0,'3'),(614957,193566,'74465','new_theme','border-top-width','1',0,'3'),(614958,193566,'74465','new_theme','border-top-color','$content-border-1',0,'3'),(614959,193566,'74465','new_theme','margin-left','10',0,'3'),(614960,193566,'74465','new_theme','margin-right','10',0,'3'),(614961,193566,'74465','new_theme','content','\\_',0,'4'),(614962,193566,'74465','new_theme','display','inline-block',0,'4'),(614963,193566,'74465','new_theme','width','70',0,'4'),(614964,193566,'74465','new_theme','height','5',0,'4'),(614965,193566,'74465','new_theme','border-top-width','1',0,'4'),(614966,193566,'74465','new_theme','border-top-color','$content-border-1',0,'4'),(614967,193566,'74465','new_theme','margin-left','10',0,'4'),(614968,193566,'74465','new_theme','margin-right','10',0,'4'),(614969,193566,'74465','new_theme','position','relative',0,''),(614970,193566,'74465','new_theme','top','-10',0,''),(614971,193567,'74466','new_theme','tab_1','GUEST – SINGLE USE ACCOUNT',1,''),(614972,193567,'74466','new_theme','tab_2','RETURNING CUSTOMER',1,''),(614973,193567,'74466','new_theme','tab_3','REGISTER TO SAVE YOUR DETAILS',1,''),(614974,193567,'74466','new_theme','tab_1','GUEST – SINGLE USE ACCOUNT',0,''),(614975,193567,'74466','new_theme','tab_2','RETURNING CUSTOMER',0,''),(614976,193567,'74466','new_theme','tab_3','REGISTER TO SAVE YOUR DETAILS',0,''),(614977,193568,'74467','new_theme','block_type','8',0,''),(614978,193569,'74468','new_theme','text','<div class=\"info\">\n ##TEXT_GUEST_MESSAGE_1##\n </div>\n <div class=\"info info-plus\">\n ##TEXT_GUEST_MESSAGE_2##\n </div>',0,''),(614979,193572,'74471','new_theme','block_type','8',0,''),(614980,193573,'74472','new_theme','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(614981,193574,'74473','new_theme','block_type','1',0,''),(614982,193574,'74473','new_theme','padding-left','20',0,''),(614983,193574,'74473','new_theme','padding-right','20',0,''),(614984,193576,'74475','new_theme','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(614985,193577,'74476','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(614986,193577,'74476','new_theme','font-size','26',0,''),(614987,193577,'74476','new_theme','font-family','$font-1',0,''),(614988,193577,'74476','new_theme','padding-top','15',0,''),(614989,193577,'74476','new_theme','padding-bottom','15',0,''),(614990,193577,'74476','new_theme','text-align','center',0,''),(614991,193578,'74477','new_theme','block_type','1',0,''),(614992,193578,'74477','new_theme','padding-top','40',0,''),(614993,193578,'74477','new_theme','background-color','$content-bg-2',0,''),(614994,193578,'74477','new_theme','padding-bottom','40',0,''),(614995,193579,'74478','new_theme','block_type','2',0,''),(614996,193579,'74478','new_theme','background-color','$content-bg-1',0,''),(614997,193579,'74478','new_theme','max-width','830',0,''),(614998,193579,'74478','new_theme','margin_left_measure','auto',0,''),(614999,193579,'74478','new_theme','margin_right_measure','auto',0,''),(615000,193579,'74478','new_theme','padding-top','40',0,''),(615001,193579,'74478','new_theme','padding-bottom','40',0,''),(615002,193580,'74479','new_theme','block_type','1',0,''),(615003,193581,'74480','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(615004,193581,'74480','new_theme','font-size','18',0,''),(615005,193581,'74480','new_theme','font-family','$font-1',0,''),(615006,193581,'74480','new_theme','padding-top','15',0,''),(615007,193581,'74480','new_theme','padding-bottom','15',0,''),(615008,193581,'74480','new_theme','text-align','center',0,''),(615009,193581,'74480','new_theme','text-transform','uppercase',0,''),(615010,193582,'74481','new_theme','text-align','center',0,''),(615011,193582,'74481','new_theme','hide_parents','2',0,''),(615012,193583,'74482','new_theme','text-align','center',0,''),(615013,193584,'74483','new_theme','text-align','center',0,''),(615014,193584,'74483','new_theme','margin-bottom','40',0,''),(615015,193585,'74484','new_theme','text','##TEXT_OR##',0,''),(615016,193585,'74484','new_theme','font-size','18',0,''),(615017,193585,'74484','new_theme','font-weight','700',0,''),(615018,193585,'74484','new_theme','text-align','center',0,''),(615019,193585,'74484','new_theme','content','\\_',0,'3'),(615020,193585,'74484','new_theme','height','5',0,'3'),(615021,193585,'74484','new_theme','width','70',0,'3'),(615022,193585,'74484','new_theme','display','inline-block',0,'3'),(615023,193585,'74484','new_theme','border-top-width','1',0,'3'),(615024,193585,'74484','new_theme','border-top-color','$content-border-1',0,'3'),(615025,193585,'74484','new_theme','margin-left','10',0,'3'),(615026,193585,'74484','new_theme','margin-right','10',0,'3'),(615027,193585,'74484','new_theme','content','\\_',0,'4'),(615028,193585,'74484','new_theme','display','inline-block',0,'4'),(615029,193585,'74484','new_theme','width','70',0,'4'),(615030,193585,'74484','new_theme','height','5',0,'4'),(615031,193585,'74484','new_theme','border-top-width','1',0,'4'),(615032,193585,'74484','new_theme','border-top-color','$content-border-1',0,'4'),(615033,193585,'74484','new_theme','margin-left','10',0,'4'),(615034,193585,'74484','new_theme','margin-right','10',0,'4'),(615035,193585,'74484','new_theme','position','relative',0,''),(615036,193585,'74484','new_theme','padding-top','10',0,''),(615037,193585,'74484','new_theme','padding-bottom','10',0,''),(615038,193586,'74485','new_theme','text','##NEW_CUSTOMER##',0,''),(615039,193586,'74485','new_theme','font-size','18',0,''),(615040,193586,'74485','new_theme','font-family','$font-1',0,''),(615041,193586,'74485','new_theme','text-align','center',0,''),(615042,193586,'74485','new_theme','text-transform','uppercase',0,''),(615043,193586,'74485','new_theme','margin-bottom','10',0,''),(615044,193587,'74486','new_theme','text','##RETURNING_CUSTOMER##',0,''),(615045,193587,'74486','new_theme','font-size','18',0,''),(615046,193587,'74486','new_theme','font-family','$font-1',0,''),(615047,193587,'74486','new_theme','text-transform','uppercase',0,''),(615048,193587,'74486','new_theme','text-align','center',0,''),(615049,193588,'74487','new_theme','max-width','230',0,''),(615050,193588,'74487','new_theme','margin_left_measure','auto',0,''),(615051,193588,'74487','new_theme','margin_right_measure','auto',0,''),(615052,193589,'74488','new_theme','block_type','1',0,''),(615053,193589,'74488','new_theme','padding-top','40',0,''),(615054,193589,'74488','new_theme','background-color','$content-bg-2',0,''),(615055,193589,'74488','new_theme','padding-bottom','40',0,''),(615056,193590,'74489','new_theme','block_type','2',0,''),(615057,193590,'74489','new_theme','background-color','$content-bg-1',0,''),(615058,193590,'74489','new_theme','max-width','830',0,''),(615059,193590,'74489','new_theme','margin_left_measure','auto',0,''),(615060,193590,'74489','new_theme','margin_right_measure','auto',0,''),(615061,193590,'74489','new_theme','padding-top','40',0,''),(615062,193590,'74489','new_theme','padding-bottom','40',0,''),(615063,193591,'74490','new_theme','text','##NEW_CUSTOMER##',0,''),(615064,193591,'74490','new_theme','font-size','18',0,''),(615065,193591,'74490','new_theme','font-family','$font-1',0,''),(615066,193591,'74490','new_theme','text-align','center',0,''),(615067,193591,'74490','new_theme','text-transform','uppercase',0,''),(615068,193591,'74490','new_theme','margin-bottom','10',0,''),(615069,193592,'74491','new_theme','text-align','center',0,''),(615070,193593,'74492','new_theme','text-align','center',0,''),(615071,193593,'74492','new_theme','margin-bottom','40',0,''),(615072,193594,'74493','new_theme','text','##TEXT_OR##',0,''),(615073,193594,'74493','new_theme','font-size','18',0,''),(615074,193594,'74493','new_theme','font-weight','700',0,''),(615075,193594,'74493','new_theme','text-align','center',0,''),(615076,193594,'74493','new_theme','content','\\_',0,'3'),(615077,193594,'74493','new_theme','height','5',0,'3'),(615078,193594,'74493','new_theme','width','70',0,'3'),(615079,193594,'74493','new_theme','display','inline-block',0,'3'),(615080,193594,'74493','new_theme','border-top-width','1',0,'3'),(615081,193594,'74493','new_theme','border-top-color','$content-border-1',0,'3'),(615082,193594,'74493','new_theme','margin-left','10',0,'3'),(615083,193594,'74493','new_theme','margin-right','10',0,'3'),(615084,193594,'74493','new_theme','content','\\_',0,'4'),(615085,193594,'74493','new_theme','display','inline-block',0,'4'),(615086,193594,'74493','new_theme','width','70',0,'4'),(615087,193594,'74493','new_theme','height','5',0,'4'),(615088,193594,'74493','new_theme','border-top-width','1',0,'4'),(615089,193594,'74493','new_theme','border-top-color','$content-border-1',0,'4'),(615090,193594,'74493','new_theme','margin-left','10',0,'4'),(615091,193594,'74493','new_theme','margin-right','10',0,'4'),(615092,193594,'74493','new_theme','position','relative',0,''),(615093,193594,'74493','new_theme','padding-top','10',0,''),(615094,193594,'74493','new_theme','padding-bottom','10',0,''),(615095,193595,'74494','new_theme','block_type','1',0,''),(615096,193596,'74495','new_theme','text','##LOGIN_WITH_SOCIAL##',0,''),(615097,193596,'74495','new_theme','font-size','18',0,''),(615098,193596,'74495','new_theme','font-family','$font-1',0,''),(615099,193596,'74495','new_theme','padding-top','15',0,''),(615100,193596,'74495','new_theme','padding-bottom','15',0,''),(615101,193596,'74495','new_theme','text-align','center',0,''),(615102,193596,'74495','new_theme','text-transform','uppercase',0,''),(615103,193597,'74496','new_theme','text-align','center',0,''),(615104,193597,'74496','new_theme','hide_parents','2',0,''),(615105,193598,'74497','new_theme','text','##RETURNING_CUSTOMER##',0,''),(615106,193598,'74497','new_theme','font-size','18',0,''),(615107,193598,'74497','new_theme','font-family','$font-1',0,''),(615108,193598,'74497','new_theme','text-transform','uppercase',0,''),(615109,193598,'74497','new_theme','text-align','center',0,''),(615110,193599,'74498','new_theme','max-width','230',0,''),(615111,193599,'74498','new_theme','margin_left_measure','auto',0,''),(615112,193599,'74498','new_theme','margin_right_measure','auto',0,''),(615113,193600,'74499','new_theme','block_type','1',0,''),(615114,193601,'74500','new_theme','text','<h1>##HEADING_TITLE##</h1>\n <p>##TEXT_MAIN##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(615115,193601,'74500','new_theme','margin-bottom','30',0,''),(615116,193602,'74501','new_theme','block_type','1',0,''),(615117,193603,'74502','new_theme','text','<h1>##ACCOUNT_DELETE_TITLE##</h1>\n <p>##TEXT_CUSTOMER_DELETED##</p>\n <br><br>\n <div class=\"buttons\">\n <div class=\"left-buttons\"><a href=\"##URL##index\" class=\"btn\">##IMAGE_BUTTON_CONTINUE##</a></div>\n </div>',0,''),(615118,193603,'74502','new_theme','margin-bottom','30',0,''),(615119,193604,'74503','new_theme','block_type','1',0,''),(615120,193604,'74503','new_theme','background-color','$best-sellers-bg-1',0,''),(615121,193604,'74503','new_theme','padding-top','20',0,''),(615122,193604,'74503','new_theme','padding-bottom','20',0,''),(615123,193604,'74503','new_theme','font-weight','400',0,''),(615124,193604,'74503','new_theme','visibility_product','1',0,''),(615125,193604,'74503','new_theme','visibility_catalog','1',0,''),(615126,193604,'74503','new_theme','visibility_info','1',0,''),(615127,193604,'74503','new_theme','visibility_cart','1',0,''),(615128,193604,'74503','new_theme','visibility_checkout','1',0,''),(615129,193604,'74503','new_theme','visibility_success','1',0,''),(615130,193604,'74503','new_theme','visibility_account','1',0,''),(615131,193604,'74503','new_theme','visibility_login','1',0,''),(615132,193604,'74503','new_theme','visibility_other','1',0,''),(615133,193604,'74503','new_theme','margin-bottom','20',0,''),(615134,193604,'74503','new_theme','display_none','on',0,'8451'),(615135,193605,'74504','new_theme','block_type','2',0,''),(615136,193605,'74504','new_theme','font-weight','normal',0,''),(615137,193606,'74505','new_theme','font-weight','400',0,''),(615138,193606,'74505','new_theme','visibility_product','1',0,''),(615139,193606,'74505','new_theme','show_name','0',0,''),(615140,193606,'74505','new_theme','show_stock','1',0,''),(615141,193606,'74505','new_theme','show_description','1',0,''),(615142,193606,'74505','new_theme','show_model','1',0,''),(615143,193606,'74505','new_theme','show_rating','1',0,''),(615144,193606,'74505','new_theme','show_rating_counts','1',0,''),(615145,193606,'74505','new_theme','show_qty_input','1',0,''),(615146,193606,'74505','new_theme','show_view_button','1',0,''),(615147,193606,'74505','new_theme','show_wishlist_button','1',0,''),(615148,193606,'74505','new_theme','show_compare','1',0,''),(615149,193606,'74505','new_theme','listing_type','productListing',0,''),(615150,193606,'74505','new_theme','show_properties','1',0,''),(615151,193606,'74505','new_theme','col_in_row','2',0,''),(615152,193606,'74505','new_theme','show_bonus_points','1',0,''),(615153,193606,'74505','new_theme','show_buy_button','1',0,''),(615154,193606,'74505','new_theme','show_attributes','1',0,''),(615155,193607,'74506','new_theme','font-weight','normal',0,''),(615156,193607,'74506','new_theme','visibility_product','1',0,''),(615157,193608,'74507','new_theme','font-weight','400',0,''),(615158,193608,'74507','new_theme','visibility_product','1',0,''),(615159,193608,'74507','new_theme','visibility_catalog','1',0,''),(615160,193608,'74507','new_theme','visibility_info','1',0,''),(615161,193608,'74507','new_theme','visibility_cart','1',0,''),(615162,193608,'74507','new_theme','visibility_checkout','1',0,''),(615163,193608,'74507','new_theme','visibility_success','1',0,''),(615164,193608,'74507','new_theme','visibility_account','1',0,''),(615165,193608,'74507','new_theme','visibility_login','1',0,''),(615166,193608,'74507','new_theme','visibility_other','1',0,''),(615167,193608,'74507','new_theme','banners_group','home',0,''),(615168,193608,'74507','new_theme','banners_type','single',0,''),(615169,193608,'74507','new_theme','lazy_load','1',0,''),(615170,193608,'74507','new_theme','template','1',0,''),(615171,193608,'74507','new_theme','ban_id','41',0,''),(615172,193609,'74508','new_theme','block_type','1',0,''),(615173,193609,'74508','new_theme','font-weight','normal',0,''),(615174,193610,'74510','new_theme','tab_1','##NEW_PRODUCTS##',0,''),(615175,193610,'74510','new_theme','tab_2','##SPECIALS_PRODUCTS##',0,''),(615176,193610,'74510','new_theme','tab_3','##FEATURED_PRODUCTS##',0,''),(615177,193611,'74511','new_theme','col_in_row','4',0,''),(615178,193611,'74511','new_theme','view_as','carousel',0,''),(615179,193611,'74511','new_theme','show_attributes','1',0,''),(615180,193611,'74511','new_theme','col_in_row','3',0,'8451'),(615181,193611,'74511','new_theme','col_in_row','2',0,'8444'),(615182,193611,'74511','new_theme','col_in_row','1',0,'8472'),(615183,193611,'74511','new_theme','listing_type','productListing',0,''),(615184,193611,'74511','new_theme','show_qty_input','1',0,''),(615185,193611,'74511','new_theme','show_compare','1',0,''),(615186,193611,'74511','new_theme','lazy_load','1',0,''),(615187,193612,'74512','new_theme','font-weight','400',0,''),(615188,193612,'74512','new_theme','show_compare','1',0,''),(615189,193612,'74512','new_theme','listing_type','productListing',0,''),(615190,193612,'74512','new_theme','show_model','1',0,''),(615191,193612,'74512','new_theme','show_properties','1',0,''),(615192,193612,'74512','new_theme','col_in_row','4',0,''),(615193,193612,'74512','new_theme','show_name','0',0,''),(615194,193612,'74512','new_theme','show_image','0',0,''),(615195,193612,'74512','new_theme','show_stock','0',0,''),(615196,193612,'74512','new_theme','show_description','0',0,''),(615197,193612,'74512','new_theme','show_rating','0',0,''),(615198,193612,'74512','new_theme','show_rating_counts','0',0,''),(615199,193612,'74512','new_theme','show_price','0',0,''),(615200,193612,'74512','new_theme','show_buy_button','0',0,''),(615201,193612,'74512','new_theme','show_qty_input','0',0,''),(615202,193612,'74512','new_theme','show_view_button','0',0,''),(615203,193612,'74512','new_theme','show_wishlist_button','0',0,''),(615204,193612,'74512','new_theme','col_in_row','2',0,'8451'),(615205,193612,'74512','new_theme','col_in_row','1',0,'8472'),(615206,193612,'74512','new_theme','view_as','carousel',0,''),(615207,193612,'74512','new_theme','product_names_teg','h2',0,''),(615208,193612,'74512','new_theme','show_attributes','1',0,''),(615209,193613,'74513','new_theme','font-weight','400',0,''),(615210,193613,'74513','new_theme','listing_type','productListing',0,''),(615211,193613,'74513','new_theme','col_in_row','4',0,''),(615212,193613,'74513','new_theme','show_image','0',0,''),(615213,193613,'74513','new_theme','show_stock','0',0,''),(615214,193613,'74513','new_theme','show_description','0',0,''),(615215,193613,'74513','new_theme','show_rating','0',0,''),(615216,193613,'74513','new_theme','show_rating_counts','0',0,''),(615217,193613,'74513','new_theme','show_price','0',0,''),(615218,193613,'74513','new_theme','show_buy_button','0',0,''),(615219,193613,'74513','new_theme','show_qty_input','0',0,''),(615220,193613,'74513','new_theme','show_view_button','0',0,''),(615221,193613,'74513','new_theme','show_wishlist_button','0',0,''),(615222,193613,'74513','new_theme','col_in_row','2',0,'8451'),(615223,193613,'74513','new_theme','col_in_row','1',0,'8472'),(615224,193613,'74513','new_theme','view_as','carousel',0,''),(615225,193613,'74513','new_theme','col_in_row','2',0,'8444'),(615226,193613,'74513','new_theme','featured_type_id','0',0,''),(615227,193615,'74515','new_theme','heading_type','h1',0,''),(615228,193617,'74516','new_theme','block_type','1',0,''),(615229,193618,'74517','new_theme','text','<h1>##BOX_HEADING_MANUFACTURERS##</h1>',0,''),(615230,193620,'74519','new_theme','block_type','1',0,''),(615231,193620,'74519','new_theme','padding-top','40',0,''),(615232,193620,'74519','new_theme','padding-bottom','80',0,''),(615233,193621,'74520','new_theme','block_type','6',0,''),(615234,193622,'74521','new_theme','block_type','1',0,''),(615235,193622,'74521','new_theme','padding-top','20',0,''),(615236,193622,'74521','new_theme','padding-left','20',0,''),(615237,193622,'74521','new_theme','padding-right','20',0,''),(615238,193622,'74521','new_theme','padding-bottom','20',0,''),(615239,193622,'74521','new_theme','border-top-width','1',0,''),(615240,193622,'74521','new_theme','border-left-width','1',0,''),(615241,193622,'74521','new_theme','border-right-width','1',0,''),(615242,193622,'74521','new_theme','border-bottom-width','1',0,''),(615243,193622,'74521','new_theme','border-top-color','$content-border-1',0,''),(615244,193622,'74521','new_theme','border-left-color','$content-border-1',0,''),(615245,193622,'74521','new_theme','border-right-color','$content-border-1',0,''),(615246,193622,'74521','new_theme','border-bottom-color','$content-border-1',0,''),(615247,193622,'74521','new_theme','margin-right','20',0,''),(615248,193625,'74524','new_theme','block_type','1',0,''),(615249,193625,'74524','new_theme','padding-top','20',0,''),(615250,193626,'74525','new_theme','block_type','6',0,''),(615251,193627,'74526','new_theme','padding-right','20',0,''),(615252,193629,'74528','new_theme','block_type','1',0,''),(615253,193629,'74528','new_theme','padding-top','20',0,''),(615254,193630,'74529','new_theme','block_type','6',0,''),(615255,193631,'74530','new_theme','padding-right','20',0,''),(615256,193633,'74532','new_theme','block_type','1',0,''),(615257,193633,'74532','new_theme','style_class','account-password-wrap',0,''),(615258,193634,'74533','new_theme','block_type','6',0,''),(615259,193634,'74533','new_theme','schema','6-3',0,'8451'),(615260,193635,'74534','new_theme','aria_name','account-menu',0,''),(615261,193636,'73374','new_theme','block_type','1',0,''),(615262,193636,'73374','new_theme','padding-top','70',0,''),(615263,193636,'73374','new_theme','padding-right','30',0,''),(615264,193636,'73374','new_theme','padding-bottom','30',0,''),(615265,193636,'73374','new_theme','padding-top','0',0,'8451'),(615266,193636,'73374','new_theme','padding-left','0',0,'8451'),(615267,193636,'73374','new_theme','padding-right','0',0,'8451'),(615268,193636,'73374','new_theme','padding-bottom','0',0,'8451'),(615311,193656,'74536','new_theme','text','<h1>##TEXT_HEADING_PASSWORD##</h1>',0,''),(615312,193657,'74537','new_theme','block_type','1',0,''),(615313,193657,'74537','new_theme','padding-top','20',0,''),(615314,193658,'74538','new_theme','tab_1','RETURNING CUSTOMER',1,''),(615315,193658,'74538','new_theme','tab_2','REGISTER TO SAVE YOUR DETAILS',1,''),(615316,193658,'74538','new_theme','tab_1','RETURNING CUSTOMER',0,''),(615317,193658,'74538','new_theme','tab_2','REGISTER TO SAVE YOUR DETAILS',0,''),(615318,193660,'74540','new_theme','block_type','8',0,''),(615319,193661,'74541','new_theme','text','<div class=\"info info-plus\">\n ##BENEFITS_FROM_CREATING##\n </div>',0,''),(615320,193662,'74542','new_theme','block_type','1',0,''),(615321,193662,'74542','new_theme','padding-left','20',0,''),(615322,193662,'74542','new_theme','padding-right','20',0,''),(615323,193664,'74544','new_theme','text','<div class=\"info\">\n ##TEXT_INTRO_REGISTER_ACCOUNT_2##\n</div>',0,''),(615324,193665,'74545','new_theme','block_type','1',0,''),(615325,193666,'74546','new_theme','block_type','1',0,''),(615326,193667,'74547','new_theme','margin_left_measure','auto',0,''),(615327,193667,'74547','new_theme','margin_right_measure','auto',0,''),(615328,193667,'74547','new_theme','max-width','560',0,''),(615329,193668,'74548','new_theme','margin-bottom','30',0,''),(615330,193669,'74549','new_theme','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(615331,193670,'94779','new_theme','block_type','1',0,''),(615332,193672,'94781','new_theme','block_type','6',0,''),(615333,193672,'94781','new_theme','font-weight','400',0,''),(615334,193672,'94781','new_theme','schema','6-2',0,'8472'),(615335,193672,'94781','new_theme','schema','6-2',0,'8451'),(615336,193673,'94782','new_theme','font-weight','400',0,''),(615337,193673,'94782','new_theme','padding-right','40',0,''),(615338,193673,'94782','new_theme','padding-right','0',0,'8472'),(615339,193673,'94782','new_theme','padding-right','0',0,'8451'),(615340,193674,'94783','new_theme','col_in_row','3',0,''),(615341,193674,'94783','new_theme','products_align','left',0,''),(615342,193674,'94783','new_theme','font-weight','400',0,''),(615343,193674,'94783','new_theme','show_qty_input','0',0,''),(615344,193674,'94783','new_theme','listing_type','productListing',0,''),(615345,193674,'94783','new_theme','listing_type_rows','no',0,''),(615346,193674,'94783','new_theme','show_buy_button_b2b','on',0,''),(615347,193674,'94783','new_theme','show_wishlist_button_b2b','1',0,''),(615348,193674,'94783','new_theme','show_compare_b2b','1',0,''),(615349,193674,'94783','new_theme','show_stock','0',0,''),(615350,193674,'94783','new_theme','show_description','0',0,''),(615351,193674,'94783','new_theme','show_model','0',0,''),(615352,193674,'94783','new_theme','show_properties','0',0,''),(615353,193674,'94783','new_theme','show_rating','0',0,''),(615354,193674,'94783','new_theme','show_rating_counts','0',0,''),(615355,193674,'94783','new_theme','show_price','0',0,''),(615356,193674,'94783','new_theme','show_buy_button','0',0,''),(615357,193674,'94783','new_theme','show_view_button','0',0,''),(615358,193674,'94783','new_theme','show_wishlist_button','0',0,''),(615359,193674,'94783','new_theme','show_compare','0',0,''),(615360,193674,'94783','new_theme','show_name_rows','0',0,''),(615361,193674,'94783','new_theme','show_image_rows','0',0,''),(615362,193674,'94783','new_theme','show_stock_rows','0',0,''),(615363,193674,'94783','new_theme','show_description_rows','0',0,''),(615364,193674,'94783','new_theme','show_model_rows','0',0,''),(615365,193674,'94783','new_theme','show_properties_rows','0',0,''),(615366,193674,'94783','new_theme','show_rating_rows','0',0,''),(615367,193674,'94783','new_theme','show_rating_counts_rows','0',0,''),(615368,193674,'94783','new_theme','show_price_rows','0',0,''),(615369,193674,'94783','new_theme','show_buy_button_rows','0',0,''),(615370,193674,'94783','new_theme','show_qty_input_rows','0',0,''),(615371,193674,'94783','new_theme','show_view_button_rows','0',0,''),(615372,193674,'94783','new_theme','show_wishlist_button_rows','0',0,''),(615373,193674,'94783','new_theme','show_compare_rows','0',0,''),(615374,193674,'94783','new_theme','show_name_b2b','0',0,''),(615375,193674,'94783','new_theme','show_image_b2b','0',0,''),(615376,193674,'94783','new_theme','show_stock_b2b','0',0,''),(615377,193674,'94783','new_theme','show_description_b2b','0',0,''),(615378,193674,'94783','new_theme','show_model_b2b','0',0,''),(615379,193674,'94783','new_theme','show_properties_b2b','0',0,''),(615380,193674,'94783','new_theme','show_rating_b2b','0',0,''),(615381,193674,'94783','new_theme','show_rating_counts_b2b','0',0,''),(615382,193674,'94783','new_theme','show_price_b2b','0',0,''),(615383,193674,'94783','new_theme','show_qty_input_b2b','0',0,''),(615384,193674,'94783','new_theme','show_view_button_b2b','0',0,''),(615385,193674,'94783','new_theme','show_attributes_b2b','0',0,''),(615386,193674,'94783','new_theme','items_on_page','9',0,''),(615387,193674,'94783','new_theme','col_in_row','2',0,'8451'),(615388,193674,'94783','new_theme','col_in_row','1',0,'8472'),(615389,193674,'94783','new_theme','product_names_teg','h2',0,''),(615390,193676,'94785','new_theme','block_type','5',0,''),(615391,193676,'94785','new_theme','padding-top','10',0,''),(615392,193676,'94785','new_theme','padding-bottom','10',0,''),(615393,193676,'94785','new_theme','schema','5-2',0,'8472'),(615394,193676,'94785','new_theme','border-top-color','$content-border-1',0,''),(615395,193676,'94785','new_theme','border-top-width','1',0,''),(615396,193678,'94787','new_theme','float','right',0,''),(615397,193679,'94788','new_theme','listing_type','productListing',0,''),(615398,193681,'94790','new_theme','block_type','1',0,''),(615399,193681,'94790','new_theme','padding-top','10',0,''),(615400,193681,'94790','new_theme','padding-bottom','10',0,''),(615401,193681,'94790','new_theme','border-bottom-width','1',0,''),(615402,193681,'94790','new_theme','border-bottom-color','$content-border-1',0,''),(615403,193681,'94790','new_theme','margin-left','0',0,''),(615404,193681,'94790','new_theme','margin-right','0',0,''),(615405,193682,'94791','new_theme','float','right',0,''),(615406,193682,'94791','new_theme','display','none',0,'8472'),(615407,193683,'94792','new_theme','float','left',0,''),(615408,193683,'94792','new_theme','clear','none',0,''),(615409,193683,'94792','new_theme','margin-left','20',0,''),(615410,193683,'94792','new_theme','display','none',0,'8472'),(615411,193684,'94793','new_theme','margin-right','20',0,''),(615412,193684,'94793','new_theme','float','right',0,''),(615413,193684,'94793','new_theme','clear','none',0,''),(615414,193684,'94793','new_theme','display','none',0,'8451'),(615415,193685,'94794','new_theme','float','left',0,''),(615416,193685,'94794','new_theme','clear','none',0,''),(615417,193685,'94794','new_theme','sort_pos_3','1',0,''),(615418,193685,'94794','new_theme','sort_pos_4','2',0,''),(615419,193685,'94794','new_theme','sort_pos_10','3',0,''),(615420,193685,'94794','new_theme','sort_pos_9','4',0,''),(615421,193685,'94794','new_theme','sort_pos_11','5',0,''),(615422,193685,'94794','new_theme','sort_pos_12','6',0,''),(615423,193685,'94794','new_theme','sort_pos_14','7',0,''),(615424,193685,'94794','new_theme','sort_pos_13','8',0,''),(615425,193685,'94794','new_theme','sort_pos_8','9',0,''),(615426,193685,'94794','new_theme','sort_pos_7','10',0,''),(615427,193685,'94794','new_theme','sort_pos_2','11',0,''),(615428,193685,'94794','new_theme','sort_pos_1','12',0,''),(615429,193685,'94794','new_theme','sort_pos_6','13',0,''),(615430,193685,'94794','new_theme','sort_pos_5','14',0,''),(615431,193685,'94794','new_theme','sort_pos_0','15',0,''),(615432,193685,'94794','new_theme','sort_hide_10','1',0,''),(615433,193685,'94794','new_theme','sort_hide_9','1',0,''),(615434,193685,'94794','new_theme','hide_icons','1',0,''),(615435,193685,'94794','new_theme','sort_hide_16','1',0,''),(615436,193685,'94794','new_theme','sort_hide_15','1',0,''),(615437,193685,'94794','new_theme','sort_hide_3','0',0,''),(615438,193685,'94794','new_theme','sort_hide_4','0',0,''),(615439,193685,'94794','new_theme','sort_hide_11','1',0,''),(615440,193685,'94794','new_theme','sort_hide_12','1',0,''),(615441,193685,'94794','new_theme','sort_hide_14','1',0,''),(615442,193685,'94794','new_theme','sort_hide_13','1',0,''),(615443,193685,'94794','new_theme','sort_hide_8','0',0,''),(615444,193685,'94794','new_theme','sort_hide_7','0',0,''),(615445,193685,'94794','new_theme','sort_hide_2','1',0,''),(615446,193685,'94794','new_theme','sort_hide_1','1',0,''),(615447,193685,'94794','new_theme','sort_hide_6','1',0,''),(615448,193685,'94794','new_theme','sort_hide_5','1',0,''),(615449,193685,'94794','new_theme','sort_hide_0','1',0,''),(615450,193686,'74550','new_theme','block_type','1',0,''),(615451,193687,'74551','new_theme','margin-bottom','30',0,''),(615452,193688,'74552','new_theme','text','<h1>##HEADING_COMMUNICATION_TOPIC_CREATE##</h1>',0,''),(615453,193689,'74553','new_theme','block_type','1',0,''),(615454,193690,'74554','new_theme','block_type','5',0,''),(615455,193690,'74554','new_theme','padding-top','10',0,''),(615456,193690,'74554','new_theme','padding-bottom','10',0,''),(615457,193690,'74554','new_theme','schema','5-2',0,'8472'),(615458,193690,'74554','new_theme','border-top-color','$content-border-1',0,''),(615459,193690,'74554','new_theme','border-top-width','1',0,''),(615460,193691,'74555','new_theme','padding-top','3',0,''),(615461,193692,'74556','new_theme','float','right',0,''),(615462,193692,'74556','new_theme','height','31',0,''),(615463,193693,'74557','new_theme','col_in_row','4',0,''),(615464,193693,'74557','new_theme','products_align','left',0,''),(615465,193693,'74557','new_theme','font-weight','400',0,''),(615466,193693,'74557','new_theme','listing_type','productListing',0,''),(615467,193693,'74557','new_theme','listing_type_rows','Rows',0,''),(615468,193693,'74557','new_theme','show_buy_button_b2b','on',0,''),(615469,193693,'74557','new_theme','show_wishlist_button_b2b','1',0,''),(615470,193693,'74557','new_theme','show_compare_b2b','1',0,''),(615471,193693,'74557','new_theme','show_image','0',0,''),(615472,193693,'74557','new_theme','show_stock','0',0,''),(615473,193693,'74557','new_theme','show_description','0',0,''),(615474,193693,'74557','new_theme','show_model','0',0,''),(615475,193693,'74557','new_theme','show_properties','0',0,''),(615476,193693,'74557','new_theme','show_rating','0',0,''),(615477,193693,'74557','new_theme','show_rating_counts','0',0,''),(615478,193693,'74557','new_theme','show_price','0',0,''),(615479,193693,'74557','new_theme','show_buy_button','0',0,''),(615480,193693,'74557','new_theme','show_view_button','0',0,''),(615481,193693,'74557','new_theme','show_wishlist_button','0',0,''),(615482,193693,'74557','new_theme','show_compare','0',0,''),(615483,193693,'74557','new_theme','show_name_rows','0',0,''),(615484,193693,'74557','new_theme','show_image_rows','0',0,''),(615485,193693,'74557','new_theme','show_stock_rows','0',0,''),(615486,193693,'74557','new_theme','show_description_rows','0',0,''),(615487,193693,'74557','new_theme','show_model_rows','0',0,''),(615488,193693,'74557','new_theme','show_properties_rows','0',0,''),(615489,193693,'74557','new_theme','show_rating_rows','0',0,''),(615490,193693,'74557','new_theme','show_rating_counts_rows','0',0,''),(615491,193693,'74557','new_theme','show_price_rows','0',0,''),(615492,193693,'74557','new_theme','show_buy_button_rows','0',0,''),(615493,193693,'74557','new_theme','show_qty_input_rows','0',0,''),(615494,193693,'74557','new_theme','show_view_button_rows','0',0,''),(615495,193693,'74557','new_theme','show_wishlist_button_rows','0',0,''),(615496,193693,'74557','new_theme','show_compare_rows','0',0,''),(615497,193693,'74557','new_theme','show_name_b2b','0',0,''),(615498,193693,'74557','new_theme','show_image_b2b','0',0,''),(615499,193693,'74557','new_theme','show_stock_b2b','0',0,''),(615500,193693,'74557','new_theme','show_description_b2b','0',0,''),(615501,193693,'74557','new_theme','show_model_b2b','0',0,''),(615502,193693,'74557','new_theme','show_properties_b2b','0',0,''),(615503,193693,'74557','new_theme','show_rating_b2b','0',0,''),(615504,193693,'74557','new_theme','show_rating_counts_b2b','0',0,''),(615505,193693,'74557','new_theme','show_price_b2b','0',0,''),(615506,193693,'74557','new_theme','show_qty_input_b2b','0',0,''),(615507,193693,'74557','new_theme','show_view_button_b2b','0',0,''),(615508,193693,'74557','new_theme','show_attributes_b2b','0',0,''),(615509,193693,'74557','new_theme','items_on_page','12',0,''),(615510,193693,'74557','new_theme','col_in_row','2',0,'8451'),(615511,193693,'74557','new_theme','col_in_row','1',0,'8472'),(615512,193693,'74557','new_theme','product_names_teg','h2',0,''),(615513,193696,'74560','new_theme','block_type','1',0,''),(615514,193697,'74561','new_theme','block_type','1',0,''),(615515,193697,'74561','new_theme','padding-top','10',0,''),(615516,193697,'74561','new_theme','padding-bottom','10',0,''),(615517,193697,'74561','new_theme','border-bottom-width','1',0,''),(615518,193697,'74561','new_theme','border-bottom-color','$content-border-1',0,''),(615519,193697,'74561','new_theme','margin-left','0',0,''),(615520,193697,'74561','new_theme','margin-right','0',0,''),(615521,193698,'74562','new_theme','clear','none',0,''),(615522,193698,'74562','new_theme','float','left',0,''),(615523,193698,'74562','new_theme','padding-top','3',0,''),(615524,193698,'74562','new_theme','margin-left','20',0,''),(615525,193699,'74563','new_theme','float','right',0,''),(615526,193699,'74563','new_theme','display','none',0,'8472'),(615527,193700,'74564','new_theme','margin-right','20',0,''),(615528,193700,'74564','new_theme','float','right',0,''),(615529,193700,'74564','new_theme','clear','none',0,''),(615530,193700,'74564','new_theme','display','none',0,'8451'),(615531,193701,'74565','new_theme','float','left',0,''),(615532,193701,'74565','new_theme','clear','none',0,''),(615533,193701,'74565','new_theme','margin-left','20',0,''),(615534,193701,'74565','new_theme','display','none',0,'8472'),(615535,193702,'74566','new_theme','float','left',0,''),(615536,193702,'74566','new_theme','clear','none',0,''),(615537,193702,'74566','new_theme','sort_pos_3','2',0,''),(615538,193702,'74566','new_theme','sort_pos_4','3',0,''),(615539,193702,'74566','new_theme','sort_pos_10','11',0,''),(615540,193702,'74566','new_theme','sort_pos_9','10',0,''),(615541,193702,'74566','new_theme','sort_pos_11','12',0,''),(615542,193702,'74566','new_theme','sort_pos_12','13',0,''),(615543,193702,'74566','new_theme','sort_pos_14','15',0,''),(615544,193702,'74566','new_theme','sort_pos_13','14',0,''),(615545,193702,'74566','new_theme','sort_pos_8','4',0,''),(615546,193702,'74566','new_theme','sort_pos_7','5',0,''),(615547,193702,'74566','new_theme','sort_pos_2','7',0,''),(615548,193702,'74566','new_theme','sort_pos_1','6',0,''),(615549,193702,'74566','new_theme','sort_pos_6','9',0,''),(615550,193702,'74566','new_theme','sort_pos_5','8',0,''),(615551,193702,'74566','new_theme','sort_pos_0','1',0,''),(615552,193702,'74566','new_theme','sort_hide_10','1',0,''),(615553,193702,'74566','new_theme','sort_hide_9','1',0,''),(615554,193702,'74566','new_theme','sort_pos_15','16',0,''),(615555,193702,'74566','new_theme','sort_pos_16','17',0,''),(615556,193702,'74566','new_theme','sort_hide_4','0',0,''),(615557,193702,'74566','new_theme','sort_hide_3','0',0,''),(615558,193702,'74566','new_theme','sort_hide_16','1',0,''),(615559,193702,'74566','new_theme','sort_hide_15','1',0,''),(615560,193702,'74566','new_theme','sort_hide_11','1',0,''),(615561,193702,'74566','new_theme','sort_hide_12','1',0,''),(615562,193702,'74566','new_theme','sort_hide_14','1',0,''),(615563,193702,'74566','new_theme','sort_hide_13','1',0,''),(615564,193702,'74566','new_theme','sort_hide_8','0',0,''),(615565,193702,'74566','new_theme','sort_hide_7','0',0,''),(615566,193702,'74566','new_theme','sort_hide_2','1',0,''),(615567,193702,'74566','new_theme','sort_hide_1','1',0,''),(615568,193702,'74566','new_theme','sort_hide_6','1',0,''),(615569,193702,'74566','new_theme','sort_hide_5','1',0,''),(615570,193702,'74566','new_theme','sort_hide_0','0',0,''),(615571,193702,'74566','new_theme','hide_icons','1',0,''),(615572,193703,'74567','new_theme','margin-bottom','20',0,''),(615573,193704,'74568','new_theme','block_type','1',0,''),(615574,193704,'74568','new_theme','style_class','account-order-history',0,''),(615575,193705,'74569','new_theme','block_type','6',0,''),(615576,193705,'74569','new_theme','schema','6-3',0,'8451'),(615577,193706,'74570','new_theme','aria_name','account-menu',0,''),(615578,193707,'73374','new_theme','block_type','1',0,''),(615579,193707,'73374','new_theme','padding-top','70',0,''),(615580,193707,'73374','new_theme','padding-right','30',0,''),(615581,193707,'73374','new_theme','padding-bottom','30',0,''),(615582,193707,'73374','new_theme','padding-top','0',0,'8451'),(615583,193707,'73374','new_theme','padding-left','0',0,'8451'),(615584,193707,'73374','new_theme','padding-right','0',0,'8451'),(615585,193707,'73374','new_theme','padding-bottom','0',0,'8451'),(615628,193726,'74571','new_theme','text','<h1>##TEXT_HEADING_HISTORY##</h1>',0,''),(615629,193727,'74572','new_theme','link','Order History Info',0,''),(615630,193727,'74572','new_theme','text','TEXT_VIEW',0,''),(615631,193727,'74572','new_theme','show_pagenation','1',0,''),(615632,193727,'74572','new_theme','link_pay','Order pay',0,''),(615633,193727,'74572','new_theme','margin-bottom','20',0,''),(615634,193728,'74573','new_theme','block_type','1',0,''),(615635,193728,'74573','new_theme','style_class','account-order-history-info',0,''),(615636,193729,'74574','new_theme','block_type','6',0,''),(615637,193729,'74574','new_theme','schema','6-3',0,'8451'),(615638,193730,'74575','new_theme','aria_name','account-menu',0,''),(615639,193731,'73374','new_theme','block_type','1',0,''),(615640,193731,'73374','new_theme','padding-top','70',0,''),(615641,193731,'73374','new_theme','padding-right','30',0,''),(615642,193731,'73374','new_theme','padding-bottom','30',0,''),(615643,193731,'73374','new_theme','padding-top','0',0,'8451'),(615644,193731,'73374','new_theme','padding-left','0',0,'8451'),(615645,193731,'73374','new_theme','padding-right','0',0,'8451'),(615646,193731,'73374','new_theme','padding-bottom','0',0,'8451'),(615689,193750,'74576','new_theme','float','right',0,''),(615690,193750,'74576','new_theme','clear','none',0,''),(615691,193750,'74576','new_theme','margin-left','20',0,''),(615692,193752,'74578','new_theme','float','right',0,''),(615693,193752,'74578','new_theme','clear','none',0,''),(615694,193752,'74578','new_theme','like_button','2',0,''),(615695,193752,'74578','new_theme','link','Order pay',0,''),(615696,193753,'74579','new_theme','block_type','2',0,''),(615697,193753,'74579','new_theme','padding-top','20',0,''),(615698,193753,'74579','new_theme','margin-bottom','20',0,''),(615699,193754,'74580','new_theme','like_button','1',0,''),(615700,193754,'74580','new_theme','text','IMAGE_BUTTON_BACK',0,''),(615701,193754,'74580','new_theme','link','Order History',0,''),(615702,193755,'74581','new_theme','text-align','right',0,''),(615703,193756,'74582','new_theme','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(615704,193758,'74584','new_theme','float','right',0,''),(615705,193758,'74584','new_theme','clear','none',0,''),(615706,193758,'74584','new_theme','margin-left','20',0,''),(615707,193760,'74586','new_theme','float','right',0,''),(615708,193761,'74587','new_theme','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(615709,193763,'74589','new_theme','float','left',0,''),(615710,193764,'74590','new_theme','block_type','3',0,''),(615711,193764,'74590','new_theme','clear','both',0,''),(615712,193764,'74590','new_theme','padding-top','20',0,''),(615713,193764,'74590','new_theme','schema','3-4',0,'8444'),(615714,193765,'74591','new_theme','block_type','1',0,''),(615715,193765,'74591','new_theme','margin-bottom','20',0,''),(615716,193765,'74591','new_theme','padding-right','0',0,'8444'),(615717,193765,'74591','new_theme','padding-right','20',0,''),(615718,193766,'74592','new_theme','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(615719,193767,'74593','new_theme','padding-left','30',0,''),(615720,193767,'74593','new_theme','orders_data','telephone',0,''),(615721,193767,'74593','new_theme','hide_parents','2',0,''),(615722,193768,'74594','new_theme','block_type','1',0,''),(615723,193768,'74594','new_theme','padding-right','20',0,''),(615724,193768,'74594','new_theme','padding-bottom','20',0,''),(615725,193768,'74594','new_theme','padding-right','0',0,'8444'),(615726,193769,'74595','new_theme','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(615727,193770,'74596','new_theme','orders_data','name',0,''),(615728,193770,'74596','new_theme','padding-left','30',0,''),(615729,193771,'74597','new_theme','block_type','1',0,''),(615730,193771,'74597','new_theme','padding-right','20',0,''),(615731,193771,'74597','new_theme','margin-bottom','20',0,''),(615732,193771,'74597','new_theme','padding-right','0',0,'8444'),(615733,193772,'74598','new_theme','short_view','1',0,''),(615734,193772,'74598','new_theme','hide_parents','2',0,''),(615735,193773,'74599','new_theme','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(615736,193774,'74600','new_theme','link','Tracking numbers',0,''),(615737,193774,'74600','new_theme','text','MORE_TRACKING_NUMBER',0,''),(615738,193774,'74600','new_theme','popup','1',0,''),(615739,193774,'74600','new_theme','order_id','1',0,''),(615740,193774,'74600','new_theme','popup_class','tracking-numbers-popup',0,''),(615741,193774,'74600','new_theme','font-weight','700',0,''),(615742,193774,'74600','new_theme','font-size','18',0,''),(615743,193775,'74601','new_theme','block_type','1',0,''),(615744,193775,'74601','new_theme','padding-right','20',0,''),(615745,193775,'74601','new_theme','padding-right','0',0,'8444'),(615746,193776,'74602','new_theme','orders_data','shipping_method',0,''),(615747,193776,'74602','new_theme','padding-left','30',0,''),(615748,193777,'74603','new_theme','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(615749,193778,'74604','new_theme','block_type','1',0,''),(615750,193778,'74604','new_theme','padding-right','20',0,''),(615751,193778,'74604','new_theme','padding-bottom','20',0,''),(615752,193778,'74604','new_theme','padding-right','0',0,'8444'),(615753,193779,'74605','new_theme','orders_data','delivery_address',0,''),(615754,193779,'74605','new_theme','padding-left','30',0,''),(615755,193780,'74606','new_theme','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(615756,193781,'74607','new_theme','block_type','1',0,''),(615757,193782,'74608','new_theme','orders_data','payment_method',0,''),(615758,193782,'74608','new_theme','padding-left','30',0,''),(615759,193783,'74609','new_theme','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(615760,193784,'74610','new_theme','block_type','1',0,''),(615761,193784,'74610','new_theme','padding-bottom','20',0,''),(615762,193785,'74611','new_theme','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(615763,193786,'74612','new_theme','orders_data','billing_address',0,''),(615764,193786,'74612','new_theme','padding-left','30',0,''),(615765,193787,'74613','new_theme','block_type','1',0,''),(615766,193787,'74613','new_theme','style_class','account-order-pay',0,''),(615767,193788,'74614','new_theme','block_type','6',0,''),(615768,193788,'74614','new_theme','schema','6-3',0,'8451'),(615769,193789,'74615','new_theme','aria_name','account-menu',0,''),(615770,193790,'73374','new_theme','block_type','1',0,''),(615771,193790,'73374','new_theme','padding-top','70',0,''),(615772,193790,'73374','new_theme','padding-right','30',0,''),(615773,193790,'73374','new_theme','padding-bottom','30',0,''),(615774,193790,'73374','new_theme','padding-top','0',0,'8451'),(615775,193790,'73374','new_theme','padding-left','0',0,'8451'),(615776,193790,'73374','new_theme','padding-right','0',0,'8451'),(615777,193790,'73374','new_theme','padding-bottom','0',0,'8451'),(615820,193810,'74617','new_theme','block_type','3',0,''),(615821,193811,'74618','new_theme','block_type','1',0,''),(615822,193811,'74618','new_theme','padding-right','20',0,''),(615823,193811,'74618','new_theme','padding-bottom','20',0,''),(615824,193812,'74619','new_theme','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(615825,193813,'74620','new_theme','orders_data','name',0,''),(615826,193813,'74620','new_theme','padding-left','30',0,''),(615827,193814,'74621','new_theme','block_type','1',0,''),(615828,193815,'74622','new_theme','padding-left','30',0,''),(615829,193816,'74623','new_theme','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(615830,193817,'74624','new_theme','block_type','1',0,''),(615831,193817,'74624','new_theme','padding-right','20',0,''),(615832,193817,'74624','new_theme','padding-bottom','20',0,''),(615833,193818,'74625','new_theme','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(615834,193819,'74626','new_theme','orders_data','delivery_address',0,''),(615835,193819,'74626','new_theme','padding-left','30',0,''),(615836,193820,'74627','new_theme','block_type','1',0,''),(615837,193820,'74627','new_theme','padding-right','20',0,''),(615838,193821,'74628','new_theme','orders_data','shipping_method',0,''),(615839,193821,'74628','new_theme','padding-left','30',0,''),(615840,193822,'74629','new_theme','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(615841,193823,'74630','new_theme','block_type','1',0,''),(615842,193824,'74631','new_theme','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(615843,193825,'74632','new_theme','orders_data','payment_method',0,''),(615844,193825,'74632','new_theme','padding-left','30',0,''),(615845,193826,'74633','new_theme','block_type','1',0,''),(615846,193826,'74633','new_theme','padding-bottom','20',0,''),(615847,193827,'74634','new_theme','orders_data','billing_address',0,''),(615848,193827,'74634','new_theme','padding-left','30',0,''),(615849,193828,'74635','new_theme','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(615850,193829,'74636','new_theme','margin-bottom','20',0,''),(615851,193830,'74637','new_theme','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(615852,193833,'74640','new_theme','width','680',0,''),(615853,193833,'74640','new_theme','font-weight','400',0,''),(615854,193833,'74640','new_theme','font-size','12',0,''),(615855,193833,'74640','new_theme','padding-top','20',0,''),(615856,193833,'74640','new_theme','padding-bottom','20',0,''),(615857,193834,'74641','new_theme','block_type','2',0,''),(615858,193834,'74641','new_theme','font-weight','normal',0,''),(615859,193834,'74641','new_theme','padding-bottom','20',0,''),(615860,193835,'74642','new_theme','font-weight','400',0,''),(615861,193835,'74642','new_theme','text-align','center',0,''),(615862,193835,'74642','new_theme','padding-top','10',0,''),(615863,193835,'74642','new_theme','logo_from','theme',0,''),(615864,193836,'74643','new_theme','block_type','11',0,''),(615865,193836,'74643','new_theme','font-weight','normal',0,''),(615866,193837,'74644','new_theme','text','<p>Email:</p>',1,''),(615867,193837,'74644','new_theme','font-weight','normal',0,''),(615868,193837,'74644','new_theme','text-align','right',0,''),(615869,193837,'74644','new_theme','text','<p>Email:</p>',0,''),(615870,193838,'74645','new_theme','font-weight','normal',0,''),(615871,193838,'74645','new_theme','text-align','right',0,''),(615872,193839,'74646','new_theme','block_type','11',0,''),(615873,193839,'74646','new_theme','font-weight','normal',0,''),(615874,193840,'74647','new_theme','text','<p>Phone:</p>',1,''),(615875,193840,'74647','new_theme','font-weight','normal',0,''),(615876,193840,'74647','new_theme','text-align','right',0,''),(615877,193840,'74647','new_theme','text','<p>Phone:</p>',0,''),(615878,193841,'74648','new_theme','font-weight','normal',0,''),(615879,193841,'74648','new_theme','text-align','right',0,''),(615880,193842,'74649','new_theme','block_type','1',0,''),(615881,193843,'74650','new_theme','font-weight','400',0,''),(615882,193843,'74650','new_theme','text-align','right',0,''),(615883,193843,'74650','new_theme','padding-bottom','10',0,''),(615884,193843,'74650','new_theme','address_spacer',',',0,''),(615885,193843,'74650','new_theme','font-size','12',0,''),(615886,193844,'74651','new_theme','block_type','11',0,''),(615887,193844,'74651','new_theme','font-weight','400',0,''),(615888,193845,'74652','new_theme','text','<p>Web:</p>',1,''),(615889,193845,'74652','new_theme','font-weight','400',0,''),(615890,193845,'74652','new_theme','text-align','right',0,''),(615891,193845,'74652','new_theme','text','<p>Web:</p>',0,''),(615892,193846,'74653','new_theme','font-weight','normal',0,''),(615893,193846,'74653','new_theme','text-align','right',0,''),(615894,193847,'74654','new_theme','font-weight','normal',0,''),(615895,193847,'74654','new_theme','padding-top','20',0,''),(615896,193847,'74654','new_theme','font-size','12',0,''),(615897,193848,'74655','new_theme','block_type','1',0,''),(615898,193848,'74655','new_theme','font-weight','normal',0,''),(615899,193848,'74655','new_theme','padding-top','10',0,''),(615900,193848,'74655','new_theme','padding-bottom','10',0,''),(615901,193850,'74657','new_theme','text','<p>If undelivered please return to:</p>',1,''),(615902,193850,'74657','new_theme','font-weight','bold',0,''),(615903,193850,'74657','new_theme','text','<p>If undelivered please return to:</p>',0,''),(615904,193851,'74658','new_theme','block_type','4',0,''),(615905,193851,'74658','new_theme','font-weight','400',0,''),(615906,193851,'74658','new_theme','border-top-width','1',0,''),(615907,193851,'74658','new_theme','border-top-color','$content-border-1',0,''),(615908,193851,'74658','new_theme','border-left-width','1',0,''),(615909,193851,'74658','new_theme','border-left-color','$content-border-1',0,''),(615910,193851,'74658','new_theme','border-right-width','1',0,''),(615911,193851,'74658','new_theme','border-right-color','$content-border-1',0,''),(615912,193851,'74658','new_theme','border-bottom-width','1',0,''),(615913,193851,'74658','new_theme','border-bottom-color','$content-border-1',0,''),(615914,193852,'74659','new_theme','block_type','2',0,''),(615915,193852,'74659','new_theme','font-weight','normal',0,''),(615916,193852,'74659','new_theme','border-right-width','1',0,''),(615917,193852,'74659','new_theme','border-right-color','$content-border-1',0,''),(615918,193853,'74660','new_theme','block_type','1',0,''),(615919,193853,'74660','new_theme','font-weight','normal',0,''),(615920,193853,'74660','new_theme','border-right-width','1',0,''),(615921,193853,'74660','new_theme','border-right-color','$content-border-1',0,''),(615922,193853,'74660','new_theme','background-color','$content-bg-2',0,''),(615923,193853,'74660','new_theme','padding-top','10',0,''),(615924,193853,'74660','new_theme','padding-left','10',0,''),(615925,193853,'74660','new_theme','padding-right','10',0,''),(615926,193853,'74660','new_theme','padding-bottom','10',0,''),(615927,193854,'74661','new_theme','font-size','12',0,''),(615928,193854,'74661','new_theme','font-weight','normal',0,''),(615929,193855,'74662','new_theme','text','<p>SHIPPING ADDRESS:</p>',1,''),(615930,193855,'74662','new_theme','font-size','13',0,''),(615931,193855,'74662','new_theme','font-weight','bold',0,''),(615932,193855,'74662','new_theme','padding-bottom','10',0,''),(615933,193855,'74662','new_theme','text','<p>SHIPPING ADDRESS:</p>',0,''),(615934,193856,'74663','new_theme','block_type','1',0,''),(615935,193856,'74663','new_theme','font-weight','normal',0,''),(615936,193856,'74663','new_theme','padding-top','10',0,''),(615937,193856,'74663','new_theme','padding-left','10',0,''),(615938,193856,'74663','new_theme','padding-right','10',0,''),(615939,193856,'74663','new_theme','padding-bottom','10',0,''),(615940,193857,'74664','new_theme','text','<p>CUSTOMER:</p>',1,''),(615941,193857,'74664','new_theme','font-size','13',0,''),(615942,193857,'74664','new_theme','font-weight','bold',0,''),(615943,193857,'74664','new_theme','text','<p>CUSTOMER:</p>',0,''),(615944,193858,'74665','new_theme','font-size','12',0,''),(615945,193860,'74667','new_theme','text','<p>PHONE NUMBER:</p>',1,''),(615946,193860,'74667','new_theme','font-size','13',0,''),(615947,193860,'74667','new_theme','font-weight','bold',0,''),(615948,193860,'74667','new_theme','padding-top','10',0,''),(615949,193860,'74667','new_theme','text','<p>PHONE NUMBER:</p>',0,''),(615950,193861,'74668','new_theme','font-size','12',0,''),(615951,193862,'74669','new_theme','text','<p>E-MAIL ADDRESS:</p>',1,''),(615952,193862,'74669','new_theme','font-size','13',0,''),(615953,193862,'74669','new_theme','font-weight','bold',0,''),(615954,193862,'74669','new_theme','padding-top','10',0,''),(615955,193862,'74669','new_theme','text','<p>E-MAIL ADDRESS:</p>',0,''),(615956,193863,'74670','new_theme','block_type','2',0,''),(615957,193863,'74670','new_theme','font-weight','normal',0,''),(615958,193863,'74670','new_theme','border-right-width','1',0,''),(615959,193863,'74670','new_theme','border-right-color','$content-border-1',0,''),(615960,193863,'74670','new_theme','border-top-width','1',0,''),(615961,193863,'74670','new_theme','border-top-color','$content-border-1',0,''),(615962,193864,'74671','new_theme','block_type','1',0,''),(615963,193864,'74671','new_theme','font-weight','normal',0,''),(615964,193864,'74671','new_theme','padding-top','10',0,''),(615965,193864,'74671','new_theme','padding-left','10',0,''),(615966,193864,'74671','new_theme','padding-right','10',0,''),(615967,193864,'74671','new_theme','padding-bottom','10',0,''),(615968,193864,'74671','new_theme','border-right-width','1',0,''),(615969,193864,'74671','new_theme','border-right-color','$content-border-1',0,''),(615970,193866,'74673','new_theme','text','<p>Shipping via</p>',1,''),(615971,193866,'74673','new_theme','font-weight','bold',0,''),(615972,193866,'74673','new_theme','text','<p>Shipping via</p>',0,''),(615973,193867,'74674','new_theme','block_type','1',0,''),(615974,193867,'74674','new_theme','font-weight','normal',0,''),(615975,193867,'74674','new_theme','padding-top','10',0,''),(615976,193867,'74674','new_theme','padding-left','10',0,''),(615977,193867,'74674','new_theme','padding-right','10',0,''),(615978,193867,'74674','new_theme','padding-bottom','10',0,''),(615979,193869,'74676','new_theme','text','<p>Shipping service</p>',1,''),(615980,193869,'74676','new_theme','font-weight','bold',0,''),(615981,193869,'74676','new_theme','text','<p>Shipping service</p>',0,''),(615982,193870,'74677','new_theme','font-weight','normal',0,''),(615983,193870,'74677','new_theme','text-align','center',0,''),(615984,193870,'74677','new_theme','padding-top','40',0,''),(615985,193871,'74678','new_theme','block_type','1',0,''),(615986,193872,'74679','new_theme','block_type','8',0,''),(615987,193873,'74680','new_theme','text','##TEXT_MAIN##',0,''),(615988,193873,'74680','new_theme','margin-bottom','20',0,''),(615989,193873,'74680','new_theme','text-align','center',0,''),(615990,193874,'74681','new_theme','margin-bottom','20',0,''),(615991,193875,'74682','new_theme','text','<h1>##HEADING_TITLE##</h1>',0,''),(615992,193877,'74684','new_theme','block_type','2',0,''),(615993,193878,'74685','new_theme','block_type','1',0,''),(615994,193878,'74685','new_theme','style_class','product',0,''),(615995,193878,'74685','new_theme','padding-right','10',0,''),(615996,193878,'74685','new_theme','padding-bottom','20',0,''),(615997,193879,'74686','new_theme','block_type','1',0,''),(615998,193880,'74687','new_theme','product_element','products_name',0,''),(615999,193880,'74687','new_theme','font-family','$font-1',0,''),(616000,193880,'74687','new_theme','padding-bottom','10',0,''),(616001,193880,'74687','new_theme','font-size','16',0,''),(616002,193881,'74688','new_theme','block_type','2',0,''),(616003,193882,'74689','new_theme','product_element','image',0,''),(616004,193882,'74689','new_theme','padding-right','10',0,''),(616005,193883,'74690','new_theme','product_element','products_price_old',0,''),(616006,193883,'74690','new_theme','font-family','$font-1',0,''),(616007,193883,'74690','new_theme','font-size','14',0,''),(616008,193883,'74690','new_theme','text-decoration','line-through',0,''),(616009,193884,'74691','new_theme','product_element','products_price',0,''),(616010,193884,'74691','new_theme','font-family','$font-1',0,''),(616011,193884,'74691','new_theme','font-size','20',0,''),(616012,193884,'74691','new_theme','padding-top','20',0,''),(616013,193885,'74692','new_theme','block_type','1',0,''),(616014,193885,'74692','new_theme','style_class','product',0,''),(616015,193885,'74692','new_theme','padding-left','10',0,''),(616016,193885,'74692','new_theme','padding-bottom','20',0,''),(616017,193886,'74693','new_theme','block_type','2',0,''),(616018,193887,'74694','new_theme','product_element','image',0,''),(616019,193887,'74694','new_theme','padding-right','10',0,''),(616020,193888,'74695','new_theme','font-size','14',0,''),(616021,193888,'74695','new_theme','font-family','$font-1',0,''),(616022,193888,'74695','new_theme','text-decoration','line-through',0,''),(616023,193888,'74695','new_theme','product_element','products_price_old',0,''),(616024,193889,'74696','new_theme','product_element','products_price',0,''),(616025,193889,'74696','new_theme','font-family','$font-1',0,''),(616026,193889,'74696','new_theme','font-size','20',0,''),(616027,193889,'74696','new_theme','padding-top','20',0,''),(616028,193890,'74697','new_theme','block_type','1',0,''),(616029,193891,'74698','new_theme','product_element','products_name',0,''),(616030,193891,'74698','new_theme','font-family','$font-1',0,''),(616031,193891,'74698','new_theme','font-size','16',0,''),(616032,193891,'74698','new_theme','padding-bottom','10',0,''),(616033,193892,'74699','new_theme','font-size','30',0,''),(616034,193892,'74699','new_theme','font-family','$font-1',0,''),(616035,193892,'74699','new_theme','text-align','center',0,''),(616036,193892,'74699','new_theme','padding-bottom','50',0,''),(616037,193893,'74700','new_theme','padding-bottom','20',0,''),(616038,193893,'74700','new_theme','text-align','center',0,''),(616039,193894,'74701','new_theme','width','680',0,''),(616040,193895,'74702','new_theme','padding-top','200',0,''),(616041,193895,'74702','new_theme','padding-left','200',0,''),(616042,193895,'74702','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',1,''),(616043,193895,'74702','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',0,''),(616044,193896,'74703','new_theme','text','osCommerce 4',1,''),(616045,193896,'74703','new_theme','font-family','$font-1',0,''),(616046,193896,'74703','new_theme','font-size','40',0,''),(616047,193896,'74703','new_theme','padding-top','50',0,''),(616048,193896,'74703','new_theme','text-align','center',0,''),(616049,193896,'74703','new_theme','text','osCommerce 4',0,''),(616050,193897,'74704','new_theme','block_type','2',0,''),(616051,193897,'74704','new_theme','border-top-width','1',0,''),(616052,193897,'74704','new_theme','border-top-color','$content-border-1',0,''),(616053,193898,'74705','new_theme','text-align','right',0,''),(616054,193898,'74705','new_theme','padding-top','15',0,''),(616055,193898,'74705','new_theme','padding-bottom','15',0,''),(616056,193898,'74705','new_theme','font-size','14',0,''),(616057,193899,'74706','new_theme','font-family','$font-1',0,''),(616058,193899,'74706','new_theme','text-align','center',0,''),(616059,193899,'74706','new_theme','font-size','20',0,''),(616060,193899,'74706','new_theme','color','$highlight-color-1',0,''),(616061,193899,'74706','new_theme','border-bottom-width','1',0,''),(616062,193899,'74706','new_theme','border-bottom-color','$content-border-1',0,''),(616063,193899,'74706','new_theme','padding-top','10',0,''),(616064,193899,'74706','new_theme','padding-bottom','10',0,''),(616065,193900,'74707','new_theme','block_type','1',0,''),(616066,193901,'74708','new_theme','block_type','6',0,''),(616067,193901,'74708','new_theme','schema','6-3',0,'8451'),(616068,193902,'74709','new_theme','aria_name','account-menu',0,''),(616069,193903,'73374','new_theme','block_type','1',0,''),(616070,193903,'73374','new_theme','padding-top','70',0,''),(616071,193903,'73374','new_theme','padding-right','30',0,''),(616072,193903,'73374','new_theme','padding-bottom','30',0,''),(616073,193903,'73374','new_theme','padding-top','0',0,'8451'),(616074,193903,'73374','new_theme','padding-left','0',0,'8451'),(616075,193903,'73374','new_theme','padding-right','0',0,'8451'),(616076,193903,'73374','new_theme','padding-bottom','0',0,'8451'),(616119,193922,'74710','new_theme','text','<h1>##TEXT_PERSONAL_CATALOG##</h1>',0,''),(616120,193923,'74711','new_theme','like_button','1',0,''),(616121,193923,'74711','new_theme','link','personal_catalog',0,''),(616122,193923,'74711','new_theme','text','BOX_INFORMATION_ALLPRODS',0,''),(616123,193923,'74711','new_theme','text-align','center',0,''),(616124,193923,'74711','new_theme','padding-top','20',0,''),(616125,193923,'74711','new_theme','padding-bottom','20',0,''),(616126,193924,'74712','new_theme','max_items','10',0,''),(616127,193925,'74713','new_theme','block_type','1',0,''),(616128,193925,'74713','new_theme','padding-top','20',0,''),(616129,193925,'74713','new_theme','padding-left','20',0,''),(616130,193925,'74713','new_theme','padding-right','20',0,''),(616131,193925,'74713','new_theme','padding-bottom','20',0,''),(616132,193926,'74714','new_theme','text','<div class=\"heading-2\">##BONUS_AMOUNT_HISTORY##</div>',0,''),(616133,193928,'74716','new_theme','block_type','1',0,''),(616134,193929,'74717','new_theme','margin_left_measure','auto',0,''),(616135,193929,'74717','new_theme','margin_right_measure','auto',0,''),(616136,193929,'74717','new_theme','max-width','560',0,''),(616137,193930,'74718','new_theme','text','<h1>##TEXT_COMMUNICATION_POST##</h1>',0,''),(616138,193931,'74719','new_theme','margin-bottom','30',0,''),(616139,193932,'74720','new_theme','block_type','1',0,''),(616140,193932,'74720','new_theme','style_class','catalog-product-wrap',0,''),(616141,193934,'74722','new_theme','block_type','2',0,''),(616142,193934,'74722','new_theme','font-weight','400',0,''),(616143,193934,'74722','new_theme','padding-bottom','20',0,''),(616144,193934,'74722','new_theme','schema','2-2',0,'8472'),(616145,193935,'74724','new_theme','font-weight','400',0,''),(616146,193935,'74724','new_theme','padding-top','20',0,''),(616147,193935,'74724','new_theme','padding-right','20',0,''),(616148,193935,'74724','new_theme','box_align','4',0,''),(616149,193935,'74724','new_theme','margin-bottom','50',0,''),(616150,193935,'74724','new_theme','align_position','horizontal',0,''),(616151,193938,'74727','new_theme','block_type','12',0,''),(616152,193938,'74727','new_theme','padding-top','15',0,''),(616153,193938,'74727','new_theme','padding-bottom','5',0,''),(616154,193938,'74727','new_theme','border-top-width','1',0,''),(616155,193938,'74727','new_theme','border-top-color','$content-border-1',0,''),(616156,193938,'74727','new_theme','schema','2-2',0,'8444'),(616157,193938,'74727','new_theme','margin-bottom','15',0,''),(616158,193938,'74727','new_theme','border-bottom-width','1',0,''),(616159,193938,'74727','new_theme','border-bottom-color','$content-border-1',0,''),(616160,193938,'74727','new_theme','schema','12-2',0,'8451'),(616161,193939,'74728','new_theme','padding-top','10',0,''),(616162,193939,'74728','new_theme','padding-bottom','10',0,''),(616163,193940,'74729','new_theme','block_type','2',0,''),(616164,193940,'74729','new_theme','schema','2-1',0,'8451'),(616165,193941,'74730','new_theme','font-size','30',0,''),(616166,193941,'74730','new_theme','font-weight','400',0,''),(616167,193941,'74730','new_theme','line-height','35',0,''),(616168,193941,'74730','new_theme','font-family','$font-1',0,''),(616169,193941,'74730','new_theme','line_height_measure','px',0,''),(616170,193941,'74730','new_theme','padding-top','5',0,''),(616171,193942,'74731','new_theme','box_align','4',0,''),(616172,193942,'74731','new_theme','margin-bottom','15',0,'8451'),(616173,193942,'74731','new_theme','text-align','right',0,'8451'),(616174,193942,'74731','new_theme','padding-top','5',0,''),(616175,193942,'74731','new_theme','text-align','left',0,''),(616176,193943,'74732','new_theme','margin-bottom','15',0,''),(616177,193943,'74732','new_theme','padding-top','15',0,''),(616178,193944,'1694165842.4776','new_theme','padding-top','10',0,''),(616179,193945,'74733','new_theme','text-align','right',0,''),(616180,193945,'74733','new_theme','width','100',0,'8444'),(616181,193945,'74733','new_theme','width_measure','%',0,'8444'),(616182,193945,'74733','new_theme','float','none',0,'8444'),(616183,193945,'74733','new_theme','hide_additional_buttons','1',0,''),(616184,193946,'74734','new_theme','text-align','right',0,''),(616185,193947,'74735','new_theme','cat_description','on',0,''),(616186,193947,'74735','new_theme','length_description','250',0,''),(616187,193947,'74735','new_theme','padding-bottom','20',0,''),(616188,193948,'74737','new_theme','document_types_id','4',0,''),(616189,193949,'74738','new_theme','show_address','1',0,''),(616190,193949,'74738','new_theme','show_time','1',0,''),(616191,193949,'74738','new_theme','show_qty','1',0,''),(616192,193949,'74738','new_theme','show_qty_level1','500',0,''),(616193,193949,'74738','new_theme','show_qty_level2','2000',0,''),(616194,193949,'74738','new_theme','text-align','right',0,''),(616195,193949,'74738','new_theme','margin-bottom','10',0,''),(616196,193950,'74739','new_theme','block_type','2',0,''),(616197,193954,'74745','new_theme','font-weight','400',0,''),(616198,193958,'74750','new_theme','font-weight','normal',0,''),(616199,193958,'74750','new_theme','padding-top','10',0,''),(616200,193958,'74750','new_theme','padding-bottom','10',0,''),(616201,193958,'74750','new_theme','box_align','4',0,''),(616202,193959,'74752','new_theme','tab_1','Description',1,''),(616203,193959,'74752','new_theme','tab_2','Reviews',1,''),(616204,193959,'74752','new_theme','font-weight','400',0,''),(616205,193959,'74752','new_theme','tab_1','Description',0,''),(616206,193959,'74752','new_theme','tab_2','Reviews',0,''),(616207,193960,'74753','new_theme','hTagsInline','block',0,''),(616208,193961,'74754','new_theme','margin-bottom','20',0,''),(616209,193961,'74754','new_theme','max-width','500',0,''),(616210,193962,'74755','new_theme','padding-bottom','10',0,''),(616211,193962,'74755','new_theme','padding-top','5',0,''),(616212,193963,'74757','new_theme','font-weight','normal',0,''),(616213,193963,'74757','new_theme','padding-bottom','20',0,''),(616214,193964,'74758','new_theme','font-weight','normal',0,''),(616215,193964,'74758','new_theme','padding-bottom','20',0,''),(616216,193965,'1694166186.2638','new_theme','block_type','1',0,''),(616217,193966,'74751','new_theme','font-weight','400',0,''),(616218,193966,'74751','new_theme','padding-bottom','20',0,''),(616219,193966,'74751','new_theme','show_qty_input','1',0,''),(616220,193966,'74751','new_theme','show_compare','1',0,''),(616221,193966,'74751','new_theme','listing_type','productListing',0,''),(616222,193966,'74751','new_theme','view_as','carousel',0,''),(616223,193966,'74751','new_theme','show_name','0',0,''),(616224,193966,'74751','new_theme','show_image','0',0,''),(616225,193966,'74751','new_theme','show_stock','0',0,''),(616226,193966,'74751','new_theme','show_description','0',0,''),(616227,193966,'74751','new_theme','show_model','0',0,''),(616228,193966,'74751','new_theme','show_properties','0',0,''),(616229,193966,'74751','new_theme','show_rating','0',0,''),(616230,193966,'74751','new_theme','show_rating_counts','0',0,''),(616231,193966,'74751','new_theme','show_price','0',0,''),(616232,193966,'74751','new_theme','show_buy_button','0',0,''),(616233,193966,'74751','new_theme','show_view_button','0',0,''),(616234,193966,'74751','new_theme','show_wishlist_button','0',0,''),(616235,193966,'74751','new_theme','display','none',0,'8451'),(616236,193966,'74751','new_theme','product_names_teg','h2',0,''),(616237,193966,'74751','new_theme','show_attributes','1',0,''),(616238,193966,'74751','new_theme','col_in_row','4',0,''),(616239,193966,'74751','new_theme','hide_parents','2',0,''),(616240,193967,'1694166209.3278','new_theme','text','<div class=\"heading-3\">##PRODUCT_ALSO_PURCHASED##</div>',0,''),(616241,193968,'1694166191.5684','new_theme','block_type','1',0,''),(616242,193969,'74747','new_theme','font-weight','400',0,''),(616243,193969,'74747','new_theme','padding-bottom','20',0,''),(616244,193969,'74747','new_theme','show_compare','1',0,''),(616245,193969,'74747','new_theme','show_name','0',0,''),(616246,193969,'74747','new_theme','show_image','0',0,''),(616247,193969,'74747','new_theme','show_stock','0',0,''),(616248,193969,'74747','new_theme','show_description','0',0,''),(616249,193969,'74747','new_theme','show_model','0',0,''),(616250,193969,'74747','new_theme','show_properties','0',0,''),(616251,193969,'74747','new_theme','show_rating','0',0,''),(616252,193969,'74747','new_theme','show_rating_counts','0',0,''),(616253,193969,'74747','new_theme','show_price','0',0,''),(616254,193969,'74747','new_theme','show_buy_button','0',0,''),(616255,193969,'74747','new_theme','show_view_button','0',0,''),(616256,193969,'74747','new_theme','show_wishlist_button','0',0,''),(616257,193969,'74747','new_theme','listing_type','productListing',0,''),(616258,193969,'74747','new_theme','col_in_row','2',0,'8451'),(616259,193969,'74747','new_theme','col_in_row','1',0,'8472'),(616260,193969,'74747','new_theme','col_in_row','4',0,''),(616261,193969,'74747','new_theme','hide_parents','2',0,''),(616262,193970,'1694166222.3382','new_theme','text','<div class=\"heading-3\">##VIEWED_PRODUCTS##</div>',0,''),(616263,193981,'74771','new_theme','block_type','1',0,''),(616264,193981,'74771','new_theme','style_class','item-holder',0,''),(616265,193981,'74771','new_theme','padding-top','25',0,''),(616266,193981,'74771','new_theme','padding-left','25',0,''),(616267,193981,'74771','new_theme','padding-right','25',0,''),(616268,193981,'74771','new_theme','padding-bottom','25',0,''),(616269,193981,'74771','new_theme','text-align','left',0,''),(616270,193984,'74775','new_theme','description_characters','90',0,''),(616271,193985,'74776','new_theme','text-align','right',0,''),(616272,193985,'74776','new_theme','margin-bottom','10',0,''),(616273,193986,'74777','new_theme','text-align','right',0,''),(616274,193986,'74777','new_theme','clear','none',0,''),(616275,193986,'74777','new_theme','float','left',0,''),(616276,193988,'74779','new_theme','block_type','2',0,''),(616277,193989,'74780','new_theme','margin-bottom','7',0,''),(616278,193990,'74781','new_theme','margin-bottom','10',0,''),(616279,193990,'74781','new_theme','text-align','right',0,''),(616280,193990,'74781','new_theme','float','right',0,''),(616281,193991,'74782','new_theme','clear','both',0,''),(616282,193992,'74783','new_theme','float','left',0,''),(616283,193992,'74783','new_theme','margin-right','20',0,''),(616284,193992,'74783','new_theme','margin-bottom','5',0,''),(616285,193994,'74785','new_theme','block_type','1',0,''),(616286,193995,'74786','new_theme','block_type','6',0,''),(616287,193995,'74786','new_theme','font-weight','400',0,''),(616288,193995,'74786','new_theme','schema','6-2',0,'8472'),(616289,193995,'74786','new_theme','schema','6-2',0,'8451'),(616290,193996,'74787','new_theme','font-weight','400',0,''),(616291,193996,'74787','new_theme','padding-right','40',0,''),(616292,193996,'74787','new_theme','padding-right','0',0,'8472'),(616293,193996,'74787','new_theme','padding-right','0',0,'8451'),(616294,193996,'74787','new_theme','margin-bottom','20',0,''),(616295,193997,'74788','new_theme','margin-bottom','20',0,''),(616296,193999,'74790','new_theme','block_type','1',0,''),(616297,193999,'74790','new_theme','padding-top','10',0,''),(616298,193999,'74790','new_theme','padding-bottom','10',0,''),(616299,193999,'74790','new_theme','border-bottom-width','1',0,''),(616300,193999,'74790','new_theme','border-bottom-color','$content-border-1',0,''),(616301,193999,'74790','new_theme','margin-left','0',0,''),(616302,193999,'74790','new_theme','margin-right','0',0,''),(616303,194000,'74791','new_theme','float','left',0,''),(616304,194000,'74791','new_theme','clear','none',0,''),(616305,194000,'74791','new_theme','sort_pos_3','2',0,''),(616306,194000,'74791','new_theme','sort_pos_4','3',0,''),(616307,194000,'74791','new_theme','sort_pos_10','11',0,''),(616308,194000,'74791','new_theme','sort_pos_9','10',0,''),(616309,194000,'74791','new_theme','sort_pos_11','12',0,''),(616310,194000,'74791','new_theme','sort_pos_12','13',0,''),(616311,194000,'74791','new_theme','sort_pos_14','15',0,''),(616312,194000,'74791','new_theme','sort_pos_13','14',0,''),(616313,194000,'74791','new_theme','sort_pos_8','4',0,''),(616314,194000,'74791','new_theme','sort_pos_7','5',0,''),(616315,194000,'74791','new_theme','sort_pos_2','7',0,''),(616316,194000,'74791','new_theme','sort_pos_1','6',0,''),(616317,194000,'74791','new_theme','sort_pos_6','9',0,''),(616318,194000,'74791','new_theme','sort_pos_5','8',0,''),(616319,194000,'74791','new_theme','sort_pos_0','1',0,''),(616320,194000,'74791','new_theme','sort_hide_10','1',0,''),(616321,194000,'74791','new_theme','sort_hide_9','1',0,''),(616322,194000,'74791','new_theme','sort_pos_15','16',0,''),(616323,194000,'74791','new_theme','sort_pos_16','17',0,''),(616324,194000,'74791','new_theme','sort_hide_4','0',0,''),(616325,194000,'74791','new_theme','sort_hide_3','0',0,''),(616326,194000,'74791','new_theme','sort_hide_16','1',0,''),(616327,194000,'74791','new_theme','sort_hide_15','1',0,''),(616328,194000,'74791','new_theme','sort_hide_11','1',0,''),(616329,194000,'74791','new_theme','sort_hide_12','1',0,''),(616330,194000,'74791','new_theme','sort_hide_14','1',0,''),(616331,194000,'74791','new_theme','sort_hide_13','1',0,''),(616332,194000,'74791','new_theme','sort_hide_8','0',0,''),(616333,194000,'74791','new_theme','sort_hide_7','0',0,''),(616334,194000,'74791','new_theme','sort_hide_2','1',0,''),(616335,194000,'74791','new_theme','sort_hide_1','1',0,''),(616336,194000,'74791','new_theme','sort_hide_6','1',0,''),(616337,194000,'74791','new_theme','sort_hide_5','1',0,''),(616338,194000,'74791','new_theme','sort_hide_0','0',0,''),(616339,194000,'74791','new_theme','hide_icons','1',0,''),(616340,194001,'74792','new_theme','float','right',0,''),(616341,194001,'74792','new_theme','display','none',0,'8472'),(616342,194002,'74793','new_theme','float','left',0,''),(616343,194002,'74793','new_theme','clear','none',0,''),(616344,194002,'74793','new_theme','margin-left','20',0,''),(616345,194002,'74793','new_theme','display','none',0,'8472'),(616346,194003,'74794','new_theme','margin-right','20',0,''),(616347,194003,'74794','new_theme','float','right',0,''),(616348,194003,'74794','new_theme','clear','none',0,''),(616349,194003,'74794','new_theme','display','none',0,'8451'),(616350,194004,'74795','new_theme','block_type','5',0,''),(616351,194004,'74795','new_theme','padding-top','10',0,''),(616352,194004,'74795','new_theme','padding-bottom','10',0,''),(616353,194004,'74795','new_theme','schema','5-2',0,'8472'),(616354,194004,'74795','new_theme','border-top-color','$content-border-1',0,''),(616355,194004,'74795','new_theme','border-top-width','1',0,''),(616356,194005,'74796','new_theme','padding-top','3',0,''),(616357,194006,'74797','new_theme','float','right',0,''),(616358,194006,'74797','new_theme','height','31',0,''),(616359,194007,'74798','new_theme','col_in_row','3',0,''),(616360,194007,'74798','new_theme','products_align','left',0,''),(616361,194007,'74798','new_theme','font-weight','400',0,''),(616362,194007,'74798','new_theme','listing_type','productListing',0,''),(616363,194007,'74798','new_theme','listing_type_rows','Rows',0,''),(616364,194007,'74798','new_theme','show_buy_button_b2b','on',0,''),(616365,194007,'74798','new_theme','show_wishlist_button_b2b','1',0,''),(616366,194007,'74798','new_theme','show_compare_b2b','1',0,''),(616367,194007,'74798','new_theme','show_image','0',0,''),(616368,194007,'74798','new_theme','show_stock','0',0,''),(616369,194007,'74798','new_theme','show_description','0',0,''),(616370,194007,'74798','new_theme','show_model','0',0,''),(616371,194007,'74798','new_theme','show_properties','0',0,''),(616372,194007,'74798','new_theme','show_rating','0',0,''),(616373,194007,'74798','new_theme','show_rating_counts','0',0,''),(616374,194007,'74798','new_theme','show_price','0',0,''),(616375,194007,'74798','new_theme','show_buy_button','0',0,''),(616376,194007,'74798','new_theme','show_view_button','0',0,''),(616377,194007,'74798','new_theme','show_wishlist_button','0',0,''),(616378,194007,'74798','new_theme','show_compare','0',0,''),(616379,194007,'74798','new_theme','show_name_rows','0',0,''),(616380,194007,'74798','new_theme','show_image_rows','0',0,''),(616381,194007,'74798','new_theme','show_stock_rows','0',0,''),(616382,194007,'74798','new_theme','show_description_rows','0',0,''),(616383,194007,'74798','new_theme','show_model_rows','0',0,''),(616384,194007,'74798','new_theme','show_properties_rows','0',0,''),(616385,194007,'74798','new_theme','show_rating_rows','0',0,''),(616386,194007,'74798','new_theme','show_rating_counts_rows','0',0,''),(616387,194007,'74798','new_theme','show_price_rows','0',0,''),(616388,194007,'74798','new_theme','show_buy_button_rows','0',0,''),(616389,194007,'74798','new_theme','show_qty_input_rows','0',0,''),(616390,194007,'74798','new_theme','show_view_button_rows','0',0,''),(616391,194007,'74798','new_theme','show_wishlist_button_rows','0',0,''),(616392,194007,'74798','new_theme','show_compare_rows','0',0,''),(616393,194007,'74798','new_theme','show_name_b2b','0',0,''),(616394,194007,'74798','new_theme','show_image_b2b','0',0,''),(616395,194007,'74798','new_theme','show_stock_b2b','0',0,''),(616396,194007,'74798','new_theme','show_description_b2b','0',0,''),(616397,194007,'74798','new_theme','show_model_b2b','0',0,''),(616398,194007,'74798','new_theme','show_properties_b2b','0',0,''),(616399,194007,'74798','new_theme','show_rating_b2b','0',0,''),(616400,194007,'74798','new_theme','show_rating_counts_b2b','0',0,''),(616401,194007,'74798','new_theme','show_price_b2b','0',0,''),(616402,194007,'74798','new_theme','show_qty_input_b2b','0',0,''),(616403,194007,'74798','new_theme','show_view_button_b2b','0',0,''),(616404,194007,'74798','new_theme','show_attributes_b2b','0',0,''),(616405,194007,'74798','new_theme','items_on_page','9',0,''),(616406,194007,'74798','new_theme','col_in_row','2',0,'8451'),(616407,194007,'74798','new_theme','col_in_row','1',0,'8472'),(616408,194007,'74798','new_theme','product_names_teg','h2',0,''),(616409,194009,'74800','new_theme','block_type','1',0,''),(616410,194010,'74801','new_theme','margin-bottom','20',0,''),(616411,194012,'74802','new_theme','block_type','1',0,''),(616412,194014,'74804','new_theme','text','<h1><span class=\"icons\"></span>##CURRENT_PROMOTIONS##</h1>',0,''),(616413,194015,'74805','new_theme','width','680',0,''),(616414,194015,'74805','new_theme','font-weight','normal',0,''),(616415,194015,'74805','new_theme','font-size','12',0,''),(616416,194015,'74805','new_theme','padding-top','20',0,''),(616417,194015,'74805','new_theme','padding-bottom','20',0,''),(616418,194015,'74805','new_theme','color','$content-color-1',0,''),(616419,194016,'74806','new_theme','font-weight','400',0,''),(616420,194016,'74806','new_theme','padding-top','20',0,''),(616421,194016,'74806','new_theme','padding-bottom','0',0,''),(616422,194016,'74806','new_theme','font-size','12',0,''),(616423,194017,'74807','new_theme','block_type','3',0,''),(616424,194017,'74807','new_theme','font-weight','normal',0,''),(616425,194017,'74807','new_theme','padding-top','20',0,''),(616426,194018,'74808','new_theme','text','<p>If undelivered please return to:</p>',1,''),(616427,194018,'74808','new_theme','font-size','12',0,''),(616428,194018,'74808','new_theme','font-weight','bold',0,''),(616429,194018,'74808','new_theme','text','<p>If undelivered please return to:</p>',0,''),(616430,194019,'74809','new_theme','font-size','12',0,''),(616431,194020,'74810','new_theme','text','<p>Thank you for your order</p>',1,''),(616432,194020,'74810','new_theme','color','$color-8',0,''),(616433,194020,'74810','new_theme','font-size','13',0,''),(616434,194020,'74810','new_theme','font-weight','bold',0,''),(616435,194020,'74810','new_theme','padding-top','5',0,''),(616436,194020,'74810','new_theme','text-align','center',0,''),(616437,194020,'74810','new_theme','text','<p>Thank you for your order</p>',0,''),(616438,194021,'74811','new_theme','font-weight','400',0,''),(616439,194021,'74811','new_theme','text-align','center',0,''),(616440,194021,'74811','new_theme','padding-top','0',0,''),(616441,194021,'74811','new_theme','padding-left','20',0,''),(616442,194021,'74811','new_theme','padding-right','20',0,''),(616443,194022,'74812','new_theme','block_type','6',0,''),(616444,194022,'74812','new_theme','font-weight','normal',0,''),(616445,194022,'74812','new_theme','font-size','16',0,''),(616446,194023,'74813','new_theme','text','<p>Email:</p>',1,''),(616447,194023,'74813','new_theme','font-weight','normal',0,''),(616448,194023,'74813','new_theme','text-align','right',0,''),(616449,194023,'74813','new_theme','font-size','12',0,''),(616450,194023,'74813','new_theme','text','<p>Email:</p>',0,''),(616451,194024,'74814','new_theme','font-weight','normal',0,''),(616452,194024,'74814','new_theme','text-align','right',0,''),(616453,194024,'74814','new_theme','font-size','12',0,''),(616454,194025,'74815','new_theme','text','<p>If something has gone wrong please contact us at:</p>',1,''),(616455,194025,'74815','new_theme','font-size','12',0,''),(616456,194025,'74815','new_theme','font-weight','bold',0,''),(616457,194025,'74815','new_theme','text-align','right',0,''),(616458,194025,'74815','new_theme','text','<p>If something has gone wrong please contact us at:</p>',0,''),(616459,194026,'74816','new_theme','block_type','6',0,''),(616460,194026,'74816','new_theme','font-weight','normal',0,''),(616461,194026,'74816','new_theme','font-size','16',0,''),(616462,194027,'74817','new_theme','text','<p>Phone:</p>',1,''),(616463,194027,'74817','new_theme','font-weight','normal',0,''),(616464,194027,'74817','new_theme','text-align','right',0,''),(616465,194027,'74817','new_theme','font-size','12',0,''),(616466,194027,'74817','new_theme','text','<p>Phone:</p>',0,''),(616467,194028,'74818','new_theme','font-weight','normal',0,''),(616468,194028,'74818','new_theme','text-align','right',0,''),(616469,194028,'74818','new_theme','font-size','12',0,''),(616470,194029,'74819','new_theme','block_type','2',0,''),(616471,194029,'74819','new_theme','font-weight','normal',0,''),(616472,194029,'74819','new_theme','padding-bottom','20',0,''),(616473,194030,'74820','new_theme','font-weight','400',0,''),(616474,194030,'74820','new_theme','padding-top','20',0,''),(616475,194031,'74821','new_theme','block_type','11',0,''),(616476,194031,'74821','new_theme','font-weight','normal',0,''),(616477,194032,'74822','new_theme','text','<p>Phone:</p>',1,''),(616478,194032,'74822','new_theme','font-weight','normal',0,''),(616479,194032,'74822','new_theme','text-align','right',0,''),(616480,194032,'74822','new_theme','text','<p>Phone:</p>',0,''),(616481,194033,'74823','new_theme','font-weight','normal',0,''),(616482,194033,'74823','new_theme','text-align','right',0,''),(616483,194034,'74824','new_theme','block_type','11',0,''),(616484,194034,'74824','new_theme','font-weight','normal',0,''),(616485,194035,'74825','new_theme','text','<p>Web:</p>',1,''),(616486,194035,'74825','new_theme','font-weight','normal',0,''),(616487,194035,'74825','new_theme','text-align','right',0,''),(616488,194035,'74825','new_theme','text','<p>Web:</p>',0,''),(616489,194036,'74826','new_theme','font-weight','normal',0,''),(616490,194036,'74826','new_theme','text-align','right',0,''),(616491,194037,'74827','new_theme','block_type','1',0,''),(616492,194038,'74828','new_theme','font-weight','normal',0,''),(616493,194038,'74828','new_theme','text-align','right',0,''),(616494,194038,'74828','new_theme','padding-bottom','10',0,''),(616495,194038,'74828','new_theme','address_spacer',',',0,''),(616496,194038,'74828','new_theme','font-size','12',0,''),(616497,194039,'74829','new_theme','block_type','11',0,''),(616498,194039,'74829','new_theme','font-weight','normal',0,''),(616499,194040,'74830','new_theme','text','<p>Email:</p>',1,''),(616500,194040,'74830','new_theme','font-weight','normal',0,''),(616501,194040,'74830','new_theme','text-align','right',0,''),(616502,194040,'74830','new_theme','text','<p>Email:</p>',0,''),(616503,194041,'74831','new_theme','font-weight','normal',0,''),(616504,194041,'74831','new_theme','text-align','right',0,''),(616505,194042,'74832','new_theme','block_type','4',0,''),(616506,194042,'74832','new_theme','font-weight','normal',0,''),(616507,194042,'74832','new_theme','border-top-width','1',0,''),(616508,194042,'74832','new_theme','border-top-color','$content-border-1',0,''),(616509,194042,'74832','new_theme','border-left-width','1',0,''),(616510,194042,'74832','new_theme','border-left-color','$content-border-1',0,''),(616511,194042,'74832','new_theme','border-right-width','1',0,''),(616512,194042,'74832','new_theme','border-right-color','$content-border-1',0,''),(616513,194042,'74832','new_theme','border-bottom-width','1',0,''),(616514,194042,'74832','new_theme','border-bottom-color','$content-border-1',0,''),(616515,194043,'74833','new_theme','block_type','2',0,''),(616516,194043,'74833','new_theme','font-weight','normal',0,''),(616517,194043,'74833','new_theme','border-right-width','1',0,''),(616518,194043,'74833','new_theme','border-right-color','$content-border-1',0,''),(616519,194044,'74834','new_theme','block_type','1',0,''),(616520,194044,'74834','new_theme','font-weight','400',0,''),(616521,194044,'74834','new_theme','background-color','$content-bg-2',0,''),(616522,194044,'74834','new_theme','padding-top','10',0,''),(616523,194044,'74834','new_theme','padding-left','10',0,''),(616524,194044,'74834','new_theme','padding-right','10',0,''),(616525,194044,'74834','new_theme','padding-bottom','30',0,''),(616526,194045,'74835','new_theme','font-size','12',0,''),(616527,194046,'74836','new_theme','text','<p>ADDRESS:</p>\n',1,''),(616528,194046,'74836','new_theme','font-size','14',0,''),(616529,194046,'74836','new_theme','font-weight','bold',0,''),(616530,194046,'74836','new_theme','text','<p>ADDRESS:</p>\n',0,''),(616531,194047,'74837','new_theme','block_type','1',0,''),(616532,194047,'74837','new_theme','font-weight','normal',0,''),(616533,194047,'74837','new_theme','padding-top','10',0,''),(616534,194047,'74837','new_theme','padding-left','10',0,''),(616535,194047,'74837','new_theme','padding-right','10',0,''),(616536,194047,'74837','new_theme','padding-bottom','10',0,''),(616537,194049,'74839','new_theme','text','<p>E-MAIL ADDRESS:</p>',1,''),(616538,194049,'74839','new_theme','font-weight','bold',0,''),(616539,194049,'74839','new_theme','font-size','14',0,''),(616540,194049,'74839','new_theme','padding-top','10',0,''),(616541,194049,'74839','new_theme','text','<p>E-MAIL ADDRESS:</p>',0,''),(616542,194050,'74840','new_theme','font-weight','normal',0,''),(616543,194051,'74841','new_theme','font-weight','normal',0,''),(616544,194052,'74842','new_theme','text','<p>PHONE NUMBER:</p>',1,''),(616545,194052,'74842','new_theme','font-size','14',0,''),(616546,194052,'74842','new_theme','font-weight','bold',0,''),(616547,194052,'74842','new_theme','padding-top','10',0,''),(616548,194052,'74842','new_theme','text','<p>PHONE NUMBER:</p>',0,''),(616549,194053,'74843','new_theme','text','<p>CUSTOMER:</p>',1,''),(616550,194053,'74843','new_theme','font-size','13',0,''),(616551,194053,'74843','new_theme','font-weight','bold',0,''),(616552,194053,'74843','new_theme','text','<p>CUSTOMER:</p>',0,''),(616553,194054,'74844','new_theme','font-size','14',0,''),(616554,194054,'74844','new_theme','font-weight','bold',0,''),(616555,194054,'74844','new_theme','text-align','center',0,''),(616556,194054,'74844','new_theme','padding-bottom','10',0,''),(616557,194054,'74844','new_theme','padding-top','10',0,''),(616558,194055,'74845','new_theme','text','<p>Order date:</p>\n',1,''),(616559,194055,'74845','new_theme','font-weight','bold',0,''),(616560,194055,'74845','new_theme','text-align','center',0,''),(616561,194055,'74845','new_theme','font-size','12',0,''),(616562,194055,'74845','new_theme','text','<p>Order date:</p>\n',0,''),(616563,194056,'74846','new_theme','font-weight','normal',0,''),(616564,194056,'74846','new_theme','text-align','center',0,''),(616565,194056,'74846','new_theme','padding-bottom','10',0,''),(616566,194057,'74847','new_theme','block_type','5',0,''),(616567,194057,'74847','new_theme','font-weight','normal',0,''),(616568,194057,'74847','new_theme','border-bottom-width','1',0,''),(616569,194057,'74847','new_theme','border-bottom-color','$content-border-1',0,''),(616570,194057,'74847','new_theme','border-top-width','1',0,''),(616571,194057,'74847','new_theme','border-top-color','$content-border-1',0,''),(616572,194057,'74847','new_theme','border-left-color','$content-border-1',0,''),(616573,194057,'74847','new_theme','border-left-width','1',0,''),(616574,194058,'74848','new_theme','block_type','1',0,''),(616575,194058,'74848','new_theme','font-weight','normal',0,''),(616576,194058,'74848','new_theme','padding-top','10',0,''),(616577,194058,'74848','new_theme','padding-left','10',0,''),(616578,194058,'74848','new_theme','padding-right','10',0,''),(616579,194059,'74849','new_theme','font-weight','400',0,''),(616580,194059,'74849','new_theme','line-height','120',0,''),(616581,194059,'74849','new_theme','line_height_measure','%',0,''),(616582,194059,'74849','new_theme','font-size','12',0,''),(616583,194060,'74850','new_theme','text','<p>SHIPPING ADDRESS:</p>',1,''),(616584,194060,'74850','new_theme','font-size','14',0,''),(616585,194060,'74850','new_theme','font-weight','bold',0,''),(616586,194060,'74850','new_theme','padding-bottom','10',0,''),(616587,194060,'74850','new_theme','text','<p>SHIPPING ADDRESS:</p>',0,''),(616588,194061,'74851','new_theme','block_type','1',0,''),(616589,194062,'74852','new_theme','block_type','6',0,''),(616590,194063,'74853','new_theme','aria_name','account-menu',0,''),(616591,194064,'73374','new_theme','block_type','1',0,''),(616592,194064,'73374','new_theme','padding-top','70',0,''),(616593,194064,'73374','new_theme','padding-right','30',0,''),(616594,194064,'73374','new_theme','padding-bottom','30',0,''),(616595,194064,'73374','new_theme','padding-top','0',0,'8451'),(616596,194064,'73374','new_theme','padding-left','0',0,'8451'),(616597,194064,'73374','new_theme','padding-right','0',0,'8451'),(616598,194064,'73374','new_theme','padding-bottom','0',0,'8451'),(616641,194083,'74854','new_theme','text','<h1>##TEXT_HEADING_QUOTE_CART##</h1>',0,''),(616642,194084,'74855','new_theme','link','Quotation Info',0,''),(616643,194084,'74855','new_theme','margin-bottom','20',0,''),(616644,194085,'74856','new_theme','block_type','1',0,''),(616645,194086,'74857','new_theme','block_type','6',0,''),(616646,194086,'74857','new_theme','schema','6-3',0,'8451'),(616647,194087,'74858','new_theme','aria_name','account-menu',0,''),(616648,194088,'73374','new_theme','block_type','1',0,''),(616649,194088,'73374','new_theme','padding-top','70',0,''),(616650,194088,'73374','new_theme','padding-right','30',0,''),(616651,194088,'73374','new_theme','padding-bottom','30',0,''),(616652,194088,'73374','new_theme','padding-top','0',0,'8451'),(616653,194088,'73374','new_theme','padding-left','0',0,'8451'),(616654,194088,'73374','new_theme','padding-right','0',0,'8451'),(616655,194088,'73374','new_theme','padding-bottom','0',0,'8451'),(616698,194107,'74859','new_theme','block_type','3',0,''),(616699,194108,'74860','new_theme','block_type','1',0,''),(616700,194108,'74860','new_theme','padding-right','20',0,''),(616701,194108,'74860','new_theme','padding-bottom','20',0,''),(616702,194109,'74861','new_theme','orders_data','name',0,''),(616703,194110,'74862','new_theme','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(616704,194111,'74863','new_theme','block_type','1',0,''),(616705,194111,'74863','new_theme','padding-right','20',0,''),(616706,194111,'74863','new_theme','padding-bottom','20',0,''),(616707,194112,'74864','new_theme','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(616708,194113,'74865','new_theme','orders_data','telephone',0,''),(616709,194114,'74866','new_theme','block_type','1',0,''),(616710,194114,'74866','new_theme','padding-right','20',0,''),(616711,194115,'74867','new_theme','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(616712,194116,'74868','new_theme','orders_data','shipping_method',0,''),(616713,194117,'74869','new_theme','block_type','1',0,''),(616714,194117,'74869','new_theme','padding-right','20',0,''),(616715,194117,'74869','new_theme','padding-bottom','20',0,''),(616716,194118,'74870','new_theme','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(616717,194119,'74871','new_theme','orders_data','delivery_address',0,''),(616718,194120,'74872','new_theme','block_type','1',0,''),(616719,194120,'74872','new_theme','padding-bottom','20',0,''),(616720,194121,'74873','new_theme','orders_data','billing_address',0,''),(616721,194122,'74874','new_theme','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(616722,194123,'74875','new_theme','block_type','1',0,''),(616723,194124,'74876','new_theme','orders_data','payment_method',0,''),(616724,194125,'74877','new_theme','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(616725,194126,'74878','new_theme','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(616726,194128,'74880','new_theme','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(616727,194131,'74883','new_theme','block_type','2',0,''),(616728,194131,'74883','new_theme','padding-top','20',0,''),(616729,194131,'74883','new_theme','margin-bottom','20',0,''),(616730,194132,'74884','new_theme','like_button','1',0,''),(616731,194132,'74884','new_theme','text','IMAGE_BUTTON_BACK',0,''),(616732,194132,'74884','new_theme','link','Quotations',0,''),(616733,194133,'74885','new_theme','text','<h1>##HEADING_TITLE##</h1>',0,''),(616734,194134,'74886','new_theme','padding-top','20',0,''),(616735,194134,'74886','new_theme','padding-bottom','20',0,''),(616736,194134,'74886','new_theme','block_type','1',0,''),(616737,194134,'74886','new_theme','background-color','$content-bg-2',0,''),(616738,194136,'74888','new_theme','block_type','4',0,''),(616739,194137,'74889','new_theme','background-color','$content-bg-1',0,''),(616740,194138,'74890','new_theme','block_type','1',0,''),(616741,194138,'74890','new_theme','style_class','order-summary',0,''),(616742,194138,'74890','new_theme','margin-left','30',0,''),(616743,194139,'74891','new_theme','block_type','1',0,''),(616744,194139,'74891','new_theme','padding-left','20',0,''),(616745,194139,'74891','new_theme','padding-right','20',0,''),(616746,194139,'74891','new_theme','padding-bottom','30',0,''),(616747,194142,'74894','new_theme','block_type','1',0,''),(616748,194143,'74895','new_theme','block_type','6',0,''),(616749,194143,'74895','new_theme','schema','6-3',0,'8451'),(616750,194144,'74896','new_theme','aria_name','account-menu',0,''),(616751,194145,'73374','new_theme','block_type','1',0,''),(616752,194145,'73374','new_theme','padding-top','70',0,''),(616753,194145,'73374','new_theme','padding-right','30',0,''),(616754,194145,'73374','new_theme','padding-bottom','30',0,''),(616755,194145,'73374','new_theme','padding-top','0',0,'8451'),(616756,194145,'73374','new_theme','padding-left','0',0,'8451'),(616757,194145,'73374','new_theme','padding-right','0',0,'8451'),(616758,194145,'73374','new_theme','padding-bottom','0',0,'8451'),(616801,194164,'74897','new_theme','text','<h1>##HEADING_PRODUCTS_REVIEWS_TITLE##</h1>',0,''),(616802,194165,'74898','new_theme','margin-bottom','20',0,''),(616803,194166,'74899','new_theme','block_type','1',0,''),(616804,194168,'74901','new_theme','pagination','bottom',0,''),(616805,194169,'74902','new_theme','width','800',0,''),(616806,194170,'74903','new_theme','block_type','11',0,''),(616807,194170,'74903','new_theme','border-top-width','1',0,''),(616808,194170,'74903','new_theme','border-left-width','1',0,''),(616809,194170,'74903','new_theme','border-right-width','1',0,''),(616810,194170,'74903','new_theme','border-bottom-width','1',0,''),(616811,194170,'74903','new_theme','border-top-color','$content-border-1',0,''),(616812,194170,'74903','new_theme','border-left-color','$content-border-1',0,''),(616813,194170,'74903','new_theme','border-right-color','$content-border-1',0,''),(616814,194170,'74903','new_theme','border-bottom-color','$content-border-1',0,''),(616815,194171,'74904','new_theme','block_type','1',0,''),(616816,194171,'74904','new_theme','border-right-width','1',0,''),(616817,194171,'74904','new_theme','border-right-color','$content-border-1',0,''),(616818,194171,'74904','new_theme','padding-top','10',0,''),(616819,194171,'74904','new_theme','padding-right','10',0,''),(616820,194171,'74904','new_theme','padding-bottom','10',0,''),(616821,194172,'74905','new_theme','block_type','9',0,''),(616822,194173,'74906','new_theme','text','1.',0,''),(616823,194173,'74906','new_theme','font-size','12',0,''),(616824,194173,'74906','new_theme','text-align','right',0,''),(616825,194173,'74906','new_theme','padding-right','5',0,''),(616826,194174,'74907','new_theme','text','Contact ##STORE_NAME## Customer Service at ##STORE_PHONE## to obtain an RMA number.',0,''),(616827,194174,'74907','new_theme','font-size','12',0,''),(616828,194174,'74907','new_theme','padding-bottom','5',0,''),(616829,194175,'74908','new_theme','block_type','9',0,''),(616830,194176,'74909','new_theme','text','4.',0,''),(616831,194176,'74909','new_theme','font-size','12',0,''),(616832,194176,'74909','new_theme','text-align','right',0,''),(616833,194176,'74909','new_theme','margin-right','5',0,''),(616834,194177,'74910','new_theme','text','Our Replacement Department will process your request.',0,''),(616835,194177,'74910','new_theme','font-size','12',0,''),(616836,194177,'74910','new_theme','padding-bottom','5',0,''),(616837,194178,'74911','new_theme','block_type','9',0,''),(616838,194179,'74912','new_theme','text','3.',0,''),(616839,194179,'74912','new_theme','font-size','12',0,''),(616840,194179,'74912','new_theme','text-align','right',0,''),(616841,194179,'74912','new_theme','margin-right','5',0,''),(616842,194180,'74913','new_theme','text','Return the authorized item(s) per shipping instructions.',0,''),(616843,194180,'74913','new_theme','font-size','12',0,''),(616844,194180,'74913','new_theme','padding-bottom','5',0,''),(616845,194181,'74914','new_theme','block_type','9',0,''),(616846,194182,'74915','new_theme','text','2.',0,''),(616847,194182,'74915','new_theme','font-size','12',0,''),(616848,194182,'74915','new_theme','text-align','right',0,''),(616849,194182,'74915','new_theme','margin-right','5',0,''),(616850,194183,'74916','new_theme','text','Fill out the Return Material Authorization Form in its entirety place the RMA Form in the box with the item(s) being returned.',0,''),(616851,194183,'74916','new_theme','font-size','12',0,''),(616852,194183,'74916','new_theme','padding-bottom','5',0,''),(616853,194184,'74917','new_theme','block_type','1',0,''),(616854,194184,'74917','new_theme','padding-left','15',0,''),(616855,194185,'74918','new_theme','text','Replacement Policy:',0,''),(616856,194185,'74918','new_theme','font-size','14',0,''),(616857,194185,'74918','new_theme','padding-bottom','5',0,''),(616858,194185,'74918','new_theme','font-weight','bold',0,''),(616859,194186,'74919','new_theme','text','Products purchased through ##STORE_NAME## and under warranty* may be returned for replacement by following these steps:',0,''),(616860,194186,'74919','new_theme','font-size','11',0,''),(616861,194186,'74919','new_theme','font-style','italic',0,''),(616862,194186,'74919','new_theme','padding-bottom','5',0,''),(616863,194187,'74920','new_theme','block_type','1',0,''),(616864,194187,'74920','new_theme','border-bottom-width','1',0,''),(616865,194187,'74920','new_theme','border-bottom-color','$content-border-1',0,''),(616866,194188,'74921','new_theme','text','Return Material Authorization (RMA) Form',0,''),(616867,194188,'74921','new_theme','text-align','center',0,''),(616868,194188,'74921','new_theme','font-size','16',0,''),(616869,194188,'74921','new_theme','font-weight','bold',0,''),(616870,194189,'74922','new_theme','text-align','center',0,''),(616871,194189,'74922','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',1,''),(616872,194189,'74922','new_theme','padding-top','10',0,''),(616873,194189,'74922','new_theme','padding-bottom','10',0,''),(616874,194189,'74922','new_theme','logo','themes/new_theme/img/themes/basic/img/oscommerce_logo.png',0,''),(616875,194190,'74923','new_theme','block_type','1',0,''),(616876,194190,'74923','new_theme','padding-top','10',0,''),(616877,194190,'74923','new_theme','padding-left','10',0,''),(616878,194190,'74923','new_theme','padding-right','10',0,''),(616879,194190,'74923','new_theme','padding-bottom','20',0,''),(616880,194191,'74924','new_theme','block_type','2',0,''),(616881,194191,'74924','new_theme','padding-top','5',0,''),(616882,194192,'74925','new_theme','block_type','11',0,''),(616883,194193,'74926','new_theme','text','Email:',0,''),(616884,194193,'74926','new_theme','font-size','12',0,''),(616885,194194,'74927','new_theme','data','rrDelivery_email_address',0,''),(616886,194194,'74927','new_theme','font-size','12',0,''),(616887,194195,'74928','new_theme','block_type','11',0,''),(616888,194196,'74929','new_theme','text','Phone:',0,''),(616889,194196,'74929','new_theme','font-size','12',0,''),(616890,194197,'74930','new_theme','data','rrDelivery_telephone',0,''),(616891,194197,'74930','new_theme','font-size','12',0,''),(616892,194198,'74931','new_theme','block_type','2',0,''),(616893,194198,'74931','new_theme','padding-top','5',0,''),(616894,194199,'74932','new_theme','block_type','11',0,''),(616895,194200,'74933','new_theme','text','Country:',0,''),(616896,194200,'74933','new_theme','font-size','12',0,''),(616897,194201,'74934','new_theme','data','rrDelivery_country',0,''),(616898,194201,'74934','new_theme','font-size','12',0,''),(616899,194202,'74935','new_theme','block_type','11',0,''),(616900,194203,'74936','new_theme','text','Postcode:',0,''),(616901,194203,'74936','new_theme','font-size','12',0,''),(616902,194204,'74937','new_theme','data','rrDelivery_postcode',0,''),(616903,194204,'74937','new_theme','font-size','12',0,''),(616904,194205,'74938','new_theme','block_type','2',0,''),(616905,194205,'74938','new_theme','padding-top','5',0,''),(616906,194206,'74939','new_theme','block_type','11',0,''),(616907,194207,'74940','new_theme','text','City:',0,''),(616908,194207,'74940','new_theme','font-size','12',0,''),(616909,194208,'74941','new_theme','data','rrDelivery_city',0,''),(616910,194208,'74941','new_theme','font-size','12',0,''),(616911,194209,'74942','new_theme','block_type','11',0,''),(616912,194210,'74943','new_theme','text','State:',0,''),(616913,194210,'74943','new_theme','font-size','12',0,''),(616914,194211,'74944','new_theme','data','rrDelivery_state',0,''),(616915,194211,'74944','new_theme','font-size','12',0,''),(616916,194212,'74945','new_theme','block_type','9',0,''),(616917,194212,'74945','new_theme','padding-top','5',0,''),(616918,194213,'74946','new_theme','text','Address:',0,''),(616919,194213,'74946','new_theme','font-size','12',0,''),(616920,194214,'74947','new_theme','data','rrDelivery_street_address',0,''),(616921,194214,'74947','new_theme','font-size','12',0,''),(616922,194215,'74948','new_theme','block_type','2',0,''),(616923,194216,'74949','new_theme','block_type','11',0,''),(616924,194217,'74950','new_theme','text','Company:',0,''),(616925,194217,'74950','new_theme','font-size','12',0,''),(616926,194218,'74951','new_theme','data','rrDelivery_company',0,''),(616927,194218,'74951','new_theme','font-size','12',0,''),(616928,194219,'74952','new_theme','block_type','2',0,''),(616929,194220,'74953','new_theme','text','Contact Name:',0,''),(616930,194220,'74953','new_theme','font-size','12',0,''),(616931,194221,'74954','new_theme','data','rrDelivery_name',0,''),(616932,194221,'74954','new_theme','font-size','12',0,''),(616933,194222,'74955','new_theme','block_type','2',0,''),(616934,194222,'74955','new_theme','padding-left','10',0,''),(616935,194222,'74955','new_theme','padding-top','20',0,''),(616936,194222,'74955','new_theme','padding-right','10',0,''),(616937,194223,'74956','new_theme','block_type','5',0,''),(616938,194224,'74957','new_theme','text','RMA No:',0,''),(616939,194224,'74957','new_theme','font-size','12',0,''),(616940,194224,'74957','new_theme','font-weight','bold',0,''),(616941,194225,'74958','new_theme','data','rrNumber',0,''),(616942,194225,'74958','new_theme','font-size','12',0,''),(616943,194225,'74958','new_theme','font-weight','bold',0,''),(616944,194226,'74959','new_theme','block_type','2',0,''),(616945,194227,'74960','new_theme','text','Date Issued:',0,''),(616946,194227,'74960','new_theme','font-size','12',0,''),(616947,194227,'74960','new_theme','font-weight','bold',0,''),(616948,194228,'74961','new_theme','data','rrDateCreate',0,''),(616949,194228,'74961','new_theme','font-size','12',0,''),(616950,194228,'74961','new_theme','font-weight','bold',0,''),(616951,194229,'74962','new_theme','block_type','1',0,''),(616952,194230,'74963','new_theme','text','*Under Warranty (Must provide original order number and date in order to verify warranty coverage).',0,''),(616953,194230,'74963','new_theme','font-size','12',0,''),(616954,194230,'74963','new_theme','font-style','italic',0,''),(616955,194230,'74963','new_theme','padding-bottom','20',0,''),(616956,194232,'74965','new_theme','block_type','1',0,''),(616957,194232,'74965','new_theme','border-top-width','1',0,''),(616958,194232,'74965','new_theme','border-left-width','1',0,''),(616959,194232,'74965','new_theme','border-right-width','1',0,''),(616960,194232,'74965','new_theme','border-bottom-width','1',0,''),(616961,194232,'74965','new_theme','border-top-color','$content-border-1',0,''),(616962,194232,'74965','new_theme','border-left-color','$content-border-1',0,''),(616963,194232,'74965','new_theme','border-right-color','$content-border-1',0,''),(616964,194232,'74965','new_theme','border-bottom-color','$content-border-1',0,''),(616965,194233,'74966','new_theme','block_type','11',0,''),(616966,194234,'74967','new_theme','block_type','1',0,''),(616967,194234,'74967','new_theme','padding-top','10',0,''),(616968,194234,'74967','new_theme','padding-right','10',0,''),(616969,194234,'74967','new_theme','padding-bottom','10',0,''),(616970,194234,'74967','new_theme','border-right-width','1',0,''),(616971,194234,'74967','new_theme','border-right-color','$content-border-1',0,''),(616972,194235,'74968','new_theme','block_type','9',0,''),(616973,194236,'74969','new_theme','text','4.',0,''),(616974,194236,'74969','new_theme','font-size','12',0,''),(616975,194236,'74969','new_theme','text-align','right',0,''),(616976,194236,'74969','new_theme','padding-right','5',0,''),(616977,194237,'74970','new_theme','font-size','11',0,''),(616978,194237,'74970','new_theme','font-style','italic',0,''),(616979,194237,'74970','new_theme','padding-bottom','5',0,''),(616980,194238,'74971','new_theme','text','Ship returned items to:',0,''),(616981,194238,'74971','new_theme','font-size','12',0,''),(616982,194238,'74971','new_theme','padding-bottom','5',0,''),(616983,194239,'74972','new_theme','block_type','9',0,''),(616984,194240,'74973','new_theme','text','3.',0,''),(616985,194240,'74973','new_theme','font-size','12',0,''),(616986,194240,'74973','new_theme','text-align','right',0,''),(616987,194240,'74973','new_theme','padding-right','5',0,''),(616988,194241,'74974','new_theme','text','Ship only the items that are authorized.',0,''),(616989,194241,'74974','new_theme','font-size','12',0,''),(616990,194241,'74974','new_theme','padding-bottom','10',0,''),(616991,194242,'74975','new_theme','block_type','9',0,''),(616992,194243,'74976','new_theme','text','1.',0,''),(616993,194243,'74976','new_theme','font-size','12',0,''),(616994,194243,'74976','new_theme','text-align','right',0,''),(616995,194243,'74976','new_theme','padding-right','5',0,''),(616996,194244,'74977','new_theme','text','The bottom of the original packing slip contains ##STORE_NAME## returns address. Use this portion of the form to affix to the box(s).',0,''),(616997,194244,'74977','new_theme','font-size','12',0,''),(616998,194244,'74977','new_theme','padding-bottom','10',0,''),(616999,194245,'74978','new_theme','block_type','1',0,''),(617000,194246,'74979','new_theme','text','Shipping Instructions:',0,''),(617001,194246,'74979','new_theme','font-weight','bold',0,''),(617002,194246,'74979','new_theme','font-size','14',0,''),(617003,194246,'74979','new_theme','padding-bottom','5',0,''),(617004,194246,'74979','new_theme','padding-left','10',0,''),(617005,194247,'74980','new_theme','block_type','9',0,''),(617006,194248,'74981','new_theme','text','2.',0,''),(617007,194248,'74981','new_theme','font-size','12',0,''),(617008,194248,'74981','new_theme','text-align','right',0,''),(617009,194248,'74981','new_theme','padding-right','5',0,''),(617010,194249,'74982','new_theme','text','Be sure to obtain an RMA number and clearly mark the outside of the box(s) with this number.',0,''),(617011,194249,'74982','new_theme','font-size','12',0,''),(617012,194249,'74982','new_theme','padding-bottom','10',0,''),(617013,194250,'74983','new_theme','block_type','1',0,''),(617014,194250,'74983','new_theme','padding-left','10',0,''),(617015,194250,'74983','new_theme','padding-right','10',0,''),(617016,194250,'74983','new_theme','padding-bottom','10',0,''),(617017,194251,'74984','new_theme','text','Shipments received by ##STORE_NAME## without an RMA number will be refused.',0,''),(617018,194251,'74984','new_theme','font-size','11',0,''),(617019,194251,'74984','new_theme','font-style','italic',0,''),(617020,194252,'74985','new_theme','block_type','1',0,''),(617021,194252,'74985','new_theme','padding-top','10',0,''),(617022,194252,'74985','new_theme','padding-left','40',0,''),(617023,194252,'74985','new_theme','padding-right','40',0,''),(617024,194252,'74985','new_theme','padding-bottom','10',0,''),(617025,194253,'74986','new_theme','block_type','1',0,''),(617026,194253,'74986','new_theme','padding-top','10',0,''),(617027,194253,'74986','new_theme','padding-left','10',0,''),(617028,194253,'74986','new_theme','padding-right','10',0,''),(617029,194253,'74986','new_theme','padding-bottom','10',0,''),(617030,194253,'74986','new_theme','border-top-width','1',0,''),(617031,194253,'74986','new_theme','border-left-width','1',0,''),(617032,194253,'74986','new_theme','border-right-width','1',0,''),(617033,194253,'74986','new_theme','border-bottom-width','1',0,''),(617034,194253,'74986','new_theme','border-top-color','$content-border-1',0,''),(617035,194253,'74986','new_theme','border-left-color','$content-border-1',0,''),(617036,194253,'74986','new_theme','border-right-color','$content-border-1',0,''),(617037,194253,'74986','new_theme','border-bottom-color','$content-border-1',0,''),(617038,194254,'74987','new_theme','block_type','3',0,''),(617039,194255,'74988','new_theme','data','rrDelivery_name',0,''),(617040,194255,'74988','new_theme','font-size','9',0,''),(617041,194256,'74989','new_theme','block_type','2',0,''),(617042,194257,'74990','new_theme','text','RMA#:',0,''),(617043,194257,'74990','new_theme','font-size','10',0,''),(617044,194258,'74991','new_theme','data','rrNumber',0,''),(617045,194258,'74991','new_theme','font-size','9',0,''),(617046,194259,'74992','new_theme','block_type','5',0,''),(617047,194260,'74993','new_theme','font-size','9',0,''),(617048,194261,'74994','new_theme','block_type','1',0,''),(617049,194261,'74994','new_theme','padding-left','10',0,''),(617050,194261,'74994','new_theme','padding-right','10',0,''),(617051,194261,'74994','new_theme','padding-bottom','10',0,''),(617052,194262,'74995','new_theme','text','Use this space for additional Comments:',0,''),(617053,194262,'74995','new_theme','font-size','11',0,''),(617054,194262,'74995','new_theme','font-style','italic',0,''),(617055,194263,'74996','new_theme','text','&nbsp;',0,''),(617056,194263,'74996','new_theme','border-bottom-width','1',0,''),(617057,194263,'74996','new_theme','border-bottom-color','$content-border-1',0,''),(617058,194264,'74997','new_theme','text','&nbsp;',0,''),(617059,194264,'74997','new_theme','border-bottom-width','1',0,''),(617060,194264,'74997','new_theme','border-bottom-color','$content-border-1',0,''),(617061,194264,'74997','new_theme','padding-top','5',0,''),(617062,194265,'74998','new_theme','text','&nbsp;',0,''),(617063,194265,'74998','new_theme','border-bottom-width','1',0,''),(617064,194265,'74998','new_theme','border-bottom-color','$content-border-1',0,''),(617065,194265,'74998','new_theme','padding-top','5',0,''),(617066,194266,'74999','new_theme','text','&nbsp;',0,''),(617067,194266,'74999','new_theme','border-bottom-width','1',0,''),(617068,194266,'74999','new_theme','border-bottom-color','$content-border-1',0,''),(617069,194266,'74999','new_theme','padding-top','5',0,''),(617070,194267,'75000','new_theme','block_type','3',0,''),(617071,194267,'75000','new_theme','padding-top','10',0,''),(617072,194267,'75000','new_theme','padding-bottom','10',0,''),(617073,194267,'75000','new_theme','padding-right','10',0,''),(617074,194268,'75001','new_theme','font-size','11',0,''),(617075,194268,'75001','new_theme','font-weight','bold',0,''),(617076,194268,'75001','new_theme','text','Return Approval:',0,''),(617077,194268,'75001','new_theme','padding-top','5',0,''),(617078,194268,'75001','new_theme','padding-left','10',0,''),(617079,194269,'75002','new_theme','border-bottom-width','1',0,''),(617080,194269,'75002','new_theme','border-bottom-color','$content-border-1',0,''),(617081,194269,'75002','new_theme','text','&nbsp;',0,''),(617082,194270,'75003','new_theme','block_type','5',0,''),(617083,194271,'75004','new_theme','text','Date:',0,''),(617084,194271,'75004','new_theme','padding-top','5',0,''),(617085,194271,'75004','new_theme','font-size','11',0,''),(617086,194271,'75004','new_theme','font-weight','bold',0,''),(617087,194271,'75004','new_theme','padding-left','5',0,''),(617088,194272,'75005','new_theme','text','&nbsp;',0,''),(617089,194272,'75005','new_theme','border-bottom-width','1',0,''),(617090,194272,'75005','new_theme','border-bottom-color','$content-border-1',0,''),(617091,194273,'75006','new_theme','block_type','3',0,''),(617092,194273,'75006','new_theme','padding-right','10',0,''),(617093,194274,'75007','new_theme','text','Customer Signature:',0,''),(617094,194274,'75007','new_theme','font-weight','bold',0,''),(617095,194274,'75007','new_theme','font-size','11',0,''),(617096,194274,'75007','new_theme','padding-top','5',0,''),(617097,194274,'75007','new_theme','padding-left','10',0,''),(617098,194275,'75008','new_theme','text','&nbsp;',0,''),(617099,194275,'75008','new_theme','border-bottom-width','1',0,''),(617100,194275,'75008','new_theme','border-bottom-color','$content-border-1',0,''),(617101,194276,'75009','new_theme','block_type','5',0,''),(617102,194277,'75010','new_theme','text','Date:',0,''),(617103,194277,'75010','new_theme','padding-top','5',0,''),(617104,194277,'75010','new_theme','font-size','11',0,''),(617105,194277,'75010','new_theme','font-weight','bold',0,''),(617106,194277,'75010','new_theme','padding-left','5',0,''),(617107,194278,'75011','new_theme','text','&nbsp;',0,''),(617108,194278,'75011','new_theme','border-bottom-width','1',0,''),(617109,194278,'75011','new_theme','border-bottom-color','$content-border-1',0,''),(617110,194279,'75012','new_theme','block_type','1',0,''),(617111,194279,'75012','new_theme','style_class','item-holder',0,''),(617112,194279,'75012','new_theme','padding-top','25',0,''),(617113,194279,'75012','new_theme','padding-bottom','25',0,''),(617114,194279,'75012','new_theme','text-align','left',0,''),(617115,194279,'75012','new_theme','border-top-width','1',0,''),(617116,194279,'75012','new_theme','border-top-color','$content-border-1',0,''),(617117,194280,'75013','new_theme','block_type','7',0,''),(617118,194280,'75013','new_theme','schema','7-2',0,'8451'),(617119,194281,'75014','new_theme','block_type','5',0,''),(617120,194281,'75014','new_theme','schema','5-2',0,'8451'),(617121,194282,'75015','new_theme','clear','none',0,''),(617122,194282,'75015','new_theme','padding-right','20',0,''),(617123,194283,'75016','new_theme','padding-right','20',0,''),(617124,194283,'75016','new_theme','max-width','300',0,'8451'),(617125,194283,'75016','new_theme','margin_left_measure','auto',0,'8451'),(617126,194283,'75016','new_theme','margin_right_measure','auto',0,'8451'),(617127,194284,'75017','new_theme','block_type','1',0,''),(617128,194285,'75018','new_theme','text-align','right',0,''),(617129,194285,'75018','new_theme','margin-top','4',0,''),(617130,194285,'75018','new_theme','margin-bottom','7',0,''),(617131,194285,'75018','new_theme','float','left',0,''),(617132,194286,'75019','new_theme','padding-top','6',0,''),(617133,194286,'75019','new_theme','padding-left','5',0,''),(617134,194286,'75019','new_theme','float','left',0,''),(617135,194286,'75019','new_theme','clear','none',0,''),(617136,194287,'75020','new_theme','padding-right','20',0,''),(617137,194288,'75021','new_theme','description_characters','200',0,''),(617138,194288,'75021','new_theme','clear','none',0,''),(617139,194288,'75021','new_theme','padding-right','20',0,''),(617140,194289,'75022','new_theme','clear','none',0,''),(617141,194290,'75023','new_theme','margin-bottom','20',0,''),(617142,194291,'75024','new_theme','block_type','1',0,''),(617143,194291,'75024','new_theme','padding-left','40',0,''),(617144,194291,'75024','new_theme','style_class','right-aria',0,''),(617145,194291,'75024','new_theme','padding-left','0',0,'8451'),(617146,194292,'75025','new_theme','margin-bottom','15',0,''),(617147,194292,'75025','new_theme','text-align','right',0,''),(617148,194293,'75026','new_theme','margin-bottom','10',0,''),(617149,194293,'75026','new_theme','text-align','right',0,''),(617150,194294,'75027','new_theme','margin-bottom','10',0,''),(617151,194295,'75028','new_theme','text-align','right',0,''),(617152,194295,'75028','new_theme','margin-bottom','15',0,''),(617153,194296,'75030','new_theme','text-align','right',0,''),(617154,194296,'75030','new_theme','margin-bottom','10',0,''),(617155,194297,'75031','new_theme','block_type','1',0,''),(617156,194297,'75031','new_theme','padding-top','20',0,''),(617157,194297,'75031','new_theme','padding-bottom','20',0,''),(617158,194297,'75031','new_theme','background-color','$content-bg-2',0,''),(617159,194299,'75033','new_theme','block_type','4',0,''),(617160,194300,'75034','new_theme','padding-bottom','20',0,''),(617161,194300,'75034','new_theme','background-color','$content-bg-1',0,''),(617162,194301,'75035','new_theme','style_class','order-summary',0,''),(617163,194301,'75035','new_theme','padding-left','30',0,''),(617164,194301,'75035','new_theme','block_type','1',0,''),(617165,194302,'75036','new_theme','block_type','1',0,''),(617166,194302,'75036','new_theme','padding-left','20',0,''),(617167,194302,'75036','new_theme','padding-right','20',0,''),(617168,194302,'75036','new_theme','padding-bottom','20',0,''),(617169,194302,'75036','new_theme','padding-top','20',0,''),(617170,194303,'75037','new_theme','margin-bottom','40',0,''),(617171,194304,'75038','new_theme','block_type','1',0,''),(617172,194304,'75038','new_theme','style_class','account-samples',0,''),(617173,194305,'75039','new_theme','block_type','6',0,''),(617174,194305,'75039','new_theme','schema','6-3',0,'8451'),(617175,194306,'75040','new_theme','aria_name','account-menu',0,''),(617176,194307,'73374','new_theme','block_type','1',0,''),(617177,194307,'73374','new_theme','padding-top','70',0,''),(617178,194307,'73374','new_theme','padding-right','30',0,''),(617179,194307,'73374','new_theme','padding-bottom','30',0,''),(617180,194307,'73374','new_theme','padding-top','0',0,'8451'),(617181,194307,'73374','new_theme','padding-left','0',0,'8451'),(617182,194307,'73374','new_theme','padding-right','0',0,'8451'),(617183,194307,'73374','new_theme','padding-bottom','0',0,'8451'),(617226,194326,'75041','new_theme','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(617227,194327,'75042','new_theme','show_pagenation','1',0,''),(617228,194327,'75042','new_theme','link','Sample Info',0,''),(617229,194327,'75042','new_theme','margin-bottom','20',0,''),(617230,194328,'75043','new_theme','block_type','1',0,''),(617231,194328,'75043','new_theme','style_class','account-sample-info',0,''),(617232,194329,'75044','new_theme','block_type','6',0,''),(617233,194330,'75045','new_theme','aria_name','account-menu',0,''),(617234,194331,'73374','new_theme','block_type','1',0,''),(617235,194331,'73374','new_theme','padding-top','70',0,''),(617236,194331,'73374','new_theme','padding-right','30',0,''),(617237,194331,'73374','new_theme','padding-bottom','30',0,''),(617238,194331,'73374','new_theme','padding-top','0',0,'8451'),(617239,194331,'73374','new_theme','padding-left','0',0,'8451'),(617240,194331,'73374','new_theme','padding-right','0',0,'8451'),(617241,194331,'73374','new_theme','padding-bottom','0',0,'8451'),(617284,194350,'75046','new_theme','text','<h1>##TEXT_HEADING_SAMPLE_CART##</h1>',0,''),(617285,194351,'75047','new_theme','block_type','2',0,''),(617286,194351,'75047','new_theme','padding-top','20',0,''),(617287,194351,'75047','new_theme','margin-bottom','20',0,''),(617288,194352,'75048','new_theme','like_button','1',0,''),(617289,194352,'75048','new_theme','text','IMAGE_BUTTON_BACK',0,''),(617290,194352,'75048','new_theme','link','Samples',0,''),(617291,194354,'75050','new_theme','text','<div class=\"heading-4\">##HEADING_PRODUCT_DETAILS##</div>',0,''),(617292,194357,'75053','new_theme','text','<div class=\"heading-4\">##HEADING_ORDER_HISTORY##</div>',0,''),(617293,194358,'75054','new_theme','block_type','3',0,''),(617294,194359,'75055','new_theme','block_type','1',0,''),(617295,194359,'75055','new_theme','padding-right','20',0,''),(617296,194359,'75055','new_theme','padding-bottom','20',0,''),(617297,194360,'75056','new_theme','text','<div class=\"heading-4\">##ENTRY_TELEPHONE_NUMBER##</div>',0,''),(617298,194361,'75057','new_theme','orders_data','telephone',0,''),(617299,194362,'75058','new_theme','block_type','1',0,''),(617300,194362,'75058','new_theme','padding-right','20',0,''),(617301,194362,'75058','new_theme','padding-bottom','20',0,''),(617302,194363,'75059','new_theme','orders_data','name',0,''),(617303,194364,'75060','new_theme','text','<div class=\"heading-4\">##TEXT_NAME##</div>',0,''),(617304,194365,'75061','new_theme','block_type','1',0,''),(617305,194365,'75061','new_theme','padding-right','20',0,''),(617306,194366,'75062','new_theme','orders_data','shipping_method',0,''),(617307,194367,'75063','new_theme','text','<div class=\"heading-4\">##HEADING_SHIPPING_METHOD##</div>',0,''),(617308,194368,'75064','new_theme','block_type','1',0,''),(617309,194368,'75064','new_theme','padding-right','20',0,''),(617310,194368,'75064','new_theme','padding-bottom','20',0,''),(617311,194369,'75065','new_theme','orders_data','delivery_address',0,''),(617312,194370,'75066','new_theme','text','<div class=\"heading-4\">##HEADING_DELIVERY_ADDRESS##</div>',0,''),(617313,194371,'75067','new_theme','block_type','1',0,''),(617314,194372,'75068','new_theme','orders_data','payment_method',0,''),(617315,194373,'75069','new_theme','text','<div class=\"heading-4\">##HEADING_PAYMENT_METHOD##</div>',0,''),(617316,194374,'75070','new_theme','block_type','1',0,''),(617317,194374,'75070','new_theme','padding-bottom','20',0,''),(617318,194375,'75071','new_theme','orders_data','billing_address',0,''),(617319,194376,'75072','new_theme','text','<div class=\"heading-4\">##BILLING_ADDRESS##</div>',0,''),(617320,194377,'75073','new_theme','block_type','1',0,''),(617321,194378,'75074','new_theme','text','<h1>##TEXT_SITE_MAP_TITLE##</h1>',0,''),(617322,194379,'75075','new_theme','block_type','6',0,''),(617323,194380,'75076','new_theme','text','<div class=\"heading-4\">##TEXT_SITE_MAP_PAGES_GROUP##</div>',0,''),(617324,194381,'75077','new_theme','text','<div class=\"heading-4\">##TEXT_MY_ACCOUNT_INFORMATION_GROUP##</div>',0,''),(617325,194382,'75078','new_theme','text','<div class=\"heading-4\">Categories</div>',0,''),(617326,194385,'75081','new_theme','class','menu-simple',0,''),(617327,194387,'75083','new_theme','text','<div class=\"heading-4\">##TEXT_SITE_MAP_DELIVERY_LOCATION##</div>',0,''),(617328,194388,'75084','new_theme','block_type','1',0,''),(617329,194389,'75085','new_theme','text','<div class=\"heading-2\">##TEXT_UNSUBSCRIBE##</div>',0,''),(617330,194389,'75085','new_theme','style_class','middle-form',0,''),(617331,194390,'75086','new_theme','style_class','middle-form',0,''),(617332,194391,'75087','new_theme','text','<h1>##TEXT_KEEP_UPTODATE_VIA_EMAIL##</h1>',0,''),(617333,194392,'75088','new_theme','style_class','middle-form',0,''),(617334,194392,'75088','new_theme','margin-bottom','30',0,''),(617335,194393,'75089','new_theme','block_type','1',0,''),(617336,194394,'75090','new_theme','text','##TEXT_SUCCESSFULLY_SUBSCRIBED##',0,''),(617337,194394,'75090','new_theme','padding-top','100',0,''),(617338,194394,'75090','new_theme','margin-bottom','100',0,''),(617339,194394,'75090','new_theme','text-align','center',0,''),(617340,194394,'75090','new_theme','font-size','20',0,''),(617341,194395,'94795','new_theme','block_type','1',0,''),(617342,194396,'94796','new_theme','block_type','6',0,''),(617343,194396,'94796','new_theme','schema','6-3',0,'8451'),(617344,194397,'94797','new_theme','aria_name','account-menu',0,''),(617345,194398,'73374','new_theme','block_type','1',0,''),(617346,194398,'73374','new_theme','padding-top','70',0,''),(617347,194398,'73374','new_theme','padding-right','30',0,''),(617348,194398,'73374','new_theme','padding-bottom','30',0,''),(617349,194398,'73374','new_theme','padding-top','0',0,'8451'),(617350,194398,'73374','new_theme','padding-left','0',0,'8451'),(617351,194398,'73374','new_theme','padding-right','0',0,'8451'),(617352,194398,'73374','new_theme','padding-bottom','0',0,'8451'),(617395,194417,'94798','new_theme','text','<h1>##TEXT_SUBSCRIPTION##</h1>',0,''),(617396,194418,'94799','new_theme','text','##SUBSCRIPTION_TEXT##',0,''),(617397,194420,'1694099590.22143','new_theme','block_type','1',0,''),(617398,194420,'1694099590.22143','new_theme','background-color','$content-bg-2',0,''),(617399,194420,'1694099590.22143','new_theme','padding-bottom','30',0,''),(617400,194420,'1694099590.22143','new_theme','style_class','success-page',0,''),(617401,194420,'1694099590.22143','new_theme','color','$content-color-2',0,''),(617402,194421,'1694099590.340695','new_theme','block_type','12',0,''),(617403,194421,'1694099590.340695','new_theme','schema','4-2',0,'8451'),(617404,194422,'1694099590.343733','new_theme','block_type','1',0,''),(617405,194422,'1694099590.343733','new_theme','padding-right','40',0,''),(617406,194422,'1694099590.343733','new_theme','padding-right','0',0,'8451'),(617407,194423,'1694099590.345212','new_theme','block_type','2',0,''),(617408,194423,'1694099590.345212','new_theme','margin-bottom','20',0,''),(617409,194423,'1694099590.345212','new_theme','schema','2-2',0,'8444'),(617410,194423,'1694099590.345212','new_theme','background-color','$content-bg-1',0,''),(617411,194423,'1694099590.345212','new_theme','color','$content-color-1',0,''),(617412,194424,'1694099590.34749','new_theme','block_type','1',0,''),(617413,194424,'1694099590.34749','new_theme','border-right-width','20',0,''),(617414,194424,'1694099590.34749','new_theme','border-right-color','$content-bg-2',0,''),(617415,194424,'1694099590.34749','new_theme','margin-right','-10',0,''),(617416,194424,'1694099590.34749','new_theme','padding-right','30',0,''),(617417,194424,'1694099590.34749','new_theme','padding-top','20',0,''),(617418,194424,'1694099590.34749','new_theme','padding-left','30',0,''),(617419,194424,'1694099590.34749','new_theme','padding-bottom','20',0,''),(617420,194424,'1694099590.34749','new_theme','border-right-width','0',0,'8451'),(617421,194424,'1694099590.34749','new_theme','margin-right','0',0,'8451'),(617422,194424,'1694099590.34749','new_theme','margin-bottom','20',0,'8451'),(617423,194424,'1694099590.34749','new_theme','padding-left','20',0,'8451'),(617424,194424,'1694099590.34749','new_theme','padding-right','20',0,'8451'),(617425,194426,'1694099590.351567','new_theme','margin-bottom','20',0,''),(617426,194427,'1694099590.35337','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(617427,194427,'1694099590.35337','new_theme','padding-top','20',0,''),(617428,194428,'1694099590.360420','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(617429,194428,'1694099590.360420','new_theme','clear','none',0,''),(617430,194429,'1694099590.362714','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(617431,194431,'1694099590.365625','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(617432,194431,'1694099590.365625','new_theme','clear','none',0,''),(617433,194432,'1694099590.367789','new_theme','block_type','1',0,''),(617434,194432,'1694099590.367789','new_theme','padding-left','30',0,''),(617435,194432,'1694099590.367789','new_theme','border-left-width','20',0,''),(617436,194432,'1694099590.367789','new_theme','border-left-color','$content-bg-2',0,''),(617437,194432,'1694099590.367789','new_theme','margin-left','-10',0,''),(617438,194432,'1694099590.367789','new_theme','padding-right','30',0,''),(617439,194432,'1694099590.367789','new_theme','padding-top','20',0,''),(617440,194432,'1694099590.367789','new_theme','padding-bottom','20',0,''),(617441,194432,'1694099590.367789','new_theme','border-left-width','0',0,'8451'),(617442,194434,'1694099590.370690','new_theme','margin-bottom','20',0,''),(617443,194435,'1694099590.371953','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(617444,194435,'1694099590.371953','new_theme','clear','none',0,''),(617445,194436,'1694099590.373633','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(617446,194437,'1694099590.37590','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(617447,194437,'1694099590.37590','new_theme','clear','none',0,''),(617448,194438,'1694099590.376747','new_theme','text','<div class=\"page-success\">\n\n<div class=\"text-2\">##WEVE_RECEIVED_ORDER##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_ORDER_STATUS##</div>\n</div>',0,''),(617449,194438,'1694099590.376747','new_theme','background-color','$content-bg-1',0,''),(617450,194438,'1694099590.376747','new_theme','margin-bottom','30',0,''),(617451,194438,'1694099590.376747','new_theme','padding-top','30',0,''),(617452,194438,'1694099590.376747','new_theme','padding-bottom','30',0,''),(617453,194438,'1694099590.376747','new_theme','padding-left','30',0,''),(617454,194438,'1694099590.376747','new_theme','padding-right','30',0,''),(617455,194438,'1694099590.376747','new_theme','color','$content-color-1',0,''),(617456,194439,'1694099590.38020','new_theme','block_type','1',0,''),(617457,194439,'1694099590.38020','new_theme','style_class','order-summary2 hiding-box',0,''),(617458,194440,'1694099590.381373','new_theme','text-align','center',0,''),(617459,194440,'1694099590.381373','new_theme','margin-bottom','20',0,''),(617460,194441,'1694099590.382864','new_theme','text-align','center',0,''),(617461,194444,'1694099590.386683','new_theme','block_type','12',0,''),(617462,194445,'1694099590.387673','new_theme','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n</div>\n',0,''),(617463,194445,'1694099590.387673','new_theme','margin-bottom','20',0,''),(617464,194446,'1694099590.389337','new_theme','text-align','center',0,''),(617465,194446,'1694099590.389337','new_theme','padding-top','40',0,''),(617466,194447,'75097','new_theme','block_type','1',0,''),(617467,194448,'75098','new_theme','block_type','1',0,''),(617468,194448,'75098','new_theme','font-weight','normal',0,''),(617469,194449,'75099','new_theme','block_type','1',0,''),(617470,194449,'75099','new_theme','text-align','center',0,''),(617471,194449,'75099','new_theme','padding-top','30',0,''),(617472,194449,'75099','new_theme','margin-bottom','200',0,''),(617473,194450,'75100','new_theme','display','inline-block',0,''),(617474,194450,'75100','new_theme','clear','none',0,''),(617475,194450,'75100','new_theme','margin-left','20',0,''),(617476,194451,'75101','new_theme','display','inline-block',0,''),(617477,194452,'75102','new_theme','text','<div class=\"page-success\">\n<div class=\"text-1\">##THANK_YOU##</div>\n\n<div class=\"text-2\">##WEVE_RECEIVED_QUOTE##</div>\n \n<div class=\"text-3\">##WELL_SEND_YOU_QUOTE_STATUS##</div>\n</div>\n ',0,''),(617478,194453,'75107','new_theme','width','680',0,''),(617479,194453,'75107','new_theme','font-weight','normal',0,''),(617480,194453,'75107','new_theme','font-size','12',0,''),(617481,194453,'75107','new_theme','padding-top','20',0,''),(617482,194453,'75107','new_theme','padding-bottom','20',0,''),(617483,194453,'75107','new_theme','color','$content-color-1',0,''),(617484,194454,'75108','new_theme','block_type','5',0,''),(617485,194454,'75108','new_theme','font-weight','normal',0,''),(617486,194454,'75108','new_theme','border-bottom-width','1',0,''),(617487,194454,'75108','new_theme','border-bottom-color','$content-border-1',0,''),(617488,194454,'75108','new_theme','border-top-width','1',0,''),(617489,194454,'75108','new_theme','border-top-color','$content-border-1',0,''),(617490,194454,'75108','new_theme','border-left-color','$content-border-1',0,''),(617491,194454,'75108','new_theme','border-left-width','1',0,''),(617492,194455,'75109','new_theme','block_type','1',0,''),(617493,194455,'75109','new_theme','font-weight','normal',0,''),(617494,194455,'75109','new_theme','padding-top','10',0,''),(617495,194455,'75109','new_theme','padding-left','10',0,''),(617496,194455,'75109','new_theme','padding-right','10',0,''),(617497,194456,'75110','new_theme','font-weight','400',0,''),(617498,194456,'75110','new_theme','line-height','120',0,''),(617499,194456,'75110','new_theme','line_height_measure','%',0,''),(617500,194456,'75110','new_theme','font-size','12',0,''),(617501,194457,'75111','new_theme','text','<p>SHIPPING ADDRESS:</p>',1,''),(617502,194457,'75111','new_theme','font-size','14',0,''),(617503,194457,'75111','new_theme','font-weight','bold',0,''),(617504,194457,'75111','new_theme','padding-bottom','10',0,''),(617505,194457,'75111','new_theme','text','<p>SHIPPING ADDRESS:</p>',0,''),(617506,194458,'75112','new_theme','block_type','1',0,''),(617507,194458,'75112','new_theme','background-color','$content-bg-2',0,''),(617508,194458,'75112','new_theme','padding-top','20',0,''),(617509,194458,'75112','new_theme','padding-left','10',0,''),(617510,194458,'75112','new_theme','padding-right','10',0,''),(617511,194458,'75112','new_theme','padding-bottom','20',0,''),(617512,194458,'75112','new_theme','font-size','14',0,''),(617513,194459,'75113','new_theme','font-weight','normal',0,''),(617514,194459,'75113','new_theme','text-align','right',0,''),(617515,194459,'75113','new_theme','font-size','14',0,''),(617516,194459,'75113','new_theme','box_align','3',0,''),(617517,194460,'75114','new_theme','block_type','3',0,''),(617518,194460,'75114','new_theme','font-weight','normal',0,''),(617519,194460,'75114','new_theme','padding-top','20',0,''),(617520,194461,'75115','new_theme','text','<p>If undelivered please return to:</p>',1,''),(617521,194461,'75115','new_theme','font-size','12',0,''),(617522,194461,'75115','new_theme','font-weight','bold',0,''),(617523,194461,'75115','new_theme','text','<p>If undelivered please return to:</p>',0,''),(617524,194462,'75116','new_theme','font-size','12',0,''),(617525,194463,'75117','new_theme','font-weight','400',0,''),(617526,194463,'75117','new_theme','text-align','center',0,''),(617527,194463,'75117','new_theme','padding-top','0',0,''),(617528,194463,'75117','new_theme','padding-left','20',0,''),(617529,194463,'75117','new_theme','padding-right','20',0,''),(617530,194464,'75118','new_theme','text','<p>Thank you for your order</p>',1,''),(617531,194464,'75118','new_theme','color','$color-8',0,''),(617532,194464,'75118','new_theme','font-size','13',0,''),(617533,194464,'75118','new_theme','font-weight','bold',0,''),(617534,194464,'75118','new_theme','padding-top','5',0,''),(617535,194464,'75118','new_theme','text-align','center',0,''),(617536,194464,'75118','new_theme','text','<p>Thank you for your order</p>',0,''),(617537,194465,'75119','new_theme','text','<p>If something has gone wrong please contact us at:</p>',1,''),(617538,194465,'75119','new_theme','font-size','12',0,''),(617539,194465,'75119','new_theme','font-weight','bold',0,''),(617540,194465,'75119','new_theme','text-align','right',0,''),(617541,194465,'75119','new_theme','text','<p>If something has gone wrong please contact us at:</p>',0,''),(617542,194466,'75120','new_theme','block_type','6',0,''),(617543,194466,'75120','new_theme','font-weight','normal',0,''),(617544,194466,'75120','new_theme','font-size','16',0,''),(617545,194467,'75121','new_theme','text','<p>Email:</p>',1,''),(617546,194467,'75121','new_theme','font-weight','normal',0,''),(617547,194467,'75121','new_theme','text-align','right',0,''),(617548,194467,'75121','new_theme','font-size','12',0,''),(617549,194467,'75121','new_theme','text','<p>Email:</p>',0,''),(617550,194468,'75122','new_theme','font-weight','normal',0,''),(617551,194468,'75122','new_theme','text-align','right',0,''),(617552,194468,'75122','new_theme','font-size','12',0,''),(617553,194469,'75123','new_theme','block_type','6',0,''),(617554,194469,'75123','new_theme','font-weight','normal',0,''),(617555,194469,'75123','new_theme','font-size','16',0,''),(617556,194470,'75124','new_theme','text','<p>Phone:</p>',1,''),(617557,194470,'75124','new_theme','font-weight','normal',0,''),(617558,194470,'75124','new_theme','text-align','right',0,''),(617559,194470,'75124','new_theme','font-size','12',0,''),(617560,194470,'75124','new_theme','text','<p>Phone:</p>',0,''),(617561,194471,'75125','new_theme','font-weight','normal',0,''),(617562,194471,'75125','new_theme','text-align','right',0,''),(617563,194471,'75125','new_theme','font-size','12',0,''),(617564,194472,'75126','new_theme','font-weight','400',0,''),(617565,194472,'75126','new_theme','padding-top','20',0,''),(617566,194472,'75126','new_theme','padding-bottom','0',0,''),(617567,194472,'75126','new_theme','font-size','12',0,''),(617568,194473,'75127','new_theme','block_type','2',0,''),(617569,194473,'75127','new_theme','font-weight','normal',0,''),(617570,194473,'75127','new_theme','padding-bottom','20',0,''),(617571,194474,'75128','new_theme','block_type','11',0,''),(617572,194474,'75128','new_theme','font-weight','normal',0,''),(617573,194475,'75129','new_theme','text','<p>Email:</p>',1,''),(617574,194475,'75129','new_theme','font-weight','normal',0,''),(617575,194475,'75129','new_theme','text-align','right',0,''),(617576,194475,'75129','new_theme','text','<p>Email:</p>',0,''),(617577,194476,'75130','new_theme','font-weight','normal',0,''),(617578,194476,'75130','new_theme','text-align','right',0,''),(617579,194477,'75131','new_theme','block_type','11',0,''),(617580,194477,'75131','new_theme','font-weight','normal',0,''),(617581,194478,'75132','new_theme','text','<p>Web:</p>',1,''),(617582,194478,'75132','new_theme','font-weight','normal',0,''),(617583,194478,'75132','new_theme','text-align','right',0,''),(617584,194478,'75132','new_theme','text','<p>Web:</p>',0,''),(617585,194479,'75133','new_theme','font-weight','normal',0,''),(617586,194479,'75133','new_theme','text-align','right',0,''),(617587,194480,'75134','new_theme','block_type','1',0,''),(617588,194481,'75135','new_theme','font-weight','normal',0,''),(617589,194481,'75135','new_theme','text-align','right',0,''),(617590,194481,'75135','new_theme','padding-bottom','10',0,''),(617591,194481,'75135','new_theme','address_spacer',',',0,''),(617592,194481,'75135','new_theme','font-size','12',0,''),(617593,194482,'75136','new_theme','block_type','11',0,''),(617594,194482,'75136','new_theme','font-weight','normal',0,''),(617595,194483,'75137','new_theme','text','<p>Phone:</p>',1,''),(617596,194483,'75137','new_theme','font-weight','normal',0,''),(617597,194483,'75137','new_theme','text-align','right',0,''),(617598,194483,'75137','new_theme','text','<p>Phone:</p>',0,''),(617599,194484,'75138','new_theme','font-weight','normal',0,''),(617600,194484,'75138','new_theme','text-align','right',0,''),(617601,194485,'75139','new_theme','block_type','4',0,''),(617602,194485,'75139','new_theme','font-weight','normal',0,''),(617603,194485,'75139','new_theme','border-top-width','1',0,''),(617604,194485,'75139','new_theme','border-top-color','$content-border-1',0,''),(617605,194485,'75139','new_theme','border-left-width','1',0,''),(617606,194485,'75139','new_theme','border-left-color','$content-border-1',0,''),(617607,194485,'75139','new_theme','border-right-width','1',0,''),(617608,194485,'75139','new_theme','border-right-color','$content-border-1',0,''),(617609,194485,'75139','new_theme','border-bottom-width','1',0,''),(617610,194485,'75139','new_theme','border-bottom-color','$content-border-1',0,''),(617611,194486,'75140','new_theme','block_type','2',0,''),(617612,194486,'75140','new_theme','font-weight','normal',0,''),(617613,194486,'75140','new_theme','border-top-width','1',0,''),(617614,194486,'75140','new_theme','border-top-color','$content-border-1',0,''),(617615,194486,'75140','new_theme','border-right-width','1',0,''),(617616,194486,'75140','new_theme','border-right-color','$content-border-1',0,''),(617617,194487,'75141','new_theme','block_type','1',0,''),(617618,194487,'75141','new_theme','font-weight','normal',0,''),(617619,194487,'75141','new_theme','padding-top','10',0,''),(617620,194487,'75141','new_theme','padding-left','10',0,''),(617621,194487,'75141','new_theme','padding-right','10',0,''),(617622,194487,'75141','new_theme','padding-bottom','10',0,''),(617623,194487,'75141','new_theme','border-right-width','1',0,''),(617624,194487,'75141','new_theme','border-right-color','$content-border-1',0,''),(617625,194488,'75142','new_theme','text','<p>Shipping via</p>',1,''),(617626,194488,'75142','new_theme','font-weight','bold',0,''),(617627,194488,'75142','new_theme','font-size','14',0,''),(617628,194488,'75142','new_theme','text','<p>Shipping via</p>',0,''),(617629,194490,'75144','new_theme','block_type','1',0,''),(617630,194490,'75144','new_theme','font-weight','normal',0,''),(617631,194490,'75144','new_theme','padding-top','10',0,''),(617632,194490,'75144','new_theme','padding-left','10',0,''),(617633,194490,'75144','new_theme','padding-right','10',0,''),(617634,194490,'75144','new_theme','padding-bottom','10',0,''),(617635,194491,'75145','new_theme','text','<p>Shipping service</p>',1,''),(617636,194491,'75145','new_theme','font-weight','bold',0,''),(617637,194491,'75145','new_theme','font-size','14',0,''),(617638,194491,'75145','new_theme','text','<p>Shipping service</p>',0,''),(617639,194493,'75147','new_theme','block_type','2',0,''),(617640,194493,'75147','new_theme','font-weight','normal',0,''),(617641,194493,'75147','new_theme','border-right-width','1',0,''),(617642,194493,'75147','new_theme','border-right-color','$content-border-1',0,''),(617643,194494,'75148','new_theme','block_type','1',0,''),(617644,194494,'75148','new_theme','font-weight','400',0,''),(617645,194494,'75148','new_theme','background-color','$content-bg-2',0,''),(617646,194494,'75148','new_theme','padding-top','10',0,''),(617647,194494,'75148','new_theme','padding-left','10',0,''),(617648,194494,'75148','new_theme','padding-right','10',0,''),(617649,194494,'75148','new_theme','padding-bottom','30',0,''),(617650,194495,'75149','new_theme','font-size','12',0,''),(617651,194496,'75150','new_theme','text','<p>INVOICE ADDRESS:</p>',1,''),(617652,194496,'75150','new_theme','font-size','14',0,''),(617653,194496,'75150','new_theme','font-weight','bold',0,''),(617654,194496,'75150','new_theme','text','<p>INVOICE ADDRESS:</p>',0,''),(617655,194497,'75151','new_theme','block_type','1',0,''),(617656,194497,'75151','new_theme','font-weight','normal',0,''),(617657,194497,'75151','new_theme','padding-top','10',0,''),(617658,194497,'75151','new_theme','padding-left','10',0,''),(617659,194497,'75151','new_theme','padding-right','10',0,''),(617660,194497,'75151','new_theme','padding-bottom','10',0,''),(617661,194498,'75152','new_theme','font-weight','normal',0,''),(617662,194499,'75153','new_theme','text','<p>PHONE NUMBER:</p>',1,''),(617663,194499,'75153','new_theme','font-size','14',0,''),(617664,194499,'75153','new_theme','font-weight','bold',0,''),(617665,194499,'75153','new_theme','padding-top','10',0,''),(617666,194499,'75153','new_theme','text','<p>PHONE NUMBER:</p>',0,''),(617667,194501,'75155','new_theme','font-weight','normal',0,''),(617668,194502,'75156','new_theme','text','<p>E-MAIL ADDRESS:</p>',1,''),(617669,194502,'75156','new_theme','font-weight','bold',0,''),(617670,194502,'75156','new_theme','font-size','14',0,''),(617671,194502,'75156','new_theme','padding-top','10',0,''),(617672,194502,'75156','new_theme','text','<p>E-MAIL ADDRESS:</p>',0,''),(617673,194503,'75157','new_theme','text','<p>CUSTOMER:</p>',1,''),(617674,194503,'75157','new_theme','font-size','13',0,''),(617675,194503,'75157','new_theme','font-weight','bold',0,''),(617676,194503,'75157','new_theme','text','<p>CUSTOMER:</p>',0,''),(617677,194504,'75158','new_theme','font-weight','normal',0,''),(617678,194504,'75158','new_theme','text-align','center',0,''),(617679,194504,'75158','new_theme','padding-bottom','10',0,''),(617680,194505,'75159','new_theme','text','<p>Payment date:</p>',1,''),(617681,194505,'75159','new_theme','font-weight','bold',0,''),(617682,194505,'75159','new_theme','text-align','center',0,''),(617683,194505,'75159','new_theme','font-size','12',0,''),(617684,194505,'75159','new_theme','text','<p>Payment date:</p>',0,''),(617685,194506,'75160','new_theme','text','<p>Payment Method:</p>',1,''),(617686,194506,'75160','new_theme','font-weight','bold',0,''),(617687,194506,'75160','new_theme','text-align','center',0,''),(617688,194506,'75160','new_theme','text','<p>Payment Method:</p>',0,''),(617689,194507,'75161','new_theme','font-size','14',0,''),(617690,194507,'75161','new_theme','font-weight','bold',0,''),(617691,194507,'75161','new_theme','text-align','center',0,''),(617692,194507,'75161','new_theme','padding-bottom','10',0,''),(617693,194507,'75161','new_theme','padding-top','10',0,''),(617694,194508,'75162','new_theme','font-weight','normal',0,''),(617695,194508,'75162','new_theme','text-align','center',0,''),(617696,194508,'75162','new_theme','padding-bottom','20',0,''),(617697,194509,'75163','new_theme','font-weight','normal',0,''),(617698,194509,'75163','new_theme','text-align','center',0,''),(617699,194510,'75194','new_theme','block_type','1',0,''),(617700,194511,'75195','new_theme','text','<div class=\"heading-4\">##TRACKING_NUMBER##</div>',0,''),(617701,194513,'75418','new_theme','block_type','1',0,''),(617702,194514,'75419','new_theme','text','##TEXT_SUCCESSFULLY_UNSUBSCRIBED##',0,''),(617703,194514,'75419','new_theme','padding-top','100',0,''),(617704,194514,'75419','new_theme','margin-bottom','100',0,''),(617705,194514,'75419','new_theme','text-align','center',0,''),(617706,194514,'75419','new_theme','font-size','20',0,''),(617707,194515,'75420','new_theme','block_type','1',0,''),(617708,194515,'75420','new_theme','background-color','$content-bg-2',0,''),(617709,194515,'75420','new_theme','padding-bottom','30',0,''),(617710,194516,'75421','new_theme','block_type','4',0,''),(617711,194516,'75421','new_theme','schema','4-2',0,'8451'),(617712,194517,'75422','new_theme','block_type','1',0,''),(617713,194517,'75422','new_theme','padding-right','40',0,''),(617714,194517,'75422','new_theme','padding-right','0',0,'8451'),(617715,194518,'75423','new_theme','block_type','2',0,''),(617716,194518,'75423','new_theme','margin-bottom','20',0,''),(617717,194518,'75423','new_theme','schema','2-2',0,'8444'),(617718,194518,'75423','new_theme','background-color','$content-bg-1',0,''),(617719,194519,'75424','new_theme','block_type','1',0,''),(617720,194519,'75424','new_theme','border-right-width','20',0,''),(617721,194519,'75424','new_theme','border-right-color','$content-border-1',0,''),(617722,194519,'75424','new_theme','margin-right','-10',0,''),(617723,194519,'75424','new_theme','padding-right','30',0,''),(617724,194519,'75424','new_theme','padding-top','20',0,''),(617725,194519,'75424','new_theme','padding-left','30',0,''),(617726,194519,'75424','new_theme','padding-bottom','20',0,''),(617727,194519,'75424','new_theme','border-right-width','0',0,'8451'),(617728,194519,'75424','new_theme','margin-right','0',0,'8451'),(617729,194519,'75424','new_theme','margin-bottom','20',0,'8451'),(617730,194519,'75424','new_theme','padding-left','20',0,'8451'),(617731,194519,'75424','new_theme','padding-right','20',0,'8451'),(617732,194521,'75426','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(617733,194521,'75426','new_theme','clear','none',0,''),(617734,194522,'75427','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(617735,194522,'75427','new_theme','clear','none',0,''),(617736,194523,'75428','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(617737,194525,'75430','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(617738,194525,'75430','new_theme','padding-top','20',0,''),(617739,194528,'75433','new_theme','margin-bottom','20',0,''),(617740,194529,'75434','new_theme','block_type','1',0,''),(617741,194529,'75434','new_theme','padding-left','30',0,''),(617742,194529,'75434','new_theme','border-left-width','20',0,''),(617743,194529,'75434','new_theme','border-left-color','$content-border-1',0,''),(617744,194529,'75434','new_theme','margin-left','-10',0,''),(617745,194529,'75434','new_theme','padding-right','30',0,''),(617746,194529,'75434','new_theme','padding-top','20',0,''),(617747,194529,'75434','new_theme','padding-bottom','20',0,''),(617748,194529,'75434','new_theme','border-left-width','0',0,'8451'),(617749,194530,'75435','new_theme','margin-bottom','20',0,''),(617750,194532,'75437','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(617751,194533,'75438','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(617752,194533,'75438','new_theme','clear','none',0,''),(617753,194534,'75439','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(617754,194534,'75439','new_theme','clear','none',0,''),(617755,194535,'75440','new_theme','block_type','1',0,''),(617756,194535,'75440','new_theme','padding-right','30',0,''),(617757,194535,'75440','new_theme','background-color','$content-bg-1',0,''),(617758,194535,'75440','new_theme','padding-top','20',0,''),(617759,194535,'75440','new_theme','padding-left','30',0,''),(617760,194535,'75440','new_theme','padding-bottom','20',0,''),(617761,194535,'75440','new_theme','padding-left','20',0,'8451'),(617762,194535,'75440','new_theme','padding-right','20',0,'8451'),(617763,194537,'75442','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(617764,194538,'75443','new_theme','block_type','1',0,''),(617765,194538,'75443','new_theme','padding-top','20',0,''),(617766,194538,'75443','new_theme','padding-left','20',0,''),(617767,194538,'75443','new_theme','padding-right','20',0,''),(617768,194538,'75443','new_theme','padding-bottom','20',0,''),(617769,194538,'75443','new_theme','background-color','$content-bg-1',0,''),(617770,194538,'75443','new_theme','style_class','order-summary',0,''),(617771,194539,'75444','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(617772,194543,'75448','new_theme','block_type','1',0,''),(617773,194543,'75448','new_theme','background-color','$content-bg-2',0,''),(617774,194543,'75448','new_theme','padding-bottom','30',0,''),(617775,194544,'75449','new_theme','block_type','4',0,''),(617776,194544,'75449','new_theme','schema','4-2',0,'8451'),(617777,194545,'75450','new_theme','block_type','1',0,''),(617778,194545,'75450','new_theme','padding-right','40',0,''),(617779,194545,'75450','new_theme','padding-right','0',0,'8451'),(617780,194546,'75451','new_theme','block_type','2',0,''),(617781,194546,'75451','new_theme','margin-bottom','20',0,''),(617782,194546,'75451','new_theme','schema','2-2',0,'8444'),(617783,194546,'75451','new_theme','background-color','$content-bg-1',0,''),(617784,194547,'75452','new_theme','block_type','1',0,''),(617785,194547,'75452','new_theme','border-right-width','20',0,''),(617786,194547,'75452','new_theme','border-right-color','$content-border-1',0,''),(617787,194547,'75452','new_theme','margin-right','-10',0,''),(617788,194547,'75452','new_theme','padding-right','30',0,''),(617789,194547,'75452','new_theme','padding-top','20',0,''),(617790,194547,'75452','new_theme','padding-left','30',0,''),(617791,194547,'75452','new_theme','padding-bottom','20',0,''),(617792,194547,'75452','new_theme','border-right-width','0',0,'8451'),(617793,194547,'75452','new_theme','margin-right','0',0,'8451'),(617794,194547,'75452','new_theme','margin-bottom','20',0,'8451'),(617795,194547,'75452','new_theme','padding-left','20',0,'8451'),(617796,194547,'75452','new_theme','padding-right','20',0,'8451'),(617797,194548,'75453','new_theme','margin-bottom','20',0,''),(617798,194551,'75456','new_theme','text',' <div class=\"heading-4\">##CONTACT_INFORMATION##</div>',0,''),(617799,194551,'75456','new_theme','padding-top','20',0,''),(617800,194553,'75458','new_theme','text','<div class=\"heading-4\">##SHIPPING_METHOD##</div>',0,''),(617801,194553,'75458','new_theme','clear','none',0,''),(617802,194555,'75460','new_theme','text','<div class=\"heading-2 ship-ico\">##TEXT_SHIPPING##</div>',0,''),(617803,194556,'75461','new_theme','text','\n <div class=\"heading-4\">##SHIPPING_ADDRESS##</div>',0,''),(617804,194556,'75461','new_theme','clear','none',0,''),(617805,194557,'75462','new_theme','block_type','1',0,''),(617806,194557,'75462','new_theme','padding-left','30',0,''),(617807,194557,'75462','new_theme','border-left-width','20',0,''),(617808,194557,'75462','new_theme','border-left-color','$content-border-1',0,''),(617809,194557,'75462','new_theme','margin-left','-10',0,''),(617810,194557,'75462','new_theme','padding-right','30',0,''),(617811,194557,'75462','new_theme','padding-top','20',0,''),(617812,194557,'75462','new_theme','padding-bottom','20',0,''),(617813,194557,'75462','new_theme','border-left-width','0',0,'8451'),(617814,194558,'75463','new_theme','text','<div class=\"heading-2 pay-ico\">##TEXT_PAYMENT##</div>',0,''),(617815,194559,'75464','new_theme','text','<div class=\"heading-4\">##TEXT_BILLING_ADDRESS##</div>',0,''),(617816,194559,'75464','new_theme','clear','none',0,''),(617817,194560,'75465','new_theme','text','<div class=\"heading-4\">##PAYMENT_METHOD##</div>',0,''),(617818,194560,'75465','new_theme','clear','none',0,''),(617819,194561,'75466','new_theme','margin-bottom','20',0,''),(617820,194563,'75468','new_theme','block_type','1',0,''),(617821,194563,'75468','new_theme','padding-right','30',0,''),(617822,194563,'75468','new_theme','background-color','$content-bg-1',0,''),(617823,194563,'75468','new_theme','padding-top','20',0,''),(617824,194563,'75468','new_theme','padding-left','30',0,''),(617825,194563,'75468','new_theme','padding-bottom','20',0,''),(617826,194563,'75468','new_theme','padding-left','20',0,'8451'),(617827,194563,'75468','new_theme','padding-right','20',0,'8451'),(617828,194564,'75469','new_theme','text',' <div class=\"heading-2 prod-ico\">##PRODUCT_S##</div>',0,''),(617829,194566,'75471','new_theme','block_type','1',0,''),(617830,194566,'75471','new_theme','padding-top','20',0,''),(617831,194566,'75471','new_theme','padding-left','20',0,''),(617832,194566,'75471','new_theme','padding-right','20',0,''),(617833,194566,'75471','new_theme','padding-bottom','20',0,''),(617834,194566,'75471','new_theme','background-color','$content-bg-1',0,''),(617835,194566,'75471','new_theme','style_class','order-summary',0,''),(617836,194569,'75474','new_theme','text','<div class=\"heading-2 order-ico\">##ORDER_SUMMARY##</div>',0,''),(617837,194571,'75540','new_theme','block_type','1',0,''),(617838,194572,'75541','new_theme','block_type','6',0,''),(617839,194572,'75541','new_theme','schema','6-3',0,'8451'),(617840,194573,'75542','new_theme','aria_name','account-menu',0,''),(617841,194574,'73374','new_theme','block_type','1',0,''),(617842,194574,'73374','new_theme','padding-top','70',0,''),(617843,194574,'73374','new_theme','padding-right','30',0,''),(617844,194574,'73374','new_theme','padding-bottom','30',0,''),(617845,194574,'73374','new_theme','padding-top','0',0,'8451'),(617846,194574,'73374','new_theme','padding-left','0',0,'8451'),(617847,194574,'73374','new_theme','padding-right','0',0,'8451'),(617848,194574,'73374','new_theme','padding-bottom','0',0,'8451'),(617849,194575,'73375','new_theme','block_type','1',0,''),(617850,194575,'73375','new_theme','style_class','account-menu',0,''),(617851,194576,'73376','new_theme','text','<div class=\"heading-4\">##TEXT_ACTIONS##</div>',0,''),(617852,194576,'73376','new_theme','style_class','heading-settings',0,''),(617853,194577,'73377','new_theme','link','logoff',0,''),(617854,194578,'73378','new_theme','link','delete',0,''),(617855,194578,'73378','new_theme','text','DELETE_ACCOUNT',0,''),(617856,194579,'73379','new_theme','text','TEXT_DASHBOARD',0,''),(617857,194579,'73379','new_theme','font-family','$font-1',0,''),(617858,194579,'73379','new_theme','font-size','18',0,''),(617859,194579,'73379','new_theme','text-transform','uppercase',0,''),(617860,194580,'73380','new_theme','text','<div class=\"heading-4\">##MY_SAVED_LISTS##</div>',0,''),(617861,194580,'73380','new_theme','style_class','heading-saved-lists',0,''),(617862,194581,'73381','new_theme','link','Personal Catalog',0,''),(617863,194581,'73381','new_theme','text','TEXT_PERSONAL_CATALOG',0,''),(617864,194581,'73381','new_theme','hide_link','personal_catalog',0,''),(617865,194582,'73382','new_theme','link','Order History',0,''),(617866,194582,'73382','new_theme','text','HEADING_ORDER_HISTORY',0,''),(617867,194582,'73382','new_theme','active_link','Order History Info,Order pay',0,''),(617868,194583,'73383','new_theme','link','Address Book',0,''),(617869,194583,'73383','new_theme','text','IMAGE_BUTTON_ADDRESS_BOOK',0,''),(617870,194584,'73384','new_theme','text','<div class=\"heading-4\">##MY_ORDERED_ITEMS##</div>',0,''),(617871,194584,'73384','new_theme','style_class','heading-ordered-items',0,''),(617872,194585,'73385','new_theme','link','Wishlist',0,''),(617873,194585,'73385','new_theme','hide_link','wishlist',0,''),(617874,194585,'73385','new_theme','text','BOX_HEADING_CUSTOMER_WISHLIST',0,''),(617875,194586,'73386','new_theme','link','My password',0,''),(617876,194586,'73386','new_theme','text','TEXT_MY_PASSWORD',0,''),(617877,194587,'73387','new_theme','link','Samples',0,''),(617878,194587,'73387','new_theme','text','TEXT_HEADING_SAMPLE_CART',0,''),(617879,194587,'73387','new_theme','hide_link','samples',0,''),(617880,194588,'73388','new_theme','link','Review',0,''),(617881,194588,'73388','new_theme','text','REVIEWS',0,''),(617882,194589,'73389','new_theme','link','Quotations',0,''),(617883,194589,'73389','new_theme','hide_link','quotations',0,''),(617884,194589,'73389','new_theme','text','TEXT_HEADING_QUOTE_CART',0,''),(617885,194590,'73390','new_theme','link','Account edit',0,''),(617886,194590,'73390','new_theme','text','ACCOUNT_EDIT',0,''),(617887,194591,'73391','new_theme','text','<div class=\"heading-4\">##MY_SETTINGS##</div>',0,''),(617888,194591,'73391','new_theme','style_class','heading-settings',0,''),(617889,194592,'73392','new_theme','link','trade_form',0,''),(617890,194592,'73392','new_theme','text','TRADE_FORM',0,''),(617891,194593,'75543','new_theme','margin-bottom','20',0,''),(617892,194594,'75544','new_theme','text','<h1>##BOX_HEADING_CUSTOMER_WISHLIST##</h1>',0,''),(617893,194595,'75545','new_theme','block_type','1',0,''),(617894,194595,'75545','new_theme','padding-top','20',0,''),(617895,194595,'75545','new_theme','padding-bottom','20',0,''),(617896,194597,'75547','new_theme','padding-top','20',0,''),(617897,194597,'75547','new_theme','padding-bottom','20',0,''),(617899,110488,'1683018455.4659','furniture','preload','1',0,''),(617904,179376,'1712674967.356553','furniture','width','159',1,''),(617906,179372,'1712674967.104961','furniture','logo','themes/furniture/img/Logo-4.webp',1,''),(617907,179372,'1712674967.104961','furniture','logo_from','theme',0,''),(617908,110380,'117275','furniture','logo','themes/furniture/img/logonew.jpg',1,''),(617910,110380,'117275','furniture','logo_from','theme',0,''),(617911,110380,'117275','furniture','background-color','$header-bg-1',0,''),(617912,110380,'117275','furniture','padding-left','10',0,''),(617913,110380,'117275','furniture','padding-right','10',0,''),(617914,110492,'1705058746.898727','furniture','lazy_load','1',0,''),(617915,179376,'1712674967.356553','furniture','height','126',1,''),(617916,179376,'1712674967.356553','furniture','lazy_load','1',0,''),(617917,112982,'74507','watch','preload','1',0,''),(617918,115482,'1683025508.153','printshop','preload','1',0,''),(617919,122965,'1683024814.1915','deals','preload','1',0,'');
/*!40000 ALTER TABLE `design_boxes_settings_tmp` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `design_boxes_tmp`
--

DROP TABLE IF EXISTS `design_boxes_tmp`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `design_boxes_tmp` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `microtime` varchar(32) NOT NULL,
  `theme_name` varchar(128) CHARACTER SET latin1 COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `block_name` varchar(128) CHARACTER SET latin1 COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `widget_name` text,
  `widget_params` text,
  `sort_order` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `design_boxes_tmp_microtime` (`microtime`),
  KEY `idx_theme_name_block_name` (`theme_name`,`block_name`)
) ENGINE=InnoDB AUTO_INCREMENT=194598 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `design_boxes_tmp`
--

LOCK TABLES `design_boxes_tmp` WRITE;
/*!40000 ALTER TABLE `design_boxes_tmp` DISABLE KEYS */;
INSERT INTO `design_boxes_tmp` VALUES (2926,'94814','watch-mobile','404','Html_box','',1),(3023,'94911','watch-mobile','account','BlockBox','',1),(3024,'94912','watch-mobile','block-3023','BlockBox','',1),(3025,'94913','watch-mobile','block-3024','WidgetsAria','',1),(3026,'94914','watch-mobile','block-3024-2','Html_box','',3),(3027,'94915','watch-mobile','block-3024-2','account\\OrdersHistory','',4),(3028,'94916','watch-mobile','block-3024-2','Html_box','',1),(3029,'94917','watch-mobile','block-3024-2','BlockBox','',2),(3030,'94918','watch-mobile','block-3029','Html_box','',1),(3031,'94919','watch-mobile','block-3029','account\\LastOrder','',2),(3032,'94920','watch-mobile','block-3029-2','Html_box','',1),(3033,'94921','watch-mobile','block-3029-2','account\\AccountLink','',3),(3034,'94922','watch-mobile','block-3029-2','account\\OrderCount','',2),(3035,'94923','watch-mobile','block-3029-3','Html_box','',1),(3036,'94924','watch-mobile','block-3029-3','account\\TotalOrdered','',2),(3037,'94925','watch-mobile','block-3029-4','Html_box','',1),(3038,'94926','watch-mobile','block-3029-4','account\\AccountLink','',3),(3039,'94927','watch-mobile','block-3029-4','account\\CreditAmount','',2),(3040,'94928','watch-mobile','block-3029-5','account\\AccountLink','',3),(3041,'94929','watch-mobile','block-3029-5','account\\PointsEarnt','',2),(3042,'94930','watch-mobile','block-3029-5','Html_box','',1),(3043,'94931','watch-mobile','block-3024-2','BlockBox','',5),(3044,'94932','watch-mobile','block-3043','account\\GiftCards','',6),(3045,'94933','watch-mobile','block-3043','Html_box','',1),(3046,'94934','watch-mobile','block-3024-2','Html_box','',5),(3047,'94935','watch-mobile','account-menu','BlockBox','',1),(3048,'94936','watch-mobile','block-3047','BlockBox','account-side',1),(3049,'94937','watch-mobile','block-3048','Html_box','',16),(3050,'94938','watch-mobile','block-3048','account\\AccountLink','',18),(3051,'94939','watch-mobile','block-3048','account\\AccountLink','',1),(3052,'94940','watch-mobile','block-3048','Html_box','',2),(3053,'94941','watch-mobile','block-3048','account\\AccountLink','',17),(3054,'94942','watch-mobile','block-3048','account\\AccountLink','',4),(3055,'94943','watch-mobile','block-3048','account\\AccountLink','',11),(3056,'94944','watch-mobile','block-3048','Html_box','',6),(3057,'94945','watch-mobile','block-3048','account\\AccountLink','',8),(3058,'94946','watch-mobile','block-3048','account\\AccountLink','',7),(3059,'94947','watch-mobile','block-3048','account\\AccountLink','',14),(3060,'94948','watch-mobile','block-3048','account\\AccountLink','',5),(3061,'94949','watch-mobile','block-3048','account\\AccountLink','',12),(3062,'94950','watch-mobile','block-3048','account\\AccountLink','',9),(3063,'94951','watch-mobile','block-3048','Html_box','',10),(3064,'94952','watch-mobile','block-3048','account\\AccountLink','',15),(3065,'94953','watch-mobile','account_edit','BlockBox','',1),(3066,'94954','watch-mobile','block-3065','BlockBox','',1),(3067,'94955','watch-mobile','block-3066','WidgetsAria','',1),(3068,'94956','watch-mobile','block-3066-2','account\\AccountEdit','',2),(3069,'94957','watch-mobile','block-3066-2','Html_box','',1),(3070,'94958','watch-mobile','block-3066-2','account\\AccountLink','',3),(3071,'94959','watch-mobile','address_book','BlockBox','',1),(3072,'94960','watch-mobile','block-3071','BlockBox','',1),(3073,'94961','watch-mobile','block-3072','WidgetsAria','',1),(3074,'94962','watch-mobile','block-3072-2','account\\AddressBook','',3),(3075,'94963','watch-mobile','block-3072-2','Html_box','',1),(3076,'94964','watch-mobile','address_book_process','BlockBox','',1),(3077,'94965','watch-mobile','block-3076','BlockBox','',1),(3078,'94966','watch-mobile','block-3077','WidgetsAria','',1),(3079,'94967','watch-mobile','block-3077-2','account\\EditAddress','',2),(3080,'94968','watch-mobile','block-3077-2','Html_box','',1),(3081,'94969','watch-mobile','block-3077-2','account\\AccountLink','',3),(3082,'94970','watch-mobile','b2b','BlockBox','listing-item',1),(3083,'94971','watch-mobile','block-3082','BlockBox','',1),(3084,'94972','watch-mobile','block-3083','productListing\\image','',1),(3085,'94973','watch-mobile','block-3083-2','productListing\\model','',5),(3086,'94974','watch-mobile','block-3083-2','productListing\\attributes','',3),(3087,'94975','watch-mobile','block-3083-2','BlockBox','',4),(3088,'94976','watch-mobile','block-3087','BlockBox','',1),(3089,'94977','watch-mobile','block-3088','productListing\\price','',1),(3090,'94978','watch-mobile','block-3088-2','productListing\\bonusPoints','',1),(3091,'94979','watch-mobile','block-3087-2','productListing\\qtyInput','',1),(3092,'94980','watch-mobile','block-3083-2','productListing\\description','',6),(3093,'94981','watch-mobile','block-3083-2','BlockBox','',2),(3094,'94982','watch-mobile','block-3093','productListing\\stock','',1),(3095,'94983','watch-mobile','block-3093-2','productListing\\rating','',1),(3096,'94984','watch-mobile','block-3083-2','productListing\\name','',1),(3097,'94985','watch-mobile','batch','BlockBox','',1),(3098,'94986','watch-mobile','block-3097','productListing\\attributes','',5),(3099,'94987','watch-mobile','block-3097','productListing\\price','',6),(3100,'94988','watch-mobile','block-3097','productListing\\name','',4),(3101,'94989','watch-mobile','block-3097','productListing\\image','',2),(3102,'94990','watch-mobile','block-3097','batchSelect','',1),(3103,'94991','watch-mobile','batch_selected','BlockBox','',1),(3104,'94992','watch-mobile','block-3103','BlockBox','',13),(3105,'94993','watch-mobile','block-3104','productListing\\image','',1),(3106,'94994','watch-mobile','block-3104-2','batchRemove','',1),(3107,'94995','watch-mobile','block-3104-2','productListing\\price','',3),(3108,'94996','watch-mobile','block-3104-2','productListing\\name','',2),(3109,'94997','watch-mobile','bbbbb','BlockBox','',1),(3110,'94998','watch-mobile','block-3109','BlockBox','',2),(3111,'94999','watch-mobile','block-3110','Filters','',1),(3112,'95000','watch-mobile','block-3110-2','BlockBox','',6),(3113,'95001','watch-mobile','block-3112','catalog\\CountsItems','',1),(3114,'95002','watch-mobile','block-3112-2','catalog\\Paging','',1),(3115,'95003','watch-mobile','block-3110-2','catalog\\Image','',1),(3116,'95004','watch-mobile','block-3110-2','Listing','',5),(3117,'95005','watch-mobile','block-3110-2','catalog\\ImageMapCategory','',3),(3118,'95006','watch-mobile','block-3110-2','BlockBox','',4),(3119,'95007','watch-mobile','block-3118','catalog\\ListingLook','',1),(3120,'95008','watch-mobile','block-3118','catalog\\CompareButton','',2),(3121,'95009','watch-mobile','block-3118','catalog\\ItemsOnPage','',4),(3122,'95010','watch-mobile','block-3118','catalog\\Sorting','',3),(3123,'95011','watch-mobile','block-3110-2','Categories','',2),(3124,'95012','watch-mobile','block-3109','catalog\\Title','',1),(3125,'75559','watch-mobile','blog','BlockBox','',1),(3126,'75560','watch-mobile','block-3125','BlockBox','',1),(3127,'75561','watch-mobile','block-3126','BlogContent','',1),(3128,'75562','watch-mobile','block-3126-2','BlogSidebar','',1),(3129,'113643','watch-mobile','blogsidebar','BlockBox','',1),(3130,'113644','watch-mobile','block-3129','Blog\\widget\\RecentPosts','',4),(3131,'113645','watch-mobile','block-3129','Blog\\widget\\TagCloud','',2),(3132,'113646','watch-mobile','block-3129','Blog\\widget\\CategoriesList','',1),(3133,'113647','watch-mobile','block-3129','Blog\\widget\\MostPopularPosts','',3),(3134,'115968','watch-mobile','cart','BlockBox','',2),(3135,'115969','watch-mobile','block-3134','BlockBox','',4),(3136,'115970','watch-mobile','block-3135','Html_box','',1),(3137,'115971','watch-mobile','block-3135','cart\\UpSell','6',2),(3138,'115972','watch-mobile','block-3134','BlockBox','',1),(3139,'115973','watch-mobile','block-3138','cart\\Products','',3),(3140,'115974','watch-mobile','block-3138','BlockBox','',2),(3141,'115976','watch-mobile','block-3140','MultiCart\\SaveCart','',2),(3142,'115977','watch-mobile','block-3140-2','MultiCart\\Actions','',1),(3143,'115975','watch-mobile','block-3138','MultiCart\\CartSwitcher','',1),(3144,'115978','watch-mobile','block-3134','BlockBox','',3),(3145,'115979','watch-mobile','block-3144','cart\\GiveAway','',2),(3146,'115980','watch-mobile','block-3144','Html_box','',1),(3147,'115981','watch-mobile','block-3134','BlockBox','',2),(3148,'115982','watch-mobile','block-3147','Html_box','',1),(3149,'115983','watch-mobile','block-3147','BlockBox','',2),(3150,'115984','watch-mobile','block-3149','cart\\DiscountCoupon','',1),(3151,'115985','watch-mobile','block-3149','cart\\CreditAmount','',2),(3152,'115986','watch-mobile','block-3149','cart\\BonusPoints','',3),(3153,'115987','watch-mobile','block-3134','BlockBox','',5),(3154,'115988','watch-mobile','block-3153','Html_box','',1),(3155,'115989','watch-mobile','block-3153','cart\\ShippingEstimator','',2),(3156,'115990','watch-mobile','block-3134','BlockBox','',7),(3157,'115991','watch-mobile','block-3156','BlockBox','',2),(3158,'115992','watch-mobile','block-3157','Image','',4),(3159,'115993','watch-mobile','block-3157','cart\\CheckoutBtn','',2),(3160,'115994','watch-mobile','block-3157','cart\\OrderTotal','',1),(3161,'115995','watch-mobile','block-3134','Html_box','',6),(3162,'113648','watch-mobile','cart2','BlockBox','',2),(3163,'113649','watch-mobile','block-3162','cart\\CartTabs','',2),(3164,'113650','watch-mobile','block-3163','BlockBox','',1),(3165,'113651','watch-mobile','block-3164','BlockBox','',4),(3166,'113652','watch-mobile','block-3165','cart\\UpSell','6',2),(3167,'113653','watch-mobile','block-3165','Html_box','',1),(3168,'113654','watch-mobile','block-3164','BlockBox','',1),(3169,'113655','watch-mobile','block-3168','cart\\Products','',3),(3170,'113656','watch-mobile','block-3168','BlockBox','',2),(3171,'113657','watch-mobile','block-3170','MultiCart\\CartSwitcher','',1),(3172,'113658','watch-mobile','block-3170','MultiCart\\SaveCart','',2),(3173,'113659','watch-mobile','block-3170-2','MultiCart\\Actions','',1),(3174,'113660','watch-mobile','block-3164','BlockBox','',3),(3175,'113661','watch-mobile','block-3174','cart\\GiveAway','',2),(3176,'113662','watch-mobile','block-3174','Html_box','',1),(3177,'113663','watch-mobile','block-3164','BlockBox','',2),(3178,'113664','watch-mobile','block-3177','Html_box','',1),(3179,'113665','watch-mobile','block-3177','BlockBox','',2),(3180,'113666','watch-mobile','block-3179','cart\\DiscountCoupon','',1),(3181,'113667','watch-mobile','block-3179-2','cart\\CreditAmount','',1),(3182,'113668','watch-mobile','block-3179-3','cart\\BonusPoints','',1),(3183,'113669','watch-mobile','block-3164','BlockBox','',5),(3184,'113670','watch-mobile','block-3183','Html_box','',1),(3185,'113671','watch-mobile','block-3183','cart\\ShippingEstimator','',2),(3186,'113672','watch-mobile','block-3164-2','BlockBox','',1),(3187,'113673','watch-mobile','block-3186','Html_box','',1),(3188,'113674','watch-mobile','block-3186','BlockBox','',2),(3189,'113675','watch-mobile','block-3188','Image','',4),(3190,'113676','watch-mobile','block-3188','cart\\CheckoutBtn','',2),(3191,'113677','watch-mobile','block-3188','cart\\OrderTotal','',1),(3192,'75585','watch-mobile','categories','BlockBox','catalog-features',1),(3193,'75586','watch-mobile','block-3192','catalog\\Title','',1),(3194,'75587','watch-mobile','block-3192','Categories','',2),(3195,'75588','watch-mobile','categories','BlockBox','catalog-content',2),(3196,'75589','watch-mobile','block-3195','Listing','',3),(3197,'75590','watch-mobile','block-3195','BlockBox','',1),(3198,'75591','watch-mobile','block-3197','catalog\\Sorting','',1),(3199,'75592','watch-mobile','block-3197-2','catalog\\CountsItems','',1),(3200,'75593','watch-mobile','block-3195','catalog\\Paging','',2),(3201,'75594','watch-mobile','category','ListingFunctionality','',2),(3202,'75595','watch-mobile','category','Categories','',1),(3203,'75596','watch-mobile','category','PagingBar','',5),(3204,'75597','watch-mobile','category','PagingBar','',3),(3205,'75598','watch-mobile','category','Listing','',4),(3206,'113678','watch-mobile','category_2','BlockBox','',1),(3207,'113679','watch-mobile','block-3206','catalog\\Title','',1),(3208,'113680','watch-mobile','block-3206','BlockBox','',2),(3209,'113681','watch-mobile','block-3208','Filters','',1),(3210,'113682','watch-mobile','block-3208-2','catalog\\Image','',1),(3211,'113683','watch-mobile','block-3208-2','Listing','',5),(3212,'113684','watch-mobile','block-3208-2','BlockBox','',4),(3213,'113685','watch-mobile','block-3212','catalog\\Sorting','',3),(3214,'113686','watch-mobile','block-3212','catalog\\ItemsOnPage','',4),(3215,'113687','watch-mobile','block-3212','catalog\\CompareButton','',2),(3216,'113688','watch-mobile','block-3212','catalog\\ListingLook','',1),(3217,'113689','watch-mobile','block-3208-2','catalog\\ImageMapCategory','',3),(3218,'113690','watch-mobile','block-3208-2','Categories','',2),(3219,'113691','watch-mobile','block-3208-2','BlockBox','',6),(3220,'113692','watch-mobile','block-3219','catalog\\CountsItems','',1),(3221,'113693','watch-mobile','block-3219-2','catalog\\Paging','',1),(3222,'113694','watch-mobile','category_no_filters','BlockBox','',1),(3223,'113695','watch-mobile','block-3222','catalog\\B2bAddButton','',7),(3224,'113696','watch-mobile','block-3222','BlockBox','',6),(3225,'113697','watch-mobile','block-3224','catalog\\CountsItems','',1),(3226,'113698','watch-mobile','block-3224-2','catalog\\Paging','',1),(3227,'113699','watch-mobile','block-3222','Listing','',5),(3228,'113700','watch-mobile','block-3222','catalog\\Image','',2),(3229,'113701','watch-mobile','block-3222','BlockBox','',4),(3230,'113702','watch-mobile','block-3229','catalog\\ListingLook','',1),(3231,'113703','watch-mobile','block-3229','catalog\\CompareButton','',2),(3232,'113704','watch-mobile','block-3229','HeaderStock','',5),(3233,'113705','watch-mobile','block-3229','catalog\\ItemsOnPage','',4),(3234,'113706','watch-mobile','block-3229','catalog\\Sorting','',3),(3235,'113707','watch-mobile','block-3222','Categories','',3),(3236,'113708','watch-mobile','block-3222','catalog\\Title','',1),(3281,'113753','watch-mobile','checkout_confirmation','BlockBox','',1),(3282,'113754','watch-mobile','block-3281','checkout\\ConfirmBtn','',4),(3283,'113755','watch-mobile','block-3281','cart\\Products','',7),(3284,'113756','watch-mobile','block-3281','BlockBox','',2),(3285,'113757','watch-mobile','block-3284','BlockBox','',1),(3286,'113758','watch-mobile','block-3285','Html_box','',1),(3287,'113759','watch-mobile','block-3285','checkout\\ShippingAddressConfirm','',3),(3288,'113760','watch-mobile','block-3284','BlockBox','',2),(3289,'113761','watch-mobile','block-3288','Html_box','',1),(3290,'113762','watch-mobile','block-3288','checkout\\BillingAddressConfirm','',3),(3291,'113763','watch-mobile','block-3281','checkout\\ConfirmBtn','',9),(3292,'113764','watch-mobile','block-3281','BlockBox','',3),(3293,'113765','watch-mobile','block-3292','BlockBox','',1),(3294,'113766','watch-mobile','block-3293','Html_box','',1),(3295,'113767','watch-mobile','block-3293','checkout\\ShippingConfirm','',3),(3296,'113768','watch-mobile','block-3292','BlockBox','',2),(3297,'113769','watch-mobile','block-3296','checkout\\PaymentMethodConfirm','',3),(3298,'113770','watch-mobile','block-3296','Html_box','',1),(3299,'113771','watch-mobile','block-3281','checkout\\EditBtn','',6),(3300,'113772','watch-mobile','block-3281','checkout\\Totals','',8),(3301,'113773','watch-mobile','block-3281','Html_box','',5),(3302,'113774','watch-mobile','checkout_confirmation_no_shipping_q','BlockBox','',1),(3303,'113775','watch-mobile','block-3302','checkout\\Totals','',5),(3304,'113776','watch-mobile','block-3302','checkout\\ConfirmBtn','',6),(3305,'113777','watch-mobile','block-3302','BlockBox','',1),(3306,'113778','watch-mobile','block-3305','BlockBox','',1),(3307,'113779','watch-mobile','block-3306','Html_box','',1),(3308,'113780','watch-mobile','block-3306','checkout\\BillingAddressConfirm','',3),(3309,'113781','watch-mobile','block-3305-2','BlockBox','',1),(3310,'113782','watch-mobile','block-3309','Html_box','',1),(3311,'113783','watch-mobile','block-3309','checkout\\PaymentMethodConfirm','',3),(3312,'113784','watch-mobile','block-3302','Html_box','',3),(3313,'113785','watch-mobile','block-3302','quote\\Products','',4),(3314,'113786','watch-mobile','block-3302','checkout\\ConfirmBtn','',2),(3315,'113787','watch-mobile','checkout_confirmation_no_shipping','BlockBox','',1),(3316,'113788','watch-mobile','block-3315','Html_box','',5),(3317,'113789','watch-mobile','block-3315','checkout\\ConfirmBtn','',4),(3318,'113790','watch-mobile','block-3315','cart\\Products','',7),(3319,'113791','watch-mobile','block-3315','checkout\\Totals','',8),(3320,'113792','watch-mobile','block-3315','checkout\\ConfirmBtn','',9),(3321,'113793','watch-mobile','block-3315','BlockBox','',2),(3322,'113794','watch-mobile','block-3321','BlockBox','',1),(3323,'113795','watch-mobile','block-3322','checkout\\BillingAddressConfirm','',3),(3324,'113796','watch-mobile','block-3322','Html_box','',1),(3325,'113797','watch-mobile','block-3321-2','BlockBox','',1),(3326,'113798','watch-mobile','block-3325','Html_box','',1),(3327,'113799','watch-mobile','block-3325','checkout\\PaymentMethodConfirm','',3),(3328,'113800','watch-mobile','checkout_confirmation_q','BlockBox','',1),(3329,'113801','watch-mobile','block-3328','BlockBox','',2),(3330,'113802','watch-mobile','block-3329','BlockBox','',1),(3331,'113803','watch-mobile','block-3330','checkout\\ShippingConfirm','',3),(3332,'113804','watch-mobile','block-3330','Html_box','',1),(3333,'113805','watch-mobile','block-3329-2','BlockBox','',1),(3334,'113806','watch-mobile','block-3333','Html_box','',1),(3335,'113807','watch-mobile','block-3333','checkout\\PaymentMethodConfirm','',3),(3336,'113808','watch-mobile','block-3328','checkout\\ConfirmBtn','',8),(3337,'113809','watch-mobile','block-3328','checkout\\ConfirmBtn','',3),(3338,'113810','watch-mobile','block-3328','checkout\\EditBtn','',5),(3339,'113811','watch-mobile','block-3328','quote\\Products','',6),(3340,'113812','watch-mobile','block-3328','Html_box','',4),(3341,'113813','watch-mobile','block-3328','checkout\\Totals','',7),(3342,'113814','watch-mobile','block-3328','BlockBox','',1),(3343,'113815','watch-mobile','block-3342','BlockBox','',1),(3344,'113816','watch-mobile','block-3343','checkout\\ShippingAddressConfirm','',3),(3345,'113817','watch-mobile','block-3343','Html_box','',1),(3346,'113818','watch-mobile','block-3342-2','BlockBox','',1),(3347,'113819','watch-mobile','block-3346','Html_box','',1),(3348,'113820','watch-mobile','block-3346','checkout\\BillingAddressConfirm','',3),(3349,'113821','watch-mobile','checkout_confirmation_title','Html_box','',1),(3350,'113822','watch-mobile','checkout_confirmation_title_g','Html_box','',1),(3351,'113823','watch-mobile','checkout_confirmation_title_no_shipping_g','Html_box','',1),(3352,'113824','watch-mobile','checkout_confirmation_title_no_shipping','Html_box','',1),(3353,'113825','watch-mobile','checkout_confirmation_title_q','Html_box','',1),(3354,'113826','watch-mobile','checkout_confirmation_title_s','Html_box','',1),(3355,'113827','watch-mobile','checkout_delivery','BlockBox','',1),(3356,'113828','watch-mobile','block-3355','BlockBox','',1),(3359,'113831','watch-mobile','block-3355','BlockBox','',2),(3360,'113832','watch-mobile','block-3359','Neighbour\\Checkout','',4),(3361,'113833','watch-mobile','block-3359','Html_box','',1),(3362,'113834','watch-mobile','block-3359','checkout\\Shipping','',2),(3363,'113835','watch-mobile','block-3359','DelayedDespatch\\Checkout','',3),(3364,'113836','watch-mobile','checkout_delivery','BlockBox','',2),(3365,'113837','watch-mobile','block-3364','BlockBox','',1),(3366,'113838','watch-mobile','block-3365','Html_box','',1),(3367,'113839','watch-mobile','block-3365','checkout\\ContactInformation','',2),(3368,'113840','watch-mobile','block-3364','BlockBox','',2),(3369,'113841','watch-mobile','block-3368','Html_box','',1),(3370,'113842','watch-mobile','block-3368','checkout\\Comments','',2),(3371,'113843','watch-mobile','checkout_delivery','BlockBox','',3),(3372,'113844','watch-mobile','block-3371','Html_box','',1),(3373,'113845','watch-mobile','block-3371','checkout\\ContinueBtn','',2),(3374,'113846','watch-mobile','checkout_delivery_g','BlockBox','',1),(3375,'113847','watch-mobile','block-3374','BlockBox','',1),(3376,'113848','watch-mobile','block-3375','checkout\\ShippingAddress','',2),(3377,'113849','watch-mobile','block-3375','Html_box','',1),(3378,'113850','watch-mobile','block-3374-2','BlockBox','',1),(3379,'113851','watch-mobile','block-3378','Html_box','',1),(3380,'113852','watch-mobile','block-3378','Neighbour\\Checkout','',4),(3381,'113853','watch-mobile','block-3378','checkout\\Shipping','',2),(3382,'113854','watch-mobile','block-3378','DelayedDespatch\\Checkout','',3),(3383,'113855','watch-mobile','checkout_delivery_g','BlockBox','',3),(3384,'113856','watch-mobile','block-3383','Html_box','',1),(3385,'113857','watch-mobile','block-3383-2','checkout\\ContinueBtn','',1),(3386,'113858','watch-mobile','checkout_delivery_g','BlockBox','',2),(3387,'113859','watch-mobile','block-3386','BlockBox','',1),(3388,'113860','watch-mobile','block-3387','checkout\\ContactInformation','',2),(3389,'113861','watch-mobile','block-3387','Html_box','',1),(3390,'113862','watch-mobile','block-3386-2','BlockBox','',1),(3391,'113863','watch-mobile','block-3390','checkout\\Comments','',2),(3392,'113864','watch-mobile','block-3390','Html_box','',1),(3393,'113865','watch-mobile','checkout_delivery_no_shipping','BlockBox','',2),(3394,'113866','watch-mobile','block-3393','Html_box','',1),(3395,'113867','watch-mobile','block-3393-2','checkout\\ContinueBtn','',1),(3396,'113868','watch-mobile','checkout_delivery_no_shipping','BlockBox','',1),(3397,'113869','watch-mobile','block-3396','BlockBox','',1),(3398,'113870','watch-mobile','block-3397','checkout\\ContactInformation','',2),(3399,'113871','watch-mobile','block-3396-2','BlockBox','',1),(3400,'113872','watch-mobile','block-3399','checkout\\Comments','',2),(3401,'113873','watch-mobile','block-3399','Html_box','',1),(3402,'113874','watch-mobile','checkout_delivery_no_shipping_g','BlockBox','',1),(3403,'113875','watch-mobile','block-3402','BlockBox','',1),(3404,'113876','watch-mobile','block-3403','checkout\\ContactInformation','',2),(3405,'113877','watch-mobile','block-3402-2','BlockBox','',1),(3406,'113878','watch-mobile','block-3405','Html_box','',1),(3407,'113879','watch-mobile','block-3405','checkout\\Comments','',2),(3408,'113880','watch-mobile','checkout_delivery_no_shipping_g','BlockBox','',2),(3409,'113881','watch-mobile','block-3408','Html_box','',1),(3410,'113882','watch-mobile','block-3408-2','checkout\\ContinueBtn','',1),(3411,'113883','watch-mobile','checkout_delivery_title','Html_box','',1),(3412,'113884','watch-mobile','checkout_delivery_title_g','Html_box','',1),(3413,'113885','watch-mobile','checkout_delivery_title_no_shipping_g','Html_box','',1),(3414,'113886','watch-mobile','checkout_delivery_title_no_shipping','Html_box','',1),(3415,'113887','watch-mobile','checkout_delivery_title_q','Html_box','',1),(3416,'113888','watch-mobile','checkout_delivery_title_s','Html_box','',1),(3417,'113889','watch-mobile','checkout_free_s','BlockBox','',1),(3418,'113890','watch-mobile','block-3417','BlockBox','',2),(3419,'113891','watch-mobile','block-3418','BlockBox','',2),(3420,'113892','watch-mobile','block-3419','BlockBox','',2),(3421,'113893','watch-mobile','block-3420','Neighbour\\Checkout','',4),(3422,'113894','watch-mobile','block-3420','BlockBox','',3),(3423,'113895','watch-mobile','block-3422','BlockBox','',1),(3424,'113896','watch-mobile','block-3423','checkout\\ShippingAddress','',2),(3425,'113897','watch-mobile','block-3423','Html_box','',3),(3426,'113898','watch-mobile','block-3423','checkout\\ContactInformation','',4),(3427,'113899','watch-mobile','block-3422','BlockBox','',2),(3428,'113900','watch-mobile','block-3427','DelayedDespatch\\Checkout','',3),(3429,'113901','watch-mobile','block-3420','Html_box','',1),(3430,'113902','watch-mobile','block-3420','BlockBox','',2),(3431,'113903','watch-mobile','block-3430','checkout\\ShippingChoice','',1),(3432,'113904','watch-mobile','block-3419','BlockBox','',3),(3433,'113905','watch-mobile','block-3432','Html_box','',1),(3434,'113906','watch-mobile','block-3432','checkout\\Comments','',2),(3435,'113908','watch-mobile','block-3419','BlockBox','',4),(3436,'113909','watch-mobile','block-3435','checkout\\CreateAccount','',3),(3437,'113910','watch-mobile','block-3435','sample\\Products','',1),(3438,'113911','watch-mobile','block-3419','BlockBox','',5),(3439,'113912','watch-mobile','block-3438','checkout\\ContinueBtn','',1),(3440,'113913','watch-mobile','block-3438','Html_box','',3),(3441,'116002','watch-mobile','block-3438','checkout\\Terms','',2),(3442,'113914','watch-mobile','checkout_no_shipping','BlockBox','',1),(3443,'113915','watch-mobile','block-3442','BlockBox','',2),(3444,'113916','watch-mobile','block-3443','BlockBox','',1),(3445,'113917','watch-mobile','block-3444','BlockBox','',5),(3446,'113918','watch-mobile','block-3445','Html_box','',1),(3447,'113919','watch-mobile','block-3445','checkout\\Comments','',2),(3448,'113920','watch-mobile','block-3444','BlockBox','',4),(3449,'113921','watch-mobile','block-3448','BlockBox','',2),(3450,'113922','watch-mobile','block-3449','CouponsAndVauchers\\Checkout','',1),(3451,'113923','watch-mobile','block-3449-2','checkout\\BonusPoints','',2),(3452,'113924','watch-mobile','block-3449-2','checkout\\CreditAmount','',1),(3453,'113925','watch-mobile','block-3448','Html_box','',1),(3454,'113926','watch-mobile','block-3444','BlockBox','',3),(3455,'113927','watch-mobile','block-3454','BlockBox','',2),(3456,'113928','watch-mobile','block-3455','Html_box','',1),(3457,'113929','watch-mobile','block-3455','checkout\\BillingAddress','',2),(3458,'113930','watch-mobile','block-3455-2','BlockBox','',1),(3459,'113931','watch-mobile','block-3458','Html_box','',1),(3460,'113932','watch-mobile','block-3458','checkout\\PaymentMethod','',2),(3461,'113933','watch-mobile','block-3454','Html_box','',1),(3462,'113934','watch-mobile','block-3444','BlockBox','',6),(3463,'113935','watch-mobile','block-3462','cart\\Products','',1),(3464,'113936','watch-mobile','block-3462','checkout\\CreateAccount','',2),(3465,'113937','watch-mobile','block-3443-2','BlockBox','',1),(3466,'113938','watch-mobile','block-3465','checkout\\Terms','',4),(3467,'113939','watch-mobile','block-3465','checkout\\ContinueBtn','',3),(3468,'113940','watch-mobile','block-3465','checkout\\Totals','',2),(3469,'113941','watch-mobile','block-3465','Html_box','',5),(3470,'113942','watch-mobile','block-3465','Html_box','',1),(3471,'113943','watch-mobile','checkout_no_shipping_g','BlockBox','',1),(3472,'113944','watch-mobile','block-3471','quote\\Products','',3),(3473,'113945','watch-mobile','block-3471','BlockBox','',1),(3474,'113946','watch-mobile','block-3473','BlockBox','',1),(3475,'113947','watch-mobile','block-3474','checkout\\BillingAddress','',2),(3476,'113948','watch-mobile','block-3474','Html_box','',1),(3477,'113949','watch-mobile','block-3473-2','BlockBox','',1),(3478,'113950','watch-mobile','block-3477','checkout\\CreditAmount','',3),(3479,'113951','watch-mobile','block-3477','Html_box','',1),(3480,'113952','watch-mobile','block-3477','checkout\\PaymentMethod','',2),(3481,'113953','watch-mobile','block-3477','CouponsAndVauchers\\Checkout','',5),(3482,'113954','watch-mobile','block-3477','checkout\\BonusPoints','',4),(3483,'113955','watch-mobile','block-3471','BlockBox','',2),(3484,'113956','watch-mobile','block-3483','BlockBox','',1),(3485,'113957','watch-mobile','block-3484','Html_box','',1),(3486,'113958','watch-mobile','block-3484','checkout\\ContactInformation','',2),(3487,'113959','watch-mobile','block-3483-2','BlockBox','',1),(3488,'113960','watch-mobile','block-3487','Html_box','',1),(3489,'113961','watch-mobile','block-3487','checkout\\Comments','',2),(3490,'113962','watch-mobile','block-3471','BlockBox','',6),(3491,'113963','watch-mobile','block-3490','Html_box','',1),(3492,'113964','watch-mobile','block-3490-2','checkout\\ContinueBtn','',1),(3493,'113965','watch-mobile','block-3471','checkout\\Totals','',5),(3494,'113966','watch-mobile','checkout_no_shipping_q','BlockBox','',1),(3495,'113967','watch-mobile','block-3494','BlockBox','',2),(3496,'113968','watch-mobile','block-3495','BlockBox','',2),(3497,'113969','watch-mobile','block-3496','BlockBox','',3),(3498,'113970','watch-mobile','block-3497','BlockBox','',2),(3499,'113971','watch-mobile','block-3498','checkout\\BillingAddress','',2),(3500,'113972','watch-mobile','block-3498','Html_box','',1),(3501,'113973','watch-mobile','block-3498-2','BlockBox','',1),(3502,'113974','watch-mobile','block-3501','Html_box','',1),(3503,'113975','watch-mobile','block-3501','checkout\\PaymentMethod','',2),(3504,'113976','watch-mobile','block-3497','Html_box','',1),(3505,'113977','watch-mobile','block-3496','BlockBox','',6),(3506,'113978','watch-mobile','block-3505','checkout\\CreateAccount','',3),(3507,'113979','watch-mobile','block-3505','quote\\Products','',2),(3508,'113980','watch-mobile','block-3496','BlockBox','',5),(3509,'113981','watch-mobile','block-3508','checkout\\Comments','',2),(3510,'113982','watch-mobile','block-3508','Html_box','',1),(3511,'113983','watch-mobile','block-3496','checkout\\Gdpr','',1),(3512,'113984','watch-mobile','block-3495-2','BlockBox','',1),(3513,'113985','watch-mobile','block-3512','Html_box','',4),(3514,'113986','watch-mobile','block-3512','checkout\\Totals','',2),(3515,'113987','watch-mobile','block-3512','checkout\\ContinueBtn','',3),(3516,'113988','watch-mobile','block-3512','Html_box','',1),(3517,'113989','watch-mobile','checkout_payment','BlockBox','',2),(3518,'113990','watch-mobile','block-3517','Html_box','',1),(3519,'113991','watch-mobile','block-3517','checkout\\ContinueBtn','',2),(3520,'113992','watch-mobile','checkout_payment','BlockBox','',1),(3521,'113993','watch-mobile','block-3520','BlockBox','',1),(3522,'113994','watch-mobile','block-3521','checkout\\BillingAddress','',2),(3523,'113995','watch-mobile','block-3521','Html_box','',1),(3524,'113996','watch-mobile','block-3520','BlockBox','',2),(3525,'113997','watch-mobile','block-3524','checkout\\PaymentMethod','',2),(3526,'113998','watch-mobile','block-3524','Html_box','',1),(3527,'113999','watch-mobile','block-3524','checkout\\CreditAmount','',3),(3528,'114000','watch-mobile','block-3524','CouponsAndVauchers\\Checkout','',5),(3529,'114001','watch-mobile','block-3524','checkout\\BonusPoints','',4),(3530,'114002','watch-mobile','checkout_payment_g','BlockBox','',1),(3531,'114003','watch-mobile','block-3530','BlockBox','',1),(3532,'114004','watch-mobile','block-3531','Html_box','',1),(3533,'114005','watch-mobile','block-3531','checkout\\BillingAddress','',2),(3534,'114006','watch-mobile','block-3530-2','BlockBox','',1),(3535,'114007','watch-mobile','block-3534','checkout\\BonusPoints','',4),(3536,'114008','watch-mobile','block-3534','Html_box','',1),(3537,'114009','watch-mobile','block-3534','CouponsAndVauchers\\Checkout','',5),(3538,'114010','watch-mobile','block-3534','checkout\\CreditAmount','',3),(3539,'114011','watch-mobile','block-3534','checkout\\PaymentMethod','',2),(3540,'114012','watch-mobile','checkout_payment_g','BlockBox','',2),(3541,'114013','watch-mobile','block-3540','Html_box','',1),(3542,'114014','watch-mobile','block-3540-2','checkout\\ContinueBtn','',1),(3543,'114015','watch-mobile','checkout_payment_no_shipping','BlockBox','',1),(3544,'114016','watch-mobile','block-3543','BlockBox','',1),(3545,'114017','watch-mobile','block-3544','Html_box','',1),(3546,'114018','watch-mobile','block-3544','checkout\\BillingAddress','',2),(3547,'114019','watch-mobile','block-3543-2','BlockBox','',1),(3548,'114020','watch-mobile','block-3547','Html_box','',1),(3549,'114021','watch-mobile','block-3547','checkout\\PaymentMethod','',2),(3550,'114022','watch-mobile','block-3547','checkout\\CreditAmount','',3),(3551,'114023','watch-mobile','block-3547','CouponsAndVauchers\\Checkout','',5),(3552,'114024','watch-mobile','block-3547','checkout\\BonusPoints','',4),(3553,'114025','watch-mobile','checkout_payment_no_shipping','BlockBox','',2),(3554,'114026','watch-mobile','block-3553','Html_box','',1),(3555,'114027','watch-mobile','block-3553-2','checkout\\ContinueBtn','',1),(3556,'114028','watch-mobile','checkout_payment_no_shipping_g','BlockBox','',2),(3557,'114029','watch-mobile','block-3556','Html_box','',1),(3558,'114030','watch-mobile','block-3556-2','checkout\\ContinueBtn','',1),(3559,'114031','watch-mobile','checkout_payment_no_shipping_g','BlockBox','',1),(3560,'114032','watch-mobile','block-3559','BlockBox','',1),(3561,'114033','watch-mobile','block-3560','checkout\\BillingAddress','',2),(3562,'114034','watch-mobile','block-3560','Html_box','',1),(3563,'114035','watch-mobile','block-3559-2','BlockBox','',1),(3564,'114036','watch-mobile','block-3563','checkout\\PaymentMethod','',2),(3565,'114037','watch-mobile','block-3563','Html_box','',1),(3566,'114038','watch-mobile','block-3563','checkout\\CreditAmount','',3),(3567,'114039','watch-mobile','block-3563','CouponsAndVauchers\\Checkout','',5),(3568,'114040','watch-mobile','block-3563','checkout\\BonusPoints','',4),(3569,'114041','watch-mobile','checkout_payment_title','Html_box','',1),(3570,'114042','watch-mobile','checkout_payment_title_g','Html_box','',1),(3571,'114043','watch-mobile','checkout_payment_title_no_shipping','Html_box','',1),(3572,'114044','watch-mobile','checkout_payment_title_no_shipping_g','Html_box','',1),(3573,'114045','watch-mobile','checkout_payment_title_q','Html_box','',1),(3574,'114046','watch-mobile','checkout_payment_title_s','Html_box','',1),(3575,'114047','watch-mobile','checkout_q','BlockBox','',1),(3576,'114048','watch-mobile','block-3575','BlockBox','',2),(3577,'114049','watch-mobile','block-3576','BlockBox','',2),(3578,'114050','watch-mobile','block-3577','BlockBox','',3),(3579,'114051','watch-mobile','block-3578','BlockBox','',2),(3580,'114052','watch-mobile','block-3579','checkout\\BillingAddress','',2),(3581,'114053','watch-mobile','block-3579','Html_box','',1),(3582,'114054','watch-mobile','block-3579','BlockBox','',3),(3583,'114055','watch-mobile','block-3582','Html_box','',1),(3584,'114056','watch-mobile','block-3582','checkout\\PaymentMethod','',2),(3585,'114057','watch-mobile','block-3578','Html_box','',1),(3586,'114058','watch-mobile','block-3577','BlockBox','',4),(3587,'114059','watch-mobile','block-3586','Html_box','',1),(3588,'114060','watch-mobile','block-3586','checkout\\Comments','',2),(3589,'114062','watch-mobile','block-3577','BlockBox','',2),(3590,'114063','watch-mobile','block-3589','BlockBox','',3),(3591,'114064','watch-mobile','block-3590','BlockBox','',1),(3592,'114065','watch-mobile','block-3591','Html_box','',3),(3593,'114066','watch-mobile','block-3591','checkout\\ShippingAddress','',2),(3594,'114067','watch-mobile','block-3591','checkout\\ContactInformation','',4),(3595,'114068','watch-mobile','block-3590','BlockBox','',2),(3596,'114069','watch-mobile','block-3595','DelayedDespatch\\Checkout','',3),(3597,'114070','watch-mobile','block-3595','Html_box','',1),(3598,'114071','watch-mobile','block-3595','checkout\\Shipping','',2),(3599,'114072','watch-mobile','block-3589','Html_box','',1),(3600,'114073','watch-mobile','block-3589','Neighbour\\Checkout','',4),(3601,'114074','watch-mobile','block-3589','BlockBox','',2),(3602,'114075','watch-mobile','block-3601','checkout\\ShippingChoice','',1),(3603,'114076','watch-mobile','block-3577','BlockBox','',5),(3604,'114077','watch-mobile','block-3603','quote\\Products','',2),(3605,'114078','watch-mobile','block-3603','checkout\\CreateAccount','',3),(3606,'114079','watch-mobile','block-3577','BlockBox','',6),(3607,'114080','watch-mobile','block-3606','checkout\\ContinueBtn','',3),(3608,'114081','watch-mobile','block-3606','checkout\\Totals','',2),(3609,'114082','watch-mobile','block-3606','Html_box','',5),(3610,'114083','watch-mobile','block-3606','Html_box','',1),(3611,'116000','watch-mobile','block-3606','checkout\\Terms','',4),(3612,'114084','watch-mobile','checkout_s','BlockBox','',1),(3613,'114085','watch-mobile','block-3612','BlockBox','',2),(3614,'114086','watch-mobile','block-3613','BlockBox','',2),(3615,'114093','watch-mobile','block-3614','BlockBox','',3),(3616,'114094','watch-mobile','block-3615','Html_box','',1),(3617,'114095','watch-mobile','block-3615','BlockBox','',2),(3618,'114096','watch-mobile','block-3617','checkout\\BillingAddress','',2),(3619,'114097','watch-mobile','block-3617','Html_box','',1),(3620,'114098','watch-mobile','block-3617','BlockBox','',3),(3621,'114099','watch-mobile','block-3620','checkout\\PaymentMethod','',2),(3622,'114100','watch-mobile','block-3620','Html_box','',1),(3623,'114101','watch-mobile','block-3614','BlockBox','',5),(3624,'114102','watch-mobile','block-3623','checkout\\Comments','',2),(3625,'114103','watch-mobile','block-3623','Html_box','',1),(3626,'114104','watch-mobile','block-3614','BlockBox','',2),(3627,'114105','watch-mobile','block-3626','BlockBox','',2),(3628,'114106','watch-mobile','block-3627','checkout\\ShippingChoice','',1),(3629,'114107','watch-mobile','block-3626','Html_box','',1),(3630,'114108','watch-mobile','block-3626','BlockBox','',3),(3631,'114109','watch-mobile','block-3630','BlockBox','',1),(3632,'114110','watch-mobile','block-3631','checkout\\ShippingAddress','',2),(3633,'114111','watch-mobile','block-3631','Html_box','',3),(3634,'114112','watch-mobile','block-3631','checkout\\ContactInformation','',4),(3635,'114113','watch-mobile','block-3630','BlockBox','',2),(3636,'114114','watch-mobile','block-3635','DelayedDespatch\\Checkout','',3),(3637,'114115','watch-mobile','block-3635','Html_box','',1),(3638,'114116','watch-mobile','block-3635','checkout\\Shipping','',2),(3639,'114117','watch-mobile','block-3626','Neighbour\\Checkout','',4),(3640,'114118','watch-mobile','block-3614','BlockBox','',6),(3641,'114119','watch-mobile','block-3640','checkout\\CreateAccount','',3),(3642,'114120','watch-mobile','block-3640','sample\\Products','',1),(3643,'114122','watch-mobile','block-3614','BlockBox','',7),(3644,'114123','watch-mobile','block-3643','Html_box','',1),(3645,'114124','watch-mobile','block-3643','checkout\\ContinueBtn','',3),(3646,'114125','watch-mobile','block-3643','Html_box','',5),(3647,'114126','watch-mobile','block-3643','checkout\\Totals','',2),(3648,'116001','watch-mobile','block-3643','checkout\\Terms','',4),(3649,'114127','watch-mobile','checkout_step_bottom','cart\\Products','',2),(3650,'114128','watch-mobile','checkout_step_bottom','checkout\\Totals','',3),(3651,'114129','watch-mobile','checkout_step_bottom','Html_box','',1),(3652,'114130','watch-mobile','checkout_step_bottom_g','checkout\\Totals','',3),(3653,'114131','watch-mobile','checkout_step_bottom_g','quote\\Products','',2),(3654,'114132','watch-mobile','checkout_step_bottom_g','Html_box','',1),(3655,'114133','watch-mobile','checkout_step_bottom_no_shipping_g','Html_box','',1),(3656,'114134','watch-mobile','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(3657,'114135','watch-mobile','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(3658,'114136','watch-mobile','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(3659,'114137','watch-mobile','checkout_step_bottom_no_shipping','Html_box','',1),(3660,'114138','watch-mobile','checkout_step_bottom_no_shipping','cart\\Products','',2),(3661,'114139','watch-mobile','communication','BlockBox','',1),(3662,'114140','watch-mobile','block-3661','Html_box','',2),(3663,'114141','watch-mobile','block-3661','Communication\\Topic','',3),(3664,'114142','watch-mobile','block-3661','Communication\\NewTopicButton','',1),(3665,'114143','watch-mobile','compare','BlockBox','',1),(3666,'114144','watch-mobile','block-3665','catalog\\Compare','',1),(3667,'114145','watch-mobile','compare_products','BlockBox','',2),(3668,'114146','watch-mobile','block-3667','productListing\\rating','',4),(3669,'114147','watch-mobile','block-3667','productListing\\model','',5),(3670,'114148','watch-mobile','block-3667','productListing\\compare','',1),(3671,'114149','watch-mobile','block-3667','BlockBox','',2),(3672,'114150','watch-mobile','block-3671','productListing\\image','',1),(3673,'114151','watch-mobile','block-3671-2','productListing\\name','',2),(3674,'114152','watch-mobile','block-3667','BlockBox','',3),(3675,'114153','watch-mobile','block-3674','productListing\\price','',1),(3676,'114154','watch-mobile','block-3674-2','productListing\\buyButton','',1),(3677,'114155','watch-mobile','confirmation','BlockBox','',1),(3678,'114156','watch-mobile','block-3677','BlockBox','',2),(3679,'114157','watch-mobile','block-3678','UploadCustomerId\\UploadCustomerIdForm','',1),(3680,'114158','watch-mobile','block-3678','BlockBox','',2),(3681,'114159','watch-mobile','block-3680','BlockBox','',1),(3682,'114160','watch-mobile','block-3681','BlockBox','',1),(3683,'114161','watch-mobile','block-3682','checkout\\ShippingAddressConfirm','',4),(3684,'114162','watch-mobile','block-3682','Html_box','',1),(3685,'114163','watch-mobile','block-3682','Html_box','',2),(3686,'114164','watch-mobile','block-3682','checkout\\ContactConfirm','',11),(3687,'114165','watch-mobile','block-3682','checkout\\EditBtn','',3),(3688,'114166','watch-mobile','block-3682','Html_box','',5),(3689,'114167','watch-mobile','block-3682','DelayedDespatch\\CheckoutConfirm','',8),(3690,'114168','watch-mobile','block-3682','checkout\\EditBtn','',10),(3691,'114169','watch-mobile','block-3682','checkout\\EditBtn','',6),(3692,'114170','watch-mobile','block-3682','Html_box','',9),(3693,'114171','watch-mobile','block-3682','checkout\\ShippingConfirm','',7),(3694,'114172','watch-mobile','block-3681','BlockBox','',2),(3695,'114173','watch-mobile','block-3694','Html_box','',2),(3696,'114174','watch-mobile','block-3694','checkout\\BillingAddressConfirm','',4),(3697,'114175','watch-mobile','block-3694','Html_box','',5),(3698,'114176','watch-mobile','block-3694','checkout\\PaymentMethodConfirm','',7),(3699,'114177','watch-mobile','block-3694','Html_box','',1),(3700,'114178','watch-mobile','block-3694','checkout\\EditBtn','',3),(3701,'114179','watch-mobile','block-3694','checkout\\EditBtn','',6),(3702,'114180','watch-mobile','block-3680','BlockBox','',3),(3703,'114181','watch-mobile','block-3702','Html_box','',1),(3704,'114182','watch-mobile','block-3702','checkout\\EditBtn','',2),(3705,'114183','watch-mobile','block-3702','cart\\Products','',3),(3706,'114184','watch-mobile','block-3680','BlockBox','',2),(3707,'114185','watch-mobile','block-3706','Html_box','',1),(3708,'114186','watch-mobile','block-3706','checkout\\CommentsConfirm','',3),(3709,'114187','watch-mobile','block-3706','checkout\\EditBtn','',2),(3710,'114188','watch-mobile','block-3680','BlockBox','',4),(3711,'114189','watch-mobile','block-3710','checkout\\Totals','',2),(3712,'114190','watch-mobile','block-3710','Html_box','',1),(3713,'114191','watch-mobile','block-3710','checkout\\ConfirmBtn','',3),(3714,'114192','watch-mobile','block-3677','Html_box','',1),(3715,'114193','watch-mobile','confirmation_free_s','BlockBox','',1),(3716,'114194','watch-mobile','block-3715','Html_box','',1),(3717,'114195','watch-mobile','block-3715','BlockBox','',2),(3718,'114196','watch-mobile','block-3717','BlockBox','',1),(3719,'114197','watch-mobile','block-3718','BlockBox','',1),(3720,'114198','watch-mobile','block-3719','BlockBox','',1),(3721,'114199','watch-mobile','block-3720','checkout\\EditBtn','',6),(3722,'114200','watch-mobile','block-3720','checkout\\ShippingAddressConfirm','',4),(3723,'114201','watch-mobile','block-3720','Html_box','',2),(3724,'114202','watch-mobile','block-3720','checkout\\ShippingConfirm','',7),(3725,'114203','watch-mobile','block-3720','checkout\\EditBtn','',3),(3726,'114204','watch-mobile','block-3720','Html_box','',5),(3727,'114205','watch-mobile','block-3719','BlockBox','',2),(3728,'114206','watch-mobile','block-3727','Html_box','',1),(3729,'114207','watch-mobile','block-3727','checkout\\EditBtn','',2),(3730,'114208','watch-mobile','block-3727','DelayedDespatch\\CheckoutConfirm','',4),(3731,'114209','watch-mobile','block-3727','checkout\\ContactConfirm','',3),(3732,'114210','watch-mobile','block-3718','BlockBox','',2),(3733,'114211','watch-mobile','block-3732','checkout\\CommentsConfirm','',3),(3734,'114212','watch-mobile','block-3732','checkout\\EditBtn','',2),(3735,'114213','watch-mobile','block-3732','Html_box','',1),(3736,'114214','watch-mobile','block-3718','BlockBox','',3),(3737,'114215','watch-mobile','block-3736','sample\\Products','',2),(3738,'114216','watch-mobile','block-3736','Html_box','',1),(3739,'114217','watch-mobile','block-3736','checkout\\EditBtn','',3),(3740,'114218','watch-mobile','block-3718','BlockBox','',4),(3741,'114219','watch-mobile','block-3740','checkout\\ConfirmBtn','',3),(3742,'114220','watch-mobile','confirmation_no_shipping','BlockBox','',1),(3743,'114221','watch-mobile','block-3742','Html_box','',1),(3744,'114222','watch-mobile','block-3742','BlockBox','',2),(3745,'114223','watch-mobile','block-3744','BlockBox','',1),(3746,'114224','watch-mobile','block-3745','BlockBox','',3),(3747,'114225','watch-mobile','block-3746','checkout\\EditBtn','',2),(3748,'114226','watch-mobile','block-3746','Html_box','',1),(3749,'114227','watch-mobile','block-3746','cart\\Products','',3),(3750,'114228','watch-mobile','block-3745','BlockBox','',2),(3751,'114229','watch-mobile','block-3750','checkout\\EditBtn','',2),(3752,'114230','watch-mobile','block-3750','checkout\\CommentsConfirm','',3),(3753,'114231','watch-mobile','block-3750','Html_box','',1),(3754,'114232','watch-mobile','block-3745','BlockBox','',1),(3755,'114233','watch-mobile','block-3754','BlockBox','',1),(3756,'114234','watch-mobile','block-3755','Html_box','',9),(3757,'114235','watch-mobile','block-3755','checkout\\ContactConfirm','',11),(3758,'114236','watch-mobile','block-3755','checkout\\EditBtn','',10),(3759,'114237','watch-mobile','block-3754-2','BlockBox','',1),(3760,'114238','watch-mobile','block-3759','checkout\\EditBtn','',3),(3761,'114239','watch-mobile','block-3759','Html_box','',2),(3762,'114240','watch-mobile','block-3759','Html_box','',1),(3763,'114241','watch-mobile','block-3759','Html_box','',5),(3764,'114242','watch-mobile','block-3759','checkout\\BillingAddressConfirm','',4),(3765,'114243','watch-mobile','block-3759','checkout\\PaymentMethodConfirm','',7),(3766,'114244','watch-mobile','block-3759','checkout\\EditBtn','',6),(3767,'114245','watch-mobile','block-3744-2','BlockBox','',1),(3768,'114246','watch-mobile','block-3767','checkout\\ConfirmBtn','',3),(3769,'114247','watch-mobile','block-3767','checkout\\Totals','',2),(3770,'114248','watch-mobile','block-3767','Html_box','',1),(3771,'114249','watch-mobile','confirmation_no_shipping_q','BlockBox','',2),(3772,'114250','watch-mobile','block-3771','BlockBox','',2),(3773,'114251','watch-mobile','block-3772','BlockBox','',1),(3774,'114252','watch-mobile','block-3773','BlockBox','',3),(3775,'114253','watch-mobile','block-3774','quote\\Products','',3),(3776,'114254','watch-mobile','block-3774','checkout\\EditBtn','',2),(3777,'114255','watch-mobile','block-3774','Html_box','',1),(3778,'114256','watch-mobile','block-3773','BlockBox','',1),(3779,'114257','watch-mobile','block-3778','BlockBox','',1),(3780,'114258','watch-mobile','block-3779','checkout\\EditBtn','',2),(3781,'114259','watch-mobile','block-3779','Html_box','',1),(3782,'114260','watch-mobile','block-3779','Html_box','',4),(3783,'114261','watch-mobile','block-3779','checkout\\PaymentMethodConfirm','',3),(3784,'114262','watch-mobile','block-3779','checkout\\EditBtn','',5),(3785,'114263','watch-mobile','block-3779','checkout\\ContactConfirm','',6),(3786,'114264','watch-mobile','block-3778-2','BlockBox','',1),(3787,'114265','watch-mobile','block-3786','Html_box','',2),(3788,'114266','watch-mobile','block-3786','checkout\\EditBtn','',3),(3789,'114267','watch-mobile','block-3786','checkout\\BillingAddressConfirm','',4),(3790,'114268','watch-mobile','block-3773','BlockBox','',2),(3791,'114269','watch-mobile','block-3790','checkout\\CommentsConfirm','',3),(3792,'114270','watch-mobile','block-3790','Html_box','',1),(3793,'114271','watch-mobile','block-3790','checkout\\EditBtn','',2),(3794,'114272','watch-mobile','block-3772-2','BlockBox','',1),(3795,'114273','watch-mobile','block-3794','Html_box','',1),(3796,'114274','watch-mobile','block-3794','checkout\\Totals','',2),(3797,'114275','watch-mobile','block-3794','checkout\\ConfirmBtn','',3),(3798,'114276','watch-mobile','block-3771','Html_box','',1),(3799,'114277','watch-mobile','confirmation_q','BlockBox','',1),(3800,'114278','watch-mobile','block-3799','Html_box','',1),(3801,'114279','watch-mobile','block-3799','BlockBox','',2),(3802,'114280','watch-mobile','block-3801','BlockBox','',1),(3803,'114281','watch-mobile','block-3802','BlockBox','',3),(3804,'114282','watch-mobile','block-3803','checkout\\EditBtn','',2),(3805,'114283','watch-mobile','block-3803','Html_box','',1),(3806,'114284','watch-mobile','block-3803','quote\\Products','',3),(3807,'114285','watch-mobile','block-3802','BlockBox','',2),(3808,'114286','watch-mobile','block-3807','checkout\\EditBtn','',2),(3809,'114287','watch-mobile','block-3807','checkout\\CommentsConfirm','',3),(3810,'114288','watch-mobile','block-3807','Html_box','',1),(3811,'114289','watch-mobile','block-3802','BlockBox','',1),(3812,'114290','watch-mobile','block-3811','BlockBox','',1),(3813,'114291','watch-mobile','block-3812','Html_box','',5),(3814,'114292','watch-mobile','block-3812','Html_box','',9),(3815,'114293','watch-mobile','block-3812','checkout\\EditBtn','',6),(3816,'114294','watch-mobile','block-3812','checkout\\ShippingConfirm','',7),(3817,'114295','watch-mobile','block-3812','checkout\\EditBtn','',3),(3818,'114296','watch-mobile','block-3812','DelayedDespatch\\CheckoutConfirm','',8),(3819,'114297','watch-mobile','block-3812','checkout\\ShippingAddressConfirm','',4),(3820,'114298','watch-mobile','block-3812','checkout\\ContactConfirm','',11),(3821,'114299','watch-mobile','block-3812','checkout\\EditBtn','',10),(3822,'114300','watch-mobile','block-3812','Html_box','',2),(3823,'114301','watch-mobile','block-3812','Html_box','',1),(3824,'114302','watch-mobile','block-3811','BlockBox','',2),(3825,'114303','watch-mobile','block-3824','Html_box','',1),(3826,'114304','watch-mobile','block-3824','Html_box','',2),(3827,'114305','watch-mobile','block-3824','checkout\\PaymentMethodConfirm','',7),(3828,'114306','watch-mobile','block-3824','Html_box','',5),(3829,'114307','watch-mobile','block-3824','checkout\\BillingAddressConfirm','',4),(3830,'114308','watch-mobile','block-3824','checkout\\EditBtn','',6),(3831,'114309','watch-mobile','block-3824','checkout\\EditBtn','',3),(3832,'114310','watch-mobile','block-3802','BlockBox','',4),(3833,'114311','watch-mobile','block-3832','checkout\\ConfirmBtn','',3),(3834,'114312','watch-mobile','block-3832','Html_box','',1),(3835,'114313','watch-mobile','block-3832','checkout\\Totals','',2),(3836,'114314','watch-mobile','confirmation_s','BlockBox','',1),(3837,'114315','watch-mobile','block-3836','Html_box','',1),(3838,'114316','watch-mobile','block-3836','BlockBox','',2),(3839,'114317','watch-mobile','block-3838','BlockBox','',1),(3840,'114318','watch-mobile','block-3839','BlockBox','',2),(3841,'114319','watch-mobile','block-3840','checkout\\CommentsConfirm','',3),(3842,'114320','watch-mobile','block-3840','checkout\\EditBtn','',2),(3843,'114321','watch-mobile','block-3840','Html_box','',1),(3844,'114322','watch-mobile','block-3839','BlockBox','',3),(3845,'114323','watch-mobile','block-3844','sample\\Products','',2),(3846,'114324','watch-mobile','block-3844','Html_box','',1),(3847,'114325','watch-mobile','block-3844','checkout\\EditBtn','',3),(3848,'114326','watch-mobile','block-3839','BlockBox','',1),(3849,'114327','watch-mobile','block-3848','BlockBox','',1),(3850,'114328','watch-mobile','block-3849','Html_box','',9),(3851,'114329','watch-mobile','block-3849','checkout\\ContactConfirm','',11),(3852,'114330','watch-mobile','block-3849','checkout\\EditBtn','',6),(3853,'114331','watch-mobile','block-3849','checkout\\EditBtn','',10),(3854,'114332','watch-mobile','block-3849','Html_box','',1),(3855,'114333','watch-mobile','block-3849','DelayedDespatch\\CheckoutConfirm','',8),(3856,'114334','watch-mobile','block-3849','checkout\\EditBtn','',3),(3857,'114335','watch-mobile','block-3849','checkout\\ShippingAddressConfirm','',4),(3858,'114336','watch-mobile','block-3849','Html_box','',5),(3859,'114337','watch-mobile','block-3849','Html_box','',2),(3860,'114338','watch-mobile','block-3849','checkout\\ShippingConfirm','',7),(3861,'114339','watch-mobile','block-3848','BlockBox','',2),(3862,'114340','watch-mobile','block-3861','Html_box','',5),(3863,'114341','watch-mobile','block-3861','Html_box','',1),(3864,'114342','watch-mobile','block-3861','checkout\\EditBtn','',6),(3865,'114343','watch-mobile','block-3861','checkout\\BillingAddressConfirm','',4),(3866,'114344','watch-mobile','block-3861','checkout\\EditBtn','',3),(3867,'114345','watch-mobile','block-3861','Html_box','',2),(3868,'114346','watch-mobile','block-3861','checkout\\PaymentMethodConfirm','',7),(3869,'114347','watch-mobile','block-3839','BlockBox','',4),(3870,'114348','watch-mobile','block-3869','checkout\\Totals','',2),(3871,'114349','watch-mobile','block-3869','Html_box','',1),(3872,'114350','watch-mobile','block-3869','checkout\\ConfirmBtn','',3),(3873,'75599','watch-mobile','contact','BlockBox','',1),(3874,'75600','watch-mobile','block-3873','BlockBox','',4),(3875,'75601','watch-mobile','block-3874','contact\\Map','',1),(3876,'75602','watch-mobile','block-3874-2','contact\\StreetView','',1),(3877,'75603','watch-mobile','block-3873','BlockBox','',3),(3878,'75604','watch-mobile','block-3877','contact\\ContactForm','',1),(3879,'75605','watch-mobile','block-3877-2','contact\\Contacts','',1),(3880,'75606','watch-mobile','block-3873','info\\Title','',1),(3881,'114351','watch-mobile','created_success','BlockBox','',1),(3882,'114352','watch-mobile','block-3881','Html_box','',2),(3883,'114353','watch-mobile','block-3881','Html_box','',1),(3884,'114354','watch-mobile','credit_note','invoice\\Container','',1),(3885,'114355','watch-mobile','block-3884','BlockBox','',2),(3886,'114356','watch-mobile','block-3885','BlockBox','',8),(3887,'114357','watch-mobile','block-3886','BlockBox','',1),(3888,'114358','watch-mobile','block-3887','Text','',1),(3889,'114359','watch-mobile','block-3887','invoice\\ShippingMethod','',2),(3890,'114360','watch-mobile','block-3886-2','BlockBox','',1),(3891,'114361','watch-mobile','block-3890','invoice\\ShippingMethod','',2),(3892,'114362','watch-mobile','block-3890','Text','',1),(3893,'114363','watch-mobile','block-3885','BlockBox','',7),(3894,'114364','watch-mobile','block-3893','BlockBox','',1),(3895,'114365','watch-mobile','block-3894','invoice\\BillingAddress','',2),(3896,'114366','watch-mobile','block-3894','Text','',1),(3897,'114367','watch-mobile','block-3893-2','BlockBox','',1),(3898,'114368','watch-mobile','block-3897','Text','',5),(3899,'114369','watch-mobile','block-3897','invoice\\CustomerName','',2),(3900,'114370','watch-mobile','block-3897','invoice\\CustomerEmail','',6),(3901,'114371','watch-mobile','block-3897','Text','',3),(3902,'114372','watch-mobile','block-3897','Text','',1),(3903,'114373','watch-mobile','block-3897','invoice\\CustomerPhone','',4),(3904,'114374','watch-mobile','block-3885-2','invoice\\PaymentDate','',3),(3905,'114375','watch-mobile','block-3885-2','Text','',2),(3906,'114376','watch-mobile','block-3885-2','invoice\\OrderId','',1),(3907,'114377','watch-mobile','block-3884','BlockBox','',4),(3908,'114378','watch-mobile','block-3907','BlockBox','',1),(3909,'114379','watch-mobile','block-3908','Text','',1),(3910,'114380','watch-mobile','block-3908','invoice\\ShippingAddress','',2),(3911,'114381','watch-mobile','block-3907-2','BlockBox','',1),(3912,'114382','watch-mobile','block-3884','BlockBox','',1),(3913,'114383','watch-mobile','block-3912','Logo','',1),(3914,'114384','watch-mobile','block-3912-2','BlockBox','',1),(3915,'114385','watch-mobile','block-3914','invoice\\StoreAddress','',1),(3916,'114386','watch-mobile','block-3912-2','BlockBox','',3),(3917,'114387','watch-mobile','block-3916','Text','',1),(3918,'114388','watch-mobile','block-3916-2','invoice\\StoreEmail','',1),(3919,'114389','watch-mobile','block-3912-2','BlockBox','',2),(3920,'114390','watch-mobile','block-3919','Text','',1),(3921,'114391','watch-mobile','block-3919-2','invoice\\StorePhone','',1),(3922,'114392','watch-mobile','block-3912-2','BlockBox','',4),(3923,'114393','watch-mobile','block-3922','Text','',1),(3924,'114394','watch-mobile','block-3922-2','invoice\\StoreSite','',1),(3925,'114395','watch-mobile','block-3884','invoice\\Products','',3),(3926,'114396','watch-mobile','block-3884','BlockBox','',5),(3927,'114397','watch-mobile','block-3926','invoice\\StoreAddress','',8),(3928,'114398','watch-mobile','block-3926','Text','',1),(3929,'114399','watch-mobile','block-3926-2','Text','',2),(3930,'114400','watch-mobile','block-3926-2','Logo','',1),(3931,'114401','watch-mobile','block-3926-3','BlockBox','',2),(3932,'114402','watch-mobile','block-3931','Text','',1),(3933,'114403','watch-mobile','block-3931-2','invoice\\StorePhone','',1),(3934,'114404','watch-mobile','block-3926-3','BlockBox','',3),(3935,'114405','watch-mobile','block-3934','Text','',1),(3936,'114406','watch-mobile','block-3934-2','invoice\\StoreEmail','',1),(3937,'114407','watch-mobile','block-3926-3','Text','',1),(3938,'75607','watch-mobile','delivery-location','DeliveryLocation\\LocationProducts','',8),(3939,'75608','watch-mobile','delivery-location','DeliveryLocation\\LocationLongDescription','',5),(3940,'75609','watch-mobile','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(3941,'75610','watch-mobile','delivery-location','DeliveryLocation\\LocationDescription','',3),(3942,'75611','watch-mobile','delivery-location','DeliveryLocation\\FeaturedList','',6),(3943,'75612','watch-mobile','delivery-location','DeliveryLocation\\LocationList','',7),(3944,'75613','watch-mobile','delivery-location','DeliveryLocation\\LocationTitle','',2),(3945,'75614','watch-mobile','delivery-location-default','DeliveryLocation\\TopLocationList','',2),(3946,'75615','watch-mobile','delivery-location-default','Heading','',1),(3947,'114408','watch-mobile','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(3948,'114409','watch-mobile','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(3949,'114410','watch-mobile','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(3950,'114411','watch-mobile','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(3951,'114412','watch-mobile','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(3952,'114413','watch-mobile','delivery_loc_2','DeliveryLocation\\LocationList','',7),(3953,'114414','watch-mobile','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(3954,'75616','watch-mobile','email','email\\Content','',3),(3955,'75617','watch-mobile','email','email\\BlockBox','',1),(3956,'75618','watch-mobile','block-3955','Logo','',1),(3957,'75619','watch-mobile','email','Copyright','',7),(3958,'75620','watch-mobile','email','email\\BlockBox','',4),(3959,'75621','watch-mobile','email','Text','',5),(3960,'75622','watch-mobile','email','email\\BlockBox','',2),(3961,'75623','watch-mobile','block-3960','email\\Title','',1),(3962,'75624','watch-mobile','block-3960-2','email\\Date','',1),(3963,'114415','watch-mobile','email_2','email\\BlockBox','',1),(3964,'114416','watch-mobile','block-3963','email\\BlockBox','',1),(3965,'114417','watch-mobile','block-3964','email\\Content','',3),(3966,'114418','watch-mobile','block-3964','email\\BlockBox','',2),(3967,'114419','watch-mobile','block-3966','email\\Title','',1),(3968,'114420','watch-mobile','block-3966-2','email\\Date','',1),(3969,'114421','watch-mobile','block-3964','Copyright','',4),(3970,'114422','watch-mobile','block-3964','Logo','',1),(3971,'114423','watch-mobile','email_3','email\\BlockBox','',1),(3972,'114424','watch-mobile','block-3971','email\\BlockBox','',1),(3973,'114425','watch-mobile','block-3972','Logo','',1),(3974,'114426','watch-mobile','block-3972','Copyright','',3),(3975,'114427','watch-mobile','block-3972','email\\BlockBox','',2),(3976,'114428','watch-mobile','block-3975','email\\BlockBox','',1),(3977,'114429','watch-mobile','block-3976','email\\Title','',1),(3978,'114430','watch-mobile','block-3976-2','email\\Date','',1),(3979,'114431','watch-mobile','block-3975','email\\Content','',2),(3980,'114432','watch-mobile','email_4','email\\BlockBox','',1),(3981,'114433','watch-mobile','block-3980','email\\BlockBox','',1),(3982,'114434','watch-mobile','block-3981','email\\BlockBox','',1),(3983,'114435','watch-mobile','block-3982','email\\Content','',2),(3984,'114436','watch-mobile','block-3982','email\\BlockBox','',1),(3985,'114437','watch-mobile','block-3984','Logo','',1),(3986,'114438','watch-mobile','block-3984-2','email\\Title','',1),(3987,'114439','watch-mobile','block-3984-2','email\\Date','',2),(3988,'114440','watch-mobile','block-3981','Copyright','',2),(3989,'75625','watch-mobile','footer','BlockBox','footer-content',1),(3990,'75628','watch-mobile','block-3989','BlockBox','',4),(3991,'75629','watch-mobile','block-3990','Text','',1),(3992,'75630','watch-mobile','block-3990','Menu','footer3',2),(3993,'75632','watch-mobile','block-3989','Copyright','',10),(3994,'75633','watch-mobile','block-3989','BlockBox','',2),(3995,'75634','watch-mobile','block-3994','Menu','footer2',2),(3996,'75635','watch-mobile','block-3994','Text','',1),(3997,'75636','watch-mobile','block-3989','BlockBox','',3),(3998,'75637','watch-mobile','block-3997','Text','',1),(3999,'75638','watch-mobile','block-3997','Menu','footer1',2),(4000,'75640','watch-mobile','block-3989','BlockBox','',1),(4001,'75641','watch-mobile','block-4000','Contacts','',2),(4002,'75642','watch-mobile','block-4000','Text','',1),(4003,'114441','watch-mobile','for_menu','BlockBox','',1),(4004,'114442','watch-mobile','block-4003','Html_box','',1),(4005,'114443','watch-mobile','block-4003-2','Languages','',1),(4006,'114444','watch-mobile','for_menu','BlockBox','',3),(4007,'114445','watch-mobile','block-4006','Html_box','',1),(4008,'114446','watch-mobile','block-4006-2','Currencies','',1),(4009,'75650','watch-mobile','gift','BlockBox','',1),(4010,'75651','watch-mobile','block-4009','BlockBox','',3),(4011,'75652','watch-mobile','block-4010','BlockBox','',1),(4012,'75653','watch-mobile','block-4011','BlockBox','',1),(4013,'75654','watch-mobile','block-4012','BlockBox','',9),(4014,'75655','watch-mobile','block-4013','Text','',1),(4015,'75656','watch-mobile','block-4013','invoice\\StoreEmail','',3),(4016,'75657','watch-mobile','block-4013','invoice\\StorePhone','',2),(4017,'75658','watch-mobile','block-4012','Text','',6),(4018,'75659','watch-mobile','block-4012','Text','',4),(4019,'75660','watch-mobile','block-4012','Text','',7),(4020,'75661','watch-mobile','block-4012','Text','',2),(4021,'75662','watch-mobile','block-4012','BlockBox','',8),(4022,'75663','watch-mobile','block-4021','Text','',1),(4023,'75664','watch-mobile','block-4021-2','gift\\CodeView','',1),(4024,'75665','watch-mobile','block-4012','gift\\MessageView','',5),(4025,'75666','watch-mobile','block-4012','gift\\AmountView','',3),(4026,'75667','watch-mobile','block-4012','Text','',1),(4027,'75668','watch-mobile','block-4010-2','gift\\Form','',2),(4028,'75669','watch-mobile','block-4010-2','Text','',1),(4029,'75670','watch-mobile','block-4009','info\\Title','',1),(4030,'114447','watch-mobile','gift_card','BlockBox','',1),(4031,'114448','watch-mobile','block-4030','Text','',9),(4032,'114449','watch-mobile','block-4030','Text','',4),(4033,'114450','watch-mobile','block-4030','Logo','',1),(4034,'114451','watch-mobile','block-4030','Image','',2),(4035,'114452','watch-mobile','block-4030','Text','',6),(4036,'114453','watch-mobile','block-4030','gift\\AmountView','',5),(4037,'114454','watch-mobile','block-4030','gift\\MessageView','',7),(4038,'114455','watch-mobile','block-4030','BlockBox','',10),(4039,'114456','watch-mobile','block-4038','Text','',1),(4040,'114457','watch-mobile','block-4038-2','gift\\CodeView','',1),(4041,'114458','watch-mobile','block-4030','Text','',3),(4042,'114459','watch-mobile','block-4030','Text','',8),(4043,'114460','watch-mobile','block-4030','BlockBox','',11),(4044,'114461','watch-mobile','block-4043','invoice\\StorePhone','',2),(4045,'114462','watch-mobile','block-4043','Text','',1),(4046,'114463','watch-mobile','block-4043','invoice\\StoreEmail','',3),(4047,'114464','watch-mobile','gift_card_2','BlockBox','',1),(4048,'114465','watch-mobile','block-4047','Text','',1),(4049,'114466','watch-mobile','block-4047','Text','',2),(4050,'114467','watch-mobile','block-4047','Text','',6),(4051,'114468','watch-mobile','block-4047','gift\\MessageView','',5),(4052,'114469','watch-mobile','block-4047','Text','',7),(4053,'114470','watch-mobile','block-4047','Text','',4),(4054,'114471','watch-mobile','block-4047','BlockBox','',9),(4055,'114472','watch-mobile','block-4054','invoice\\StorePhone','',2),(4056,'114473','watch-mobile','block-4054','Text','',1),(4057,'114474','watch-mobile','block-4054','invoice\\StoreEmail','',3),(4058,'114475','watch-mobile','block-4047','BlockBox','',8),(4059,'114476','watch-mobile','block-4058','Text','',1),(4060,'114477','watch-mobile','block-4058-2','gift\\CodeView','',1),(4061,'114478','watch-mobile','block-4047','gift\\AmountView','',3),(4062,'114479','watch-mobile','gift_card_2_pdf','BlockBox','',1),(4063,'114480','watch-mobile','block-4062','BlockBox','',12),(4064,'114481','watch-mobile','block-4063','invoice\\StoreEmail','',4),(4065,'114482','watch-mobile','block-4063','invoice\\StorePhone','',3),(4066,'114483','watch-mobile','block-4063','Html_box','',1),(4067,'114484','watch-mobile','block-4062','BlockBox','',11),(4068,'114485','watch-mobile','block-4067','Html_box','',1),(4069,'114486','watch-mobile','block-4067-2','gift\\CodeViewPdf','',1),(4070,'114487','watch-mobile','block-4062','BlockBox','',1),(4071,'114488','watch-mobile','block-4070','Text','',4),(4072,'114489','watch-mobile','block-4070','Html_box','',1),(4073,'114490','watch-mobile','block-4070','Html_box','',2),(4074,'114491','watch-mobile','block-4070','gift\\AmountViewPdf','',3),(4075,'114492','watch-mobile','block-4070','gift\\MessageViewPdf','',5),(4076,'114493','watch-mobile','block-4070','Html_box','',7),(4077,'114494','watch-mobile','block-4070','Html_box','',6),(4078,'114495','watch-mobile','gift_card_2_pdf','Import','',1),(4079,'114496','watch-mobile','gift_card_pdf','BlockBox','',1),(4080,'114497','watch-mobile','block-4079','BlockBox','',12),(4081,'114498','watch-mobile','block-4080','invoice\\StoreEmail','',4),(4082,'114499','watch-mobile','block-4080','invoice\\StorePhone','',3),(4083,'114500','watch-mobile','block-4080','Html_box','',1),(4084,'114501','watch-mobile','block-4079','BlockBox','',11),(4085,'114502','watch-mobile','block-4084','Html_box','',1),(4086,'114503','watch-mobile','block-4084-2','gift\\CodeViewPdf','',1),(4087,'114504','watch-mobile','block-4079','BlockBox','',1),(4088,'114505','watch-mobile','block-4087','Text','',4),(4089,'114506','watch-mobile','block-4087','Html_box','',1),(4090,'114507','watch-mobile','block-4087','Html_box','',2),(4091,'114508','watch-mobile','block-4087','gift\\AmountViewPdf','',3),(4092,'114509','watch-mobile','block-4087','gift\\MessageViewPdf','',5),(4093,'114510','watch-mobile','block-4087','Html_box','',7),(4094,'114511','watch-mobile','block-4087','Html_box','',6),(4095,'114512','watch-mobile','gift_card_pdf','Import','',1),(4096,'114513','watch-mobile','gift_certificate','BlockBox','',1),(4097,'114514','watch-mobile','block-4096','account\\ApplyCertificate','',2),(4098,'114515','watch-mobile','block-4096','Html_box','',1),(4099,'114516','watch-mobile','gigt_card_3','BlockBox','',1),(4100,'114517','watch-mobile','block-4099','Text','',7),(4101,'114518','watch-mobile','block-4099','Text','',4),(4102,'114519','watch-mobile','block-4099','gift\\AmountView','',3),(4103,'114520','watch-mobile','block-4099','Text','',2),(4104,'114521','watch-mobile','block-4099','gift\\MessageView','',5),(4105,'114522','watch-mobile','block-4099','Text','',1),(4106,'114523','watch-mobile','block-4099','BlockBox','',9),(4107,'114524','watch-mobile','block-4106','invoice\\StoreEmail','',3),(4108,'114525','watch-mobile','block-4106','invoice\\StorePhone','',2),(4109,'114526','watch-mobile','block-4106','Text','',1),(4110,'114527','watch-mobile','block-4099','Text','',6),(4111,'114528','watch-mobile','block-4099','BlockBox','',8),(4112,'114529','watch-mobile','block-4111','Text','',1),(4113,'114530','watch-mobile','block-4111-2','gift\\CodeView','',1),(4114,'114531','watch-mobile','gigt_card_3_pdf','BlockBox','',1),(4115,'114532','watch-mobile','block-4114','BlockBox','',12),(4116,'114533','watch-mobile','block-4115','invoice\\StoreEmail','',4),(4117,'114534','watch-mobile','block-4115','invoice\\StorePhone','',3),(4118,'114535','watch-mobile','block-4115','Html_box','',1),(4119,'114536','watch-mobile','block-4114','BlockBox','',11),(4120,'114537','watch-mobile','block-4119','Html_box','',1),(4121,'114538','watch-mobile','block-4119-2','gift\\CodeViewPdf','',1),(4122,'114539','watch-mobile','block-4114','BlockBox','',1),(4123,'114540','watch-mobile','block-4122','Text','',4),(4124,'114541','watch-mobile','block-4122','Html_box','',1),(4125,'114542','watch-mobile','block-4122','Html_box','',2),(4126,'114543','watch-mobile','block-4122','gift\\AmountViewPdf','',3),(4127,'114544','watch-mobile','block-4122','gift\\MessageViewPdf','',5),(4128,'114545','watch-mobile','block-4122','Html_box','',7),(4129,'114546','watch-mobile','block-4122','Html_box','',6),(4130,'75671','watch-mobile','header','Logo','',2),(4131,'75672','watch-mobile','header','catalog\\Paging','',3),(4132,'75681','watch-mobile','header','BlockBox','header-content',3),(4133,'75682','watch-mobile','block-4132','Menu','Categories',1),(4134,'75683','watch-mobile','block-4132-2','Search','',1),(4135,'75684','watch-mobile','block-4132-3','Account','',1),(4136,'75685','watch-mobile','block-4132-4','Cart','',1),(4137,'75686','watch-mobile','info','BlockBox','',1),(4138,'75687','watch-mobile','block-4137','info\\Content','',3),(4139,'75688','watch-mobile','block-4137','info\\Title','',2),(4140,'75689','watch-mobile','invoice','invoice\\Container','',1),(4141,'75690','watch-mobile','block-4140','BlockBox','',4),(4142,'75691','watch-mobile','block-4141','BlockBox','',1),(4143,'75692','watch-mobile','block-4142','invoice\\ShippingAddress','',2),(4144,'75693','watch-mobile','block-4142','Text','',1),(4145,'75694','watch-mobile','block-4141-2','BlockBox','',1),(4146,'75695','watch-mobile','block-4145','invoice\\Totals','',1),(4147,'75696','watch-mobile','block-4140','invoice\\Products','',3),(4148,'75697','watch-mobile','block-4140','BlockBox','',1),(4149,'75698','watch-mobile','block-4148','Logo','',1),(4150,'75699','watch-mobile','block-4148-2','BlockBox','',2),(4151,'75700','watch-mobile','block-4150','Text','',1),(4152,'75701','watch-mobile','block-4150-2','invoice\\StorePhone','',1),(4153,'75702','watch-mobile','block-4148-2','BlockBox','',1),(4154,'75703','watch-mobile','block-4153','invoice\\StoreAddress','',1),(4155,'75704','watch-mobile','block-4148-2','BlockBox','',4),(4156,'75705','watch-mobile','block-4155','Text','',1),(4157,'75706','watch-mobile','block-4155-2','invoice\\StoreSite','',1),(4158,'75707','watch-mobile','block-4148-2','BlockBox','',3),(4159,'75708','watch-mobile','block-4158','Text','',1),(4160,'75709','watch-mobile','block-4158-2','invoice\\StoreEmail','',1),(4161,'75710','watch-mobile','block-4140','BlockBox','',5),(4162,'75711','watch-mobile','block-4161','Text','',1),(4163,'75712','watch-mobile','block-4161','invoice\\StoreAddress','',8),(4164,'75713','watch-mobile','block-4161-2','Text','',2),(4165,'75714','watch-mobile','block-4161-2','Logo','',1),(4166,'75715','watch-mobile','block-4161-3','BlockBox','',3),(4167,'75716','watch-mobile','block-4166','Text','',1),(4168,'75717','watch-mobile','block-4166-2','invoice\\StoreEmail','',1),(4169,'75718','watch-mobile','block-4161-3','BlockBox','',2),(4170,'75719','watch-mobile','block-4169','Text','',1),(4171,'75720','watch-mobile','block-4169-2','invoice\\StorePhone','',1),(4172,'75721','watch-mobile','block-4161-3','Text','',1),(4173,'75722','watch-mobile','block-4140','BlockBox','',2),(4174,'75723','watch-mobile','block-4173','BlockBox','',8),(4175,'75724','watch-mobile','block-4174','BlockBox','',1),(4176,'75725','watch-mobile','block-4175','Text','',1),(4177,'75726','watch-mobile','block-4175','invoice\\ShippingMethod','',2),(4178,'75727','watch-mobile','block-4174-2','BlockBox','',1),(4179,'75728','watch-mobile','block-4178','invoice\\ShippingMethod','',2),(4180,'75729','watch-mobile','block-4178','Text','',1),(4181,'75730','watch-mobile','block-4173','BlockBox','',7),(4182,'75731','watch-mobile','block-4181','BlockBox','',1),(4183,'75732','watch-mobile','block-4182','Text','',1),(4184,'75733','watch-mobile','block-4182','invoice\\BillingAddress','',2),(4185,'75734','watch-mobile','block-4181-2','BlockBox','',1),(4186,'75735','watch-mobile','block-4185','invoice\\CustomerPhone','',4),(4187,'75736','watch-mobile','block-4185','Text','',1),(4188,'75737','watch-mobile','block-4185','invoice\\CustomerName','',2),(4189,'75738','watch-mobile','block-4185','Text','',3),(4190,'75739','watch-mobile','block-4185','Text','',5),(4191,'75740','watch-mobile','block-4185','invoice\\CustomerEmail','',6),(4192,'75741','watch-mobile','block-4173-2','invoice\\PaymentMethod','',5),(4193,'75742','watch-mobile','block-4173-2','invoice\\PaymentDate','',3),(4194,'75743','watch-mobile','block-4173-2','invoice\\OrderId','',1),(4195,'75744','watch-mobile','block-4173-2','invoice\\OrderBarcode','',6),(4196,'75745','watch-mobile','block-4173-2','Text','',2),(4197,'75746','watch-mobile','block-4173-2','Text','',4),(4198,'94802','watch-mobile','login_account','BlockBox','',1),(4199,'94803','watch-mobile','block-4198','Tabs','',2),(4200,'94804','watch-mobile','block-4199-1','login\\Returning','',1),(4201,'94809','watch-mobile','block-4199-2','login\\Register','',2),(4202,'94810','watch-mobile','block-4198','BlockBox','',1),(4203,'94811','watch-mobile','block-4202','Html_box','',3),(4204,'94812','watch-mobile','block-4202','Html_box','',1),(4205,'94813','watch-mobile','block-4202','login\\Socials','',2),(4206,'114547','watch-mobile','login_checkout','BlockBox','',1),(4207,'114548','watch-mobile','block-4206','BlockBox','',1),(4208,'114549','watch-mobile','block-4207','Html_box','',2),(4209,'114550','watch-mobile','block-4207','checkout\\CreateBtn','',5),(4210,'114551','watch-mobile','block-4207','checkout\\GuestBtn','',3),(4211,'114552','watch-mobile','block-4207','Html_box','',4),(4212,'114553','watch-mobile','block-4207','BlockBox','',6),(4213,'114554','watch-mobile','block-4212','Html_box','',1),(4214,'114555','watch-mobile','block-4212','login\\Socials','',2),(4215,'114556','watch-mobile','block-4207','login\\Returning','',1),(4216,'114557','watch-mobile','block-4207','Html_box','',1),(4217,'114558','watch-mobile','login_checkout2','BlockBox','',1),(4218,'114559','watch-mobile','block-4217','Html_box','',1),(4219,'114560','watch-mobile','block-4217','Html_box','',3),(4220,'114561','watch-mobile','block-4217','login\\Socials','',2),(4221,'114562','watch-mobile','block-4217','Tabs','',4),(4222,'114563','watch-mobile','block-4221-1','BlockBox','',1),(4223,'114564','watch-mobile','block-4222','Html_box','',1),(4224,'114565','watch-mobile','block-4222-2','BlockBox','',1),(4225,'114566','watch-mobile','block-4224','Html_box','',2),(4226,'114567','watch-mobile','block-4224','login\\Guest','',1),(4227,'114568','watch-mobile','block-4221-2','login\\Returning','',1),(4228,'114569','watch-mobile','block-4221-3','BlockBox','',1),(4229,'114570','watch-mobile','block-4228','Html_box','',1),(4230,'114571','watch-mobile','block-4228-2','BlockBox','',1),(4231,'114572','watch-mobile','block-4230','login\\Register','',1),(4232,'114573','watch-mobile','block-4230','Html_box','',2),(4233,'114574','watch-mobile','login_checkout2_q','BlockBox','',1),(4234,'114575','watch-mobile','block-4233','login\\Socials','',2),(4235,'114576','watch-mobile','block-4233','Html_box','',1),(4236,'114577','watch-mobile','block-4233','Html_box','',3),(4237,'114578','watch-mobile','block-4233','Tabs','',4),(4238,'114579','watch-mobile','block-4237-1','BlockBox','',1),(4239,'114580','watch-mobile','block-4238','Html_box','',1),(4240,'114581','watch-mobile','block-4238-2','quote\\FastOrder','',1),(4241,'114582','watch-mobile','block-4237-2','login\\Returning','',1),(4242,'114583','watch-mobile','block-4237-3','BlockBox','',1),(4243,'114584','watch-mobile','block-4242','Html_box','',1),(4244,'114585','watch-mobile','block-4242','Import','',2),(4245,'114586','watch-mobile','block-4242-2','BlockBox','',1),(4246,'114587','watch-mobile','block-4245','Html_box','',2),(4247,'114588','watch-mobile','block-4245','login\\Register','',1),(4248,'114589','watch-mobile','login_checkout2_s','BlockBox','',1),(4249,'114590','watch-mobile','block-4248','Html_box','',1),(4250,'114591','watch-mobile','block-4248','Tabs','',4),(4251,'114592','watch-mobile','block-4250-1','BlockBox','',1),(4252,'114593','watch-mobile','block-4251','Html_box','',1),(4253,'114594','watch-mobile','block-4251-2','quote\\FastOrder','',1),(4254,'114595','watch-mobile','block-4250-2','login\\Returning','',1),(4255,'114596','watch-mobile','block-4250-3','BlockBox','',1),(4256,'114597','watch-mobile','block-4255','Html_box','',1),(4257,'114598','watch-mobile','block-4255-2','BlockBox','',1),(4258,'114599','watch-mobile','block-4257','Html_box','',2),(4259,'114600','watch-mobile','block-4257','login\\Register','',1),(4260,'114601','watch-mobile','block-4248','login\\Socials','',2),(4261,'114602','watch-mobile','block-4248','Html_box','',3),(4262,'114603','watch-mobile','login_checkout_q','BlockBox','',1),(4263,'114604','watch-mobile','block-4262','BlockBox','',1),(4264,'114605','watch-mobile','block-4263','checkout\\CreateBtn','',5),(4265,'114606','watch-mobile','block-4263','checkout\\GuestBtn','',2),(4266,'114607','watch-mobile','block-4263','Html_box','',1),(4267,'114608','watch-mobile','block-4263','Html_box','',4),(4268,'114609','watch-mobile','block-4263','BlockBox','',6),(4269,'114610','watch-mobile','block-4268','login\\Socials','',2),(4270,'114611','watch-mobile','block-4268','Html_box','',1),(4271,'114612','watch-mobile','block-4263-2','login\\Returning','',2),(4272,'114613','watch-mobile','block-4263-2','Html_box','',1),(4273,'114614','watch-mobile','login_checkout_s','BlockBox','',1),(4274,'114615','watch-mobile','block-4273','BlockBox','',1),(4275,'114616','watch-mobile','block-4274','BlockBox','',5),(4276,'114617','watch-mobile','block-4275','Html_box','',1),(4277,'114618','watch-mobile','block-4275','login\\Socials','',2),(4278,'114619','watch-mobile','block-4274','Html_box','',3),(4279,'114620','watch-mobile','block-4274','checkout\\CreateBtn','',4),(4280,'114621','watch-mobile','block-4274','Html_box','',1),(4281,'114622','watch-mobile','block-4274','checkout\\GuestBtn','',2),(4282,'114623','watch-mobile','block-4274-2','Html_box','',1),(4283,'114624','watch-mobile','block-4274-2','login\\Returning','',2),(4284,'114625','watch-mobile','logoff','BlockBox','',1),(4285,'114626','watch-mobile','block-4284','Html_box','',1),(4286,'114627','watch-mobile','logoff_forever','BlockBox','',1),(4287,'114628','watch-mobile','block-4286','Html_box','',1),(4288,'75747','watch-mobile','main','BlockBox','main-content',5),(4289,'75748','watch-mobile','block-4288','TopCategories','',1),(4290,'75749','watch-mobile','block-4288','PromoCode','',2),(4291,'75750','watch-mobile','block-4288','Tabs','',3),(4292,'75751','watch-mobile','block-4291-1','NewProducts','4',1),(4293,'75752','watch-mobile','block-4291-2','SpecialsProducts','4',1),(4294,'75753','watch-mobile','block-4291-3','FeaturedProducts','4',1),(4295,'75754','watch-mobile','main','Heading','',2),(4296,'75755','watch-mobile','main','BlockBox','',6),(4297,'75756','watch-mobile','block-4296','BlockBox','',1),(4298,'75757','watch-mobile','block-4297','Bestsellers','10',1),(4299,'75758','watch-mobile','block-4297-2','Reviews','4',1),(4300,'114629','watch-mobile','manufacturers','BlockBox','',1),(4301,'114630','watch-mobile','block-4300','Html_box','',1),(4302,'114631','watch-mobile','block-4300','Brands','',2),(4303,'114632','watch-mobile','messages-index','BlockBox','',1),(4304,'114633','watch-mobile','block-4303','BlockBox','',1),(4305,'114634','watch-mobile','block-4304','BlockBox','',1),(4306,'114635','watch-mobile','block-4305','Messages\\Sidebar','',1),(4307,'114636','watch-mobile','block-4304-2','Messages\\Listing','',1),(4308,'114637','watch-mobile','messages-new','BlockBox','',1),(4309,'114638','watch-mobile','block-4308','BlockBox','',1),(4310,'114639','watch-mobile','block-4309','Messages\\Sidebar','',1),(4311,'114640','watch-mobile','block-4309-2','Messages\\NewMessage','',1),(4312,'114641','watch-mobile','messages-view','BlockBox','',1),(4313,'114642','watch-mobile','block-4312','BlockBox','',1),(4314,'114643','watch-mobile','block-4313','Messages\\Sidebar','',1),(4315,'114644','watch-mobile','block-4313-2','Messages\\Message','',1),(4316,'114645','watch-mobile','my_password','BlockBox','',1),(4317,'114646','watch-mobile','block-4316','BlockBox','',1),(4318,'114647','watch-mobile','block-4317','WidgetsAria','',1),(4319,'114648','watch-mobile','block-4317-2','account\\ChangePassword','',2),(4320,'114649','watch-mobile','block-4317-2','Html_box','',1),(4321,'114650','watch-mobile','block-4317-2','account\\AccountLink','',3),(4322,'114651','watch-mobile','need_login','BlockBox','',1),(4323,'114652','watch-mobile','block-4322','BlockBox','',1),(4324,'114653','watch-mobile','block-4322','Tabs','',2),(4325,'114654','watch-mobile','block-4324-1','login\\Returning','',1),(4326,'114655','watch-mobile','block-4324-2','BlockBox','',1),(4327,'114656','watch-mobile','block-4326','Html_box','',1),(4328,'114657','watch-mobile','block-4326-2','BlockBox','',1),(4329,'114658','watch-mobile','block-4328','login\\Register','',1),(4330,'114659','watch-mobile','block-4328','Html_box','',2),(4331,'114660','watch-mobile','new-topic','BlockBox','',1),(4332,'114661','watch-mobile','block-4331','Communication\\NewTopic','',3),(4333,'114662','watch-mobile','block-4331','Html_box','',1),(4334,'114663','watch-mobile','block-4331','Breadcrumb','',2),(4335,'114664','watch-mobile','nnnn','BlockBox','',1),(4336,'114665','watch-mobile','block-4335','catalog\\Title','',1),(4337,'114666','watch-mobile','block-4335','BlockBox','',2),(4338,'114667','watch-mobile','block-4337','Filters','',1),(4339,'114668','watch-mobile','block-4337-2','Listing','',5),(4340,'114669','watch-mobile','block-4337-2','catalog\\Image','',1),(4341,'114670','watch-mobile','block-4337-2','BlockBox','',6),(4342,'114671','watch-mobile','block-4341','catalog\\CountsItems','',1),(4343,'114672','watch-mobile','block-4341-2','catalog\\Paging','',1),(4344,'114673','watch-mobile','block-4337-2','catalog\\ImageMapCategory','',3),(4345,'114674','watch-mobile','block-4337-2','Categories','',2),(4346,'114675','watch-mobile','block-4337-2','BlockBox','',4),(4347,'114676','watch-mobile','block-4346','catalog\\ListingLook','',1),(4348,'114677','watch-mobile','block-4346','catalog\\ItemsOnPage','',4),(4349,'114678','watch-mobile','block-4346','catalog\\CompareButton','',2),(4350,'114679','watch-mobile','block-4346','catalog\\Sorting','',3),(4351,'114680','watch-mobile','no-logged','BlockBox','',1),(4352,'114681','watch-mobile','block-4351','Html_box','',1),(4353,'114682','watch-mobile','block-4351','Communication\\NewTopic','',2),(4354,'114683','watch-mobile','no_filters','BlockBox','',1),(4355,'114684','watch-mobile','block-4354','BlockBox','',2),(4356,'114685','watch-mobile','block-4355','catalog\\Image','',1),(4357,'114686','watch-mobile','block-4355','BlockBox','',2),(4358,'114687','watch-mobile','block-4357','catalog\\Sorting','',3),(4359,'114688','watch-mobile','block-4357','catalog\\ItemsOnPage','',4),(4360,'114689','watch-mobile','block-4357','HeaderStock','',5),(4361,'114690','watch-mobile','block-4357','catalog\\CompareButton','',2),(4362,'114691','watch-mobile','block-4357','catalog\\ListingLook','',1),(4363,'114692','watch-mobile','block-4354','BlockBox','',4),(4364,'114693','watch-mobile','block-4363','catalog\\CountsItems','',1),(4365,'114694','watch-mobile','block-4363-2','catalog\\Paging','',1),(4366,'114695','watch-mobile','block-4354','catalog\\B2bAddButton','',5),(4367,'114696','watch-mobile','block-4354','catalog\\Title','',1),(4368,'114697','watch-mobile','block-4354','Listing','',3),(4369,'114698','watch-mobile','order_history','BlockBox','',1),(4370,'114699','watch-mobile','block-4369','BlockBox','',1),(4371,'114700','watch-mobile','block-4370','WidgetsAria','',1),(4372,'114701','watch-mobile','block-4370-2','account\\OrdersHistory','',2),(4373,'114702','watch-mobile','block-4370-2','Html_box','',1),(4374,'114703','watch-mobile','order_history_info','BlockBox','',1),(4375,'114704','watch-mobile','block-4374','BlockBox','',1),(4376,'114705','watch-mobile','block-4375','WidgetsAria','',1),(4377,'114706','watch-mobile','block-4375-2','account\\OrderReorderButton','',2),(4378,'114707','watch-mobile','block-4375-2','BlockBox','',7),(4379,'114708','watch-mobile','block-4378','BlockBox','',3),(4380,'114709','watch-mobile','block-4379','account\\AccountLink','',3),(4381,'114710','watch-mobile','block-4379','Html_box','',1),(4382,'114711','watch-mobile','block-4379','account\\OrderTracking','',2),(4383,'114712','watch-mobile','block-4378','BlockBox','',2),(4384,'114713','watch-mobile','block-4383','Html_box','',1),(4385,'114714','watch-mobile','block-4383','account\\OrderData','',2),(4386,'114715','watch-mobile','block-4378','BlockBox','',1),(4387,'114716','watch-mobile','block-4386','account\\OrderData','',2),(4388,'114717','watch-mobile','block-4386','Html_box','',1),(4389,'114718','watch-mobile','block-4378-2','BlockBox','',1),(4390,'114719','watch-mobile','block-4389','Html_box','',1),(4391,'114720','watch-mobile','block-4389','account\\OrderData','',2),(4392,'114721','watch-mobile','block-4378-2','BlockBox','',2),(4393,'114722','watch-mobile','block-4392','Html_box','',1),(4394,'114723','watch-mobile','block-4392','account\\OrderData','',2),(4395,'114724','watch-mobile','block-4378-3','BlockBox','',1),(4396,'114725','watch-mobile','block-4395','Html_box','',1),(4397,'114726','watch-mobile','block-4395','account\\OrderData','',2),(4398,'114727','watch-mobile','block-4378-3','BlockBox','',2),(4399,'114728','watch-mobile','block-4398','Html_box','',1),(4400,'114729','watch-mobile','block-4398','account\\OrderData','',2),(4401,'114730','watch-mobile','block-4375-2','account\\OrderDownload','',6),(4402,'114731','watch-mobile','block-4375-2','account\\OrderProducts','',9),(4403,'114732','watch-mobile','block-4375-2','Html_box','',11),(4404,'114733','watch-mobile','block-4375-2','account\\OrderHeading','',1),(4405,'114734','watch-mobile','block-4375-2','account\\OrderHistory','',12),(4406,'114735','watch-mobile','block-4375-2','account\\OrderCancelAndReorder','',4),(4407,'114736','watch-mobile','block-4375-2','Html_box','',8),(4408,'114737','watch-mobile','block-4375-2','account\\OrderSubTotals','',10),(4409,'114738','watch-mobile','block-4375-2','account\\OrderPayButton','',5),(4410,'114739','watch-mobile','block-4375-2','account\\OrderInvoiceButton','',3),(4411,'114740','watch-mobile','block-4375-2','BlockBox','',13),(4412,'114741','watch-mobile','block-4411','account\\AccountLink','',1),(4413,'114742','watch-mobile','block-4411-2','account\\OrderInvoiceButton','',1),(4414,'114743','watch-mobile','order_pay','BlockBox','',1),(4415,'114744','watch-mobile','block-4414','BlockBox','',1),(4416,'114745','watch-mobile','block-4415','WidgetsAria','',1),(4417,'114746','watch-mobile','block-4415-2','account\\OrderSubTotals','',5),(4418,'114747','watch-mobile','block-4415-2','account\\OrderHeading','',1),(4419,'114748','watch-mobile','block-4415-2','Html_box','',3),(4420,'114749','watch-mobile','block-4415-2','UpdateAndPay\\PayForm','',6),(4421,'114750','watch-mobile','block-4415-2','BlockBox','',2),(4422,'114751','watch-mobile','block-4421','BlockBox','',4),(4423,'114752','watch-mobile','block-4422','Html_box','',1),(4424,'114753','watch-mobile','block-4422','account\\OrderData','',2),(4425,'114754','watch-mobile','block-4421','BlockBox','',1),(4426,'114755','watch-mobile','block-4425','Html_box','',1),(4427,'114756','watch-mobile','block-4425','account\\OrderData','',2),(4428,'114757','watch-mobile','block-4421-2','BlockBox','',2),(4429,'114758','watch-mobile','block-4428','account\\OrderData','',2),(4430,'114759','watch-mobile','block-4428','Html_box','',1),(4431,'114760','watch-mobile','block-4421-2','BlockBox','',1),(4432,'114761','watch-mobile','block-4431','Html_box','',1),(4433,'114762','watch-mobile','block-4431','account\\OrderData','',2),(4434,'114763','watch-mobile','block-4421-3','BlockBox','',2),(4435,'114764','watch-mobile','block-4434','Html_box','',1),(4436,'114765','watch-mobile','block-4434','account\\OrderData','',2),(4437,'114766','watch-mobile','block-4421-3','BlockBox','',1),(4438,'114767','watch-mobile','block-4437','account\\OrderData','',2),(4439,'114768','watch-mobile','block-4437','Html_box','',1),(4440,'114769','watch-mobile','block-4415-2','account\\OrderProducts','',4),(4441,'75759','watch-mobile','packingslip','invoice\\Container','',2),(4442,'75760','watch-mobile','block-4441','packingslip\\Products','',3),(4443,'75761','watch-mobile','block-4441','BlockBox','',2),(4444,'75762','watch-mobile','block-4443','BlockBox','',2),(4445,'75763','watch-mobile','block-4444','BlockBox','',1),(4446,'75764','watch-mobile','block-4445','Text','',1),(4447,'75765','watch-mobile','block-4445','invoice\\ShippingAddress','',2),(4448,'75766','watch-mobile','block-4444-2','BlockBox','',1),(4449,'75767','watch-mobile','block-4448','invoice\\CustomerEmail','',6),(4450,'75768','watch-mobile','block-4448','invoice\\CustomerName','',2),(4451,'75769','watch-mobile','block-4448','invoice\\CustomerPhone','',4),(4452,'75770','watch-mobile','block-4448','Text','',5),(4453,'75771','watch-mobile','block-4448','Text','',1),(4454,'75772','watch-mobile','block-4448','Text','',3),(4455,'75773','watch-mobile','block-4443','BlockBox','',3),(4456,'75774','watch-mobile','block-4455','BlockBox','',1),(4457,'75775','watch-mobile','block-4456','invoice\\ShippingMethod','',2),(4458,'75776','watch-mobile','block-4456','Text','',1),(4459,'75777','watch-mobile','block-4455-2','BlockBox','',1),(4460,'75778','watch-mobile','block-4459','Text','',1),(4461,'75779','watch-mobile','block-4459','invoice\\ShippingMethod','',2),(4462,'75780','watch-mobile','block-4443-2','invoice\\AddressQrcode','',1),(4463,'75781','watch-mobile','block-4441','BlockBox','',4),(4464,'75782','watch-mobile','block-4463','Text','',1),(4465,'75783','watch-mobile','block-4463','invoice\\StoreAddress','',2),(4466,'75784','watch-mobile','block-4441','BlockBox','',1),(4467,'75785','watch-mobile','block-4466','Logo','',1),(4468,'75786','watch-mobile','block-4466-2','BlockBox','',1),(4469,'75787','watch-mobile','block-4468','invoice\\StoreAddress','',1),(4470,'75788','watch-mobile','block-4466-2','BlockBox','',2),(4471,'75789','watch-mobile','block-4470','Text','',2),(4472,'75790','watch-mobile','block-4470-2','invoice\\StorePhone','',1),(4473,'75791','watch-mobile','block-4466-2','BlockBox','',4),(4474,'75792','watch-mobile','block-4473','Text','',2),(4475,'75793','watch-mobile','block-4473-2','invoice\\StoreSite','',1),(4476,'75794','watch-mobile','block-4466-2','BlockBox','',3),(4477,'75795','watch-mobile','block-4476','Text','',2),(4478,'75796','watch-mobile','block-4476-2','invoice\\StoreEmail','',1),(4479,'114770','watch-mobile','password_forgotten','BlockBox','',1),(4480,'114771','watch-mobile','block-4479','Html_box','',1),(4481,'114772','watch-mobile','block-4479','BlockBox','',2),(4482,'114773','watch-mobile','block-4481-2','login\\PasswordForgotten','',2),(4483,'114774','watch-mobile','block-4481-2','Html_box','',1),(4484,'75797','watch-mobile','pdf','invoice\\Container','',1),(4485,'75798','watch-mobile','block-4484','BlockBox','',1),(4486,'75799','watch-mobile','block-4485','BlockBox','',1),(4487,'75800','watch-mobile','block-4486','BlockBox','',2),(4488,'75801','watch-mobile','block-4487','pdf\\ProductElement','',1),(4489,'75802','watch-mobile','block-4487-2','pdf\\ProductElement','',2),(4490,'75803','watch-mobile','block-4487-2','pdf\\ProductElement','',1),(4491,'75804','watch-mobile','block-4486','BlockBox','',1),(4492,'75805','watch-mobile','block-4491','pdf\\ProductElement','',1),(4493,'75806','watch-mobile','block-4485-2','BlockBox','',1),(4494,'75807','watch-mobile','block-4493','BlockBox','',1),(4495,'75808','watch-mobile','block-4494','pdf\\ProductElement','',1),(4496,'75809','watch-mobile','block-4493','BlockBox','',2),(4497,'75810','watch-mobile','block-4496','pdf\\ProductElement','',1),(4498,'75811','watch-mobile','block-4496-2','pdf\\ProductElement','',2),(4499,'75812','watch-mobile','block-4496-2','pdf\\ProductElement','',1),(4500,'75813','watch-mobile','pdf_category','pdf\\CategoryName','',2),(4501,'75814','watch-mobile','pdf_category','pdf\\CategoryImage','',1),(4502,'75815','watch-mobile','pdf_cover','invoice\\Container','',1),(4503,'75816','watch-mobile','block-4502','Logo','',1),(4504,'75817','watch-mobile','block-4502','Text','',3),(4505,'75818','watch-mobile','pdf_footer','BlockBox','',1),(4506,'75819','watch-mobile','block-4505-2','pdf\\PageNumber','',1),(4507,'75820','watch-mobile','pdf_header','pdf\\CategoryName','',1),(4508,'114775','watch-mobile','personal_catalog','BlockBox','',1),(4509,'114776','watch-mobile','block-4508','BlockBox','',1),(4510,'114777','watch-mobile','block-4509','WidgetsAria','',1),(4511,'114778','watch-mobile','block-4509-2','Html_box','',1),(4512,'114779','watch-mobile','block-4509-2','account\\PersonalCatalog','',2),(4513,'114780','watch-mobile','points_earnt_history','BlockBox','',1),(4514,'114781','watch-mobile','block-4513','Html_box','',1),(4515,'114782','watch-mobile','block-4513','account\\PointsEarntHistory','',2),(4516,'114783','watch-mobile','posts','BlockBox','',1),(4517,'114784','watch-mobile','block-4516','Breadcrumb','',2),(4518,'114785','watch-mobile','block-4516','Communication\\Post','',3),(4519,'114786','watch-mobile','block-4516','Html_box','',1),(4520,'75821','watch-mobile','product','BlockBox','',1),(4521,'75822','watch-mobile','block-4520','BlockBox','',5),(4522,'75823','watch-mobile','block-4521','product\\Stock','',2),(4523,'75824','watch-mobile','block-4521','product\\Price','',1),(4524,'75825','watch-mobile','block-4521-2','product\\Quantity','',1),(4525,'75826','watch-mobile','block-4520','product\\Bundle','',6),(4526,'75827','watch-mobile','block-4520','product\\Video','',3),(4527,'75828','watch-mobile','block-4520','product\\Documents','',16),(4528,'75829','watch-mobile','block-4520','product\\Buttons','',7),(4529,'75830','watch-mobile','block-4520','product\\Images','',2),(4530,'75831','watch-mobile','block-4520','product\\Name','',1),(4531,'75832','watch-mobile','block-4520','BlockBox','',8),(4532,'75833','watch-mobile','block-4531','product\\WishlistButton','',1),(4533,'75834','watch-mobile','block-4531','product\\PersonalCatalogButton','',2),(4534,'75835','watch-mobile','block-4531','product\\WeddingRegistryButton','',3),(4535,'75836','watch-mobile','block-4520','product\\BonusPoints','',9),(4536,'75837','watch-mobile','block-4520','product\\CrossSell','',13),(4537,'75838','watch-mobile','block-4520','product\\AlsoPurchased','10',11),(4538,'75839','watch-mobile','block-4520','product\\InBundles','',14),(4539,'75840','watch-mobile','block-4520','Tabs','',12),(4540,'75841','watch-mobile','block-4539-1','product\\Description','',1),(4541,'75842','watch-mobile','block-4539-1','product\\Properties','',2),(4542,'75843','watch-mobile','block-4539-2','product\\Reviews','',1),(4543,'75844','watch-mobile','block-4520','product\\Attributes','',4),(4544,'75845','watch-mobile','block-4520','product\\Configurator','',10),(4545,'75846','watch-mobile','block-4520','ViewedProducts','',15),(4546,'75847','watch-mobile','product-bottom','product\\Properties','',1),(4547,'75848','watch-mobile','product-tabs','product\\Reviews','',2),(4548,'75849','watch-mobile','product-tabs','product\\Description','',1),(4549,'75850','watch-mobile','product-top-left','product\\Images','',1),(4550,'75851','watch-mobile','product-top-right','product\\Attributes','',3),(4551,'75852','watch-mobile','product-top-right','product\\Buttons','',6),(4552,'75853','watch-mobile','product-top-right','product\\Quantity','',6),(4553,'75854','watch-mobile','product-top-right','product\\Quantity','',5),(4554,'75855','watch-mobile','product-top-right','product\\Name','',1),(4555,'75856','watch-mobile','product-top-right','product\\Price','',2),(4556,'75888','watch-mobile','productListing','BlockBox','listing-item',1),(4557,'75890','watch-mobile','block-4556','productListing\\model','',7),(4558,'75891','watch-mobile','block-4556','productListing\\bonusPoints','',6),(4559,'75892','watch-mobile','block-4556','productListing\\description','',5),(4560,'75893','watch-mobile','block-4556','productListing\\buyButton','',9),(4561,'75894','watch-mobile','block-4556','productListing\\rating','',3),(4562,'75895','watch-mobile','block-4556','productListing\\image','',1),(4563,'75896','watch-mobile','block-4556','BlockBox','',8),(4564,'75897','watch-mobile','block-4563','productListing\\price','',1),(4565,'75898','watch-mobile','block-4563-2','productListing\\qtyInput','',1),(4566,'75899','watch-mobile','block-4556','productListing\\name','',4),(4567,'75900','watch-mobile','block-4556','productListing\\stock','',2),(4568,'75857','watch-mobile','products','BlockBox','catalog-content',1),(4569,'75858','watch-mobile','block-4568','Filters','',3),(4570,'75859','watch-mobile','block-4568','catalog\\Paging','',5),(4571,'75860','watch-mobile','block-4568','catalog\\Title','',1),(4572,'75861','watch-mobile','block-4568','catalog\\Image','',2),(4573,'75862','watch-mobile','block-4568','BlockBox','catalog-features',4),(4574,'75863','watch-mobile','block-4573','catalog\\Sorting','',1),(4575,'75864','watch-mobile','block-4573-2','catalog\\CountsItems','',1),(4576,'75865','watch-mobile','block-4568','Listing','',7),(4577,'114787','watch-mobile','products-list','packingslip\\AllProductsList','',2),(4578,'114788','watch-mobile','promotions','BlockBox','',1),(4579,'114789','watch-mobile','block-4578','promotions\\PromoList','',2),(4580,'114790','watch-mobile','block-4578','Html_box','',1),(4581,'114791','watch-mobile','purchase','invoice\\Container','',1),(4582,'114792','watch-mobile','block-4581','BlockBox','',4),(4583,'114793','watch-mobile','block-4582','BlockBox','',1),(4584,'114794','watch-mobile','block-4583','Text','',1),(4585,'114795','watch-mobile','block-4583','invoice\\ShippingAddress','',2),(4586,'114796','watch-mobile','block-4581','BlockBox','',2),(4587,'114797','watch-mobile','block-4586','BlockBox','',7),(4588,'114798','watch-mobile','block-4587','BlockBox','',1),(4589,'114799','watch-mobile','block-4588','Text','',1),(4590,'114800','watch-mobile','block-4588','invoice\\BillingAddress','',2),(4591,'114801','watch-mobile','block-4587-2','BlockBox','',1),(4592,'114802','watch-mobile','block-4591','Text','',1),(4593,'114803','watch-mobile','block-4591','Text','',3),(4594,'114804','watch-mobile','block-4591','Text','',5),(4595,'114805','watch-mobile','block-4591','invoice\\CustomerName','',2),(4596,'114806','watch-mobile','block-4591','invoice\\CustomerPhone','',4),(4597,'114807','watch-mobile','block-4591','invoice\\CustomerEmail','',6),(4598,'114808','watch-mobile','block-4586-2','Text','',2),(4599,'114809','watch-mobile','block-4586-2','invoice\\PaymentDate','',3),(4600,'114810','watch-mobile','block-4586-2','invoice\\OrderId','',1),(4601,'114811','watch-mobile','block-4581','BlockBox','',1),(4602,'114812','watch-mobile','block-4601','Logo','',1),(4603,'114813','watch-mobile','block-4601-2','BlockBox','',1),(4604,'114814','watch-mobile','block-4603','invoice\\StoreAddress','',1),(4605,'114815','watch-mobile','block-4601-2','BlockBox','',3),(4606,'114816','watch-mobile','block-4605','Text','',1),(4607,'114817','watch-mobile','block-4605-2','invoice\\StoreEmail','',1),(4608,'114818','watch-mobile','block-4601-2','BlockBox','',4),(4609,'114819','watch-mobile','block-4608','Text','',1),(4610,'114820','watch-mobile','block-4608-2','invoice\\StoreSite','',1),(4611,'114821','watch-mobile','block-4601-2','BlockBox','',2),(4612,'114822','watch-mobile','block-4611','Text','',1),(4613,'114823','watch-mobile','block-4611-2','invoice\\StorePhone','',1),(4614,'114824','watch-mobile','block-4581','BlockBox','',5),(4615,'114825','watch-mobile','block-4614','invoice\\StoreAddress','',8),(4616,'114826','watch-mobile','block-4614','Text','',1),(4617,'114827','watch-mobile','block-4614-2','Text','',2),(4618,'114828','watch-mobile','block-4614-2','Logo','',1),(4619,'114829','watch-mobile','block-4614-3','BlockBox','',2),(4620,'114830','watch-mobile','block-4619','Text','',1),(4621,'114831','watch-mobile','block-4619-2','invoice\\StorePhone','',1),(4622,'114832','watch-mobile','block-4614-3','Text','',1),(4623,'114833','watch-mobile','block-4614-3','BlockBox','',3),(4624,'114834','watch-mobile','block-4623','Text','',1),(4625,'114835','watch-mobile','block-4623-2','invoice\\StoreEmail','',1),(4626,'114836','watch-mobile','block-4581','invoice\\Products','',3),(4627,'114837','watch-mobile','quotations','BlockBox','',1),(4628,'114838','watch-mobile','block-4627','BlockBox','',1),(4629,'114839','watch-mobile','block-4628','WidgetsAria','',1),(4630,'114840','watch-mobile','block-4628-2','Html_box','',1),(4631,'114841','watch-mobile','block-4628-2','Quotations\\QuotationsHistory','',2),(4632,'114842','watch-mobile','quotation_info','BlockBox','',1),(4633,'114843','watch-mobile','block-4632','BlockBox','',1),(4634,'114844','watch-mobile','block-4633','WidgetsAria','',1),(4635,'114845','watch-mobile','block-4633-2','Quotations\\QuotationHistory','',10),(4636,'114846','watch-mobile','block-4633-2','Quotations\\QuotationProducts','',7),(4637,'114847','watch-mobile','block-4633-2','Html_box','',9),(4638,'114848','watch-mobile','block-4633-2','Html_box','',6),(4639,'114849','watch-mobile','block-4633-2','Quotations\\QuotationSubTotal','',8),(4640,'114850','watch-mobile','block-4633-2','Html_box','',4),(4641,'114851','watch-mobile','block-4633-2','BlockBox','',12),(4642,'114852','watch-mobile','block-4641','account\\AccountLink','',1),(4643,'114853','watch-mobile','block-4633-2','BlockBox','',5),(4644,'114854','watch-mobile','block-4643','BlockBox','',4),(4645,'114855','watch-mobile','block-4644','Html_box','',1),(4646,'114856','watch-mobile','block-4644','Quotations\\QuotationData','',2),(4647,'114857','watch-mobile','block-4643','BlockBox','',1),(4648,'114858','watch-mobile','block-4647','Quotations\\QuotationData','',2),(4649,'114859','watch-mobile','block-4647','Html_box','',1),(4650,'114860','watch-mobile','block-4643-2','BlockBox','',2),(4651,'114861','watch-mobile','block-4650','Html_box','',1),(4652,'114862','watch-mobile','block-4650','Quotations\\QuotationData','',2),(4653,'114863','watch-mobile','block-4643-2','BlockBox','',1),(4654,'114864','watch-mobile','block-4653','Html_box','',1),(4655,'114865','watch-mobile','block-4653','Quotations\\QuotationData','',2),(4656,'114866','watch-mobile','block-4643-3','BlockBox','',1),(4657,'114867','watch-mobile','block-4656','Html_box','',1),(4658,'114868','watch-mobile','block-4656','Quotations\\QuotationData','',2),(4659,'114869','watch-mobile','block-4643-3','BlockBox','',2),(4660,'114870','watch-mobile','block-4659','Quotations\\QuotationData','',2),(4661,'114871','watch-mobile','block-4659','Html_box','',1),(4662,'75866','watch-mobile','quote','quote\\CheckoutBtn','',3),(4663,'75867','watch-mobile','quote','quote\\Products','',2),(4664,'75868','watch-mobile','quote','Text','',1),(4665,'114872','watch-mobile','review','BlockBox','',1),(4666,'114873','watch-mobile','block-4665','BlockBox','',1),(4667,'114874','watch-mobile','block-4666','WidgetsAria','',1),(4668,'114875','watch-mobile','block-4666-2','Html_box','',1),(4669,'114876','watch-mobile','block-4666-2','account\\Reviews','',2),(4670,'114877','watch-mobile','reviews','BlockBox','',1),(4671,'114878','watch-mobile','block-4670','reviews\\Content','',2),(4672,'114879','watch-mobile','block-4670','reviews\\Heading','',1),(4673,'114880','watch-mobile','rma_document','invoice\\Container','',1),(4674,'114881','watch-mobile','block-4673','BlockBox','',3),(4675,'114882','watch-mobile','block-4674','BlockBox','',1),(4676,'114883','watch-mobile','block-4675','BlockBox','',1),(4677,'114884','watch-mobile','block-4676','BlockBox','',6),(4678,'114885','watch-mobile','block-4677','Html_box','',1),(4679,'114886','watch-mobile','block-4676','BlockBox','',3),(4680,'114887','watch-mobile','block-4679','Html_box','',1),(4681,'114888','watch-mobile','block-4679-2','Html_box','',1),(4682,'114889','watch-mobile','block-4676','BlockBox','',1),(4683,'114890','watch-mobile','block-4682','Html_box','',1),(4684,'114891','watch-mobile','block-4676','BlockBox','',2),(4685,'114892','watch-mobile','block-4684','Html_box','',1),(4686,'114893','watch-mobile','block-4684-2','Html_box','',1),(4687,'114894','watch-mobile','block-4676','BlockBox','',4),(4688,'114895','watch-mobile','block-4687','Html_box','',1),(4689,'114896','watch-mobile','block-4687-2','Html_box','',1),(4690,'114897','watch-mobile','block-4676','BlockBox','',5),(4691,'114898','watch-mobile','block-4690','Html_box','',1),(4692,'114899','watch-mobile','block-4690-2','Html_box','',1),(4693,'114900','watch-mobile','block-4690-2','invoice\\StoreAddress','',2),(4694,'114901','watch-mobile','block-4675-2','BlockBox','',3),(4695,'114902','watch-mobile','block-4694','Html_box','',1),(4696,'114903','watch-mobile','block-4694-2','Html_box','',1),(4697,'114904','watch-mobile','block-4694-3','BlockBox','',1),(4698,'114905','watch-mobile','block-4697','Html_box','',1),(4699,'114906','watch-mobile','block-4697-2','Html_box','',1),(4700,'114907','watch-mobile','block-4675-2','BlockBox','',4),(4701,'114908','watch-mobile','block-4700','Html_box','',1),(4702,'114909','watch-mobile','block-4700-2','Html_box','',1),(4703,'114910','watch-mobile','block-4700-3','BlockBox','',1),(4704,'114911','watch-mobile','block-4703','Html_box','',1),(4705,'114912','watch-mobile','block-4703-2','Html_box','',1),(4706,'114913','watch-mobile','block-4675-2','BlockBox','',2),(4707,'114914','watch-mobile','block-4706','Html_box','',1),(4708,'114915','watch-mobile','block-4706','Html_box','',2),(4709,'114916','watch-mobile','block-4706','Html_box','',3),(4710,'114917','watch-mobile','block-4706','Html_box','',4),(4711,'114918','watch-mobile','block-4706','Html_box','',5),(4712,'114919','watch-mobile','block-4675-2','BlockBox','',1),(4713,'114920','watch-mobile','block-4712','BlockBox','',1),(4714,'114921','watch-mobile','block-4713','BlockBox','',1),(4715,'114922','watch-mobile','block-4714','Rma\\DocumentData','',2),(4716,'114923','watch-mobile','block-4714-3','BlockBox','',1),(4717,'114924','watch-mobile','block-4716','Html_box','',1),(4718,'114925','watch-mobile','block-4716-2','Rma\\DocumentData','',1),(4719,'114926','watch-mobile','block-4713','BlockBox','',2),(4720,'114927','watch-mobile','block-4719-2','invoice\\StoreAddress','',1),(4721,'114928','watch-mobile','block-4673','BlockBox','',2),(4722,'114929','watch-mobile','block-4721','Rma\\Products','',2),(4723,'114930','watch-mobile','block-4721','Html_box','',1),(4724,'114931','watch-mobile','block-4673','BlockBox','',1),(4725,'114932','watch-mobile','block-4724','BlockBox','',1),(4726,'114933','watch-mobile','block-4725','BlockBox','',1),(4727,'114934','watch-mobile','block-4726','Html_box','',2),(4728,'114935','watch-mobile','block-4726','Html_box','',1),(4729,'114936','watch-mobile','block-4725','BlockBox','',3),(4730,'114937','watch-mobile','block-4729','Html_box','',1),(4731,'114938','watch-mobile','block-4729-2','Html_box','',1),(4732,'114939','watch-mobile','block-4725','BlockBox','',2),(4733,'114940','watch-mobile','block-4732','Html_box','',1),(4734,'114941','watch-mobile','block-4732-2','Html_box','',1),(4735,'114942','watch-mobile','block-4725','BlockBox','',4),(4736,'114943','watch-mobile','block-4735','Html_box','',1),(4737,'114944','watch-mobile','block-4735-2','Html_box','',1),(4738,'114945','watch-mobile','block-4725','BlockBox','',5),(4739,'114946','watch-mobile','block-4738','Html_box','',1),(4740,'114947','watch-mobile','block-4738-2','Html_box','',1),(4741,'114948','watch-mobile','block-4724-2','BlockBox','',3),(4742,'114949','watch-mobile','block-4741','BlockBox','',1),(4743,'114950','watch-mobile','block-4742','Html_box','',1),(4744,'114951','watch-mobile','block-4742-2','Rma\\DocumentData','',1),(4745,'114952','watch-mobile','block-4741-2','BlockBox','',1),(4746,'114953','watch-mobile','block-4745','Html_box','',1),(4747,'114954','watch-mobile','block-4745-2','Rma\\DocumentData','',1),(4748,'114955','watch-mobile','block-4724-2','BlockBox','',2),(4749,'114956','watch-mobile','block-4748','BlockBox','',1),(4750,'114957','watch-mobile','block-4749','BlockBox','',1),(4751,'114958','watch-mobile','block-4750','Html_box','',1),(4752,'114959','watch-mobile','block-4750-2','Rma\\DocumentData','',1),(4753,'114960','watch-mobile','block-4749-2','BlockBox','',1),(4754,'114961','watch-mobile','block-4753','Html_box','',1),(4755,'114962','watch-mobile','block-4753-2','Rma\\DocumentData','',1),(4756,'114963','watch-mobile','block-4748','BlockBox','',2),(4757,'114964','watch-mobile','block-4756','Html_box','',1),(4758,'114965','watch-mobile','block-4756-2','Rma\\DocumentData','',1),(4759,'114966','watch-mobile','block-4748','BlockBox','',3),(4760,'114967','watch-mobile','block-4759','BlockBox','',1),(4761,'114968','watch-mobile','block-4760','Html_box','',1),(4762,'114969','watch-mobile','block-4760-2','Rma\\DocumentData','',1),(4763,'114970','watch-mobile','block-4759-2','BlockBox','',1),(4764,'114971','watch-mobile','block-4763','Html_box','',1),(4765,'114972','watch-mobile','block-4763-2','Rma\\DocumentData','',1),(4766,'114973','watch-mobile','block-4748','BlockBox','',4),(4767,'114974','watch-mobile','block-4766','BlockBox','',1),(4768,'114975','watch-mobile','block-4767','Html_box','',1),(4769,'114976','watch-mobile','block-4767-2','Rma\\DocumentData','',1),(4770,'114977','watch-mobile','block-4766-2','BlockBox','',1),(4771,'114978','watch-mobile','block-4770','Html_box','',1),(4772,'114979','watch-mobile','block-4770-2','Rma\\DocumentData','',1),(4773,'114980','watch-mobile','block-4748','BlockBox','',5),(4774,'114981','watch-mobile','block-4773','BlockBox','',1),(4775,'114982','watch-mobile','block-4774','Html_box','',1),(4776,'114983','watch-mobile','block-4774-2','Rma\\DocumentData','',1),(4777,'114984','watch-mobile','block-4773-2','BlockBox','',1),(4778,'114985','watch-mobile','block-4777','Html_box','',1),(4779,'114986','watch-mobile','block-4777-2','Rma\\DocumentData','',1),(4780,'114987','watch-mobile','block-4724-2','BlockBox','',1),(4781,'114988','watch-mobile','block-4780','Logo','',1),(4782,'114989','watch-mobile','block-4780','Html_box','',2),(4783,'114990','watch-mobile','rows','BlockBox','listing-item',1),(4784,'114991','watch-mobile','block-4783','BlockBox','',2),(4785,'114992','watch-mobile','block-4784','BlockBox','',2),(4786,'114993','watch-mobile','block-4785','BlockBox','',3),(4787,'114994','watch-mobile','block-4786','productListing\\rating','',1),(4788,'114995','watch-mobile','block-4786','productListing\\ratingCounts','',2),(4789,'114996','watch-mobile','block-4785','productListing\\bonusPoints','',1),(4790,'114997','watch-mobile','block-4785','productListing\\image','',2),(4791,'114998','watch-mobile','block-4785-2','productListing\\model','',3),(4792,'114999','watch-mobile','block-4785-2','productListing\\name','',1),(4793,'115000','watch-mobile','block-4785-2','productListing\\description','',2),(4794,'115001','watch-mobile','block-4785-2','productListing\\attributes','',4),(4795,'115002','watch-mobile','block-4784-2','BlockBox','',1),(4796,'115003','watch-mobile','block-4795','productListing\\stock','',1),(4797,'115004','watch-mobile','block-4795','productListing\\price','',2),(4798,'115005','watch-mobile','block-4795','productListing\\wishlistButton','',6),(4799,'115006','watch-mobile','block-4795','productListing\\qtyInput','',3),(4800,'115007','watch-mobile','block-4795','productListing\\compare','',5),(4801,'115008','watch-mobile','block-4795','productListing\\buyButton','',4),(4802,'75869','watch-mobile','sample','BlockBox','',1),(4803,'75870','watch-mobile','block-4802','sample\\Products','',2),(4804,'75871','watch-mobile','block-4802','sample\\CheckoutBtn','',3),(4805,'75872','watch-mobile','block-4802','Text','',1),(4806,'115009','watch-mobile','samples','BlockBox','',1),(4807,'115010','watch-mobile','block-4806','BlockBox','',1),(4808,'115011','watch-mobile','block-4807','WidgetsAria','',1),(4809,'115012','watch-mobile','block-4807-2','Html_box','',1),(4810,'115013','watch-mobile','block-4807-2','Samples\\SamplesHistory','',2),(4811,'115014','watch-mobile','sample_info','BlockBox','',1),(4812,'115015','watch-mobile','block-4811','BlockBox','',1),(4813,'115016','watch-mobile','block-4812','WidgetsAria','',1),(4814,'115017','watch-mobile','block-4812-2','Html_box','',6),(4815,'115018','watch-mobile','block-4812-2','BlockBox','',2),(4816,'115019','watch-mobile','block-4815','BlockBox','',4),(4817,'115020','watch-mobile','block-4816','Html_box','',1),(4818,'115021','watch-mobile','block-4816','Samples\\SampleData','',2),(4819,'115022','watch-mobile','block-4815','BlockBox','',1),(4820,'115023','watch-mobile','block-4819','Samples\\SampleData','',2),(4821,'115024','watch-mobile','block-4819','Html_box','',1),(4822,'115025','watch-mobile','block-4815-2','BlockBox','',1),(4823,'115026','watch-mobile','block-4822','Html_box','',1),(4824,'115027','watch-mobile','block-4822','Samples\\SampleData','',2),(4825,'115028','watch-mobile','block-4815-2','BlockBox','',2),(4826,'115029','watch-mobile','block-4825','Samples\\SampleData','',2),(4827,'115030','watch-mobile','block-4825','Html_box','',1),(4828,'115031','watch-mobile','block-4815-3','BlockBox','',1),(4829,'115032','watch-mobile','block-4828','Html_box','',1),(4830,'115033','watch-mobile','block-4828','Samples\\SampleData','',2),(4831,'115034','watch-mobile','block-4815-3','BlockBox','',2),(4832,'115035','watch-mobile','block-4831','Samples\\SampleData','',2),(4833,'115036','watch-mobile','block-4831','Html_box','',1),(4834,'115037','watch-mobile','block-4812-2','Html_box','',3),(4835,'115038','watch-mobile','block-4812-2','Samples\\SampleProducts','',4),(4836,'115039','watch-mobile','block-4812-2','Samples\\SampleSubTotal','',5),(4837,'115040','watch-mobile','block-4812-2','BlockBox','',8),(4838,'115041','watch-mobile','block-4837','account\\AccountLink','',1),(4839,'115042','watch-mobile','block-4812-2','Samples\\SampleHistory','',7),(4840,'115043','watch-mobile','block-4812-2','Html_box','',1),(4841,'115715','watch-mobile','sample_info','BlockBox','',1),(4842,'115716','watch-mobile','block-4841','BlockBox','',1),(4843,'115717','watch-mobile','block-4842','WidgetsAria','',1),(4844,'115718','watch-mobile','block-4842-2','Html_box','',3),(4845,'115719','watch-mobile','block-4842-2','account\\OrdersHistory','',4),(4846,'115720','watch-mobile','block-4842-2','Html_box','',1),(4847,'115721','watch-mobile','block-4842-2','BlockBox','',2),(4848,'115722','watch-mobile','block-4847','Html_box','',1),(4849,'115723','watch-mobile','block-4847','account\\LastOrder','',2),(4850,'115724','watch-mobile','block-4847-2','Html_box','',1),(4851,'115725','watch-mobile','block-4847-2','account\\AccountLink','',3),(4852,'115726','watch-mobile','block-4847-2','account\\OrderCount','',2),(4853,'115727','watch-mobile','block-4847-3','Html_box','',1),(4854,'115728','watch-mobile','block-4847-3','account\\TotalOrdered','',2),(4855,'115729','watch-mobile','block-4847-4','Html_box','',1),(4856,'115730','watch-mobile','block-4847-4','account\\AccountLink','',3),(4857,'115731','watch-mobile','block-4847-4','account\\CreditAmount','',2),(4858,'115732','watch-mobile','block-4847-5','account\\AccountLink','',3),(4859,'115733','watch-mobile','block-4847-5','account\\PointsEarnt','',2),(4860,'115734','watch-mobile','block-4847-5','Html_box','',1),(4861,'115735','watch-mobile','block-4842-2','BlockBox','',5),(4862,'115736','watch-mobile','block-4861','account\\GiftCards','',6),(4863,'115737','watch-mobile','block-4861','Html_box','',1),(4864,'115738','watch-mobile','block-4842-2','Html_box','',5),(4865,'115044','watch-mobile','sitemap','BlockBox','',1),(4866,'115045','watch-mobile','block-4865','BlockBox','',2),(4867,'115046','watch-mobile','block-4866','Menu','Account box',6),(4868,'115047','watch-mobile','block-4866','sitemap\\InfoPages','',2),(4869,'115048','watch-mobile','block-4866','Html_box','',5),(4870,'115049','watch-mobile','block-4866','sitemap\\Categories','',4),(4871,'115050','watch-mobile','block-4866','Html_box','',3),(4872,'115051','watch-mobile','block-4866','Html_box','',1),(4873,'115052','watch-mobile','block-4866-2','Html_box','',1),(4874,'115053','watch-mobile','block-4866-2','sitemap\\DeliveryLocation','',2),(4875,'115054','watch-mobile','block-4865','Html_box','',1),(4876,'115055','watch-mobile','subscribe','BlockBox','',1),(4877,'115056','watch-mobile','block-4876','subscribers\\SubscribeForm','',2),(4878,'115057','watch-mobile','block-4876','Html_box','',1),(4879,'115058','watch-mobile','block-4876','Html_box','',3),(4880,'115059','watch-mobile','block-4876','subscribers\\UnsubscribeForm','',4),(4881,'115060','watch-mobile','subscribed','BlockBox','',1),(4882,'115061','watch-mobile','block-4881','Html_box','',1),(4883,'115062','watch-mobile','subscription','BlockBox','',2),(4884,'115063','watch-mobile','block-4883','BlockBox','',1),(4885,'115064','watch-mobile','block-4884','WidgetsAria','',1),(4886,'115065','watch-mobile','block-4884-2','Html_box','',2),(4887,'115066','watch-mobile','block-4884-2','Html_box','',3),(4888,'115067','watch-mobile','block-4884-2','account\\Subscription','',4),(4889,'75873','watch-mobile','success','BlockBox','',1),(4890,'75874','watch-mobile','block-4889','BlockBox','',1),(4891,'75875','watch-mobile','block-4890','Text','',2),(4892,'75876','watch-mobile','block-4890','BlockBox','',3),(4893,'75877','watch-mobile','block-4892','Html','',3),(4894,'75878','watch-mobile','block-4892-2','success\\PrintBtn','',1),(4895,'75879','watch-mobile','block-4892-3','success\\ContinueBtn','',1),(4896,'115068','watch-mobile','success_q','BlockBox','',1),(4897,'115069','watch-mobile','block-4896','BlockBox','',1),(4898,'115070','watch-mobile','block-4897','BlockBox','',2),(4899,'115071','watch-mobile','block-4898','success\\PrintBtn','',1),(4900,'115072','watch-mobile','block-4898','success\\ContinueBtn','',2),(4901,'115073','watch-mobile','block-4897','Html_box','',1),(4905,'115074','watch-mobile','ticket','invoice\\Container','',1),(4906,'115075','watch-mobile','block-4905','BlockBox','',1),(4907,'115076','watch-mobile','block-4906-2','BlockBox','',1),(4908,'115077','watch-mobile','block-4907','invoice\\StoreAddress','',1),(4909,'115078','watch-mobile','block-4906-2','BlockBox','',2),(4910,'115079','watch-mobile','block-4909','Text','',1),(4911,'115080','watch-mobile','block-4909-2','invoice\\StorePhone','',1),(4912,'115081','watch-mobile','block-4906-2','BlockBox','',4),(4913,'115082','watch-mobile','block-4912','Text','',1),(4914,'115083','watch-mobile','block-4912-2','invoice\\StoreSite','',1),(4915,'115084','watch-mobile','block-4906-2','BlockBox','',3),(4916,'115085','watch-mobile','block-4915','Text','',1),(4917,'115086','watch-mobile','block-4915-2','invoice\\StoreEmail','',1),(4918,'115087','watch-mobile','block-4905','BlockBox','',2),(4919,'115088','watch-mobile','block-4918','BlockBox','',7),(4920,'115089','watch-mobile','block-4919','BlockBox','',1),(4921,'115090','watch-mobile','block-4920','Text','',1),(4922,'115091','watch-mobile','block-4920','invoice\\BillingAddress','',2),(4923,'115092','watch-mobile','block-4919-2','BlockBox','',1),(4924,'115093','watch-mobile','block-4923','Text','',3),(4925,'115094','watch-mobile','block-4923','Text','',5),(4926,'115095','watch-mobile','block-4923','Text','',1),(4927,'115096','watch-mobile','block-4923','invoice\\CustomerPhone','',4),(4928,'115097','watch-mobile','block-4923','invoice\\CustomerName','',2),(4929,'115098','watch-mobile','block-4923','invoice\\CustomerEmail','',6),(4930,'115099','watch-mobile','block-4918','BlockBox','',8),(4931,'115100','watch-mobile','block-4930','BlockBox','',1),(4932,'115101','watch-mobile','block-4931','Text','',1),(4933,'115102','watch-mobile','block-4931','invoice\\ShippingMethod','',2),(4934,'115103','watch-mobile','block-4930-2','BlockBox','',1),(4935,'115104','watch-mobile','block-4934','invoice\\ShippingMethod','',2),(4936,'115105','watch-mobile','block-4934','Text','',1),(4937,'115106','watch-mobile','block-4918-2','Text','',2),(4938,'115107','watch-mobile','block-4918-2','invoice\\OrderBarcode','',6),(4939,'115108','watch-mobile','block-4918-2','Text','',4),(4940,'115109','watch-mobile','block-4918-2','invoice\\OrderId','',1),(4941,'115110','watch-mobile','block-4918-2','invoice\\PaymentDate','',3),(4942,'115111','watch-mobile','block-4918-2','invoice\\PaymentMethod','',5),(4943,'115112','watch-mobile','block-4905','BlockBox','',5),(4944,'115113','watch-mobile','block-4943','Text','',1),(4945,'115114','watch-mobile','block-4943','invoice\\StoreAddress','',8),(4946,'115115','watch-mobile','block-4943-2','Logo','',1),(4947,'115116','watch-mobile','block-4943-2','Text','',2),(4948,'115117','watch-mobile','block-4943-3','BlockBox','',2),(4949,'115118','watch-mobile','block-4948','Text','',1),(4950,'115119','watch-mobile','block-4948-2','invoice\\StorePhone','',1),(4951,'115120','watch-mobile','block-4943-3','Text','',1),(4952,'115121','watch-mobile','block-4943-3','BlockBox','',3),(4953,'115122','watch-mobile','block-4952','Text','',1),(4954,'115123','watch-mobile','block-4952-2','invoice\\StoreEmail','',1),(4955,'115124','watch-mobile','block-4905','invoice\\Products','',3),(4956,'115125','watch-mobile','block-4905','BlockBox','',4),(4957,'115126','watch-mobile','block-4956','BlockBox','',1),(4958,'115127','watch-mobile','block-4957','invoice\\ShippingAddress','',2),(4959,'115128','watch-mobile','block-4957','Text','',1),(4960,'115129','watch-mobile','block-4956-2','BlockBox','',1),(4961,'115130','watch-mobile','block-4960','invoice\\Totals','',1),(4962,'115131','watch-mobile','tl_blog_category','BlockBox','',1),(4963,'115132','watch-mobile','block-4962','BlockBox','',1),(4964,'115133','watch-mobile','block-4963','BlockBox','',1),(4965,'115134','watch-mobile','block-4964','Blog\\widget\\PostListing','',1),(4966,'115135','watch-mobile','block-4964','catalog\\Paging','',2),(4967,'115136','watch-mobile','block-4963-2','WidgetsAria','',1),(4968,'115137','watch-mobile','tl_blog_index','BlockBox','',2),(4969,'115138','watch-mobile','block-4968','BlockBox','',2),(4970,'115139','watch-mobile','block-4969','BlockBox','',1),(4971,'115140','watch-mobile','block-4970','Blog\\widget\\PostListing','',1),(4972,'115141','watch-mobile','block-4970','catalog\\Paging','',2),(4973,'115142','watch-mobile','block-4969-2','WidgetsAria','',1),(4974,'115143','watch-mobile','block-4968','Banner','',1),(4975,'115144','watch-mobile','tl_blog_post','BlockBox','',1),(4976,'115145','watch-mobile','block-4975','BlockBox','',3),(4977,'115146','watch-mobile','block-4976','Blog\\widget\\PostTags','',2),(4978,'115147','watch-mobile','block-4976','BlockBox','',3),(4979,'115148','watch-mobile','block-4978','Html_box','',1),(4980,'115149','watch-mobile','block-4978','Blog\\widget\\PostLinkedProducts','',2),(4981,'115150','watch-mobile','block-4976','BlockBox','',1),(4982,'115151','watch-mobile','block-4981','Blog\\widget\\PostTitle','',3),(4983,'115152','watch-mobile','block-4981','Blog\\widget\\PostImage','',1),(4984,'115153','watch-mobile','block-4981','Blog\\widget\\PostDescription','',4),(4985,'115154','watch-mobile','block-4981','BlockBox','',5),(4986,'115155','watch-mobile','block-4985','Blog\\widget\\PostViewed','',1),(4987,'115156','watch-mobile','block-4981','Blog\\widget\\PostDate','',2),(4988,'115157','watch-mobile','block-4976-2','WidgetsAria','',1),(4989,'115158','watch-mobile','tl_blog_tags','BlockBox','',1),(4990,'115159','watch-mobile','block-4989','BlockBox','',1),(4991,'115160','watch-mobile','block-4990','BlockBox','',1),(4992,'115161','watch-mobile','block-4991','Blog\\widget\\PostListing','',1),(4993,'115162','watch-mobile','block-4991','catalog\\Paging','',2),(4994,'115163','watch-mobile','block-4990-2','WidgetsAria','',1),(4995,'115164','watch-mobile','tracking_numbers','BlockBox','',1),(4996,'115165','watch-mobile','block-4995','account\\OrderTracking','',2),(4997,'115166','watch-mobile','block-4995','Html_box','',1),(4998,'115167','watch-mobile','trade_form','BlockBox','',1),(4999,'115168','watch-mobile','block-4998','BlockBox','',3),(5000,'115169','watch-mobile','block-4999','BlockBox','',1),(5001,'115170','watch-mobile','block-5000','account\\CustomerAdditionalField','',2),(5002,'115171','watch-mobile','block-5000','account\\CustomerAdditionalField','',1),(5003,'115172','watch-mobile','block-4998','BlockBox','',14),(5004,'115173','watch-mobile','block-5003','account\\BackButton','',1),(5005,'115174','watch-mobile','block-5003-2','account\\PdfButton','',2),(5006,'115175','watch-mobile','block-5003-2','account\\SaveButton','',1),(5007,'115176','watch-mobile','block-4998','BlockBox','',13),(5008,'115177','watch-mobile','block-5007','BlockBox','',1),(5009,'115178','watch-mobile','block-5008','account\\CustomerAdditionalField','',1),(5010,'115179','watch-mobile','block-5007-2','BlockBox','',1),(5011,'115180','watch-mobile','block-5010','account\\CustomerAdditionalField','',1),(5012,'115181','watch-mobile','block-4998','Html_box','',10),(5013,'115182','watch-mobile','block-4998','Html_box','',8),(5014,'115183','watch-mobile','block-4998','Html_box','',12),(5015,'115184','watch-mobile','block-4998','BlockBox','',11),(5016,'115185','watch-mobile','block-5015','BlockBox','',1),(5017,'115186','watch-mobile','block-5016','account\\CustomerAdditionalField','',4),(5018,'115187','watch-mobile','block-5016','account\\CustomerAdditionalField','',2),(5019,'115188','watch-mobile','block-5016','Html_box','',1),(5020,'115189','watch-mobile','block-5016','account\\CustomerAdditionalField','',3),(5021,'115190','watch-mobile','block-5015-2','BlockBox','',1),(5022,'115191','watch-mobile','block-5021','Html_box','',1),(5023,'115192','watch-mobile','block-5021','account\\CustomerAdditionalField','',3),(5024,'115193','watch-mobile','block-5021','account\\CustomerAdditionalField','',2),(5025,'115194','watch-mobile','block-5021','account\\CustomerAdditionalField','',4),(5026,'115195','watch-mobile','block-4998','BlockBox','',5),(5027,'115196','watch-mobile','block-5026','BlockBox','',1),(5028,'115197','watch-mobile','block-5027','account\\CustomerAdditionalField','',2),(5029,'115198','watch-mobile','block-5027','account\\CustomerAdditionalField','',1),(5030,'115199','watch-mobile','block-4998','BlockBox','',4),(5031,'115200','watch-mobile','block-5030','BlockBox','',1),(5032,'115201','watch-mobile','block-5031','account\\AddressesList','',2),(5033,'115202','watch-mobile','block-5031','Html_box','',1),(5034,'115203','watch-mobile','block-5031','account\\CustomerAdditionalField','',5),(5035,'115204','watch-mobile','block-5031','BlockBox','',3),(5036,'115205','watch-mobile','block-5035','account\\CustomerAdditionalField','',1),(5037,'115206','watch-mobile','block-5031','BlockBox','',4),(5038,'115207','watch-mobile','block-5037','BlockBox','',1),(5039,'115208','watch-mobile','block-5038','account\\CustomerAdditionalField','',1),(5040,'115209','watch-mobile','block-5038','account\\CustomerAdditionalField','',4),(5041,'115210','watch-mobile','block-5038','account\\CustomerAdditionalField','',2),(5042,'115211','watch-mobile','block-5038','account\\CustomerAdditionalField','',3),(5043,'115212','watch-mobile','block-5037-2','BlockBox','',1),(5044,'115213','watch-mobile','block-5043','account\\CustomerAdditionalField','',4),(5045,'115214','watch-mobile','block-5043','account\\CustomerAdditionalField','',3),(5046,'115215','watch-mobile','block-5043','account\\CustomerAdditionalField','',2),(5047,'115216','watch-mobile','block-5043','account\\CustomerAdditionalField','',1),(5048,'115217','watch-mobile','block-5030-2','BlockBox','',1),(5049,'115218','watch-mobile','block-5048','account\\AddressesList','',2),(5050,'115219','watch-mobile','block-5048','BlockBox','',3),(5051,'115220','watch-mobile','block-5050','BlockBox','',1),(5052,'115221','watch-mobile','block-5051','account\\CustomerAdditionalField','',1),(5053,'115222','watch-mobile','block-5051','account\\CustomerAdditionalField','',2),(5054,'115223','watch-mobile','block-5050-2','BlockBox','',1),(5055,'115224','watch-mobile','block-5054','account\\CustomerAdditionalField','',1),(5056,'115225','watch-mobile','block-5048','BlockBox','',4),(5057,'115226','watch-mobile','block-5056','BlockBox','',1),(5058,'115227','watch-mobile','block-5057','account\\CustomerAdditionalField','',2),(5059,'115228','watch-mobile','block-5057','account\\CustomerAdditionalField','',1),(5060,'115229','watch-mobile','block-5057','account\\CustomerAdditionalField','',3),(5061,'115230','watch-mobile','block-5056-2','BlockBox','',1),(5062,'115231','watch-mobile','block-5061','account\\CustomerAdditionalField','',2),(5063,'115232','watch-mobile','block-5061','account\\CustomerAdditionalField','',1),(5064,'115233','watch-mobile','block-5061','account\\CustomerAdditionalField','',3),(5065,'115234','watch-mobile','block-5048','Html_box','',1),(5066,'115235','watch-mobile','block-4998','BlockBox','',9),(5067,'115236','watch-mobile','block-5066','BlockBox','',1),(5068,'115237','watch-mobile','block-5067','account\\CustomerAdditionalField','',1),(5069,'115238','watch-mobile','block-5067','account\\CustomerAdditionalField','',2),(5070,'115239','watch-mobile','block-5066-2','BlockBox','',1),(5071,'115240','watch-mobile','block-5070','account\\CustomerAdditionalField','',1),(5072,'115241','watch-mobile','block-4998','Html_box','',2),(5073,'115242','watch-mobile','block-4998','BlockBox','',7),(5074,'115243','watch-mobile','block-5073','BlockBox','',1),(5075,'115244','watch-mobile','block-5074','account\\CustomerAdditionalField','',1),(5076,'115245','watch-mobile','block-5074','account\\CustomerAdditionalField','',2),(5077,'115246','watch-mobile','block-5073-2','BlockBox','',1),(5078,'115247','watch-mobile','block-5077','account\\CustomerAdditionalField','',1),(5079,'115248','watch-mobile','block-5077','account\\CustomerAdditionalField','',2),(5080,'115249','watch-mobile','block-4998','Html_box','',1),(5081,'115250','watch-mobile','block-4998','Html_box','',6),(5082,'115251','watch-mobile','trade_form_pdf','BlockBox','',1),(5083,'115252','watch-mobile','block-5082','BlockBox','',14),(5084,'115253','watch-mobile','block-5083','Html_box','',1),(5085,'115254','watch-mobile','block-5083-2','account\\CustomerAdditionalField','',1),(5086,'115255','watch-mobile','block-5082','BlockBox','',6),(5087,'115256','watch-mobile','block-5086','Html_box','',1),(5088,'115257','watch-mobile','block-5086-2','account\\CombinedField','',2),(5089,'115258','watch-mobile','block-5082','BlockBox','',13),(5090,'115259','watch-mobile','block-5089','Html_box','',1),(5091,'115260','watch-mobile','block-5089-2','account\\CustomerAdditionalField','',1),(5092,'115261','watch-mobile','block-5082','BlockBox','',12),(5093,'115262','watch-mobile','block-5092','Html_box','',1),(5094,'115263','watch-mobile','block-5092-2','account\\CombinedField','',2),(5095,'115264','watch-mobile','block-5082','BlockBox','',11),(5096,'115265','watch-mobile','block-5095','Html_box','',1),(5097,'115266','watch-mobile','block-5095-2','account\\CombinedField','',1),(5098,'115267','watch-mobile','block-5082','BlockBox','',9),(5099,'115268','watch-mobile','block-5098','Html_box','',1),(5100,'115269','watch-mobile','block-5098-2','account\\CustomerAdditionalField','',1),(5101,'115270','watch-mobile','block-5082','BlockBox','',8),(5102,'115271','watch-mobile','block-5101','Html_box','',1),(5103,'115272','watch-mobile','block-5101-2','BlockBox','',1),(5104,'115273','watch-mobile','block-5103','account\\CustomerAdditionalField','',1),(5105,'115274','watch-mobile','block-5103-2','BlockBox','',1),(5106,'115275','watch-mobile','block-5105','Html_box','',2),(5107,'115276','watch-mobile','block-5105-2','account\\CustomerAdditionalField','',1),(5108,'115277','watch-mobile','block-5082','BlockBox','',3),(5109,'115278','watch-mobile','block-5108','Html_box','',1),(5110,'115279','watch-mobile','block-5082','BlockBox','',1),(5111,'115280','watch-mobile','block-5110','Contacts','',1),(5112,'115281','watch-mobile','block-5110-2','Html_box','',1),(5113,'115282','watch-mobile','block-5082','BlockBox','',4),(5114,'115283','watch-mobile','block-5113-2','BlockBox','',1),(5115,'115284','watch-mobile','block-5114','BlockBox','',1),(5116,'115285','watch-mobile','block-5115','Html_box','',2),(5117,'115286','watch-mobile','block-5115-2','account\\CustomerAdditionalField','',1),(5118,'115287','watch-mobile','block-5114-2','BlockBox','',1),(5119,'115288','watch-mobile','block-5118','Html_box','',1),(5120,'115289','watch-mobile','block-5118-2','account\\CustomerAdditionalField','',1),(5121,'115290','watch-mobile','block-5082','BlockBox','',2),(5122,'115291','watch-mobile','block-5121','Contacts','',1),(5123,'115292','watch-mobile','block-5082','BlockBox','',7),(5124,'115293','watch-mobile','block-5123','Html_box','',1),(5125,'115294','watch-mobile','block-5123-2','account\\CustomerAdditionalField','',1),(5126,'115295','watch-mobile','block-5082','BlockBox','',5),(5127,'115296','watch-mobile','block-5126','Html_box','',1),(5128,'115297','watch-mobile','block-5126-2','account\\CustomerAdditionalField','',1),(5129,'115298','watch-mobile','block-5082','BlockBox','',10),(5130,'115299','watch-mobile','block-5129','Html_box','',1),(5131,'115300','watch-mobile','block-5129-2','account\\CustomerAdditionalField','',1),(5132,'115301','watch-mobile','block-5082','BlockBox','',18),(5133,'115302','watch-mobile','block-5132','Html_box','',1),(5134,'115303','watch-mobile','block-5132-2','account\\CustomerAdditionalField','',1),(5135,'115304','watch-mobile','block-5082','BlockBox','',15),(5136,'115305','watch-mobile','block-5135','Html_box','',1),(5137,'115306','watch-mobile','block-5082','BlockBox','',17),(5138,'115307','watch-mobile','block-5137','Html_box','',1),(5139,'115308','watch-mobile','block-5082','BlockBox','',20),(5140,'115309','watch-mobile','block-5139','Html_box','',1),(5141,'115310','watch-mobile','block-5139-2','account\\CustomerAdditionalField','',1),(5142,'115311','watch-mobile','block-5082','BlockBox','',19),(5143,'115312','watch-mobile','block-5142','Html_box','',1),(5144,'115313','watch-mobile','block-5142-2','account\\CustomerAdditionalField','',1),(5145,'115314','watch-mobile','block-5082','BlockBox','',16),(5146,'115315','watch-mobile','block-5145','Html_box','',1),(5147,'115316','watch-mobile','block-5145-2','BlockBox','',1),(5148,'115317','watch-mobile','block-5147','account\\CustomerAdditionalField','',1),(5149,'115318','watch-mobile','block-5147-2','Html_box','',1),(5150,'115319','watch-mobile','block-5147-3','account\\CustomerAdditionalField','',1),(5151,'115320','watch-mobile','block-5145-3','BlockBox','',1),(5152,'115321','watch-mobile','block-5082','BlockBox','',23),(5153,'115322','watch-mobile','block-5152','Html_box','',1),(5154,'115323','watch-mobile','block-5152-2','account\\CustomerAdditionalField','',1),(5155,'115324','watch-mobile','block-5082','BlockBox','',21),(5156,'115325','watch-mobile','block-5155','Html_box','',1),(5157,'115326','watch-mobile','block-5082','BlockBox','',26),(5158,'115327','watch-mobile','block-5157','Html_box','',1),(5159,'115328','watch-mobile','block-5082','BlockBox','',24),(5160,'115329','watch-mobile','block-5159','Html_box','',1),(5161,'115330','watch-mobile','block-5159-2','account\\CustomerAdditionalField','',1),(5162,'115331','watch-mobile','block-5082','BlockBox','',25),(5163,'115332','watch-mobile','block-5162','Html_box','',1),(5164,'115333','watch-mobile','block-5082','BlockBox','',22),(5165,'115334','watch-mobile','block-5164','Html_box','',1),(5166,'115335','watch-mobile','block-5164-2','account\\CustomerAdditionalField','',1),(5167,'115336','watch-mobile','block-5082','BlockBox','',27),(5168,'115337','watch-mobile','block-5167','Html_box','',1),(5169,'115338','watch-mobile','block-5167-2','Html_box','',1),(5170,'115339','watch-mobile','block-5167-3','Html_box','',1),(5171,'115340','watch-mobile','block-5167-4','Html_box','',1),(5172,'115341','watch-mobile','block-5082','BlockBox','',28),(5173,'115342','watch-mobile','block-5172','Html_box','',1),(5174,'115343','watch-mobile','block-5172-2','account\\CustomerAdditionalField','',1),(5175,'115344','watch-mobile','block-5172-3','Html_box','',1),(5176,'115345','watch-mobile','block-5172-4','account\\CustomerAdditionalField','',1),(5177,'115346','watch-mobile','block-5082','BlockBox','',29),(5178,'115347','watch-mobile','block-5177','Html_box','',1),(5179,'115348','watch-mobile','unsubscribed','BlockBox','',1),(5180,'115349','watch-mobile','block-5179','Html_box','',1),(5181,'115350','watch-mobile','update-and-pay-order_confirmation','BlockBox','',1),(5182,'115351','watch-mobile','block-5181','BlockBox','',3),(5183,'115352','watch-mobile','block-5182','BlockBox','',1),(5184,'115353','watch-mobile','block-5183','BlockBox','',1),(5185,'115354','watch-mobile','block-5184','BlockBox','',1),(5186,'115355','watch-mobile','block-5185','Html_box','',4),(5187,'115356','watch-mobile','block-5185','Html_box','',2),(5188,'115357','watch-mobile','block-5185','Html_box','',1),(5189,'115358','watch-mobile','block-5185','order\\ShippingMethod','',5),(5190,'115359','watch-mobile','block-5185','order\\DeliveryAddress','',3),(5191,'115360','watch-mobile','block-5185','order\\Telephone','',8),(5192,'115361','watch-mobile','block-5185','order\\Email','',9),(5193,'115362','watch-mobile','block-5185','order\\Name','',7),(5194,'115363','watch-mobile','block-5185','Html_box','',6),(5195,'115364','watch-mobile','block-5184-2','BlockBox','',1),(5196,'115365','watch-mobile','block-5195','order\\BillingAddress','',3),(5197,'115366','watch-mobile','block-5195','UpdateAndPay\\PayConfirm','',5),(5198,'115367','watch-mobile','block-5195','Html_box','',1),(5199,'115368','watch-mobile','block-5195','Html_box','',2),(5200,'115369','watch-mobile','block-5195','Html_box','',4),(5201,'115370','watch-mobile','block-5183','BlockBox','',3),(5202,'115371','watch-mobile','block-5201','order\\Products','',2),(5203,'115372','watch-mobile','block-5201','Html_box','',1),(5204,'115373','watch-mobile','block-5182-2','BlockBox','',1),(5205,'115374','watch-mobile','block-5204','Html_box','',1),(5206,'115375','watch-mobile','block-5204','checkout\\ContinueBtn','',3),(5207,'115376','watch-mobile','block-5204','order\\Totals','',2),(5208,'115377','watch-mobile','block-5181','account\\OrderHeading','',1),(5209,'115378','watch-mobile','update-and-pay-order_pay','BlockBox','',1),(5210,'115379','watch-mobile','block-5209','BlockBox','',3),(5211,'115380','watch-mobile','block-5210','BlockBox','',1),(5212,'115381','watch-mobile','block-5211','BlockBox','',3),(5213,'115382','watch-mobile','block-5212','Html_box','',1),(5214,'115383','watch-mobile','block-5212','order\\Products','',2),(5215,'115384','watch-mobile','block-5211','BlockBox','',1),(5216,'115385','watch-mobile','block-5215','BlockBox','',1),(5217,'115386','watch-mobile','block-5216','order\\Name','',7),(5218,'115387','watch-mobile','block-5216','order\\Email','',9),(5219,'115388','watch-mobile','block-5216','order\\DeliveryAddress','',3),(5220,'115389','watch-mobile','block-5216','Html_box','',6),(5221,'115390','watch-mobile','block-5216','order\\Telephone','',8),(5222,'115391','watch-mobile','block-5216','Html_box','',2),(5223,'115392','watch-mobile','block-5216','order\\ShippingMethod','',5),(5224,'115393','watch-mobile','block-5216','Html_box','',4),(5225,'115394','watch-mobile','block-5216','Html_box','',1),(5226,'115395','watch-mobile','block-5215-2','BlockBox','',1),(5227,'115396','watch-mobile','block-5226','Html_box','',2),(5228,'115397','watch-mobile','block-5226','Html_box','',1),(5229,'115398','watch-mobile','block-5226','Html_box','',4),(5230,'115399','watch-mobile','block-5226','order\\BillingAddress','',3),(5231,'115400','watch-mobile','block-5226','UpdateAndPay\\PayForm','',5),(5232,'115401','watch-mobile','block-5210-2','BlockBox','',1),(5233,'115402','watch-mobile','block-5232','order\\Totals','',2),(5234,'115403','watch-mobile','block-5232','Html_box','',1),(5235,'115404','watch-mobile','block-5232','checkout\\ContinueBtn','',3),(5236,'115405','watch-mobile','block-5209','account\\OrderHeading','',1),(5237,'115406','watch-mobile','wedding_index','BlockBox','',1),(5238,'115407','watch-mobile','block-5237','BlockBox','',1),(5239,'115408','watch-mobile','block-5238','WeddingRegistry\\widgets\\ViewCreateRegistryWidget','',2),(5240,'115409','watch-mobile','block-5238','WeddingRegistry\\widgets\\SearchRegistryButton','',3),(5241,'115410','watch-mobile','block-5238','Heading','',1),(5242,'115411','watch-mobile','wedding_manage','BlockBox','',2),(5243,'115412','watch-mobile','block-5242','WeddingRegistry\\widgets\\Photos','',1),(5244,'115413','watch-mobile','block-5242-2','WeddingRegistry\\widgets\\ManageNames','',1),(5245,'115414','watch-mobile','block-5242-2','BlockBox','',3),(5246,'115415','watch-mobile','block-5245','WeddingRegistry\\widgets\\EditLink','',1),(5247,'115416','watch-mobile','block-5245','WeddingRegistry\\widgets\\DeleteLink','',2),(5248,'115417','watch-mobile','block-5245','WeddingRegistry\\widgets\\ShareLink','',3),(5249,'115418','watch-mobile','block-5242-2','WeddingRegistry\\widgets\\ManageDate','',2),(5250,'115419','watch-mobile','block-5242-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(5251,'115420','watch-mobile','wedding_manage','WeddingRegistry\\widgets\\ManageBanner','',1),(5252,'115421','watch-mobile','wedding_manage','WeddingRegistry\\widgets\\AddItemsLink','',3),(5253,'115422','watch-mobile','wedding_manage','WeddingRegistry\\widgets\\Products','',4),(5257,'115423','watch-mobile','wedding_search','BlockBox','',1),(5258,'115424','watch-mobile','block-5257','WeddingRegistry\\widgets\\SearchList','',2),(5259,'115425','watch-mobile','block-5257','WeddingRegistry\\widgets\\SearchPaging','',3),(5260,'115426','watch-mobile','block-5257','BlockBox','',1),(5261,'115427','watch-mobile','block-5260','BlockBox','',1),(5262,'115428','watch-mobile','block-5261','WeddingRegistry\\widgets\\SearchForm','',2),(5263,'115429','watch-mobile','block-5261','Html_box','',1),(5264,'115430','watch-mobile','wedding_share','BlockBox','',1),(5265,'115431','watch-mobile','block-5264','BlockBox','',4),(5266,'115432','watch-mobile','block-5265-2','Html_box','',3),(5267,'115433','watch-mobile','block-5265-2','Html_box','',1),(5268,'115434','watch-mobile','block-5265-2','WeddingRegistry\\widgets\\ShareUrl','',2),(5269,'115435','watch-mobile','block-5265-2','WeddingRegistry\\widgets\\InviteList','',4),(5270,'115436','watch-mobile','block-5264','WeddingRegistry\\widgets\\ManageBanner','',1),(5271,'115437','watch-mobile','block-5264','WeddingRegistry\\widgets\\Photos','',2),(5272,'115438','watch-mobile','block-5264','Html_box','',3),(5273,'115439','watch-mobile','wedding_success','Html_box','',1),(5274,'115440','watch-mobile','wedding_success','WeddingRegistry\\widgets\\BackButton','',2),(5275,'115441','watch-mobile','wedding_update','BlockBox','',2),(5276,'115442','watch-mobile','block-5275','BlockBox','',1),(5277,'115443','watch-mobile','block-5276','Html_box','',5),(5278,'115444','watch-mobile','block-5276','Html_box','',3),(5279,'115445','watch-mobile','block-5276','WeddingRegistry\\widgets\\Details','',4),(5280,'115446','watch-mobile','block-5276','WeddingRegistry\\widgets\\Names','',2),(5281,'115447','watch-mobile','block-5276','Html_box','',1),(5282,'115448','watch-mobile','block-5276','WeddingRegistry\\widgets\\ShareRegistry','',6),(5283,'115449','watch-mobile','block-5275-2','BlockBox','',1),(5284,'115450','watch-mobile','block-5283','WeddingRegistry\\widgets\\ShippingDetails','',2),(5285,'115451','watch-mobile','block-5283','Html_box','',1),(5286,'115452','watch-mobile','block-5283','Html_box','',5),(5287,'115453','watch-mobile','block-5283','WeddingRegistry\\widgets\\Photos','',6),(5288,'115454','watch-mobile','block-5283','Html_box','',3),(5289,'115455','watch-mobile','block-5283','WeddingRegistry\\widgets\\InformationText','',4),(5290,'115456','watch-mobile','wedding_update','Html_box','',1),(5291,'115457','watch-mobile','wedding_update','BlockBox','',3),(5292,'115458','watch-mobile','block-5291','WeddingRegistry\\widgets\\BackButton','',1),(5293,'115459','watch-mobile','block-5291-2','WeddingRegistry\\widgets\\SaveButton','',1),(5294,'115460','watch-mobile','wedding_view','WeddingRegistry\\widgets\\ManageBanner','',1),(5295,'115461','watch-mobile','wedding_view','BlockBox','',2),(5296,'115462','watch-mobile','block-5295','WeddingRegistry\\widgets\\Photos','',1),(5297,'115463','watch-mobile','block-5295-2','WeddingRegistry\\widgets\\ManageDate','',2),(5298,'115464','watch-mobile','block-5295-2','WeddingRegistry\\widgets\\ManageNames','',1),(5299,'115465','watch-mobile','block-5295-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(5300,'115466','watch-mobile','wedding_view','WeddingRegistry\\widgets\\Products','',6),(5301,'115467','watch-mobile','wishlist','BlockBox','',1),(5302,'115468','watch-mobile','block-5301','BlockBox','',1),(5303,'115469','watch-mobile','block-5302','WidgetsAria','',1),(5304,'115470','watch-mobile','block-5302-2','Html_box','',1),(5305,'115471','watch-mobile','block-5302-2','account\\Wishlist','',2),(5306,'115472','watch-mobile','wishlist-cart','BlockBox','',1),(5307,'115473','watch-mobile','block-5306','cart\\CartTabs','',1),(5308,'115474','watch-mobile','block-5307','account\\Wishlist','',1),(12909,'118459','printshop-mobile','404','Html_box','',1),(13006,'118556','printshop-mobile','account','BlockBox','',1),(13007,'118557','printshop-mobile','block-13006','BlockBox','',1),(13008,'118558','printshop-mobile','block-13007','WidgetsAria','',1),(13009,'118559','printshop-mobile','block-13007-2','Html_box','',3),(13010,'118560','printshop-mobile','block-13007-2','account\\OrdersHistory','',4),(13011,'118561','printshop-mobile','block-13007-2','Html_box','',1),(13012,'118562','printshop-mobile','block-13007-2','BlockBox','',2),(13013,'118563','printshop-mobile','block-13012','Html_box','',1),(13014,'118564','printshop-mobile','block-13012','account\\LastOrder','',2),(13015,'118565','printshop-mobile','block-13012-2','Html_box','',1),(13016,'118566','printshop-mobile','block-13012-2','account\\AccountLink','',3),(13017,'118567','printshop-mobile','block-13012-2','account\\OrderCount','',2),(13018,'118568','printshop-mobile','block-13012-3','Html_box','',1),(13019,'118569','printshop-mobile','block-13012-3','account\\TotalOrdered','',2),(13020,'118570','printshop-mobile','block-13012-4','Html_box','',1),(13021,'118571','printshop-mobile','block-13012-4','account\\AccountLink','',3),(13022,'118572','printshop-mobile','block-13012-4','account\\CreditAmount','',2),(13023,'118573','printshop-mobile','block-13012-5','account\\AccountLink','',3),(13024,'118574','printshop-mobile','block-13012-5','account\\PointsEarnt','',2),(13025,'118575','printshop-mobile','block-13012-5','Html_box','',1),(13026,'118576','printshop-mobile','block-13007-2','BlockBox','',5),(13027,'118577','printshop-mobile','block-13026','account\\GiftCards','',6),(13028,'118578','printshop-mobile','block-13026','Html_box','',1),(13029,'118579','printshop-mobile','block-13007-2','Html_box','',5),(13030,'118580','printshop-mobile','account-menu','BlockBox','',1),(13031,'118581','printshop-mobile','block-13030','BlockBox','',1),(13032,'118582','printshop-mobile','block-13031','Html_box','',16),(13033,'118583','printshop-mobile','block-13031','account\\AccountLink','',18),(13034,'118584','printshop-mobile','block-13031','account\\AccountLink','',1),(13035,'118585','printshop-mobile','block-13031','Html_box','',2),(13036,'118586','printshop-mobile','block-13031','account\\AccountLink','',17),(13037,'118587','printshop-mobile','block-13031','account\\AccountLink','',4),(13038,'118588','printshop-mobile','block-13031','account\\AccountLink','',11),(13039,'118589','printshop-mobile','block-13031','Html_box','',6),(13040,'118590','printshop-mobile','block-13031','account\\AccountLink','',8),(13041,'118591','printshop-mobile','block-13031','account\\AccountLink','',7),(13042,'118592','printshop-mobile','block-13031','account\\AccountLink','',14),(13043,'118593','printshop-mobile','block-13031','account\\AccountLink','',5),(13044,'118594','printshop-mobile','block-13031','account\\AccountLink','',12),(13045,'118595','printshop-mobile','block-13031','account\\AccountLink','',9),(13046,'118596','printshop-mobile','block-13031','Html_box','',10),(13047,'118597','printshop-mobile','block-13031','account\\AccountLink','',15),(13048,'118598','printshop-mobile','account_edit','BlockBox','',1),(13049,'118599','printshop-mobile','block-13048','BlockBox','',1),(13050,'118600','printshop-mobile','block-13049','WidgetsAria','',1),(13051,'118601','printshop-mobile','block-13049-2','account\\AccountEdit','',2),(13052,'118602','printshop-mobile','block-13049-2','Html_box','',1),(13053,'118603','printshop-mobile','block-13049-2','account\\AccountLink','',3),(13054,'118604','printshop-mobile','address_book','BlockBox','',1),(13055,'118605','printshop-mobile','block-13054','BlockBox','',1),(13056,'118606','printshop-mobile','block-13055','WidgetsAria','',1),(13057,'118607','printshop-mobile','block-13055-2','account\\AddressBook','',3),(13058,'118608','printshop-mobile','block-13055-2','Html_box','',1),(13059,'118609','printshop-mobile','address_book_process','BlockBox','',1),(13060,'118610','printshop-mobile','block-13059','BlockBox','',1),(13061,'118611','printshop-mobile','block-13060','WidgetsAria','',1),(13062,'118612','printshop-mobile','block-13060-2','account\\EditAddress','',2),(13063,'118613','printshop-mobile','block-13060-2','Html_box','',1),(13064,'118614','printshop-mobile','block-13060-2','account\\AccountLink','',3),(13065,'118615','printshop-mobile','b2b','BlockBox','',1),(13066,'118616','printshop-mobile','block-13065','BlockBox','',1),(13067,'118617','printshop-mobile','block-13066','productListing\\image','',1),(13068,'118618','printshop-mobile','block-13066-2','productListing\\model','',5),(13069,'118619','printshop-mobile','block-13066-2','productListing\\attributes','',3),(13070,'118620','printshop-mobile','block-13066-2','BlockBox','',4),(13071,'118621','printshop-mobile','block-13070','BlockBox','',1),(13072,'118622','printshop-mobile','block-13071','productListing\\price','',1),(13073,'118623','printshop-mobile','block-13071-2','productListing\\bonusPoints','',1),(13074,'118624','printshop-mobile','block-13070-2','productListing\\qtyInput','',1),(13075,'118625','printshop-mobile','block-13066-2','productListing\\description','',6),(13076,'118626','printshop-mobile','block-13066-2','BlockBox','',2),(13077,'118627','printshop-mobile','block-13076','productListing\\stock','',1),(13078,'118628','printshop-mobile','block-13076-2','productListing\\rating','',1),(13079,'118629','printshop-mobile','block-13066-2','productListing\\name','',1),(13080,'118630','printshop-mobile','batch','BlockBox','',1),(13081,'118631','printshop-mobile','block-13080','productListing\\attributes','',5),(13082,'118632','printshop-mobile','block-13080','productListing\\price','',6),(13083,'118633','printshop-mobile','block-13080','productListing\\name','',4),(13084,'118634','printshop-mobile','block-13080','productListing\\image','',2),(13085,'118635','printshop-mobile','block-13080','batchSelect','',1),(13086,'118636','printshop-mobile','batch_selected','BlockBox','',1),(13087,'118637','printshop-mobile','block-13086','BlockBox','',13),(13088,'118638','printshop-mobile','block-13087','productListing\\image','',1),(13089,'118639','printshop-mobile','block-13087-2','batchRemove','',1),(13090,'118640','printshop-mobile','block-13087-2','productListing\\price','',3),(13091,'118641','printshop-mobile','block-13087-2','productListing\\name','',2),(13092,'118642','printshop-mobile','bbbbb','BlockBox','',1),(13093,'118643','printshop-mobile','block-13092','BlockBox','',2),(13094,'118644','printshop-mobile','block-13093','Filters','',1),(13095,'118645','printshop-mobile','block-13093-2','BlockBox','',6),(13096,'118646','printshop-mobile','block-13095','catalog\\CountsItems','',1),(13097,'118647','printshop-mobile','block-13095-2','catalog\\Paging','',1),(13098,'118648','printshop-mobile','block-13093-2','catalog\\Image','',1),(13099,'118649','printshop-mobile','block-13093-2','Listing','',5),(13100,'118650','printshop-mobile','block-13093-2','catalog\\ImageMapCategory','',3),(13101,'118651','printshop-mobile','block-13093-2','BlockBox','',4),(13102,'118652','printshop-mobile','block-13101','catalog\\ListingLook','',1),(13103,'118653','printshop-mobile','block-13101','catalog\\CompareButton','',2),(13104,'118654','printshop-mobile','block-13101','catalog\\ItemsOnPage','',4),(13105,'118655','printshop-mobile','block-13101','catalog\\Sorting','',3),(13106,'118656','printshop-mobile','block-13093-2','Categories','',2),(13107,'118657','printshop-mobile','block-13092','catalog\\Title','',1),(13108,'118658','printshop-mobile','blog','BlockBox','',1),(13109,'118659','printshop-mobile','block-13108','BlockBox','',1),(13110,'118660','printshop-mobile','block-13109','BlogContent','',1),(13111,'118661','printshop-mobile','block-13109-2','BlogSidebar','',1),(13112,'118662','printshop-mobile','blogsidebar','BlockBox','',1),(13113,'118663','printshop-mobile','block-13112','Blog\\widget\\RecentPosts','',4),(13114,'118664','printshop-mobile','block-13112','Blog\\widget\\TagCloud','',2),(13115,'118665','printshop-mobile','block-13112','Blog\\widget\\CategoriesList','',1),(13116,'118666','printshop-mobile','block-13112','Blog\\widget\\MostPopularPosts','',3),(13117,'118667','printshop-mobile','cart','BlockBox','',2),(13118,'118668','printshop-mobile','block-13117','BlockBox','',4),(13119,'118669','printshop-mobile','block-13118','Html_box','',1),(13120,'118670','printshop-mobile','block-13118','cart\\UpSell','6',2),(13121,'118671','printshop-mobile','block-13117','BlockBox','',1),(13122,'118672','printshop-mobile','block-13121','cart\\Products','',3),(13123,'118673','printshop-mobile','block-13121','BlockBox','',2),(13124,'118674','printshop-mobile','block-13123','MultiCart\\SaveCart','',2),(13125,'118675','printshop-mobile','block-13123-2','MultiCart\\Actions','',1),(13126,'118676','printshop-mobile','block-13121','MultiCart\\CartSwitcher','',1),(13127,'118677','printshop-mobile','block-13117','BlockBox','',3),(13128,'118678','printshop-mobile','block-13127','cart\\GiveAway','',2),(13129,'118679','printshop-mobile','block-13127','Html_box','',1),(13130,'118680','printshop-mobile','block-13117','BlockBox','',2),(13131,'118681','printshop-mobile','block-13130','Html_box','',1),(13132,'118682','printshop-mobile','block-13130','BlockBox','',2),(13133,'118683','printshop-mobile','block-13132','cart\\DiscountCoupon','',1),(13134,'118684','printshop-mobile','block-13132','cart\\CreditAmount','',2),(13135,'118685','printshop-mobile','block-13132','cart\\BonusPoints','',3),(13136,'118686','printshop-mobile','block-13117','BlockBox','',5),(13137,'118687','printshop-mobile','block-13136','Html_box','',1),(13138,'118688','printshop-mobile','block-13136','cart\\ShippingEstimator','',2),(13139,'118689','printshop-mobile','block-13117','BlockBox','',7),(13140,'118690','printshop-mobile','block-13139','BlockBox','',2),(13141,'118691','printshop-mobile','block-13140','Image','',4),(13142,'118692','printshop-mobile','block-13140','cart\\CheckoutBtn','',2),(13143,'118693','printshop-mobile','block-13140','cart\\OrderTotal','',1),(13144,'118694','printshop-mobile','block-13117','Html_box','',6),(13145,'118695','printshop-mobile','cart2','BlockBox','',2),(13146,'118696','printshop-mobile','block-13145','cart\\CartTabs','',2),(13147,'118697','printshop-mobile','block-13146','BlockBox','',1),(13148,'118698','printshop-mobile','block-13147','BlockBox','',4),(13149,'118699','printshop-mobile','block-13148','cart\\UpSell','6',2),(13150,'118700','printshop-mobile','block-13148','Html_box','',1),(13151,'118701','printshop-mobile','block-13147','BlockBox','',1),(13152,'118702','printshop-mobile','block-13151','cart\\Products','',3),(13153,'118703','printshop-mobile','block-13151','BlockBox','',2),(13154,'118704','printshop-mobile','block-13153','MultiCart\\CartSwitcher','',1),(13155,'118705','printshop-mobile','block-13153','MultiCart\\SaveCart','',2),(13156,'118706','printshop-mobile','block-13153-2','MultiCart\\Actions','',1),(13157,'118707','printshop-mobile','block-13147','BlockBox','',3),(13158,'118708','printshop-mobile','block-13157','cart\\GiveAway','',2),(13159,'118709','printshop-mobile','block-13157','Html_box','',1),(13160,'118710','printshop-mobile','block-13147','BlockBox','',2),(13161,'118711','printshop-mobile','block-13160','Html_box','',1),(13162,'118712','printshop-mobile','block-13160','BlockBox','',2),(13163,'118713','printshop-mobile','block-13162','cart\\DiscountCoupon','',1),(13164,'118714','printshop-mobile','block-13162-2','cart\\CreditAmount','',1),(13165,'118715','printshop-mobile','block-13162-3','cart\\BonusPoints','',1),(13166,'118716','printshop-mobile','block-13147','BlockBox','',5),(13167,'118717','printshop-mobile','block-13166','Html_box','',1),(13168,'118718','printshop-mobile','block-13166','cart\\ShippingEstimator','',2),(13169,'118719','printshop-mobile','block-13147-2','BlockBox','',1),(13170,'118720','printshop-mobile','block-13169','Html_box','',1),(13171,'118721','printshop-mobile','block-13169','BlockBox','',2),(13172,'118722','printshop-mobile','block-13171','Image','',4),(13173,'118723','printshop-mobile','block-13171','cart\\CheckoutBtn','',2),(13174,'118724','printshop-mobile','block-13171','cart\\OrderTotal','',1),(13175,'118725','printshop-mobile','categories','BlockBox','',1),(13176,'118726','printshop-mobile','block-13175','catalog\\Title','',1),(13177,'118727','printshop-mobile','block-13175','Categories','',2),(13178,'118728','printshop-mobile','categories','BlockBox','',2),(13179,'118729','printshop-mobile','block-13178','Listing','',3),(13180,'118730','printshop-mobile','block-13178','BlockBox','',1),(13181,'118731','printshop-mobile','block-13180','catalog\\Sorting','',1),(13182,'118732','printshop-mobile','block-13180-2','catalog\\CountsItems','',1),(13183,'118733','printshop-mobile','block-13178','catalog\\Paging','',2),(13184,'118734','printshop-mobile','category','ListingFunctionality','',2),(13185,'118735','printshop-mobile','category','Categories','',1),(13186,'118736','printshop-mobile','category','PagingBar','',5),(13187,'118737','printshop-mobile','category','PagingBar','',3),(13188,'118738','printshop-mobile','category','Listing','',4),(13189,'118739','printshop-mobile','category_2','BlockBox','',1),(13190,'118740','printshop-mobile','block-13189','catalog\\Title','',1),(13191,'118741','printshop-mobile','block-13189','BlockBox','',2),(13192,'118742','printshop-mobile','block-13191','Filters','',1),(13193,'118743','printshop-mobile','block-13191-2','catalog\\Image','',1),(13194,'118744','printshop-mobile','block-13191-2','Listing','',5),(13195,'118745','printshop-mobile','block-13191-2','BlockBox','',4),(13196,'118746','printshop-mobile','block-13195','catalog\\Sorting','',3),(13197,'118747','printshop-mobile','block-13195','catalog\\ItemsOnPage','',4),(13198,'118748','printshop-mobile','block-13195','catalog\\CompareButton','',2),(13199,'118749','printshop-mobile','block-13195','catalog\\ListingLook','',1),(13200,'118750','printshop-mobile','block-13191-2','catalog\\ImageMapCategory','',3),(13201,'118751','printshop-mobile','block-13191-2','Categories','',2),(13202,'118752','printshop-mobile','block-13191-2','BlockBox','',6),(13203,'118753','printshop-mobile','block-13202','catalog\\CountsItems','',1),(13204,'118754','printshop-mobile','block-13202-2','catalog\\Paging','',1),(13205,'118755','printshop-mobile','category_no_filters','BlockBox','',1),(13206,'118756','printshop-mobile','block-13205','catalog\\B2bAddButton','',7),(13207,'118757','printshop-mobile','block-13205','BlockBox','',6),(13208,'118758','printshop-mobile','block-13207','catalog\\CountsItems','',1),(13209,'118759','printshop-mobile','block-13207-2','catalog\\Paging','',1),(13210,'118760','printshop-mobile','block-13205','Listing','',5),(13211,'118761','printshop-mobile','block-13205','catalog\\Image','',2),(13212,'118762','printshop-mobile','block-13205','BlockBox','',4),(13213,'118763','printshop-mobile','block-13212','catalog\\ListingLook','',1),(13214,'118764','printshop-mobile','block-13212','catalog\\CompareButton','',2),(13215,'118765','printshop-mobile','block-13212','HeaderStock','',5),(13216,'118766','printshop-mobile','block-13212','catalog\\ItemsOnPage','',4),(13217,'118767','printshop-mobile','block-13212','catalog\\Sorting','',3),(13218,'118768','printshop-mobile','block-13205','Categories','',3),(13219,'118769','printshop-mobile','block-13205','catalog\\Title','',1),(13220,'118770','printshop-mobile','checkout','BlockBox','',1),(13221,'118771','printshop-mobile','block-13220','BlockBox','',1),(13222,'118772','printshop-mobile','block-13221','BlockBox','',2),(13223,'118773','printshop-mobile','block-13222','BlockBox','',3),(13224,'118774','printshop-mobile','block-13223','BlockBox','',2),(13225,'118775','printshop-mobile','block-13224','checkout\\BillingAddress','',2),(13226,'118776','printshop-mobile','block-13224','Html_box','',1),(13227,'118777','printshop-mobile','block-13224-2','BlockBox','',1),(13228,'118778','printshop-mobile','block-13227','Html_box','',1),(13229,'118779','printshop-mobile','block-13227','checkout\\PaymentMethod','',2),(13230,'118780','printshop-mobile','block-13223','Html_box','',1),(13231,'118781','printshop-mobile','block-13222','BlockBox','',6),(13232,'118782','printshop-mobile','block-13231','checkout\\CreateAccount','',2),(13233,'118783','printshop-mobile','block-13231','cart\\Products','',1),(13234,'118784','printshop-mobile','block-13222','BlockBox','',2),(13235,'118785','printshop-mobile','block-13234','Html_box','',1),(13236,'118786','printshop-mobile','block-13234','BlockBox','',3),(13237,'118787','printshop-mobile','block-13236','BlockBox','',1),(13238,'118788','printshop-mobile','block-13237','checkout\\ContactInformation','',4),(13239,'118789','printshop-mobile','block-13237','UploadCustomerId\\UploadCustomerIdForm','',4),(13240,'118790','printshop-mobile','block-13237','checkout\\ShippingAddress','',2),(13241,'118791','printshop-mobile','block-13237','Html_box','',3),(13242,'118792','printshop-mobile','block-13234','BlockBox','',4),(13243,'118793','printshop-mobile','block-13242','Html_box','',1),(13244,'118794','printshop-mobile','block-13242','DelayedDespatch\\Checkout','',3),(13245,'118795','printshop-mobile','block-13242','checkout\\Shipping','',2),(13246,'118796','printshop-mobile','block-13234','Neighbour\\Checkout','',5),(13247,'118797','printshop-mobile','block-13234','BlockBox','',2),(13248,'118798','printshop-mobile','block-13247','checkout\\ShippingChoice','',1),(13249,'118799','printshop-mobile','block-13222','BlockBox','',4),(13250,'118800','printshop-mobile','block-13249','Html_box','',1),(13251,'118801','printshop-mobile','block-13249','BlockBox','',2),(13252,'118802','printshop-mobile','block-13251','CouponsAndVauchers\\Checkout','',1),(13253,'118803','printshop-mobile','block-13251-2','checkout\\BonusPoints','',2),(13254,'118804','printshop-mobile','block-13251-2','checkout\\CreditAmount','',1),(13255,'118805','printshop-mobile','block-13222','BlockBox','',5),(13256,'118806','printshop-mobile','block-13255','checkout\\Comments','',2),(13257,'118807','printshop-mobile','block-13255','Html_box','',1),(13258,'118808','printshop-mobile','block-13220','BlockBox','',2),(13259,'118809','printshop-mobile','block-13258','checkout\\Totals','',2),(13260,'118810','printshop-mobile','block-13258','checkout\\ContinueBtn','',3),(13261,'118811','printshop-mobile','block-13258','Html_box','',1),(13262,'118812','printshop-mobile','block-13258','checkout\\Terms','',4),(13263,'118813','printshop-mobile','block-13258','Html_box','',5),(13264,'118814','printshop-mobile','checkout_confirmation','BlockBox','',1),(13265,'118815','printshop-mobile','block-13264','checkout\\ConfirmBtn','',4),(13266,'118816','printshop-mobile','block-13264','cart\\Products','',7),(13267,'118817','printshop-mobile','block-13264','BlockBox','',2),(13268,'118818','printshop-mobile','block-13267','BlockBox','',1),(13269,'118819','printshop-mobile','block-13268','Html_box','',1),(13270,'118820','printshop-mobile','block-13268','checkout\\ShippingAddressConfirm','',3),(13271,'118821','printshop-mobile','block-13267-2','BlockBox','',1),(13272,'118822','printshop-mobile','block-13271','Html_box','',1),(13273,'118823','printshop-mobile','block-13271','checkout\\BillingAddressConfirm','',3),(13274,'118824','printshop-mobile','block-13264','checkout\\ConfirmBtn','',9),(13275,'118825','printshop-mobile','block-13264','BlockBox','',3),(13276,'118826','printshop-mobile','block-13275','BlockBox','',1),(13277,'118827','printshop-mobile','block-13276','Html_box','',1),(13278,'118828','printshop-mobile','block-13276','checkout\\ShippingConfirm','',3),(13279,'118829','printshop-mobile','block-13275-2','BlockBox','',1),(13280,'118830','printshop-mobile','block-13279','checkout\\PaymentMethodConfirm','',3),(13281,'118831','printshop-mobile','block-13279','Html_box','',1),(13282,'118832','printshop-mobile','block-13264','checkout\\EditBtn','',6),(13283,'118833','printshop-mobile','block-13264','checkout\\Totals','',8),(13284,'118834','printshop-mobile','block-13264','Html_box','',5),(13285,'118835','printshop-mobile','checkout_confirmation_no_shipping_q','BlockBox','',1),(13286,'118836','printshop-mobile','block-13285','checkout\\Totals','',5),(13287,'118837','printshop-mobile','block-13285','checkout\\ConfirmBtn','',6),(13288,'118838','printshop-mobile','block-13285','BlockBox','',1),(13289,'118839','printshop-mobile','block-13288','BlockBox','',1),(13290,'118840','printshop-mobile','block-13289','Html_box','',1),(13291,'118841','printshop-mobile','block-13289','checkout\\BillingAddressConfirm','',3),(13292,'118842','printshop-mobile','block-13288-2','BlockBox','',1),(13293,'118843','printshop-mobile','block-13292','Html_box','',1),(13294,'118844','printshop-mobile','block-13292','checkout\\PaymentMethodConfirm','',3),(13295,'118845','printshop-mobile','block-13285','Html_box','',3),(13296,'118846','printshop-mobile','block-13285','quote\\Products','',4),(13297,'118847','printshop-mobile','block-13285','checkout\\ConfirmBtn','',2),(13298,'118848','printshop-mobile','checkout_confirmation_no_shipping','BlockBox','',1),(13299,'118849','printshop-mobile','block-13298','Html_box','',5),(13300,'118850','printshop-mobile','block-13298','checkout\\ConfirmBtn','',4),(13301,'118851','printshop-mobile','block-13298','cart\\Products','',7),(13302,'118852','printshop-mobile','block-13298','checkout\\Totals','',8),(13303,'118853','printshop-mobile','block-13298','checkout\\ConfirmBtn','',9),(13304,'118854','printshop-mobile','block-13298','BlockBox','',2),(13305,'118855','printshop-mobile','block-13304','BlockBox','',1),(13306,'118856','printshop-mobile','block-13305','checkout\\BillingAddressConfirm','',3),(13307,'118857','printshop-mobile','block-13305','Html_box','',1),(13308,'118858','printshop-mobile','block-13304-2','BlockBox','',1),(13309,'118859','printshop-mobile','block-13308','Html_box','',1),(13310,'118860','printshop-mobile','block-13308','checkout\\PaymentMethodConfirm','',3),(13311,'118861','printshop-mobile','checkout_confirmation_q','BlockBox','',1),(13312,'118862','printshop-mobile','block-13311','BlockBox','',2),(13313,'118863','printshop-mobile','block-13312','BlockBox','',1),(13314,'118864','printshop-mobile','block-13313','checkout\\ShippingConfirm','',3),(13315,'118865','printshop-mobile','block-13313','Html_box','',1),(13316,'118866','printshop-mobile','block-13312-2','BlockBox','',1),(13317,'118867','printshop-mobile','block-13316','Html_box','',1),(13318,'118868','printshop-mobile','block-13316','checkout\\PaymentMethodConfirm','',3),(13319,'118869','printshop-mobile','block-13311','checkout\\ConfirmBtn','',8),(13320,'118870','printshop-mobile','block-13311','checkout\\ConfirmBtn','',3),(13321,'118871','printshop-mobile','block-13311','checkout\\EditBtn','',5),(13322,'118872','printshop-mobile','block-13311','quote\\Products','',6),(13323,'118873','printshop-mobile','block-13311','Html_box','',4),(13324,'118874','printshop-mobile','block-13311','checkout\\Totals','',7),(13325,'118875','printshop-mobile','block-13311','BlockBox','',1),(13326,'118876','printshop-mobile','block-13325','BlockBox','',1),(13327,'118877','printshop-mobile','block-13326','checkout\\ShippingAddressConfirm','',3),(13328,'118878','printshop-mobile','block-13326','Html_box','',1),(13329,'118879','printshop-mobile','block-13325-2','BlockBox','',1),(13330,'118880','printshop-mobile','block-13329','Html_box','',1),(13331,'118881','printshop-mobile','block-13329','checkout\\BillingAddressConfirm','',3),(13332,'118882','printshop-mobile','checkout_confirmation_title','Html_box','',1),(13333,'118883','printshop-mobile','checkout_confirmation_title_g','Html_box','',1),(13334,'118884','printshop-mobile','checkout_confirmation_title_no_shipping_g','Html_box','',1),(13335,'118885','printshop-mobile','checkout_confirmation_title_no_shipping','Html_box','',1),(13336,'118886','printshop-mobile','checkout_confirmation_title_q','Html_box','',1),(13337,'118887','printshop-mobile','checkout_confirmation_title_s','Html_box','',1),(13338,'118888','printshop-mobile','checkout_delivery','BlockBox','',1),(13339,'118889','printshop-mobile','block-13338','BlockBox','',1),(13340,'118890','printshop-mobile','block-13339','checkout\\ShippingAddress','',2),(13341,'118891','printshop-mobile','block-13339','Html_box','',1),(13342,'118892','printshop-mobile','block-13338-2','BlockBox','',1),(13343,'118893','printshop-mobile','block-13342','Neighbour\\Checkout','',4),(13344,'118894','printshop-mobile','block-13342','Html_box','',1),(13345,'118895','printshop-mobile','block-13342','checkout\\Shipping','',2),(13346,'118896','printshop-mobile','block-13342','DelayedDespatch\\Checkout','',3),(13347,'118897','printshop-mobile','checkout_delivery','BlockBox','',2),(13348,'118898','printshop-mobile','block-13347','BlockBox','',1),(13349,'118899','printshop-mobile','block-13348','Html_box','',1),(13350,'118900','printshop-mobile','block-13348','checkout\\ContactInformation','',2),(13351,'118901','printshop-mobile','block-13347-2','BlockBox','',1),(13352,'118902','printshop-mobile','block-13351','Html_box','',1),(13353,'118903','printshop-mobile','block-13351','checkout\\Comments','',2),(13354,'118904','printshop-mobile','checkout_delivery','BlockBox','',3),(13355,'118905','printshop-mobile','block-13354','Html_box','',1),(13356,'118906','printshop-mobile','block-13354-2','checkout\\ContinueBtn','',1),(13357,'118907','printshop-mobile','checkout_delivery_g','BlockBox','',1),(13358,'118908','printshop-mobile','block-13357','BlockBox','',1),(13359,'118909','printshop-mobile','block-13358','checkout\\ShippingAddress','',2),(13360,'118910','printshop-mobile','block-13358','Html_box','',1),(13361,'118911','printshop-mobile','block-13357-2','BlockBox','',1),(13362,'118912','printshop-mobile','block-13361','Html_box','',1),(13363,'118913','printshop-mobile','block-13361','Neighbour\\Checkout','',4),(13364,'118914','printshop-mobile','block-13361','checkout\\Shipping','',2),(13365,'118915','printshop-mobile','block-13361','DelayedDespatch\\Checkout','',3),(13366,'118916','printshop-mobile','checkout_delivery_g','BlockBox','',3),(13367,'118917','printshop-mobile','block-13366','Html_box','',1),(13368,'118918','printshop-mobile','block-13366-2','checkout\\ContinueBtn','',1),(13369,'118919','printshop-mobile','checkout_delivery_g','BlockBox','',2),(13370,'118920','printshop-mobile','block-13369','BlockBox','',1),(13371,'118921','printshop-mobile','block-13370','checkout\\ContactInformation','',2),(13372,'118922','printshop-mobile','block-13370','Html_box','',1),(13373,'118923','printshop-mobile','block-13369-2','BlockBox','',1),(13374,'118924','printshop-mobile','block-13373','checkout\\Comments','',2),(13375,'118925','printshop-mobile','block-13373','Html_box','',1),(13376,'118926','printshop-mobile','checkout_delivery_no_shipping','BlockBox','',2),(13377,'118927','printshop-mobile','block-13376','Html_box','',1),(13378,'118928','printshop-mobile','block-13376-2','checkout\\ContinueBtn','',1),(13379,'118929','printshop-mobile','checkout_delivery_no_shipping','BlockBox','',1),(13380,'118930','printshop-mobile','block-13379','BlockBox','',1),(13381,'118931','printshop-mobile','block-13380','checkout\\ContactInformation','',2),(13382,'118932','printshop-mobile','block-13379-2','BlockBox','',1),(13383,'118933','printshop-mobile','block-13382','checkout\\Comments','',2),(13384,'118934','printshop-mobile','block-13382','Html_box','',1),(13385,'118935','printshop-mobile','checkout_delivery_no_shipping_g','BlockBox','',1),(13386,'118936','printshop-mobile','block-13385','BlockBox','',1),(13387,'118937','printshop-mobile','block-13386','checkout\\ContactInformation','',2),(13388,'118938','printshop-mobile','block-13385-2','BlockBox','',1),(13389,'118939','printshop-mobile','block-13388','Html_box','',1),(13390,'118940','printshop-mobile','block-13388','checkout\\Comments','',2),(13391,'118941','printshop-mobile','checkout_delivery_no_shipping_g','BlockBox','',2),(13392,'118942','printshop-mobile','block-13391','Html_box','',1),(13393,'118943','printshop-mobile','block-13391-2','checkout\\ContinueBtn','',1),(13394,'118944','printshop-mobile','checkout_delivery_title','Html_box','',1),(13395,'118945','printshop-mobile','checkout_delivery_title_g','Html_box','',1),(13396,'118946','printshop-mobile','checkout_delivery_title_no_shipping_g','Html_box','',1),(13397,'118947','printshop-mobile','checkout_delivery_title_no_shipping','Html_box','',1),(13398,'118948','printshop-mobile','checkout_delivery_title_q','Html_box','',1),(13399,'118949','printshop-mobile','checkout_delivery_title_s','Html_box','',1),(13400,'118950','printshop-mobile','checkout_free_s','BlockBox','',1),(13401,'118951','printshop-mobile','block-13400','BlockBox','',2),(13402,'118952','printshop-mobile','block-13401','BlockBox','',2),(13403,'118953','printshop-mobile','block-13402','BlockBox','',2),(13404,'118954','printshop-mobile','block-13403','Neighbour\\Checkout','',4),(13405,'118955','printshop-mobile','block-13403','BlockBox','',3),(13406,'118956','printshop-mobile','block-13405','BlockBox','',1),(13407,'118957','printshop-mobile','block-13406','checkout\\ShippingAddress','',2),(13408,'118958','printshop-mobile','block-13406','Html_box','',3),(13409,'118959','printshop-mobile','block-13406','checkout\\ContactInformation','',4),(13410,'118960','printshop-mobile','block-13405-2','BlockBox','',1),(13411,'118961','printshop-mobile','block-13410','DelayedDespatch\\Checkout','',3),(13412,'118962','printshop-mobile','block-13403','Html_box','',1),(13413,'118963','printshop-mobile','block-13403','BlockBox','',2),(13414,'118964','printshop-mobile','block-13413','checkout\\ShippingChoice','',1),(13415,'118965','printshop-mobile','block-13402','BlockBox','',5),(13416,'118966','printshop-mobile','block-13415','Html_box','',1),(13417,'118967','printshop-mobile','block-13415','checkout\\Comments','',2),(13418,'118968','printshop-mobile','block-13402','checkout\\Gdpr','',1),(13419,'118969','printshop-mobile','block-13402','BlockBox','',6),(13420,'118970','printshop-mobile','block-13419','checkout\\CreateAccount','',3),(13421,'118971','printshop-mobile','block-13419','sample\\Products','',1),(13422,'118972','printshop-mobile','block-13401-2','BlockBox','',1),(13423,'118973','printshop-mobile','block-13422','checkout\\ContinueBtn','',3),(13424,'118974','printshop-mobile','block-13422','Html_box','',4),(13425,'118975','printshop-mobile','checkout_no_shipping','BlockBox','',1),(13426,'118976','printshop-mobile','block-13425','BlockBox','',2),(13427,'118977','printshop-mobile','block-13426','BlockBox','',1),(13428,'118978','printshop-mobile','block-13427','BlockBox','',5),(13429,'118979','printshop-mobile','block-13428','Html_box','',1),(13430,'118980','printshop-mobile','block-13428','checkout\\Comments','',2),(13431,'118981','printshop-mobile','block-13427','BlockBox','',4),(13432,'118982','printshop-mobile','block-13431','BlockBox','',2),(13433,'118983','printshop-mobile','block-13432','CouponsAndVauchers\\Checkout','',1),(13434,'118984','printshop-mobile','block-13432-2','checkout\\BonusPoints','',2),(13435,'118985','printshop-mobile','block-13432-2','checkout\\CreditAmount','',1),(13436,'118986','printshop-mobile','block-13431','Html_box','',1),(13437,'118987','printshop-mobile','block-13427','BlockBox','',3),(13438,'118988','printshop-mobile','block-13437','BlockBox','',2),(13439,'118989','printshop-mobile','block-13438','Html_box','',1),(13440,'118990','printshop-mobile','block-13438','checkout\\BillingAddress','',2),(13441,'118991','printshop-mobile','block-13438-2','BlockBox','',1),(13442,'118992','printshop-mobile','block-13441','Html_box','',1),(13443,'118993','printshop-mobile','block-13441','checkout\\PaymentMethod','',2),(13444,'118994','printshop-mobile','block-13437','Html_box','',1),(13445,'118995','printshop-mobile','block-13427','BlockBox','',6),(13446,'118996','printshop-mobile','block-13445','cart\\Products','',1),(13447,'118997','printshop-mobile','block-13445','checkout\\CreateAccount','',2),(13448,'118998','printshop-mobile','block-13426-2','BlockBox','',1),(13449,'118999','printshop-mobile','block-13448','checkout\\Terms','',4),(13450,'119000','printshop-mobile','block-13448','checkout\\ContinueBtn','',3),(13451,'119001','printshop-mobile','block-13448','checkout\\Totals','',2),(13452,'119002','printshop-mobile','block-13448','Html_box','',5),(13453,'119003','printshop-mobile','block-13448','Html_box','',1),(13454,'119004','printshop-mobile','checkout_no_shipping_g','BlockBox','',1),(13455,'119005','printshop-mobile','block-13454','quote\\Products','',3),(13456,'119006','printshop-mobile','block-13454','BlockBox','',1),(13457,'119007','printshop-mobile','block-13456','BlockBox','',1),(13458,'119008','printshop-mobile','block-13457','checkout\\BillingAddress','',2),(13459,'119009','printshop-mobile','block-13457','Html_box','',1),(13460,'119010','printshop-mobile','block-13456-2','BlockBox','',1),(13461,'119011','printshop-mobile','block-13460','checkout\\CreditAmount','',3),(13462,'119012','printshop-mobile','block-13460','Html_box','',1),(13463,'119013','printshop-mobile','block-13460','checkout\\PaymentMethod','',2),(13464,'119014','printshop-mobile','block-13460','CouponsAndVauchers\\Checkout','',5),(13465,'119015','printshop-mobile','block-13460','checkout\\BonusPoints','',4),(13466,'119016','printshop-mobile','block-13454','BlockBox','',2),(13467,'119017','printshop-mobile','block-13466','BlockBox','',1),(13468,'119018','printshop-mobile','block-13467','Html_box','',1),(13469,'119019','printshop-mobile','block-13467','checkout\\ContactInformation','',2),(13470,'119020','printshop-mobile','block-13466-2','BlockBox','',1),(13471,'119021','printshop-mobile','block-13470','Html_box','',1),(13472,'119022','printshop-mobile','block-13470','checkout\\Comments','',2),(13473,'119023','printshop-mobile','block-13454','BlockBox','',6),(13474,'119024','printshop-mobile','block-13473','Html_box','',1),(13475,'119025','printshop-mobile','block-13473-2','checkout\\ContinueBtn','',1),(13476,'119026','printshop-mobile','block-13454','checkout\\Totals','',5),(13477,'119027','printshop-mobile','checkout_no_shipping_q','BlockBox','',1),(13478,'119028','printshop-mobile','block-13477','BlockBox','',2),(13479,'119029','printshop-mobile','block-13478','BlockBox','',2),(13480,'119030','printshop-mobile','block-13479','BlockBox','',3),(13481,'119031','printshop-mobile','block-13480','BlockBox','',2),(13482,'119032','printshop-mobile','block-13481','checkout\\BillingAddress','',2),(13483,'119033','printshop-mobile','block-13481','Html_box','',1),(13484,'119034','printshop-mobile','block-13481-2','BlockBox','',1),(13485,'119035','printshop-mobile','block-13484','Html_box','',1),(13486,'119036','printshop-mobile','block-13484','checkout\\PaymentMethod','',2),(13487,'119037','printshop-mobile','block-13480','Html_box','',1),(13488,'119038','printshop-mobile','block-13479','BlockBox','',6),(13489,'119039','printshop-mobile','block-13488','checkout\\CreateAccount','',3),(13490,'119040','printshop-mobile','block-13488','quote\\Products','',2),(13491,'119041','printshop-mobile','block-13479','BlockBox','',5),(13492,'119042','printshop-mobile','block-13491','checkout\\Comments','',2),(13493,'119043','printshop-mobile','block-13491','Html_box','',1),(13494,'119044','printshop-mobile','block-13479','checkout\\Gdpr','',1),(13495,'119045','printshop-mobile','block-13478-2','BlockBox','',1),(13496,'119046','printshop-mobile','block-13495','Html_box','',4),(13497,'119047','printshop-mobile','block-13495','checkout\\Totals','',2),(13498,'119048','printshop-mobile','block-13495','checkout\\ContinueBtn','',3),(13499,'119049','printshop-mobile','block-13495','Html_box','',1),(13500,'119050','printshop-mobile','checkout_payment','BlockBox','',2),(13501,'119051','printshop-mobile','block-13500','Html_box','',1),(13502,'119052','printshop-mobile','block-13500-2','checkout\\ContinueBtn','',1),(13503,'119053','printshop-mobile','checkout_payment','BlockBox','',1),(13504,'119054','printshop-mobile','block-13503','BlockBox','',1),(13505,'119055','printshop-mobile','block-13504','checkout\\BillingAddress','',2),(13506,'119056','printshop-mobile','block-13504','Html_box','',1),(13507,'119057','printshop-mobile','block-13503-2','BlockBox','',1),(13508,'119058','printshop-mobile','block-13507','checkout\\PaymentMethod','',2),(13509,'119059','printshop-mobile','block-13507','Html_box','',1),(13510,'119060','printshop-mobile','block-13507','checkout\\CreditAmount','',3),(13511,'119061','printshop-mobile','block-13507','CouponsAndVauchers\\Checkout','',5),(13512,'119062','printshop-mobile','block-13507','checkout\\BonusPoints','',4),(13513,'119063','printshop-mobile','checkout_payment_g','BlockBox','',1),(13514,'119064','printshop-mobile','block-13513','BlockBox','',1),(13515,'119065','printshop-mobile','block-13514','Html_box','',1),(13516,'119066','printshop-mobile','block-13514','checkout\\BillingAddress','',2),(13517,'119067','printshop-mobile','block-13513-2','BlockBox','',1),(13518,'119068','printshop-mobile','block-13517','checkout\\BonusPoints','',4),(13519,'119069','printshop-mobile','block-13517','Html_box','',1),(13520,'119070','printshop-mobile','block-13517','CouponsAndVauchers\\Checkout','',5),(13521,'119071','printshop-mobile','block-13517','checkout\\CreditAmount','',3),(13522,'119072','printshop-mobile','block-13517','checkout\\PaymentMethod','',2),(13523,'119073','printshop-mobile','checkout_payment_g','BlockBox','',2),(13524,'119074','printshop-mobile','block-13523','Html_box','',1),(13525,'119075','printshop-mobile','block-13523-2','checkout\\ContinueBtn','',1),(13526,'119076','printshop-mobile','checkout_payment_no_shipping','BlockBox','',1),(13527,'119077','printshop-mobile','block-13526','BlockBox','',1),(13528,'119078','printshop-mobile','block-13527','Html_box','',1),(13529,'119079','printshop-mobile','block-13527','checkout\\BillingAddress','',2),(13530,'119080','printshop-mobile','block-13526-2','BlockBox','',1),(13531,'119081','printshop-mobile','block-13530','Html_box','',1),(13532,'119082','printshop-mobile','block-13530','checkout\\PaymentMethod','',2),(13533,'119083','printshop-mobile','block-13530','checkout\\CreditAmount','',3),(13534,'119084','printshop-mobile','block-13530','CouponsAndVauchers\\Checkout','',5),(13535,'119085','printshop-mobile','block-13530','checkout\\BonusPoints','',4),(13536,'119086','printshop-mobile','checkout_payment_no_shipping','BlockBox','',2),(13537,'119087','printshop-mobile','block-13536','Html_box','',1),(13538,'119088','printshop-mobile','block-13536-2','checkout\\ContinueBtn','',1),(13539,'119089','printshop-mobile','checkout_payment_no_shipping_g','BlockBox','',2),(13540,'119090','printshop-mobile','block-13539','Html_box','',1),(13541,'119091','printshop-mobile','block-13539-2','checkout\\ContinueBtn','',1),(13542,'119092','printshop-mobile','checkout_payment_no_shipping_g','BlockBox','',1),(13543,'119093','printshop-mobile','block-13542','BlockBox','',1),(13544,'119094','printshop-mobile','block-13543','checkout\\BillingAddress','',2),(13545,'119095','printshop-mobile','block-13543','Html_box','',1),(13546,'119096','printshop-mobile','block-13542-2','BlockBox','',1),(13547,'119097','printshop-mobile','block-13546','checkout\\PaymentMethod','',2),(13548,'119098','printshop-mobile','block-13546','Html_box','',1),(13549,'119099','printshop-mobile','block-13546','checkout\\CreditAmount','',3),(13550,'119100','printshop-mobile','block-13546','CouponsAndVauchers\\Checkout','',5),(13551,'119101','printshop-mobile','block-13546','checkout\\BonusPoints','',4),(13552,'119102','printshop-mobile','checkout_payment_title','Html_box','',1),(13553,'119103','printshop-mobile','checkout_payment_title_g','Html_box','',1),(13554,'119104','printshop-mobile','checkout_payment_title_no_shipping','Html_box','',1),(13555,'119105','printshop-mobile','checkout_payment_title_no_shipping_g','Html_box','',1),(13556,'119106','printshop-mobile','checkout_payment_title_q','Html_box','',1),(13557,'119107','printshop-mobile','checkout_payment_title_s','Html_box','',1),(13558,'119108','printshop-mobile','checkout_q','BlockBox','',1),(13559,'119109','printshop-mobile','block-13558','BlockBox','',2),(13560,'119110','printshop-mobile','block-13559','BlockBox','',2),(13561,'119111','printshop-mobile','block-13560','BlockBox','',3),(13562,'119112','printshop-mobile','block-13561','BlockBox','',2),(13563,'119113','printshop-mobile','block-13562','checkout\\BillingAddress','',2),(13564,'119114','printshop-mobile','block-13562','Html_box','',1),(13565,'119115','printshop-mobile','block-13562-2','BlockBox','',1),(13566,'119116','printshop-mobile','block-13565','Html_box','',1),(13567,'119117','printshop-mobile','block-13565','checkout\\PaymentMethod','',2),(13568,'119118','printshop-mobile','block-13561','Html_box','',1),(13569,'119119','printshop-mobile','block-13560','BlockBox','',5),(13570,'119120','printshop-mobile','block-13569','Html_box','',1),(13571,'119121','printshop-mobile','block-13569','checkout\\Comments','',2),(13572,'119122','printshop-mobile','block-13560','checkout\\Gdpr','',1),(13573,'119123','printshop-mobile','block-13560','BlockBox','',2),(13574,'119124','printshop-mobile','block-13573','BlockBox','',3),(13575,'119125','printshop-mobile','block-13574','BlockBox','',1),(13576,'119126','printshop-mobile','block-13575','Html_box','',3),(13577,'119127','printshop-mobile','block-13575','checkout\\ShippingAddress','',2),(13578,'119128','printshop-mobile','block-13575','checkout\\ContactInformation','',4),(13579,'119129','printshop-mobile','block-13574-2','BlockBox','',1),(13580,'119130','printshop-mobile','block-13579','DelayedDespatch\\Checkout','',3),(13581,'119131','printshop-mobile','block-13579','Html_box','',1),(13582,'119132','printshop-mobile','block-13579','checkout\\Shipping','',2),(13583,'119133','printshop-mobile','block-13573','Html_box','',1),(13584,'119134','printshop-mobile','block-13573','Neighbour\\Checkout','',4),(13585,'119135','printshop-mobile','block-13573','BlockBox','',2),(13586,'119136','printshop-mobile','block-13585','checkout\\ShippingChoice','',1),(13587,'119137','printshop-mobile','block-13560','BlockBox','',6),(13588,'119138','printshop-mobile','block-13587','quote\\Products','',2),(13589,'119139','printshop-mobile','block-13587','checkout\\CreateAccount','',3),(13590,'119140','printshop-mobile','block-13559-2','BlockBox','',1),(13591,'119141','printshop-mobile','block-13590','checkout\\ContinueBtn','',3),(13592,'119142','printshop-mobile','block-13590','checkout\\Totals','',2),(13593,'119143','printshop-mobile','block-13590','Html_box','',4),(13594,'119144','printshop-mobile','block-13590','Html_box','',1),(13595,'119145','printshop-mobile','checkout_s','BlockBox','',1),(13596,'119146','printshop-mobile','block-13595','BlockBox','',2),(13597,'119147','printshop-mobile','block-13596','BlockBox','',2),(13598,'119148','printshop-mobile','block-13597','BlockBox','',4),(13599,'119149','printshop-mobile','block-13598','BlockBox','',2),(13600,'119150','printshop-mobile','block-13599','CouponsAndVauchers\\Checkout','',1),(13601,'119151','printshop-mobile','block-13599-2','checkout\\CreditAmount','',1),(13602,'119152','printshop-mobile','block-13599-2','checkout\\BonusPoints','',2),(13603,'119153','printshop-mobile','block-13598','Html_box','',1),(13604,'119154','printshop-mobile','block-13597','BlockBox','',3),(13605,'119155','printshop-mobile','block-13604','Html_box','',1),(13606,'119156','printshop-mobile','block-13604','BlockBox','',2),(13607,'119157','printshop-mobile','block-13606','checkout\\BillingAddress','',2),(13608,'119158','printshop-mobile','block-13606','Html_box','',1),(13609,'119159','printshop-mobile','block-13606-2','BlockBox','',1),(13610,'119160','printshop-mobile','block-13609','checkout\\PaymentMethod','',2),(13611,'119161','printshop-mobile','block-13609','Html_box','',1),(13612,'119162','printshop-mobile','block-13597','BlockBox','',5),(13613,'119163','printshop-mobile','block-13612','checkout\\Comments','',2),(13614,'119164','printshop-mobile','block-13612','Html_box','',1),(13615,'119165','printshop-mobile','block-13597','BlockBox','',2),(13616,'119166','printshop-mobile','block-13615','BlockBox','',2),(13617,'119167','printshop-mobile','block-13616','checkout\\ShippingChoice','',1),(13618,'119168','printshop-mobile','block-13615','Html_box','',1),(13619,'119169','printshop-mobile','block-13615','BlockBox','',3),(13620,'119170','printshop-mobile','block-13619','BlockBox','',1),(13621,'119171','printshop-mobile','block-13620','checkout\\ShippingAddress','',2),(13622,'119172','printshop-mobile','block-13620','Html_box','',3),(13623,'119173','printshop-mobile','block-13620','checkout\\ContactInformation','',4),(13624,'119174','printshop-mobile','block-13619-2','BlockBox','',1),(13625,'119175','printshop-mobile','block-13624','DelayedDespatch\\Checkout','',3),(13626,'119176','printshop-mobile','block-13624','Html_box','',1),(13627,'119177','printshop-mobile','block-13624','checkout\\Shipping','',2),(13628,'119178','printshop-mobile','block-13615','Neighbour\\Checkout','',4),(13629,'119179','printshop-mobile','block-13597','BlockBox','',6),(13630,'119180','printshop-mobile','block-13629','checkout\\CreateAccount','',3),(13631,'119181','printshop-mobile','block-13629','sample\\Products','',1),(13632,'119182','printshop-mobile','block-13597','checkout\\Gdpr','',1),(13633,'119183','printshop-mobile','block-13596-2','BlockBox','',1),(13634,'119184','printshop-mobile','block-13633','Html_box','',1),(13635,'119185','printshop-mobile','block-13633','checkout\\ContinueBtn','',3),(13636,'119186','printshop-mobile','block-13633','Html_box','',4),(13637,'119187','printshop-mobile','block-13633','checkout\\Totals','',2),(13638,'119188','printshop-mobile','checkout_step_bottom','cart\\Products','',2),(13639,'119189','printshop-mobile','checkout_step_bottom','checkout\\Totals','',3),(13640,'119190','printshop-mobile','checkout_step_bottom','Html_box','',1),(13641,'119191','printshop-mobile','checkout_step_bottom_g','checkout\\Totals','',3),(13642,'119192','printshop-mobile','checkout_step_bottom_g','quote\\Products','',2),(13643,'119193','printshop-mobile','checkout_step_bottom_g','Html_box','',1),(13644,'119194','printshop-mobile','checkout_step_bottom_no_shipping_g','Html_box','',1),(13645,'119195','printshop-mobile','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(13646,'119196','printshop-mobile','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(13647,'119197','printshop-mobile','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(13648,'119198','printshop-mobile','checkout_step_bottom_no_shipping','Html_box','',1),(13649,'119199','printshop-mobile','checkout_step_bottom_no_shipping','cart\\Products','',2),(13650,'119200','printshop-mobile','communication','BlockBox','',1),(13651,'119201','printshop-mobile','block-13650','Html_box','',2),(13652,'119202','printshop-mobile','block-13650','Communication\\Topic','',3),(13653,'119203','printshop-mobile','block-13650','Communication\\NewTopicButton','',1),(13654,'119204','printshop-mobile','compare','BlockBox','',1),(13655,'119205','printshop-mobile','block-13654','catalog\\Compare','',1),(13656,'119206','printshop-mobile','compare_products','BlockBox','',2),(13657,'119207','printshop-mobile','block-13656','productListing\\rating','',4),(13658,'119208','printshop-mobile','block-13656','productListing\\model','',5),(13659,'119209','printshop-mobile','block-13656','productListing\\compare','',1),(13660,'119210','printshop-mobile','block-13656','BlockBox','',2),(13661,'119211','printshop-mobile','block-13660','productListing\\image','',1),(13662,'119212','printshop-mobile','block-13660-2','productListing\\name','',2),(13663,'119213','printshop-mobile','block-13656','BlockBox','',3),(13664,'119214','printshop-mobile','block-13663','productListing\\price','',1),(13665,'119215','printshop-mobile','block-13663-2','productListing\\buyButton','',1),(13666,'119216','printshop-mobile','confirmation','BlockBox','',1),(13667,'119217','printshop-mobile','block-13666','BlockBox','',2),(13668,'119218','printshop-mobile','block-13667','UploadCustomerId\\UploadCustomerIdForm','',1),(13669,'119219','printshop-mobile','block-13667','BlockBox','',2),(13670,'119220','printshop-mobile','block-13669','BlockBox','',1),(13671,'119221','printshop-mobile','block-13670','BlockBox','',1),(13672,'119222','printshop-mobile','block-13671','checkout\\ShippingAddressConfirm','',4),(13673,'119223','printshop-mobile','block-13671','Html_box','',1),(13674,'119224','printshop-mobile','block-13671','Html_box','',2),(13675,'119225','printshop-mobile','block-13671','checkout\\ContactConfirm','',11),(13676,'119226','printshop-mobile','block-13671','checkout\\EditBtn','',3),(13677,'119227','printshop-mobile','block-13671','Html_box','',5),(13678,'119228','printshop-mobile','block-13671','DelayedDespatch\\CheckoutConfirm','',8),(13679,'119229','printshop-mobile','block-13671','checkout\\EditBtn','',10),(13680,'119230','printshop-mobile','block-13671','checkout\\EditBtn','',6),(13681,'119231','printshop-mobile','block-13671','Html_box','',9),(13682,'119232','printshop-mobile','block-13671','checkout\\ShippingConfirm','',7),(13683,'119233','printshop-mobile','block-13670','BlockBox','',2),(13684,'119234','printshop-mobile','block-13683','Html_box','',2),(13685,'119235','printshop-mobile','block-13683','checkout\\BillingAddressConfirm','',4),(13686,'119236','printshop-mobile','block-13683','Html_box','',5),(13687,'119237','printshop-mobile','block-13683','checkout\\PaymentMethodConfirm','',7),(13688,'119238','printshop-mobile','block-13683','Html_box','',1),(13689,'119239','printshop-mobile','block-13683','checkout\\EditBtn','',3),(13690,'119240','printshop-mobile','block-13683','checkout\\EditBtn','',6),(13691,'119241','printshop-mobile','block-13669','BlockBox','',3),(13692,'119242','printshop-mobile','block-13691','Html_box','',1),(13693,'119243','printshop-mobile','block-13691','checkout\\EditBtn','',2),(13694,'119244','printshop-mobile','block-13691','cart\\Products','',3),(13695,'119245','printshop-mobile','block-13669','BlockBox','',2),(13696,'119246','printshop-mobile','block-13695','Html_box','',1),(13697,'119247','printshop-mobile','block-13695','checkout\\CommentsConfirm','',3),(13698,'119248','printshop-mobile','block-13695','checkout\\EditBtn','',2),(13699,'119249','printshop-mobile','block-13669','BlockBox','',4),(13700,'119250','printshop-mobile','block-13699','checkout\\Totals','',2),(13701,'119251','printshop-mobile','block-13699','Html_box','',1),(13702,'119252','printshop-mobile','block-13699','checkout\\ConfirmBtn','',3),(13703,'119253','printshop-mobile','block-13666','Html_box','',1),(13704,'119254','printshop-mobile','confirmation_free_s','BlockBox','',1),(13705,'119255','printshop-mobile','block-13704','Html_box','',1),(13706,'119256','printshop-mobile','block-13704','BlockBox','',2),(13707,'119257','printshop-mobile','block-13706','BlockBox','',1),(13708,'119258','printshop-mobile','block-13707','BlockBox','',1),(13709,'119259','printshop-mobile','block-13708','BlockBox','',1),(13710,'119260','printshop-mobile','block-13709','checkout\\EditBtn','',6),(13711,'119261','printshop-mobile','block-13709','checkout\\ShippingAddressConfirm','',4),(13712,'119262','printshop-mobile','block-13709','Html_box','',2),(13713,'119263','printshop-mobile','block-13709','checkout\\ShippingConfirm','',7),(13714,'119264','printshop-mobile','block-13709','checkout\\EditBtn','',3),(13715,'119265','printshop-mobile','block-13709','Html_box','',5),(13716,'119266','printshop-mobile','block-13708-2','BlockBox','',1),(13717,'119267','printshop-mobile','block-13716','Html_box','',1),(13718,'119268','printshop-mobile','block-13716','checkout\\EditBtn','',2),(13719,'119269','printshop-mobile','block-13716','DelayedDespatch\\CheckoutConfirm','',4),(13720,'119270','printshop-mobile','block-13716','checkout\\ContactConfirm','',3),(13721,'119271','printshop-mobile','block-13707','BlockBox','',2),(13722,'119272','printshop-mobile','block-13721','checkout\\CommentsConfirm','',3),(13723,'119273','printshop-mobile','block-13721','checkout\\EditBtn','',2),(13724,'119274','printshop-mobile','block-13721','Html_box','',1),(13725,'119275','printshop-mobile','block-13707','BlockBox','',3),(13726,'119276','printshop-mobile','block-13725','sample\\Products','',2),(13727,'119277','printshop-mobile','block-13725','Html_box','',1),(13728,'119278','printshop-mobile','block-13725','checkout\\EditBtn','',3),(13729,'119279','printshop-mobile','block-13706-2','BlockBox','',1),(13730,'119280','printshop-mobile','block-13729','checkout\\ConfirmBtn','',3),(13731,'119281','printshop-mobile','confirmation_no_shipping','BlockBox','',1),(13732,'119282','printshop-mobile','block-13731','Html_box','',1),(13733,'119283','printshop-mobile','block-13731','BlockBox','',2),(13734,'119284','printshop-mobile','block-13733','BlockBox','',1),(13735,'119285','printshop-mobile','block-13734','BlockBox','',3),(13736,'119286','printshop-mobile','block-13735','checkout\\EditBtn','',2),(13737,'119287','printshop-mobile','block-13735','Html_box','',1),(13738,'119288','printshop-mobile','block-13735','cart\\Products','',3),(13739,'119289','printshop-mobile','block-13734','BlockBox','',2),(13740,'119290','printshop-mobile','block-13739','checkout\\EditBtn','',2),(13741,'119291','printshop-mobile','block-13739','checkout\\CommentsConfirm','',3),(13742,'119292','printshop-mobile','block-13739','Html_box','',1),(13743,'119293','printshop-mobile','block-13734','BlockBox','',1),(13744,'119294','printshop-mobile','block-13743','BlockBox','',1),(13745,'119295','printshop-mobile','block-13744','Html_box','',9),(13746,'119296','printshop-mobile','block-13744','checkout\\ContactConfirm','',11),(13747,'119297','printshop-mobile','block-13744','checkout\\EditBtn','',10),(13748,'119298','printshop-mobile','block-13743-2','BlockBox','',1),(13749,'119299','printshop-mobile','block-13748','checkout\\EditBtn','',3),(13750,'119300','printshop-mobile','block-13748','Html_box','',2),(13751,'119301','printshop-mobile','block-13748','Html_box','',1),(13752,'119302','printshop-mobile','block-13748','Html_box','',5),(13753,'119303','printshop-mobile','block-13748','checkout\\BillingAddressConfirm','',4),(13754,'119304','printshop-mobile','block-13748','checkout\\PaymentMethodConfirm','',7),(13755,'119305','printshop-mobile','block-13748','checkout\\EditBtn','',6),(13756,'119306','printshop-mobile','block-13733-2','BlockBox','',1),(13757,'119307','printshop-mobile','block-13756','checkout\\ConfirmBtn','',3),(13758,'119308','printshop-mobile','block-13756','checkout\\Totals','',2),(13759,'119309','printshop-mobile','block-13756','Html_box','',1),(13760,'119310','printshop-mobile','confirmation_no_shipping_q','BlockBox','',2),(13761,'119311','printshop-mobile','block-13760','BlockBox','',2),(13762,'119312','printshop-mobile','block-13761','BlockBox','',1),(13763,'119313','printshop-mobile','block-13762','BlockBox','',3),(13764,'119314','printshop-mobile','block-13763','quote\\Products','',3),(13765,'119315','printshop-mobile','block-13763','checkout\\EditBtn','',2),(13766,'119316','printshop-mobile','block-13763','Html_box','',1),(13767,'119317','printshop-mobile','block-13762','BlockBox','',1),(13768,'119318','printshop-mobile','block-13767','BlockBox','',1),(13769,'119319','printshop-mobile','block-13768','checkout\\EditBtn','',2),(13770,'119320','printshop-mobile','block-13768','Html_box','',1),(13771,'119321','printshop-mobile','block-13768','Html_box','',4),(13772,'119322','printshop-mobile','block-13768','checkout\\PaymentMethodConfirm','',3),(13773,'119323','printshop-mobile','block-13768','checkout\\EditBtn','',5),(13774,'119324','printshop-mobile','block-13768','checkout\\ContactConfirm','',6),(13775,'119325','printshop-mobile','block-13767-2','BlockBox','',1),(13776,'119326','printshop-mobile','block-13775','Html_box','',2),(13777,'119327','printshop-mobile','block-13775','checkout\\EditBtn','',3),(13778,'119328','printshop-mobile','block-13775','checkout\\BillingAddressConfirm','',4),(13779,'119329','printshop-mobile','block-13762','BlockBox','',2),(13780,'119330','printshop-mobile','block-13779','checkout\\CommentsConfirm','',3),(13781,'119331','printshop-mobile','block-13779','Html_box','',1),(13782,'119332','printshop-mobile','block-13779','checkout\\EditBtn','',2),(13783,'119333','printshop-mobile','block-13761-2','BlockBox','',1),(13784,'119334','printshop-mobile','block-13783','Html_box','',1),(13785,'119335','printshop-mobile','block-13783','checkout\\Totals','',2),(13786,'119336','printshop-mobile','block-13783','checkout\\ConfirmBtn','',3),(13787,'119337','printshop-mobile','block-13760','Html_box','',1),(13788,'119338','printshop-mobile','confirmation_q','BlockBox','',1),(13789,'119339','printshop-mobile','block-13788','Html_box','',1),(13790,'119340','printshop-mobile','block-13788','BlockBox','',2),(13791,'119341','printshop-mobile','block-13790','BlockBox','',1),(13792,'119342','printshop-mobile','block-13791','BlockBox','',3),(13793,'119343','printshop-mobile','block-13792','checkout\\EditBtn','',2),(13794,'119344','printshop-mobile','block-13792','Html_box','',1),(13795,'119345','printshop-mobile','block-13792','quote\\Products','',3),(13796,'119346','printshop-mobile','block-13791','BlockBox','',2),(13797,'119347','printshop-mobile','block-13796','checkout\\EditBtn','',2),(13798,'119348','printshop-mobile','block-13796','checkout\\CommentsConfirm','',3),(13799,'119349','printshop-mobile','block-13796','Html_box','',1),(13800,'119350','printshop-mobile','block-13791','BlockBox','',1),(13801,'119351','printshop-mobile','block-13800','BlockBox','',1),(13802,'119352','printshop-mobile','block-13801','Html_box','',5),(13803,'119353','printshop-mobile','block-13801','Html_box','',9),(13804,'119354','printshop-mobile','block-13801','checkout\\EditBtn','',6),(13805,'119355','printshop-mobile','block-13801','checkout\\ShippingConfirm','',7),(13806,'119356','printshop-mobile','block-13801','checkout\\EditBtn','',3),(13807,'119357','printshop-mobile','block-13801','DelayedDespatch\\CheckoutConfirm','',8),(13808,'119358','printshop-mobile','block-13801','checkout\\ShippingAddressConfirm','',4),(13809,'119359','printshop-mobile','block-13801','checkout\\ContactConfirm','',11),(13810,'119360','printshop-mobile','block-13801','checkout\\EditBtn','',10),(13811,'119361','printshop-mobile','block-13801','Html_box','',2),(13812,'119362','printshop-mobile','block-13801','Html_box','',1),(13813,'119363','printshop-mobile','block-13800-2','BlockBox','',1),(13814,'119364','printshop-mobile','block-13813','Html_box','',1),(13815,'119365','printshop-mobile','block-13813','Html_box','',2),(13816,'119366','printshop-mobile','block-13813','checkout\\PaymentMethodConfirm','',7),(13817,'119367','printshop-mobile','block-13813','Html_box','',5),(13818,'119368','printshop-mobile','block-13813','checkout\\BillingAddressConfirm','',4),(13819,'119369','printshop-mobile','block-13813','checkout\\EditBtn','',6),(13820,'119370','printshop-mobile','block-13813','checkout\\EditBtn','',3),(13821,'119371','printshop-mobile','block-13790-2','BlockBox','',1),(13822,'119372','printshop-mobile','block-13821','checkout\\ConfirmBtn','',3),(13823,'119373','printshop-mobile','block-13821','Html_box','',1),(13824,'119374','printshop-mobile','block-13821','checkout\\Totals','',2),(13825,'119375','printshop-mobile','confirmation_s','BlockBox','',1),(13826,'119376','printshop-mobile','block-13825','Html_box','',1),(13827,'119377','printshop-mobile','block-13825','BlockBox','',2),(13828,'119378','printshop-mobile','block-13827','BlockBox','',1),(13829,'119379','printshop-mobile','block-13828','BlockBox','',2),(13830,'119380','printshop-mobile','block-13829','checkout\\CommentsConfirm','',3),(13831,'119381','printshop-mobile','block-13829','checkout\\EditBtn','',2),(13832,'119382','printshop-mobile','block-13829','Html_box','',1),(13833,'119383','printshop-mobile','block-13828','BlockBox','',3),(13834,'119384','printshop-mobile','block-13833','sample\\Products','',2),(13835,'119385','printshop-mobile','block-13833','Html_box','',1),(13836,'119386','printshop-mobile','block-13833','checkout\\EditBtn','',3),(13837,'119387','printshop-mobile','block-13828','BlockBox','',1),(13838,'119388','printshop-mobile','block-13837','BlockBox','',1),(13839,'119389','printshop-mobile','block-13838','Html_box','',9),(13840,'119390','printshop-mobile','block-13838','checkout\\ContactConfirm','',11),(13841,'119391','printshop-mobile','block-13838','checkout\\EditBtn','',6),(13842,'119392','printshop-mobile','block-13838','checkout\\EditBtn','',10),(13843,'119393','printshop-mobile','block-13838','Html_box','',1),(13844,'119394','printshop-mobile','block-13838','DelayedDespatch\\CheckoutConfirm','',8),(13845,'119395','printshop-mobile','block-13838','checkout\\EditBtn','',3),(13846,'119396','printshop-mobile','block-13838','checkout\\ShippingAddressConfirm','',4),(13847,'119397','printshop-mobile','block-13838','Html_box','',5),(13848,'119398','printshop-mobile','block-13838','Html_box','',2),(13849,'119399','printshop-mobile','block-13838','checkout\\ShippingConfirm','',7),(13850,'119400','printshop-mobile','block-13837-2','BlockBox','',1),(13851,'119401','printshop-mobile','block-13850','Html_box','',5),(13852,'119402','printshop-mobile','block-13850','Html_box','',1),(13853,'119403','printshop-mobile','block-13850','checkout\\EditBtn','',6),(13854,'119404','printshop-mobile','block-13850','checkout\\BillingAddressConfirm','',4),(13855,'119405','printshop-mobile','block-13850','checkout\\EditBtn','',3),(13856,'119406','printshop-mobile','block-13850','Html_box','',2),(13857,'119407','printshop-mobile','block-13850','checkout\\PaymentMethodConfirm','',7),(13858,'119408','printshop-mobile','block-13827-2','BlockBox','',1),(13859,'119409','printshop-mobile','block-13858','checkout\\Totals','',2),(13860,'119410','printshop-mobile','block-13858','Html_box','',1),(13861,'119411','printshop-mobile','block-13858','checkout\\ConfirmBtn','',3),(13862,'119412','printshop-mobile','contact','BlockBox','',1),(13863,'119413','printshop-mobile','block-13862','BlockBox','',4),(13864,'119414','printshop-mobile','block-13863','contact\\Map','',1),(13865,'119415','printshop-mobile','block-13863-2','contact\\StreetView','',1),(13866,'119416','printshop-mobile','block-13862','BlockBox','',3),(13867,'119417','printshop-mobile','block-13866','contact\\ContactForm','',1),(13868,'119418','printshop-mobile','block-13866-2','contact\\Contacts','',1),(13869,'119419','printshop-mobile','block-13862','info\\Title','',1),(13870,'119420','printshop-mobile','created_success','BlockBox','',1),(13871,'119421','printshop-mobile','block-13870','Html_box','',2),(13872,'119422','printshop-mobile','block-13870','Html_box','',1),(13873,'119423','printshop-mobile','credit_note','invoice\\Container','',1),(13874,'119424','printshop-mobile','block-13873','BlockBox','',2),(13875,'119425','printshop-mobile','block-13874','BlockBox','',8),(13876,'119426','printshop-mobile','block-13875','BlockBox','',1),(13877,'119427','printshop-mobile','block-13876','Text','',1),(13878,'119428','printshop-mobile','block-13876','invoice\\ShippingMethod','',2),(13879,'119429','printshop-mobile','block-13875-2','BlockBox','',1),(13880,'119430','printshop-mobile','block-13879','invoice\\ShippingMethod','',2),(13881,'119431','printshop-mobile','block-13879','Text','',1),(13882,'119432','printshop-mobile','block-13874','BlockBox','',7),(13883,'119433','printshop-mobile','block-13882','BlockBox','',1),(13884,'119434','printshop-mobile','block-13883','invoice\\BillingAddress','',2),(13885,'119435','printshop-mobile','block-13883','Text','',1),(13886,'119436','printshop-mobile','block-13882-2','BlockBox','',1),(13887,'119437','printshop-mobile','block-13886','Text','',5),(13888,'119438','printshop-mobile','block-13886','invoice\\CustomerName','',2),(13889,'119439','printshop-mobile','block-13886','invoice\\CustomerEmail','',6),(13890,'119440','printshop-mobile','block-13886','Text','',3),(13891,'119441','printshop-mobile','block-13886','Text','',1),(13892,'119442','printshop-mobile','block-13886','invoice\\CustomerPhone','',4),(13893,'119443','printshop-mobile','block-13874-2','invoice\\PaymentDate','',3),(13894,'119444','printshop-mobile','block-13874-2','Text','',2),(13895,'119445','printshop-mobile','block-13874-2','invoice\\OrderId','',1),(13896,'119446','printshop-mobile','block-13873','BlockBox','',4),(13897,'119447','printshop-mobile','block-13896','BlockBox','',1),(13898,'119448','printshop-mobile','block-13897','Text','',1),(13899,'119449','printshop-mobile','block-13897','invoice\\ShippingAddress','',2),(13900,'119450','printshop-mobile','block-13896-2','BlockBox','',1),(13901,'119451','printshop-mobile','block-13873','BlockBox','',1),(13902,'119452','printshop-mobile','block-13901','Logo','',1),(13903,'119453','printshop-mobile','block-13901-2','BlockBox','',1),(13904,'119454','printshop-mobile','block-13903','invoice\\StoreAddress','',1),(13905,'119455','printshop-mobile','block-13901-2','BlockBox','',3),(13906,'119456','printshop-mobile','block-13905','Text','',1),(13907,'119457','printshop-mobile','block-13905-2','invoice\\StoreEmail','',1),(13908,'119458','printshop-mobile','block-13901-2','BlockBox','',2),(13909,'119459','printshop-mobile','block-13908','Text','',1),(13910,'119460','printshop-mobile','block-13908-2','invoice\\StorePhone','',1),(13911,'119461','printshop-mobile','block-13901-2','BlockBox','',4),(13912,'119462','printshop-mobile','block-13911','Text','',1),(13913,'119463','printshop-mobile','block-13911-2','invoice\\StoreSite','',1),(13914,'119464','printshop-mobile','block-13873','invoice\\Products','',3),(13915,'119465','printshop-mobile','block-13873','BlockBox','',5),(13916,'119466','printshop-mobile','block-13915','invoice\\StoreAddress','',8),(13917,'119467','printshop-mobile','block-13915','Text','',1),(13918,'119468','printshop-mobile','block-13915-2','Text','',2),(13919,'119469','printshop-mobile','block-13915-2','Logo','',1),(13920,'119470','printshop-mobile','block-13915-3','BlockBox','',2),(13921,'119471','printshop-mobile','block-13920','Text','',1),(13922,'119472','printshop-mobile','block-13920-2','invoice\\StorePhone','',1),(13923,'119473','printshop-mobile','block-13915-3','BlockBox','',3),(13924,'119474','printshop-mobile','block-13923','Text','',1),(13925,'119475','printshop-mobile','block-13923-2','invoice\\StoreEmail','',1),(13926,'119476','printshop-mobile','block-13915-3','Text','',1),(13927,'119477','printshop-mobile','delivery-location','DeliveryLocation\\LocationProducts','',8),(13928,'119478','printshop-mobile','delivery-location','DeliveryLocation\\LocationLongDescription','',5),(13929,'119479','printshop-mobile','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(13930,'119480','printshop-mobile','delivery-location','DeliveryLocation\\LocationDescription','',3),(13931,'119481','printshop-mobile','delivery-location','DeliveryLocation\\FeaturedList','',6),(13932,'119482','printshop-mobile','delivery-location','DeliveryLocation\\LocationList','',7),(13933,'119483','printshop-mobile','delivery-location','DeliveryLocation\\LocationTitle','',2),(13934,'119484','printshop-mobile','delivery-location-default','DeliveryLocation\\TopLocationList','',2),(13935,'119485','printshop-mobile','delivery-location-default','Heading','',1),(13936,'119486','printshop-mobile','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(13937,'119487','printshop-mobile','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(13938,'119488','printshop-mobile','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(13939,'119489','printshop-mobile','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(13940,'119490','printshop-mobile','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(13941,'119491','printshop-mobile','delivery_loc_2','DeliveryLocation\\LocationList','',7),(13942,'119492','printshop-mobile','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(13943,'119493','printshop-mobile','email','email\\Content','',3),(13944,'119494','printshop-mobile','email','email\\BlockBox','',1),(13945,'119495','printshop-mobile','block-13944','Logo','logo-2.png',1),(13946,'119496','printshop-mobile','email','Copyright','',7),(13947,'119497','printshop-mobile','email','email\\BlockBox','',4),(13948,'119498','printshop-mobile','email','Text','',5),(13949,'119499','printshop-mobile','email','email\\BlockBox','',2),(13950,'119500','printshop-mobile','block-13949','email\\Title','',1),(13951,'119501','printshop-mobile','block-13949-2','email\\Date','',1),(13952,'119502','printshop-mobile','email_2','email\\BlockBox','',1),(13953,'119503','printshop-mobile','block-13952','email\\BlockBox','',1),(13954,'119504','printshop-mobile','block-13953','email\\Content','',3),(13955,'119505','printshop-mobile','block-13953','email\\BlockBox','',2),(13956,'119506','printshop-mobile','block-13955','email\\Title','',1),(13957,'119507','printshop-mobile','block-13955-2','email\\Date','',1),(13958,'119508','printshop-mobile','block-13953','Copyright','',4),(13959,'119509','printshop-mobile','block-13953','Logo','',1),(13960,'119510','printshop-mobile','email_3','email\\BlockBox','',1),(13961,'119511','printshop-mobile','block-13960','email\\BlockBox','',1),(13962,'119512','printshop-mobile','block-13961','Logo','',1),(13963,'119513','printshop-mobile','block-13961','Copyright','',3),(13964,'119514','printshop-mobile','block-13961','email\\BlockBox','',2),(13965,'119515','printshop-mobile','block-13964','email\\BlockBox','',1),(13966,'119516','printshop-mobile','block-13965','email\\Title','',1),(13967,'119517','printshop-mobile','block-13965-2','email\\Date','',1),(13968,'119518','printshop-mobile','block-13964','email\\Content','',2),(13969,'119519','printshop-mobile','email_4','email\\BlockBox','',1),(13970,'119520','printshop-mobile','block-13969','email\\BlockBox','',1),(13971,'119521','printshop-mobile','block-13970','email\\BlockBox','',1),(13972,'119522','printshop-mobile','block-13971','email\\Content','',2),(13973,'119523','printshop-mobile','block-13971','email\\BlockBox','',1),(13974,'119524','printshop-mobile','block-13973','Logo','',1),(13975,'119525','printshop-mobile','block-13973-2','email\\Title','',1),(13976,'119526','printshop-mobile','block-13973-2','email\\Date','',2),(13977,'119527','printshop-mobile','block-13970','Copyright','',2),(13978,'119528','printshop-mobile','footer','BlockBox','',1),(13979,'119529','printshop-mobile','block-13978','BlockBox','',4),(13980,'119530','printshop-mobile','block-13979','Text','',1),(13981,'119531','printshop-mobile','block-13979','Menu','footer3',2),(13982,'119532','printshop-mobile','block-13978','Copyright','',10),(13983,'119533','printshop-mobile','block-13978','BlockBox','',2),(13984,'119534','printshop-mobile','block-13983','Menu','footer2',2),(13985,'119535','printshop-mobile','block-13983','Text','',1),(13986,'119536','printshop-mobile','block-13978','BlockBox','',3),(13987,'119537','printshop-mobile','block-13986','Text','',1),(13988,'119538','printshop-mobile','block-13986','Menu','footer1',2),(13989,'119539','printshop-mobile','block-13978','BlockBox','',1),(13990,'119540','printshop-mobile','block-13989','Contacts','',2),(13991,'119541','printshop-mobile','block-13989','Text','',1),(13992,'119542','printshop-mobile','for_menu','BlockBox','',1),(13993,'119543','printshop-mobile','block-13992','Html_box','',1),(13994,'119544','printshop-mobile','block-13992-2','Languages','',1),(13995,'119545','printshop-mobile','for_menu','BlockBox','',3),(13996,'119546','printshop-mobile','block-13995','Html_box','',1),(13997,'119547','printshop-mobile','block-13995-2','Currencies','',1),(13998,'119548','printshop-mobile','gift','BlockBox','',1),(13999,'119549','printshop-mobile','block-13998','BlockBox','',3),(14000,'119550','printshop-mobile','block-13999','BlockBox','',1),(14001,'119551','printshop-mobile','block-14000','BlockBox','',1),(14002,'119552','printshop-mobile','block-14001','BlockBox','',9),(14003,'119553','printshop-mobile','block-14002','Text','',1),(14004,'119554','printshop-mobile','block-14002','invoice\\StoreEmail','',3),(14005,'119555','printshop-mobile','block-14002','invoice\\StorePhone','',2),(14006,'119556','printshop-mobile','block-14001','Text','',6),(14007,'119557','printshop-mobile','block-14001','Text','',4),(14008,'119558','printshop-mobile','block-14001','Text','',7),(14009,'119559','printshop-mobile','block-14001','Text','',2),(14010,'119560','printshop-mobile','block-14001','BlockBox','',8),(14011,'119561','printshop-mobile','block-14010','Text','',1),(14012,'119562','printshop-mobile','block-14010-2','gift\\CodeView','',1),(14013,'119563','printshop-mobile','block-14001','gift\\MessageView','',5),(14014,'119564','printshop-mobile','block-14001','gift\\AmountView','',3),(14015,'119565','printshop-mobile','block-14001','Text','',1),(14016,'119566','printshop-mobile','block-13999-2','gift\\Form','',2),(14017,'119567','printshop-mobile','block-13999-2','Text','',1),(14018,'119568','printshop-mobile','block-13998','info\\Title','',1),(14019,'119569','printshop-mobile','gift_card','BlockBox','',1),(14020,'119570','printshop-mobile','block-14019','Text','',9),(14021,'119571','printshop-mobile','block-14019','Text','',4),(14022,'119572','printshop-mobile','block-14019','Logo','',1),(14023,'119573','printshop-mobile','block-14019','Image','',2),(14024,'119574','printshop-mobile','block-14019','Text','',6),(14025,'119575','printshop-mobile','block-14019','gift\\AmountView','',5),(14026,'119576','printshop-mobile','block-14019','gift\\MessageView','',7),(14027,'119577','printshop-mobile','block-14019','BlockBox','',10),(14028,'119578','printshop-mobile','block-14027','Text','',1),(14029,'119579','printshop-mobile','block-14027-2','gift\\CodeView','',1),(14030,'119580','printshop-mobile','block-14019','Text','',3),(14031,'119581','printshop-mobile','block-14019','Text','',8),(14032,'119582','printshop-mobile','block-14019','BlockBox','',11),(14033,'119583','printshop-mobile','block-14032','invoice\\StorePhone','',2),(14034,'119584','printshop-mobile','block-14032','Text','',1),(14035,'119585','printshop-mobile','block-14032','invoice\\StoreEmail','',3),(14036,'119586','printshop-mobile','gift_card_2','BlockBox','',1),(14037,'119587','printshop-mobile','block-14036','Text','',1),(14038,'119588','printshop-mobile','block-14036','Text','',2),(14039,'119589','printshop-mobile','block-14036','Text','',6),(14040,'119590','printshop-mobile','block-14036','gift\\MessageView','',5),(14041,'119591','printshop-mobile','block-14036','Text','',7),(14042,'119592','printshop-mobile','block-14036','Text','',4),(14043,'119593','printshop-mobile','block-14036','BlockBox','',9),(14044,'119594','printshop-mobile','block-14043','invoice\\StorePhone','',2),(14045,'119595','printshop-mobile','block-14043','Text','',1),(14046,'119596','printshop-mobile','block-14043','invoice\\StoreEmail','',3),(14047,'119597','printshop-mobile','block-14036','BlockBox','',8),(14048,'119598','printshop-mobile','block-14047','Text','',1),(14049,'119599','printshop-mobile','block-14047-2','gift\\CodeView','',1),(14050,'119600','printshop-mobile','block-14036','gift\\AmountView','',3),(14051,'119601','printshop-mobile','gift_card_2_pdf','BlockBox','',1),(14052,'119602','printshop-mobile','block-14051','BlockBox','',12),(14053,'119603','printshop-mobile','block-14052','invoice\\StoreEmail','',4),(14054,'119604','printshop-mobile','block-14052','invoice\\StorePhone','',3),(14055,'119605','printshop-mobile','block-14052','Html_box','',1),(14056,'119606','printshop-mobile','block-14051','BlockBox','',11),(14057,'119607','printshop-mobile','block-14056','Html_box','',1),(14058,'119608','printshop-mobile','block-14056-2','gift\\CodeViewPdf','',1),(14059,'119609','printshop-mobile','block-14051','BlockBox','',1),(14060,'119610','printshop-mobile','block-14059','Text','',4),(14061,'119611','printshop-mobile','block-14059','Html_box','',1),(14062,'119612','printshop-mobile','block-14059','Html_box','',2),(14063,'119613','printshop-mobile','block-14059','gift\\AmountViewPdf','',3),(14064,'119614','printshop-mobile','block-14059','gift\\MessageViewPdf','',5),(14065,'119615','printshop-mobile','block-14059','Html_box','',7),(14066,'119616','printshop-mobile','block-14059','Html_box','',6),(14067,'119617','printshop-mobile','gift_card_2_pdf','Import','',1),(14068,'119618','printshop-mobile','gift_card_pdf','BlockBox','',1),(14069,'119619','printshop-mobile','block-14068','BlockBox','',12),(14070,'119620','printshop-mobile','block-14069','invoice\\StoreEmail','',4),(14071,'119621','printshop-mobile','block-14069','invoice\\StorePhone','',3),(14072,'119622','printshop-mobile','block-14069','Html_box','',1),(14073,'119623','printshop-mobile','block-14068','BlockBox','',11),(14074,'119624','printshop-mobile','block-14073','Html_box','',1),(14075,'119625','printshop-mobile','block-14073-2','gift\\CodeViewPdf','',1),(14076,'119626','printshop-mobile','block-14068','BlockBox','',1),(14077,'119627','printshop-mobile','block-14076','Text','',4),(14078,'119628','printshop-mobile','block-14076','Html_box','',1),(14079,'119629','printshop-mobile','block-14076','Html_box','',2),(14080,'119630','printshop-mobile','block-14076','gift\\AmountViewPdf','',3),(14081,'119631','printshop-mobile','block-14076','gift\\MessageViewPdf','',5),(14082,'119632','printshop-mobile','block-14076','Html_box','',7),(14083,'119633','printshop-mobile','block-14076','Html_box','',6),(14084,'119634','printshop-mobile','gift_card_pdf','Import','',1),(14085,'119635','printshop-mobile','gift_certificate','BlockBox','',1),(14086,'119636','printshop-mobile','block-14085','account\\ApplyCertificate','',2),(14087,'119637','printshop-mobile','block-14085','Html_box','',1),(14088,'119638','printshop-mobile','gigt_card_3','BlockBox','',1),(14089,'119639','printshop-mobile','block-14088','Text','',7),(14090,'119640','printshop-mobile','block-14088','Text','',4),(14091,'119641','printshop-mobile','block-14088','gift\\AmountView','',3),(14092,'119642','printshop-mobile','block-14088','Text','',2),(14093,'119643','printshop-mobile','block-14088','gift\\MessageView','',5),(14094,'119644','printshop-mobile','block-14088','Text','',1),(14095,'119645','printshop-mobile','block-14088','BlockBox','',9),(14096,'119646','printshop-mobile','block-14095','invoice\\StoreEmail','',3),(14097,'119647','printshop-mobile','block-14095','invoice\\StorePhone','',2),(14098,'119648','printshop-mobile','block-14095','Text','',1),(14099,'119649','printshop-mobile','block-14088','Text','',6),(14100,'119650','printshop-mobile','block-14088','BlockBox','',8),(14101,'119651','printshop-mobile','block-14100','Text','',1),(14102,'119652','printshop-mobile','block-14100-2','gift\\CodeView','',1),(14103,'119653','printshop-mobile','gigt_card_3_pdf','BlockBox','',1),(14104,'119654','printshop-mobile','block-14103','BlockBox','',12),(14105,'119655','printshop-mobile','block-14104','invoice\\StoreEmail','',4),(14106,'119656','printshop-mobile','block-14104','invoice\\StorePhone','',3),(14107,'119657','printshop-mobile','block-14104','Html_box','',1),(14108,'119658','printshop-mobile','block-14103','BlockBox','',11),(14109,'119659','printshop-mobile','block-14108','Html_box','',1),(14110,'119660','printshop-mobile','block-14108-2','gift\\CodeViewPdf','',1),(14111,'119661','printshop-mobile','block-14103','BlockBox','',1),(14112,'119662','printshop-mobile','block-14111','Text','',4),(14113,'119663','printshop-mobile','block-14111','Html_box','',1),(14114,'119664','printshop-mobile','block-14111','Html_box','',2),(14115,'119665','printshop-mobile','block-14111','gift\\AmountViewPdf','',3),(14116,'119666','printshop-mobile','block-14111','gift\\MessageViewPdf','',5),(14117,'119667','printshop-mobile','block-14111','Html_box','',7),(14118,'119668','printshop-mobile','block-14111','Html_box','',6),(14119,'119669','printshop-mobile','header','Logo','',2),(14120,'119670','printshop-mobile','header','catalog\\Paging','',3),(14121,'119671','printshop-mobile','header','BlockBox','',1),(14122,'119672','printshop-mobile','block-14121','Text','',1),(14123,'119673','printshop-mobile','block-14121','BlockBox','',2),(14124,'119674','printshop-mobile','block-14123','Text','',2),(14125,'119675','printshop-mobile','block-14123','Image','',1),(14126,'119676','printshop-mobile','block-14123-2','BlockBox','',1),(14127,'119677','printshop-mobile','block-14126','Html_box','',2),(14128,'119678','printshop-mobile','block-14126-2','Html_box','',2),(14129,'119679','printshop-mobile','header','BlockBox','',3),(14130,'119680','printshop-mobile','block-14129','Menu','Categories',1),(14131,'119681','printshop-mobile','block-14129-2','Search','',1),(14132,'119682','printshop-mobile','block-14129-3','Account','',1),(14133,'119683','printshop-mobile','block-14129-4','Cart','',1),(14134,'119684','printshop-mobile','info','BlockBox','',1),(14135,'119685','printshop-mobile','block-14134','info\\Content','',3),(14136,'119686','printshop-mobile','block-14134','info\\Title','',2),(14137,'119687','printshop-mobile','invoice','invoice\\Container','',1),(14138,'119688','printshop-mobile','block-14137','BlockBox','',4),(14139,'119689','printshop-mobile','block-14138','BlockBox','',1),(14140,'119690','printshop-mobile','block-14139','invoice\\ShippingAddress','',2),(14141,'119691','printshop-mobile','block-14139','Text','',1),(14142,'119692','printshop-mobile','block-14138-2','BlockBox','',1),(14143,'119693','printshop-mobile','block-14142','invoice\\Totals','',1),(14144,'119694','printshop-mobile','block-14137','invoice\\Products','',3),(14145,'119695','printshop-mobile','block-14137','BlockBox','',1),(14146,'119696','printshop-mobile','block-14145','Logo','',1),(14147,'119697','printshop-mobile','block-14145-2','BlockBox','',2),(14148,'119698','printshop-mobile','block-14147','Text','',1),(14149,'119699','printshop-mobile','block-14147-2','invoice\\StorePhone','',1),(14150,'119700','printshop-mobile','block-14145-2','BlockBox','',1),(14151,'119701','printshop-mobile','block-14150','invoice\\StoreAddress','',1),(14152,'119702','printshop-mobile','block-14145-2','BlockBox','',4),(14153,'119703','printshop-mobile','block-14152','Text','',1),(14154,'119704','printshop-mobile','block-14152-2','invoice\\StoreSite','',1),(14155,'119705','printshop-mobile','block-14145-2','BlockBox','',3),(14156,'119706','printshop-mobile','block-14155','Text','',1),(14157,'119707','printshop-mobile','block-14155-2','invoice\\StoreEmail','',1),(14158,'119708','printshop-mobile','block-14137','BlockBox','',5),(14159,'119709','printshop-mobile','block-14158','Text','',1),(14160,'119710','printshop-mobile','block-14158','invoice\\StoreAddress','',8),(14161,'119711','printshop-mobile','block-14158-2','Text','',2),(14162,'119712','printshop-mobile','block-14158-2','Logo','',1),(14163,'119713','printshop-mobile','block-14158-3','BlockBox','',3),(14164,'119714','printshop-mobile','block-14163','Text','',1),(14165,'119715','printshop-mobile','block-14163-2','invoice\\StoreEmail','',1),(14166,'119716','printshop-mobile','block-14158-3','BlockBox','',2),(14167,'119717','printshop-mobile','block-14166','Text','',1),(14168,'119718','printshop-mobile','block-14166-2','invoice\\StorePhone','',1),(14169,'119719','printshop-mobile','block-14158-3','Text','',1),(14170,'119720','printshop-mobile','block-14137','BlockBox','',2),(14171,'119721','printshop-mobile','block-14170','BlockBox','',8),(14172,'119722','printshop-mobile','block-14171','BlockBox','',1),(14173,'119723','printshop-mobile','block-14172','Text','',1),(14174,'119724','printshop-mobile','block-14172','invoice\\ShippingMethod','',2),(14175,'119725','printshop-mobile','block-14171-2','BlockBox','',1),(14176,'119726','printshop-mobile','block-14175','invoice\\ShippingMethod','',2),(14177,'119727','printshop-mobile','block-14175','Text','',1),(14178,'119728','printshop-mobile','block-14170','BlockBox','',7),(14179,'119729','printshop-mobile','block-14178','BlockBox','',1),(14180,'119730','printshop-mobile','block-14179','Text','',1),(14181,'119731','printshop-mobile','block-14179','invoice\\BillingAddress','',2),(14182,'119732','printshop-mobile','block-14178-2','BlockBox','',1),(14183,'119733','printshop-mobile','block-14182','invoice\\CustomerPhone','',4),(14184,'119734','printshop-mobile','block-14182','Text','',1),(14185,'119735','printshop-mobile','block-14182','invoice\\CustomerName','',2),(14186,'119736','printshop-mobile','block-14182','Text','',3),(14187,'119737','printshop-mobile','block-14182','Text','',5),(14188,'119738','printshop-mobile','block-14182','invoice\\CustomerEmail','',6),(14189,'119739','printshop-mobile','block-14170-2','invoice\\PaymentMethod','',5),(14190,'119740','printshop-mobile','block-14170-2','invoice\\PaymentDate','',3),(14191,'119741','printshop-mobile','block-14170-2','invoice\\OrderId','',1),(14192,'119742','printshop-mobile','block-14170-2','invoice\\OrderBarcode','',6),(14193,'119743','printshop-mobile','block-14170-2','Text','',2),(14194,'119744','printshop-mobile','block-14170-2','Text','',4),(14195,'119745','printshop-mobile','login_account','BlockBox','',1),(14196,'119746','printshop-mobile','block-14195','Tabs','',2),(14197,'119747','printshop-mobile','block-14196-1','login\\Returning','',1),(14198,'119748','printshop-mobile','block-14196-2','login\\Register','',2),(14199,'119749','printshop-mobile','block-14195','BlockBox','',1),(14200,'119750','printshop-mobile','block-14199','Html_box','',3),(14201,'119751','printshop-mobile','block-14199','Html_box','',1),(14202,'119752','printshop-mobile','block-14199','login\\Socials','',2),(14203,'119753','printshop-mobile','login_checkout','BlockBox','',1),(14204,'119754','printshop-mobile','block-14203','BlockBox','',1),(14205,'119755','printshop-mobile','block-14204','Html_box','',2),(14206,'119756','printshop-mobile','block-14204','checkout\\CreateBtn','',5),(14207,'119757','printshop-mobile','block-14204','checkout\\GuestBtn','',3),(14208,'119758','printshop-mobile','block-14204','Html_box','',4),(14209,'119759','printshop-mobile','block-14204','BlockBox','',6),(14210,'119760','printshop-mobile','block-14209','Html_box','',1),(14211,'119761','printshop-mobile','block-14209','login\\Socials','',2),(14212,'119762','printshop-mobile','block-14204','login\\Returning','',1),(14213,'119763','printshop-mobile','block-14204','Html_box','',1),(14214,'119764','printshop-mobile','login_checkout2','BlockBox','',1),(14215,'119765','printshop-mobile','block-14214','Html_box','',1),(14216,'119766','printshop-mobile','block-14214','Html_box','',3),(14217,'119767','printshop-mobile','block-14214','login\\Socials','',2),(14218,'119768','printshop-mobile','block-14214','Tabs','',4),(14219,'119769','printshop-mobile','block-14218-1','BlockBox','',1),(14220,'119770','printshop-mobile','block-14219','Html_box','',1),(14221,'119771','printshop-mobile','block-14219-2','BlockBox','',1),(14222,'119772','printshop-mobile','block-14221','Html_box','',2),(14223,'119773','printshop-mobile','block-14221','login\\Guest','',1),(14224,'119774','printshop-mobile','block-14218-2','login\\Returning','',1),(14225,'119775','printshop-mobile','block-14218-3','BlockBox','',1),(14226,'119776','printshop-mobile','block-14225','Html_box','',1),(14227,'119777','printshop-mobile','block-14225-2','BlockBox','',1),(14228,'119778','printshop-mobile','block-14227','login\\Register','',1),(14229,'119779','printshop-mobile','block-14227','Html_box','',2),(14230,'119780','printshop-mobile','login_checkout2_q','BlockBox','',1),(14231,'119781','printshop-mobile','block-14230','login\\Socials','',2),(14232,'119782','printshop-mobile','block-14230','Html_box','',1),(14233,'119783','printshop-mobile','block-14230','Html_box','',3),(14234,'119784','printshop-mobile','block-14230','Tabs','',4),(14235,'119785','printshop-mobile','block-14234-1','BlockBox','',1),(14236,'119786','printshop-mobile','block-14235','Html_box','',1),(14237,'119787','printshop-mobile','block-14235-2','quote\\FastOrder','',1),(14238,'119788','printshop-mobile','block-14234-2','login\\Returning','',1),(14239,'119789','printshop-mobile','block-14234-3','BlockBox','',1),(14240,'119790','printshop-mobile','block-14239','Html_box','',1),(14241,'119791','printshop-mobile','block-14239','Import','',2),(14242,'119792','printshop-mobile','block-14239-2','BlockBox','',1),(14243,'119793','printshop-mobile','block-14242','Html_box','',2),(14244,'119794','printshop-mobile','block-14242','login\\Register','',1),(14245,'119795','printshop-mobile','login_checkout2_s','BlockBox','',1),(14246,'119796','printshop-mobile','block-14245','Html_box','',1),(14247,'119797','printshop-mobile','block-14245','Tabs','',4),(14248,'119798','printshop-mobile','block-14247-1','BlockBox','',1),(14249,'119799','printshop-mobile','block-14248','Html_box','',1),(14250,'119800','printshop-mobile','block-14248-2','quote\\FastOrder','',1),(14251,'119801','printshop-mobile','block-14247-2','login\\Returning','',1),(14252,'119802','printshop-mobile','block-14247-3','BlockBox','',1),(14253,'119803','printshop-mobile','block-14252','Html_box','',1),(14254,'119804','printshop-mobile','block-14252-2','BlockBox','',1),(14255,'119805','printshop-mobile','block-14254','Html_box','',2),(14256,'119806','printshop-mobile','block-14254','login\\Register','',1),(14257,'119807','printshop-mobile','block-14245','login\\Socials','',2),(14258,'119808','printshop-mobile','block-14245','Html_box','',3),(14259,'119809','printshop-mobile','login_checkout_q','BlockBox','',1),(14260,'119810','printshop-mobile','block-14259','BlockBox','',1),(14261,'119811','printshop-mobile','block-14260','checkout\\CreateBtn','',5),(14262,'119812','printshop-mobile','block-14260','checkout\\GuestBtn','',2),(14263,'119813','printshop-mobile','block-14260','Html_box','',1),(14264,'119814','printshop-mobile','block-14260','Html_box','',4),(14265,'119815','printshop-mobile','block-14260','BlockBox','',6),(14266,'119816','printshop-mobile','block-14265','login\\Socials','',2),(14267,'119817','printshop-mobile','block-14265','Html_box','',1),(14268,'119818','printshop-mobile','block-14260-2','login\\Returning','',2),(14269,'119819','printshop-mobile','block-14260-2','Html_box','',1),(14270,'119820','printshop-mobile','login_checkout_s','BlockBox','',1),(14271,'119821','printshop-mobile','block-14270','BlockBox','',1),(14272,'119822','printshop-mobile','block-14271','BlockBox','',5),(14273,'119823','printshop-mobile','block-14272','Html_box','',1),(14274,'119824','printshop-mobile','block-14272','login\\Socials','',2),(14275,'119825','printshop-mobile','block-14271','Html_box','',3),(14276,'119826','printshop-mobile','block-14271','checkout\\CreateBtn','',4),(14277,'119827','printshop-mobile','block-14271','Html_box','',1),(14278,'119828','printshop-mobile','block-14271','checkout\\GuestBtn','',2),(14279,'119829','printshop-mobile','block-14271-2','Html_box','',1),(14280,'119830','printshop-mobile','block-14271-2','login\\Returning','',2),(14281,'119831','printshop-mobile','logoff','BlockBox','',1),(14282,'119832','printshop-mobile','block-14281','Html_box','',1),(14283,'119833','printshop-mobile','logoff_forever','BlockBox','',1),(14284,'119834','printshop-mobile','block-14283','Html_box','',1),(14285,'119835','printshop-mobile','main','BlockBox','',5),(14286,'119836','printshop-mobile','block-14285','TopCategories','',1),(14287,'119837','printshop-mobile','block-14285','PromoCode','',2),(14288,'119838','printshop-mobile','block-14285','Tabs','',3),(14289,'119839','printshop-mobile','block-14288-1','NewProducts','4',1),(14290,'119840','printshop-mobile','block-14288-2','SpecialsProducts','4',1),(14291,'119841','printshop-mobile','block-14288-3','FeaturedProducts','4',1),(14292,'119842','printshop-mobile','main','Heading','',2),(14293,'119843','printshop-mobile','main','BlockBox','',6),(14294,'119844','printshop-mobile','block-14293','BlockBox','',1),(14295,'119845','printshop-mobile','block-14294','Bestsellers','10',1),(14296,'119846','printshop-mobile','block-14294-2','Reviews','4',1),(14297,'119847','printshop-mobile','manufacturers','BlockBox','',1),(14298,'119848','printshop-mobile','block-14297','Html_box','',1),(14299,'119849','printshop-mobile','block-14297','Brands','',2),(14300,'119850','printshop-mobile','messages-index','BlockBox','',1),(14301,'119851','printshop-mobile','block-14300','BlockBox','',1),(14302,'119852','printshop-mobile','block-14301','BlockBox','',1),(14303,'119853','printshop-mobile','block-14302','Messages\\Sidebar','',1),(14304,'119854','printshop-mobile','block-14301-2','Messages\\Listing','',1),(14305,'119855','printshop-mobile','messages-new','BlockBox','',1),(14306,'119856','printshop-mobile','block-14305','BlockBox','',1),(14307,'119857','printshop-mobile','block-14306','Messages\\Sidebar','',1),(14308,'119858','printshop-mobile','block-14306-2','Messages\\NewMessage','',1),(14309,'119859','printshop-mobile','messages-view','BlockBox','',1),(14310,'119860','printshop-mobile','block-14309','BlockBox','',1),(14311,'119861','printshop-mobile','block-14310','Messages\\Sidebar','',1),(14312,'119862','printshop-mobile','block-14310-2','Messages\\Message','',1),(14313,'119863','printshop-mobile','my_password','BlockBox','',1),(14314,'119864','printshop-mobile','block-14313','BlockBox','',1),(14315,'119865','printshop-mobile','block-14314','WidgetsAria','',1),(14316,'119866','printshop-mobile','block-14314-2','account\\ChangePassword','',2),(14317,'119867','printshop-mobile','block-14314-2','Html_box','',1),(14318,'119868','printshop-mobile','block-14314-2','account\\AccountLink','',3),(14319,'119869','printshop-mobile','need_login','BlockBox','',1),(14320,'119870','printshop-mobile','block-14319','BlockBox','',1),(14321,'119871','printshop-mobile','block-14319','Tabs','',2),(14322,'119872','printshop-mobile','block-14321-1','login\\Returning','',1),(14323,'119873','printshop-mobile','block-14321-2','BlockBox','',1),(14324,'119874','printshop-mobile','block-14323','Html_box','',1),(14325,'119875','printshop-mobile','block-14323-2','BlockBox','',1),(14326,'119876','printshop-mobile','block-14325','login\\Register','',1),(14327,'119877','printshop-mobile','block-14325','Html_box','',2),(14328,'119878','printshop-mobile','new-topic','BlockBox','',1),(14329,'119879','printshop-mobile','block-14328','Communication\\NewTopic','',3),(14330,'119880','printshop-mobile','block-14328','Html_box','',1),(14331,'119881','printshop-mobile','block-14328','Breadcrumb','',2),(14332,'119882','printshop-mobile','nnnn','BlockBox','',1),(14333,'119883','printshop-mobile','block-14332','catalog\\Title','',1),(14334,'119884','printshop-mobile','block-14332','BlockBox','',2),(14335,'119885','printshop-mobile','block-14334','Filters','',1),(14336,'119886','printshop-mobile','block-14334-2','Listing','',5),(14337,'119887','printshop-mobile','block-14334-2','catalog\\Image','',1),(14338,'119888','printshop-mobile','block-14334-2','BlockBox','',6),(14339,'119889','printshop-mobile','block-14338','catalog\\CountsItems','',1),(14340,'119890','printshop-mobile','block-14338-2','catalog\\Paging','',1),(14341,'119891','printshop-mobile','block-14334-2','catalog\\ImageMapCategory','',3),(14342,'119892','printshop-mobile','block-14334-2','Categories','',2),(14343,'119893','printshop-mobile','block-14334-2','BlockBox','',4),(14344,'119894','printshop-mobile','block-14343','catalog\\ListingLook','',1),(14345,'119895','printshop-mobile','block-14343','catalog\\ItemsOnPage','',4),(14346,'119896','printshop-mobile','block-14343','catalog\\CompareButton','',2),(14347,'119897','printshop-mobile','block-14343','catalog\\Sorting','',3),(14348,'119898','printshop-mobile','no-logged','BlockBox','',1),(14349,'119899','printshop-mobile','block-14348','Html_box','',1),(14350,'119900','printshop-mobile','block-14348','Communication\\NewTopic','',2),(14351,'119901','printshop-mobile','no_filters','BlockBox','',1),(14352,'119902','printshop-mobile','block-14351','BlockBox','',2),(14353,'119903','printshop-mobile','block-14352','catalog\\Image','',1),(14354,'119904','printshop-mobile','block-14352','BlockBox','',2),(14355,'119905','printshop-mobile','block-14354','catalog\\Sorting','',3),(14356,'119906','printshop-mobile','block-14354','catalog\\ItemsOnPage','',4),(14357,'119907','printshop-mobile','block-14354','HeaderStock','',5),(14358,'119908','printshop-mobile','block-14354','catalog\\CompareButton','',2),(14359,'119909','printshop-mobile','block-14354','catalog\\ListingLook','',1),(14360,'119910','printshop-mobile','block-14351','BlockBox','',4),(14361,'119911','printshop-mobile','block-14360','catalog\\CountsItems','',1),(14362,'119912','printshop-mobile','block-14360-2','catalog\\Paging','',1),(14363,'119913','printshop-mobile','block-14351','catalog\\B2bAddButton','',5),(14364,'119914','printshop-mobile','block-14351','catalog\\Title','',1),(14365,'119915','printshop-mobile','block-14351','Listing','',3),(14366,'119916','printshop-mobile','order_history','BlockBox','',1),(14367,'119917','printshop-mobile','block-14366','BlockBox','',1),(14368,'119918','printshop-mobile','block-14367','WidgetsAria','',1),(14369,'119919','printshop-mobile','block-14367-2','account\\OrdersHistory','',2),(14370,'119920','printshop-mobile','block-14367-2','Html_box','',1),(14371,'119921','printshop-mobile','order_history_info','BlockBox','',1),(14372,'119922','printshop-mobile','block-14371','BlockBox','',1),(14373,'119923','printshop-mobile','block-14372','WidgetsAria','',1),(14374,'119924','printshop-mobile','block-14372-2','account\\OrderReorderButton','',2),(14375,'119925','printshop-mobile','block-14372-2','BlockBox','',7),(14376,'119926','printshop-mobile','block-14375','BlockBox','',3),(14377,'119927','printshop-mobile','block-14376','account\\AccountLink','',3),(14378,'119928','printshop-mobile','block-14376','Html_box','',1),(14379,'119929','printshop-mobile','block-14376','account\\OrderTracking','',2),(14380,'119930','printshop-mobile','block-14375','BlockBox','',2),(14381,'119931','printshop-mobile','block-14380','Html_box','',1),(14382,'119932','printshop-mobile','block-14380','account\\OrderData','',2),(14383,'119933','printshop-mobile','block-14375','BlockBox','',1),(14384,'119934','printshop-mobile','block-14383','account\\OrderData','',2),(14385,'119935','printshop-mobile','block-14383','Html_box','',1),(14386,'119936','printshop-mobile','block-14375-2','BlockBox','',1),(14387,'119937','printshop-mobile','block-14386','Html_box','',1),(14388,'119938','printshop-mobile','block-14386','account\\OrderData','',2),(14389,'119939','printshop-mobile','block-14375-2','BlockBox','',2),(14390,'119940','printshop-mobile','block-14389','Html_box','',1),(14391,'119941','printshop-mobile','block-14389','account\\OrderData','',2),(14392,'119942','printshop-mobile','block-14375-3','BlockBox','',1),(14393,'119943','printshop-mobile','block-14392','Html_box','',1),(14394,'119944','printshop-mobile','block-14392','account\\OrderData','',2),(14395,'119945','printshop-mobile','block-14375-3','BlockBox','',2),(14396,'119946','printshop-mobile','block-14395','Html_box','',1),(14397,'119947','printshop-mobile','block-14395','account\\OrderData','',2),(14398,'119948','printshop-mobile','block-14372-2','account\\OrderDownload','',6),(14399,'119949','printshop-mobile','block-14372-2','account\\OrderProducts','',9),(14400,'119950','printshop-mobile','block-14372-2','Html_box','',11),(14401,'119951','printshop-mobile','block-14372-2','account\\OrderHeading','',1),(14402,'119952','printshop-mobile','block-14372-2','account\\OrderHistory','',12),(14403,'119953','printshop-mobile','block-14372-2','account\\OrderCancelAndReorder','',4),(14404,'119954','printshop-mobile','block-14372-2','Html_box','',8),(14405,'119955','printshop-mobile','block-14372-2','account\\OrderSubTotals','',10),(14406,'119956','printshop-mobile','block-14372-2','account\\OrderPayButton','',5),(14407,'119957','printshop-mobile','block-14372-2','account\\OrderInvoiceButton','',3),(14408,'119958','printshop-mobile','block-14372-2','BlockBox','',13),(14409,'119959','printshop-mobile','block-14408','account\\AccountLink','',1),(14410,'119960','printshop-mobile','block-14408-2','account\\OrderInvoiceButton','',1),(14411,'119961','printshop-mobile','order_pay','BlockBox','',1),(14412,'119962','printshop-mobile','block-14411','BlockBox','',1),(14413,'119963','printshop-mobile','block-14412','WidgetsAria','',1),(14414,'119964','printshop-mobile','block-14412-2','account\\OrderSubTotals','',5),(14415,'119965','printshop-mobile','block-14412-2','account\\OrderHeading','',1),(14416,'119966','printshop-mobile','block-14412-2','Html_box','',3),(14417,'119967','printshop-mobile','block-14412-2','UpdateAndPay\\PayForm','',6),(14418,'119968','printshop-mobile','block-14412-2','BlockBox','',2),(14419,'119969','printshop-mobile','block-14418','BlockBox','',4),(14420,'119970','printshop-mobile','block-14419','Html_box','',1),(14421,'119971','printshop-mobile','block-14419','account\\OrderData','',2),(14422,'119972','printshop-mobile','block-14418','BlockBox','',1),(14423,'119973','printshop-mobile','block-14422','Html_box','',1),(14424,'119974','printshop-mobile','block-14422','account\\OrderData','',2),(14425,'119975','printshop-mobile','block-14418-2','BlockBox','',2),(14426,'119976','printshop-mobile','block-14425','account\\OrderData','',2),(14427,'119977','printshop-mobile','block-14425','Html_box','',1),(14428,'119978','printshop-mobile','block-14418-2','BlockBox','',1),(14429,'119979','printshop-mobile','block-14428','Html_box','',1),(14430,'119980','printshop-mobile','block-14428','account\\OrderData','',2),(14431,'119981','printshop-mobile','block-14418-3','BlockBox','',2),(14432,'119982','printshop-mobile','block-14431','Html_box','',1),(14433,'119983','printshop-mobile','block-14431','account\\OrderData','',2),(14434,'119984','printshop-mobile','block-14418-3','BlockBox','',1),(14435,'119985','printshop-mobile','block-14434','account\\OrderData','',2),(14436,'119986','printshop-mobile','block-14434','Html_box','',1),(14437,'119987','printshop-mobile','block-14412-2','account\\OrderProducts','',4),(14438,'119988','printshop-mobile','packingslip','invoice\\Container','',2),(14439,'119989','printshop-mobile','block-14438','packingslip\\Products','',3),(14440,'119990','printshop-mobile','block-14438','BlockBox','',2),(14441,'119991','printshop-mobile','block-14440','BlockBox','',2),(14442,'119992','printshop-mobile','block-14441','BlockBox','',1),(14443,'119993','printshop-mobile','block-14442','Text','',1),(14444,'119994','printshop-mobile','block-14442','invoice\\ShippingAddress','',2),(14445,'119995','printshop-mobile','block-14441-2','BlockBox','',1),(14446,'119996','printshop-mobile','block-14445','invoice\\CustomerEmail','',6),(14447,'119997','printshop-mobile','block-14445','invoice\\CustomerName','',2),(14448,'119998','printshop-mobile','block-14445','invoice\\CustomerPhone','',4),(14449,'119999','printshop-mobile','block-14445','Text','',5),(14450,'120000','printshop-mobile','block-14445','Text','',1),(14451,'120001','printshop-mobile','block-14445','Text','',3),(14452,'120002','printshop-mobile','block-14440','BlockBox','',3),(14453,'120003','printshop-mobile','block-14452','BlockBox','',1),(14454,'120004','printshop-mobile','block-14453','invoice\\ShippingMethod','',2),(14455,'120005','printshop-mobile','block-14453','Text','',1),(14456,'120006','printshop-mobile','block-14452-2','BlockBox','',1),(14457,'120007','printshop-mobile','block-14456','Text','',1),(14458,'120008','printshop-mobile','block-14456','invoice\\ShippingMethod','',2),(14459,'120009','printshop-mobile','block-14440-2','invoice\\AddressQrcode','',1),(14460,'120010','printshop-mobile','block-14438','BlockBox','',4),(14461,'120011','printshop-mobile','block-14460','Text','',1),(14462,'120012','printshop-mobile','block-14460','invoice\\StoreAddress','',2),(14463,'120013','printshop-mobile','block-14438','BlockBox','',1),(14464,'120014','printshop-mobile','block-14463','Logo','',1),(14465,'120015','printshop-mobile','block-14463-2','BlockBox','',1),(14466,'120016','printshop-mobile','block-14465','invoice\\StoreAddress','',1),(14467,'120017','printshop-mobile','block-14463-2','BlockBox','',2),(14468,'120018','printshop-mobile','block-14467','Text','',2),(14469,'120019','printshop-mobile','block-14467-2','invoice\\StorePhone','',1),(14470,'120020','printshop-mobile','block-14463-2','BlockBox','',4),(14471,'120021','printshop-mobile','block-14470','Text','',2),(14472,'120022','printshop-mobile','block-14470-2','invoice\\StoreSite','',1),(14473,'120023','printshop-mobile','block-14463-2','BlockBox','',3),(14474,'120024','printshop-mobile','block-14473','Text','',2),(14475,'120025','printshop-mobile','block-14473-2','invoice\\StoreEmail','',1),(14476,'120026','printshop-mobile','password_forgotten','BlockBox','',1),(14477,'120027','printshop-mobile','block-14476','Html_box','',1),(14478,'120028','printshop-mobile','block-14476','BlockBox','',2),(14479,'120029','printshop-mobile','block-14478-2','login\\PasswordForgotten','',2),(14480,'120030','printshop-mobile','block-14478-2','Html_box','',1),(14481,'120031','printshop-mobile','pdf','invoice\\Container','',1),(14482,'120032','printshop-mobile','block-14481','BlockBox','',1),(14483,'120033','printshop-mobile','block-14482','BlockBox','',1),(14484,'120034','printshop-mobile','block-14483','BlockBox','',2),(14485,'120035','printshop-mobile','block-14484','pdf\\ProductElement','',1),(14486,'120036','printshop-mobile','block-14484-2','pdf\\ProductElement','',2),(14487,'120037','printshop-mobile','block-14484-2','pdf\\ProductElement','',1),(14488,'120038','printshop-mobile','block-14483','BlockBox','',1),(14489,'120039','printshop-mobile','block-14488','pdf\\ProductElement','',1),(14490,'120040','printshop-mobile','block-14482-2','BlockBox','',1),(14491,'120041','printshop-mobile','block-14490','BlockBox','',1),(14492,'120042','printshop-mobile','block-14491','pdf\\ProductElement','',1),(14493,'120043','printshop-mobile','block-14490','BlockBox','',2),(14494,'120044','printshop-mobile','block-14493','pdf\\ProductElement','',1),(14495,'120045','printshop-mobile','block-14493-2','pdf\\ProductElement','',2),(14496,'120046','printshop-mobile','block-14493-2','pdf\\ProductElement','',1),(14497,'120047','printshop-mobile','pdf_category','pdf\\CategoryName','',2),(14498,'120048','printshop-mobile','pdf_category','pdf\\CategoryImage','',1),(14499,'120049','printshop-mobile','pdf_cover','invoice\\Container','',1),(14500,'120050','printshop-mobile','block-14499','Logo','',1),(14501,'120051','printshop-mobile','block-14499','Text','',3),(14502,'120052','printshop-mobile','pdf_footer','BlockBox','',1),(14503,'120053','printshop-mobile','block-14502-2','pdf\\PageNumber','',1),(14504,'120054','printshop-mobile','pdf_header','pdf\\CategoryName','',1),(14505,'120055','printshop-mobile','personal_catalog','BlockBox','',1),(14506,'120056','printshop-mobile','block-14505','BlockBox','',1),(14507,'120057','printshop-mobile','block-14506','WidgetsAria','',1),(14508,'120058','printshop-mobile','block-14506-2','Html_box','',1),(14509,'120059','printshop-mobile','block-14506-2','account\\PersonalCatalog','',2),(14510,'120060','printshop-mobile','points_earnt_history','BlockBox','',1),(14511,'120061','printshop-mobile','block-14510','Html_box','',1),(14512,'120062','printshop-mobile','block-14510','account\\PointsEarntHistory','',2),(14513,'120063','printshop-mobile','posts','BlockBox','',1),(14514,'120064','printshop-mobile','block-14513','Breadcrumb','',2),(14515,'120065','printshop-mobile','block-14513','Communication\\Post','',3),(14516,'120066','printshop-mobile','block-14513','Html_box','',1),(14517,'120067','printshop-mobile','product','BlockBox','',1),(14518,'120068','printshop-mobile','block-14517','BlockBox','',5),(14519,'120069','printshop-mobile','block-14518','product\\Stock','',2),(14520,'120070','printshop-mobile','block-14518','product\\Price','',1),(14521,'120071','printshop-mobile','block-14518-2','product\\Quantity','',1),(14522,'120072','printshop-mobile','block-14517','product\\Bundle','',6),(14523,'120073','printshop-mobile','block-14517','product\\Video','',3),(14524,'120074','printshop-mobile','block-14517','product\\Documents','',16),(14525,'120075','printshop-mobile','block-14517','product\\Buttons','',7),(14526,'120076','printshop-mobile','block-14517','product\\Images','',2),(14527,'120077','printshop-mobile','block-14517','product\\Name','',1),(14528,'120078','printshop-mobile','block-14517','BlockBox','',8),(14529,'120079','printshop-mobile','block-14528','product\\WishlistButton','',1),(14530,'120080','printshop-mobile','block-14528','product\\PersonalCatalogButton','',2),(14531,'120081','printshop-mobile','block-14528','product\\WeddingRegistryButton','',3),(14532,'120082','printshop-mobile','block-14517','product\\BonusPoints','',9),(14533,'120083','printshop-mobile','block-14517','product\\CrossSell','',13),(14534,'120084','printshop-mobile','block-14517','product\\AlsoPurchased','10',11),(14535,'120085','printshop-mobile','block-14517','product\\InBundles','',14),(14536,'120086','printshop-mobile','block-14517','Tabs','',12),(14537,'120087','printshop-mobile','block-14536-1','product\\Description','',1),(14538,'120088','printshop-mobile','block-14536-1','product\\Properties','',2),(14539,'120089','printshop-mobile','block-14536-2','product\\Reviews','',1),(14540,'120090','printshop-mobile','block-14517','product\\Attributes','',4),(14541,'120091','printshop-mobile','block-14517','product\\Configurator','',10),(14542,'120092','printshop-mobile','block-14517','ViewedProducts','',15),(14543,'120093','printshop-mobile','product-bottom','product\\Properties','',1),(14544,'120094','printshop-mobile','product-tabs','product\\Reviews','',2),(14545,'120095','printshop-mobile','product-tabs','product\\Description','',1),(14546,'120096','printshop-mobile','product-top-left','product\\Images','',1),(14547,'120097','printshop-mobile','product-top-right','product\\Attributes','',3),(14548,'120098','printshop-mobile','product-top-right','product\\Buttons','',6),(14549,'120099','printshop-mobile','product-top-right','product\\Quantity','',6),(14550,'120100','printshop-mobile','product-top-right','product\\Quantity','',5),(14551,'120101','printshop-mobile','product-top-right','product\\Name','',1),(14552,'120102','printshop-mobile','product-top-right','product\\Price','',2),(14553,'120103','printshop-mobile','productListing','BlockBox','',1),(14554,'120104','printshop-mobile','block-14553','productListing\\model','',7),(14555,'120105','printshop-mobile','block-14553','productListing\\bonusPoints','',6),(14556,'120106','printshop-mobile','block-14553','productListing\\description','',5),(14557,'120107','printshop-mobile','block-14553','productListing\\buyButton','',9),(14558,'120108','printshop-mobile','block-14553','productListing\\rating','',3),(14559,'120109','printshop-mobile','block-14553','productListing\\image','',1),(14560,'120110','printshop-mobile','block-14553','BlockBox','',8),(14561,'120111','printshop-mobile','block-14560','productListing\\price','',1),(14562,'120112','printshop-mobile','block-14560-2','productListing\\qtyInput','',1),(14563,'120113','printshop-mobile','block-14553','productListing\\name','',4),(14564,'120114','printshop-mobile','block-14553','productListing\\stock','',2),(14565,'120115','printshop-mobile','products','BlockBox','',1),(14566,'120116','printshop-mobile','block-14565','Filters','',3),(14567,'120117','printshop-mobile','block-14565','catalog\\Paging','',5),(14568,'120118','printshop-mobile','block-14565','catalog\\Title','',1),(14569,'120119','printshop-mobile','block-14565','catalog\\Image','',2),(14570,'120120','printshop-mobile','block-14565','BlockBox','',4),(14571,'120121','printshop-mobile','block-14570','catalog\\Sorting','',1),(14572,'120122','printshop-mobile','block-14570-2','catalog\\CountsItems','',1),(14573,'120123','printshop-mobile','block-14565','Listing','',7),(14574,'120124','printshop-mobile','products-list','packingslip\\AllProductsList','',2),(14575,'120125','printshop-mobile','promotions','BlockBox','',1),(14576,'120126','printshop-mobile','block-14575','promotions\\PromoList','',2),(14577,'120127','printshop-mobile','block-14575','Html_box','',1),(14578,'120128','printshop-mobile','purchase','invoice\\Container','',1),(14579,'120129','printshop-mobile','block-14578','BlockBox','',4),(14580,'120130','printshop-mobile','block-14579','BlockBox','',1),(14581,'120131','printshop-mobile','block-14580','Text','',1),(14582,'120132','printshop-mobile','block-14580','invoice\\ShippingAddress','',2),(14583,'120133','printshop-mobile','block-14578','BlockBox','',2),(14584,'120134','printshop-mobile','block-14583','BlockBox','',7),(14585,'120135','printshop-mobile','block-14584','BlockBox','',1),(14586,'120136','printshop-mobile','block-14585','Text','',1),(14587,'120137','printshop-mobile','block-14585','invoice\\BillingAddress','',2),(14588,'120138','printshop-mobile','block-14584-2','BlockBox','',1),(14589,'120139','printshop-mobile','block-14588','Text','',1),(14590,'120140','printshop-mobile','block-14588','Text','',3),(14591,'120141','printshop-mobile','block-14588','Text','',5),(14592,'120142','printshop-mobile','block-14588','invoice\\CustomerName','',2),(14593,'120143','printshop-mobile','block-14588','invoice\\CustomerPhone','',4),(14594,'120144','printshop-mobile','block-14588','invoice\\CustomerEmail','',6),(14595,'120145','printshop-mobile','block-14583-2','Text','',2),(14596,'120146','printshop-mobile','block-14583-2','invoice\\PaymentDate','',3),(14597,'120147','printshop-mobile','block-14583-2','invoice\\OrderId','',1),(14598,'120148','printshop-mobile','block-14578','BlockBox','',1),(14599,'120149','printshop-mobile','block-14598','Logo','',1),(14600,'120150','printshop-mobile','block-14598-2','BlockBox','',1),(14601,'120151','printshop-mobile','block-14600','invoice\\StoreAddress','',1),(14602,'120152','printshop-mobile','block-14598-2','BlockBox','',3),(14603,'120153','printshop-mobile','block-14602','Text','',1),(14604,'120154','printshop-mobile','block-14602-2','invoice\\StoreEmail','',1),(14605,'120155','printshop-mobile','block-14598-2','BlockBox','',4),(14606,'120156','printshop-mobile','block-14605','Text','',1),(14607,'120157','printshop-mobile','block-14605-2','invoice\\StoreSite','',1),(14608,'120158','printshop-mobile','block-14598-2','BlockBox','',2),(14609,'120159','printshop-mobile','block-14608','Text','',1),(14610,'120160','printshop-mobile','block-14608-2','invoice\\StorePhone','',1),(14611,'120161','printshop-mobile','block-14578','BlockBox','',5),(14612,'120162','printshop-mobile','block-14611','invoice\\StoreAddress','',8),(14613,'120163','printshop-mobile','block-14611','Text','',1),(14614,'120164','printshop-mobile','block-14611-2','Text','',2),(14615,'120165','printshop-mobile','block-14611-2','Logo','',1),(14616,'120166','printshop-mobile','block-14611-3','BlockBox','',2),(14617,'120167','printshop-mobile','block-14616','Text','',1),(14618,'120168','printshop-mobile','block-14616-2','invoice\\StorePhone','',1),(14619,'120169','printshop-mobile','block-14611-3','Text','',1),(14620,'120170','printshop-mobile','block-14611-3','BlockBox','',3),(14621,'120171','printshop-mobile','block-14620','Text','',1),(14622,'120172','printshop-mobile','block-14620-2','invoice\\StoreEmail','',1),(14623,'120173','printshop-mobile','block-14578','invoice\\Products','',3),(14624,'120174','printshop-mobile','quotations','BlockBox','',1),(14625,'120175','printshop-mobile','block-14624','BlockBox','',1),(14626,'120176','printshop-mobile','block-14625','WidgetsAria','',1),(14627,'120177','printshop-mobile','block-14625-2','Html_box','',1),(14628,'120178','printshop-mobile','block-14625-2','Quotations\\QuotationsHistory','',2),(14629,'120179','printshop-mobile','quotation_info','BlockBox','',1),(14630,'120180','printshop-mobile','block-14629','BlockBox','',1),(14631,'120181','printshop-mobile','block-14630','WidgetsAria','',1),(14632,'120182','printshop-mobile','block-14630-2','Quotations\\QuotationHistory','',10),(14633,'120183','printshop-mobile','block-14630-2','Quotations\\QuotationProducts','',7),(14634,'120184','printshop-mobile','block-14630-2','Html_box','',9),(14635,'120185','printshop-mobile','block-14630-2','Html_box','',6),(14636,'120186','printshop-mobile','block-14630-2','Quotations\\QuotationSubTotal','',8),(14637,'120187','printshop-mobile','block-14630-2','Html_box','',4),(14638,'120188','printshop-mobile','block-14630-2','BlockBox','',12),(14639,'120189','printshop-mobile','block-14638','account\\AccountLink','',1),(14640,'120190','printshop-mobile','block-14630-2','BlockBox','',5),(14641,'120191','printshop-mobile','block-14640','BlockBox','',4),(14642,'120192','printshop-mobile','block-14641','Html_box','',1),(14643,'120193','printshop-mobile','block-14641','Quotations\\QuotationData','',2),(14644,'120194','printshop-mobile','block-14640','BlockBox','',1),(14645,'120195','printshop-mobile','block-14644','Quotations\\QuotationData','',2),(14646,'120196','printshop-mobile','block-14644','Html_box','',1),(14647,'120197','printshop-mobile','block-14640-2','BlockBox','',2),(14648,'120198','printshop-mobile','block-14647','Html_box','',1),(14649,'120199','printshop-mobile','block-14647','Quotations\\QuotationData','',2),(14650,'120200','printshop-mobile','block-14640-2','BlockBox','',1),(14651,'120201','printshop-mobile','block-14650','Html_box','',1),(14652,'120202','printshop-mobile','block-14650','Quotations\\QuotationData','',2),(14653,'120203','printshop-mobile','block-14640-3','BlockBox','',1),(14654,'120204','printshop-mobile','block-14653','Html_box','',1),(14655,'120205','printshop-mobile','block-14653','Quotations\\QuotationData','',2),(14656,'120206','printshop-mobile','block-14640-3','BlockBox','',2),(14657,'120207','printshop-mobile','block-14656','Quotations\\QuotationData','',2),(14658,'120208','printshop-mobile','block-14656','Html_box','',1),(14659,'120209','printshop-mobile','quote','quote\\CheckoutBtn','',3),(14660,'120210','printshop-mobile','quote','quote\\Products','',2),(14661,'120211','printshop-mobile','quote','Text','',1),(14662,'120212','printshop-mobile','review','BlockBox','',1),(14663,'120213','printshop-mobile','block-14662','BlockBox','',1),(14664,'120214','printshop-mobile','block-14663','WidgetsAria','',1),(14665,'120215','printshop-mobile','block-14663-2','Html_box','',1),(14666,'120216','printshop-mobile','block-14663-2','account\\Reviews','',2),(14667,'120217','printshop-mobile','reviews','BlockBox','',1),(14668,'120218','printshop-mobile','block-14667','reviews\\Content','',2),(14669,'120219','printshop-mobile','block-14667','reviews\\Heading','',1),(14670,'120220','printshop-mobile','rma_document','invoice\\Container','',1),(14671,'120221','printshop-mobile','block-14670','BlockBox','',3),(14672,'120222','printshop-mobile','block-14671','BlockBox','',1),(14673,'120223','printshop-mobile','block-14672','BlockBox','',1),(14674,'120224','printshop-mobile','block-14673','BlockBox','',6),(14675,'120225','printshop-mobile','block-14674','Html_box','',1),(14676,'120226','printshop-mobile','block-14673','BlockBox','',3),(14677,'120227','printshop-mobile','block-14676','Html_box','',1),(14678,'120228','printshop-mobile','block-14676-2','Html_box','',1),(14679,'120229','printshop-mobile','block-14673','BlockBox','',1),(14680,'120230','printshop-mobile','block-14679','Html_box','',1),(14681,'120231','printshop-mobile','block-14673','BlockBox','',2),(14682,'120232','printshop-mobile','block-14681','Html_box','',1),(14683,'120233','printshop-mobile','block-14681-2','Html_box','',1),(14684,'120234','printshop-mobile','block-14673','BlockBox','',4),(14685,'120235','printshop-mobile','block-14684','Html_box','',1),(14686,'120236','printshop-mobile','block-14684-2','Html_box','',1),(14687,'120237','printshop-mobile','block-14673','BlockBox','',5),(14688,'120238','printshop-mobile','block-14687','Html_box','',1),(14689,'120239','printshop-mobile','block-14687-2','Html_box','',1),(14690,'120240','printshop-mobile','block-14687-2','invoice\\StoreAddress','',2),(14691,'120241','printshop-mobile','block-14672-2','BlockBox','',3),(14692,'120242','printshop-mobile','block-14691','Html_box','',1),(14693,'120243','printshop-mobile','block-14691-2','Html_box','',1),(14694,'120244','printshop-mobile','block-14691-3','BlockBox','',1),(14695,'120245','printshop-mobile','block-14694','Html_box','',1),(14696,'120246','printshop-mobile','block-14694-2','Html_box','',1),(14697,'120247','printshop-mobile','block-14672-2','BlockBox','',4),(14698,'120248','printshop-mobile','block-14697','Html_box','',1),(14699,'120249','printshop-mobile','block-14697-2','Html_box','',1),(14700,'120250','printshop-mobile','block-14697-3','BlockBox','',1),(14701,'120251','printshop-mobile','block-14700','Html_box','',1),(14702,'120252','printshop-mobile','block-14700-2','Html_box','',1),(14703,'120253','printshop-mobile','block-14672-2','BlockBox','',2),(14704,'120254','printshop-mobile','block-14703','Html_box','',1),(14705,'120255','printshop-mobile','block-14703','Html_box','',2),(14706,'120256','printshop-mobile','block-14703','Html_box','',3),(14707,'120257','printshop-mobile','block-14703','Html_box','',4),(14708,'120258','printshop-mobile','block-14703','Html_box','',5),(14709,'120259','printshop-mobile','block-14672-2','BlockBox','',1),(14710,'120260','printshop-mobile','block-14709','BlockBox','',1),(14711,'120261','printshop-mobile','block-14710','BlockBox','',1),(14712,'120262','printshop-mobile','block-14711','Rma\\DocumentData','',2),(14713,'120263','printshop-mobile','block-14711-3','BlockBox','',1),(14714,'120264','printshop-mobile','block-14713','Html_box','',1),(14715,'120265','printshop-mobile','block-14713-2','Rma\\DocumentData','',1),(14716,'120266','printshop-mobile','block-14710','BlockBox','',2),(14717,'120267','printshop-mobile','block-14716-2','invoice\\StoreAddress','',1),(14718,'120268','printshop-mobile','block-14670','BlockBox','',2),(14719,'120269','printshop-mobile','block-14718','Rma\\Products','',2),(14720,'120270','printshop-mobile','block-14718','Html_box','',1),(14721,'120271','printshop-mobile','block-14670','BlockBox','',1),(14722,'120272','printshop-mobile','block-14721','BlockBox','',1),(14723,'120273','printshop-mobile','block-14722','BlockBox','',1),(14724,'120274','printshop-mobile','block-14723','Html_box','',2),(14725,'120275','printshop-mobile','block-14723','Html_box','',1),(14726,'120276','printshop-mobile','block-14722','BlockBox','',3),(14727,'120277','printshop-mobile','block-14726','Html_box','',1),(14728,'120278','printshop-mobile','block-14726-2','Html_box','',1),(14729,'120279','printshop-mobile','block-14722','BlockBox','',2),(14730,'120280','printshop-mobile','block-14729','Html_box','',1),(14731,'120281','printshop-mobile','block-14729-2','Html_box','',1),(14732,'120282','printshop-mobile','block-14722','BlockBox','',4),(14733,'120283','printshop-mobile','block-14732','Html_box','',1),(14734,'120284','printshop-mobile','block-14732-2','Html_box','',1),(14735,'120285','printshop-mobile','block-14722','BlockBox','',5),(14736,'120286','printshop-mobile','block-14735','Html_box','',1),(14737,'120287','printshop-mobile','block-14735-2','Html_box','',1),(14738,'120288','printshop-mobile','block-14721-2','BlockBox','',3),(14739,'120289','printshop-mobile','block-14738','BlockBox','',1),(14740,'120290','printshop-mobile','block-14739','Html_box','',1),(14741,'120291','printshop-mobile','block-14739-2','Rma\\DocumentData','',1),(14742,'120292','printshop-mobile','block-14738-2','BlockBox','',1),(14743,'120293','printshop-mobile','block-14742','Html_box','',1),(14744,'120294','printshop-mobile','block-14742-2','Rma\\DocumentData','',1),(14745,'120295','printshop-mobile','block-14721-2','BlockBox','',2),(14746,'120296','printshop-mobile','block-14745','BlockBox','',1),(14747,'120297','printshop-mobile','block-14746','BlockBox','',1),(14748,'120298','printshop-mobile','block-14747','Html_box','',1),(14749,'120299','printshop-mobile','block-14747-2','Rma\\DocumentData','',1),(14750,'120300','printshop-mobile','block-14746-2','BlockBox','',1),(14751,'120301','printshop-mobile','block-14750','Html_box','',1),(14752,'120302','printshop-mobile','block-14750-2','Rma\\DocumentData','',1),(14753,'120303','printshop-mobile','block-14745','BlockBox','',2),(14754,'120304','printshop-mobile','block-14753','Html_box','',1),(14755,'120305','printshop-mobile','block-14753-2','Rma\\DocumentData','',1),(14756,'120306','printshop-mobile','block-14745','BlockBox','',3),(14757,'120307','printshop-mobile','block-14756','BlockBox','',1),(14758,'120308','printshop-mobile','block-14757','Html_box','',1),(14759,'120309','printshop-mobile','block-14757-2','Rma\\DocumentData','',1),(14760,'120310','printshop-mobile','block-14756-2','BlockBox','',1),(14761,'120311','printshop-mobile','block-14760','Html_box','',1),(14762,'120312','printshop-mobile','block-14760-2','Rma\\DocumentData','',1),(14763,'120313','printshop-mobile','block-14745','BlockBox','',4),(14764,'120314','printshop-mobile','block-14763','BlockBox','',1),(14765,'120315','printshop-mobile','block-14764','Html_box','',1),(14766,'120316','printshop-mobile','block-14764-2','Rma\\DocumentData','',1),(14767,'120317','printshop-mobile','block-14763-2','BlockBox','',1),(14768,'120318','printshop-mobile','block-14767','Html_box','',1),(14769,'120319','printshop-mobile','block-14767-2','Rma\\DocumentData','',1),(14770,'120320','printshop-mobile','block-14745','BlockBox','',5),(14771,'120321','printshop-mobile','block-14770','BlockBox','',1),(14772,'120322','printshop-mobile','block-14771','Html_box','',1),(14773,'120323','printshop-mobile','block-14771-2','Rma\\DocumentData','',1),(14774,'120324','printshop-mobile','block-14770-2','BlockBox','',1),(14775,'120325','printshop-mobile','block-14774','Html_box','',1),(14776,'120326','printshop-mobile','block-14774-2','Rma\\DocumentData','',1),(14777,'120327','printshop-mobile','block-14721-2','BlockBox','',1),(14778,'120328','printshop-mobile','block-14777','Logo','',1),(14779,'120329','printshop-mobile','block-14777','Html_box','',2),(14780,'120330','printshop-mobile','rows','BlockBox','',1),(14781,'120331','printshop-mobile','block-14780','BlockBox','',2),(14782,'120332','printshop-mobile','block-14781','BlockBox','',2),(14783,'120333','printshop-mobile','block-14782','BlockBox','',3),(14784,'120334','printshop-mobile','block-14783','productListing\\rating','',1),(14785,'120335','printshop-mobile','block-14783','productListing\\ratingCounts','',2),(14786,'120336','printshop-mobile','block-14782','productListing\\bonusPoints','',1),(14787,'120337','printshop-mobile','block-14782','productListing\\image','',2),(14788,'120338','printshop-mobile','block-14782-2','productListing\\model','',3),(14789,'120339','printshop-mobile','block-14782-2','productListing\\name','',1),(14790,'120340','printshop-mobile','block-14782-2','productListing\\description','',2),(14791,'120341','printshop-mobile','block-14782-2','productListing\\attributes','',4),(14792,'120342','printshop-mobile','block-14781-2','BlockBox','',1),(14793,'120343','printshop-mobile','block-14792','productListing\\stock','',1),(14794,'120344','printshop-mobile','block-14792','productListing\\price','',2),(14795,'120345','printshop-mobile','block-14792','productListing\\wishlistButton','',6),(14796,'120346','printshop-mobile','block-14792','productListing\\qtyInput','',3),(14797,'120347','printshop-mobile','block-14792','productListing\\compare','',5),(14798,'120348','printshop-mobile','block-14792','productListing\\buyButton','',4),(14799,'120349','printshop-mobile','sample','BlockBox','',1),(14800,'120350','printshop-mobile','block-14799','sample\\Products','',2),(14801,'120351','printshop-mobile','block-14799','sample\\CheckoutBtn','',3),(14802,'120352','printshop-mobile','block-14799','Text','',1),(14803,'120353','printshop-mobile','samples','BlockBox','',1),(14804,'120354','printshop-mobile','block-14803','BlockBox','',1),(14805,'120355','printshop-mobile','block-14804','WidgetsAria','',1),(14806,'120356','printshop-mobile','block-14804-2','Html_box','',1),(14807,'120357','printshop-mobile','block-14804-2','Samples\\SamplesHistory','',2),(14808,'120358','printshop-mobile','sample_info','BlockBox','',1),(14809,'120359','printshop-mobile','block-14808','BlockBox','',1),(14810,'120360','printshop-mobile','block-14809','WidgetsAria','',1),(14811,'120361','printshop-mobile','block-14809-2','Html_box','',6),(14812,'120362','printshop-mobile','block-14809-2','BlockBox','',2),(14813,'120363','printshop-mobile','block-14812','BlockBox','',4),(14814,'120364','printshop-mobile','block-14813','Html_box','',1),(14815,'120365','printshop-mobile','block-14813','Samples\\SampleData','',2),(14816,'120366','printshop-mobile','block-14812','BlockBox','',1),(14817,'120367','printshop-mobile','block-14816','Samples\\SampleData','',2),(14818,'120368','printshop-mobile','block-14816','Html_box','',1),(14819,'120369','printshop-mobile','block-14812-2','BlockBox','',1),(14820,'120370','printshop-mobile','block-14819','Html_box','',1),(14821,'120371','printshop-mobile','block-14819','Samples\\SampleData','',2),(14822,'120372','printshop-mobile','block-14812-2','BlockBox','',2),(14823,'120373','printshop-mobile','block-14822','Samples\\SampleData','',2),(14824,'120374','printshop-mobile','block-14822','Html_box','',1),(14825,'120375','printshop-mobile','block-14812-3','BlockBox','',1),(14826,'120376','printshop-mobile','block-14825','Html_box','',1),(14827,'120377','printshop-mobile','block-14825','Samples\\SampleData','',2),(14828,'120378','printshop-mobile','block-14812-3','BlockBox','',2),(14829,'120379','printshop-mobile','block-14828','Samples\\SampleData','',2),(14830,'120380','printshop-mobile','block-14828','Html_box','',1),(14831,'120381','printshop-mobile','block-14809-2','Html_box','',3),(14832,'120382','printshop-mobile','block-14809-2','Samples\\SampleProducts','',4),(14833,'120383','printshop-mobile','block-14809-2','Samples\\SampleSubTotal','',5),(14834,'120384','printshop-mobile','block-14809-2','BlockBox','',8),(14835,'120385','printshop-mobile','block-14834','account\\AccountLink','',1),(14836,'120386','printshop-mobile','block-14809-2','Samples\\SampleHistory','',7),(14837,'120387','printshop-mobile','block-14809-2','Html_box','',1),(14838,'120388','printshop-mobile','sample_info','BlockBox','',1),(14839,'120389','printshop-mobile','block-14838','BlockBox','',1),(14840,'120390','printshop-mobile','block-14839','WidgetsAria','',1),(14841,'120391','printshop-mobile','block-14839-2','Html_box','',3),(14842,'120392','printshop-mobile','block-14839-2','account\\OrdersHistory','',4),(14843,'120393','printshop-mobile','block-14839-2','Html_box','',1),(14844,'120394','printshop-mobile','block-14839-2','BlockBox','',2),(14845,'120395','printshop-mobile','block-14844','Html_box','',1),(14846,'120396','printshop-mobile','block-14844','account\\LastOrder','',2),(14847,'120397','printshop-mobile','block-14844-2','Html_box','',1),(14848,'120398','printshop-mobile','block-14844-2','account\\AccountLink','',3),(14849,'120399','printshop-mobile','block-14844-2','account\\OrderCount','',2),(14850,'120400','printshop-mobile','block-14844-3','Html_box','',1),(14851,'120401','printshop-mobile','block-14844-3','account\\TotalOrdered','',2),(14852,'120402','printshop-mobile','block-14844-4','Html_box','',1),(14853,'120403','printshop-mobile','block-14844-4','account\\AccountLink','',3),(14854,'120404','printshop-mobile','block-14844-4','account\\CreditAmount','',2),(14855,'120405','printshop-mobile','block-14844-5','account\\AccountLink','',3),(14856,'120406','printshop-mobile','block-14844-5','account\\PointsEarnt','',2),(14857,'120407','printshop-mobile','block-14844-5','Html_box','',1),(14858,'120408','printshop-mobile','block-14839-2','BlockBox','',5),(14859,'120409','printshop-mobile','block-14858','account\\GiftCards','',6),(14860,'120410','printshop-mobile','block-14858','Html_box','',1),(14861,'120411','printshop-mobile','block-14839-2','Html_box','',5),(14862,'120412','printshop-mobile','sitemap','BlockBox','',1),(14863,'120413','printshop-mobile','block-14862','BlockBox','',2),(14864,'120414','printshop-mobile','block-14863','Menu','Account box',6),(14865,'120415','printshop-mobile','block-14863','sitemap\\InfoPages','',2),(14866,'120416','printshop-mobile','block-14863','Html_box','',5),(14867,'120417','printshop-mobile','block-14863','sitemap\\Categories','',4),(14868,'120418','printshop-mobile','block-14863','Html_box','',3),(14869,'120419','printshop-mobile','block-14863','Html_box','',1),(14870,'120420','printshop-mobile','block-14863-2','Html_box','',1),(14871,'120421','printshop-mobile','block-14863-2','sitemap\\DeliveryLocation','',2),(14872,'120422','printshop-mobile','block-14862','Html_box','',1),(14873,'120423','printshop-mobile','subscribe','BlockBox','',1),(14874,'120424','printshop-mobile','block-14873','subscribers\\SubscribeForm','',2),(14875,'120425','printshop-mobile','block-14873','Html_box','',1),(14876,'120426','printshop-mobile','block-14873','Html_box','',3),(14877,'120427','printshop-mobile','block-14873','subscribers\\UnsubscribeForm','',4),(14878,'120428','printshop-mobile','subscribed','BlockBox','',1),(14879,'120429','printshop-mobile','block-14878','Html_box','',1),(14880,'120430','printshop-mobile','subscription','BlockBox','',2),(14881,'120431','printshop-mobile','block-14880','BlockBox','',1),(14882,'120432','printshop-mobile','block-14881','WidgetsAria','',1),(14883,'120433','printshop-mobile','block-14881-2','Html_box','',2),(14884,'120434','printshop-mobile','block-14881-2','Html_box','',3),(14885,'120435','printshop-mobile','block-14881-2','account\\Subscription','',4),(14886,'120436','printshop-mobile','success','BlockBox','',1),(14887,'120437','printshop-mobile','block-14886','BlockBox','',1),(14888,'120438','printshop-mobile','block-14887','Text','',2),(14889,'120439','printshop-mobile','block-14887','BlockBox','',3),(14890,'120440','printshop-mobile','block-14889','Html','',3),(14891,'120441','printshop-mobile','block-14889-2','success\\PrintBtn','',1),(14892,'120442','printshop-mobile','block-14889-3','success\\ContinueBtn','',1),(14893,'120443','printshop-mobile','success_q','BlockBox','',1),(14894,'120444','printshop-mobile','block-14893','BlockBox','',1),(14895,'120445','printshop-mobile','block-14894','BlockBox','',2),(14896,'120446','printshop-mobile','block-14895','success\\PrintBtn','',1),(14897,'120447','printshop-mobile','block-14895','success\\ContinueBtn','',2),(14898,'120448','printshop-mobile','block-14894','Html_box','',1),(14902,'120452','printshop-mobile','ticket','invoice\\Container','',1),(14903,'120453','printshop-mobile','block-14902','BlockBox','',1),(14904,'120454','printshop-mobile','block-14903-2','BlockBox','',1),(14905,'120455','printshop-mobile','block-14904','invoice\\StoreAddress','',1),(14906,'120456','printshop-mobile','block-14903-2','BlockBox','',2),(14907,'120457','printshop-mobile','block-14906','Text','',1),(14908,'120458','printshop-mobile','block-14906-2','invoice\\StorePhone','',1),(14909,'120459','printshop-mobile','block-14903-2','BlockBox','',4),(14910,'120460','printshop-mobile','block-14909','Text','',1),(14911,'120461','printshop-mobile','block-14909-2','invoice\\StoreSite','',1),(14912,'120462','printshop-mobile','block-14903-2','BlockBox','',3),(14913,'120463','printshop-mobile','block-14912','Text','',1),(14914,'120464','printshop-mobile','block-14912-2','invoice\\StoreEmail','',1),(14915,'120465','printshop-mobile','block-14902','BlockBox','',2),(14916,'120466','printshop-mobile','block-14915','BlockBox','',7),(14917,'120467','printshop-mobile','block-14916','BlockBox','',1),(14918,'120468','printshop-mobile','block-14917','Text','',1),(14919,'120469','printshop-mobile','block-14917','invoice\\BillingAddress','',2),(14920,'120470','printshop-mobile','block-14916-2','BlockBox','',1),(14921,'120471','printshop-mobile','block-14920','Text','',3),(14922,'120472','printshop-mobile','block-14920','Text','',5),(14923,'120473','printshop-mobile','block-14920','Text','',1),(14924,'120474','printshop-mobile','block-14920','invoice\\CustomerPhone','',4),(14925,'120475','printshop-mobile','block-14920','invoice\\CustomerName','',2),(14926,'120476','printshop-mobile','block-14920','invoice\\CustomerEmail','',6),(14927,'120477','printshop-mobile','block-14915','BlockBox','',8),(14928,'120478','printshop-mobile','block-14927','BlockBox','',1),(14929,'120479','printshop-mobile','block-14928','Text','',1),(14930,'120480','printshop-mobile','block-14928','invoice\\ShippingMethod','',2),(14931,'120481','printshop-mobile','block-14927-2','BlockBox','',1),(14932,'120482','printshop-mobile','block-14931','invoice\\ShippingMethod','',2),(14933,'120483','printshop-mobile','block-14931','Text','',1),(14934,'120484','printshop-mobile','block-14915-2','Text','',2),(14935,'120485','printshop-mobile','block-14915-2','invoice\\OrderBarcode','',6),(14936,'120486','printshop-mobile','block-14915-2','Text','',4),(14937,'120487','printshop-mobile','block-14915-2','invoice\\OrderId','',1),(14938,'120488','printshop-mobile','block-14915-2','invoice\\PaymentDate','',3),(14939,'120489','printshop-mobile','block-14915-2','invoice\\PaymentMethod','',5),(14940,'120490','printshop-mobile','block-14902','BlockBox','',5),(14941,'120491','printshop-mobile','block-14940','Text','',1),(14942,'120492','printshop-mobile','block-14940','invoice\\StoreAddress','',8),(14943,'120493','printshop-mobile','block-14940-2','Logo','',1),(14944,'120494','printshop-mobile','block-14940-2','Text','',2),(14945,'120495','printshop-mobile','block-14940-3','BlockBox','',2),(14946,'120496','printshop-mobile','block-14945','Text','',1),(14947,'120497','printshop-mobile','block-14945-2','invoice\\StorePhone','',1),(14948,'120498','printshop-mobile','block-14940-3','Text','',1),(14949,'120499','printshop-mobile','block-14940-3','BlockBox','',3),(14950,'120500','printshop-mobile','block-14949','Text','',1),(14951,'120501','printshop-mobile','block-14949-2','invoice\\StoreEmail','',1),(14952,'120502','printshop-mobile','block-14902','invoice\\Products','',3),(14953,'120503','printshop-mobile','block-14902','BlockBox','',4),(14954,'120504','printshop-mobile','block-14953','BlockBox','',1),(14955,'120505','printshop-mobile','block-14954','invoice\\ShippingAddress','',2),(14956,'120506','printshop-mobile','block-14954','Text','',1),(14957,'120507','printshop-mobile','block-14953-2','BlockBox','',1),(14958,'120508','printshop-mobile','block-14957','invoice\\Totals','',1),(14959,'120509','printshop-mobile','tl_blog_category','BlockBox','',1),(14960,'120510','printshop-mobile','block-14959','BlockBox','',1),(14961,'120511','printshop-mobile','block-14960','BlockBox','',1),(14962,'120512','printshop-mobile','block-14961','Blog\\widget\\PostListing','',1),(14963,'120513','printshop-mobile','block-14961','catalog\\Paging','',2),(14964,'120514','printshop-mobile','block-14960-2','WidgetsAria','',1),(14965,'120515','printshop-mobile','tl_blog_index','BlockBox','',2),(14966,'120516','printshop-mobile','block-14965','BlockBox','',2),(14967,'120517','printshop-mobile','block-14966','BlockBox','',1),(14968,'120518','printshop-mobile','block-14967','Blog\\widget\\PostListing','',1),(14969,'120519','printshop-mobile','block-14967','catalog\\Paging','',2),(14970,'120520','printshop-mobile','block-14966-2','WidgetsAria','',1),(14971,'120521','printshop-mobile','block-14965','Banner','',1),(14972,'120522','printshop-mobile','tl_blog_post','BlockBox','',1),(14973,'120523','printshop-mobile','block-14972','BlockBox','',3),(14974,'120524','printshop-mobile','block-14973','Blog\\widget\\PostTags','',2),(14975,'120525','printshop-mobile','block-14973','BlockBox','',3),(14976,'120526','printshop-mobile','block-14975','Html_box','',1),(14977,'120527','printshop-mobile','block-14975','Blog\\widget\\PostLinkedProducts','',2),(14978,'120528','printshop-mobile','block-14973','BlockBox','',1),(14979,'120529','printshop-mobile','block-14978','Blog\\widget\\PostTitle','',3),(14980,'120530','printshop-mobile','block-14978','Blog\\widget\\PostImage','',1),(14981,'120531','printshop-mobile','block-14978','Blog\\widget\\PostDescription','',4),(14982,'120532','printshop-mobile','block-14978','BlockBox','',5),(14983,'120533','printshop-mobile','block-14982','Blog\\widget\\PostViewed','',1),(14984,'120534','printshop-mobile','block-14978','Blog\\widget\\PostDate','',2),(14985,'120535','printshop-mobile','block-14973-2','WidgetsAria','',1),(14986,'120536','printshop-mobile','tl_blog_tags','BlockBox','',1),(14987,'120537','printshop-mobile','block-14986','BlockBox','',1),(14988,'120538','printshop-mobile','block-14987','BlockBox','',1),(14989,'120539','printshop-mobile','block-14988','Blog\\widget\\PostListing','',1),(14990,'120540','printshop-mobile','block-14988','catalog\\Paging','',2),(14991,'120541','printshop-mobile','block-14987-2','WidgetsAria','',1),(14992,'120542','printshop-mobile','tracking_numbers','BlockBox','',1),(14993,'120543','printshop-mobile','block-14992','account\\OrderTracking','',2),(14994,'120544','printshop-mobile','block-14992','Html_box','',1),(14995,'120545','printshop-mobile','trade_form','BlockBox','',1),(14996,'120546','printshop-mobile','block-14995','BlockBox','',3),(14997,'120547','printshop-mobile','block-14996','BlockBox','',1),(14998,'120548','printshop-mobile','block-14997','account\\CustomerAdditionalField','',2),(14999,'120549','printshop-mobile','block-14997','account\\CustomerAdditionalField','',1),(15000,'120550','printshop-mobile','block-14995','BlockBox','',14),(15001,'120551','printshop-mobile','block-15000','account\\BackButton','',1),(15002,'120552','printshop-mobile','block-15000-2','account\\PdfButton','',2),(15003,'120553','printshop-mobile','block-15000-2','account\\SaveButton','',1),(15004,'120554','printshop-mobile','block-14995','BlockBox','',13),(15005,'120555','printshop-mobile','block-15004','BlockBox','',1),(15006,'120556','printshop-mobile','block-15005','account\\CustomerAdditionalField','',1),(15007,'120557','printshop-mobile','block-15004-2','BlockBox','',1),(15008,'120558','printshop-mobile','block-15007','account\\CustomerAdditionalField','',1),(15009,'120559','printshop-mobile','block-14995','Html_box','',10),(15010,'120560','printshop-mobile','block-14995','Html_box','',8),(15011,'120561','printshop-mobile','block-14995','Html_box','',12),(15012,'120562','printshop-mobile','block-14995','BlockBox','',11),(15013,'120563','printshop-mobile','block-15012','BlockBox','',1),(15014,'120564','printshop-mobile','block-15013','account\\CustomerAdditionalField','',4),(15015,'120565','printshop-mobile','block-15013','account\\CustomerAdditionalField','',2),(15016,'120566','printshop-mobile','block-15013','Html_box','',1),(15017,'120567','printshop-mobile','block-15013','account\\CustomerAdditionalField','',3),(15018,'120568','printshop-mobile','block-15012-2','BlockBox','',1),(15019,'120569','printshop-mobile','block-15018','Html_box','',1),(15020,'120570','printshop-mobile','block-15018','account\\CustomerAdditionalField','',3),(15021,'120571','printshop-mobile','block-15018','account\\CustomerAdditionalField','',2),(15022,'120572','printshop-mobile','block-15018','account\\CustomerAdditionalField','',4),(15023,'120573','printshop-mobile','block-14995','BlockBox','',5),(15024,'120574','printshop-mobile','block-15023','BlockBox','',1),(15025,'120575','printshop-mobile','block-15024','account\\CustomerAdditionalField','',2),(15026,'120576','printshop-mobile','block-15024','account\\CustomerAdditionalField','',1),(15027,'120577','printshop-mobile','block-14995','BlockBox','',4),(15028,'120578','printshop-mobile','block-15027','BlockBox','',1),(15029,'120579','printshop-mobile','block-15028','account\\AddressesList','',2),(15030,'120580','printshop-mobile','block-15028','Html_box','',1),(15031,'120581','printshop-mobile','block-15028','account\\CustomerAdditionalField','',5),(15032,'120582','printshop-mobile','block-15028','BlockBox','',3),(15033,'120583','printshop-mobile','block-15032','account\\CustomerAdditionalField','',1),(15034,'120584','printshop-mobile','block-15028','BlockBox','',4),(15035,'120585','printshop-mobile','block-15034','BlockBox','',1),(15036,'120586','printshop-mobile','block-15035','account\\CustomerAdditionalField','',1),(15037,'120587','printshop-mobile','block-15035','account\\CustomerAdditionalField','',4),(15038,'120588','printshop-mobile','block-15035','account\\CustomerAdditionalField','',2),(15039,'120589','printshop-mobile','block-15035','account\\CustomerAdditionalField','',3),(15040,'120590','printshop-mobile','block-15034-2','BlockBox','',1),(15041,'120591','printshop-mobile','block-15040','account\\CustomerAdditionalField','',4),(15042,'120592','printshop-mobile','block-15040','account\\CustomerAdditionalField','',3),(15043,'120593','printshop-mobile','block-15040','account\\CustomerAdditionalField','',2),(15044,'120594','printshop-mobile','block-15040','account\\CustomerAdditionalField','',1),(15045,'120595','printshop-mobile','block-15027-2','BlockBox','',1),(15046,'120596','printshop-mobile','block-15045','account\\AddressesList','',2),(15047,'120597','printshop-mobile','block-15045','BlockBox','',3),(15048,'120598','printshop-mobile','block-15047','BlockBox','',1),(15049,'120599','printshop-mobile','block-15048','account\\CustomerAdditionalField','',1),(15050,'120600','printshop-mobile','block-15048','account\\CustomerAdditionalField','',2),(15051,'120601','printshop-mobile','block-15047-2','BlockBox','',1),(15052,'120602','printshop-mobile','block-15051','account\\CustomerAdditionalField','',1),(15053,'120603','printshop-mobile','block-15045','BlockBox','',4),(15054,'120604','printshop-mobile','block-15053','BlockBox','',1),(15055,'120605','printshop-mobile','block-15054','account\\CustomerAdditionalField','',2),(15056,'120606','printshop-mobile','block-15054','account\\CustomerAdditionalField','',1),(15057,'120607','printshop-mobile','block-15054','account\\CustomerAdditionalField','',3),(15058,'120608','printshop-mobile','block-15053-2','BlockBox','',1),(15059,'120609','printshop-mobile','block-15058','account\\CustomerAdditionalField','',2),(15060,'120610','printshop-mobile','block-15058','account\\CustomerAdditionalField','',1),(15061,'120611','printshop-mobile','block-15058','account\\CustomerAdditionalField','',3),(15062,'120612','printshop-mobile','block-15045','Html_box','',1),(15063,'120613','printshop-mobile','block-14995','BlockBox','',9),(15064,'120614','printshop-mobile','block-15063','BlockBox','',1),(15065,'120615','printshop-mobile','block-15064','account\\CustomerAdditionalField','',1),(15066,'120616','printshop-mobile','block-15064','account\\CustomerAdditionalField','',2),(15067,'120617','printshop-mobile','block-15063-2','BlockBox','',1),(15068,'120618','printshop-mobile','block-15067','account\\CustomerAdditionalField','',1),(15069,'120619','printshop-mobile','block-14995','Html_box','',2),(15070,'120620','printshop-mobile','block-14995','BlockBox','',7),(15071,'120621','printshop-mobile','block-15070','BlockBox','',1),(15072,'120622','printshop-mobile','block-15071','account\\CustomerAdditionalField','',1),(15073,'120623','printshop-mobile','block-15071','account\\CustomerAdditionalField','',2),(15074,'120624','printshop-mobile','block-15070-2','BlockBox','',1),(15075,'120625','printshop-mobile','block-15074','account\\CustomerAdditionalField','',1),(15076,'120626','printshop-mobile','block-15074','account\\CustomerAdditionalField','',2),(15077,'120627','printshop-mobile','block-14995','Html_box','',1),(15078,'120628','printshop-mobile','block-14995','Html_box','',6),(15079,'120629','printshop-mobile','trade_form_pdf','BlockBox','',1),(15080,'120630','printshop-mobile','block-15079','BlockBox','',14),(15081,'120631','printshop-mobile','block-15080','Html_box','',1),(15082,'120632','printshop-mobile','block-15080-2','account\\CustomerAdditionalField','',1),(15083,'120633','printshop-mobile','block-15079','BlockBox','',6),(15084,'120634','printshop-mobile','block-15083','Html_box','',1),(15085,'120635','printshop-mobile','block-15083-2','account\\CombinedField','',2),(15086,'120636','printshop-mobile','block-15079','BlockBox','',13),(15087,'120637','printshop-mobile','block-15086','Html_box','',1),(15088,'120638','printshop-mobile','block-15086-2','account\\CustomerAdditionalField','',1),(15089,'120639','printshop-mobile','block-15079','BlockBox','',12),(15090,'120640','printshop-mobile','block-15089','Html_box','',1),(15091,'120641','printshop-mobile','block-15089-2','account\\CombinedField','',2),(15092,'120642','printshop-mobile','block-15079','BlockBox','',11),(15093,'120643','printshop-mobile','block-15092','Html_box','',1),(15094,'120644','printshop-mobile','block-15092-2','account\\CombinedField','',1),(15095,'120645','printshop-mobile','block-15079','BlockBox','',9),(15096,'120646','printshop-mobile','block-15095','Html_box','',1),(15097,'120647','printshop-mobile','block-15095-2','account\\CustomerAdditionalField','',1),(15098,'120648','printshop-mobile','block-15079','BlockBox','',8),(15099,'120649','printshop-mobile','block-15098','Html_box','',1),(15100,'120650','printshop-mobile','block-15098-2','BlockBox','',1),(15101,'120651','printshop-mobile','block-15100','account\\CustomerAdditionalField','',1),(15102,'120652','printshop-mobile','block-15100-2','BlockBox','',1),(15103,'120653','printshop-mobile','block-15102','Html_box','',2),(15104,'120654','printshop-mobile','block-15102-2','account\\CustomerAdditionalField','',1),(15105,'120655','printshop-mobile','block-15079','BlockBox','',3),(15106,'120656','printshop-mobile','block-15105','Html_box','',1),(15107,'120657','printshop-mobile','block-15079','BlockBox','',1),(15108,'120658','printshop-mobile','block-15107','Contacts','',1),(15109,'120659','printshop-mobile','block-15107-2','Html_box','',1),(15110,'120660','printshop-mobile','block-15079','BlockBox','',4),(15111,'120661','printshop-mobile','block-15110-2','BlockBox','',1),(15112,'120662','printshop-mobile','block-15111','BlockBox','',1),(15113,'120663','printshop-mobile','block-15112','Html_box','',2),(15114,'120664','printshop-mobile','block-15112-2','account\\CustomerAdditionalField','',1),(15115,'120665','printshop-mobile','block-15111-2','BlockBox','',1),(15116,'120666','printshop-mobile','block-15115','Html_box','',1),(15117,'120667','printshop-mobile','block-15115-2','account\\CustomerAdditionalField','',1),(15118,'120668','printshop-mobile','block-15079','BlockBox','',2),(15119,'120669','printshop-mobile','block-15118','Contacts','',1),(15120,'120670','printshop-mobile','block-15079','BlockBox','',7),(15121,'120671','printshop-mobile','block-15120','Html_box','',1),(15122,'120672','printshop-mobile','block-15120-2','account\\CustomerAdditionalField','',1),(15123,'120673','printshop-mobile','block-15079','BlockBox','',5),(15124,'120674','printshop-mobile','block-15123','Html_box','',1),(15125,'120675','printshop-mobile','block-15123-2','account\\CustomerAdditionalField','',1),(15126,'120676','printshop-mobile','block-15079','BlockBox','',10),(15127,'120677','printshop-mobile','block-15126','Html_box','',1),(15128,'120678','printshop-mobile','block-15126-2','account\\CustomerAdditionalField','',1),(15129,'120679','printshop-mobile','block-15079','BlockBox','',18),(15130,'120680','printshop-mobile','block-15129','Html_box','',1),(15131,'120681','printshop-mobile','block-15129-2','account\\CustomerAdditionalField','',1),(15132,'120682','printshop-mobile','block-15079','BlockBox','',15),(15133,'120683','printshop-mobile','block-15132','Html_box','',1),(15134,'120684','printshop-mobile','block-15079','BlockBox','',17),(15135,'120685','printshop-mobile','block-15134','Html_box','',1),(15136,'120686','printshop-mobile','block-15079','BlockBox','',20),(15137,'120687','printshop-mobile','block-15136','Html_box','',1),(15138,'120688','printshop-mobile','block-15136-2','account\\CustomerAdditionalField','',1),(15139,'120689','printshop-mobile','block-15079','BlockBox','',19),(15140,'120690','printshop-mobile','block-15139','Html_box','',1),(15141,'120691','printshop-mobile','block-15139-2','account\\CustomerAdditionalField','',1),(15142,'120692','printshop-mobile','block-15079','BlockBox','',16),(15143,'120693','printshop-mobile','block-15142','Html_box','',1),(15144,'120694','printshop-mobile','block-15142-2','BlockBox','',1),(15145,'120695','printshop-mobile','block-15144','account\\CustomerAdditionalField','',1),(15146,'120696','printshop-mobile','block-15144-2','Html_box','',1),(15147,'120697','printshop-mobile','block-15144-3','account\\CustomerAdditionalField','',1),(15148,'120698','printshop-mobile','block-15142-3','BlockBox','',1),(15149,'120699','printshop-mobile','block-15079','BlockBox','',23),(15150,'120700','printshop-mobile','block-15149','Html_box','',1),(15151,'120701','printshop-mobile','block-15149-2','account\\CustomerAdditionalField','',1),(15152,'120702','printshop-mobile','block-15079','BlockBox','',21),(15153,'120703','printshop-mobile','block-15152','Html_box','',1),(15154,'120704','printshop-mobile','block-15079','BlockBox','',26),(15155,'120705','printshop-mobile','block-15154','Html_box','',1),(15156,'120706','printshop-mobile','block-15079','BlockBox','',24),(15157,'120707','printshop-mobile','block-15156','Html_box','',1),(15158,'120708','printshop-mobile','block-15156-2','account\\CustomerAdditionalField','',1),(15159,'120709','printshop-mobile','block-15079','BlockBox','',25),(15160,'120710','printshop-mobile','block-15159','Html_box','',1),(15161,'120711','printshop-mobile','block-15079','BlockBox','',22),(15162,'120712','printshop-mobile','block-15161','Html_box','',1),(15163,'120713','printshop-mobile','block-15161-2','account\\CustomerAdditionalField','',1),(15164,'120714','printshop-mobile','block-15079','BlockBox','',27),(15165,'120715','printshop-mobile','block-15164','Html_box','',1),(15166,'120716','printshop-mobile','block-15164-2','Html_box','',1),(15167,'120717','printshop-mobile','block-15164-3','Html_box','',1),(15168,'120718','printshop-mobile','block-15164-4','Html_box','',1),(15169,'120719','printshop-mobile','block-15079','BlockBox','',28),(15170,'120720','printshop-mobile','block-15169','Html_box','',1),(15171,'120721','printshop-mobile','block-15169-2','account\\CustomerAdditionalField','',1),(15172,'120722','printshop-mobile','block-15169-3','Html_box','',1),(15173,'120723','printshop-mobile','block-15169-4','account\\CustomerAdditionalField','',1),(15174,'120724','printshop-mobile','block-15079','BlockBox','',29),(15175,'120725','printshop-mobile','block-15174','Html_box','',1),(15176,'120726','printshop-mobile','unsubscribed','BlockBox','',1),(15177,'120727','printshop-mobile','block-15176','Html_box','',1),(15178,'120728','printshop-mobile','update-and-pay-order_confirmation','BlockBox','',1),(15179,'120729','printshop-mobile','block-15178','BlockBox','',3),(15180,'120730','printshop-mobile','block-15179','BlockBox','',1),(15181,'120731','printshop-mobile','block-15180','BlockBox','',1),(15182,'120732','printshop-mobile','block-15181','BlockBox','',1),(15183,'120733','printshop-mobile','block-15182','Html_box','',4),(15184,'120734','printshop-mobile','block-15182','Html_box','',2),(15185,'120735','printshop-mobile','block-15182','Html_box','',1),(15186,'120736','printshop-mobile','block-15182','order\\ShippingMethod','',5),(15187,'120737','printshop-mobile','block-15182','order\\DeliveryAddress','',3),(15188,'120738','printshop-mobile','block-15182','order\\Telephone','',8),(15189,'120739','printshop-mobile','block-15182','order\\Email','',9),(15190,'120740','printshop-mobile','block-15182','order\\Name','',7),(15191,'120741','printshop-mobile','block-15182','Html_box','',6),(15192,'120742','printshop-mobile','block-15181-2','BlockBox','',1),(15193,'120743','printshop-mobile','block-15192','order\\BillingAddress','',3),(15194,'120744','printshop-mobile','block-15192','UpdateAndPay\\PayConfirm','',5),(15195,'120745','printshop-mobile','block-15192','Html_box','',1),(15196,'120746','printshop-mobile','block-15192','Html_box','',2),(15197,'120747','printshop-mobile','block-15192','Html_box','',4),(15198,'120748','printshop-mobile','block-15180','BlockBox','',3),(15199,'120749','printshop-mobile','block-15198','order\\Products','',2),(15200,'120750','printshop-mobile','block-15198','Html_box','',1),(15201,'120751','printshop-mobile','block-15179-2','BlockBox','',1),(15202,'120752','printshop-mobile','block-15201','Html_box','',1),(15203,'120753','printshop-mobile','block-15201','checkout\\ContinueBtn','',3),(15204,'120754','printshop-mobile','block-15201','order\\Totals','',2),(15205,'120755','printshop-mobile','block-15178','account\\OrderHeading','',1),(15206,'120756','printshop-mobile','update-and-pay-order_pay','BlockBox','',1),(15207,'120757','printshop-mobile','block-15206','BlockBox','',3),(15208,'120758','printshop-mobile','block-15207','BlockBox','',1),(15209,'120759','printshop-mobile','block-15208','BlockBox','',3),(15210,'120760','printshop-mobile','block-15209','Html_box','',1),(15211,'120761','printshop-mobile','block-15209','order\\Products','',2),(15212,'120762','printshop-mobile','block-15208','BlockBox','',1),(15213,'120763','printshop-mobile','block-15212','BlockBox','',1),(15214,'120764','printshop-mobile','block-15213','order\\Name','',7),(15215,'120765','printshop-mobile','block-15213','order\\Email','',9),(15216,'120766','printshop-mobile','block-15213','order\\DeliveryAddress','',3),(15217,'120767','printshop-mobile','block-15213','Html_box','',6),(15218,'120768','printshop-mobile','block-15213','order\\Telephone','',8),(15219,'120769','printshop-mobile','block-15213','Html_box','',2),(15220,'120770','printshop-mobile','block-15213','order\\ShippingMethod','',5),(15221,'120771','printshop-mobile','block-15213','Html_box','',4),(15222,'120772','printshop-mobile','block-15213','Html_box','',1),(15223,'120773','printshop-mobile','block-15212-2','BlockBox','',1),(15224,'120774','printshop-mobile','block-15223','Html_box','',2),(15225,'120775','printshop-mobile','block-15223','Html_box','',1),(15226,'120776','printshop-mobile','block-15223','Html_box','',4),(15227,'120777','printshop-mobile','block-15223','order\\BillingAddress','',3),(15228,'120778','printshop-mobile','block-15223','UpdateAndPay\\PayForm','',5),(15229,'120779','printshop-mobile','block-15207-2','BlockBox','',1),(15230,'120780','printshop-mobile','block-15229','order\\Totals','',2),(15231,'120781','printshop-mobile','block-15229','Html_box','',1),(15232,'120782','printshop-mobile','block-15229','checkout\\ContinueBtn','',3),(15233,'120783','printshop-mobile','block-15206','account\\OrderHeading','',1),(15234,'120784','printshop-mobile','wedding_index','BlockBox','',1),(15235,'120785','printshop-mobile','block-15234','BlockBox','',1),(15236,'120786','printshop-mobile','block-15235','WeddingRegistry\\widgets\\ViewCreateRegistryWidget','',2),(15237,'120787','printshop-mobile','block-15235','WeddingRegistry\\widgets\\SearchRegistryButton','',3),(15238,'120788','printshop-mobile','block-15235','Heading','',1),(15239,'120789','printshop-mobile','wedding_manage','BlockBox','',2),(15240,'120790','printshop-mobile','block-15239','WeddingRegistry\\widgets\\Photos','',1),(15241,'120791','printshop-mobile','block-15239-2','WeddingRegistry\\widgets\\ManageNames','',1),(15242,'120792','printshop-mobile','block-15239-2','BlockBox','',3),(15243,'120793','printshop-mobile','block-15242','WeddingRegistry\\widgets\\EditLink','',1),(15244,'120794','printshop-mobile','block-15242','WeddingRegistry\\widgets\\DeleteLink','',2),(15245,'120795','printshop-mobile','block-15242','WeddingRegistry\\widgets\\ShareLink','',3),(15246,'120796','printshop-mobile','block-15239-2','WeddingRegistry\\widgets\\ManageDate','',2),(15247,'120797','printshop-mobile','block-15239-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(15248,'120798','printshop-mobile','wedding_manage','WeddingRegistry\\widgets\\ManageBanner','',1),(15249,'120799','printshop-mobile','wedding_manage','WeddingRegistry\\widgets\\AddItemsLink','',3),(15250,'120800','printshop-mobile','wedding_manage','WeddingRegistry\\widgets\\Products','',4),(15254,'120804','printshop-mobile','wedding_search','BlockBox','',1),(15255,'120805','printshop-mobile','block-15254','WeddingRegistry\\widgets\\SearchList','',2),(15256,'120806','printshop-mobile','block-15254','WeddingRegistry\\widgets\\SearchPaging','',3),(15257,'120807','printshop-mobile','block-15254','BlockBox','',1),(15258,'120808','printshop-mobile','block-15257','BlockBox','',1),(15259,'120809','printshop-mobile','block-15258','WeddingRegistry\\widgets\\SearchForm','',2),(15260,'120810','printshop-mobile','block-15258','Html_box','',1),(15261,'120811','printshop-mobile','wedding_share','BlockBox','',1),(15262,'120812','printshop-mobile','block-15261','BlockBox','',4),(15263,'120813','printshop-mobile','block-15262-2','Html_box','',3),(15264,'120814','printshop-mobile','block-15262-2','Html_box','',1),(15265,'120815','printshop-mobile','block-15262-2','WeddingRegistry\\widgets\\ShareUrl','',2),(15266,'120816','printshop-mobile','block-15262-2','WeddingRegistry\\widgets\\InviteList','',4),(15267,'120817','printshop-mobile','block-15261','WeddingRegistry\\widgets\\ManageBanner','',1),(15268,'120818','printshop-mobile','block-15261','WeddingRegistry\\widgets\\Photos','',2),(15269,'120819','printshop-mobile','block-15261','Html_box','',3),(15270,'120820','printshop-mobile','wedding_success','Html_box','',1),(15271,'120821','printshop-mobile','wedding_success','WeddingRegistry\\widgets\\BackButton','',2),(15272,'120822','printshop-mobile','wedding_update','BlockBox','',2),(15273,'120823','printshop-mobile','block-15272','BlockBox','',1),(15274,'120824','printshop-mobile','block-15273','Html_box','',5),(15275,'120825','printshop-mobile','block-15273','Html_box','',3),(15276,'120826','printshop-mobile','block-15273','WeddingRegistry\\widgets\\Details','',4),(15277,'120827','printshop-mobile','block-15273','WeddingRegistry\\widgets\\Names','',2),(15278,'120828','printshop-mobile','block-15273','Html_box','',1),(15279,'120829','printshop-mobile','block-15273','WeddingRegistry\\widgets\\ShareRegistry','',6),(15280,'120830','printshop-mobile','block-15272-2','BlockBox','',1),(15281,'120831','printshop-mobile','block-15280','WeddingRegistry\\widgets\\ShippingDetails','',2),(15282,'120832','printshop-mobile','block-15280','Html_box','',1),(15283,'120833','printshop-mobile','block-15280','Html_box','',5),(15284,'120834','printshop-mobile','block-15280','WeddingRegistry\\widgets\\Photos','',6),(15285,'120835','printshop-mobile','block-15280','Html_box','',3),(15286,'120836','printshop-mobile','block-15280','WeddingRegistry\\widgets\\InformationText','',4),(15287,'120837','printshop-mobile','wedding_update','Html_box','',1),(15288,'120838','printshop-mobile','wedding_update','BlockBox','',3),(15289,'120839','printshop-mobile','block-15288','WeddingRegistry\\widgets\\BackButton','',1),(15290,'120840','printshop-mobile','block-15288-2','WeddingRegistry\\widgets\\SaveButton','',1),(15291,'120841','printshop-mobile','wedding_view','WeddingRegistry\\widgets\\ManageBanner','',1),(15292,'120842','printshop-mobile','wedding_view','BlockBox','',2),(15293,'120843','printshop-mobile','block-15292','WeddingRegistry\\widgets\\Photos','',1),(15294,'120844','printshop-mobile','block-15292-2','WeddingRegistry\\widgets\\ManageDate','',2),(15295,'120845','printshop-mobile','block-15292-2','WeddingRegistry\\widgets\\ManageNames','',1),(15296,'120846','printshop-mobile','block-15292-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(15297,'120847','printshop-mobile','wedding_view','WeddingRegistry\\widgets\\Products','',6),(15298,'120848','printshop-mobile','wishlist','BlockBox','',1),(15299,'120849','printshop-mobile','block-15298','BlockBox','',1),(15300,'120850','printshop-mobile','block-15299','WidgetsAria','',1),(15301,'120851','printshop-mobile','block-15299-2','Html_box','',1),(15302,'120852','printshop-mobile','block-15299-2','account\\Wishlist','',2),(15303,'120853','printshop-mobile','wishlist-cart','BlockBox','',1),(15304,'120854','printshop-mobile','block-15303','cart\\CartTabs','',1),(15305,'120855','printshop-mobile','block-15304','account\\Wishlist','',1),(17790,'118459','deals-mobile','404','Html_box','',1),(17887,'118556','deals-mobile','account','BlockBox','',1),(17888,'118557','deals-mobile','block-17887','BlockBox','',1),(17889,'118558','deals-mobile','block-17888','WidgetsAria','',1),(17890,'118559','deals-mobile','block-17888-2','Html_box','',3),(17891,'118560','deals-mobile','block-17888-2','account\\OrdersHistory','',4),(17892,'118561','deals-mobile','block-17888-2','Html_box','',1),(17893,'118562','deals-mobile','block-17888-2','BlockBox','',2),(17894,'118563','deals-mobile','block-17893','Html_box','',1),(17895,'118564','deals-mobile','block-17893','account\\LastOrder','',2),(17896,'118565','deals-mobile','block-17893-2','Html_box','',1),(17897,'118566','deals-mobile','block-17893-2','account\\AccountLink','',3),(17898,'118567','deals-mobile','block-17893-2','account\\OrderCount','',2),(17899,'118568','deals-mobile','block-17893-3','Html_box','',1),(17900,'118569','deals-mobile','block-17893-3','account\\TotalOrdered','',2),(17901,'118570','deals-mobile','block-17893-4','Html_box','',1),(17902,'118571','deals-mobile','block-17893-4','account\\AccountLink','',3),(17903,'118572','deals-mobile','block-17893-4','account\\CreditAmount','',2),(17904,'118573','deals-mobile','block-17893-5','account\\AccountLink','',3),(17905,'118574','deals-mobile','block-17893-5','account\\PointsEarnt','',2),(17906,'118575','deals-mobile','block-17893-5','Html_box','',1),(17907,'118576','deals-mobile','block-17888-2','BlockBox','',5),(17908,'118577','deals-mobile','block-17907','account\\GiftCards','',6),(17909,'118578','deals-mobile','block-17907','Html_box','',1),(17910,'118579','deals-mobile','block-17888-2','Html_box','',5),(17911,'118580','deals-mobile','account-menu','BlockBox','',1),(17912,'118581','deals-mobile','block-17911','BlockBox','',1),(17913,'118582','deals-mobile','block-17912','Html_box','',16),(17914,'118583','deals-mobile','block-17912','account\\AccountLink','',18),(17915,'118584','deals-mobile','block-17912','account\\AccountLink','',1),(17916,'118585','deals-mobile','block-17912','Html_box','',2),(17917,'118586','deals-mobile','block-17912','account\\AccountLink','',17),(17918,'118587','deals-mobile','block-17912','account\\AccountLink','',4),(17919,'118588','deals-mobile','block-17912','account\\AccountLink','',11),(17920,'118589','deals-mobile','block-17912','Html_box','',6),(17921,'118590','deals-mobile','block-17912','account\\AccountLink','',8),(17922,'118591','deals-mobile','block-17912','account\\AccountLink','',7),(17923,'118592','deals-mobile','block-17912','account\\AccountLink','',14),(17924,'118593','deals-mobile','block-17912','account\\AccountLink','',5),(17925,'118594','deals-mobile','block-17912','account\\AccountLink','',12),(17926,'118595','deals-mobile','block-17912','account\\AccountLink','',9),(17927,'118596','deals-mobile','block-17912','Html_box','',10),(17928,'118597','deals-mobile','block-17912','account\\AccountLink','',15),(17929,'118598','deals-mobile','account_edit','BlockBox','',1),(17930,'118599','deals-mobile','block-17929','BlockBox','',1),(17931,'118600','deals-mobile','block-17930','WidgetsAria','',1),(17932,'118601','deals-mobile','block-17930-2','account\\AccountEdit','',2),(17933,'118602','deals-mobile','block-17930-2','Html_box','',1),(17934,'118603','deals-mobile','block-17930-2','account\\AccountLink','',3),(17935,'118604','deals-mobile','address_book','BlockBox','',1),(17936,'118605','deals-mobile','block-17935','BlockBox','',1),(17937,'118606','deals-mobile','block-17936','WidgetsAria','',1),(17938,'118607','deals-mobile','block-17936-2','account\\AddressBook','',3),(17939,'118608','deals-mobile','block-17936-2','Html_box','',1),(17940,'118609','deals-mobile','address_book_process','BlockBox','',1),(17941,'118610','deals-mobile','block-17940','BlockBox','',1),(17942,'118611','deals-mobile','block-17941','WidgetsAria','',1),(17943,'118612','deals-mobile','block-17941-2','account\\EditAddress','',2),(17944,'118613','deals-mobile','block-17941-2','Html_box','',1),(17945,'118614','deals-mobile','block-17941-2','account\\AccountLink','',3),(17946,'118615','deals-mobile','b2b','BlockBox','',1),(17947,'118616','deals-mobile','block-17946','BlockBox','',1),(17948,'118617','deals-mobile','block-17947','productListing\\image','',1),(17949,'118618','deals-mobile','block-17947-2','productListing\\model','',5),(17950,'118619','deals-mobile','block-17947-2','productListing\\attributes','',3),(17951,'118620','deals-mobile','block-17947-2','BlockBox','',4),(17952,'118621','deals-mobile','block-17951','BlockBox','',1),(17953,'118622','deals-mobile','block-17952','productListing\\price','',1),(17954,'118623','deals-mobile','block-17952-2','productListing\\bonusPoints','',1),(17955,'118624','deals-mobile','block-17951-2','productListing\\qtyInput','',1),(17956,'118625','deals-mobile','block-17947-2','productListing\\description','',6),(17957,'118626','deals-mobile','block-17947-2','BlockBox','',2),(17958,'118627','deals-mobile','block-17957','productListing\\stock','',1),(17959,'118628','deals-mobile','block-17957-2','productListing\\rating','',1),(17960,'118629','deals-mobile','block-17947-2','productListing\\name','',1),(17961,'118630','deals-mobile','batch','BlockBox','',1),(17962,'118631','deals-mobile','block-17961','productListing\\attributes','',5),(17963,'118632','deals-mobile','block-17961','productListing\\price','',6),(17964,'118633','deals-mobile','block-17961','productListing\\name','',4),(17965,'118634','deals-mobile','block-17961','productListing\\image','',2),(17966,'118635','deals-mobile','block-17961','batchSelect','',1),(17967,'118636','deals-mobile','batch_selected','BlockBox','',1),(17968,'118637','deals-mobile','block-17967','BlockBox','',13),(17969,'118638','deals-mobile','block-17968','productListing\\image','',1),(17970,'118639','deals-mobile','block-17968-2','batchRemove','',1),(17971,'118640','deals-mobile','block-17968-2','productListing\\price','',3),(17972,'118641','deals-mobile','block-17968-2','productListing\\name','',2),(17973,'118642','deals-mobile','bbbbb','BlockBox','',1),(17974,'118643','deals-mobile','block-17973','BlockBox','',2),(17975,'118644','deals-mobile','block-17974','Filters','',1),(17976,'118645','deals-mobile','block-17974-2','BlockBox','',6),(17977,'118646','deals-mobile','block-17976','catalog\\CountsItems','',1),(17978,'118647','deals-mobile','block-17976-2','catalog\\Paging','',1),(17979,'118648','deals-mobile','block-17974-2','catalog\\Image','',1),(17980,'118649','deals-mobile','block-17974-2','Listing','',5),(17981,'118650','deals-mobile','block-17974-2','catalog\\ImageMapCategory','',3),(17982,'118651','deals-mobile','block-17974-2','BlockBox','',4),(17983,'118652','deals-mobile','block-17982','catalog\\ListingLook','',1),(17984,'118653','deals-mobile','block-17982','catalog\\CompareButton','',2),(17985,'118654','deals-mobile','block-17982','catalog\\ItemsOnPage','',4),(17986,'118655','deals-mobile','block-17982','catalog\\Sorting','',3),(17987,'118656','deals-mobile','block-17974-2','Categories','',2),(17988,'118657','deals-mobile','block-17973','catalog\\Title','',1),(17989,'118658','deals-mobile','blog','BlockBox','',1),(17990,'118659','deals-mobile','block-17989','BlockBox','',1),(17991,'118660','deals-mobile','block-17990','BlogContent','',1),(17992,'118661','deals-mobile','block-17990-2','BlogSidebar','',1),(17993,'118662','deals-mobile','blogsidebar','BlockBox','',1),(17994,'118663','deals-mobile','block-17993','Blog\\widget\\RecentPosts','',4),(17995,'118664','deals-mobile','block-17993','Blog\\widget\\TagCloud','',2),(17996,'118665','deals-mobile','block-17993','Blog\\widget\\CategoriesList','',1),(17997,'118666','deals-mobile','block-17993','Blog\\widget\\MostPopularPosts','',3),(17998,'118667','deals-mobile','cart','BlockBox','',2),(17999,'118668','deals-mobile','block-17998','BlockBox','',4),(18000,'118669','deals-mobile','block-17999','Html_box','',1),(18001,'118670','deals-mobile','block-17999','cart\\UpSell','6',2),(18002,'118671','deals-mobile','block-17998','BlockBox','',1),(18003,'118672','deals-mobile','block-18002','cart\\Products','',3),(18004,'118673','deals-mobile','block-18002','BlockBox','',2),(18005,'118674','deals-mobile','block-18004','MultiCart\\SaveCart','',2),(18006,'118675','deals-mobile','block-18004-2','MultiCart\\Actions','',1),(18007,'118676','deals-mobile','block-18002','MultiCart\\CartSwitcher','',1),(18008,'118677','deals-mobile','block-17998','BlockBox','',3),(18009,'118678','deals-mobile','block-18008','cart\\GiveAway','',2),(18010,'118679','deals-mobile','block-18008','Html_box','',1),(18011,'118680','deals-mobile','block-17998','BlockBox','',2),(18012,'118681','deals-mobile','block-18011','Html_box','',1),(18013,'118682','deals-mobile','block-18011','BlockBox','',2),(18014,'118683','deals-mobile','block-18013','cart\\DiscountCoupon','',1),(18015,'118684','deals-mobile','block-18013','cart\\CreditAmount','',2),(18016,'118685','deals-mobile','block-18013','cart\\BonusPoints','',3),(18017,'118686','deals-mobile','block-17998','BlockBox','',5),(18018,'118687','deals-mobile','block-18017','Html_box','',1),(18019,'118688','deals-mobile','block-18017','cart\\ShippingEstimator','',2),(18020,'118689','deals-mobile','block-17998','BlockBox','',7),(18021,'118690','deals-mobile','block-18020','BlockBox','',2),(18022,'118691','deals-mobile','block-18021','Image','',4),(18023,'118692','deals-mobile','block-18021','cart\\CheckoutBtn','',2),(18024,'118693','deals-mobile','block-18021','cart\\OrderTotal','',1),(18025,'118694','deals-mobile','block-17998','Html_box','',6),(18026,'118695','deals-mobile','cart2','BlockBox','',2),(18027,'118696','deals-mobile','block-18026','cart\\CartTabs','',2),(18028,'118697','deals-mobile','block-18027','BlockBox','',1),(18029,'118698','deals-mobile','block-18028','BlockBox','',4),(18030,'118699','deals-mobile','block-18029','cart\\UpSell','6',2),(18031,'118700','deals-mobile','block-18029','Html_box','',1),(18032,'118701','deals-mobile','block-18028','BlockBox','',1),(18033,'118702','deals-mobile','block-18032','cart\\Products','',3),(18034,'118703','deals-mobile','block-18032','BlockBox','',2),(18035,'118704','deals-mobile','block-18034','MultiCart\\CartSwitcher','',1),(18036,'118705','deals-mobile','block-18034','MultiCart\\SaveCart','',2),(18037,'118706','deals-mobile','block-18034-2','MultiCart\\Actions','',1),(18038,'118707','deals-mobile','block-18028','BlockBox','',3),(18039,'118708','deals-mobile','block-18038','cart\\GiveAway','',2),(18040,'118709','deals-mobile','block-18038','Html_box','',1),(18041,'118710','deals-mobile','block-18028','BlockBox','',2),(18042,'118711','deals-mobile','block-18041','Html_box','',1),(18043,'118712','deals-mobile','block-18041','BlockBox','',2),(18044,'118713','deals-mobile','block-18043','cart\\DiscountCoupon','',1),(18045,'118714','deals-mobile','block-18043-2','cart\\CreditAmount','',1),(18046,'118715','deals-mobile','block-18043-3','cart\\BonusPoints','',1),(18047,'118716','deals-mobile','block-18028','BlockBox','',5),(18048,'118717','deals-mobile','block-18047','Html_box','',1),(18049,'118718','deals-mobile','block-18047','cart\\ShippingEstimator','',2),(18050,'118719','deals-mobile','block-18028-2','BlockBox','',1),(18051,'118720','deals-mobile','block-18050','Html_box','',1),(18052,'118721','deals-mobile','block-18050','BlockBox','',2),(18053,'118722','deals-mobile','block-18052','Image','',4),(18054,'118723','deals-mobile','block-18052','cart\\CheckoutBtn','',2),(18055,'118724','deals-mobile','block-18052','cart\\OrderTotal','',1),(18056,'118725','deals-mobile','categories','BlockBox','',1),(18057,'118726','deals-mobile','block-18056','catalog\\Title','',1),(18058,'118727','deals-mobile','block-18056','Categories','',2),(18059,'118728','deals-mobile','categories','BlockBox','',2),(18060,'118729','deals-mobile','block-18059','Listing','',3),(18061,'118730','deals-mobile','block-18059','BlockBox','',1),(18062,'118731','deals-mobile','block-18061','catalog\\Sorting','',1),(18063,'118732','deals-mobile','block-18061-2','catalog\\CountsItems','',1),(18064,'118733','deals-mobile','block-18059','catalog\\Paging','',2),(18065,'118734','deals-mobile','category','ListingFunctionality','',2),(18066,'118735','deals-mobile','category','Categories','',1),(18067,'118736','deals-mobile','category','PagingBar','',5),(18068,'118737','deals-mobile','category','PagingBar','',3),(18069,'118738','deals-mobile','category','Listing','',4),(18070,'118739','deals-mobile','category_2','BlockBox','',1),(18071,'118740','deals-mobile','block-18070','catalog\\Title','',1),(18072,'118741','deals-mobile','block-18070','BlockBox','',2),(18073,'118742','deals-mobile','block-18072','Filters','',1),(18074,'118743','deals-mobile','block-18072-2','catalog\\Image','',1),(18075,'118744','deals-mobile','block-18072-2','Listing','',5),(18076,'118745','deals-mobile','block-18072-2','BlockBox','',4),(18077,'118746','deals-mobile','block-18076','catalog\\Sorting','',3),(18078,'118747','deals-mobile','block-18076','catalog\\ItemsOnPage','',4),(18079,'118748','deals-mobile','block-18076','catalog\\CompareButton','',2),(18080,'118749','deals-mobile','block-18076','catalog\\ListingLook','',1),(18081,'118750','deals-mobile','block-18072-2','catalog\\ImageMapCategory','',3),(18082,'118751','deals-mobile','block-18072-2','Categories','',2),(18083,'118752','deals-mobile','block-18072-2','BlockBox','',6),(18084,'118753','deals-mobile','block-18083','catalog\\CountsItems','',1),(18085,'118754','deals-mobile','block-18083-2','catalog\\Paging','',1),(18086,'118755','deals-mobile','category_no_filters','BlockBox','',1),(18087,'118756','deals-mobile','block-18086','catalog\\B2bAddButton','',7),(18088,'118757','deals-mobile','block-18086','BlockBox','',6),(18089,'118758','deals-mobile','block-18088','catalog\\CountsItems','',1),(18090,'118759','deals-mobile','block-18088-2','catalog\\Paging','',1),(18091,'118760','deals-mobile','block-18086','Listing','',5),(18092,'118761','deals-mobile','block-18086','catalog\\Image','',2),(18093,'118762','deals-mobile','block-18086','BlockBox','',4),(18094,'118763','deals-mobile','block-18093','catalog\\ListingLook','',1),(18095,'118764','deals-mobile','block-18093','catalog\\CompareButton','',2),(18096,'118765','deals-mobile','block-18093','HeaderStock','',5),(18097,'118766','deals-mobile','block-18093','catalog\\ItemsOnPage','',4),(18098,'118767','deals-mobile','block-18093','catalog\\Sorting','',3),(18099,'118768','deals-mobile','block-18086','Categories','',3),(18100,'118769','deals-mobile','block-18086','catalog\\Title','',1),(18101,'118770','deals-mobile','checkout','BlockBox','',1),(18102,'118771','deals-mobile','block-18101','BlockBox','',1),(18103,'118772','deals-mobile','block-18102','BlockBox','',2),(18104,'118773','deals-mobile','block-18103','BlockBox','',3),(18105,'118774','deals-mobile','block-18104','BlockBox','',2),(18106,'118775','deals-mobile','block-18105','checkout\\BillingAddress','',2),(18107,'118776','deals-mobile','block-18105','Html_box','',1),(18108,'118777','deals-mobile','block-18105-2','BlockBox','',1),(18109,'118778','deals-mobile','block-18108','Html_box','',1),(18110,'118779','deals-mobile','block-18108','checkout\\PaymentMethod','',2),(18111,'118780','deals-mobile','block-18104','Html_box','',1),(18112,'118781','deals-mobile','block-18103','BlockBox','',6),(18113,'118782','deals-mobile','block-18112','checkout\\CreateAccount','',2),(18114,'118783','deals-mobile','block-18112','cart\\Products','',1),(18115,'118784','deals-mobile','block-18103','BlockBox','',2),(18116,'118785','deals-mobile','block-18115','Html_box','',1),(18117,'118786','deals-mobile','block-18115','BlockBox','',3),(18118,'118787','deals-mobile','block-18117','BlockBox','',1),(18119,'118788','deals-mobile','block-18118','checkout\\ContactInformation','',4),(18120,'118789','deals-mobile','block-18118','UploadCustomerId\\UploadCustomerIdForm','',4),(18121,'118790','deals-mobile','block-18118','checkout\\ShippingAddress','',2),(18122,'118791','deals-mobile','block-18118','Html_box','',3),(18123,'118792','deals-mobile','block-18115','BlockBox','',4),(18124,'118793','deals-mobile','block-18123','Html_box','',1),(18125,'118794','deals-mobile','block-18123','DelayedDespatch\\Checkout','',3),(18126,'118795','deals-mobile','block-18123','checkout\\Shipping','',2),(18127,'118796','deals-mobile','block-18115','Neighbour\\Checkout','',5),(18128,'118797','deals-mobile','block-18115','BlockBox','',2),(18129,'118798','deals-mobile','block-18128','checkout\\ShippingChoice','',1),(18130,'118799','deals-mobile','block-18103','BlockBox','',4),(18131,'118800','deals-mobile','block-18130','Html_box','',1),(18132,'118801','deals-mobile','block-18130','BlockBox','',2),(18133,'118802','deals-mobile','block-18132','CouponsAndVauchers\\Checkout','',1),(18134,'118803','deals-mobile','block-18132-2','checkout\\BonusPoints','',2),(18135,'118804','deals-mobile','block-18132-2','checkout\\CreditAmount','',1),(18136,'118805','deals-mobile','block-18103','BlockBox','',5),(18137,'118806','deals-mobile','block-18136','checkout\\Comments','',2),(18138,'118807','deals-mobile','block-18136','Html_box','',1),(18139,'118808','deals-mobile','block-18101','BlockBox','',2),(18140,'118809','deals-mobile','block-18139','checkout\\Totals','',2),(18141,'118810','deals-mobile','block-18139','checkout\\ContinueBtn','',3),(18142,'118811','deals-mobile','block-18139','Html_box','',1),(18143,'118812','deals-mobile','block-18139','checkout\\Terms','',4),(18144,'118813','deals-mobile','block-18139','Html_box','',5),(18145,'118814','deals-mobile','checkout_confirmation','BlockBox','',1),(18146,'118815','deals-mobile','block-18145','checkout\\ConfirmBtn','',4),(18147,'118816','deals-mobile','block-18145','cart\\Products','',7),(18148,'118817','deals-mobile','block-18145','BlockBox','',2),(18149,'118818','deals-mobile','block-18148','BlockBox','',1),(18150,'118819','deals-mobile','block-18149','Html_box','',1),(18151,'118820','deals-mobile','block-18149','checkout\\ShippingAddressConfirm','',3),(18152,'118821','deals-mobile','block-18148-2','BlockBox','',1),(18153,'118822','deals-mobile','block-18152','Html_box','',1),(18154,'118823','deals-mobile','block-18152','checkout\\BillingAddressConfirm','',3),(18155,'118824','deals-mobile','block-18145','checkout\\ConfirmBtn','',9),(18156,'118825','deals-mobile','block-18145','BlockBox','',3),(18157,'118826','deals-mobile','block-18156','BlockBox','',1),(18158,'118827','deals-mobile','block-18157','Html_box','',1),(18159,'118828','deals-mobile','block-18157','checkout\\ShippingConfirm','',3),(18160,'118829','deals-mobile','block-18156-2','BlockBox','',1),(18161,'118830','deals-mobile','block-18160','checkout\\PaymentMethodConfirm','',3),(18162,'118831','deals-mobile','block-18160','Html_box','',1),(18163,'118832','deals-mobile','block-18145','checkout\\EditBtn','',6),(18164,'118833','deals-mobile','block-18145','checkout\\Totals','',8),(18165,'118834','deals-mobile','block-18145','Html_box','',5),(18166,'118835','deals-mobile','checkout_confirmation_no_shipping_q','BlockBox','',1),(18167,'118836','deals-mobile','block-18166','checkout\\Totals','',5),(18168,'118837','deals-mobile','block-18166','checkout\\ConfirmBtn','',6),(18169,'118838','deals-mobile','block-18166','BlockBox','',1),(18170,'118839','deals-mobile','block-18169','BlockBox','',1),(18171,'118840','deals-mobile','block-18170','Html_box','',1),(18172,'118841','deals-mobile','block-18170','checkout\\BillingAddressConfirm','',3),(18173,'118842','deals-mobile','block-18169-2','BlockBox','',1),(18174,'118843','deals-mobile','block-18173','Html_box','',1),(18175,'118844','deals-mobile','block-18173','checkout\\PaymentMethodConfirm','',3),(18176,'118845','deals-mobile','block-18166','Html_box','',3),(18177,'118846','deals-mobile','block-18166','quote\\Products','',4),(18178,'118847','deals-mobile','block-18166','checkout\\ConfirmBtn','',2),(18179,'118848','deals-mobile','checkout_confirmation_no_shipping','BlockBox','',1),(18180,'118849','deals-mobile','block-18179','Html_box','',5),(18181,'118850','deals-mobile','block-18179','checkout\\ConfirmBtn','',4),(18182,'118851','deals-mobile','block-18179','cart\\Products','',7),(18183,'118852','deals-mobile','block-18179','checkout\\Totals','',8),(18184,'118853','deals-mobile','block-18179','checkout\\ConfirmBtn','',9),(18185,'118854','deals-mobile','block-18179','BlockBox','',2),(18186,'118855','deals-mobile','block-18185','BlockBox','',1),(18187,'118856','deals-mobile','block-18186','checkout\\BillingAddressConfirm','',3),(18188,'118857','deals-mobile','block-18186','Html_box','',1),(18189,'118858','deals-mobile','block-18185-2','BlockBox','',1),(18190,'118859','deals-mobile','block-18189','Html_box','',1),(18191,'118860','deals-mobile','block-18189','checkout\\PaymentMethodConfirm','',3),(18192,'118861','deals-mobile','checkout_confirmation_q','BlockBox','',1),(18193,'118862','deals-mobile','block-18192','BlockBox','',2),(18194,'118863','deals-mobile','block-18193','BlockBox','',1),(18195,'118864','deals-mobile','block-18194','checkout\\ShippingConfirm','',3),(18196,'118865','deals-mobile','block-18194','Html_box','',1),(18197,'118866','deals-mobile','block-18193-2','BlockBox','',1),(18198,'118867','deals-mobile','block-18197','Html_box','',1),(18199,'118868','deals-mobile','block-18197','checkout\\PaymentMethodConfirm','',3),(18200,'118869','deals-mobile','block-18192','checkout\\ConfirmBtn','',8),(18201,'118870','deals-mobile','block-18192','checkout\\ConfirmBtn','',3),(18202,'118871','deals-mobile','block-18192','checkout\\EditBtn','',5),(18203,'118872','deals-mobile','block-18192','quote\\Products','',6),(18204,'118873','deals-mobile','block-18192','Html_box','',4),(18205,'118874','deals-mobile','block-18192','checkout\\Totals','',7),(18206,'118875','deals-mobile','block-18192','BlockBox','',1),(18207,'118876','deals-mobile','block-18206','BlockBox','',1),(18208,'118877','deals-mobile','block-18207','checkout\\ShippingAddressConfirm','',3),(18209,'118878','deals-mobile','block-18207','Html_box','',1),(18210,'118879','deals-mobile','block-18206-2','BlockBox','',1),(18211,'118880','deals-mobile','block-18210','Html_box','',1),(18212,'118881','deals-mobile','block-18210','checkout\\BillingAddressConfirm','',3),(18213,'118882','deals-mobile','checkout_confirmation_title','Html_box','',1),(18214,'118883','deals-mobile','checkout_confirmation_title_g','Html_box','',1),(18215,'118884','deals-mobile','checkout_confirmation_title_no_shipping_g','Html_box','',1),(18216,'118885','deals-mobile','checkout_confirmation_title_no_shipping','Html_box','',1),(18217,'118886','deals-mobile','checkout_confirmation_title_q','Html_box','',1),(18218,'118887','deals-mobile','checkout_confirmation_title_s','Html_box','',1),(18219,'118888','deals-mobile','checkout_delivery','BlockBox','',1),(18220,'118889','deals-mobile','block-18219','BlockBox','',1),(18221,'118890','deals-mobile','block-18220','checkout\\ShippingAddress','',2),(18222,'118891','deals-mobile','block-18220','Html_box','',1),(18223,'118892','deals-mobile','block-18219-2','BlockBox','',1),(18224,'118893','deals-mobile','block-18223','Neighbour\\Checkout','',4),(18225,'118894','deals-mobile','block-18223','Html_box','',1),(18226,'118895','deals-mobile','block-18223','checkout\\Shipping','',2),(18227,'118896','deals-mobile','block-18223','DelayedDespatch\\Checkout','',3),(18228,'118897','deals-mobile','checkout_delivery','BlockBox','',2),(18229,'118898','deals-mobile','block-18228','BlockBox','',1),(18230,'118899','deals-mobile','block-18229','Html_box','',1),(18231,'118900','deals-mobile','block-18229','checkout\\ContactInformation','',2),(18232,'118901','deals-mobile','block-18228-2','BlockBox','',1),(18233,'118902','deals-mobile','block-18232','Html_box','',1),(18234,'118903','deals-mobile','block-18232','checkout\\Comments','',2),(18235,'118904','deals-mobile','checkout_delivery','BlockBox','',3),(18236,'118905','deals-mobile','block-18235','Html_box','',1),(18237,'118906','deals-mobile','block-18235-2','checkout\\ContinueBtn','',1),(18238,'118907','deals-mobile','checkout_delivery_g','BlockBox','',1),(18239,'118908','deals-mobile','block-18238','BlockBox','',1),(18240,'118909','deals-mobile','block-18239','checkout\\ShippingAddress','',2),(18241,'118910','deals-mobile','block-18239','Html_box','',1),(18242,'118911','deals-mobile','block-18238-2','BlockBox','',1),(18243,'118912','deals-mobile','block-18242','Html_box','',1),(18244,'118913','deals-mobile','block-18242','Neighbour\\Checkout','',4),(18245,'118914','deals-mobile','block-18242','checkout\\Shipping','',2),(18246,'118915','deals-mobile','block-18242','DelayedDespatch\\Checkout','',3),(18247,'118916','deals-mobile','checkout_delivery_g','BlockBox','',3),(18248,'118917','deals-mobile','block-18247','Html_box','',1),(18249,'118918','deals-mobile','block-18247-2','checkout\\ContinueBtn','',1),(18250,'118919','deals-mobile','checkout_delivery_g','BlockBox','',2),(18251,'118920','deals-mobile','block-18250','BlockBox','',1),(18252,'118921','deals-mobile','block-18251','checkout\\ContactInformation','',2),(18253,'118922','deals-mobile','block-18251','Html_box','',1),(18254,'118923','deals-mobile','block-18250-2','BlockBox','',1),(18255,'118924','deals-mobile','block-18254','checkout\\Comments','',2),(18256,'118925','deals-mobile','block-18254','Html_box','',1),(18257,'118926','deals-mobile','checkout_delivery_no_shipping','BlockBox','',2),(18258,'118927','deals-mobile','block-18257','Html_box','',1),(18259,'118928','deals-mobile','block-18257-2','checkout\\ContinueBtn','',1),(18260,'118929','deals-mobile','checkout_delivery_no_shipping','BlockBox','',1),(18261,'118930','deals-mobile','block-18260','BlockBox','',1),(18262,'118931','deals-mobile','block-18261','checkout\\ContactInformation','',2),(18263,'118932','deals-mobile','block-18260-2','BlockBox','',1),(18264,'118933','deals-mobile','block-18263','checkout\\Comments','',2),(18265,'118934','deals-mobile','block-18263','Html_box','',1),(18266,'118935','deals-mobile','checkout_delivery_no_shipping_g','BlockBox','',1),(18267,'118936','deals-mobile','block-18266','BlockBox','',1),(18268,'118937','deals-mobile','block-18267','checkout\\ContactInformation','',2),(18269,'118938','deals-mobile','block-18266-2','BlockBox','',1),(18270,'118939','deals-mobile','block-18269','Html_box','',1),(18271,'118940','deals-mobile','block-18269','checkout\\Comments','',2),(18272,'118941','deals-mobile','checkout_delivery_no_shipping_g','BlockBox','',2),(18273,'118942','deals-mobile','block-18272','Html_box','',1),(18274,'118943','deals-mobile','block-18272-2','checkout\\ContinueBtn','',1),(18275,'118944','deals-mobile','checkout_delivery_title','Html_box','',1),(18276,'118945','deals-mobile','checkout_delivery_title_g','Html_box','',1),(18277,'118946','deals-mobile','checkout_delivery_title_no_shipping_g','Html_box','',1),(18278,'118947','deals-mobile','checkout_delivery_title_no_shipping','Html_box','',1),(18279,'118948','deals-mobile','checkout_delivery_title_q','Html_box','',1),(18280,'118949','deals-mobile','checkout_delivery_title_s','Html_box','',1),(18281,'118950','deals-mobile','checkout_free_s','BlockBox','',1),(18282,'118951','deals-mobile','block-18281','BlockBox','',2),(18283,'118952','deals-mobile','block-18282','BlockBox','',2),(18284,'118953','deals-mobile','block-18283','BlockBox','',2),(18285,'118954','deals-mobile','block-18284','Neighbour\\Checkout','',4),(18286,'118955','deals-mobile','block-18284','BlockBox','',3),(18287,'118956','deals-mobile','block-18286','BlockBox','',1),(18288,'118957','deals-mobile','block-18287','checkout\\ShippingAddress','',2),(18289,'118958','deals-mobile','block-18287','Html_box','',3),(18290,'118959','deals-mobile','block-18287','checkout\\ContactInformation','',4),(18291,'118960','deals-mobile','block-18286-2','BlockBox','',1),(18292,'118961','deals-mobile','block-18291','DelayedDespatch\\Checkout','',3),(18293,'118962','deals-mobile','block-18284','Html_box','',1),(18294,'118963','deals-mobile','block-18284','BlockBox','',2),(18295,'118964','deals-mobile','block-18294','checkout\\ShippingChoice','',1),(18296,'118965','deals-mobile','block-18283','BlockBox','',5),(18297,'118966','deals-mobile','block-18296','Html_box','',1),(18298,'118967','deals-mobile','block-18296','checkout\\Comments','',2),(18299,'118968','deals-mobile','block-18283','checkout\\Gdpr','',1),(18300,'118969','deals-mobile','block-18283','BlockBox','',6),(18301,'118970','deals-mobile','block-18300','checkout\\CreateAccount','',3),(18302,'118971','deals-mobile','block-18300','sample\\Products','',1),(18303,'118972','deals-mobile','block-18282-2','BlockBox','',1),(18304,'118973','deals-mobile','block-18303','checkout\\ContinueBtn','',3),(18305,'118974','deals-mobile','block-18303','Html_box','',4),(18306,'118975','deals-mobile','checkout_no_shipping','BlockBox','',1),(18307,'118976','deals-mobile','block-18306','BlockBox','',2),(18308,'118977','deals-mobile','block-18307','BlockBox','',1),(18309,'118978','deals-mobile','block-18308','BlockBox','',5),(18310,'118979','deals-mobile','block-18309','Html_box','',1),(18311,'118980','deals-mobile','block-18309','checkout\\Comments','',2),(18312,'118981','deals-mobile','block-18308','BlockBox','',4),(18313,'118982','deals-mobile','block-18312','BlockBox','',2),(18314,'118983','deals-mobile','block-18313','CouponsAndVauchers\\Checkout','',1),(18315,'118984','deals-mobile','block-18313-2','checkout\\BonusPoints','',2),(18316,'118985','deals-mobile','block-18313-2','checkout\\CreditAmount','',1),(18317,'118986','deals-mobile','block-18312','Html_box','',1),(18318,'118987','deals-mobile','block-18308','BlockBox','',3),(18319,'118988','deals-mobile','block-18318','BlockBox','',2),(18320,'118989','deals-mobile','block-18319','Html_box','',1),(18321,'118990','deals-mobile','block-18319','checkout\\BillingAddress','',2),(18322,'118991','deals-mobile','block-18319-2','BlockBox','',1),(18323,'118992','deals-mobile','block-18322','Html_box','',1),(18324,'118993','deals-mobile','block-18322','checkout\\PaymentMethod','',2),(18325,'118994','deals-mobile','block-18318','Html_box','',1),(18326,'118995','deals-mobile','block-18308','BlockBox','',6),(18327,'118996','deals-mobile','block-18326','cart\\Products','',1),(18328,'118997','deals-mobile','block-18326','checkout\\CreateAccount','',2),(18329,'118998','deals-mobile','block-18307-2','BlockBox','',1),(18330,'118999','deals-mobile','block-18329','checkout\\Terms','',4),(18331,'119000','deals-mobile','block-18329','checkout\\ContinueBtn','',3),(18332,'119001','deals-mobile','block-18329','checkout\\Totals','',2),(18333,'119002','deals-mobile','block-18329','Html_box','',5),(18334,'119003','deals-mobile','block-18329','Html_box','',1),(18335,'119004','deals-mobile','checkout_no_shipping_g','BlockBox','',1),(18336,'119005','deals-mobile','block-18335','quote\\Products','',3),(18337,'119006','deals-mobile','block-18335','BlockBox','',1),(18338,'119007','deals-mobile','block-18337','BlockBox','',1),(18339,'119008','deals-mobile','block-18338','checkout\\BillingAddress','',2),(18340,'119009','deals-mobile','block-18338','Html_box','',1),(18341,'119010','deals-mobile','block-18337-2','BlockBox','',1),(18342,'119011','deals-mobile','block-18341','checkout\\CreditAmount','',3),(18343,'119012','deals-mobile','block-18341','Html_box','',1),(18344,'119013','deals-mobile','block-18341','checkout\\PaymentMethod','',2),(18345,'119014','deals-mobile','block-18341','CouponsAndVauchers\\Checkout','',5),(18346,'119015','deals-mobile','block-18341','checkout\\BonusPoints','',4),(18347,'119016','deals-mobile','block-18335','BlockBox','',2),(18348,'119017','deals-mobile','block-18347','BlockBox','',1),(18349,'119018','deals-mobile','block-18348','Html_box','',1),(18350,'119019','deals-mobile','block-18348','checkout\\ContactInformation','',2),(18351,'119020','deals-mobile','block-18347-2','BlockBox','',1),(18352,'119021','deals-mobile','block-18351','Html_box','',1),(18353,'119022','deals-mobile','block-18351','checkout\\Comments','',2),(18354,'119023','deals-mobile','block-18335','BlockBox','',6),(18355,'119024','deals-mobile','block-18354','Html_box','',1),(18356,'119025','deals-mobile','block-18354-2','checkout\\ContinueBtn','',1),(18357,'119026','deals-mobile','block-18335','checkout\\Totals','',5),(18358,'119027','deals-mobile','checkout_no_shipping_q','BlockBox','',1),(18359,'119028','deals-mobile','block-18358','BlockBox','',2),(18360,'119029','deals-mobile','block-18359','BlockBox','',2),(18361,'119030','deals-mobile','block-18360','BlockBox','',3),(18362,'119031','deals-mobile','block-18361','BlockBox','',2),(18363,'119032','deals-mobile','block-18362','checkout\\BillingAddress','',2),(18364,'119033','deals-mobile','block-18362','Html_box','',1),(18365,'119034','deals-mobile','block-18362-2','BlockBox','',1),(18366,'119035','deals-mobile','block-18365','Html_box','',1),(18367,'119036','deals-mobile','block-18365','checkout\\PaymentMethod','',2),(18368,'119037','deals-mobile','block-18361','Html_box','',1),(18369,'119038','deals-mobile','block-18360','BlockBox','',6),(18370,'119039','deals-mobile','block-18369','checkout\\CreateAccount','',3),(18371,'119040','deals-mobile','block-18369','quote\\Products','',2),(18372,'119041','deals-mobile','block-18360','BlockBox','',5),(18373,'119042','deals-mobile','block-18372','checkout\\Comments','',2),(18374,'119043','deals-mobile','block-18372','Html_box','',1),(18375,'119044','deals-mobile','block-18360','checkout\\Gdpr','',1),(18376,'119045','deals-mobile','block-18359-2','BlockBox','',1),(18377,'119046','deals-mobile','block-18376','Html_box','',4),(18378,'119047','deals-mobile','block-18376','checkout\\Totals','',2),(18379,'119048','deals-mobile','block-18376','checkout\\ContinueBtn','',3),(18380,'119049','deals-mobile','block-18376','Html_box','',1),(18381,'119050','deals-mobile','checkout_payment','BlockBox','',2),(18382,'119051','deals-mobile','block-18381','Html_box','',1),(18383,'119052','deals-mobile','block-18381-2','checkout\\ContinueBtn','',1),(18384,'119053','deals-mobile','checkout_payment','BlockBox','',1),(18385,'119054','deals-mobile','block-18384','BlockBox','',1),(18386,'119055','deals-mobile','block-18385','checkout\\BillingAddress','',2),(18387,'119056','deals-mobile','block-18385','Html_box','',1),(18388,'119057','deals-mobile','block-18384-2','BlockBox','',1),(18389,'119058','deals-mobile','block-18388','checkout\\PaymentMethod','',2),(18390,'119059','deals-mobile','block-18388','Html_box','',1),(18391,'119060','deals-mobile','block-18388','checkout\\CreditAmount','',3),(18392,'119061','deals-mobile','block-18388','CouponsAndVauchers\\Checkout','',5),(18393,'119062','deals-mobile','block-18388','checkout\\BonusPoints','',4),(18394,'119063','deals-mobile','checkout_payment_g','BlockBox','',1),(18395,'119064','deals-mobile','block-18394','BlockBox','',1),(18396,'119065','deals-mobile','block-18395','Html_box','',1),(18397,'119066','deals-mobile','block-18395','checkout\\BillingAddress','',2),(18398,'119067','deals-mobile','block-18394-2','BlockBox','',1),(18399,'119068','deals-mobile','block-18398','checkout\\BonusPoints','',4),(18400,'119069','deals-mobile','block-18398','Html_box','',1),(18401,'119070','deals-mobile','block-18398','CouponsAndVauchers\\Checkout','',5),(18402,'119071','deals-mobile','block-18398','checkout\\CreditAmount','',3),(18403,'119072','deals-mobile','block-18398','checkout\\PaymentMethod','',2),(18404,'119073','deals-mobile','checkout_payment_g','BlockBox','',2),(18405,'119074','deals-mobile','block-18404','Html_box','',1),(18406,'119075','deals-mobile','block-18404-2','checkout\\ContinueBtn','',1),(18407,'119076','deals-mobile','checkout_payment_no_shipping','BlockBox','',1),(18408,'119077','deals-mobile','block-18407','BlockBox','',1),(18409,'119078','deals-mobile','block-18408','Html_box','',1),(18410,'119079','deals-mobile','block-18408','checkout\\BillingAddress','',2),(18411,'119080','deals-mobile','block-18407-2','BlockBox','',1),(18412,'119081','deals-mobile','block-18411','Html_box','',1),(18413,'119082','deals-mobile','block-18411','checkout\\PaymentMethod','',2),(18414,'119083','deals-mobile','block-18411','checkout\\CreditAmount','',3),(18415,'119084','deals-mobile','block-18411','CouponsAndVauchers\\Checkout','',5),(18416,'119085','deals-mobile','block-18411','checkout\\BonusPoints','',4),(18417,'119086','deals-mobile','checkout_payment_no_shipping','BlockBox','',2),(18418,'119087','deals-mobile','block-18417','Html_box','',1),(18419,'119088','deals-mobile','block-18417-2','checkout\\ContinueBtn','',1),(18420,'119089','deals-mobile','checkout_payment_no_shipping_g','BlockBox','',2),(18421,'119090','deals-mobile','block-18420','Html_box','',1),(18422,'119091','deals-mobile','block-18420-2','checkout\\ContinueBtn','',1),(18423,'119092','deals-mobile','checkout_payment_no_shipping_g','BlockBox','',1),(18424,'119093','deals-mobile','block-18423','BlockBox','',1),(18425,'119094','deals-mobile','block-18424','checkout\\BillingAddress','',2),(18426,'119095','deals-mobile','block-18424','Html_box','',1),(18427,'119096','deals-mobile','block-18423-2','BlockBox','',1),(18428,'119097','deals-mobile','block-18427','checkout\\PaymentMethod','',2),(18429,'119098','deals-mobile','block-18427','Html_box','',1),(18430,'119099','deals-mobile','block-18427','checkout\\CreditAmount','',3),(18431,'119100','deals-mobile','block-18427','CouponsAndVauchers\\Checkout','',5),(18432,'119101','deals-mobile','block-18427','checkout\\BonusPoints','',4),(18433,'119102','deals-mobile','checkout_payment_title','Html_box','',1),(18434,'119103','deals-mobile','checkout_payment_title_g','Html_box','',1),(18435,'119104','deals-mobile','checkout_payment_title_no_shipping','Html_box','',1),(18436,'119105','deals-mobile','checkout_payment_title_no_shipping_g','Html_box','',1),(18437,'119106','deals-mobile','checkout_payment_title_q','Html_box','',1),(18438,'119107','deals-mobile','checkout_payment_title_s','Html_box','',1),(18439,'119108','deals-mobile','checkout_q','BlockBox','',1),(18440,'119109','deals-mobile','block-18439','BlockBox','',2),(18441,'119110','deals-mobile','block-18440','BlockBox','',2),(18442,'119111','deals-mobile','block-18441','BlockBox','',3),(18443,'119112','deals-mobile','block-18442','BlockBox','',2),(18444,'119113','deals-mobile','block-18443','checkout\\BillingAddress','',2),(18445,'119114','deals-mobile','block-18443','Html_box','',1),(18446,'119115','deals-mobile','block-18443-2','BlockBox','',1),(18447,'119116','deals-mobile','block-18446','Html_box','',1),(18448,'119117','deals-mobile','block-18446','checkout\\PaymentMethod','',2),(18449,'119118','deals-mobile','block-18442','Html_box','',1),(18450,'119119','deals-mobile','block-18441','BlockBox','',5),(18451,'119120','deals-mobile','block-18450','Html_box','',1),(18452,'119121','deals-mobile','block-18450','checkout\\Comments','',2),(18453,'119122','deals-mobile','block-18441','checkout\\Gdpr','',1),(18454,'119123','deals-mobile','block-18441','BlockBox','',2),(18455,'119124','deals-mobile','block-18454','BlockBox','',3),(18456,'119125','deals-mobile','block-18455','BlockBox','',1),(18457,'119126','deals-mobile','block-18456','Html_box','',3),(18458,'119127','deals-mobile','block-18456','checkout\\ShippingAddress','',2),(18459,'119128','deals-mobile','block-18456','checkout\\ContactInformation','',4),(18460,'119129','deals-mobile','block-18455-2','BlockBox','',1),(18461,'119130','deals-mobile','block-18460','DelayedDespatch\\Checkout','',3),(18462,'119131','deals-mobile','block-18460','Html_box','',1),(18463,'119132','deals-mobile','block-18460','checkout\\Shipping','',2),(18464,'119133','deals-mobile','block-18454','Html_box','',1),(18465,'119134','deals-mobile','block-18454','Neighbour\\Checkout','',4),(18466,'119135','deals-mobile','block-18454','BlockBox','',2),(18467,'119136','deals-mobile','block-18466','checkout\\ShippingChoice','',1),(18468,'119137','deals-mobile','block-18441','BlockBox','',6),(18469,'119138','deals-mobile','block-18468','quote\\Products','',2),(18470,'119139','deals-mobile','block-18468','checkout\\CreateAccount','',3),(18471,'119140','deals-mobile','block-18440-2','BlockBox','',1),(18472,'119141','deals-mobile','block-18471','checkout\\ContinueBtn','',3),(18473,'119142','deals-mobile','block-18471','checkout\\Totals','',2),(18474,'119143','deals-mobile','block-18471','Html_box','',4),(18475,'119144','deals-mobile','block-18471','Html_box','',1),(18476,'119145','deals-mobile','checkout_s','BlockBox','',1),(18477,'119146','deals-mobile','block-18476','BlockBox','',2),(18478,'119147','deals-mobile','block-18477','BlockBox','',2),(18479,'119148','deals-mobile','block-18478','BlockBox','',4),(18480,'119149','deals-mobile','block-18479','BlockBox','',2),(18481,'119150','deals-mobile','block-18480','CouponsAndVauchers\\Checkout','',1),(18482,'119151','deals-mobile','block-18480-2','checkout\\CreditAmount','',1),(18483,'119152','deals-mobile','block-18480-2','checkout\\BonusPoints','',2),(18484,'119153','deals-mobile','block-18479','Html_box','',1),(18485,'119154','deals-mobile','block-18478','BlockBox','',3),(18486,'119155','deals-mobile','block-18485','Html_box','',1),(18487,'119156','deals-mobile','block-18485','BlockBox','',2),(18488,'119157','deals-mobile','block-18487','checkout\\BillingAddress','',2),(18489,'119158','deals-mobile','block-18487','Html_box','',1),(18490,'119159','deals-mobile','block-18487-2','BlockBox','',1),(18491,'119160','deals-mobile','block-18490','checkout\\PaymentMethod','',2),(18492,'119161','deals-mobile','block-18490','Html_box','',1),(18493,'119162','deals-mobile','block-18478','BlockBox','',5),(18494,'119163','deals-mobile','block-18493','checkout\\Comments','',2),(18495,'119164','deals-mobile','block-18493','Html_box','',1),(18496,'119165','deals-mobile','block-18478','BlockBox','',2),(18497,'119166','deals-mobile','block-18496','BlockBox','',2),(18498,'119167','deals-mobile','block-18497','checkout\\ShippingChoice','',1),(18499,'119168','deals-mobile','block-18496','Html_box','',1),(18500,'119169','deals-mobile','block-18496','BlockBox','',3),(18501,'119170','deals-mobile','block-18500','BlockBox','',1),(18502,'119171','deals-mobile','block-18501','checkout\\ShippingAddress','',2),(18503,'119172','deals-mobile','block-18501','Html_box','',3),(18504,'119173','deals-mobile','block-18501','checkout\\ContactInformation','',4),(18505,'119174','deals-mobile','block-18500-2','BlockBox','',1),(18506,'119175','deals-mobile','block-18505','DelayedDespatch\\Checkout','',3),(18507,'119176','deals-mobile','block-18505','Html_box','',1),(18508,'119177','deals-mobile','block-18505','checkout\\Shipping','',2),(18509,'119178','deals-mobile','block-18496','Neighbour\\Checkout','',4),(18510,'119179','deals-mobile','block-18478','BlockBox','',6),(18511,'119180','deals-mobile','block-18510','checkout\\CreateAccount','',3),(18512,'119181','deals-mobile','block-18510','sample\\Products','',1),(18513,'119182','deals-mobile','block-18478','checkout\\Gdpr','',1),(18514,'119183','deals-mobile','block-18477-2','BlockBox','',1),(18515,'119184','deals-mobile','block-18514','Html_box','',1),(18516,'119185','deals-mobile','block-18514','checkout\\ContinueBtn','',3),(18517,'119186','deals-mobile','block-18514','Html_box','',4),(18518,'119187','deals-mobile','block-18514','checkout\\Totals','',2),(18519,'119188','deals-mobile','checkout_step_bottom','cart\\Products','',2),(18520,'119189','deals-mobile','checkout_step_bottom','checkout\\Totals','',3),(18521,'119190','deals-mobile','checkout_step_bottom','Html_box','',1),(18522,'119191','deals-mobile','checkout_step_bottom_g','checkout\\Totals','',3),(18523,'119192','deals-mobile','checkout_step_bottom_g','quote\\Products','',2),(18524,'119193','deals-mobile','checkout_step_bottom_g','Html_box','',1),(18525,'119194','deals-mobile','checkout_step_bottom_no_shipping_g','Html_box','',1),(18526,'119195','deals-mobile','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(18527,'119196','deals-mobile','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(18528,'119197','deals-mobile','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(18529,'119198','deals-mobile','checkout_step_bottom_no_shipping','Html_box','',1),(18530,'119199','deals-mobile','checkout_step_bottom_no_shipping','cart\\Products','',2),(18531,'119200','deals-mobile','communication','BlockBox','',1),(18532,'119201','deals-mobile','block-18531','Html_box','',2),(18533,'119202','deals-mobile','block-18531','Communication\\Topic','',3),(18534,'119203','deals-mobile','block-18531','Communication\\NewTopicButton','',1),(18535,'119204','deals-mobile','compare','BlockBox','',1),(18536,'119205','deals-mobile','block-18535','catalog\\Compare','',1),(18537,'119206','deals-mobile','compare_products','BlockBox','',2),(18538,'119207','deals-mobile','block-18537','productListing\\rating','',4),(18539,'119208','deals-mobile','block-18537','productListing\\model','',5),(18540,'119209','deals-mobile','block-18537','productListing\\compare','',1),(18541,'119210','deals-mobile','block-18537','BlockBox','',2),(18542,'119211','deals-mobile','block-18541','productListing\\image','',1),(18543,'119212','deals-mobile','block-18541-2','productListing\\name','',2),(18544,'119213','deals-mobile','block-18537','BlockBox','',3),(18545,'119214','deals-mobile','block-18544','productListing\\price','',1),(18546,'119215','deals-mobile','block-18544-2','productListing\\buyButton','',1),(18547,'119216','deals-mobile','confirmation','BlockBox','',1),(18548,'119217','deals-mobile','block-18547','BlockBox','',2),(18549,'119218','deals-mobile','block-18548','UploadCustomerId\\UploadCustomerIdForm','',1),(18550,'119219','deals-mobile','block-18548','BlockBox','',2),(18551,'119220','deals-mobile','block-18550','BlockBox','',1),(18552,'119221','deals-mobile','block-18551','BlockBox','',1),(18553,'119222','deals-mobile','block-18552','checkout\\ShippingAddressConfirm','',4),(18554,'119223','deals-mobile','block-18552','Html_box','',1),(18555,'119224','deals-mobile','block-18552','Html_box','',2),(18556,'119225','deals-mobile','block-18552','checkout\\ContactConfirm','',11),(18557,'119226','deals-mobile','block-18552','checkout\\EditBtn','',3),(18558,'119227','deals-mobile','block-18552','Html_box','',5),(18559,'119228','deals-mobile','block-18552','DelayedDespatch\\CheckoutConfirm','',8),(18560,'119229','deals-mobile','block-18552','checkout\\EditBtn','',10),(18561,'119230','deals-mobile','block-18552','checkout\\EditBtn','',6),(18562,'119231','deals-mobile','block-18552','Html_box','',9),(18563,'119232','deals-mobile','block-18552','checkout\\ShippingConfirm','',7),(18564,'119233','deals-mobile','block-18551','BlockBox','',2),(18565,'119234','deals-mobile','block-18564','Html_box','',2),(18566,'119235','deals-mobile','block-18564','checkout\\BillingAddressConfirm','',4),(18567,'119236','deals-mobile','block-18564','Html_box','',5),(18568,'119237','deals-mobile','block-18564','checkout\\PaymentMethodConfirm','',7),(18569,'119238','deals-mobile','block-18564','Html_box','',1),(18570,'119239','deals-mobile','block-18564','checkout\\EditBtn','',3),(18571,'119240','deals-mobile','block-18564','checkout\\EditBtn','',6),(18572,'119241','deals-mobile','block-18550','BlockBox','',3),(18573,'119242','deals-mobile','block-18572','Html_box','',1),(18574,'119243','deals-mobile','block-18572','checkout\\EditBtn','',2),(18575,'119244','deals-mobile','block-18572','cart\\Products','',3),(18576,'119245','deals-mobile','block-18550','BlockBox','',2),(18577,'119246','deals-mobile','block-18576','Html_box','',1),(18578,'119247','deals-mobile','block-18576','checkout\\CommentsConfirm','',3),(18579,'119248','deals-mobile','block-18576','checkout\\EditBtn','',2),(18580,'119249','deals-mobile','block-18550','BlockBox','',4),(18581,'119250','deals-mobile','block-18580','checkout\\Totals','',2),(18582,'119251','deals-mobile','block-18580','Html_box','',1),(18583,'119252','deals-mobile','block-18580','checkout\\ConfirmBtn','',3),(18584,'119253','deals-mobile','block-18547','Html_box','',1),(18585,'119254','deals-mobile','confirmation_free_s','BlockBox','',1),(18586,'119255','deals-mobile','block-18585','Html_box','',1),(18587,'119256','deals-mobile','block-18585','BlockBox','',2),(18588,'119257','deals-mobile','block-18587','BlockBox','',1),(18589,'119258','deals-mobile','block-18588','BlockBox','',1),(18590,'119259','deals-mobile','block-18589','BlockBox','',1),(18591,'119260','deals-mobile','block-18590','checkout\\EditBtn','',6),(18592,'119261','deals-mobile','block-18590','checkout\\ShippingAddressConfirm','',4),(18593,'119262','deals-mobile','block-18590','Html_box','',2),(18594,'119263','deals-mobile','block-18590','checkout\\ShippingConfirm','',7),(18595,'119264','deals-mobile','block-18590','checkout\\EditBtn','',3),(18596,'119265','deals-mobile','block-18590','Html_box','',5),(18597,'119266','deals-mobile','block-18589-2','BlockBox','',1),(18598,'119267','deals-mobile','block-18597','Html_box','',1),(18599,'119268','deals-mobile','block-18597','checkout\\EditBtn','',2),(18600,'119269','deals-mobile','block-18597','DelayedDespatch\\CheckoutConfirm','',4),(18601,'119270','deals-mobile','block-18597','checkout\\ContactConfirm','',3),(18602,'119271','deals-mobile','block-18588','BlockBox','',2),(18603,'119272','deals-mobile','block-18602','checkout\\CommentsConfirm','',3),(18604,'119273','deals-mobile','block-18602','checkout\\EditBtn','',2),(18605,'119274','deals-mobile','block-18602','Html_box','',1),(18606,'119275','deals-mobile','block-18588','BlockBox','',3),(18607,'119276','deals-mobile','block-18606','sample\\Products','',2),(18608,'119277','deals-mobile','block-18606','Html_box','',1),(18609,'119278','deals-mobile','block-18606','checkout\\EditBtn','',3),(18610,'119279','deals-mobile','block-18587-2','BlockBox','',1),(18611,'119280','deals-mobile','block-18610','checkout\\ConfirmBtn','',3),(18612,'119281','deals-mobile','confirmation_no_shipping','BlockBox','',1),(18613,'119282','deals-mobile','block-18612','Html_box','',1),(18614,'119283','deals-mobile','block-18612','BlockBox','',2),(18615,'119284','deals-mobile','block-18614','BlockBox','',1),(18616,'119285','deals-mobile','block-18615','BlockBox','',3),(18617,'119286','deals-mobile','block-18616','checkout\\EditBtn','',2),(18618,'119287','deals-mobile','block-18616','Html_box','',1),(18619,'119288','deals-mobile','block-18616','cart\\Products','',3),(18620,'119289','deals-mobile','block-18615','BlockBox','',2),(18621,'119290','deals-mobile','block-18620','checkout\\EditBtn','',2),(18622,'119291','deals-mobile','block-18620','checkout\\CommentsConfirm','',3),(18623,'119292','deals-mobile','block-18620','Html_box','',1),(18624,'119293','deals-mobile','block-18615','BlockBox','',1),(18625,'119294','deals-mobile','block-18624','BlockBox','',1),(18626,'119295','deals-mobile','block-18625','Html_box','',9),(18627,'119296','deals-mobile','block-18625','checkout\\ContactConfirm','',11),(18628,'119297','deals-mobile','block-18625','checkout\\EditBtn','',10),(18629,'119298','deals-mobile','block-18624-2','BlockBox','',1),(18630,'119299','deals-mobile','block-18629','checkout\\EditBtn','',3),(18631,'119300','deals-mobile','block-18629','Html_box','',2),(18632,'119301','deals-mobile','block-18629','Html_box','',1),(18633,'119302','deals-mobile','block-18629','Html_box','',5),(18634,'119303','deals-mobile','block-18629','checkout\\BillingAddressConfirm','',4),(18635,'119304','deals-mobile','block-18629','checkout\\PaymentMethodConfirm','',7),(18636,'119305','deals-mobile','block-18629','checkout\\EditBtn','',6),(18637,'119306','deals-mobile','block-18614-2','BlockBox','',1),(18638,'119307','deals-mobile','block-18637','checkout\\ConfirmBtn','',3),(18639,'119308','deals-mobile','block-18637','checkout\\Totals','',2),(18640,'119309','deals-mobile','block-18637','Html_box','',1),(18641,'119310','deals-mobile','confirmation_no_shipping_q','BlockBox','',2),(18642,'119311','deals-mobile','block-18641','BlockBox','',2),(18643,'119312','deals-mobile','block-18642','BlockBox','',1),(18644,'119313','deals-mobile','block-18643','BlockBox','',3),(18645,'119314','deals-mobile','block-18644','quote\\Products','',3),(18646,'119315','deals-mobile','block-18644','checkout\\EditBtn','',2),(18647,'119316','deals-mobile','block-18644','Html_box','',1),(18648,'119317','deals-mobile','block-18643','BlockBox','',1),(18649,'119318','deals-mobile','block-18648','BlockBox','',1),(18650,'119319','deals-mobile','block-18649','checkout\\EditBtn','',2),(18651,'119320','deals-mobile','block-18649','Html_box','',1),(18652,'119321','deals-mobile','block-18649','Html_box','',4),(18653,'119322','deals-mobile','block-18649','checkout\\PaymentMethodConfirm','',3),(18654,'119323','deals-mobile','block-18649','checkout\\EditBtn','',5),(18655,'119324','deals-mobile','block-18649','checkout\\ContactConfirm','',6),(18656,'119325','deals-mobile','block-18648-2','BlockBox','',1),(18657,'119326','deals-mobile','block-18656','Html_box','',2),(18658,'119327','deals-mobile','block-18656','checkout\\EditBtn','',3),(18659,'119328','deals-mobile','block-18656','checkout\\BillingAddressConfirm','',4),(18660,'119329','deals-mobile','block-18643','BlockBox','',2),(18661,'119330','deals-mobile','block-18660','checkout\\CommentsConfirm','',3),(18662,'119331','deals-mobile','block-18660','Html_box','',1),(18663,'119332','deals-mobile','block-18660','checkout\\EditBtn','',2),(18664,'119333','deals-mobile','block-18642-2','BlockBox','',1),(18665,'119334','deals-mobile','block-18664','Html_box','',1),(18666,'119335','deals-mobile','block-18664','checkout\\Totals','',2),(18667,'119336','deals-mobile','block-18664','checkout\\ConfirmBtn','',3),(18668,'119337','deals-mobile','block-18641','Html_box','',1),(18669,'119338','deals-mobile','confirmation_q','BlockBox','',1),(18670,'119339','deals-mobile','block-18669','Html_box','',1),(18671,'119340','deals-mobile','block-18669','BlockBox','',2),(18672,'119341','deals-mobile','block-18671','BlockBox','',1),(18673,'119342','deals-mobile','block-18672','BlockBox','',3),(18674,'119343','deals-mobile','block-18673','checkout\\EditBtn','',2),(18675,'119344','deals-mobile','block-18673','Html_box','',1),(18676,'119345','deals-mobile','block-18673','quote\\Products','',3),(18677,'119346','deals-mobile','block-18672','BlockBox','',2),(18678,'119347','deals-mobile','block-18677','checkout\\EditBtn','',2),(18679,'119348','deals-mobile','block-18677','checkout\\CommentsConfirm','',3),(18680,'119349','deals-mobile','block-18677','Html_box','',1),(18681,'119350','deals-mobile','block-18672','BlockBox','',1),(18682,'119351','deals-mobile','block-18681','BlockBox','',1),(18683,'119352','deals-mobile','block-18682','Html_box','',5),(18684,'119353','deals-mobile','block-18682','Html_box','',9),(18685,'119354','deals-mobile','block-18682','checkout\\EditBtn','',6),(18686,'119355','deals-mobile','block-18682','checkout\\ShippingConfirm','',7),(18687,'119356','deals-mobile','block-18682','checkout\\EditBtn','',3),(18688,'119357','deals-mobile','block-18682','DelayedDespatch\\CheckoutConfirm','',8),(18689,'119358','deals-mobile','block-18682','checkout\\ShippingAddressConfirm','',4),(18690,'119359','deals-mobile','block-18682','checkout\\ContactConfirm','',11),(18691,'119360','deals-mobile','block-18682','checkout\\EditBtn','',10),(18692,'119361','deals-mobile','block-18682','Html_box','',2),(18693,'119362','deals-mobile','block-18682','Html_box','',1),(18694,'119363','deals-mobile','block-18681-2','BlockBox','',1),(18695,'119364','deals-mobile','block-18694','Html_box','',1),(18696,'119365','deals-mobile','block-18694','Html_box','',2),(18697,'119366','deals-mobile','block-18694','checkout\\PaymentMethodConfirm','',7),(18698,'119367','deals-mobile','block-18694','Html_box','',5),(18699,'119368','deals-mobile','block-18694','checkout\\BillingAddressConfirm','',4),(18700,'119369','deals-mobile','block-18694','checkout\\EditBtn','',6),(18701,'119370','deals-mobile','block-18694','checkout\\EditBtn','',3),(18702,'119371','deals-mobile','block-18671-2','BlockBox','',1),(18703,'119372','deals-mobile','block-18702','checkout\\ConfirmBtn','',3),(18704,'119373','deals-mobile','block-18702','Html_box','',1),(18705,'119374','deals-mobile','block-18702','checkout\\Totals','',2),(18706,'119375','deals-mobile','confirmation_s','BlockBox','',1),(18707,'119376','deals-mobile','block-18706','Html_box','',1),(18708,'119377','deals-mobile','block-18706','BlockBox','',2),(18709,'119378','deals-mobile','block-18708','BlockBox','',1),(18710,'119379','deals-mobile','block-18709','BlockBox','',2),(18711,'119380','deals-mobile','block-18710','checkout\\CommentsConfirm','',3),(18712,'119381','deals-mobile','block-18710','checkout\\EditBtn','',2),(18713,'119382','deals-mobile','block-18710','Html_box','',1),(18714,'119383','deals-mobile','block-18709','BlockBox','',3),(18715,'119384','deals-mobile','block-18714','sample\\Products','',2),(18716,'119385','deals-mobile','block-18714','Html_box','',1),(18717,'119386','deals-mobile','block-18714','checkout\\EditBtn','',3),(18718,'119387','deals-mobile','block-18709','BlockBox','',1),(18719,'119388','deals-mobile','block-18718','BlockBox','',1),(18720,'119389','deals-mobile','block-18719','Html_box','',9),(18721,'119390','deals-mobile','block-18719','checkout\\ContactConfirm','',11),(18722,'119391','deals-mobile','block-18719','checkout\\EditBtn','',6),(18723,'119392','deals-mobile','block-18719','checkout\\EditBtn','',10),(18724,'119393','deals-mobile','block-18719','Html_box','',1),(18725,'119394','deals-mobile','block-18719','DelayedDespatch\\CheckoutConfirm','',8),(18726,'119395','deals-mobile','block-18719','checkout\\EditBtn','',3),(18727,'119396','deals-mobile','block-18719','checkout\\ShippingAddressConfirm','',4),(18728,'119397','deals-mobile','block-18719','Html_box','',5),(18729,'119398','deals-mobile','block-18719','Html_box','',2),(18730,'119399','deals-mobile','block-18719','checkout\\ShippingConfirm','',7),(18731,'119400','deals-mobile','block-18718-2','BlockBox','',1),(18732,'119401','deals-mobile','block-18731','Html_box','',5),(18733,'119402','deals-mobile','block-18731','Html_box','',1),(18734,'119403','deals-mobile','block-18731','checkout\\EditBtn','',6),(18735,'119404','deals-mobile','block-18731','checkout\\BillingAddressConfirm','',4),(18736,'119405','deals-mobile','block-18731','checkout\\EditBtn','',3),(18737,'119406','deals-mobile','block-18731','Html_box','',2),(18738,'119407','deals-mobile','block-18731','checkout\\PaymentMethodConfirm','',7),(18739,'119408','deals-mobile','block-18708-2','BlockBox','',1),(18740,'119409','deals-mobile','block-18739','checkout\\Totals','',2),(18741,'119410','deals-mobile','block-18739','Html_box','',1),(18742,'119411','deals-mobile','block-18739','checkout\\ConfirmBtn','',3),(18743,'119412','deals-mobile','contact','BlockBox','',1),(18744,'119413','deals-mobile','block-18743','BlockBox','',4),(18745,'119414','deals-mobile','block-18744','contact\\Map','',1),(18746,'119415','deals-mobile','block-18744-2','contact\\StreetView','',1),(18747,'119416','deals-mobile','block-18743','BlockBox','',3),(18748,'119417','deals-mobile','block-18747','contact\\ContactForm','',1),(18749,'119418','deals-mobile','block-18747-2','contact\\Contacts','',1),(18750,'119419','deals-mobile','block-18743','info\\Title','',1),(18751,'119420','deals-mobile','created_success','BlockBox','',1),(18752,'119421','deals-mobile','block-18751','Html_box','',2),(18753,'119422','deals-mobile','block-18751','Html_box','',1),(18754,'119423','deals-mobile','credit_note','invoice\\Container','',1),(18755,'119424','deals-mobile','block-18754','BlockBox','',2),(18756,'119425','deals-mobile','block-18755','BlockBox','',8),(18757,'119426','deals-mobile','block-18756','BlockBox','',1),(18758,'119427','deals-mobile','block-18757','Text','',1),(18759,'119428','deals-mobile','block-18757','invoice\\ShippingMethod','',2),(18760,'119429','deals-mobile','block-18756-2','BlockBox','',1),(18761,'119430','deals-mobile','block-18760','invoice\\ShippingMethod','',2),(18762,'119431','deals-mobile','block-18760','Text','',1),(18763,'119432','deals-mobile','block-18755','BlockBox','',7),(18764,'119433','deals-mobile','block-18763','BlockBox','',1),(18765,'119434','deals-mobile','block-18764','invoice\\BillingAddress','',2),(18766,'119435','deals-mobile','block-18764','Text','',1),(18767,'119436','deals-mobile','block-18763-2','BlockBox','',1),(18768,'119437','deals-mobile','block-18767','Text','',5),(18769,'119438','deals-mobile','block-18767','invoice\\CustomerName','',2),(18770,'119439','deals-mobile','block-18767','invoice\\CustomerEmail','',6),(18771,'119440','deals-mobile','block-18767','Text','',3),(18772,'119441','deals-mobile','block-18767','Text','',1),(18773,'119442','deals-mobile','block-18767','invoice\\CustomerPhone','',4),(18774,'119443','deals-mobile','block-18755-2','invoice\\PaymentDate','',3),(18775,'119444','deals-mobile','block-18755-2','Text','',2),(18776,'119445','deals-mobile','block-18755-2','invoice\\OrderId','',1),(18777,'119446','deals-mobile','block-18754','BlockBox','',4),(18778,'119447','deals-mobile','block-18777','BlockBox','',1),(18779,'119448','deals-mobile','block-18778','Text','',1),(18780,'119449','deals-mobile','block-18778','invoice\\ShippingAddress','',2),(18781,'119450','deals-mobile','block-18777-2','BlockBox','',1),(18782,'119451','deals-mobile','block-18754','BlockBox','',1),(18783,'119452','deals-mobile','block-18782','Logo','',1),(18784,'119453','deals-mobile','block-18782-2','BlockBox','',1),(18785,'119454','deals-mobile','block-18784','invoice\\StoreAddress','',1),(18786,'119455','deals-mobile','block-18782-2','BlockBox','',3),(18787,'119456','deals-mobile','block-18786','Text','',1),(18788,'119457','deals-mobile','block-18786-2','invoice\\StoreEmail','',1),(18789,'119458','deals-mobile','block-18782-2','BlockBox','',2),(18790,'119459','deals-mobile','block-18789','Text','',1),(18791,'119460','deals-mobile','block-18789-2','invoice\\StorePhone','',1),(18792,'119461','deals-mobile','block-18782-2','BlockBox','',4),(18793,'119462','deals-mobile','block-18792','Text','',1),(18794,'119463','deals-mobile','block-18792-2','invoice\\StoreSite','',1),(18795,'119464','deals-mobile','block-18754','invoice\\Products','',3),(18796,'119465','deals-mobile','block-18754','BlockBox','',5),(18797,'119466','deals-mobile','block-18796','invoice\\StoreAddress','',8),(18798,'119467','deals-mobile','block-18796','Text','',1),(18799,'119468','deals-mobile','block-18796-2','Text','',2),(18800,'119469','deals-mobile','block-18796-2','Logo','',1),(18801,'119470','deals-mobile','block-18796-3','BlockBox','',2),(18802,'119471','deals-mobile','block-18801','Text','',1),(18803,'119472','deals-mobile','block-18801-2','invoice\\StorePhone','',1),(18804,'119473','deals-mobile','block-18796-3','BlockBox','',3),(18805,'119474','deals-mobile','block-18804','Text','',1),(18806,'119475','deals-mobile','block-18804-2','invoice\\StoreEmail','',1),(18807,'119476','deals-mobile','block-18796-3','Text','',1),(18808,'119477','deals-mobile','delivery-location','DeliveryLocation\\LocationProducts','',8),(18809,'119478','deals-mobile','delivery-location','DeliveryLocation\\LocationLongDescription','',5),(18810,'119479','deals-mobile','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(18811,'119480','deals-mobile','delivery-location','DeliveryLocation\\LocationDescription','',3),(18812,'119481','deals-mobile','delivery-location','DeliveryLocation\\FeaturedList','',6),(18813,'119482','deals-mobile','delivery-location','DeliveryLocation\\LocationList','',7),(18814,'119483','deals-mobile','delivery-location','DeliveryLocation\\LocationTitle','',2),(18815,'119484','deals-mobile','delivery-location-default','DeliveryLocation\\TopLocationList','',2),(18816,'119485','deals-mobile','delivery-location-default','Heading','',1),(18817,'119486','deals-mobile','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(18818,'119487','deals-mobile','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(18819,'119488','deals-mobile','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(18820,'119489','deals-mobile','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(18821,'119490','deals-mobile','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(18822,'119491','deals-mobile','delivery_loc_2','DeliveryLocation\\LocationList','',7),(18823,'119492','deals-mobile','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(18824,'119493','deals-mobile','email','email\\Content','',3),(18825,'119494','deals-mobile','email','email\\BlockBox','',1),(18826,'119495','deals-mobile','block-18825','Logo','logo-2.png',1),(18827,'119496','deals-mobile','email','Copyright','',7),(18828,'119497','deals-mobile','email','email\\BlockBox','',4),(18829,'119498','deals-mobile','email','Text','',5),(18830,'119499','deals-mobile','email','email\\BlockBox','',2),(18831,'119500','deals-mobile','block-18830','email\\Title','',1),(18832,'119501','deals-mobile','block-18830-2','email\\Date','',1),(18833,'119502','deals-mobile','email_2','email\\BlockBox','',1),(18834,'119503','deals-mobile','block-18833','email\\BlockBox','',1),(18835,'119504','deals-mobile','block-18834','email\\Content','',3),(18836,'119505','deals-mobile','block-18834','email\\BlockBox','',2),(18837,'119506','deals-mobile','block-18836','email\\Title','',1),(18838,'119507','deals-mobile','block-18836-2','email\\Date','',1),(18839,'119508','deals-mobile','block-18834','Copyright','',4),(18840,'119509','deals-mobile','block-18834','Logo','',1),(18841,'119510','deals-mobile','email_3','email\\BlockBox','',1),(18842,'119511','deals-mobile','block-18841','email\\BlockBox','',1),(18843,'119512','deals-mobile','block-18842','Logo','',1),(18844,'119513','deals-mobile','block-18842','Copyright','',3),(18845,'119514','deals-mobile','block-18842','email\\BlockBox','',2),(18846,'119515','deals-mobile','block-18845','email\\BlockBox','',1),(18847,'119516','deals-mobile','block-18846','email\\Title','',1),(18848,'119517','deals-mobile','block-18846-2','email\\Date','',1),(18849,'119518','deals-mobile','block-18845','email\\Content','',2),(18850,'119519','deals-mobile','email_4','email\\BlockBox','',1),(18851,'119520','deals-mobile','block-18850','email\\BlockBox','',1),(18852,'119521','deals-mobile','block-18851','email\\BlockBox','',1),(18853,'119522','deals-mobile','block-18852','email\\Content','',2),(18854,'119523','deals-mobile','block-18852','email\\BlockBox','',1),(18855,'119524','deals-mobile','block-18854','Logo','',1),(18856,'119525','deals-mobile','block-18854-2','email\\Title','',1),(18857,'119526','deals-mobile','block-18854-2','email\\Date','',2),(18858,'119527','deals-mobile','block-18851','Copyright','',2),(18859,'119528','deals-mobile','footer','BlockBox','',1),(18860,'119529','deals-mobile','block-18859','BlockBox','',4),(18861,'119530','deals-mobile','block-18860','Text','',1),(18862,'119531','deals-mobile','block-18860','Menu','footer3',2),(18863,'119532','deals-mobile','block-18859','Copyright','',10),(18864,'119533','deals-mobile','block-18859','BlockBox','',2),(18865,'119534','deals-mobile','block-18864','Menu','footer2',2),(18866,'119535','deals-mobile','block-18864','Text','',1),(18867,'119536','deals-mobile','block-18859','BlockBox','',3),(18868,'119537','deals-mobile','block-18867','Text','',1),(18869,'119538','deals-mobile','block-18867','Menu','footer1',2),(18870,'119539','deals-mobile','block-18859','BlockBox','',1),(18871,'119540','deals-mobile','block-18870','Contacts','',2),(18872,'119541','deals-mobile','block-18870','Text','',1),(18873,'119542','deals-mobile','for_menu','BlockBox','',1),(18874,'119543','deals-mobile','block-18873','Html_box','',1),(18875,'119544','deals-mobile','block-18873-2','Languages','',1),(18876,'119545','deals-mobile','for_menu','BlockBox','',3),(18877,'119546','deals-mobile','block-18876','Html_box','',1),(18878,'119547','deals-mobile','block-18876-2','Currencies','',1),(18879,'119548','deals-mobile','gift','BlockBox','',1),(18880,'119549','deals-mobile','block-18879','BlockBox','',3),(18881,'119550','deals-mobile','block-18880','BlockBox','',1),(18882,'119551','deals-mobile','block-18881','BlockBox','',1),(18883,'119552','deals-mobile','block-18882','BlockBox','',9),(18884,'119553','deals-mobile','block-18883','Text','',1),(18885,'119554','deals-mobile','block-18883','invoice\\StoreEmail','',3),(18886,'119555','deals-mobile','block-18883','invoice\\StorePhone','',2),(18887,'119556','deals-mobile','block-18882','Text','',6),(18888,'119557','deals-mobile','block-18882','Text','',4),(18889,'119558','deals-mobile','block-18882','Text','',7),(18890,'119559','deals-mobile','block-18882','Text','',2),(18891,'119560','deals-mobile','block-18882','BlockBox','',8),(18892,'119561','deals-mobile','block-18891','Text','',1),(18893,'119562','deals-mobile','block-18891-2','gift\\CodeView','',1),(18894,'119563','deals-mobile','block-18882','gift\\MessageView','',5),(18895,'119564','deals-mobile','block-18882','gift\\AmountView','',3),(18896,'119565','deals-mobile','block-18882','Text','',1),(18897,'119566','deals-mobile','block-18880-2','gift\\Form','',2),(18898,'119567','deals-mobile','block-18880-2','Text','',1),(18899,'119568','deals-mobile','block-18879','info\\Title','',1),(18900,'119569','deals-mobile','gift_card','BlockBox','',1),(18901,'119570','deals-mobile','block-18900','Text','',9),(18902,'119571','deals-mobile','block-18900','Text','',4),(18903,'119572','deals-mobile','block-18900','Logo','',1),(18904,'119573','deals-mobile','block-18900','Image','',2),(18905,'119574','deals-mobile','block-18900','Text','',6),(18906,'119575','deals-mobile','block-18900','gift\\AmountView','',5),(18907,'119576','deals-mobile','block-18900','gift\\MessageView','',7),(18908,'119577','deals-mobile','block-18900','BlockBox','',10),(18909,'119578','deals-mobile','block-18908','Text','',1),(18910,'119579','deals-mobile','block-18908-2','gift\\CodeView','',1),(18911,'119580','deals-mobile','block-18900','Text','',3),(18912,'119581','deals-mobile','block-18900','Text','',8),(18913,'119582','deals-mobile','block-18900','BlockBox','',11),(18914,'119583','deals-mobile','block-18913','invoice\\StorePhone','',2),(18915,'119584','deals-mobile','block-18913','Text','',1),(18916,'119585','deals-mobile','block-18913','invoice\\StoreEmail','',3),(18917,'119586','deals-mobile','gift_card_2','BlockBox','',1),(18918,'119587','deals-mobile','block-18917','Text','',1),(18919,'119588','deals-mobile','block-18917','Text','',2),(18920,'119589','deals-mobile','block-18917','Text','',6),(18921,'119590','deals-mobile','block-18917','gift\\MessageView','',5),(18922,'119591','deals-mobile','block-18917','Text','',7),(18923,'119592','deals-mobile','block-18917','Text','',4),(18924,'119593','deals-mobile','block-18917','BlockBox','',9),(18925,'119594','deals-mobile','block-18924','invoice\\StorePhone','',2),(18926,'119595','deals-mobile','block-18924','Text','',1),(18927,'119596','deals-mobile','block-18924','invoice\\StoreEmail','',3),(18928,'119597','deals-mobile','block-18917','BlockBox','',8),(18929,'119598','deals-mobile','block-18928','Text','',1),(18930,'119599','deals-mobile','block-18928-2','gift\\CodeView','',1),(18931,'119600','deals-mobile','block-18917','gift\\AmountView','',3),(18932,'119601','deals-mobile','gift_card_2_pdf','BlockBox','',1),(18933,'119602','deals-mobile','block-18932','BlockBox','',12),(18934,'119603','deals-mobile','block-18933','invoice\\StoreEmail','',4),(18935,'119604','deals-mobile','block-18933','invoice\\StorePhone','',3),(18936,'119605','deals-mobile','block-18933','Html_box','',1),(18937,'119606','deals-mobile','block-18932','BlockBox','',11),(18938,'119607','deals-mobile','block-18937','Html_box','',1),(18939,'119608','deals-mobile','block-18937-2','gift\\CodeViewPdf','',1),(18940,'119609','deals-mobile','block-18932','BlockBox','',1),(18941,'119610','deals-mobile','block-18940','Text','',4),(18942,'119611','deals-mobile','block-18940','Html_box','',1),(18943,'119612','deals-mobile','block-18940','Html_box','',2),(18944,'119613','deals-mobile','block-18940','gift\\AmountViewPdf','',3),(18945,'119614','deals-mobile','block-18940','gift\\MessageViewPdf','',5),(18946,'119615','deals-mobile','block-18940','Html_box','',7),(18947,'119616','deals-mobile','block-18940','Html_box','',6),(18948,'119617','deals-mobile','gift_card_2_pdf','Import','',1),(18949,'119618','deals-mobile','gift_card_pdf','BlockBox','',1),(18950,'119619','deals-mobile','block-18949','BlockBox','',12),(18951,'119620','deals-mobile','block-18950','invoice\\StoreEmail','',4),(18952,'119621','deals-mobile','block-18950','invoice\\StorePhone','',3),(18953,'119622','deals-mobile','block-18950','Html_box','',1),(18954,'119623','deals-mobile','block-18949','BlockBox','',11),(18955,'119624','deals-mobile','block-18954','Html_box','',1),(18956,'119625','deals-mobile','block-18954-2','gift\\CodeViewPdf','',1),(18957,'119626','deals-mobile','block-18949','BlockBox','',1),(18958,'119627','deals-mobile','block-18957','Text','',4),(18959,'119628','deals-mobile','block-18957','Html_box','',1),(18960,'119629','deals-mobile','block-18957','Html_box','',2),(18961,'119630','deals-mobile','block-18957','gift\\AmountViewPdf','',3),(18962,'119631','deals-mobile','block-18957','gift\\MessageViewPdf','',5),(18963,'119632','deals-mobile','block-18957','Html_box','',7),(18964,'119633','deals-mobile','block-18957','Html_box','',6),(18965,'119634','deals-mobile','gift_card_pdf','Import','',1),(18966,'119635','deals-mobile','gift_certificate','BlockBox','',1),(18967,'119636','deals-mobile','block-18966','account\\ApplyCertificate','',2),(18968,'119637','deals-mobile','block-18966','Html_box','',1),(18969,'119638','deals-mobile','gigt_card_3','BlockBox','',1),(18970,'119639','deals-mobile','block-18969','Text','',7),(18971,'119640','deals-mobile','block-18969','Text','',4),(18972,'119641','deals-mobile','block-18969','gift\\AmountView','',3),(18973,'119642','deals-mobile','block-18969','Text','',2),(18974,'119643','deals-mobile','block-18969','gift\\MessageView','',5),(18975,'119644','deals-mobile','block-18969','Text','',1),(18976,'119645','deals-mobile','block-18969','BlockBox','',9),(18977,'119646','deals-mobile','block-18976','invoice\\StoreEmail','',3),(18978,'119647','deals-mobile','block-18976','invoice\\StorePhone','',2),(18979,'119648','deals-mobile','block-18976','Text','',1),(18980,'119649','deals-mobile','block-18969','Text','',6),(18981,'119650','deals-mobile','block-18969','BlockBox','',8),(18982,'119651','deals-mobile','block-18981','Text','',1),(18983,'119652','deals-mobile','block-18981-2','gift\\CodeView','',1),(18984,'119653','deals-mobile','gigt_card_3_pdf','BlockBox','',1),(18985,'119654','deals-mobile','block-18984','BlockBox','',12),(18986,'119655','deals-mobile','block-18985','invoice\\StoreEmail','',4),(18987,'119656','deals-mobile','block-18985','invoice\\StorePhone','',3),(18988,'119657','deals-mobile','block-18985','Html_box','',1),(18989,'119658','deals-mobile','block-18984','BlockBox','',11),(18990,'119659','deals-mobile','block-18989','Html_box','',1),(18991,'119660','deals-mobile','block-18989-2','gift\\CodeViewPdf','',1),(18992,'119661','deals-mobile','block-18984','BlockBox','',1),(18993,'119662','deals-mobile','block-18992','Text','',4),(18994,'119663','deals-mobile','block-18992','Html_box','',1),(18995,'119664','deals-mobile','block-18992','Html_box','',2),(18996,'119665','deals-mobile','block-18992','gift\\AmountViewPdf','',3),(18997,'119666','deals-mobile','block-18992','gift\\MessageViewPdf','',5),(18998,'119667','deals-mobile','block-18992','Html_box','',7),(18999,'119668','deals-mobile','block-18992','Html_box','',6),(19000,'119669','deals-mobile','header','Logo','',2),(19001,'119670','deals-mobile','header','catalog\\Paging','',3),(19002,'119671','deals-mobile','header','BlockBox','',1),(19003,'119672','deals-mobile','block-19002','Text','',1),(19004,'119673','deals-mobile','block-19002','BlockBox','',2),(19005,'119674','deals-mobile','block-19004','Text','',2),(19006,'119675','deals-mobile','block-19004','Image','',1),(19007,'119676','deals-mobile','block-19004-2','BlockBox','',1),(19008,'119677','deals-mobile','block-19007','Html_box','',2),(19009,'119678','deals-mobile','block-19007-2','Html_box','',2),(19010,'119679','deals-mobile','header','BlockBox','',3),(19011,'119680','deals-mobile','block-19010','Menu','Categories',1),(19012,'119681','deals-mobile','block-19010-2','Search','',1),(19013,'119682','deals-mobile','block-19010-3','Account','',1),(19014,'119683','deals-mobile','block-19010-4','Cart','',1),(19015,'119684','deals-mobile','info','BlockBox','',1),(19016,'119685','deals-mobile','block-19015','info\\Content','',3),(19017,'119686','deals-mobile','block-19015','info\\Title','',2),(19018,'119687','deals-mobile','invoice','invoice\\Container','',1),(19019,'119688','deals-mobile','block-19018','BlockBox','',4),(19020,'119689','deals-mobile','block-19019','BlockBox','',1),(19021,'119690','deals-mobile','block-19020','invoice\\ShippingAddress','',2),(19022,'119691','deals-mobile','block-19020','Text','',1),(19023,'119692','deals-mobile','block-19019-2','BlockBox','',1),(19024,'119693','deals-mobile','block-19023','invoice\\Totals','',1),(19025,'119694','deals-mobile','block-19018','invoice\\Products','',3),(19026,'119695','deals-mobile','block-19018','BlockBox','',1),(19027,'119696','deals-mobile','block-19026','Logo','',1),(19028,'119697','deals-mobile','block-19026-2','BlockBox','',2),(19029,'119698','deals-mobile','block-19028','Text','',1),(19030,'119699','deals-mobile','block-19028-2','invoice\\StorePhone','',1),(19031,'119700','deals-mobile','block-19026-2','BlockBox','',1),(19032,'119701','deals-mobile','block-19031','invoice\\StoreAddress','',1),(19033,'119702','deals-mobile','block-19026-2','BlockBox','',4),(19034,'119703','deals-mobile','block-19033','Text','',1),(19035,'119704','deals-mobile','block-19033-2','invoice\\StoreSite','',1),(19036,'119705','deals-mobile','block-19026-2','BlockBox','',3),(19037,'119706','deals-mobile','block-19036','Text','',1),(19038,'119707','deals-mobile','block-19036-2','invoice\\StoreEmail','',1),(19039,'119708','deals-mobile','block-19018','BlockBox','',5),(19040,'119709','deals-mobile','block-19039','Text','',1),(19041,'119710','deals-mobile','block-19039','invoice\\StoreAddress','',8),(19042,'119711','deals-mobile','block-19039-2','Text','',2),(19043,'119712','deals-mobile','block-19039-2','Logo','',1),(19044,'119713','deals-mobile','block-19039-3','BlockBox','',3),(19045,'119714','deals-mobile','block-19044','Text','',1),(19046,'119715','deals-mobile','block-19044-2','invoice\\StoreEmail','',1),(19047,'119716','deals-mobile','block-19039-3','BlockBox','',2),(19048,'119717','deals-mobile','block-19047','Text','',1),(19049,'119718','deals-mobile','block-19047-2','invoice\\StorePhone','',1),(19050,'119719','deals-mobile','block-19039-3','Text','',1),(19051,'119720','deals-mobile','block-19018','BlockBox','',2),(19052,'119721','deals-mobile','block-19051','BlockBox','',8),(19053,'119722','deals-mobile','block-19052','BlockBox','',1),(19054,'119723','deals-mobile','block-19053','Text','',1),(19055,'119724','deals-mobile','block-19053','invoice\\ShippingMethod','',2),(19056,'119725','deals-mobile','block-19052-2','BlockBox','',1),(19057,'119726','deals-mobile','block-19056','invoice\\ShippingMethod','',2),(19058,'119727','deals-mobile','block-19056','Text','',1),(19059,'119728','deals-mobile','block-19051','BlockBox','',7),(19060,'119729','deals-mobile','block-19059','BlockBox','',1),(19061,'119730','deals-mobile','block-19060','Text','',1),(19062,'119731','deals-mobile','block-19060','invoice\\BillingAddress','',2),(19063,'119732','deals-mobile','block-19059-2','BlockBox','',1),(19064,'119733','deals-mobile','block-19063','invoice\\CustomerPhone','',4),(19065,'119734','deals-mobile','block-19063','Text','',1),(19066,'119735','deals-mobile','block-19063','invoice\\CustomerName','',2),(19067,'119736','deals-mobile','block-19063','Text','',3),(19068,'119737','deals-mobile','block-19063','Text','',5),(19069,'119738','deals-mobile','block-19063','invoice\\CustomerEmail','',6),(19070,'119739','deals-mobile','block-19051-2','invoice\\PaymentMethod','',5),(19071,'119740','deals-mobile','block-19051-2','invoice\\PaymentDate','',3),(19072,'119741','deals-mobile','block-19051-2','invoice\\OrderId','',1),(19073,'119742','deals-mobile','block-19051-2','invoice\\OrderBarcode','',6),(19074,'119743','deals-mobile','block-19051-2','Text','',2),(19075,'119744','deals-mobile','block-19051-2','Text','',4),(19076,'119745','deals-mobile','login_account','BlockBox','',1),(19077,'119746','deals-mobile','block-19076','Tabs','',2),(19078,'119747','deals-mobile','block-19077-1','login\\Returning','',1),(19079,'119748','deals-mobile','block-19077-2','login\\Register','',2),(19080,'119749','deals-mobile','block-19076','BlockBox','',1),(19081,'119750','deals-mobile','block-19080','Html_box','',3),(19082,'119751','deals-mobile','block-19080','Html_box','',1),(19083,'119752','deals-mobile','block-19080','login\\Socials','',2),(19084,'119753','deals-mobile','login_checkout','BlockBox','',1),(19085,'119754','deals-mobile','block-19084','BlockBox','',1),(19086,'119755','deals-mobile','block-19085','Html_box','',2),(19087,'119756','deals-mobile','block-19085','checkout\\CreateBtn','',5),(19088,'119757','deals-mobile','block-19085','checkout\\GuestBtn','',3),(19089,'119758','deals-mobile','block-19085','Html_box','',4),(19090,'119759','deals-mobile','block-19085','BlockBox','',6),(19091,'119760','deals-mobile','block-19090','Html_box','',1),(19092,'119761','deals-mobile','block-19090','login\\Socials','',2),(19093,'119762','deals-mobile','block-19085','login\\Returning','',1),(19094,'119763','deals-mobile','block-19085','Html_box','',1),(19095,'119764','deals-mobile','login_checkout2','BlockBox','',1),(19096,'119765','deals-mobile','block-19095','Html_box','',1),(19097,'119766','deals-mobile','block-19095','Html_box','',3),(19098,'119767','deals-mobile','block-19095','login\\Socials','',2),(19099,'119768','deals-mobile','block-19095','Tabs','',4),(19100,'119769','deals-mobile','block-19099-1','BlockBox','',1),(19101,'119770','deals-mobile','block-19100','Html_box','',1),(19102,'119771','deals-mobile','block-19100-2','BlockBox','',1),(19103,'119772','deals-mobile','block-19102','Html_box','',2),(19104,'119773','deals-mobile','block-19102','login\\Guest','',1),(19105,'119774','deals-mobile','block-19099-2','login\\Returning','',1),(19106,'119775','deals-mobile','block-19099-3','BlockBox','',1),(19107,'119776','deals-mobile','block-19106','Html_box','',1),(19108,'119777','deals-mobile','block-19106-2','BlockBox','',1),(19109,'119778','deals-mobile','block-19108','login\\Register','',1),(19110,'119779','deals-mobile','block-19108','Html_box','',2),(19111,'119780','deals-mobile','login_checkout2_q','BlockBox','',1),(19112,'119781','deals-mobile','block-19111','login\\Socials','',2),(19113,'119782','deals-mobile','block-19111','Html_box','',1),(19114,'119783','deals-mobile','block-19111','Html_box','',3),(19115,'119784','deals-mobile','block-19111','Tabs','',4),(19116,'119785','deals-mobile','block-19115-1','BlockBox','',1),(19117,'119786','deals-mobile','block-19116','Html_box','',1),(19118,'119787','deals-mobile','block-19116-2','quote\\FastOrder','',1),(19119,'119788','deals-mobile','block-19115-2','login\\Returning','',1),(19120,'119789','deals-mobile','block-19115-3','BlockBox','',1),(19121,'119790','deals-mobile','block-19120','Html_box','',1),(19122,'119791','deals-mobile','block-19120','Import','',2),(19123,'119792','deals-mobile','block-19120-2','BlockBox','',1),(19124,'119793','deals-mobile','block-19123','Html_box','',2),(19125,'119794','deals-mobile','block-19123','login\\Register','',1),(19126,'119795','deals-mobile','login_checkout2_s','BlockBox','',1),(19127,'119796','deals-mobile','block-19126','Html_box','',1),(19128,'119797','deals-mobile','block-19126','Tabs','',4),(19129,'119798','deals-mobile','block-19128-1','BlockBox','',1),(19130,'119799','deals-mobile','block-19129','Html_box','',1),(19131,'119800','deals-mobile','block-19129-2','quote\\FastOrder','',1),(19132,'119801','deals-mobile','block-19128-2','login\\Returning','',1),(19133,'119802','deals-mobile','block-19128-3','BlockBox','',1),(19134,'119803','deals-mobile','block-19133','Html_box','',1),(19135,'119804','deals-mobile','block-19133-2','BlockBox','',1),(19136,'119805','deals-mobile','block-19135','Html_box','',2),(19137,'119806','deals-mobile','block-19135','login\\Register','',1),(19138,'119807','deals-mobile','block-19126','login\\Socials','',2),(19139,'119808','deals-mobile','block-19126','Html_box','',3),(19140,'119809','deals-mobile','login_checkout_q','BlockBox','',1),(19141,'119810','deals-mobile','block-19140','BlockBox','',1),(19142,'119811','deals-mobile','block-19141','checkout\\CreateBtn','',5),(19143,'119812','deals-mobile','block-19141','checkout\\GuestBtn','',2),(19144,'119813','deals-mobile','block-19141','Html_box','',1),(19145,'119814','deals-mobile','block-19141','Html_box','',4),(19146,'119815','deals-mobile','block-19141','BlockBox','',6),(19147,'119816','deals-mobile','block-19146','login\\Socials','',2),(19148,'119817','deals-mobile','block-19146','Html_box','',1),(19149,'119818','deals-mobile','block-19141-2','login\\Returning','',2),(19150,'119819','deals-mobile','block-19141-2','Html_box','',1),(19151,'119820','deals-mobile','login_checkout_s','BlockBox','',1),(19152,'119821','deals-mobile','block-19151','BlockBox','',1),(19153,'119822','deals-mobile','block-19152','BlockBox','',5),(19154,'119823','deals-mobile','block-19153','Html_box','',1),(19155,'119824','deals-mobile','block-19153','login\\Socials','',2),(19156,'119825','deals-mobile','block-19152','Html_box','',3),(19157,'119826','deals-mobile','block-19152','checkout\\CreateBtn','',4),(19158,'119827','deals-mobile','block-19152','Html_box','',1),(19159,'119828','deals-mobile','block-19152','checkout\\GuestBtn','',2),(19160,'119829','deals-mobile','block-19152-2','Html_box','',1),(19161,'119830','deals-mobile','block-19152-2','login\\Returning','',2),(19162,'119831','deals-mobile','logoff','BlockBox','',1),(19163,'119832','deals-mobile','block-19162','Html_box','',1),(19164,'119833','deals-mobile','logoff_forever','BlockBox','',1),(19165,'119834','deals-mobile','block-19164','Html_box','',1),(19166,'119835','deals-mobile','main','BlockBox','',5),(19167,'119836','deals-mobile','block-19166','TopCategories','',1),(19168,'119837','deals-mobile','block-19166','PromoCode','',2),(19169,'119838','deals-mobile','block-19166','Tabs','',3),(19170,'119839','deals-mobile','block-19169-1','NewProducts','4',1),(19171,'119840','deals-mobile','block-19169-2','SpecialsProducts','4',1),(19172,'119841','deals-mobile','block-19169-3','FeaturedProducts','4',1),(19173,'119842','deals-mobile','main','Heading','',2),(19174,'119843','deals-mobile','main','BlockBox','',6),(19175,'119844','deals-mobile','block-19174','BlockBox','',1),(19176,'119845','deals-mobile','block-19175','Bestsellers','10',1),(19177,'119846','deals-mobile','block-19175-2','Reviews','4',1),(19178,'119847','deals-mobile','manufacturers','BlockBox','',1),(19179,'119848','deals-mobile','block-19178','Html_box','',1),(19180,'119849','deals-mobile','block-19178','Brands','',2),(19181,'119850','deals-mobile','messages-index','BlockBox','',1),(19182,'119851','deals-mobile','block-19181','BlockBox','',1),(19183,'119852','deals-mobile','block-19182','BlockBox','',1),(19184,'119853','deals-mobile','block-19183','Messages\\Sidebar','',1),(19185,'119854','deals-mobile','block-19182-2','Messages\\Listing','',1),(19186,'119855','deals-mobile','messages-new','BlockBox','',1),(19187,'119856','deals-mobile','block-19186','BlockBox','',1),(19188,'119857','deals-mobile','block-19187','Messages\\Sidebar','',1),(19189,'119858','deals-mobile','block-19187-2','Messages\\NewMessage','',1),(19190,'119859','deals-mobile','messages-view','BlockBox','',1),(19191,'119860','deals-mobile','block-19190','BlockBox','',1),(19192,'119861','deals-mobile','block-19191','Messages\\Sidebar','',1),(19193,'119862','deals-mobile','block-19191-2','Messages\\Message','',1),(19194,'119863','deals-mobile','my_password','BlockBox','',1),(19195,'119864','deals-mobile','block-19194','BlockBox','',1),(19196,'119865','deals-mobile','block-19195','WidgetsAria','',1),(19197,'119866','deals-mobile','block-19195-2','account\\ChangePassword','',2),(19198,'119867','deals-mobile','block-19195-2','Html_box','',1),(19199,'119868','deals-mobile','block-19195-2','account\\AccountLink','',3),(19200,'119869','deals-mobile','need_login','BlockBox','',1),(19201,'119870','deals-mobile','block-19200','BlockBox','',1),(19202,'119871','deals-mobile','block-19200','Tabs','',2),(19203,'119872','deals-mobile','block-19202-1','login\\Returning','',1),(19204,'119873','deals-mobile','block-19202-2','BlockBox','',1),(19205,'119874','deals-mobile','block-19204','Html_box','',1),(19206,'119875','deals-mobile','block-19204-2','BlockBox','',1),(19207,'119876','deals-mobile','block-19206','login\\Register','',1),(19208,'119877','deals-mobile','block-19206','Html_box','',2),(19209,'119878','deals-mobile','new-topic','BlockBox','',1),(19210,'119879','deals-mobile','block-19209','Communication\\NewTopic','',3),(19211,'119880','deals-mobile','block-19209','Html_box','',1),(19212,'119881','deals-mobile','block-19209','Breadcrumb','',2),(19213,'119882','deals-mobile','nnnn','BlockBox','',1),(19214,'119883','deals-mobile','block-19213','catalog\\Title','',1),(19215,'119884','deals-mobile','block-19213','BlockBox','',2),(19216,'119885','deals-mobile','block-19215','Filters','',1),(19217,'119886','deals-mobile','block-19215-2','Listing','',5),(19218,'119887','deals-mobile','block-19215-2','catalog\\Image','',1),(19219,'119888','deals-mobile','block-19215-2','BlockBox','',6),(19220,'119889','deals-mobile','block-19219','catalog\\CountsItems','',1),(19221,'119890','deals-mobile','block-19219-2','catalog\\Paging','',1),(19222,'119891','deals-mobile','block-19215-2','catalog\\ImageMapCategory','',3),(19223,'119892','deals-mobile','block-19215-2','Categories','',2),(19224,'119893','deals-mobile','block-19215-2','BlockBox','',4),(19225,'119894','deals-mobile','block-19224','catalog\\ListingLook','',1),(19226,'119895','deals-mobile','block-19224','catalog\\ItemsOnPage','',4),(19227,'119896','deals-mobile','block-19224','catalog\\CompareButton','',2),(19228,'119897','deals-mobile','block-19224','catalog\\Sorting','',3),(19229,'119898','deals-mobile','no-logged','BlockBox','',1),(19230,'119899','deals-mobile','block-19229','Html_box','',1),(19231,'119900','deals-mobile','block-19229','Communication\\NewTopic','',2),(19232,'119901','deals-mobile','no_filters','BlockBox','',1),(19233,'119902','deals-mobile','block-19232','BlockBox','',2),(19234,'119903','deals-mobile','block-19233','catalog\\Image','',1),(19235,'119904','deals-mobile','block-19233','BlockBox','',2),(19236,'119905','deals-mobile','block-19235','catalog\\Sorting','',3),(19237,'119906','deals-mobile','block-19235','catalog\\ItemsOnPage','',4),(19238,'119907','deals-mobile','block-19235','HeaderStock','',5),(19239,'119908','deals-mobile','block-19235','catalog\\CompareButton','',2),(19240,'119909','deals-mobile','block-19235','catalog\\ListingLook','',1),(19241,'119910','deals-mobile','block-19232','BlockBox','',4),(19242,'119911','deals-mobile','block-19241','catalog\\CountsItems','',1),(19243,'119912','deals-mobile','block-19241-2','catalog\\Paging','',1),(19244,'119913','deals-mobile','block-19232','catalog\\B2bAddButton','',5),(19245,'119914','deals-mobile','block-19232','catalog\\Title','',1),(19246,'119915','deals-mobile','block-19232','Listing','',3),(19247,'119916','deals-mobile','order_history','BlockBox','',1),(19248,'119917','deals-mobile','block-19247','BlockBox','',1),(19249,'119918','deals-mobile','block-19248','WidgetsAria','',1),(19250,'119919','deals-mobile','block-19248-2','account\\OrdersHistory','',2),(19251,'119920','deals-mobile','block-19248-2','Html_box','',1),(19252,'119921','deals-mobile','order_history_info','BlockBox','',1),(19253,'119922','deals-mobile','block-19252','BlockBox','',1),(19254,'119923','deals-mobile','block-19253','WidgetsAria','',1),(19255,'119924','deals-mobile','block-19253-2','account\\OrderReorderButton','',2),(19256,'119925','deals-mobile','block-19253-2','BlockBox','',7),(19257,'119926','deals-mobile','block-19256','BlockBox','',3),(19258,'119927','deals-mobile','block-19257','account\\AccountLink','',3),(19259,'119928','deals-mobile','block-19257','Html_box','',1),(19260,'119929','deals-mobile','block-19257','account\\OrderTracking','',2),(19261,'119930','deals-mobile','block-19256','BlockBox','',2),(19262,'119931','deals-mobile','block-19261','Html_box','',1),(19263,'119932','deals-mobile','block-19261','account\\OrderData','',2),(19264,'119933','deals-mobile','block-19256','BlockBox','',1),(19265,'119934','deals-mobile','block-19264','account\\OrderData','',2),(19266,'119935','deals-mobile','block-19264','Html_box','',1),(19267,'119936','deals-mobile','block-19256-2','BlockBox','',1),(19268,'119937','deals-mobile','block-19267','Html_box','',1),(19269,'119938','deals-mobile','block-19267','account\\OrderData','',2),(19270,'119939','deals-mobile','block-19256-2','BlockBox','',2),(19271,'119940','deals-mobile','block-19270','Html_box','',1),(19272,'119941','deals-mobile','block-19270','account\\OrderData','',2),(19273,'119942','deals-mobile','block-19256-3','BlockBox','',1),(19274,'119943','deals-mobile','block-19273','Html_box','',1),(19275,'119944','deals-mobile','block-19273','account\\OrderData','',2),(19276,'119945','deals-mobile','block-19256-3','BlockBox','',2),(19277,'119946','deals-mobile','block-19276','Html_box','',1),(19278,'119947','deals-mobile','block-19276','account\\OrderData','',2),(19279,'119948','deals-mobile','block-19253-2','account\\OrderDownload','',6),(19280,'119949','deals-mobile','block-19253-2','account\\OrderProducts','',9),(19281,'119950','deals-mobile','block-19253-2','Html_box','',11),(19282,'119951','deals-mobile','block-19253-2','account\\OrderHeading','',1),(19283,'119952','deals-mobile','block-19253-2','account\\OrderHistory','',12),(19284,'119953','deals-mobile','block-19253-2','account\\OrderCancelAndReorder','',4),(19285,'119954','deals-mobile','block-19253-2','Html_box','',8),(19286,'119955','deals-mobile','block-19253-2','account\\OrderSubTotals','',10),(19287,'119956','deals-mobile','block-19253-2','account\\OrderPayButton','',5),(19288,'119957','deals-mobile','block-19253-2','account\\OrderInvoiceButton','',3),(19289,'119958','deals-mobile','block-19253-2','BlockBox','',13),(19290,'119959','deals-mobile','block-19289','account\\AccountLink','',1),(19291,'119960','deals-mobile','block-19289-2','account\\OrderInvoiceButton','',1),(19292,'119961','deals-mobile','order_pay','BlockBox','',1),(19293,'119962','deals-mobile','block-19292','BlockBox','',1),(19294,'119963','deals-mobile','block-19293','WidgetsAria','',1),(19295,'119964','deals-mobile','block-19293-2','account\\OrderSubTotals','',5),(19296,'119965','deals-mobile','block-19293-2','account\\OrderHeading','',1),(19297,'119966','deals-mobile','block-19293-2','Html_box','',3),(19298,'119967','deals-mobile','block-19293-2','UpdateAndPay\\PayForm','',6),(19299,'119968','deals-mobile','block-19293-2','BlockBox','',2),(19300,'119969','deals-mobile','block-19299','BlockBox','',4),(19301,'119970','deals-mobile','block-19300','Html_box','',1),(19302,'119971','deals-mobile','block-19300','account\\OrderData','',2),(19303,'119972','deals-mobile','block-19299','BlockBox','',1),(19304,'119973','deals-mobile','block-19303','Html_box','',1),(19305,'119974','deals-mobile','block-19303','account\\OrderData','',2),(19306,'119975','deals-mobile','block-19299-2','BlockBox','',2),(19307,'119976','deals-mobile','block-19306','account\\OrderData','',2),(19308,'119977','deals-mobile','block-19306','Html_box','',1),(19309,'119978','deals-mobile','block-19299-2','BlockBox','',1),(19310,'119979','deals-mobile','block-19309','Html_box','',1),(19311,'119980','deals-mobile','block-19309','account\\OrderData','',2),(19312,'119981','deals-mobile','block-19299-3','BlockBox','',2),(19313,'119982','deals-mobile','block-19312','Html_box','',1),(19314,'119983','deals-mobile','block-19312','account\\OrderData','',2),(19315,'119984','deals-mobile','block-19299-3','BlockBox','',1),(19316,'119985','deals-mobile','block-19315','account\\OrderData','',2),(19317,'119986','deals-mobile','block-19315','Html_box','',1),(19318,'119987','deals-mobile','block-19293-2','account\\OrderProducts','',4),(19319,'119988','deals-mobile','packingslip','invoice\\Container','',2),(19320,'119989','deals-mobile','block-19319','packingslip\\Products','',3),(19321,'119990','deals-mobile','block-19319','BlockBox','',2),(19322,'119991','deals-mobile','block-19321','BlockBox','',2),(19323,'119992','deals-mobile','block-19322','BlockBox','',1),(19324,'119993','deals-mobile','block-19323','Text','',1),(19325,'119994','deals-mobile','block-19323','invoice\\ShippingAddress','',2),(19326,'119995','deals-mobile','block-19322-2','BlockBox','',1),(19327,'119996','deals-mobile','block-19326','invoice\\CustomerEmail','',6),(19328,'119997','deals-mobile','block-19326','invoice\\CustomerName','',2),(19329,'119998','deals-mobile','block-19326','invoice\\CustomerPhone','',4),(19330,'119999','deals-mobile','block-19326','Text','',5),(19331,'120000','deals-mobile','block-19326','Text','',1),(19332,'120001','deals-mobile','block-19326','Text','',3),(19333,'120002','deals-mobile','block-19321','BlockBox','',3),(19334,'120003','deals-mobile','block-19333','BlockBox','',1),(19335,'120004','deals-mobile','block-19334','invoice\\ShippingMethod','',2),(19336,'120005','deals-mobile','block-19334','Text','',1),(19337,'120006','deals-mobile','block-19333-2','BlockBox','',1),(19338,'120007','deals-mobile','block-19337','Text','',1),(19339,'120008','deals-mobile','block-19337','invoice\\ShippingMethod','',2),(19340,'120009','deals-mobile','block-19321-2','invoice\\AddressQrcode','',1),(19341,'120010','deals-mobile','block-19319','BlockBox','',4),(19342,'120011','deals-mobile','block-19341','Text','',1),(19343,'120012','deals-mobile','block-19341','invoice\\StoreAddress','',2),(19344,'120013','deals-mobile','block-19319','BlockBox','',1),(19345,'120014','deals-mobile','block-19344','Logo','',1),(19346,'120015','deals-mobile','block-19344-2','BlockBox','',1),(19347,'120016','deals-mobile','block-19346','invoice\\StoreAddress','',1),(19348,'120017','deals-mobile','block-19344-2','BlockBox','',2),(19349,'120018','deals-mobile','block-19348','Text','',2),(19350,'120019','deals-mobile','block-19348-2','invoice\\StorePhone','',1),(19351,'120020','deals-mobile','block-19344-2','BlockBox','',4),(19352,'120021','deals-mobile','block-19351','Text','',2),(19353,'120022','deals-mobile','block-19351-2','invoice\\StoreSite','',1),(19354,'120023','deals-mobile','block-19344-2','BlockBox','',3),(19355,'120024','deals-mobile','block-19354','Text','',2),(19356,'120025','deals-mobile','block-19354-2','invoice\\StoreEmail','',1),(19357,'120026','deals-mobile','password_forgotten','BlockBox','',1),(19358,'120027','deals-mobile','block-19357','Html_box','',1),(19359,'120028','deals-mobile','block-19357','BlockBox','',2),(19360,'120029','deals-mobile','block-19359-2','login\\PasswordForgotten','',2),(19361,'120030','deals-mobile','block-19359-2','Html_box','',1),(19362,'120031','deals-mobile','pdf','invoice\\Container','',1),(19363,'120032','deals-mobile','block-19362','BlockBox','',1),(19364,'120033','deals-mobile','block-19363','BlockBox','',1),(19365,'120034','deals-mobile','block-19364','BlockBox','',2),(19366,'120035','deals-mobile','block-19365','pdf\\ProductElement','',1),(19367,'120036','deals-mobile','block-19365-2','pdf\\ProductElement','',2),(19368,'120037','deals-mobile','block-19365-2','pdf\\ProductElement','',1),(19369,'120038','deals-mobile','block-19364','BlockBox','',1),(19370,'120039','deals-mobile','block-19369','pdf\\ProductElement','',1),(19371,'120040','deals-mobile','block-19363-2','BlockBox','',1),(19372,'120041','deals-mobile','block-19371','BlockBox','',1),(19373,'120042','deals-mobile','block-19372','pdf\\ProductElement','',1),(19374,'120043','deals-mobile','block-19371','BlockBox','',2),(19375,'120044','deals-mobile','block-19374','pdf\\ProductElement','',1),(19376,'120045','deals-mobile','block-19374-2','pdf\\ProductElement','',2),(19377,'120046','deals-mobile','block-19374-2','pdf\\ProductElement','',1),(19378,'120047','deals-mobile','pdf_category','pdf\\CategoryName','',2),(19379,'120048','deals-mobile','pdf_category','pdf\\CategoryImage','',1),(19380,'120049','deals-mobile','pdf_cover','invoice\\Container','',1),(19381,'120050','deals-mobile','block-19380','Logo','',1),(19382,'120051','deals-mobile','block-19380','Text','',3),(19383,'120052','deals-mobile','pdf_footer','BlockBox','',1),(19384,'120053','deals-mobile','block-19383-2','pdf\\PageNumber','',1),(19385,'120054','deals-mobile','pdf_header','pdf\\CategoryName','',1),(19386,'120055','deals-mobile','personal_catalog','BlockBox','',1),(19387,'120056','deals-mobile','block-19386','BlockBox','',1),(19388,'120057','deals-mobile','block-19387','WidgetsAria','',1),(19389,'120058','deals-mobile','block-19387-2','Html_box','',1),(19390,'120059','deals-mobile','block-19387-2','account\\PersonalCatalog','',2),(19391,'120060','deals-mobile','points_earnt_history','BlockBox','',1),(19392,'120061','deals-mobile','block-19391','Html_box','',1),(19393,'120062','deals-mobile','block-19391','account\\PointsEarntHistory','',2),(19394,'120063','deals-mobile','posts','BlockBox','',1),(19395,'120064','deals-mobile','block-19394','Breadcrumb','',2),(19396,'120065','deals-mobile','block-19394','Communication\\Post','',3),(19397,'120066','deals-mobile','block-19394','Html_box','',1),(19398,'120067','deals-mobile','product','BlockBox','',1),(19399,'120068','deals-mobile','block-19398','BlockBox','',5),(19400,'120069','deals-mobile','block-19399','product\\Stock','',2),(19401,'120070','deals-mobile','block-19399','product\\Price','',1),(19402,'120071','deals-mobile','block-19399-2','product\\Quantity','',1),(19403,'120072','deals-mobile','block-19398','product\\Bundle','',6),(19404,'120073','deals-mobile','block-19398','product\\Video','',3),(19405,'120074','deals-mobile','block-19398','product\\Documents','',16),(19406,'120075','deals-mobile','block-19398','product\\Buttons','',7),(19407,'120076','deals-mobile','block-19398','product\\Images','',2),(19408,'120077','deals-mobile','block-19398','product\\Name','',1),(19409,'120078','deals-mobile','block-19398','BlockBox','',8),(19410,'120079','deals-mobile','block-19409','product\\WishlistButton','',1),(19411,'120080','deals-mobile','block-19409','product\\PersonalCatalogButton','',2),(19412,'120081','deals-mobile','block-19409','product\\WeddingRegistryButton','',3),(19413,'120082','deals-mobile','block-19398','product\\BonusPoints','',9),(19414,'120083','deals-mobile','block-19398','product\\CrossSell','',13),(19415,'120084','deals-mobile','block-19398','product\\AlsoPurchased','10',11),(19416,'120085','deals-mobile','block-19398','product\\InBundles','',14),(19417,'120086','deals-mobile','block-19398','Tabs','',12),(19418,'120087','deals-mobile','block-19417-1','product\\Description','',1),(19419,'120088','deals-mobile','block-19417-1','product\\Properties','',2),(19420,'120089','deals-mobile','block-19417-2','product\\Reviews','',1),(19421,'120090','deals-mobile','block-19398','product\\Attributes','',4),(19422,'120091','deals-mobile','block-19398','product\\Configurator','',10),(19423,'120092','deals-mobile','block-19398','ViewedProducts','',15),(19424,'120093','deals-mobile','product-bottom','product\\Properties','',1),(19425,'120094','deals-mobile','product-tabs','product\\Reviews','',2),(19426,'120095','deals-mobile','product-tabs','product\\Description','',1),(19427,'120096','deals-mobile','product-top-left','product\\Images','',1),(19428,'120097','deals-mobile','product-top-right','product\\Attributes','',3),(19429,'120098','deals-mobile','product-top-right','product\\Buttons','',6),(19430,'120099','deals-mobile','product-top-right','product\\Quantity','',6),(19431,'120100','deals-mobile','product-top-right','product\\Quantity','',5),(19432,'120101','deals-mobile','product-top-right','product\\Name','',1),(19433,'120102','deals-mobile','product-top-right','product\\Price','',2),(19434,'120103','deals-mobile','productListing','BlockBox','',1),(19435,'120104','deals-mobile','block-19434','productListing\\model','',7),(19436,'120105','deals-mobile','block-19434','productListing\\bonusPoints','',6),(19437,'120106','deals-mobile','block-19434','productListing\\description','',5),(19438,'120107','deals-mobile','block-19434','productListing\\buyButton','',9),(19439,'120108','deals-mobile','block-19434','productListing\\rating','',3),(19440,'120109','deals-mobile','block-19434','productListing\\image','',1),(19441,'120110','deals-mobile','block-19434','BlockBox','',8),(19442,'120111','deals-mobile','block-19441','productListing\\price','',1),(19443,'120112','deals-mobile','block-19441-2','productListing\\qtyInput','',1),(19444,'120113','deals-mobile','block-19434','productListing\\name','',4),(19445,'120114','deals-mobile','block-19434','productListing\\stock','',2),(19446,'120115','deals-mobile','products','BlockBox','',1),(19447,'120116','deals-mobile','block-19446','Filters','',3),(19448,'120117','deals-mobile','block-19446','catalog\\Paging','',5),(19449,'120118','deals-mobile','block-19446','catalog\\Title','',1),(19450,'120119','deals-mobile','block-19446','catalog\\Image','',2),(19451,'120120','deals-mobile','block-19446','BlockBox','',4),(19452,'120121','deals-mobile','block-19451','catalog\\Sorting','',1),(19453,'120122','deals-mobile','block-19451-2','catalog\\CountsItems','',1),(19454,'120123','deals-mobile','block-19446','Listing','',7),(19455,'120124','deals-mobile','products-list','packingslip\\AllProductsList','',2),(19456,'120125','deals-mobile','promotions','BlockBox','',1),(19457,'120126','deals-mobile','block-19456','promotions\\PromoList','',2),(19458,'120127','deals-mobile','block-19456','Html_box','',1),(19459,'120128','deals-mobile','purchase','invoice\\Container','',1),(19460,'120129','deals-mobile','block-19459','BlockBox','',4),(19461,'120130','deals-mobile','block-19460','BlockBox','',1),(19462,'120131','deals-mobile','block-19461','Text','',1),(19463,'120132','deals-mobile','block-19461','invoice\\ShippingAddress','',2),(19464,'120133','deals-mobile','block-19459','BlockBox','',2),(19465,'120134','deals-mobile','block-19464','BlockBox','',7),(19466,'120135','deals-mobile','block-19465','BlockBox','',1),(19467,'120136','deals-mobile','block-19466','Text','',1),(19468,'120137','deals-mobile','block-19466','invoice\\BillingAddress','',2),(19469,'120138','deals-mobile','block-19465-2','BlockBox','',1),(19470,'120139','deals-mobile','block-19469','Text','',1),(19471,'120140','deals-mobile','block-19469','Text','',3),(19472,'120141','deals-mobile','block-19469','Text','',5),(19473,'120142','deals-mobile','block-19469','invoice\\CustomerName','',2),(19474,'120143','deals-mobile','block-19469','invoice\\CustomerPhone','',4),(19475,'120144','deals-mobile','block-19469','invoice\\CustomerEmail','',6),(19476,'120145','deals-mobile','block-19464-2','Text','',2),(19477,'120146','deals-mobile','block-19464-2','invoice\\PaymentDate','',3),(19478,'120147','deals-mobile','block-19464-2','invoice\\OrderId','',1),(19479,'120148','deals-mobile','block-19459','BlockBox','',1),(19480,'120149','deals-mobile','block-19479','Logo','',1),(19481,'120150','deals-mobile','block-19479-2','BlockBox','',1),(19482,'120151','deals-mobile','block-19481','invoice\\StoreAddress','',1),(19483,'120152','deals-mobile','block-19479-2','BlockBox','',3),(19484,'120153','deals-mobile','block-19483','Text','',1),(19485,'120154','deals-mobile','block-19483-2','invoice\\StoreEmail','',1),(19486,'120155','deals-mobile','block-19479-2','BlockBox','',4),(19487,'120156','deals-mobile','block-19486','Text','',1),(19488,'120157','deals-mobile','block-19486-2','invoice\\StoreSite','',1),(19489,'120158','deals-mobile','block-19479-2','BlockBox','',2),(19490,'120159','deals-mobile','block-19489','Text','',1),(19491,'120160','deals-mobile','block-19489-2','invoice\\StorePhone','',1),(19492,'120161','deals-mobile','block-19459','BlockBox','',5),(19493,'120162','deals-mobile','block-19492','invoice\\StoreAddress','',8),(19494,'120163','deals-mobile','block-19492','Text','',1),(19495,'120164','deals-mobile','block-19492-2','Text','',2),(19496,'120165','deals-mobile','block-19492-2','Logo','',1),(19497,'120166','deals-mobile','block-19492-3','BlockBox','',2),(19498,'120167','deals-mobile','block-19497','Text','',1),(19499,'120168','deals-mobile','block-19497-2','invoice\\StorePhone','',1),(19500,'120169','deals-mobile','block-19492-3','Text','',1),(19501,'120170','deals-mobile','block-19492-3','BlockBox','',3),(19502,'120171','deals-mobile','block-19501','Text','',1),(19503,'120172','deals-mobile','block-19501-2','invoice\\StoreEmail','',1),(19504,'120173','deals-mobile','block-19459','invoice\\Products','',3),(19505,'120174','deals-mobile','quotations','BlockBox','',1),(19506,'120175','deals-mobile','block-19505','BlockBox','',1),(19507,'120176','deals-mobile','block-19506','WidgetsAria','',1),(19508,'120177','deals-mobile','block-19506-2','Html_box','',1),(19509,'120178','deals-mobile','block-19506-2','Quotations\\QuotationsHistory','',2),(19510,'120179','deals-mobile','quotation_info','BlockBox','',1),(19511,'120180','deals-mobile','block-19510','BlockBox','',1),(19512,'120181','deals-mobile','block-19511','WidgetsAria','',1),(19513,'120182','deals-mobile','block-19511-2','Quotations\\QuotationHistory','',10),(19514,'120183','deals-mobile','block-19511-2','Quotations\\QuotationProducts','',7),(19515,'120184','deals-mobile','block-19511-2','Html_box','',9),(19516,'120185','deals-mobile','block-19511-2','Html_box','',6),(19517,'120186','deals-mobile','block-19511-2','Quotations\\QuotationSubTotal','',8),(19518,'120187','deals-mobile','block-19511-2','Html_box','',4),(19519,'120188','deals-mobile','block-19511-2','BlockBox','',12),(19520,'120189','deals-mobile','block-19519','account\\AccountLink','',1),(19521,'120190','deals-mobile','block-19511-2','BlockBox','',5),(19522,'120191','deals-mobile','block-19521','BlockBox','',4),(19523,'120192','deals-mobile','block-19522','Html_box','',1),(19524,'120193','deals-mobile','block-19522','Quotations\\QuotationData','',2),(19525,'120194','deals-mobile','block-19521','BlockBox','',1),(19526,'120195','deals-mobile','block-19525','Quotations\\QuotationData','',2),(19527,'120196','deals-mobile','block-19525','Html_box','',1),(19528,'120197','deals-mobile','block-19521-2','BlockBox','',2),(19529,'120198','deals-mobile','block-19528','Html_box','',1),(19530,'120199','deals-mobile','block-19528','Quotations\\QuotationData','',2),(19531,'120200','deals-mobile','block-19521-2','BlockBox','',1),(19532,'120201','deals-mobile','block-19531','Html_box','',1),(19533,'120202','deals-mobile','block-19531','Quotations\\QuotationData','',2),(19534,'120203','deals-mobile','block-19521-3','BlockBox','',1),(19535,'120204','deals-mobile','block-19534','Html_box','',1),(19536,'120205','deals-mobile','block-19534','Quotations\\QuotationData','',2),(19537,'120206','deals-mobile','block-19521-3','BlockBox','',2),(19538,'120207','deals-mobile','block-19537','Quotations\\QuotationData','',2),(19539,'120208','deals-mobile','block-19537','Html_box','',1),(19540,'120209','deals-mobile','quote','quote\\CheckoutBtn','',3),(19541,'120210','deals-mobile','quote','quote\\Products','',2),(19542,'120211','deals-mobile','quote','Text','',1),(19543,'120212','deals-mobile','review','BlockBox','',1),(19544,'120213','deals-mobile','block-19543','BlockBox','',1),(19545,'120214','deals-mobile','block-19544','WidgetsAria','',1),(19546,'120215','deals-mobile','block-19544-2','Html_box','',1),(19547,'120216','deals-mobile','block-19544-2','account\\Reviews','',2),(19548,'120217','deals-mobile','reviews','BlockBox','',1),(19549,'120218','deals-mobile','block-19548','reviews\\Content','',2),(19550,'120219','deals-mobile','block-19548','reviews\\Heading','',1),(19551,'120220','deals-mobile','rma_document','invoice\\Container','',1),(19552,'120221','deals-mobile','block-19551','BlockBox','',3),(19553,'120222','deals-mobile','block-19552','BlockBox','',1),(19554,'120223','deals-mobile','block-19553','BlockBox','',1),(19555,'120224','deals-mobile','block-19554','BlockBox','',6),(19556,'120225','deals-mobile','block-19555','Html_box','',1),(19557,'120226','deals-mobile','block-19554','BlockBox','',3),(19558,'120227','deals-mobile','block-19557','Html_box','',1),(19559,'120228','deals-mobile','block-19557-2','Html_box','',1),(19560,'120229','deals-mobile','block-19554','BlockBox','',1),(19561,'120230','deals-mobile','block-19560','Html_box','',1),(19562,'120231','deals-mobile','block-19554','BlockBox','',2),(19563,'120232','deals-mobile','block-19562','Html_box','',1),(19564,'120233','deals-mobile','block-19562-2','Html_box','',1),(19565,'120234','deals-mobile','block-19554','BlockBox','',4),(19566,'120235','deals-mobile','block-19565','Html_box','',1),(19567,'120236','deals-mobile','block-19565-2','Html_box','',1),(19568,'120237','deals-mobile','block-19554','BlockBox','',5),(19569,'120238','deals-mobile','block-19568','Html_box','',1),(19570,'120239','deals-mobile','block-19568-2','Html_box','',1),(19571,'120240','deals-mobile','block-19568-2','invoice\\StoreAddress','',2),(19572,'120241','deals-mobile','block-19553-2','BlockBox','',3),(19573,'120242','deals-mobile','block-19572','Html_box','',1),(19574,'120243','deals-mobile','block-19572-2','Html_box','',1),(19575,'120244','deals-mobile','block-19572-3','BlockBox','',1),(19576,'120245','deals-mobile','block-19575','Html_box','',1),(19577,'120246','deals-mobile','block-19575-2','Html_box','',1),(19578,'120247','deals-mobile','block-19553-2','BlockBox','',4),(19579,'120248','deals-mobile','block-19578','Html_box','',1),(19580,'120249','deals-mobile','block-19578-2','Html_box','',1),(19581,'120250','deals-mobile','block-19578-3','BlockBox','',1),(19582,'120251','deals-mobile','block-19581','Html_box','',1),(19583,'120252','deals-mobile','block-19581-2','Html_box','',1),(19584,'120253','deals-mobile','block-19553-2','BlockBox','',2),(19585,'120254','deals-mobile','block-19584','Html_box','',1),(19586,'120255','deals-mobile','block-19584','Html_box','',2),(19587,'120256','deals-mobile','block-19584','Html_box','',3),(19588,'120257','deals-mobile','block-19584','Html_box','',4),(19589,'120258','deals-mobile','block-19584','Html_box','',5),(19590,'120259','deals-mobile','block-19553-2','BlockBox','',1),(19591,'120260','deals-mobile','block-19590','BlockBox','',1),(19592,'120261','deals-mobile','block-19591','BlockBox','',1),(19593,'120262','deals-mobile','block-19592','Rma\\DocumentData','',2),(19594,'120263','deals-mobile','block-19592-3','BlockBox','',1),(19595,'120264','deals-mobile','block-19594','Html_box','',1),(19596,'120265','deals-mobile','block-19594-2','Rma\\DocumentData','',1),(19597,'120266','deals-mobile','block-19591','BlockBox','',2),(19598,'120267','deals-mobile','block-19597-2','invoice\\StoreAddress','',1),(19599,'120268','deals-mobile','block-19551','BlockBox','',2),(19600,'120269','deals-mobile','block-19599','Rma\\Products','',2),(19601,'120270','deals-mobile','block-19599','Html_box','',1),(19602,'120271','deals-mobile','block-19551','BlockBox','',1),(19603,'120272','deals-mobile','block-19602','BlockBox','',1),(19604,'120273','deals-mobile','block-19603','BlockBox','',1),(19605,'120274','deals-mobile','block-19604','Html_box','',2),(19606,'120275','deals-mobile','block-19604','Html_box','',1),(19607,'120276','deals-mobile','block-19603','BlockBox','',3),(19608,'120277','deals-mobile','block-19607','Html_box','',1),(19609,'120278','deals-mobile','block-19607-2','Html_box','',1),(19610,'120279','deals-mobile','block-19603','BlockBox','',2),(19611,'120280','deals-mobile','block-19610','Html_box','',1),(19612,'120281','deals-mobile','block-19610-2','Html_box','',1),(19613,'120282','deals-mobile','block-19603','BlockBox','',4),(19614,'120283','deals-mobile','block-19613','Html_box','',1),(19615,'120284','deals-mobile','block-19613-2','Html_box','',1),(19616,'120285','deals-mobile','block-19603','BlockBox','',5),(19617,'120286','deals-mobile','block-19616','Html_box','',1),(19618,'120287','deals-mobile','block-19616-2','Html_box','',1),(19619,'120288','deals-mobile','block-19602-2','BlockBox','',3),(19620,'120289','deals-mobile','block-19619','BlockBox','',1),(19621,'120290','deals-mobile','block-19620','Html_box','',1),(19622,'120291','deals-mobile','block-19620-2','Rma\\DocumentData','',1),(19623,'120292','deals-mobile','block-19619-2','BlockBox','',1),(19624,'120293','deals-mobile','block-19623','Html_box','',1),(19625,'120294','deals-mobile','block-19623-2','Rma\\DocumentData','',1),(19626,'120295','deals-mobile','block-19602-2','BlockBox','',2),(19627,'120296','deals-mobile','block-19626','BlockBox','',1),(19628,'120297','deals-mobile','block-19627','BlockBox','',1),(19629,'120298','deals-mobile','block-19628','Html_box','',1),(19630,'120299','deals-mobile','block-19628-2','Rma\\DocumentData','',1),(19631,'120300','deals-mobile','block-19627-2','BlockBox','',1),(19632,'120301','deals-mobile','block-19631','Html_box','',1),(19633,'120302','deals-mobile','block-19631-2','Rma\\DocumentData','',1),(19634,'120303','deals-mobile','block-19626','BlockBox','',2),(19635,'120304','deals-mobile','block-19634','Html_box','',1),(19636,'120305','deals-mobile','block-19634-2','Rma\\DocumentData','',1),(19637,'120306','deals-mobile','block-19626','BlockBox','',3),(19638,'120307','deals-mobile','block-19637','BlockBox','',1),(19639,'120308','deals-mobile','block-19638','Html_box','',1),(19640,'120309','deals-mobile','block-19638-2','Rma\\DocumentData','',1),(19641,'120310','deals-mobile','block-19637-2','BlockBox','',1),(19642,'120311','deals-mobile','block-19641','Html_box','',1),(19643,'120312','deals-mobile','block-19641-2','Rma\\DocumentData','',1),(19644,'120313','deals-mobile','block-19626','BlockBox','',4),(19645,'120314','deals-mobile','block-19644','BlockBox','',1),(19646,'120315','deals-mobile','block-19645','Html_box','',1),(19647,'120316','deals-mobile','block-19645-2','Rma\\DocumentData','',1),(19648,'120317','deals-mobile','block-19644-2','BlockBox','',1),(19649,'120318','deals-mobile','block-19648','Html_box','',1),(19650,'120319','deals-mobile','block-19648-2','Rma\\DocumentData','',1),(19651,'120320','deals-mobile','block-19626','BlockBox','',5),(19652,'120321','deals-mobile','block-19651','BlockBox','',1),(19653,'120322','deals-mobile','block-19652','Html_box','',1),(19654,'120323','deals-mobile','block-19652-2','Rma\\DocumentData','',1),(19655,'120324','deals-mobile','block-19651-2','BlockBox','',1),(19656,'120325','deals-mobile','block-19655','Html_box','',1),(19657,'120326','deals-mobile','block-19655-2','Rma\\DocumentData','',1),(19658,'120327','deals-mobile','block-19602-2','BlockBox','',1),(19659,'120328','deals-mobile','block-19658','Logo','',1),(19660,'120329','deals-mobile','block-19658','Html_box','',2),(19661,'120330','deals-mobile','rows','BlockBox','',1),(19662,'120331','deals-mobile','block-19661','BlockBox','',2),(19663,'120332','deals-mobile','block-19662','BlockBox','',2),(19664,'120333','deals-mobile','block-19663','BlockBox','',3),(19665,'120334','deals-mobile','block-19664','productListing\\rating','',1),(19666,'120335','deals-mobile','block-19664','productListing\\ratingCounts','',2),(19667,'120336','deals-mobile','block-19663','productListing\\bonusPoints','',1),(19668,'120337','deals-mobile','block-19663','productListing\\image','',2),(19669,'120338','deals-mobile','block-19663-2','productListing\\model','',3),(19670,'120339','deals-mobile','block-19663-2','productListing\\name','',1),(19671,'120340','deals-mobile','block-19663-2','productListing\\description','',2),(19672,'120341','deals-mobile','block-19663-2','productListing\\attributes','',4),(19673,'120342','deals-mobile','block-19662-2','BlockBox','',1),(19674,'120343','deals-mobile','block-19673','productListing\\stock','',1),(19675,'120344','deals-mobile','block-19673','productListing\\price','',2),(19676,'120345','deals-mobile','block-19673','productListing\\wishlistButton','',6),(19677,'120346','deals-mobile','block-19673','productListing\\qtyInput','',3),(19678,'120347','deals-mobile','block-19673','productListing\\compare','',5),(19679,'120348','deals-mobile','block-19673','productListing\\buyButton','',4),(19680,'120349','deals-mobile','sample','BlockBox','',1),(19681,'120350','deals-mobile','block-19680','sample\\Products','',2),(19682,'120351','deals-mobile','block-19680','sample\\CheckoutBtn','',3),(19683,'120352','deals-mobile','block-19680','Text','',1),(19684,'120353','deals-mobile','samples','BlockBox','',1),(19685,'120354','deals-mobile','block-19684','BlockBox','',1),(19686,'120355','deals-mobile','block-19685','WidgetsAria','',1),(19687,'120356','deals-mobile','block-19685-2','Html_box','',1),(19688,'120357','deals-mobile','block-19685-2','Samples\\SamplesHistory','',2),(19689,'120358','deals-mobile','sample_info','BlockBox','',1),(19690,'120359','deals-mobile','block-19689','BlockBox','',1),(19691,'120360','deals-mobile','block-19690','WidgetsAria','',1),(19692,'120361','deals-mobile','block-19690-2','Html_box','',6),(19693,'120362','deals-mobile','block-19690-2','BlockBox','',2),(19694,'120363','deals-mobile','block-19693','BlockBox','',4),(19695,'120364','deals-mobile','block-19694','Html_box','',1),(19696,'120365','deals-mobile','block-19694','Samples\\SampleData','',2),(19697,'120366','deals-mobile','block-19693','BlockBox','',1),(19698,'120367','deals-mobile','block-19697','Samples\\SampleData','',2),(19699,'120368','deals-mobile','block-19697','Html_box','',1),(19700,'120369','deals-mobile','block-19693-2','BlockBox','',1),(19701,'120370','deals-mobile','block-19700','Html_box','',1),(19702,'120371','deals-mobile','block-19700','Samples\\SampleData','',2),(19703,'120372','deals-mobile','block-19693-2','BlockBox','',2),(19704,'120373','deals-mobile','block-19703','Samples\\SampleData','',2),(19705,'120374','deals-mobile','block-19703','Html_box','',1),(19706,'120375','deals-mobile','block-19693-3','BlockBox','',1),(19707,'120376','deals-mobile','block-19706','Html_box','',1),(19708,'120377','deals-mobile','block-19706','Samples\\SampleData','',2),(19709,'120378','deals-mobile','block-19693-3','BlockBox','',2),(19710,'120379','deals-mobile','block-19709','Samples\\SampleData','',2),(19711,'120380','deals-mobile','block-19709','Html_box','',1),(19712,'120381','deals-mobile','block-19690-2','Html_box','',3),(19713,'120382','deals-mobile','block-19690-2','Samples\\SampleProducts','',4),(19714,'120383','deals-mobile','block-19690-2','Samples\\SampleSubTotal','',5),(19715,'120384','deals-mobile','block-19690-2','BlockBox','',8),(19716,'120385','deals-mobile','block-19715','account\\AccountLink','',1),(19717,'120386','deals-mobile','block-19690-2','Samples\\SampleHistory','',7),(19718,'120387','deals-mobile','block-19690-2','Html_box','',1),(19719,'120388','deals-mobile','sample_info','BlockBox','',1),(19720,'120389','deals-mobile','block-19719','BlockBox','',1),(19721,'120390','deals-mobile','block-19720','WidgetsAria','',1),(19722,'120391','deals-mobile','block-19720-2','Html_box','',3),(19723,'120392','deals-mobile','block-19720-2','account\\OrdersHistory','',4),(19724,'120393','deals-mobile','block-19720-2','Html_box','',1),(19725,'120394','deals-mobile','block-19720-2','BlockBox','',2),(19726,'120395','deals-mobile','block-19725','Html_box','',1),(19727,'120396','deals-mobile','block-19725','account\\LastOrder','',2),(19728,'120397','deals-mobile','block-19725-2','Html_box','',1),(19729,'120398','deals-mobile','block-19725-2','account\\AccountLink','',3),(19730,'120399','deals-mobile','block-19725-2','account\\OrderCount','',2),(19731,'120400','deals-mobile','block-19725-3','Html_box','',1),(19732,'120401','deals-mobile','block-19725-3','account\\TotalOrdered','',2),(19733,'120402','deals-mobile','block-19725-4','Html_box','',1),(19734,'120403','deals-mobile','block-19725-4','account\\AccountLink','',3),(19735,'120404','deals-mobile','block-19725-4','account\\CreditAmount','',2),(19736,'120405','deals-mobile','block-19725-5','account\\AccountLink','',3),(19737,'120406','deals-mobile','block-19725-5','account\\PointsEarnt','',2),(19738,'120407','deals-mobile','block-19725-5','Html_box','',1),(19739,'120408','deals-mobile','block-19720-2','BlockBox','',5),(19740,'120409','deals-mobile','block-19739','account\\GiftCards','',6),(19741,'120410','deals-mobile','block-19739','Html_box','',1),(19742,'120411','deals-mobile','block-19720-2','Html_box','',5),(19743,'120412','deals-mobile','sitemap','BlockBox','',1),(19744,'120413','deals-mobile','block-19743','BlockBox','',2),(19745,'120414','deals-mobile','block-19744','Menu','Account box',6),(19746,'120415','deals-mobile','block-19744','sitemap\\InfoPages','',2),(19747,'120416','deals-mobile','block-19744','Html_box','',5),(19748,'120417','deals-mobile','block-19744','sitemap\\Categories','',4),(19749,'120418','deals-mobile','block-19744','Html_box','',3),(19750,'120419','deals-mobile','block-19744','Html_box','',1),(19751,'120420','deals-mobile','block-19744-2','Html_box','',1),(19752,'120421','deals-mobile','block-19744-2','sitemap\\DeliveryLocation','',2),(19753,'120422','deals-mobile','block-19743','Html_box','',1),(19754,'120423','deals-mobile','subscribe','BlockBox','',1),(19755,'120424','deals-mobile','block-19754','subscribers\\SubscribeForm','',2),(19756,'120425','deals-mobile','block-19754','Html_box','',1),(19757,'120426','deals-mobile','block-19754','Html_box','',3),(19758,'120427','deals-mobile','block-19754','subscribers\\UnsubscribeForm','',4),(19759,'120428','deals-mobile','subscribed','BlockBox','',1),(19760,'120429','deals-mobile','block-19759','Html_box','',1),(19761,'120430','deals-mobile','subscription','BlockBox','',2),(19762,'120431','deals-mobile','block-19761','BlockBox','',1),(19763,'120432','deals-mobile','block-19762','WidgetsAria','',1),(19764,'120433','deals-mobile','block-19762-2','Html_box','',2),(19765,'120434','deals-mobile','block-19762-2','Html_box','',3),(19766,'120435','deals-mobile','block-19762-2','account\\Subscription','',4),(19767,'120436','deals-mobile','success','BlockBox','',1),(19768,'120437','deals-mobile','block-19767','BlockBox','',1),(19769,'120438','deals-mobile','block-19768','Text','',2),(19770,'120439','deals-mobile','block-19768','BlockBox','',3),(19771,'120440','deals-mobile','block-19770','Html','',3),(19772,'120441','deals-mobile','block-19770-2','success\\PrintBtn','',1),(19773,'120442','deals-mobile','block-19770-3','success\\ContinueBtn','',1),(19774,'120443','deals-mobile','success_q','BlockBox','',1),(19775,'120444','deals-mobile','block-19774','BlockBox','',1),(19776,'120445','deals-mobile','block-19775','BlockBox','',2),(19777,'120446','deals-mobile','block-19776','success\\PrintBtn','',1),(19778,'120447','deals-mobile','block-19776','success\\ContinueBtn','',2),(19779,'120448','deals-mobile','block-19775','Html_box','',1),(19783,'120452','deals-mobile','ticket','invoice\\Container','',1),(19784,'120453','deals-mobile','block-19783','BlockBox','',1),(19785,'120454','deals-mobile','block-19784-2','BlockBox','',1),(19786,'120455','deals-mobile','block-19785','invoice\\StoreAddress','',1),(19787,'120456','deals-mobile','block-19784-2','BlockBox','',2),(19788,'120457','deals-mobile','block-19787','Text','',1),(19789,'120458','deals-mobile','block-19787-2','invoice\\StorePhone','',1),(19790,'120459','deals-mobile','block-19784-2','BlockBox','',4),(19791,'120460','deals-mobile','block-19790','Text','',1),(19792,'120461','deals-mobile','block-19790-2','invoice\\StoreSite','',1),(19793,'120462','deals-mobile','block-19784-2','BlockBox','',3),(19794,'120463','deals-mobile','block-19793','Text','',1),(19795,'120464','deals-mobile','block-19793-2','invoice\\StoreEmail','',1),(19796,'120465','deals-mobile','block-19783','BlockBox','',2),(19797,'120466','deals-mobile','block-19796','BlockBox','',7),(19798,'120467','deals-mobile','block-19797','BlockBox','',1),(19799,'120468','deals-mobile','block-19798','Text','',1),(19800,'120469','deals-mobile','block-19798','invoice\\BillingAddress','',2),(19801,'120470','deals-mobile','block-19797-2','BlockBox','',1),(19802,'120471','deals-mobile','block-19801','Text','',3),(19803,'120472','deals-mobile','block-19801','Text','',5),(19804,'120473','deals-mobile','block-19801','Text','',1),(19805,'120474','deals-mobile','block-19801','invoice\\CustomerPhone','',4),(19806,'120475','deals-mobile','block-19801','invoice\\CustomerName','',2),(19807,'120476','deals-mobile','block-19801','invoice\\CustomerEmail','',6),(19808,'120477','deals-mobile','block-19796','BlockBox','',8),(19809,'120478','deals-mobile','block-19808','BlockBox','',1),(19810,'120479','deals-mobile','block-19809','Text','',1),(19811,'120480','deals-mobile','block-19809','invoice\\ShippingMethod','',2),(19812,'120481','deals-mobile','block-19808-2','BlockBox','',1),(19813,'120482','deals-mobile','block-19812','invoice\\ShippingMethod','',2),(19814,'120483','deals-mobile','block-19812','Text','',1),(19815,'120484','deals-mobile','block-19796-2','Text','',2),(19816,'120485','deals-mobile','block-19796-2','invoice\\OrderBarcode','',6),(19817,'120486','deals-mobile','block-19796-2','Text','',4),(19818,'120487','deals-mobile','block-19796-2','invoice\\OrderId','',1),(19819,'120488','deals-mobile','block-19796-2','invoice\\PaymentDate','',3),(19820,'120489','deals-mobile','block-19796-2','invoice\\PaymentMethod','',5),(19821,'120490','deals-mobile','block-19783','BlockBox','',5),(19822,'120491','deals-mobile','block-19821','Text','',1),(19823,'120492','deals-mobile','block-19821','invoice\\StoreAddress','',8),(19824,'120493','deals-mobile','block-19821-2','Logo','',1),(19825,'120494','deals-mobile','block-19821-2','Text','',2),(19826,'120495','deals-mobile','block-19821-3','BlockBox','',2),(19827,'120496','deals-mobile','block-19826','Text','',1),(19828,'120497','deals-mobile','block-19826-2','invoice\\StorePhone','',1),(19829,'120498','deals-mobile','block-19821-3','Text','',1),(19830,'120499','deals-mobile','block-19821-3','BlockBox','',3),(19831,'120500','deals-mobile','block-19830','Text','',1),(19832,'120501','deals-mobile','block-19830-2','invoice\\StoreEmail','',1),(19833,'120502','deals-mobile','block-19783','invoice\\Products','',3),(19834,'120503','deals-mobile','block-19783','BlockBox','',4),(19835,'120504','deals-mobile','block-19834','BlockBox','',1),(19836,'120505','deals-mobile','block-19835','invoice\\ShippingAddress','',2),(19837,'120506','deals-mobile','block-19835','Text','',1),(19838,'120507','deals-mobile','block-19834-2','BlockBox','',1),(19839,'120508','deals-mobile','block-19838','invoice\\Totals','',1),(19840,'120509','deals-mobile','tl_blog_category','BlockBox','',1),(19841,'120510','deals-mobile','block-19840','BlockBox','',1),(19842,'120511','deals-mobile','block-19841','BlockBox','',1),(19843,'120512','deals-mobile','block-19842','Blog\\widget\\PostListing','',1),(19844,'120513','deals-mobile','block-19842','catalog\\Paging','',2),(19845,'120514','deals-mobile','block-19841-2','WidgetsAria','',1),(19846,'120515','deals-mobile','tl_blog_index','BlockBox','',2),(19847,'120516','deals-mobile','block-19846','BlockBox','',2),(19848,'120517','deals-mobile','block-19847','BlockBox','',1),(19849,'120518','deals-mobile','block-19848','Blog\\widget\\PostListing','',1),(19850,'120519','deals-mobile','block-19848','catalog\\Paging','',2),(19851,'120520','deals-mobile','block-19847-2','WidgetsAria','',1),(19852,'120521','deals-mobile','block-19846','Banner','',1),(19853,'120522','deals-mobile','tl_blog_post','BlockBox','',1),(19854,'120523','deals-mobile','block-19853','BlockBox','',3),(19855,'120524','deals-mobile','block-19854','Blog\\widget\\PostTags','',2),(19856,'120525','deals-mobile','block-19854','BlockBox','',3),(19857,'120526','deals-mobile','block-19856','Html_box','',1),(19858,'120527','deals-mobile','block-19856','Blog\\widget\\PostLinkedProducts','',2),(19859,'120528','deals-mobile','block-19854','BlockBox','',1),(19860,'120529','deals-mobile','block-19859','Blog\\widget\\PostTitle','',3),(19861,'120530','deals-mobile','block-19859','Blog\\widget\\PostImage','',1),(19862,'120531','deals-mobile','block-19859','Blog\\widget\\PostDescription','',4),(19863,'120532','deals-mobile','block-19859','BlockBox','',5),(19864,'120533','deals-mobile','block-19863','Blog\\widget\\PostViewed','',1),(19865,'120534','deals-mobile','block-19859','Blog\\widget\\PostDate','',2),(19866,'120535','deals-mobile','block-19854-2','WidgetsAria','',1),(19867,'120536','deals-mobile','tl_blog_tags','BlockBox','',1),(19868,'120537','deals-mobile','block-19867','BlockBox','',1),(19869,'120538','deals-mobile','block-19868','BlockBox','',1),(19870,'120539','deals-mobile','block-19869','Blog\\widget\\PostListing','',1),(19871,'120540','deals-mobile','block-19869','catalog\\Paging','',2),(19872,'120541','deals-mobile','block-19868-2','WidgetsAria','',1),(19873,'120542','deals-mobile','tracking_numbers','BlockBox','',1),(19874,'120543','deals-mobile','block-19873','account\\OrderTracking','',2),(19875,'120544','deals-mobile','block-19873','Html_box','',1),(19876,'120545','deals-mobile','trade_form','BlockBox','',1),(19877,'120546','deals-mobile','block-19876','BlockBox','',3),(19878,'120547','deals-mobile','block-19877','BlockBox','',1),(19879,'120548','deals-mobile','block-19878','account\\CustomerAdditionalField','',2),(19880,'120549','deals-mobile','block-19878','account\\CustomerAdditionalField','',1),(19881,'120550','deals-mobile','block-19876','BlockBox','',14),(19882,'120551','deals-mobile','block-19881','account\\BackButton','',1),(19883,'120552','deals-mobile','block-19881-2','account\\PdfButton','',2),(19884,'120553','deals-mobile','block-19881-2','account\\SaveButton','',1),(19885,'120554','deals-mobile','block-19876','BlockBox','',13),(19886,'120555','deals-mobile','block-19885','BlockBox','',1),(19887,'120556','deals-mobile','block-19886','account\\CustomerAdditionalField','',1),(19888,'120557','deals-mobile','block-19885-2','BlockBox','',1),(19889,'120558','deals-mobile','block-19888','account\\CustomerAdditionalField','',1),(19890,'120559','deals-mobile','block-19876','Html_box','',10),(19891,'120560','deals-mobile','block-19876','Html_box','',8),(19892,'120561','deals-mobile','block-19876','Html_box','',12),(19893,'120562','deals-mobile','block-19876','BlockBox','',11),(19894,'120563','deals-mobile','block-19893','BlockBox','',1),(19895,'120564','deals-mobile','block-19894','account\\CustomerAdditionalField','',4),(19896,'120565','deals-mobile','block-19894','account\\CustomerAdditionalField','',2),(19897,'120566','deals-mobile','block-19894','Html_box','',1),(19898,'120567','deals-mobile','block-19894','account\\CustomerAdditionalField','',3),(19899,'120568','deals-mobile','block-19893-2','BlockBox','',1),(19900,'120569','deals-mobile','block-19899','Html_box','',1),(19901,'120570','deals-mobile','block-19899','account\\CustomerAdditionalField','',3),(19902,'120571','deals-mobile','block-19899','account\\CustomerAdditionalField','',2),(19903,'120572','deals-mobile','block-19899','account\\CustomerAdditionalField','',4),(19904,'120573','deals-mobile','block-19876','BlockBox','',5),(19905,'120574','deals-mobile','block-19904','BlockBox','',1),(19906,'120575','deals-mobile','block-19905','account\\CustomerAdditionalField','',2),(19907,'120576','deals-mobile','block-19905','account\\CustomerAdditionalField','',1),(19908,'120577','deals-mobile','block-19876','BlockBox','',4),(19909,'120578','deals-mobile','block-19908','BlockBox','',1),(19910,'120579','deals-mobile','block-19909','account\\AddressesList','',2),(19911,'120580','deals-mobile','block-19909','Html_box','',1),(19912,'120581','deals-mobile','block-19909','account\\CustomerAdditionalField','',5),(19913,'120582','deals-mobile','block-19909','BlockBox','',3),(19914,'120583','deals-mobile','block-19913','account\\CustomerAdditionalField','',1),(19915,'120584','deals-mobile','block-19909','BlockBox','',4),(19916,'120585','deals-mobile','block-19915','BlockBox','',1),(19917,'120586','deals-mobile','block-19916','account\\CustomerAdditionalField','',1),(19918,'120587','deals-mobile','block-19916','account\\CustomerAdditionalField','',4),(19919,'120588','deals-mobile','block-19916','account\\CustomerAdditionalField','',2),(19920,'120589','deals-mobile','block-19916','account\\CustomerAdditionalField','',3),(19921,'120590','deals-mobile','block-19915-2','BlockBox','',1),(19922,'120591','deals-mobile','block-19921','account\\CustomerAdditionalField','',4),(19923,'120592','deals-mobile','block-19921','account\\CustomerAdditionalField','',3),(19924,'120593','deals-mobile','block-19921','account\\CustomerAdditionalField','',2),(19925,'120594','deals-mobile','block-19921','account\\CustomerAdditionalField','',1),(19926,'120595','deals-mobile','block-19908-2','BlockBox','',1),(19927,'120596','deals-mobile','block-19926','account\\AddressesList','',2),(19928,'120597','deals-mobile','block-19926','BlockBox','',3),(19929,'120598','deals-mobile','block-19928','BlockBox','',1),(19930,'120599','deals-mobile','block-19929','account\\CustomerAdditionalField','',1),(19931,'120600','deals-mobile','block-19929','account\\CustomerAdditionalField','',2),(19932,'120601','deals-mobile','block-19928-2','BlockBox','',1),(19933,'120602','deals-mobile','block-19932','account\\CustomerAdditionalField','',1),(19934,'120603','deals-mobile','block-19926','BlockBox','',4),(19935,'120604','deals-mobile','block-19934','BlockBox','',1),(19936,'120605','deals-mobile','block-19935','account\\CustomerAdditionalField','',2),(19937,'120606','deals-mobile','block-19935','account\\CustomerAdditionalField','',1),(19938,'120607','deals-mobile','block-19935','account\\CustomerAdditionalField','',3),(19939,'120608','deals-mobile','block-19934-2','BlockBox','',1),(19940,'120609','deals-mobile','block-19939','account\\CustomerAdditionalField','',2),(19941,'120610','deals-mobile','block-19939','account\\CustomerAdditionalField','',1),(19942,'120611','deals-mobile','block-19939','account\\CustomerAdditionalField','',3),(19943,'120612','deals-mobile','block-19926','Html_box','',1),(19944,'120613','deals-mobile','block-19876','BlockBox','',9),(19945,'120614','deals-mobile','block-19944','BlockBox','',1),(19946,'120615','deals-mobile','block-19945','account\\CustomerAdditionalField','',1),(19947,'120616','deals-mobile','block-19945','account\\CustomerAdditionalField','',2),(19948,'120617','deals-mobile','block-19944-2','BlockBox','',1),(19949,'120618','deals-mobile','block-19948','account\\CustomerAdditionalField','',1),(19950,'120619','deals-mobile','block-19876','Html_box','',2),(19951,'120620','deals-mobile','block-19876','BlockBox','',7),(19952,'120621','deals-mobile','block-19951','BlockBox','',1),(19953,'120622','deals-mobile','block-19952','account\\CustomerAdditionalField','',1),(19954,'120623','deals-mobile','block-19952','account\\CustomerAdditionalField','',2),(19955,'120624','deals-mobile','block-19951-2','BlockBox','',1),(19956,'120625','deals-mobile','block-19955','account\\CustomerAdditionalField','',1),(19957,'120626','deals-mobile','block-19955','account\\CustomerAdditionalField','',2),(19958,'120627','deals-mobile','block-19876','Html_box','',1),(19959,'120628','deals-mobile','block-19876','Html_box','',6),(19960,'120629','deals-mobile','trade_form_pdf','BlockBox','',1),(19961,'120630','deals-mobile','block-19960','BlockBox','',14),(19962,'120631','deals-mobile','block-19961','Html_box','',1),(19963,'120632','deals-mobile','block-19961-2','account\\CustomerAdditionalField','',1),(19964,'120633','deals-mobile','block-19960','BlockBox','',6),(19965,'120634','deals-mobile','block-19964','Html_box','',1),(19966,'120635','deals-mobile','block-19964-2','account\\CombinedField','',2),(19967,'120636','deals-mobile','block-19960','BlockBox','',13),(19968,'120637','deals-mobile','block-19967','Html_box','',1),(19969,'120638','deals-mobile','block-19967-2','account\\CustomerAdditionalField','',1),(19970,'120639','deals-mobile','block-19960','BlockBox','',12),(19971,'120640','deals-mobile','block-19970','Html_box','',1),(19972,'120641','deals-mobile','block-19970-2','account\\CombinedField','',2),(19973,'120642','deals-mobile','block-19960','BlockBox','',11),(19974,'120643','deals-mobile','block-19973','Html_box','',1),(19975,'120644','deals-mobile','block-19973-2','account\\CombinedField','',1),(19976,'120645','deals-mobile','block-19960','BlockBox','',9),(19977,'120646','deals-mobile','block-19976','Html_box','',1),(19978,'120647','deals-mobile','block-19976-2','account\\CustomerAdditionalField','',1),(19979,'120648','deals-mobile','block-19960','BlockBox','',8),(19980,'120649','deals-mobile','block-19979','Html_box','',1),(19981,'120650','deals-mobile','block-19979-2','BlockBox','',1),(19982,'120651','deals-mobile','block-19981','account\\CustomerAdditionalField','',1),(19983,'120652','deals-mobile','block-19981-2','BlockBox','',1),(19984,'120653','deals-mobile','block-19983','Html_box','',2),(19985,'120654','deals-mobile','block-19983-2','account\\CustomerAdditionalField','',1),(19986,'120655','deals-mobile','block-19960','BlockBox','',3),(19987,'120656','deals-mobile','block-19986','Html_box','',1),(19988,'120657','deals-mobile','block-19960','BlockBox','',1),(19989,'120658','deals-mobile','block-19988','Contacts','',1),(19990,'120659','deals-mobile','block-19988-2','Html_box','',1),(19991,'120660','deals-mobile','block-19960','BlockBox','',4),(19992,'120661','deals-mobile','block-19991-2','BlockBox','',1),(19993,'120662','deals-mobile','block-19992','BlockBox','',1),(19994,'120663','deals-mobile','block-19993','Html_box','',2),(19995,'120664','deals-mobile','block-19993-2','account\\CustomerAdditionalField','',1),(19996,'120665','deals-mobile','block-19992-2','BlockBox','',1),(19997,'120666','deals-mobile','block-19996','Html_box','',1),(19998,'120667','deals-mobile','block-19996-2','account\\CustomerAdditionalField','',1),(19999,'120668','deals-mobile','block-19960','BlockBox','',2),(20000,'120669','deals-mobile','block-19999','Contacts','',1),(20001,'120670','deals-mobile','block-19960','BlockBox','',7),(20002,'120671','deals-mobile','block-20001','Html_box','',1),(20003,'120672','deals-mobile','block-20001-2','account\\CustomerAdditionalField','',1),(20004,'120673','deals-mobile','block-19960','BlockBox','',5),(20005,'120674','deals-mobile','block-20004','Html_box','',1),(20006,'120675','deals-mobile','block-20004-2','account\\CustomerAdditionalField','',1),(20007,'120676','deals-mobile','block-19960','BlockBox','',10),(20008,'120677','deals-mobile','block-20007','Html_box','',1),(20009,'120678','deals-mobile','block-20007-2','account\\CustomerAdditionalField','',1),(20010,'120679','deals-mobile','block-19960','BlockBox','',18),(20011,'120680','deals-mobile','block-20010','Html_box','',1),(20012,'120681','deals-mobile','block-20010-2','account\\CustomerAdditionalField','',1),(20013,'120682','deals-mobile','block-19960','BlockBox','',15),(20014,'120683','deals-mobile','block-20013','Html_box','',1),(20015,'120684','deals-mobile','block-19960','BlockBox','',17),(20016,'120685','deals-mobile','block-20015','Html_box','',1),(20017,'120686','deals-mobile','block-19960','BlockBox','',20),(20018,'120687','deals-mobile','block-20017','Html_box','',1),(20019,'120688','deals-mobile','block-20017-2','account\\CustomerAdditionalField','',1),(20020,'120689','deals-mobile','block-19960','BlockBox','',19),(20021,'120690','deals-mobile','block-20020','Html_box','',1),(20022,'120691','deals-mobile','block-20020-2','account\\CustomerAdditionalField','',1),(20023,'120692','deals-mobile','block-19960','BlockBox','',16),(20024,'120693','deals-mobile','block-20023','Html_box','',1),(20025,'120694','deals-mobile','block-20023-2','BlockBox','',1),(20026,'120695','deals-mobile','block-20025','account\\CustomerAdditionalField','',1),(20027,'120696','deals-mobile','block-20025-2','Html_box','',1),(20028,'120697','deals-mobile','block-20025-3','account\\CustomerAdditionalField','',1),(20029,'120698','deals-mobile','block-20023-3','BlockBox','',1),(20030,'120699','deals-mobile','block-19960','BlockBox','',23),(20031,'120700','deals-mobile','block-20030','Html_box','',1),(20032,'120701','deals-mobile','block-20030-2','account\\CustomerAdditionalField','',1),(20033,'120702','deals-mobile','block-19960','BlockBox','',21),(20034,'120703','deals-mobile','block-20033','Html_box','',1),(20035,'120704','deals-mobile','block-19960','BlockBox','',26),(20036,'120705','deals-mobile','block-20035','Html_box','',1),(20037,'120706','deals-mobile','block-19960','BlockBox','',24),(20038,'120707','deals-mobile','block-20037','Html_box','',1),(20039,'120708','deals-mobile','block-20037-2','account\\CustomerAdditionalField','',1),(20040,'120709','deals-mobile','block-19960','BlockBox','',25),(20041,'120710','deals-mobile','block-20040','Html_box','',1),(20042,'120711','deals-mobile','block-19960','BlockBox','',22),(20043,'120712','deals-mobile','block-20042','Html_box','',1),(20044,'120713','deals-mobile','block-20042-2','account\\CustomerAdditionalField','',1),(20045,'120714','deals-mobile','block-19960','BlockBox','',27),(20046,'120715','deals-mobile','block-20045','Html_box','',1),(20047,'120716','deals-mobile','block-20045-2','Html_box','',1),(20048,'120717','deals-mobile','block-20045-3','Html_box','',1),(20049,'120718','deals-mobile','block-20045-4','Html_box','',1),(20050,'120719','deals-mobile','block-19960','BlockBox','',28),(20051,'120720','deals-mobile','block-20050','Html_box','',1),(20052,'120721','deals-mobile','block-20050-2','account\\CustomerAdditionalField','',1),(20053,'120722','deals-mobile','block-20050-3','Html_box','',1),(20054,'120723','deals-mobile','block-20050-4','account\\CustomerAdditionalField','',1),(20055,'120724','deals-mobile','block-19960','BlockBox','',29),(20056,'120725','deals-mobile','block-20055','Html_box','',1),(20057,'120726','deals-mobile','unsubscribed','BlockBox','',1),(20058,'120727','deals-mobile','block-20057','Html_box','',1),(20059,'120728','deals-mobile','update-and-pay-order_confirmation','BlockBox','',1),(20060,'120729','deals-mobile','block-20059','BlockBox','',3),(20061,'120730','deals-mobile','block-20060','BlockBox','',1),(20062,'120731','deals-mobile','block-20061','BlockBox','',1),(20063,'120732','deals-mobile','block-20062','BlockBox','',1),(20064,'120733','deals-mobile','block-20063','Html_box','',4),(20065,'120734','deals-mobile','block-20063','Html_box','',2),(20066,'120735','deals-mobile','block-20063','Html_box','',1),(20067,'120736','deals-mobile','block-20063','order\\ShippingMethod','',5),(20068,'120737','deals-mobile','block-20063','order\\DeliveryAddress','',3),(20069,'120738','deals-mobile','block-20063','order\\Telephone','',8),(20070,'120739','deals-mobile','block-20063','order\\Email','',9),(20071,'120740','deals-mobile','block-20063','order\\Name','',7),(20072,'120741','deals-mobile','block-20063','Html_box','',6),(20073,'120742','deals-mobile','block-20062-2','BlockBox','',1),(20074,'120743','deals-mobile','block-20073','order\\BillingAddress','',3),(20075,'120744','deals-mobile','block-20073','UpdateAndPay\\PayConfirm','',5),(20076,'120745','deals-mobile','block-20073','Html_box','',1),(20077,'120746','deals-mobile','block-20073','Html_box','',2),(20078,'120747','deals-mobile','block-20073','Html_box','',4),(20079,'120748','deals-mobile','block-20061','BlockBox','',3),(20080,'120749','deals-mobile','block-20079','order\\Products','',2),(20081,'120750','deals-mobile','block-20079','Html_box','',1),(20082,'120751','deals-mobile','block-20060-2','BlockBox','',1),(20083,'120752','deals-mobile','block-20082','Html_box','',1),(20084,'120753','deals-mobile','block-20082','checkout\\ContinueBtn','',3),(20085,'120754','deals-mobile','block-20082','order\\Totals','',2),(20086,'120755','deals-mobile','block-20059','account\\OrderHeading','',1),(20087,'120756','deals-mobile','update-and-pay-order_pay','BlockBox','',1),(20088,'120757','deals-mobile','block-20087','BlockBox','',3),(20089,'120758','deals-mobile','block-20088','BlockBox','',1),(20090,'120759','deals-mobile','block-20089','BlockBox','',3),(20091,'120760','deals-mobile','block-20090','Html_box','',1),(20092,'120761','deals-mobile','block-20090','order\\Products','',2),(20093,'120762','deals-mobile','block-20089','BlockBox','',1),(20094,'120763','deals-mobile','block-20093','BlockBox','',1),(20095,'120764','deals-mobile','block-20094','order\\Name','',7),(20096,'120765','deals-mobile','block-20094','order\\Email','',9),(20097,'120766','deals-mobile','block-20094','order\\DeliveryAddress','',3),(20098,'120767','deals-mobile','block-20094','Html_box','',6),(20099,'120768','deals-mobile','block-20094','order\\Telephone','',8),(20100,'120769','deals-mobile','block-20094','Html_box','',2),(20101,'120770','deals-mobile','block-20094','order\\ShippingMethod','',5),(20102,'120771','deals-mobile','block-20094','Html_box','',4),(20103,'120772','deals-mobile','block-20094','Html_box','',1),(20104,'120773','deals-mobile','block-20093-2','BlockBox','',1),(20105,'120774','deals-mobile','block-20104','Html_box','',2),(20106,'120775','deals-mobile','block-20104','Html_box','',1),(20107,'120776','deals-mobile','block-20104','Html_box','',4),(20108,'120777','deals-mobile','block-20104','order\\BillingAddress','',3),(20109,'120778','deals-mobile','block-20104','UpdateAndPay\\PayForm','',5),(20110,'120779','deals-mobile','block-20088-2','BlockBox','',1),(20111,'120780','deals-mobile','block-20110','order\\Totals','',2),(20112,'120781','deals-mobile','block-20110','Html_box','',1),(20113,'120782','deals-mobile','block-20110','checkout\\ContinueBtn','',3),(20114,'120783','deals-mobile','block-20087','account\\OrderHeading','',1),(20115,'120784','deals-mobile','wedding_index','BlockBox','',1),(20116,'120785','deals-mobile','block-20115','BlockBox','',1),(20117,'120786','deals-mobile','block-20116','WeddingRegistry\\widgets\\ViewCreateRegistryWidget','',2),(20118,'120787','deals-mobile','block-20116','WeddingRegistry\\widgets\\SearchRegistryButton','',3),(20119,'120788','deals-mobile','block-20116','Heading','',1),(20120,'120789','deals-mobile','wedding_manage','BlockBox','',2),(20121,'120790','deals-mobile','block-20120','WeddingRegistry\\widgets\\Photos','',1),(20122,'120791','deals-mobile','block-20120-2','WeddingRegistry\\widgets\\ManageNames','',1),(20123,'120792','deals-mobile','block-20120-2','BlockBox','',3),(20124,'120793','deals-mobile','block-20123','WeddingRegistry\\widgets\\EditLink','',1),(20125,'120794','deals-mobile','block-20123','WeddingRegistry\\widgets\\DeleteLink','',2),(20126,'120795','deals-mobile','block-20123','WeddingRegistry\\widgets\\ShareLink','',3),(20127,'120796','deals-mobile','block-20120-2','WeddingRegistry\\widgets\\ManageDate','',2),(20128,'120797','deals-mobile','block-20120-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(20129,'120798','deals-mobile','wedding_manage','WeddingRegistry\\widgets\\ManageBanner','',1),(20130,'120799','deals-mobile','wedding_manage','WeddingRegistry\\widgets\\AddItemsLink','',3),(20131,'120800','deals-mobile','wedding_manage','WeddingRegistry\\widgets\\Products','',4),(20135,'120804','deals-mobile','wedding_search','BlockBox','',1),(20136,'120805','deals-mobile','block-20135','WeddingRegistry\\widgets\\SearchList','',2),(20137,'120806','deals-mobile','block-20135','WeddingRegistry\\widgets\\SearchPaging','',3),(20138,'120807','deals-mobile','block-20135','BlockBox','',1),(20139,'120808','deals-mobile','block-20138','BlockBox','',1),(20140,'120809','deals-mobile','block-20139','WeddingRegistry\\widgets\\SearchForm','',2),(20141,'120810','deals-mobile','block-20139','Html_box','',1),(20142,'120811','deals-mobile','wedding_share','BlockBox','',1),(20143,'120812','deals-mobile','block-20142','BlockBox','',4),(20144,'120813','deals-mobile','block-20143-2','Html_box','',3),(20145,'120814','deals-mobile','block-20143-2','Html_box','',1),(20146,'120815','deals-mobile','block-20143-2','WeddingRegistry\\widgets\\ShareUrl','',2),(20147,'120816','deals-mobile','block-20143-2','WeddingRegistry\\widgets\\InviteList','',4),(20148,'120817','deals-mobile','block-20142','WeddingRegistry\\widgets\\ManageBanner','',1),(20149,'120818','deals-mobile','block-20142','WeddingRegistry\\widgets\\Photos','',2),(20150,'120819','deals-mobile','block-20142','Html_box','',3),(20151,'120820','deals-mobile','wedding_success','Html_box','',1),(20152,'120821','deals-mobile','wedding_success','WeddingRegistry\\widgets\\BackButton','',2),(20153,'120822','deals-mobile','wedding_update','BlockBox','',2),(20154,'120823','deals-mobile','block-20153','BlockBox','',1),(20155,'120824','deals-mobile','block-20154','Html_box','',5),(20156,'120825','deals-mobile','block-20154','Html_box','',3),(20157,'120826','deals-mobile','block-20154','WeddingRegistry\\widgets\\Details','',4),(20158,'120827','deals-mobile','block-20154','WeddingRegistry\\widgets\\Names','',2),(20159,'120828','deals-mobile','block-20154','Html_box','',1),(20160,'120829','deals-mobile','block-20154','WeddingRegistry\\widgets\\ShareRegistry','',6),(20161,'120830','deals-mobile','block-20153-2','BlockBox','',1),(20162,'120831','deals-mobile','block-20161','WeddingRegistry\\widgets\\ShippingDetails','',2),(20163,'120832','deals-mobile','block-20161','Html_box','',1),(20164,'120833','deals-mobile','block-20161','Html_box','',5),(20165,'120834','deals-mobile','block-20161','WeddingRegistry\\widgets\\Photos','',6),(20166,'120835','deals-mobile','block-20161','Html_box','',3),(20167,'120836','deals-mobile','block-20161','WeddingRegistry\\widgets\\InformationText','',4),(20168,'120837','deals-mobile','wedding_update','Html_box','',1),(20169,'120838','deals-mobile','wedding_update','BlockBox','',3),(20170,'120839','deals-mobile','block-20169','WeddingRegistry\\widgets\\BackButton','',1),(20171,'120840','deals-mobile','block-20169-2','WeddingRegistry\\widgets\\SaveButton','',1),(20172,'120841','deals-mobile','wedding_view','WeddingRegistry\\widgets\\ManageBanner','',1),(20173,'120842','deals-mobile','wedding_view','BlockBox','',2),(20174,'120843','deals-mobile','block-20173','WeddingRegistry\\widgets\\Photos','',1),(20175,'120844','deals-mobile','block-20173-2','WeddingRegistry\\widgets\\ManageDate','',2),(20176,'120845','deals-mobile','block-20173-2','WeddingRegistry\\widgets\\ManageNames','',1),(20177,'120846','deals-mobile','block-20173-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(20178,'120847','deals-mobile','wedding_view','WeddingRegistry\\widgets\\Products','',6),(20179,'120848','deals-mobile','wishlist','BlockBox','',1),(20180,'120849','deals-mobile','block-20179','BlockBox','',1),(20181,'120850','deals-mobile','block-20180','WidgetsAria','',1),(20182,'120851','deals-mobile','block-20180-2','Html_box','',1),(20183,'120852','deals-mobile','block-20180-2','account\\Wishlist','',2),(20184,'120853','deals-mobile','wishlist-cart','BlockBox','',1),(20185,'120854','deals-mobile','block-20184','cart\\CartTabs','',1),(20186,'120855','deals-mobile','block-20185','account\\Wishlist','',1),(31803,'1683128325.0836','watch-mobile','block-31791','BlockBox',NULL,1),(36640,'1693578529.207944','watch-mobile','checkout','BlockBox','',1),(36641,'1693578529.311699','watch-mobile','block-36640','BlockBox','',2),(36642,'1693578529.313831','watch-mobile','block-36641','BlockBox','',2),(36643,'1693578529.315461','watch-mobile','block-36642','BlockBox','',5),(36644,'1693578529.317368','watch-mobile','block-36643','checkout\\Comments','',2),(36645,'1693578529.319136','watch-mobile','block-36643','Html_box','',1),(36646,'1693578529.322437','watch-mobile','block-36642','BlockBox','',4),(36647,'1693578529.324468','watch-mobile','block-36646','Html_box','',1),(36648,'1693578529.325521','watch-mobile','block-36646','BlockBox','',2),(36649,'1693578529.326795','watch-mobile','block-36648','CouponsAndVauchers\\Checkout','',1),(36650,'1693578529.329372','watch-mobile','block-36648-2','checkout\\CreditAmount','',1),(36651,'1693578529.331582','watch-mobile','block-36648-2','checkout\\BonusPoints','',2),(36652,'1693578529.333680','watch-mobile','block-36642','BlockBox','',2),(36653,'1693578529.335514','watch-mobile','block-36652','BlockBox','',3),(36654,'1693578529.337997','watch-mobile','block-36653','checkout\\ShippingChoice','',1),(36655,'1693578529.34334','watch-mobile','block-36652','Neighbour\\Checkout','',5),(36656,'1693578529.345418','watch-mobile','block-36652','BlockBox','',4),(36657,'1693578529.346757','watch-mobile','block-36656','BlockBox','',1),(36658,'1693578529.348387','watch-mobile','block-36657','checkout\\ShippingAddress','',2),(36659,'1693578529.351498','watch-mobile','block-36657','Html_box','',3),(36660,'1693578529.352777','watch-mobile','block-36657','checkout\\ContactInformation','',4),(36661,'1693578529.354142','watch-mobile','block-36657','UploadCustomerId\\UploadCustomerIdForm','',4),(36662,'1693578529.357732','watch-mobile','block-36656-2','BlockBox','',1),(36663,'1693578529.359364','watch-mobile','block-36662','checkout\\Shipping','',2),(36664,'1693578529.360426','watch-mobile','block-36662','DelayedDespatch\\Checkout','',3),(36665,'1693578529.361979','watch-mobile','block-36662','Html_box','',1),(36666,'1693578529.363439','watch-mobile','block-36652','Html_box','',2),(36667,'1693578529.364794','watch-mobile','block-36642','cart\\Products','',6),(36668,'1693578529.368484','watch-mobile','block-36642','checkout\\CreateAccount','',7),(36669,'1693578529.371247','watch-mobile','block-36642','BlockBox','',3),(36670,'1693578529.373462','watch-mobile','block-36669','Html_box','',1),(36671,'1693578529.374453','watch-mobile','block-36669','BlockBox','',2),(36672,'1693578529.375760','watch-mobile','block-36671','Html_box','',1),(36673,'1693578529.376655','watch-mobile','block-36671','checkout\\BillingAddress','',2),(36674,'1693578529.380694','watch-mobile','block-36671-2','BlockBox','',1),(36675,'1693578529.382181','watch-mobile','block-36674','checkout\\PaymentMethod','',2),(36676,'1693578529.383416','watch-mobile','block-36674','Html_box','',1),(36677,'1693578529.384233','watch-mobile','block-36642','BlockBox','',1),(36678,'1693578529.385877','watch-mobile','block-36677','checkout\\LoginOnForm','',0),(36679,'1693578529.387150','watch-mobile','block-36677','BlockBox','',1),(36680,'1693578529.387946','watch-mobile','block-36641-2','BlockBox','',1),(36681,'1693578529.434121','watch-mobile','block-36680','Html_box','',6),(36682,'1693578529.436482','watch-mobile','block-36680','Html_box','',1),(36683,'1693578529.437493','watch-mobile','block-36680','checkout\\Terms','',5),(36684,'1693578529.439185','watch-mobile','block-36680','checkout\\Totals','',3),(36685,'1693578529.439920','watch-mobile','block-36680','checkout\\ContinueBtn','',4),(36686,'1693578529.442458','watch-mobile','block-36680','cart\\Products','',2),(53913,'116005','furniture-mobile','404','Html_box','',1),(54010,'116102','furniture-mobile','account','BlockBox','',1),(54011,'116103','furniture-mobile','block-54010','BlockBox','',1),(54012,'116104','furniture-mobile','block-54011','WidgetsAria','',1),(54032,'116105','furniture-mobile','block-54011-2','account\\OrdersHistory','',5),(54033,'116106','furniture-mobile','block-54011-2','Html_box','',4),(54034,'116109','furniture-mobile','block-54011-2','Html_box','',1),(54035,'116112','furniture-mobile','block-54011-2','BlockBox','',2),(54036,'116113','furniture-mobile','block-54035','Html_box','',1),(54037,'116114','furniture-mobile','block-54035','account\\LastOrder','',2),(54038,'116115','furniture-mobile','block-54035-2','Html_box','',1),(54039,'116116','furniture-mobile','block-54035-2','account\\OrderCount','',2),(54040,'116117','furniture-mobile','block-54035-2','account\\AccountLink','',3),(54041,'116118','furniture-mobile','block-54035-3','Html_box','',1),(54042,'116119','furniture-mobile','block-54035-3','account\\TotalOrdered','',2),(54043,'116120','furniture-mobile','block-54035-4','Html_box','',1),(54044,'116121','furniture-mobile','block-54035-4','account\\CreditAmount','',2),(54045,'116122','furniture-mobile','block-54035-4','account\\AccountLink','',3),(54046,'116123','furniture-mobile','block-54035-5','account\\AccountLink','',3),(54047,'116124','furniture-mobile','block-54035-5','account\\PointsEarnt','',2),(54048,'116125','furniture-mobile','block-54035-5','Html_box','',1),(54049,'1639675618.1808','furniture-mobile','block-54011-2','Rma\\PrintReturn','',7),(54050,'1640098458.6988','furniture-mobile','block-54011-2','account\\SpendBalance','',3),(54070,'116145','furniture-mobile','account_edit','BlockBox','',1),(54071,'116146','furniture-mobile','block-54070','BlockBox','',1),(54072,'116147','furniture-mobile','block-54071','WidgetsAria','',1),(54092,'116148','furniture-mobile','block-54071-2','account\\AccountEdit','',2),(54093,'116149','furniture-mobile','block-54071-2','Html_box','',1),(54094,'116150','furniture-mobile','address_book','BlockBox','',1),(54095,'116151','furniture-mobile','block-54094','BlockBox','',1),(54096,'116152','furniture-mobile','block-54095','WidgetsAria','',1),(54116,'116153','furniture-mobile','block-54095-2','account\\AddressBook','',3),(54117,'116154','furniture-mobile','block-54095-2','Html_box','',1),(54118,'116155','furniture-mobile','block-54095-2','Html_box','',2),(54119,'116156','furniture-mobile','address_book_process','BlockBox','',1),(54120,'116157','furniture-mobile','block-54119','BlockBox','',1),(54121,'116158','furniture-mobile','block-54120','WidgetsAria','',1),(54141,'116159','furniture-mobile','block-54120-2','Html_box','',1),(54142,'116160','furniture-mobile','block-54120-2','account\\EditAddress','',2),(54143,'117906.000001','furniture-mobile','b2b','BlockBox','listing-item',1),(54144,'117907.000001','furniture-mobile','block-54143','BlockBox','',2),(54145,'117908.000001','furniture-mobile','block-54144','BlockBox','',2),(54146,'117909.000001','furniture-mobile','block-54145','productListing\\bonusPoints','',2),(54147,'117910.000001','furniture-mobile','block-54145','productListing\\image','',1),(54148,'117914.000001','furniture-mobile','block-54145-2','productListing\\name','',1),(54149,'117915.000001','furniture-mobile','block-54145-2','productListing\\description','',2),(54150,'117916.000001','furniture-mobile','block-54145-2','productListing\\model','',4),(54151,'117917.000001','furniture-mobile','block-54145-2','productListing\\attributes','',5),(54152,'120922.000001','furniture-mobile','block-54145-2','productListing\\properties','',3),(54153,'117918.000001','furniture-mobile','block-54144-2','BlockBox','',1),(54154,'117911.000001','furniture-mobile','block-54153','BlockBox','',3),(54155,'117912.000001','furniture-mobile','block-54154','productListing\\rating','',1),(54156,'117913.000001','furniture-mobile','block-54154','productListing\\ratingCounts','',2),(54157,'117919.000001','furniture-mobile','block-54153','productListing\\qtyInput','',4),(54158,'117920.000001','furniture-mobile','block-54153','productListing\\price','',2),(54159,'117922.000001','furniture-mobile','block-54153','productListing\\buyButton','',5),(54160,'117924.000001','furniture-mobile','block-54153','productListing\\stock','',1),(54161,'120924.000001','furniture-mobile','block-54153','BlockBox','',8),(54162,'120925.000001','furniture-mobile','block-54161','productListing\\compare','',3),(54163,'120926.000001','furniture-mobile','block-54161','productListing\\personalCatalog','',2),(54164,'120927.000001','furniture-mobile','block-54161','productListing\\viewButton','',1),(54165,'116176','furniture-mobile','batch','BlockBox','',1),(54166,'116177','furniture-mobile','block-54165','productListing\\attributes','',5),(54167,'116178','furniture-mobile','block-54165','productListing\\price','',6),(54168,'116179','furniture-mobile','block-54165','productListing\\name','',4),(54169,'116180','furniture-mobile','block-54165','productListing\\image','',2),(54170,'116181','furniture-mobile','block-54165','batchSelect','',1),(54171,'116182','furniture-mobile','batch_selected','BlockBox','',1),(54172,'116183','furniture-mobile','block-54171','BlockBox','',13),(54173,'116184','furniture-mobile','block-54172','productListing\\image','',1),(54174,'116185','furniture-mobile','block-54172-2','batchRemove','',1),(54175,'116186','furniture-mobile','block-54172-2','productListing\\price','',3),(54176,'116187','furniture-mobile','block-54172-2','productListing\\name','',2),(54177,'116188','furniture-mobile','bbbbb','BlockBox','',1),(54178,'116189','furniture-mobile','block-54177','BlockBox','',2),(54179,'116190','furniture-mobile','block-54178','Filters','',1),(54180,'116191','furniture-mobile','block-54178-2','BlockBox','',6),(54181,'116192','furniture-mobile','block-54180','catalog\\CountsItems','',1),(54182,'116193','furniture-mobile','block-54180-2','catalog\\Paging','',1),(54183,'116194','furniture-mobile','block-54178-2','catalog\\Image','',1),(54184,'116195','furniture-mobile','block-54178-2','Listing','',5),(54185,'116196','furniture-mobile','block-54178-2','catalog\\ImageMapCategory','',3),(54186,'116197','furniture-mobile','block-54178-2','BlockBox','',4),(54187,'116198','furniture-mobile','block-54186','catalog\\ListingLook','',1),(54188,'116199','furniture-mobile','block-54186','catalog\\CompareButton','',2),(54189,'116200','furniture-mobile','block-54186','catalog\\ItemsOnPage','',4),(54190,'116201','furniture-mobile','block-54186','catalog\\Sorting','',3),(54191,'116202','furniture-mobile','block-54178-2','Categories','',2),(54192,'116203','furniture-mobile','block-54177','catalog\\Title','',1),(54193,'116204','furniture-mobile','blog','BlockBox','',1),(54194,'116205','furniture-mobile','block-54193','BlockBox','',1),(54195,'116206','furniture-mobile','block-54194','BlogContent','',1),(54196,'116207','furniture-mobile','block-54194-2','BlogSidebar','',1),(54201,'1683110860.800967','furniture-mobile','cart','BlockBox','',1),(54202,'1683110860.811285','furniture-mobile','block-54201','BlockBox','',2),(54203,'1683110860.81452','furniture-mobile','block-54202','BlockBox','',4),(54204,'1683110860.815931','furniture-mobile','block-54203','Html_box','',1),(54205,'1683110860.818836','furniture-mobile','block-54203','cart\\UpSell','8',2),(54206,'1683110860.82112','furniture-mobile','block-54202','BlockBox','',1),(54207,'1683110860.82264','furniture-mobile','block-54206','cart\\Products','',4),(54208,'1683110860.823336','furniture-mobile','block-54206','BlockBox','',3),(54209,'1683110860.82490','furniture-mobile','block-54208','MultiCart\\CartSwitcher','',1),(54210,'1683110860.825674','furniture-mobile','block-54208','MultiCart\\SaveCart','',2),(54211,'1683110860.826797','furniture-mobile','block-54208-2','MultiCart\\Actions','',1),(54212,'1683110860.827896','furniture-mobile','block-54206','BlockBox','',5),(54213,'1683110860.829995','furniture-mobile','block-54212','cart\\DiscountCoupon','',1),(54214,'1683110860.830980','furniture-mobile','block-54212-2','cart\\BonusPoints','',3),(54215,'1683110860.831742','furniture-mobile','block-54212-2','cart\\CreditAmount','',2),(54216,'1683110860.83215','furniture-mobile','block-54212-3','cart\\FreeDelivery','',2),(54217,'1683110860.833430','furniture-mobile','block-54206','Html_box','',2),(54218,'1683110860.835461','furniture-mobile','block-54202','BlockBox','',3),(54219,'1683110860.837349','furniture-mobile','block-54218','cart\\GiveAway','',2),(54220,'1683110860.83786','furniture-mobile','block-54218','Html_box','',1),(54221,'1683110860.839462','furniture-mobile','block-54202','BlockBox','',5),(54222,'1683110860.841398','furniture-mobile','block-54221','Html_box','',1),(54223,'1683110860.84291','furniture-mobile','block-54221','cart\\ShippingEstimator','',2),(54224,'1683110860.843639','furniture-mobile','block-54202','cart\\DependedProducts','8',2),(54225,'1683110860.846971','furniture-mobile','block-54202-2','BlockBox','',1),(54226,'1683110860.849323','furniture-mobile','block-54225','BlockBox','',2),(54227,'1683110860.862447','furniture-mobile','block-54226','cart\\CheckoutBtn','',2),(54228,'1683110860.86420','furniture-mobile','block-54226','cart\\OrderTotal','',1),(54229,'1683110860.864695','furniture-mobile','block-54225','Html_box','',1),(54230,'116242','furniture-mobile','cart2','BlockBox','',2),(54231,'116243','furniture-mobile','block-54230','cart\\CartTabs','',2),(54232,'116244','furniture-mobile','block-54231','BlockBox','',1),(54233,'116245','furniture-mobile','block-54232','BlockBox','',4),(54234,'116246','furniture-mobile','block-54233','cart\\UpSell','6',2),(54235,'116247','furniture-mobile','block-54233','Html_box','',1),(54236,'116248','furniture-mobile','block-54232','BlockBox','',1),(54237,'116249','furniture-mobile','block-54236','cart\\Products','',3),(54238,'116250','furniture-mobile','block-54236','BlockBox','',2),(54239,'116251','furniture-mobile','block-54238','MultiCart\\CartSwitcher','',1),(54240,'116252','furniture-mobile','block-54238','MultiCart\\SaveCart','',2),(54241,'116253','furniture-mobile','block-54238-2','MultiCart\\Actions','',1),(54242,'116254','furniture-mobile','block-54232','BlockBox','',3),(54243,'116255','furniture-mobile','block-54242','cart\\GiveAway','',2),(54244,'116256','furniture-mobile','block-54242','Html_box','',1),(54245,'116257','furniture-mobile','block-54232','BlockBox','',2),(54246,'116258','furniture-mobile','block-54245','Html_box','',1),(54247,'116259','furniture-mobile','block-54245','BlockBox','',2),(54248,'116260','furniture-mobile','block-54247','cart\\DiscountCoupon','',1),(54249,'116261','furniture-mobile','block-54247-2','cart\\CreditAmount','',1),(54250,'116262','furniture-mobile','block-54247-3','cart\\BonusPoints','',1),(54251,'116263','furniture-mobile','block-54232','BlockBox','',5),(54252,'116264','furniture-mobile','block-54251','Html_box','',1),(54253,'116265','furniture-mobile','block-54251','cart\\ShippingEstimator','',2),(54254,'116266','furniture-mobile','block-54232-2','BlockBox','',1),(54255,'116267','furniture-mobile','block-54254','Html_box','',1),(54256,'116268','furniture-mobile','block-54254','BlockBox','',2),(54257,'116269','furniture-mobile','block-54256','Image','',4),(54258,'116270','furniture-mobile','block-54256','cart\\CheckoutBtn','',2),(54259,'116271','furniture-mobile','block-54256','cart\\OrderTotal','',1),(54270,'116272','furniture-mobile','categories','BlockBox','catalog-content',1),(54271,'116273','furniture-mobile','block-54270','BlockBox','',2),(54272,'116274','furniture-mobile','block-54271','Filters','',3),(54273,'1639749663.0229','furniture-mobile','block-54271','ShowInactive\\ShowInactive','',1),(54274,'116275','furniture-mobile','block-54271-2','Listing','',8),(54275,'116276','furniture-mobile','block-54271-2','catalog\\Image','',3),(54276,'116277','furniture-mobile','block-54271-2','BlockBox','',9),(54277,'116278','furniture-mobile','block-54276','catalog\\CountsItems','',1),(54278,'116279','furniture-mobile','block-54276-2','catalog\\Paging','',1),(54279,'116280','furniture-mobile','block-54271-2','catalog\\ImageMapCategory','',6),(54280,'116281','furniture-mobile','block-54271-2','Categories','',4),(54281,'116282','furniture-mobile','block-54271-2','BlockBox','catalog-features',7),(54282,'116283','furniture-mobile','block-54281','catalog\\ListingLook','',1),(54283,'116284','furniture-mobile','block-54281','catalog\\CompareButton','',2),(54284,'116285','furniture-mobile','block-54281','catalog\\ItemsOnPage','',4),(54285,'116286','furniture-mobile','block-54281','catalog\\Sorting','',3),(54286,'116287','furniture-mobile','block-54270','catalog\\Title','',1),(54287,'116288','furniture-mobile','category','Categories','',1),(54288,'116289','furniture-mobile','category','Listing','',4),(54289,'116290','furniture-mobile','category','ListingFunctionality','',2),(54290,'116291','furniture-mobile','category','PagingBar','',3),(54291,'116292','furniture-mobile','category','PagingBar','',5),(54292,'116293','furniture-mobile','category_2','BlockBox','',1),(54293,'116294','furniture-mobile','block-54292','catalog\\Title','',1),(54294,'116295','furniture-mobile','block-54292','BlockBox','',2),(54295,'116296','furniture-mobile','block-54294','Filters','',1),(54296,'116297','furniture-mobile','block-54294-2','catalog\\Image','',1),(54297,'116298','furniture-mobile','block-54294-2','Listing','',5),(54298,'116299','furniture-mobile','block-54294-2','BlockBox','',4),(54299,'116300','furniture-mobile','block-54298','catalog\\Sorting','',3),(54300,'116301','furniture-mobile','block-54298','catalog\\ItemsOnPage','',4),(54301,'116302','furniture-mobile','block-54298','catalog\\CompareButton','',2),(54302,'116303','furniture-mobile','block-54298','catalog\\ListingLook','',1),(54303,'116304','furniture-mobile','block-54294-2','catalog\\ImageMapCategory','',3),(54304,'116305','furniture-mobile','block-54294-2','Categories','',2),(54305,'116306','furniture-mobile','block-54294-2','BlockBox','',6),(54306,'116307','furniture-mobile','block-54305','catalog\\CountsItems','',1),(54307,'116308','furniture-mobile','block-54305-2','catalog\\Paging','',1),(54308,'116309','furniture-mobile','category_no_filters','BlockBox','catalog-content',1),(54309,'116310','furniture-mobile','block-54308','catalog\\Title','',1),(54310,'116311','furniture-mobile','block-54308','Categories','',3),(54311,'116312','furniture-mobile','block-54308','BlockBox','catalog-features',4),(54312,'116313','furniture-mobile','block-54311','catalog\\ItemsOnPage','',4),(54313,'116314','furniture-mobile','block-54311','catalog\\Sorting','',3),(54314,'116315','furniture-mobile','block-54311','catalog\\CompareButton','',2),(54315,'116316','furniture-mobile','block-54311','catalog\\ListingLook','',1),(54316,'116317','furniture-mobile','block-54311','HeaderStock','',5),(54317,'116318','furniture-mobile','block-54308','BlockBox','',6),(54318,'116319','furniture-mobile','block-54317','catalog\\CountsItems','',1),(54319,'116320','furniture-mobile','block-54317-2','catalog\\Paging','',1),(54320,'116321','furniture-mobile','block-54308','Listing','',5),(54321,'116322','furniture-mobile','block-54308','catalog\\Image','',2),(54322,'116323','furniture-mobile','block-54308','catalog\\B2bAddButton','',7),(54323,'1683112094.454335','furniture-mobile','checkout','BlockBox','',2),(54324,'1683112094.46510','furniture-mobile','block-54323','BlockBox','',2),(54325,'1683112094.466634','furniture-mobile','block-54324','BlockBox','',2),(54326,'1683112094.468254','furniture-mobile','block-54325','BlockBox','',5),(54327,'1683112094.470662','furniture-mobile','block-54326','checkout\\Comments','',2),(54328,'1683112094.473482','furniture-mobile','block-54326','Html_box','',1),(54329,'1683112094.477128','furniture-mobile','block-54325','BlockBox','',4),(54330,'1683112094.479689','furniture-mobile','block-54329','Html_box','',1),(54331,'1683112094.481499','furniture-mobile','block-54329','BlockBox','',2),(54332,'1683112094.482824','furniture-mobile','block-54331','CouponsAndVauchers\\Checkout','',1),(54333,'1683112094.484566','furniture-mobile','block-54331-2','checkout\\CreditAmount','',1),(54334,'1683112094.486280','furniture-mobile','block-54331-2','checkout\\BonusPoints','',2),(54335,'1683112094.487748','furniture-mobile','block-54325','BlockBox','',2),(54336,'1683112094.489595','furniture-mobile','block-54335','BlockBox','',3),(54337,'1683112094.491715','furniture-mobile','block-54336','checkout\\ShippingChoice','',1),(54338,'1683112094.49547','furniture-mobile','block-54335','Neighbour\\Checkout','',5),(54339,'1683112094.496940','furniture-mobile','block-54335','BlockBox','',4),(54340,'1683112094.498374','furniture-mobile','block-54339','BlockBox','',1),(54341,'1683112094.499910','furniture-mobile','block-54340','checkout\\ShippingAddress','',2),(54342,'1683112094.502626','furniture-mobile','block-54340','Html_box','',3),(54343,'1683112094.503954','furniture-mobile','block-54340','checkout\\ContactInformation','',4),(54344,'1683112094.505375','furniture-mobile','block-54340','UploadCustomerId\\UploadCustomerIdForm','',5),(54345,'1683112094.508236','furniture-mobile','block-54339-2','BlockBox','',1),(54346,'1683112094.509614','furniture-mobile','block-54345','checkout\\Shipping','',2),(54347,'1683112094.510627','furniture-mobile','block-54345','DelayedDespatch\\Checkout','',4),(54348,'1683112094.511898','furniture-mobile','block-54345','Html_box','',1),(54349,'1683112094.513380','furniture-mobile','block-54345','DeliveryDay','',3),(54350,'1683112094.516692','furniture-mobile','block-54345','checkout\\PoNumber','',6),(54351,'1683112094.518294','furniture-mobile','block-54335','Html_box','',2),(54352,'1683112094.5284','furniture-mobile','block-54325','BlockBox','',6),(54353,'1683112094.522685','furniture-mobile','block-54352','cart\\Products','',1),(54354,'1683112094.52788','furniture-mobile','block-54352','checkout\\CreateAccount','',2),(54355,'1683112094.530263','furniture-mobile','block-54352','DeliveryOptions\\Checkout','',0),(54356,'1683112094.532112','furniture-mobile','block-54325','BlockBox','',3),(54357,'1683112094.53526','furniture-mobile','block-54356','Html_box','',1),(54358,'1683112094.536687','furniture-mobile','block-54356','BlockBox','',2),(54359,'1683112094.53846','furniture-mobile','block-54358','Html_box','',1),(54360,'1683112094.539137','furniture-mobile','block-54358','checkout\\BillingAddress','',2),(54361,'1683112094.542437','furniture-mobile','block-54358-2','BlockBox','',1),(54362,'1683112094.543634','furniture-mobile','block-54361','checkout\\PaymentMethod','',2),(54363,'1683112094.544994','furniture-mobile','block-54361','Html_box','',1),(54364,'1683112094.546257','furniture-mobile','block-54325','BlockBox','',0),(54365,'1683112094.547713','furniture-mobile','block-54364','checkout\\LoginOnForm','',0),(54366,'1683112094.549336','furniture-mobile','block-54324-2','BlockBox','',1),(54367,'1683112094.554924','furniture-mobile','block-54366','Html_box','',5),(54368,'1683112094.556948','furniture-mobile','block-54366','Html_box','',1),(54369,'1683112094.558436','furniture-mobile','block-54366','checkout\\Terms','',4),(54370,'1683112094.560477','furniture-mobile','block-54366','checkout\\Totals','',2),(54371,'1683112094.561633','furniture-mobile','block-54366','checkout\\ContinueBtn','',3),(54372,'116368','furniture-mobile','checkout_confirmation','BlockBox','',1),(54373,'116369','furniture-mobile','block-54372','checkout\\Totals','',8),(54374,'116370','furniture-mobile','block-54372','Html_box','',5),(54375,'116371','furniture-mobile','block-54372','checkout\\EditBtn','',6),(54376,'116372','furniture-mobile','block-54372','BlockBox','',3),(54377,'116373','furniture-mobile','block-54376','BlockBox','',1),(54378,'116374','furniture-mobile','block-54377','Html_box','',1),(54379,'116375','furniture-mobile','block-54377','checkout\\ShippingConfirm','',3),(54380,'116376','furniture-mobile','block-54376-2','BlockBox','',1),(54381,'116377','furniture-mobile','block-54380','checkout\\PaymentMethodConfirm','',3),(54382,'116378','furniture-mobile','block-54380','Html_box','',1),(54383,'116379','furniture-mobile','block-54372','checkout\\ConfirmBtn','',9),(54384,'116380','furniture-mobile','block-54372','BlockBox','',2),(54385,'116381','furniture-mobile','block-54384','BlockBox','',1),(54386,'116382','furniture-mobile','block-54385','checkout\\ShippingAddressConfirm','',3),(54387,'116383','furniture-mobile','block-54385','Html_box','',1),(54388,'116384','furniture-mobile','block-54384-2','BlockBox','',1),(54389,'116385','furniture-mobile','block-54388','Html_box','',1),(54390,'116386','furniture-mobile','block-54388','checkout\\BillingAddressConfirm','',3),(54391,'116387','furniture-mobile','block-54372','checkout\\ConfirmBtn','',4),(54392,'116388','furniture-mobile','block-54372','cart\\Products','',7),(54393,'116402','furniture-mobile','checkout_confirmation_no_shipping','BlockBox','',1),(54394,'116403','furniture-mobile','block-54393','checkout\\ConfirmBtn','',9),(54395,'116404','furniture-mobile','block-54393','BlockBox','',2),(54396,'116405','furniture-mobile','block-54395','BlockBox','',1),(54397,'116406','furniture-mobile','block-54396','Html_box','',1),(54398,'116407','furniture-mobile','block-54396','checkout\\BillingAddressConfirm','',3),(54399,'116408','furniture-mobile','block-54395-2','BlockBox','',1),(54400,'116409','furniture-mobile','block-54399','Html_box','',1),(54401,'116410','furniture-mobile','block-54399','checkout\\PaymentMethodConfirm','',3),(54402,'116411','furniture-mobile','block-54393','checkout\\ConfirmBtn','',4),(54403,'116412','furniture-mobile','block-54393','checkout\\Totals','',8),(54404,'116413','furniture-mobile','block-54393','cart\\Products','',7),(54405,'116414','furniture-mobile','block-54393','Html_box','',5),(54406,'116389','furniture-mobile','checkout_confirmation_no_shipping_q','BlockBox','',1),(54407,'116390','furniture-mobile','block-54406','quote\\Products','',4),(54408,'116391','furniture-mobile','block-54406','checkout\\ConfirmBtn','',2),(54409,'116392','furniture-mobile','block-54406','checkout\\ConfirmBtn','',6),(54410,'116393','furniture-mobile','block-54406','BlockBox','',1),(54411,'116394','furniture-mobile','block-54410','BlockBox','',1),(54412,'116395','furniture-mobile','block-54411','checkout\\BillingAddressConfirm','',3),(54413,'116396','furniture-mobile','block-54411','Html_box','',1),(54414,'116397','furniture-mobile','block-54410-2','BlockBox','',1),(54415,'116398','furniture-mobile','block-54414','checkout\\PaymentMethodConfirm','',3),(54416,'116399','furniture-mobile','block-54414','Html_box','',1),(54417,'116400','furniture-mobile','block-54406','Html_box','',3),(54418,'116401','furniture-mobile','block-54406','checkout\\Totals','',5),(54419,'116415','furniture-mobile','checkout_confirmation_q','BlockBox','',1),(54420,'116416','furniture-mobile','block-54419','BlockBox','',1),(54421,'116417','furniture-mobile','block-54420','BlockBox','',1),(54422,'116418','furniture-mobile','block-54421','checkout\\ShippingAddressConfirm','',3),(54423,'116419','furniture-mobile','block-54421','Html_box','',1),(54424,'116420','furniture-mobile','block-54420-2','BlockBox','',1),(54425,'116421','furniture-mobile','block-54424','checkout\\BillingAddressConfirm','',3),(54426,'116422','furniture-mobile','block-54424','Html_box','',1),(54427,'116423','furniture-mobile','block-54419','checkout\\Totals','',7),(54428,'116424','furniture-mobile','block-54419','quote\\Products','',6),(54429,'116425','furniture-mobile','block-54419','Html_box','',4),(54430,'116426','furniture-mobile','block-54419','checkout\\EditBtn','',5),(54431,'116427','furniture-mobile','block-54419','checkout\\ConfirmBtn','',8),(54432,'116428','furniture-mobile','block-54419','checkout\\ConfirmBtn','',3),(54433,'116429','furniture-mobile','block-54419','BlockBox','',2),(54434,'116430','furniture-mobile','block-54433','BlockBox','',1),(54435,'116431','furniture-mobile','block-54434','Html_box','',1),(54436,'116432','furniture-mobile','block-54434','checkout\\ShippingConfirm','',3),(54437,'116433','furniture-mobile','block-54433-2','BlockBox','',1),(54438,'116434','furniture-mobile','block-54437','Html_box','',1),(54439,'116435','furniture-mobile','block-54437','checkout\\PaymentMethodConfirm','',3),(54440,'116436','furniture-mobile','checkout_confirmation_title','Html_box','',1),(54441,'116437','furniture-mobile','checkout_confirmation_title_g','Html_box','',1),(54442,'116439','furniture-mobile','checkout_confirmation_title_no_shipping','Html_box','',1),(54443,'116438','furniture-mobile','checkout_confirmation_title_no_shipping_g','Html_box','',1),(54444,'116440','furniture-mobile','checkout_confirmation_title_q','Html_box','',1),(54445,'116441','furniture-mobile','checkout_confirmation_title_s','Html_box','',1),(54446,'116442','furniture-mobile','checkout_delivery','BlockBox','',2),(54447,'116443','furniture-mobile','block-54446','BlockBox','',1),(54448,'116444','furniture-mobile','block-54447','Html_box','',1),(54449,'116445','furniture-mobile','block-54447','checkout\\ContactInformation','',2),(54450,'116446','furniture-mobile','block-54446','BlockBox','',2),(54451,'116447','furniture-mobile','block-54450','Html_box','',1),(54452,'116448','furniture-mobile','block-54450','checkout\\Comments','',2),(54453,'116449','furniture-mobile','checkout_delivery','BlockBox','',3),(54454,'116450','furniture-mobile','block-54453','Html_box','',1),(54455,'116451','furniture-mobile','block-54453-2','checkout\\ContinueBtn','',1),(54456,'116452','furniture-mobile','checkout_delivery','BlockBox','',1),(54457,'116453','furniture-mobile','block-54456','BlockBox','',1),(54459,'116455','furniture-mobile','block-54457','checkout\\ShippingAddress','',2),(54460,'116456','furniture-mobile','block-54456','BlockBox','checkout-shipping',2),(54461,'116457','furniture-mobile','block-54460','DelayedDespatch\\Checkout','',3),(54462,'116458','furniture-mobile','block-54460','checkout\\Shipping','',2),(54463,'116459','furniture-mobile','block-54460','Html_box','',1),(54464,'116460','furniture-mobile','block-54460','Neighbour\\Checkout','',4),(54465,'116461','furniture-mobile','checkout_delivery_g','BlockBox','',2),(54466,'116462','furniture-mobile','block-54465','BlockBox','',1),(54467,'116463','furniture-mobile','block-54466','checkout\\ContactInformation','',2),(54468,'116464','furniture-mobile','block-54466','Html_box','',1),(54469,'116465','furniture-mobile','block-54465-2','BlockBox','',1),(54470,'116466','furniture-mobile','block-54469','Html_box','',1),(54471,'116467','furniture-mobile','block-54469','checkout\\Comments','',2),(54472,'116468','furniture-mobile','checkout_delivery_g','BlockBox','',3),(54473,'116469','furniture-mobile','block-54472','Html_box','',1),(54474,'116470','furniture-mobile','block-54472-2','checkout\\ContinueBtn','',1),(54475,'116471','furniture-mobile','checkout_delivery_g','BlockBox','',1),(54476,'116472','furniture-mobile','block-54475','BlockBox','',1),(54477,'116473','furniture-mobile','block-54476','checkout\\ShippingAddress','',2),(54478,'116474','furniture-mobile','block-54476','Html_box','',1),(54479,'116475','furniture-mobile','block-54475-2','BlockBox','',1),(54480,'116476','furniture-mobile','block-54479','checkout\\Shipping','',2),(54481,'116477','furniture-mobile','block-54479','Html_box','',1),(54482,'116478','furniture-mobile','block-54479','DelayedDespatch\\Checkout','',3),(54483,'116479','furniture-mobile','block-54479','Neighbour\\Checkout','',4),(54484,'116480','furniture-mobile','checkout_delivery_no_shipping','BlockBox','',2),(54485,'116481','furniture-mobile','block-54484','Html_box','',1),(54486,'116482','furniture-mobile','block-54484-2','checkout\\ContinueBtn','',1),(54487,'116483','furniture-mobile','checkout_delivery_no_shipping','BlockBox','',1),(54488,'116484','furniture-mobile','block-54487','BlockBox','',1),(54489,'116485','furniture-mobile','block-54488','checkout\\ContactInformation','',2),(54490,'116486','furniture-mobile','block-54487-2','BlockBox','',1),(54491,'116487','furniture-mobile','block-54490','Html_box','',1),(54492,'116488','furniture-mobile','block-54490','checkout\\Comments','',2),(54493,'116489','furniture-mobile','checkout_delivery_no_shipping_g','BlockBox','',2),(54494,'116490','furniture-mobile','block-54493','Html_box','',1),(54495,'116491','furniture-mobile','block-54493-2','checkout\\ContinueBtn','',1),(54496,'116492','furniture-mobile','checkout_delivery_no_shipping_g','BlockBox','',1),(54497,'116493','furniture-mobile','block-54496','BlockBox','',1),(54498,'116494','furniture-mobile','block-54497','checkout\\ContactInformation','',2),(54499,'116495','furniture-mobile','block-54496-2','BlockBox','',1),(54500,'116496','furniture-mobile','block-54499','checkout\\Comments','',2),(54501,'116497','furniture-mobile','block-54499','Html_box','',1),(54502,'116498','furniture-mobile','checkout_delivery_title','Html_box','',1),(54503,'116499','furniture-mobile','checkout_delivery_title_g','Html_box','',1),(54504,'116501','furniture-mobile','checkout_delivery_title_no_shipping','Html_box','',1),(54505,'116500','furniture-mobile','checkout_delivery_title_no_shipping_g','Html_box','',1),(54506,'116502','furniture-mobile','checkout_delivery_title_q','Html_box','',1),(54507,'116503','furniture-mobile','checkout_delivery_title_s','Html_box','',1),(54508,'116504','furniture-mobile','checkout_free_s','BlockBox','',1),(54509,'116505','furniture-mobile','block-54508','BlockBox','',2),(54510,'116506','furniture-mobile','block-54509','BlockBox','',2),(54511,'116508','furniture-mobile','block-54510','BlockBox','',6),(54512,'116509','furniture-mobile','block-54511','sample\\Products','',1),(54513,'116510','furniture-mobile','block-54511','checkout\\CreateAccount','',3),(54514,'116511','furniture-mobile','block-54510','BlockBox','',5),(54515,'116512','furniture-mobile','block-54514','Html_box','',1),(54516,'116513','furniture-mobile','block-54514','checkout\\Comments','',2),(54517,'116514','furniture-mobile','block-54510','BlockBox','',2),(54518,'116515','furniture-mobile','block-54517','BlockBox','',2),(54519,'116516','furniture-mobile','block-54518','checkout\\ShippingChoice','',1),(54520,'116517','furniture-mobile','block-54517','Html_box','',1),(54521,'116518','furniture-mobile','block-54517','BlockBox','',3),(54522,'116519','furniture-mobile','block-54521','BlockBox','',1),(54523,'116520','furniture-mobile','block-54522','checkout\\ContactInformation','',4),(54524,'116521','furniture-mobile','block-54522','checkout\\ShippingAddress','',2),(54525,'116522','furniture-mobile','block-54522','Html_box','',3),(54526,'116523','furniture-mobile','block-54521-2','BlockBox','',1),(54527,'116524','furniture-mobile','block-54526','DelayedDespatch\\Checkout','',3),(54528,'116525','furniture-mobile','block-54517','Neighbour\\Checkout','',4),(54529,'116526','furniture-mobile','block-54509-2','BlockBox','',1),(54530,'116527','furniture-mobile','block-54529','Html_box','',3),(54531,'116528','furniture-mobile','block-54529','checkout\\ContinueBtn','',1),(54532,'1638956949.0762','furniture-mobile','block-54529','checkout\\Terms','',2),(54533,'1638957135.2709','furniture-mobile','block-54529','Html_box','',0),(54534,'116529','furniture-mobile','checkout_no_shipping','BlockBox','',1),(54535,'116530','furniture-mobile','block-54534','BlockBox','',2),(54536,'116531','furniture-mobile','block-54535','BlockBox','',1),(54537,'116532','furniture-mobile','block-54536','BlockBox','',6),(54538,'116533','furniture-mobile','block-54537','checkout\\CreateAccount','',2),(54539,'116534','furniture-mobile','block-54537','cart\\Products','',1),(54540,'116535','furniture-mobile','block-54536','BlockBox','',3),(54541,'116536','furniture-mobile','block-54540','Html_box','',1),(54542,'116537','furniture-mobile','block-54540','BlockBox','',2),(54543,'116538','furniture-mobile','block-54542','checkout\\BillingAddress','',2),(54544,'116539','furniture-mobile','block-54542','Html_box','',1),(54545,'116540','furniture-mobile','block-54542-2','BlockBox','',1),(54546,'116541','furniture-mobile','block-54545','Html_box','',1),(54547,'116542','furniture-mobile','block-54545','checkout\\PaymentMethod','',2),(54548,'116543','furniture-mobile','block-54536','BlockBox','',4),(54549,'116544','furniture-mobile','block-54548','BlockBox','',2),(54550,'116545','furniture-mobile','block-54549','CouponsAndVauchers\\Checkout','',1),(54551,'116546','furniture-mobile','block-54549-2','checkout\\CreditAmount','',1),(54552,'116547','furniture-mobile','block-54549-2','checkout\\BonusPoints','',2),(54553,'116548','furniture-mobile','block-54548','Html_box','',1),(54554,'116549','furniture-mobile','block-54536','BlockBox','',5),(54555,'116550','furniture-mobile','block-54554','checkout\\Comments','',2),(54556,'116551','furniture-mobile','block-54554','Html_box','',1),(54557,'116552','furniture-mobile','block-54535-2','BlockBox','',1),(54558,'116553','furniture-mobile','block-54557','Html_box','',1),(54559,'116554','furniture-mobile','block-54557','Html_box','',5),(54560,'116555','furniture-mobile','block-54557','checkout\\Totals','',2),(54561,'116556','furniture-mobile','block-54557','checkout\\ContinueBtn','',3),(54562,'116557','furniture-mobile','block-54557','checkout\\Terms','',4),(54563,'116558','furniture-mobile','checkout_no_shipping_g','BlockBox','',1),(54564,'116559','furniture-mobile','block-54563','checkout\\Totals','',5),(54565,'116560','furniture-mobile','block-54563','BlockBox','',6),(54566,'116561','furniture-mobile','block-54565','Html_box','',1),(54567,'116562','furniture-mobile','block-54565-2','checkout\\ContinueBtn','',1),(54568,'116563','furniture-mobile','block-54563','BlockBox','',2),(54569,'116564','furniture-mobile','block-54568','BlockBox','',1),(54570,'116565','furniture-mobile','block-54569','checkout\\ContactInformation','',2),(54571,'116566','furniture-mobile','block-54569','Html_box','',1),(54572,'116567','furniture-mobile','block-54568-2','BlockBox','',1),(54573,'116568','furniture-mobile','block-54572','checkout\\Comments','',2),(54574,'116569','furniture-mobile','block-54572','Html_box','',1),(54575,'116570','furniture-mobile','block-54563','BlockBox','',1),(54576,'116571','furniture-mobile','block-54575','BlockBox','',1),(54577,'116572','furniture-mobile','block-54576','Html_box','',1),(54578,'116573','furniture-mobile','block-54576','checkout\\BillingAddress','',2),(54579,'116574','furniture-mobile','block-54575-2','BlockBox','',1),(54580,'116575','furniture-mobile','block-54579','checkout\\BonusPoints','',4),(54581,'116576','furniture-mobile','block-54579','CouponsAndVauchers\\Checkout','',5),(54582,'116577','furniture-mobile','block-54579','checkout\\PaymentMethod','',2),(54583,'116578','furniture-mobile','block-54579','checkout\\CreditAmount','',3),(54584,'116579','furniture-mobile','block-54579','Html_box','',1),(54585,'116580','furniture-mobile','block-54563','quote\\Products','',3),(54586,'116581','furniture-mobile','checkout_no_shipping_q','BlockBox','',1),(54587,'116582','furniture-mobile','block-54586','BlockBox','',2),(54588,'116583','furniture-mobile','block-54587','BlockBox','',2),(54589,'116585','furniture-mobile','block-54588','BlockBox','',5),(54590,'116586','furniture-mobile','block-54589','checkout\\Comments','',2),(54591,'116587','furniture-mobile','block-54589','Html_box','',1),(54592,'116588','furniture-mobile','block-54588','BlockBox','',6),(54593,'116589','furniture-mobile','block-54592','checkout\\CreateAccount','',3),(54594,'116590','furniture-mobile','block-54592','quote\\Products','',2),(54595,'116591','furniture-mobile','block-54588','BlockBox','',3),(54596,'116592','furniture-mobile','block-54595','Html_box','',1),(54597,'116593','furniture-mobile','block-54595','BlockBox','',2),(54598,'116594','furniture-mobile','block-54597','Html_box','',1),(54599,'116595','furniture-mobile','block-54597','checkout\\BillingAddress','',2),(54600,'116596','furniture-mobile','block-54597-2','BlockBox','',1),(54601,'116597','furniture-mobile','block-54600','checkout\\PaymentMethod','',2),(54602,'116598','furniture-mobile','block-54600','Html_box','',1),(54603,'116599','furniture-mobile','block-54587-2','BlockBox','',1),(54604,'116600','furniture-mobile','block-54603','checkout\\ContinueBtn','',3),(54605,'116601','furniture-mobile','block-54603','Html_box','',5),(54606,'116602','furniture-mobile','block-54603','Html_box','',1),(54607,'116603','furniture-mobile','block-54603','checkout\\Totals','',2),(54608,'120984','furniture-mobile','block-54603','checkout\\Terms','',4),(54609,'116604','furniture-mobile','checkout_payment','BlockBox','',1),(54610,'116605','furniture-mobile','block-54609','BlockBox','',1),(54611,'116606','furniture-mobile','block-54610','checkout\\BillingAddress','',2),(54612,'116607','furniture-mobile','block-54610','Html_box','',1),(54613,'116608','furniture-mobile','block-54609','BlockBox','',2),(54614,'116609','furniture-mobile','block-54613','checkout\\CreditAmount','',3),(54615,'116610','furniture-mobile','block-54613','checkout\\BonusPoints','',4),(54616,'116611','furniture-mobile','block-54613','CouponsAndVauchers\\Checkout','',5),(54617,'116612','furniture-mobile','block-54613','checkout\\PaymentMethod','',2),(54618,'116613','furniture-mobile','block-54613','Html_box','',1),(54619,'116614','furniture-mobile','checkout_payment','BlockBox','',3),(54620,'116615','furniture-mobile','block-54619','Html_box','',1),(54621,'116616','furniture-mobile','block-54619-2','checkout\\ContinueBtn','',1),(54622,'116617','furniture-mobile','checkout_payment_g','BlockBox','',1),(54623,'116618','furniture-mobile','block-54622','BlockBox','',1),(54624,'116619','furniture-mobile','block-54623','checkout\\BillingAddress','',2),(54625,'116620','furniture-mobile','block-54623','Html_box','',1),(54626,'116621','furniture-mobile','block-54622-2','BlockBox','',1),(54627,'116622','furniture-mobile','block-54626','checkout\\CreditAmount','',3),(54628,'116623','furniture-mobile','block-54626','Html_box','',1),(54629,'116624','furniture-mobile','block-54626','checkout\\PaymentMethod','',2),(54630,'116625','furniture-mobile','block-54626','CouponsAndVauchers\\Checkout','',5),(54631,'116626','furniture-mobile','block-54626','checkout\\BonusPoints','',4),(54632,'116627','furniture-mobile','checkout_payment_g','BlockBox','',2),(54633,'116628','furniture-mobile','block-54632','Html_box','',1),(54634,'116629','furniture-mobile','block-54632-2','checkout\\ContinueBtn','',1),(54635,'116630','furniture-mobile','checkout_payment_no_shipping','BlockBox','',2),(54636,'116631','furniture-mobile','block-54635','Html_box','',1),(54637,'116632','furniture-mobile','block-54635-2','checkout\\ContinueBtn','',1),(54638,'116633','furniture-mobile','checkout_payment_no_shipping','BlockBox','',1),(54639,'116634','furniture-mobile','block-54638','BlockBox','',1),(54640,'116635','furniture-mobile','block-54639','Html_box','',1),(54641,'116636','furniture-mobile','block-54639','checkout\\BillingAddress','',2),(54642,'116637','furniture-mobile','block-54638-2','BlockBox','',1),(54643,'116638','furniture-mobile','block-54642','checkout\\BonusPoints','',4),(54644,'116639','furniture-mobile','block-54642','CouponsAndVauchers\\Checkout','',5),(54645,'116640','furniture-mobile','block-54642','checkout\\PaymentMethod','',2),(54646,'116641','furniture-mobile','block-54642','checkout\\CreditAmount','',3),(54647,'116642','furniture-mobile','block-54642','Html_box','',1),(54648,'116643','furniture-mobile','checkout_payment_no_shipping_g','BlockBox','',2),(54649,'116644','furniture-mobile','block-54648','Html_box','',1),(54650,'116645','furniture-mobile','block-54648-2','checkout\\ContinueBtn','',1),(54651,'116646','furniture-mobile','checkout_payment_no_shipping_g','BlockBox','',1),(54652,'116647','furniture-mobile','block-54651','BlockBox','',1),(54653,'116648','furniture-mobile','block-54652','checkout\\BillingAddress','',2),(54654,'116649','furniture-mobile','block-54652','Html_box','',1),(54655,'116650','furniture-mobile','block-54651-2','BlockBox','',1),(54656,'116651','furniture-mobile','block-54655','checkout\\BonusPoints','',4),(54657,'116652','furniture-mobile','block-54655','checkout\\CreditAmount','',3),(54658,'116653','furniture-mobile','block-54655','checkout\\PaymentMethod','',2),(54659,'116654','furniture-mobile','block-54655','Html_box','',1),(54660,'116655','furniture-mobile','block-54655','CouponsAndVauchers\\Checkout','',5),(54661,'116656','furniture-mobile','checkout_payment_title','Html_box','',1),(54662,'116657','furniture-mobile','checkout_payment_title_g','Html_box','',1),(54663,'116658','furniture-mobile','checkout_payment_title_no_shipping','Html_box','',1),(54664,'116659','furniture-mobile','checkout_payment_title_no_shipping_g','Html_box','',1),(54665,'116660','furniture-mobile','checkout_payment_title_q','Html_box','',1),(54666,'116661','furniture-mobile','checkout_payment_title_s','Html_box','',1),(54667,'120947','furniture-mobile','checkout_q','BlockBox','',1),(54668,'120948','furniture-mobile','block-54667','BlockBox','',2),(54669,'120949','furniture-mobile','block-54668','BlockBox','',2),(54670,'120950','furniture-mobile','block-54669','BlockBox','',6),(54671,'120951','furniture-mobile','block-54670','checkout\\CreateAccount','',3),(54672,'120952','furniture-mobile','block-54670','quote\\Products','',2),(54673,'120953','furniture-mobile','block-54669','BlockBox','',2),(54674,'120954','furniture-mobile','block-54673','BlockBox','',2),(54675,'120955','furniture-mobile','block-54674','checkout\\ShippingChoice','',1),(54676,'120956','furniture-mobile','block-54673','Neighbour\\Checkout','',4),(54677,'120957','furniture-mobile','block-54673','Html_box','',1),(54678,'120958','furniture-mobile','block-54673','BlockBox','',3),(54679,'120959','furniture-mobile','block-54678','BlockBox','',1),(54680,'120960','furniture-mobile','block-54679','checkout\\ContactInformation','',4),(54681,'120961','furniture-mobile','block-54679','checkout\\ShippingAddress','',2),(54682,'120962','furniture-mobile','block-54679','Html_box','',3),(54683,'120963','furniture-mobile','block-54678-2','BlockBox','',1),(54684,'120964','furniture-mobile','block-54683','checkout\\Shipping','',2),(54685,'120965','furniture-mobile','block-54683','Html_box','',1),(54686,'120966','furniture-mobile','block-54683','DelayedDespatch\\Checkout','',3),(54687,'120967','furniture-mobile','block-54669','BlockBox','',5),(54688,'120968','furniture-mobile','block-54687','Html_box','',1),(54689,'120969','furniture-mobile','block-54687','checkout\\Comments','',2),(54690,'120970','furniture-mobile','block-54669','BlockBox','',3),(54691,'120971','furniture-mobile','block-54690','Html_box','',1),(54692,'120972','furniture-mobile','block-54690','BlockBox','',2),(54693,'120973','furniture-mobile','block-54692','checkout\\BillingAddress','',2),(54694,'120974','furniture-mobile','block-54692','Html_box','',1),(54695,'120975','furniture-mobile','block-54692-2','BlockBox','',1),(54696,'120976','furniture-mobile','block-54695','checkout\\PaymentMethod','',2),(54697,'120977','furniture-mobile','block-54695','Html_box','',1),(54698,'120978','furniture-mobile','block-54668-2','BlockBox','',1),(54699,'120979','furniture-mobile','block-54698','Html_box','',1),(54700,'120980','furniture-mobile','block-54698','Html_box','',5),(54701,'120981','furniture-mobile','block-54698','checkout\\Totals','',2),(54702,'120982','furniture-mobile','block-54698','checkout\\ContinueBtn','',3),(54703,'120983','furniture-mobile','block-54698','checkout\\Terms','',4),(54704,'116699','furniture-mobile','checkout_s','BlockBox','',1),(54705,'116700','furniture-mobile','block-54704','BlockBox','',2),(54706,'116701','furniture-mobile','block-54705','BlockBox','',2),(54707,'116703','furniture-mobile','block-54706','BlockBox','',6),(54708,'116704','furniture-mobile','block-54707','sample\\Products','',1),(54709,'116705','furniture-mobile','block-54707','checkout\\CreateAccount','',3),(54710,'116706','furniture-mobile','block-54706','BlockBox','',2),(54711,'116707','furniture-mobile','block-54710','Html_box','',1),(54712,'116708','furniture-mobile','block-54710','Neighbour\\Checkout','',4),(54713,'116709','furniture-mobile','block-54710','BlockBox','',2),(54714,'116710','furniture-mobile','block-54713','checkout\\ShippingChoice','',1),(54715,'116711','furniture-mobile','block-54710','BlockBox','',3),(54716,'116712','furniture-mobile','block-54715','BlockBox','',1),(54717,'116713','furniture-mobile','block-54716','checkout\\ShippingAddress','',2),(54718,'116714','furniture-mobile','block-54716','checkout\\ContactInformation','',4),(54719,'116715','furniture-mobile','block-54716','Html_box','',3),(54720,'116716','furniture-mobile','block-54715-2','BlockBox','',1),(54721,'116717','furniture-mobile','block-54720','checkout\\Shipping','',2),(54722,'116718','furniture-mobile','block-54720','DelayedDespatch\\Checkout','',3),(54723,'116719','furniture-mobile','block-54720','Html_box','',1),(54724,'116720','furniture-mobile','block-54706','BlockBox','',3),(54725,'116721','furniture-mobile','block-54724','BlockBox','',2),(54726,'116722','furniture-mobile','block-54725','Html_box','',1),(54727,'116723','furniture-mobile','block-54725','checkout\\BillingAddress','',2),(54728,'116724','furniture-mobile','block-54725-2','BlockBox','',1),(54729,'116725','furniture-mobile','block-54728','Html_box','',1),(54730,'116726','furniture-mobile','block-54728','checkout\\PaymentMethod','',2),(54731,'116727','furniture-mobile','block-54724','Html_box','',1),(54732,'116728','furniture-mobile','block-54706','BlockBox','',5),(54733,'116729','furniture-mobile','block-54732','Html_box','',1),(54734,'116730','furniture-mobile','block-54732','checkout\\Comments','',2),(54735,'116731','furniture-mobile','block-54706','BlockBox','',4),(54736,'116732','furniture-mobile','block-54735','BlockBox','',2),(54737,'116733','furniture-mobile','block-54736','CouponsAndVauchers\\Checkout','',1),(54738,'116734','furniture-mobile','block-54736-2','checkout\\BonusPoints','',2),(54739,'116735','furniture-mobile','block-54736-2','checkout\\CreditAmount','',1),(54740,'116736','furniture-mobile','block-54735','Html_box','',1),(54741,'116737','furniture-mobile','block-54705-2','BlockBox','',1),(54742,'116738','furniture-mobile','block-54741','checkout\\Totals','',2),(54743,'116739','furniture-mobile','block-54741','Html_box','',5),(54744,'116740','furniture-mobile','block-54741','Html_box','',1),(54745,'116741','furniture-mobile','block-54741','checkout\\ContinueBtn','',3),(54746,'120986','furniture-mobile','block-54741','checkout\\Terms','',4),(54747,'116742','furniture-mobile','checkout_step_bottom','Html_box','',1),(54748,'116743','furniture-mobile','checkout_step_bottom','cart\\Products','',2),(54749,'116744','furniture-mobile','checkout_step_bottom','checkout\\Totals','',3),(54750,'116745','furniture-mobile','checkout_step_bottom_g','checkout\\Totals','',3),(54751,'116746','furniture-mobile','checkout_step_bottom_g','quote\\Products','',2),(54752,'116747','furniture-mobile','checkout_step_bottom_g','Html_box','',1),(54753,'116749','furniture-mobile','checkout_step_bottom_no_shipping','Html_box','',1),(54754,'116750','furniture-mobile','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(54755,'116753','furniture-mobile','checkout_step_bottom_no_shipping','cart\\Products','',2),(54756,'116748','furniture-mobile','checkout_step_bottom_no_shipping_g','Html_box','',1),(54757,'116751','furniture-mobile','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(54758,'116752','furniture-mobile','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(54759,'116754','furniture-mobile','communication','BlockBox','',1),(54760,'116755','furniture-mobile','block-54759','Html_box','',2),(54761,'116756','furniture-mobile','block-54759','Communication\\NewTopicButton','',1),(54762,'116757','furniture-mobile','block-54759','Communication\\Topic','',3),(54763,'116758','furniture-mobile','compare','BlockBox','',1),(54764,'116759','furniture-mobile','block-54763','catalog\\Compare','',1),(54765,'117665.000001','furniture-mobile','compareproduct','BlockBox','listing-item',1),(54766,'120921.000001','furniture-mobile','block-54765','BlockBox','',1),(54767,'120919.000001','furniture-mobile','block-54766','BlockBox','listing-item',1),(54768,'1638872990.9609','furniture-mobile','block-54767','BlockBox','',2),(54769,'117671.000001','furniture-mobile','block-54768','productListing\\image','',1),(54770,'117677.000001','furniture-mobile','block-54768-2','productListing\\compare','',1),(54771,'117675.000001','furniture-mobile','block-54768-2','productListing\\name','',2),(54772,'117676.000001','furniture-mobile','block-54768-2','productListing\\stock','',3),(54773,'1638873112.0384','furniture-mobile','block-54768-2','BlockBox','',4),(54774,'117670.000001','furniture-mobile','block-54773','productListing\\rating','',2),(54775,'117673.000001','furniture-mobile','block-54773-2','productListing\\price','',1),(54776,'116760','furniture-mobile','compare_products','BlockBox','',2),(54777,'116761','furniture-mobile','block-54776','productListing\\rating','',4),(54778,'116762','furniture-mobile','block-54776','productListing\\model','',5),(54779,'116763','furniture-mobile','block-54776','productListing\\compare','',1),(54780,'116764','furniture-mobile','block-54776','BlockBox','',2),(54781,'116765','furniture-mobile','block-54780','productListing\\image','',1),(54782,'116766','furniture-mobile','block-54780-2','productListing\\name','',2),(54783,'116767','furniture-mobile','block-54776','BlockBox','',3),(54784,'116768','furniture-mobile','block-54783','productListing\\price','',1),(54785,'116769','furniture-mobile','block-54783-2','productListing\\buyButton','',1),(54786,'116770','furniture-mobile','confirmation','BlockBox','',1),(54787,'116771','furniture-mobile','block-54786','BlockBox','',2),(54788,'116772','furniture-mobile','block-54787','BlockBox','',2),(54789,'116773','furniture-mobile','block-54788','BlockBox','',4),(54790,'116774','furniture-mobile','block-54789','checkout\\EditBtn','',2),(54791,'116775','furniture-mobile','block-54789','cart\\Products','',3),(54792,'116776','furniture-mobile','block-54789','Html_box','',1),(54793,'116777','furniture-mobile','block-54788','BlockBox','',3),(54794,'116778','furniture-mobile','block-54793','checkout\\EditBtn','',2),(54795,'116779','furniture-mobile','block-54793','Html_box','',1),(54796,'116780','furniture-mobile','block-54793','checkout\\CommentsConfirm','',3),(54797,'116781','furniture-mobile','block-54788','BlockBox','',1),(54798,'116782','furniture-mobile','block-54797','BlockBox','',1),(54799,'116783','furniture-mobile','block-54798','checkout\\EditBtn','',6),(54800,'116784','furniture-mobile','block-54798','DelayedDespatch\\CheckoutConfirm','',8),(54801,'116785','furniture-mobile','block-54798','Html_box','',9),(54802,'116786','furniture-mobile','block-54798','checkout\\EditBtn','',10),(54803,'116787','furniture-mobile','block-54798','Html_box','',5),(54804,'116788','furniture-mobile','block-54798','checkout\\ShippingConfirm','',7),(54805,'116789','furniture-mobile','block-54798','Html_box','',1),(54806,'116790','furniture-mobile','block-54798','checkout\\EditBtn','',3),(54807,'116791','furniture-mobile','block-54798','checkout\\ContactConfirm','',11),(54808,'116792','furniture-mobile','block-54798','Html_box','',2),(54809,'116793','furniture-mobile','block-54798','checkout\\ShippingAddressConfirm','',4),(54810,'116794','furniture-mobile','block-54797-2','BlockBox','',1),(54811,'116795','furniture-mobile','block-54810','checkout\\EditBtn','',6),(54812,'116796','furniture-mobile','block-54810','checkout\\EditBtn','',3),(54813,'116797','furniture-mobile','block-54810','checkout\\PaymentMethodConfirm','',7),(54814,'116798','furniture-mobile','block-54810','Html_box','',5),(54815,'116799','furniture-mobile','block-54810','Html_box','',1),(54816,'116800','furniture-mobile','block-54810','checkout\\BillingAddressConfirm','',4),(54817,'116801','furniture-mobile','block-54810','Html_box','',2),(54818,'116802','furniture-mobile','block-54787','UploadCustomerId\\UploadCustomerIdForm','',1),(54819,'116803','furniture-mobile','block-54787-2','BlockBox','',1),(54820,'116804','furniture-mobile','block-54819','Html_box','',1),(54821,'116805','furniture-mobile','block-54819','checkout\\ConfirmBtn','',3),(54822,'116806','furniture-mobile','block-54819','checkout\\Totals','',2),(54823,'116807','furniture-mobile','block-54786','Html_box','',1),(54824,'116808','furniture-mobile','confirmation_free_s','BlockBox','',1),(54825,'116809','furniture-mobile','block-54824','BlockBox','',2),(54826,'116810','furniture-mobile','block-54825','BlockBox','',1),(54827,'116811','furniture-mobile','block-54826','BlockBox','',2),(54828,'116812','furniture-mobile','block-54827','checkout\\CommentsConfirm','',3),(54829,'116813','furniture-mobile','block-54827','checkout\\EditBtn','',2),(54830,'116814','furniture-mobile','block-54827','Html_box','',1),(54831,'116815','furniture-mobile','block-54826','BlockBox','',3),(54832,'116816','furniture-mobile','block-54831','checkout\\EditBtn','',3),(54833,'116817','furniture-mobile','block-54831','Html_box','',1),(54834,'116818','furniture-mobile','block-54831','sample\\Products','',2),(54835,'116819','furniture-mobile','block-54826','BlockBox','',1),(54836,'116820','furniture-mobile','block-54835','BlockBox','',1),(54837,'116821','furniture-mobile','block-54836','checkout\\EditBtn','',3),(54838,'116822','furniture-mobile','block-54836','checkout\\ShippingConfirm','',7),(54839,'116823','furniture-mobile','block-54836','Html_box','',5),(54840,'116824','furniture-mobile','block-54836','checkout\\EditBtn','',6),(54841,'116825','furniture-mobile','block-54836','Html_box','',2),(54842,'116826','furniture-mobile','block-54836','checkout\\ShippingAddressConfirm','',4),(54843,'116827','furniture-mobile','block-54835-2','BlockBox','',1),(54844,'116828','furniture-mobile','block-54843','checkout\\ContactConfirm','',3),(54845,'116829','furniture-mobile','block-54843','DelayedDespatch\\CheckoutConfirm','',4),(54846,'116830','furniture-mobile','block-54843','checkout\\EditBtn','',2),(54847,'116831','furniture-mobile','block-54843','Html_box','',1),(54848,'116832','furniture-mobile','block-54825-2','BlockBox','',1),(54849,'116833','furniture-mobile','block-54848','checkout\\ConfirmBtn','',3),(54850,'116834','furniture-mobile','block-54824','Html_box','',1),(54851,'116835','furniture-mobile','confirmation_no_shipping','BlockBox','',1),(54852,'116836','furniture-mobile','block-54851','Html_box','',1),(54853,'116837','furniture-mobile','block-54851','BlockBox','',2),(54854,'116838','furniture-mobile','block-54853','BlockBox','',1),(54855,'116839','furniture-mobile','block-54854','BlockBox','',1),(54856,'116840','furniture-mobile','block-54855','BlockBox','',1),(54857,'116841','furniture-mobile','block-54856','checkout\\EditBtn','',10),(54858,'116842','furniture-mobile','block-54856','Html_box','',9),(54859,'116843','furniture-mobile','block-54856','checkout\\ContactConfirm','',11),(54860,'116844','furniture-mobile','block-54855-2','BlockBox','',1),(54861,'116845','furniture-mobile','block-54860','checkout\\PaymentMethodConfirm','',7),(54862,'116846','furniture-mobile','block-54860','checkout\\EditBtn','',6),(54863,'116847','furniture-mobile','block-54860','Html_box','',5),(54864,'116848','furniture-mobile','block-54860','Html_box','',1),(54865,'116849','furniture-mobile','block-54860','checkout\\EditBtn','',3),(54866,'116850','furniture-mobile','block-54860','checkout\\BillingAddressConfirm','',4),(54867,'116851','furniture-mobile','block-54860','Html_box','',2),(54868,'116852','furniture-mobile','block-54854','BlockBox','',2),(54869,'116853','furniture-mobile','block-54868','Html_box','',1),(54870,'116854','furniture-mobile','block-54868','checkout\\CommentsConfirm','',3),(54871,'116855','furniture-mobile','block-54868','checkout\\EditBtn','',2),(54872,'116856','furniture-mobile','block-54854','BlockBox','',3),(54873,'116857','furniture-mobile','block-54872','Html_box','',1),(54874,'116858','furniture-mobile','block-54872','checkout\\EditBtn','',2),(54875,'116859','furniture-mobile','block-54872','cart\\Products','',3),(54876,'116860','furniture-mobile','block-54853-2','BlockBox','',1),(54877,'116861','furniture-mobile','block-54876','checkout\\ConfirmBtn','',3),(54878,'116862','furniture-mobile','block-54876','Html_box','',1),(54879,'116863','furniture-mobile','block-54876','checkout\\Totals','',2),(54880,'116864','furniture-mobile','confirmation_no_shipping_q','BlockBox','',2),(54881,'116865','furniture-mobile','block-54880','Html_box','',1),(54882,'116866','furniture-mobile','block-54880','BlockBox','',2),(54883,'116867','furniture-mobile','block-54882','BlockBox','',1),(54884,'116868','furniture-mobile','block-54883','BlockBox','',2),(54885,'116869','furniture-mobile','block-54884','Html_box','',1),(54886,'116870','furniture-mobile','block-54884','checkout\\CommentsConfirm','',3),(54887,'116871','furniture-mobile','block-54884','checkout\\EditBtn','',2),(54888,'116872','furniture-mobile','block-54883','BlockBox','',1),(54889,'116873','furniture-mobile','block-54888','BlockBox','',1),(54890,'116874','furniture-mobile','block-54889','checkout\\EditBtn','',5),(54891,'116875','furniture-mobile','block-54889','checkout\\ContactConfirm','',6),(54892,'116876','furniture-mobile','block-54889','checkout\\PaymentMethodConfirm','',3),(54893,'116877','furniture-mobile','block-54889','checkout\\EditBtn','',2),(54894,'116878','furniture-mobile','block-54889','Html_box','',4),(54895,'116879','furniture-mobile','block-54889','Html_box','',1),(54896,'116880','furniture-mobile','block-54888-2','BlockBox','',1),(54897,'116881','furniture-mobile','block-54896','checkout\\BillingAddressConfirm','',4),(54898,'116882','furniture-mobile','block-54896','checkout\\EditBtn','',3),(54899,'116883','furniture-mobile','block-54896','Html_box','',2),(54900,'116884','furniture-mobile','block-54883','BlockBox','',3),(54901,'116885','furniture-mobile','block-54900','checkout\\EditBtn','',2),(54902,'116886','furniture-mobile','block-54900','Html_box','',1),(54903,'116887','furniture-mobile','block-54900','quote\\Products','',3),(54904,'116888','furniture-mobile','block-54882-2','BlockBox','',1),(54905,'116889','furniture-mobile','block-54904','checkout\\ConfirmBtn','',3),(54906,'116890','furniture-mobile','block-54904','checkout\\Totals','',2),(54907,'116891','furniture-mobile','block-54904','Html_box','',1),(54908,'116892','furniture-mobile','confirmation_q','BlockBox','',1),(54909,'116893','furniture-mobile','block-54908','Html_box','',1),(54910,'116894','furniture-mobile','block-54908','BlockBox','',2),(54911,'116895','furniture-mobile','block-54910','BlockBox','',1),(54912,'116896','furniture-mobile','block-54911','BlockBox','',3),(54913,'116897','furniture-mobile','block-54912','quote\\Products','',3),(54914,'116898','furniture-mobile','block-54912','Html_box','',1),(54915,'116899','furniture-mobile','block-54912','checkout\\EditBtn','',2),(54916,'116900','furniture-mobile','block-54911','BlockBox','',1),(54917,'116901','furniture-mobile','block-54916','BlockBox','',1),(54918,'116902','furniture-mobile','block-54917','Html_box','',1),(54919,'116903','furniture-mobile','block-54917','checkout\\EditBtn','',10),(54920,'116904','furniture-mobile','block-54917','Html_box','',2),(54921,'116905','furniture-mobile','block-54917','checkout\\ContactConfirm','',11),(54922,'116906','furniture-mobile','block-54917','checkout\\ShippingAddressConfirm','',4),(54923,'116907','furniture-mobile','block-54917','checkout\\ShippingConfirm','',7),(54924,'116908','furniture-mobile','block-54917','checkout\\EditBtn','',3),(54925,'116909','furniture-mobile','block-54917','DelayedDespatch\\CheckoutConfirm','',8),(54926,'116910','furniture-mobile','block-54917','Html_box','',9),(54927,'116911','furniture-mobile','block-54917','Html_box','',5),(54928,'116912','furniture-mobile','block-54917','checkout\\EditBtn','',6),(54929,'116913','furniture-mobile','block-54916-2','BlockBox','',1),(54930,'116914','furniture-mobile','block-54929','checkout\\EditBtn','',3),(54931,'116915','furniture-mobile','block-54929','checkout\\BillingAddressConfirm','',4),(54932,'116916','furniture-mobile','block-54929','checkout\\PaymentMethodConfirm','',7),(54933,'116917','furniture-mobile','block-54929','Html_box','',1),(54934,'116918','furniture-mobile','block-54929','Html_box','',2),(54935,'116919','furniture-mobile','block-54929','checkout\\EditBtn','',6),(54936,'116920','furniture-mobile','block-54929','Html_box','',5),(54937,'116921','furniture-mobile','block-54911','BlockBox','',2),(54938,'116922','furniture-mobile','block-54937','checkout\\CommentsConfirm','',3),(54939,'116923','furniture-mobile','block-54937','Html_box','',1),(54940,'116924','furniture-mobile','block-54937','checkout\\EditBtn','',2),(54941,'116925','furniture-mobile','block-54910-2','BlockBox','',1),(54942,'116926','furniture-mobile','block-54941','Html_box','',1),(54943,'116927','furniture-mobile','block-54941','checkout\\Totals','',2),(54944,'116928','furniture-mobile','block-54941','checkout\\ConfirmBtn','',3),(54945,'116929','furniture-mobile','confirmation_s','BlockBox','',1),(54946,'116930','furniture-mobile','block-54945','BlockBox','',2),(54947,'116931','furniture-mobile','block-54946','BlockBox','',1),(54948,'116932','furniture-mobile','block-54947','BlockBox','',1),(54949,'116933','furniture-mobile','block-54948','BlockBox','',1),(54950,'116934','furniture-mobile','block-54949','checkout\\ShippingAddressConfirm','',4),(54951,'116935','furniture-mobile','block-54949','checkout\\EditBtn','',3),(54952,'116936','furniture-mobile','block-54949','Html_box','',2),(54953,'116937','furniture-mobile','block-54949','DelayedDespatch\\CheckoutConfirm','',8),(54954,'116938','furniture-mobile','block-54949','checkout\\ShippingConfirm','',7),(54955,'116939','furniture-mobile','block-54949','Html_box','',1),(54956,'116940','furniture-mobile','block-54949','Html_box','',5),(54957,'116941','furniture-mobile','block-54949','Html_box','',9),(54958,'116942','furniture-mobile','block-54949','checkout\\ContactConfirm','',11),(54959,'116943','furniture-mobile','block-54949','checkout\\EditBtn','',6),(54960,'116944','furniture-mobile','block-54949','checkout\\EditBtn','',10),(54961,'116945','furniture-mobile','block-54948-2','BlockBox','',1),(54962,'116946','furniture-mobile','block-54961','Html_box','',2),(54963,'116947','furniture-mobile','block-54961','checkout\\BillingAddressConfirm','',4),(54964,'116948','furniture-mobile','block-54961','checkout\\EditBtn','',3),(54965,'116949','furniture-mobile','block-54961','checkout\\PaymentMethodConfirm','',7),(54966,'116950','furniture-mobile','block-54961','checkout\\EditBtn','',6),(54967,'116951','furniture-mobile','block-54961','Html_box','',1),(54968,'116952','furniture-mobile','block-54961','Html_box','',5),(54969,'116953','furniture-mobile','block-54947','BlockBox','',3),(54970,'116954','furniture-mobile','block-54969','checkout\\EditBtn','',3),(54971,'116955','furniture-mobile','block-54969','Html_box','',1),(54972,'116956','furniture-mobile','block-54969','sample\\Products','',2),(54973,'116957','furniture-mobile','block-54947','BlockBox','',2),(54974,'116958','furniture-mobile','block-54973','Html_box','',1),(54975,'116959','furniture-mobile','block-54973','checkout\\EditBtn','',2),(54976,'116960','furniture-mobile','block-54973','checkout\\CommentsConfirm','',3),(54977,'116961','furniture-mobile','block-54946-2','BlockBox','',1),(54978,'116962','furniture-mobile','block-54977','checkout\\Totals','',2),(54979,'116963','furniture-mobile','block-54977','checkout\\ConfirmBtn','',3),(54980,'116964','furniture-mobile','block-54977','Html_box','',1),(54981,'116965','furniture-mobile','block-54945','Html_box','',1),(54982,'116966','furniture-mobile','contact','BlockBox','info-content',1),(54983,'116967','furniture-mobile','block-54982','info\\Title','',1),(54984,'116968','furniture-mobile','block-54982','BlockBox','',2),(54985,'116969','furniture-mobile','block-54984','contact\\ContactForm','',1),(54986,'116970','furniture-mobile','block-54984-2','contact\\Contacts','',1),(54987,'116971','furniture-mobile','created_success','BlockBox','',1),(54988,'116972','furniture-mobile','block-54987','Html_box','',1),(54989,'116973','furniture-mobile','block-54987','Html_box','',2),(54990,'116102.000001','furniture-mobile','credit_amount_history','BlockBox','',1),(54991,'116103.000001','furniture-mobile','block-54990','BlockBox','',1),(54992,'116104.000001','furniture-mobile','block-54991','WidgetsAria','',1),(55012,'116109.000001','furniture-mobile','block-54991-2','Html_box','',1),(55013,'1638895944.9672','furniture-mobile','block-54991-2','account\\CreditAmountHistory','',2),(55014,'116974','furniture-mobile','credit_note','invoice\\Container','',1),(55015,'116975','furniture-mobile','block-55014','BlockBox','',5),(55016,'116976','furniture-mobile','block-55015','invoice\\StoreAddress','',8),(55017,'116977','furniture-mobile','block-55015','Text','',1),(55018,'116978','furniture-mobile','block-55015-2','Text','',2),(55019,'116979','furniture-mobile','block-55015-2','Logo','',1),(55020,'116980','furniture-mobile','block-55015-3','Text','',1),(55021,'116981','furniture-mobile','block-55015-3','BlockBox','',3),(55022,'116982','furniture-mobile','block-55021','Text','',1),(55023,'116983','furniture-mobile','block-55021-2','invoice\\StoreEmail','',1),(55024,'116984','furniture-mobile','block-55015-3','BlockBox','',2),(55025,'116985','furniture-mobile','block-55024','Text','',1),(55026,'116986','furniture-mobile','block-55024-2','invoice\\StorePhone','',1),(55027,'116987','furniture-mobile','block-55014','invoice\\Products','',3),(55028,'116988','furniture-mobile','block-55014','BlockBox','',1),(55029,'116989','furniture-mobile','block-55028','Logo','',1),(55030,'116990','furniture-mobile','block-55028-2','BlockBox','',4),(55031,'116991','furniture-mobile','block-55030','Text','',1),(55032,'116992','furniture-mobile','block-55030-2','invoice\\StoreSite','',1),(55033,'116993','furniture-mobile','block-55028-2','BlockBox','',2),(55034,'116994','furniture-mobile','block-55033','Text','',1),(55035,'116995','furniture-mobile','block-55033-2','invoice\\StorePhone','',1),(55036,'116996','furniture-mobile','block-55028-2','BlockBox','',3),(55037,'116997','furniture-mobile','block-55036','Text','',1),(55038,'116998','furniture-mobile','block-55036-2','invoice\\StoreEmail','',1),(55039,'116999','furniture-mobile','block-55028-2','BlockBox','',1),(55040,'117000','furniture-mobile','block-55039','invoice\\StoreAddress','',1),(55041,'117001','furniture-mobile','block-55014','BlockBox','',4),(55042,'117002','furniture-mobile','block-55041','BlockBox','',1),(55043,'117003','furniture-mobile','block-55042','invoice\\ShippingAddress','',2),(55044,'117004','furniture-mobile','block-55042','Text','',1),(55045,'117005','furniture-mobile','block-55041-2','BlockBox','',1),(55046,'117006','furniture-mobile','block-55014','BlockBox','',2),(55047,'117007','furniture-mobile','block-55046','BlockBox','',7),(55048,'117008','furniture-mobile','block-55047','BlockBox','',1),(55049,'117009','furniture-mobile','block-55048','Text','',1),(55050,'117010','furniture-mobile','block-55048','invoice\\BillingAddress','',2),(55051,'117011','furniture-mobile','block-55047-2','BlockBox','',1),(55052,'117012','furniture-mobile','block-55051','invoice\\CustomerPhone','',4),(55053,'117013','furniture-mobile','block-55051','Text','',1),(55054,'117014','furniture-mobile','block-55051','Text','',3),(55055,'117015','furniture-mobile','block-55051','invoice\\CustomerName','',2),(55056,'117016','furniture-mobile','block-55051','invoice\\CustomerEmail','',6),(55057,'117017','furniture-mobile','block-55051','Text','',5),(55058,'117018','furniture-mobile','block-55046','BlockBox','',8),(55059,'117019','furniture-mobile','block-55058','BlockBox','',1),(55060,'117020','furniture-mobile','block-55059','invoice\\ShippingMethod','',2),(55061,'117021','furniture-mobile','block-55059','Text','',1),(55062,'117022','furniture-mobile','block-55058-2','BlockBox','',1),(55063,'117023','furniture-mobile','block-55062','Text','',1),(55064,'117024','furniture-mobile','block-55062','invoice\\ShippingMethod','',2),(55065,'117025','furniture-mobile','block-55046-2','invoice\\OrderId','',1),(55066,'117026','furniture-mobile','block-55046-2','Text','',2),(55067,'117027','furniture-mobile','block-55046-2','invoice\\PaymentDate','',3),(55069,'117034','furniture-mobile','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(55070,'1639155816.3893','furniture-mobile','delivery-location','BlockBox','',2),(55071,'117028','furniture-mobile','block-55070','DeliveryLocation\\FeaturedList','',6),(55072,'117029','furniture-mobile','block-55070','DeliveryLocation\\LocationLongDescription','',3),(55073,'117030','furniture-mobile','block-55070','DeliveryLocation\\LocationList','',4),(55074,'117031','furniture-mobile','block-55070','DeliveryLocation\\LocationTitle','',1),(55075,'117032','furniture-mobile','block-55070','DeliveryLocation\\LocationProducts','',7),(55076,'117033','furniture-mobile','block-55070','DeliveryLocation\\LocationDescription','',2),(55077,'1639485067.5512','furniture-mobile','block-55070','DeliveryLocation\\CrossPages','',0),(55078,'1639485089.2227','furniture-mobile','block-55070','DeliveryLocation\\ProductCategories','',0),(55079,'1639154415.2739','furniture-mobile','delivery-location-default','BlockBox','',2),(55080,'117035','furniture-mobile','block-55079','DeliveryLocation\\TopLocationList','',2),(55081,'117036','furniture-mobile','block-55079','Heading','',1),(55082,'1639419797.9718','furniture-mobile','block-55079','DeliveryLocation\\ListByPage','',3),(55083,'117037','furniture-mobile','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(55084,'117038','furniture-mobile','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(55085,'117039','furniture-mobile','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(55086,'117040','furniture-mobile','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(55087,'117041','furniture-mobile','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(55088,'117042','furniture-mobile','delivery_loc_2','DeliveryLocation\\LocationList','',7),(55089,'117043','furniture-mobile','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(55090,'117044','furniture-mobile','email','email\\BlockBox','',1),(55091,'117045','furniture-mobile','block-55090','email\\BlockBox','',1),(55092,'117046','furniture-mobile','block-55091','Copyright','',4),(55093,'117047','furniture-mobile','block-55091','email\\Content','',3),(55094,'117048','furniture-mobile','block-55091','email\\BlockBox','',2),(55095,'117049','furniture-mobile','block-55094','email\\Title','',1),(55096,'117050','furniture-mobile','block-55094-2','email\\Date','',1),(55097,'117051','furniture-mobile','block-55091','Logo','',1),(55098,'117052','furniture-mobile','email_2','email\\BlockBox','',1),(55099,'117053','furniture-mobile','block-55098','email\\BlockBox','',1),(55100,'117054','furniture-mobile','block-55099','Copyright','',4),(55101,'117055','furniture-mobile','block-55099','Logo','',1),(55102,'117056','furniture-mobile','block-55099','email\\Content','',3),(55103,'117057','furniture-mobile','block-55099','email\\BlockBox','',2),(55104,'117058','furniture-mobile','block-55103','email\\Title','',1),(55105,'117059','furniture-mobile','block-55103-2','email\\Date','',1),(55106,'117060','furniture-mobile','email_3','email\\BlockBox','',1),(55107,'117061','furniture-mobile','block-55106','email\\BlockBox','',1),(55108,'117062','furniture-mobile','block-55107','email\\BlockBox','',2),(55109,'117063','furniture-mobile','block-55108','email\\Content','',2),(55110,'117064','furniture-mobile','block-55108','email\\BlockBox','',1),(55111,'117065','furniture-mobile','block-55110','email\\Title','',1),(55112,'117066','furniture-mobile','block-55110-2','email\\Date','',1),(55113,'117067','furniture-mobile','block-55107','Copyright','',3),(55114,'117068','furniture-mobile','block-55107','Logo','',1),(55115,'117069','furniture-mobile','email_4','email\\BlockBox','',1),(55116,'117070','furniture-mobile','block-55115','email\\BlockBox','',1),(55117,'117071','furniture-mobile','block-55116','Copyright','',2),(55118,'117072','furniture-mobile','block-55116','email\\BlockBox','',1),(55119,'117073','furniture-mobile','block-55118','email\\BlockBox','',1),(55120,'117074','furniture-mobile','block-55119','Logo','',1),(55121,'117075','furniture-mobile','block-55119-2','email\\Date','',2),(55122,'117076','furniture-mobile','block-55119-2','email\\Title','',1),(55123,'117077','furniture-mobile','block-55118','email\\Content','',2),(55124,'121029','furniture-mobile','filescatalog_category','BlockBox','',1),(55125,'121030','furniture-mobile','block-55124','FilesCatalog\\widgets\\FilesList','',3),(55126,'121031','furniture-mobile','block-55124','FilesCatalog\\widgets\\Title','',1),(55127,'121032','furniture-mobile','block-55124','FilesCatalog\\widgets\\Description','',2),(55128,'121025','furniture-mobile','filescatalog_index','BlockBox','',1),(55129,'121026','furniture-mobile','block-55128','Html_box','',1),(55130,'121027','furniture-mobile','block-55128','FilesCatalog\\widgets\\FilesCatalog','',2),(55131,'117078','furniture-mobile','footer','BlockBox','footer-content',1),(55132,'120866','furniture-mobile','block-55131','BlockBox','',3),(55133,'117091','furniture-mobile','block-55132','Contacts','',2),(55134,'120868','furniture-mobile','block-55132','Logo','',1),(55135,'120871','furniture-mobile','block-55132-2','BlockBox','',1),(55136,'117085','furniture-mobile','block-55135','Menu','Footer',2),(55137,'117093','furniture-mobile','footer','BlockBox','',2),(55138,'117094','furniture-mobile','block-55137','Copyright','',1),(55139,'117096','furniture-mobile','for_menu','BlockBox','',1),(55140,'117097','furniture-mobile','block-55139','Html_box','',1),(55141,'117098','furniture-mobile','block-55139-2','Languages','',1),(55142,'117099','furniture-mobile','for_menu','BlockBox','',3),(55143,'117100','furniture-mobile','block-55142','Html_box','',1),(55144,'117101','furniture-mobile','block-55142-2','Currencies','',1),(55145,'117102','furniture-mobile','gift','BlockBox','',1),(55146,'117103','furniture-mobile','block-55145','BlockBox','',3),(55147,'117104','furniture-mobile','block-55146','BlockBox','',1),(55148,'117105','furniture-mobile','block-55147','gift\\Card','',1),(55149,'117106','furniture-mobile','block-55146-2','gift\\Form','',2),(55150,'117107','furniture-mobile','block-55146-2','Text','',1),(55151,'117108','furniture-mobile','block-55145','info\\Title','',1),(55152,'117109','furniture-mobile','gift_card','BlockBox','',1),(55153,'117110','furniture-mobile','block-55152','BlockBox','',11),(55154,'117111','furniture-mobile','block-55153','invoice\\StoreEmail','',3),(55155,'117112','furniture-mobile','block-55153','Text','',1),(55156,'117113','furniture-mobile','block-55153','invoice\\StorePhone','',2),(55157,'117114','furniture-mobile','block-55152','Text','',8),(55158,'117115','furniture-mobile','block-55152','Text','',3),(55159,'117116','furniture-mobile','block-55152','BlockBox','',10),(55160,'117117','furniture-mobile','block-55159','Text','',1),(55161,'117118','furniture-mobile','block-55159-2','gift\\CodeView','',1),(55162,'117119','furniture-mobile','block-55152','gift\\MessageView','',7),(55163,'117120','furniture-mobile','block-55152','gift\\AmountView','',5),(55164,'117121','furniture-mobile','block-55152','Text','',6),(55165,'117123','furniture-mobile','block-55152','Logo','',1),(55166,'117124','furniture-mobile','block-55152','Text','',4),(55167,'117125','furniture-mobile','block-55152','Text','',9),(55168,'117126','furniture-mobile','gift_card_2','BlockBox','',1),(55169,'117127','furniture-mobile','block-55168','gift\\AmountView','',4),(55170,'117128','furniture-mobile','block-55168','BlockBox','',9),(55171,'117129','furniture-mobile','block-55170','Text','',1),(55172,'117130','furniture-mobile','block-55170-2','gift\\CodeView','',1),(55173,'117131','furniture-mobile','block-55168','BlockBox','',10),(55174,'117132','furniture-mobile','block-55173','invoice\\StoreEmail','',3),(55175,'117133','furniture-mobile','block-55173','Text','',1),(55176,'117134','furniture-mobile','block-55173','invoice\\StorePhone','',2),(55177,'117135','furniture-mobile','block-55168','gift\\MessageView','',6),(55178,'117136','furniture-mobile','block-55168','Text','',5),(55179,'117137','furniture-mobile','block-55168','Text','',8),(55180,'117138','furniture-mobile','block-55168','Text','',3),(55181,'117139','furniture-mobile','block-55168','Text','',7),(55182,'1638804282.8587','furniture-mobile','block-55168','Logo','',1),(55183,'117141','furniture-mobile','gift_card_2_pdf','BlockBox','',1),(55184,'117142','furniture-mobile','block-55183','BlockBox','',12),(55185,'117143','furniture-mobile','block-55184','invoice\\StoreEmail','',4),(55186,'117144','furniture-mobile','block-55184','invoice\\StorePhone','',3),(55187,'117145','furniture-mobile','block-55184','Html_box','',1),(55188,'117146','furniture-mobile','block-55183','BlockBox','',11),(55189,'117147','furniture-mobile','block-55188','Html_box','',1),(55190,'117148','furniture-mobile','block-55188-2','gift\\CodeViewPdf','',1),(55191,'117149','furniture-mobile','block-55183','BlockBox','',1),(55192,'117150','furniture-mobile','block-55191','Text','',4),(55193,'117151','furniture-mobile','block-55191','Html_box','',1),(55194,'117152','furniture-mobile','block-55191','Html_box','',2),(55195,'117153','furniture-mobile','block-55191','gift\\AmountViewPdf','',3),(55196,'117154','furniture-mobile','block-55191','gift\\MessageViewPdf','',5),(55197,'117155','furniture-mobile','block-55191','Html_box','',7),(55198,'117156','furniture-mobile','block-55191','Html_box','',6),(55199,'117157','furniture-mobile','gift_card_2_pdf','Import','',1),(55200,'117158','furniture-mobile','gift_card_pdf','BlockBox','',1),(55201,'117159','furniture-mobile','block-55200','BlockBox','',12),(55202,'117160','furniture-mobile','block-55201','invoice\\StoreEmail','',4),(55203,'117161','furniture-mobile','block-55201','invoice\\StorePhone','',3),(55204,'117162','furniture-mobile','block-55201','Html_box','',1),(55205,'117163','furniture-mobile','block-55200','BlockBox','',11),(55206,'117164','furniture-mobile','block-55205','Html_box','',1),(55207,'117165','furniture-mobile','block-55205-2','gift\\CodeViewPdf','',1),(55208,'117166','furniture-mobile','block-55200','BlockBox','',1),(55209,'117167','furniture-mobile','block-55208','Text','',5),(55210,'117169','furniture-mobile','block-55208','Html_box','',3),(55211,'117170','furniture-mobile','block-55208','gift\\AmountViewPdf','',4),(55212,'117171','furniture-mobile','block-55208','gift\\MessageViewPdf','',6),(55213,'117172','furniture-mobile','block-55208','Html_box','',8),(55214,'117173','furniture-mobile','block-55208','Html_box','',7),(55215,'1638978695.8384','furniture-mobile','block-55208','Logo','',2),(55216,'117175','furniture-mobile','gift_certificate','BlockBox','',1),(55217,'117176','furniture-mobile','block-55216','account\\ApplyCertificate','',2),(55218,'117177','furniture-mobile','block-55216','Html_box','',1),(55219,'117178','furniture-mobile','gigt_card_3','BlockBox','',1),(55220,'117179','furniture-mobile','block-55219','BlockBox','',9),(55221,'117180','furniture-mobile','block-55220','Text','',1),(55222,'117181','furniture-mobile','block-55220-2','gift\\CodeView','',1),(55223,'117182','furniture-mobile','block-55219','Text','',7),(55224,'117184','furniture-mobile','block-55219','BlockBox','',10),(55225,'117185','furniture-mobile','block-55224','Text','',1),(55226,'117186','furniture-mobile','block-55224','invoice\\StoreEmail','',3),(55227,'117187','furniture-mobile','block-55224','invoice\\StorePhone','',2),(55228,'117188','furniture-mobile','block-55219','gift\\MessageView','',6),(55229,'117189','furniture-mobile','block-55219','Text','',3),(55230,'117190','furniture-mobile','block-55219','Text','',5),(55231,'117191','furniture-mobile','block-55219','gift\\AmountView','',4),(55232,'117192','furniture-mobile','block-55219','Text','',8),(55233,'1638804328.7281','furniture-mobile','block-55219','Logo','',1),(55234,'117193','furniture-mobile','gigt_card_3_pdf','BlockBox','',1),(55235,'117194','furniture-mobile','block-55234','BlockBox','',12),(55236,'117195','furniture-mobile','block-55235','invoice\\StoreEmail','',4),(55237,'117196','furniture-mobile','block-55235','invoice\\StorePhone','',3),(55238,'117197','furniture-mobile','block-55235','Html_box','',1),(55239,'117198','furniture-mobile','block-55234','BlockBox','',11),(55240,'117199','furniture-mobile','block-55239','Html_box','',1),(55241,'117200','furniture-mobile','block-55239-2','gift\\CodeViewPdf','',1),(55242,'117201','furniture-mobile','block-55234','BlockBox','',1),(55243,'117202','furniture-mobile','block-55242','Text','',4),(55244,'117203','furniture-mobile','block-55242','Html_box','',1),(55245,'117204','furniture-mobile','block-55242','Html_box','',2),(55246,'117205','furniture-mobile','block-55242','gift\\AmountViewPdf','',3),(55247,'117206','furniture-mobile','block-55242','gift\\MessageViewPdf','',5),(55248,'117207','furniture-mobile','block-55242','Html_box','',7),(55249,'117208','furniture-mobile','block-55242','Html_box','',6),(55250,'117209','furniture-mobile','header','BlockBox','',5),(55251,'117210','furniture-mobile','block-55250','Menu','Categories',1),(55252,'117212','furniture-mobile','header','BlockBox','header-content',4),(55253,'117213','furniture-mobile','block-55252','Logo','',3),(55254,'117214','furniture-mobile','block-55252','Search','',5),(55255,'117215','furniture-mobile','block-55252','GoogleReviews','',8),(55256,'117216','furniture-mobile','block-55252','Cart','',1),(55257,'117217','furniture-mobile','block-55252','Account','',2),(55258,'117218','furniture-mobile','block-55252','Image','',4),(55259,'120877','furniture-mobile','block-55252','Html_box','',7),(55260,'117219','furniture-mobile','header','BlockBox','header-content-small',3),(55261,'117220','furniture-mobile','block-55260','BlockBox','header-content-small-left',1),(55262,'117221','furniture-mobile','block-55261','Menu','Header menu',1),(55263,'117222','furniture-mobile','block-55261','Currencies','',3),(55264,'117223','furniture-mobile','block-55261','Languages','',2),(55265,'121040','furniture-mobile','header','UnsupportedBrowser','',1),(55266,'120887','furniture-mobile','header_menu','Currencies','',2),(55267,'120888','furniture-mobile','header_menu','Languages','',1),(55268,'117224','furniture-mobile','info','BlockBox','info-content',1),(55269,'117225','furniture-mobile','block-55268','info\\DescriptionShort','',3),(55270,'117226','furniture-mobile','block-55268','info\\Content','',6),(55271,'117227','furniture-mobile','block-55268','info\\Title','',1),(55272,'117228','furniture-mobile','block-55268','info\\Image','',4),(55273,'1638467467.3028','furniture-mobile','block-55268','info\\DescriptionShort','',5),(55274,'117229','furniture-mobile','invoice','invoice\\Container','',1),(55275,'117230','furniture-mobile','block-55274','BlockBox','',4),(55276,'117231','furniture-mobile','block-55275','BlockBox','',8),(55277,'117232','furniture-mobile','block-55276','BlockBox','',1),(55278,'117233','furniture-mobile','block-55277','invoice\\ShippingMethod','',2),(55279,'117234','furniture-mobile','block-55277','Text','',1),(55280,'117235','furniture-mobile','block-55276-2','BlockBox','',1),(55281,'117236','furniture-mobile','block-55280','Text','',1),(55282,'117237','furniture-mobile','block-55280','invoice\\ShippingMethod','',2),(55283,'117238','furniture-mobile','block-55275','BlockBox','',7),(55284,'117239','furniture-mobile','block-55283','BlockBox','',2),(55285,'117240','furniture-mobile','block-55284','Text','',2),(55286,'117241','furniture-mobile','block-55284','invoice\\BillingAddress','',3),(55287,'1639659760.0392','furniture-mobile','block-55283','GiftWrapMessage\\ShowInfo','',1),(55288,'117242','furniture-mobile','block-55283-2','BlockBox','',1),(55289,'117243','furniture-mobile','block-55288','Text','',5),(55290,'117244','furniture-mobile','block-55288','invoice\\CustomerName','',2),(55291,'117245','furniture-mobile','block-55288','invoice\\CustomerPhone','',4),(55292,'117246','furniture-mobile','block-55288','Text','',1),(55293,'117247','furniture-mobile','block-55288','Text','',3),(55294,'117248','furniture-mobile','block-55288','invoice\\CustomerEmail','',6),(55295,'117249','furniture-mobile','block-55275-2','invoice\\PaymentMethod','',6),(55296,'117250','furniture-mobile','block-55275-2','Text','',5),(55297,'117251','furniture-mobile','block-55275-2','Text','',3),(55298,'117252','furniture-mobile','block-55275-2','invoice\\OrderId','',2),(55299,'117253','furniture-mobile','block-55275-2','invoice\\PaymentDate','',4),(55300,'117254','furniture-mobile','block-55275-2','invoice\\OrderBarcode','',7),(55301,'117255','furniture-mobile','block-55274','BlockBox','',8),(55302,'117256','furniture-mobile','block-55301','invoice\\StoreAddress','',8),(55303,'117257','furniture-mobile','block-55301','Text','',1),(55304,'117258','furniture-mobile','block-55301-2','Text','',2),(55305,'117260','furniture-mobile','block-55301-3','BlockBox','',3),(55306,'117261','furniture-mobile','block-55305','Text','',1),(55307,'117262','furniture-mobile','block-55305-2','invoice\\StoreEmail','',1),(55308,'117263','furniture-mobile','block-55301-3','BlockBox','',2),(55309,'117264','furniture-mobile','block-55308','Text','',1),(55310,'117265','furniture-mobile','block-55308-2','invoice\\StorePhone','',1),(55311,'117266','furniture-mobile','block-55301-3','Text','',1),(55312,'117267','furniture-mobile','block-55274','invoice\\Products','',5),(55313,'117268','furniture-mobile','block-55274','BlockBox','',7),(55314,'117269','furniture-mobile','block-55313','BlockBox','',1),(55315,'117270','furniture-mobile','block-55314','invoice\\ShippingAddress','',2),(55316,'117271','furniture-mobile','block-55314','Text','',1),(55317,'117272','furniture-mobile','block-55313-2','BlockBox','',1),(55318,'117273','furniture-mobile','block-55317','invoice\\Totals','',1),(55319,'117274','furniture-mobile','block-55274','BlockBox','',2),(55320,'117275','furniture-mobile','block-55319','Logo','',1),(55321,'117276','furniture-mobile','block-55319-2','BlockBox','',4),(55322,'117277','furniture-mobile','block-55321','Text','',1),(55323,'117278','furniture-mobile','block-55321-2','invoice\\StoreSite','',1),(55324,'117279','furniture-mobile','block-55319-2','BlockBox','',3),(55325,'117280','furniture-mobile','block-55324','Text','',1),(55326,'117281','furniture-mobile','block-55324-2','invoice\\StoreEmail','',1),(55327,'117282','furniture-mobile','block-55319-2','BlockBox','',1),(55328,'117283','furniture-mobile','block-55327','invoice\\StoreAddress','',2),(55329,'117284','furniture-mobile','block-55319-2','BlockBox','',2),(55330,'117285','furniture-mobile','block-55329','Text','',1),(55331,'117286','furniture-mobile','block-55329-2','invoice\\StorePhone','',1),(55332,'1640103567.8175','furniture-mobile','block-55274','invoice\\StructuredProducts','',6),(55333,'1640180896.2131','furniture-mobile','block-55274','BlockBox','',1),(55334,'1639994189.268','furniture-mobile','block-55333','invoice\\PaidMark','',1),(55335,'1639996119.9463','furniture-mobile','block-55333','invoice\\UnpaidMark','',2),(55336,'117287','furniture-mobile','login_account','BlockBox','',1),(55337,'117288','furniture-mobile','block-55336','Tabs','',2),(55338,'117289','furniture-mobile','block-55337-1','login\\Returning','',1),(55339,'117290','furniture-mobile','block-55337-2','BlockBox','',1),(55340,'117291','furniture-mobile','block-55339','Html_box','',1),(55341,'117292','furniture-mobile','block-55339-2','BlockBox','',1),(55342,'117293','furniture-mobile','block-55341','Html_box','',2),(55343,'117294','furniture-mobile','block-55341','login\\Register','',1),(55344,'117295','furniture-mobile','block-55336','BlockBox','',1),(55345,'117296','furniture-mobile','block-55344','Html_box','',5),(55346,'117297','furniture-mobile','block-55344','Html_box','',1),(55347,'117298','furniture-mobile','block-55344','login\\Socials','',4),(55348,'117299','furniture-mobile','login_checkout','BlockBox','',1),(55349,'117300','furniture-mobile','block-55348','BlockBox','',1),(55350,'117301','furniture-mobile','block-55349','checkout\\CreateBtn','',4),(55351,'117302','furniture-mobile','block-55349','checkout\\GuestBtn','',2),(55352,'117303','furniture-mobile','block-55349','Html_box','',3),(55353,'117304','furniture-mobile','block-55349','BlockBox','',5),(55354,'117305','furniture-mobile','block-55353','Html_box','',1),(55355,'117306','furniture-mobile','block-55353','login\\Socials','',2),(55356,'117307','furniture-mobile','block-55349','Html_box','',1),(55357,'117308','furniture-mobile','block-55349-2','login\\Returning','',2),(55358,'117309','furniture-mobile','block-55349-2','Html_box','',1),(55359,'117310','furniture-mobile','login_checkout2','BlockBox','',1),(55360,'117311','furniture-mobile','block-55359','Tabs','',4),(55361,'117312','furniture-mobile','block-55360-1','BlockBox','',1),(55362,'117313','furniture-mobile','block-55361','Html_box','',1),(55363,'117314','furniture-mobile','block-55361-2','BlockBox','',1),(55364,'117315','furniture-mobile','block-55363','login\\Guest','',1),(55365,'117316','furniture-mobile','block-55363','Html_box','',2),(55366,'117317','furniture-mobile','block-55360-2','login\\Returning','',1),(55367,'117318','furniture-mobile','block-55360-3','BlockBox','',1),(55368,'117319','furniture-mobile','block-55367','Html_box','',1),(55369,'117320','furniture-mobile','block-55367-2','BlockBox','',1),(55370,'117321','furniture-mobile','block-55369','Html_box','',2),(55371,'117322','furniture-mobile','block-55369','login\\Register','',1),(55372,'117323','furniture-mobile','block-55359','login\\Socials','',2),(55373,'117324','furniture-mobile','block-55359','Html_box','',3),(55374,'117325','furniture-mobile','block-55359','Html_box','',1),(55375,'117326','furniture-mobile','login_checkout2_q','BlockBox','',1),(55376,'117327','furniture-mobile','block-55375','Tabs','',4),(55377,'117328','furniture-mobile','block-55376-1','BlockBox','',1),(55378,'117329','furniture-mobile','block-55377','Html_box','',1),(55379,'117330','furniture-mobile','block-55377-2','quote\\FastOrder','',1),(55380,'117331','furniture-mobile','block-55376-2','login\\Returning','',1),(55381,'117332','furniture-mobile','block-55376-3','BlockBox','',1),(55382,'117333','furniture-mobile','block-55381','Html_box','',1),(55383,'117334','furniture-mobile','block-55381','Import','',2),(55384,'117335','furniture-mobile','block-55381-2','BlockBox','',1),(55385,'117336','furniture-mobile','block-55384','login\\Register','',1),(55386,'117337','furniture-mobile','block-55384','Html_box','',2),(55387,'117338','furniture-mobile','block-55375','Html_box','',3),(55388,'117339','furniture-mobile','block-55375','Html_box','',1),(55389,'117340','furniture-mobile','block-55375','login\\Socials','',2),(55390,'117341','furniture-mobile','login_checkout2_s','BlockBox','',1),(55391,'117342','furniture-mobile','block-55390','login\\Socials','',2),(55392,'117343','furniture-mobile','block-55390','Html_box','',3),(55393,'117344','furniture-mobile','block-55390','Tabs','',4),(55394,'117345','furniture-mobile','block-55393-1','BlockBox','',1),(55395,'117346','furniture-mobile','block-55394','Html_box','',1),(55396,'117347','furniture-mobile','block-55394-2','quote\\FastOrder','',1),(55397,'117348','furniture-mobile','block-55393-2','login\\Returning','',1),(55398,'117349','furniture-mobile','block-55393-3','BlockBox','',1),(55399,'117350','furniture-mobile','block-55398','Html_box','',1),(55400,'117351','furniture-mobile','block-55398-2','BlockBox','',1),(55401,'117352','furniture-mobile','block-55400','login\\Register','',1),(55402,'117353','furniture-mobile','block-55400','Html_box','',2),(55403,'117354','furniture-mobile','block-55390','Html_box','',1),(55404,'117355','furniture-mobile','login_checkout_q','BlockBox','',1),(55405,'117356','furniture-mobile','block-55404','BlockBox','',1),(55406,'117357','furniture-mobile','block-55405','BlockBox','',5),(55407,'117358','furniture-mobile','block-55406','Html_box','',1),(55408,'117359','furniture-mobile','block-55406','login\\Socials','',2),(55409,'117360','furniture-mobile','block-55405','checkout\\GuestBtn','',2),(55410,'117361','furniture-mobile','block-55405','checkout\\CreateBtn','',4),(55411,'117362','furniture-mobile','block-55405','Html_box','',3),(55412,'117363','furniture-mobile','block-55405','Html_box','',1),(55413,'117364','furniture-mobile','block-55405-2','Html_box','',1),(55414,'117365','furniture-mobile','block-55405-2','login\\Returning','',2),(55415,'117366','furniture-mobile','login_checkout_s','BlockBox','',1),(55416,'117367','furniture-mobile','block-55415','BlockBox','',1),(55417,'117368','furniture-mobile','block-55416','Html_box','',1),(55418,'117369','furniture-mobile','block-55416','checkout\\GuestBtn','',2),(55419,'117370','furniture-mobile','block-55416','checkout\\CreateBtn','',4),(55420,'117371','furniture-mobile','block-55416','Html_box','',3),(55421,'117372','furniture-mobile','block-55416','BlockBox','',5),(55422,'117373','furniture-mobile','block-55421','Html_box','',1),(55423,'117374','furniture-mobile','block-55421','login\\Socials','',2),(55424,'117375','furniture-mobile','block-55416-2','Html_box','',1),(55425,'117376','furniture-mobile','block-55416-2','login\\Returning','',2),(55426,'117377','furniture-mobile','logoff','BlockBox','',1),(55427,'117378','furniture-mobile','block-55426','Html_box','',1),(55428,'117379','furniture-mobile','logoff_forever','BlockBox','',1),(55429,'117380','furniture-mobile','block-55428','Html_box','',1),(55430,'117386','furniture-mobile','main','BlockBox','main-content',3),(55431,'120856','furniture-mobile','block-55430','BlockBox','',1),(55432,'120857','furniture-mobile','block-55431','Banner','',1),(55433,'120858','furniture-mobile','block-55430','BlockBox','',2),(55434,'120859','furniture-mobile','block-55433','Html_box','',1),(55435,'120860','furniture-mobile','block-55433-2','Html_box','',1),(55436,'120861','furniture-mobile','block-55433-3','Html_box','',1),(55437,'120862','furniture-mobile','block-55430','BlockBox','',3),(55438,'117389','furniture-mobile','block-55437','NewProducts','8',3),(55439,'121014','furniture-mobile','block-55437','Html_box','',2),(55440,'120864','furniture-mobile','block-55430','BlockBox','',4),(55441,'120865','furniture-mobile','block-55440','Banner','',2),(55442,'121015','furniture-mobile','block-55440','Html_box','',1),(55443,'1683022993.8509','furniture-mobile','main','BlockBox','',2),(55444,'1683023028.4274','furniture-mobile','block-55443','Banner','',1),(55445,'117394','furniture-mobile','manufacturers','BlockBox','',1),(55446,'117395','furniture-mobile','block-55445','Html_box','',1),(55447,'117396','furniture-mobile','block-55445','Brands','',2),(55448,'117397','furniture-mobile','messages-index','BlockBox','',1),(55449,'117398','furniture-mobile','block-55448','BlockBox','',1),(55450,'117399','furniture-mobile','block-55449','BlockBox','',1),(55451,'117400','furniture-mobile','block-55450','Messages\\Sidebar','',1),(55452,'117401','furniture-mobile','block-55449-2','Messages\\Listing','',1),(55453,'117402','furniture-mobile','messages-new','BlockBox','',1),(55454,'117403','furniture-mobile','block-55453','BlockBox','',1),(55455,'117404','furniture-mobile','block-55454','Messages\\Sidebar','',1),(55456,'117405','furniture-mobile','block-55454-2','Messages\\NewMessage','',1),(55457,'117406','furniture-mobile','messages-view','BlockBox','',1),(55458,'117407','furniture-mobile','block-55457','BlockBox','',1),(55459,'117408','furniture-mobile','block-55458','Messages\\Sidebar','',1),(55460,'117409','furniture-mobile','block-55458-2','Messages\\Message','',1),(55461,'117410','furniture-mobile','my_password','BlockBox','',1),(55462,'117411','furniture-mobile','block-55461','BlockBox','',1),(55463,'117412','furniture-mobile','block-55462','WidgetsAria','',1),(55483,'117413','furniture-mobile','block-55462-2','account\\ChangePassword','',2),(55484,'117414','furniture-mobile','block-55462-2','Html_box','',1),(55485,'117415','furniture-mobile','need_login','BlockBox','',1),(55486,'117416','furniture-mobile','block-55485','Tabs','',2),(55487,'117417','furniture-mobile','block-55486-1','login\\Returning','',1),(55488,'117418','furniture-mobile','block-55486-2','BlockBox','',1),(55489,'117419','furniture-mobile','block-55488','Html_box','',2),(55490,'117420','furniture-mobile','block-55488-2','BlockBox','',1),(55491,'117421','furniture-mobile','block-55490','login\\Register','',1),(55492,'117422','furniture-mobile','block-55490','Html_box','',2),(55493,'117423','furniture-mobile','block-55485','BlockBox','',1),(55494,'117424','furniture-mobile','new-topic','BlockBox','',1),(55495,'117425','furniture-mobile','block-55494','Breadcrumb','',2),(55496,'117426','furniture-mobile','block-55494','Communication\\NewTopic','',3),(55497,'117427','furniture-mobile','block-55494','Html_box','',1),(55498,'117428','furniture-mobile','nnnn','BlockBox','',1),(55499,'117429','furniture-mobile','block-55498','catalog\\Title','',1),(55500,'117430','furniture-mobile','block-55498','BlockBox','',2),(55501,'117431','furniture-mobile','block-55500','Filters','',1),(55502,'117432','furniture-mobile','block-55500-2','Listing','',5),(55503,'117433','furniture-mobile','block-55500-2','catalog\\Image','',1),(55504,'117434','furniture-mobile','block-55500-2','BlockBox','',6),(55505,'117435','furniture-mobile','block-55504','catalog\\CountsItems','',1),(55506,'117436','furniture-mobile','block-55504-2','catalog\\Paging','',1),(55507,'117437','furniture-mobile','block-55500-2','catalog\\ImageMapCategory','',3),(55508,'117438','furniture-mobile','block-55500-2','Categories','',2),(55509,'117439','furniture-mobile','block-55500-2','BlockBox','',4),(55510,'117440','furniture-mobile','block-55509','catalog\\ListingLook','',1),(55511,'117441','furniture-mobile','block-55509','catalog\\ItemsOnPage','',4),(55512,'117442','furniture-mobile','block-55509','catalog\\CompareButton','',2),(55513,'117443','furniture-mobile','block-55509','catalog\\Sorting','',3),(55514,'117444','furniture-mobile','no-logged','BlockBox','',1),(55515,'117445','furniture-mobile','block-55514','Communication\\NewTopic','',2),(55516,'117446','furniture-mobile','block-55514','Html_box','',1),(55517,'117447','furniture-mobile','no_filters','BlockBox','catalog-content',1),(55518,'117448','furniture-mobile','block-55517','BlockBox','',4),(55519,'117449','furniture-mobile','block-55518','catalog\\CountsItems','',1),(55520,'117450','furniture-mobile','block-55518-2','catalog\\Paging','',1),(55521,'117451','furniture-mobile','block-55517','Listing','',3),(55522,'117452','furniture-mobile','block-55517','catalog\\Title','',1),(55523,'117453','furniture-mobile','block-55517','catalog\\B2bAddButton','',5),(55524,'117454','furniture-mobile','block-55517','BlockBox','catalog-features',2),(55525,'117455','furniture-mobile','block-55524','BlockBox','',2),(55526,'117456','furniture-mobile','block-55525','HeaderStock','',5),(55527,'117457','furniture-mobile','block-55525','catalog\\ListingLook','',1),(55528,'117458','furniture-mobile','block-55525','catalog\\CompareButton','',2),(55529,'117459','furniture-mobile','block-55525','catalog\\ItemsOnPage','',4),(55530,'117460','furniture-mobile','block-55525','catalog\\Sorting','',3),(55531,'117461','furniture-mobile','block-55524','catalog\\Image','',1),(55532,'117462','furniture-mobile','order_history','BlockBox','',1),(55533,'117463','furniture-mobile','block-55532','BlockBox','',1),(55534,'117464','furniture-mobile','block-55533','WidgetsAria','',1),(55554,'117465','furniture-mobile','block-55533-2','Html_box','',1),(55555,'117466','furniture-mobile','block-55533-2','account\\OrdersHistory','',2),(55556,'117467','furniture-mobile','order_history_info','BlockBox','',1),(55557,'117468','furniture-mobile','block-55556','BlockBox','',1),(55558,'117469','furniture-mobile','block-55557','WidgetsAria','',1),(55578,'117470','furniture-mobile','block-55557-2','account\\OrderInvoiceButton','',3),(55579,'117471','furniture-mobile','block-55557-2','account\\OrderSubTotals','',11),(55580,'117472','furniture-mobile','block-55557-2','account\\OrderPayButton','',5),(55581,'117473','furniture-mobile','block-55557-2','BlockBox','',14),(55582,'117474','furniture-mobile','block-55581','account\\AccountLink','',1),(55583,'117475','furniture-mobile','block-55581-2','account\\OrderInvoiceButton','',1),(55584,'117476','furniture-mobile','block-55557-2','Html_box','',9),(55585,'117477','furniture-mobile','block-55557-2','account\\OrderHistory','',13),(55586,'117478','furniture-mobile','block-55557-2','account\\OrderCancelAndReorder','',4),(55587,'117479','furniture-mobile','block-55557-2','account\\OrderHeading','',1),(55588,'117480','furniture-mobile','block-55557-2','account\\OrderDownload','',6),(55589,'117481','furniture-mobile','block-55557-2','Html_box','',12),(55590,'117482','furniture-mobile','block-55557-2','account\\OrderProducts','',10),(55591,'117483','furniture-mobile','block-55557-2','account\\OrderReorderButton','',2),(55592,'117484','furniture-mobile','block-55557-2','BlockBox','',8),(55593,'117485','furniture-mobile','block-55592','BlockBox','',2),(55594,'117486','furniture-mobile','block-55593','Html_box','',1),(55595,'117487','furniture-mobile','block-55593','account\\OrderData','',2),(55596,'117488','furniture-mobile','block-55592','BlockBox','',1),(55597,'117489','furniture-mobile','block-55596','Html_box','',1),(55598,'117490','furniture-mobile','block-55596','account\\OrderData','',2),(55599,'117491','furniture-mobile','block-55592','BlockBox','',3),(55600,'117492','furniture-mobile','block-55599','account\\OrderTracking','',2),(55601,'117493','furniture-mobile','block-55599','Html_box','',1),(55602,'117494','furniture-mobile','block-55599','account\\AccountLink','',3),(55603,'117495','furniture-mobile','block-55592-2','BlockBox','',2),(55604,'117496','furniture-mobile','block-55603','account\\OrderData','',2),(55605,'117497','furniture-mobile','block-55603','Html_box','',1),(55606,'117498','furniture-mobile','block-55592-2','BlockBox','',1),(55607,'117499','furniture-mobile','block-55606','account\\OrderData','',2),(55608,'117500','furniture-mobile','block-55606','Html_box','',1),(55609,'117501','furniture-mobile','block-55592-3','BlockBox','',2),(55610,'117502','furniture-mobile','block-55609','account\\OrderData','',2),(55611,'117503','furniture-mobile','block-55609','Html_box','',1),(55612,'117504','furniture-mobile','block-55592-3','BlockBox','',1),(55613,'117505','furniture-mobile','block-55612','Html_box','',1),(55614,'117506','furniture-mobile','block-55612','account\\OrderData','',2),(55615,'117507','furniture-mobile','order_pay','BlockBox','',1),(55616,'117508','furniture-mobile','block-55615','BlockBox','',1),(55617,'117509','furniture-mobile','block-55616','WidgetsAria','',1),(55637,'117510','furniture-mobile','block-55616-2','account\\OrderProducts','',4),(55638,'117511','furniture-mobile','block-55616-2','BlockBox','',2),(55639,'117512','furniture-mobile','block-55638','BlockBox','',1),(55640,'117513','furniture-mobile','block-55639','Html_box','',1),(55641,'117514','furniture-mobile','block-55639','account\\OrderData','',2),(55642,'117515','furniture-mobile','block-55638','BlockBox','',4),(55643,'117516','furniture-mobile','block-55642','account\\OrderData','',2),(55644,'117517','furniture-mobile','block-55642','Html_box','',1),(55645,'117518','furniture-mobile','block-55638-2','BlockBox','',1),(55646,'117519','furniture-mobile','block-55645','Html_box','',1),(55647,'117520','furniture-mobile','block-55645','account\\OrderData','',2),(55648,'117521','furniture-mobile','block-55638-2','BlockBox','',2),(55649,'117522','furniture-mobile','block-55648','account\\OrderData','',2),(55650,'117523','furniture-mobile','block-55648','Html_box','',1),(55651,'117524','furniture-mobile','block-55638-3','BlockBox','',2),(55652,'117525','furniture-mobile','block-55651','Html_box','',1),(55653,'117526','furniture-mobile','block-55651','account\\OrderData','',2),(55654,'117527','furniture-mobile','block-55638-3','BlockBox','',1),(55655,'117528','furniture-mobile','block-55654','account\\OrderData','',2),(55656,'117529','furniture-mobile','block-55654','Html_box','',1),(55657,'117530','furniture-mobile','block-55616-2','UpdateAndPay\\PayForm','',6),(55658,'117531','furniture-mobile','block-55616-2','Html_box','',3),(55659,'117532','furniture-mobile','block-55616-2','account\\OrderHeading','',1),(55660,'117533','furniture-mobile','block-55616-2','account\\OrderSubTotals','',5),(55661,'117534','furniture-mobile','packingslip','invoice\\Container','',2),(55662,'117535','furniture-mobile','block-55661','BlockBox','',2),(55663,'117536','furniture-mobile','block-55662','Logo','',1),(55664,'117537','furniture-mobile','block-55662-2','BlockBox','',3),(55665,'117538','furniture-mobile','block-55664','Text','',2),(55666,'117539','furniture-mobile','block-55664-2','invoice\\StoreEmail','',1),(55667,'117540','furniture-mobile','block-55662-2','BlockBox','',2),(55668,'117541','furniture-mobile','block-55667','Text','',2),(55669,'117542','furniture-mobile','block-55667-2','invoice\\StorePhone','',1),(55670,'117543','furniture-mobile','block-55662-2','BlockBox','',1),(55671,'117544','furniture-mobile','block-55670','invoice\\StoreAddress','',1),(55672,'117545','furniture-mobile','block-55662-2','BlockBox','',4),(55673,'117546','furniture-mobile','block-55672','Text','',2),(55674,'117547','furniture-mobile','block-55672-2','invoice\\StoreSite','',1),(55675,'117548','furniture-mobile','block-55661','packingslip\\Products','',5),(55676,'117549','furniture-mobile','block-55661','BlockBox','',6),(55677,'117550','furniture-mobile','block-55676','invoice\\StoreAddress','',2),(55678,'117551','furniture-mobile','block-55676','Text','',1),(55679,'117552','furniture-mobile','block-55661','BlockBox','',3),(55680,'117553','furniture-mobile','block-55679','BlockBox','',2),(55681,'117554','furniture-mobile','block-55680','BlockBox','',1),(55682,'117555','furniture-mobile','block-55681','invoice\\ShippingAddress','',2),(55683,'117556','furniture-mobile','block-55681','Text','',1),(55684,'117557','furniture-mobile','block-55680-2','BlockBox','',1),(55685,'117558','furniture-mobile','block-55684','Text','',1),(55686,'117559','furniture-mobile','block-55684','invoice\\CustomerName','',2),(55687,'117560','furniture-mobile','block-55684','invoice\\CustomerEmail','',6),(55688,'117561','furniture-mobile','block-55684','Text','',3),(55689,'117562','furniture-mobile','block-55684','invoice\\CustomerPhone','',4),(55690,'117563','furniture-mobile','block-55684','Text','',5),(55691,'117564','furniture-mobile','block-55679','BlockBox','',3),(55692,'117565','furniture-mobile','block-55691','BlockBox','',1),(55693,'117566','furniture-mobile','block-55692','invoice\\ShippingMethod','',2),(55694,'117567','furniture-mobile','block-55692','Text','',1),(55695,'117568','furniture-mobile','block-55691-2','BlockBox','',1),(55696,'117569','furniture-mobile','block-55695','invoice\\ShippingMethod','',2),(55697,'117570','furniture-mobile','block-55695','Text','',1),(55698,'117571','furniture-mobile','block-55679-2','invoice\\AddressQrcode','',1),(55699,'1639660991.8692','furniture-mobile','block-55661','Neighbour\\PackingSlipInfo','',1),(55700,'1639661081.5616','furniture-mobile','block-55661','Neighbour\\PackingSlipInfo','',4),(55701,'117572','furniture-mobile','password_forgotten','BlockBox','',1),(55702,'117573','furniture-mobile','block-55701','BlockBox','',2),(55703,'1638807246.6206','furniture-mobile','block-55702','Html_box','',1),(55704,'117574','furniture-mobile','block-55702-2','Html_box','',1),(55705,'117575','furniture-mobile','block-55702-2','login\\PasswordForgotten','',2),(55706,'117576','furniture-mobile','block-55701','Html_box','',1),(55707,'117577','furniture-mobile','pdf','invoice\\Container','',1),(55708,'117578','furniture-mobile','block-55707','BlockBox','',1),(55709,'117579','furniture-mobile','block-55708','BlockBox','',1),(55710,'117580','furniture-mobile','block-55709','BlockBox','',1),(55711,'117581','furniture-mobile','block-55710','pdf\\ProductElement','',1),(55712,'117582','furniture-mobile','block-55709','BlockBox','',2),(55713,'117583','furniture-mobile','block-55712','pdf\\ProductElement','',1),(55714,'117584','furniture-mobile','block-55712-2','pdf\\ProductElement','',2),(55715,'117585','furniture-mobile','block-55712-2','pdf\\ProductElement','',1),(55716,'117586','furniture-mobile','block-55708-2','BlockBox','',1),(55717,'117587','furniture-mobile','block-55716','BlockBox','',2),(55718,'117588','furniture-mobile','block-55717','pdf\\ProductElement','',1),(55719,'117589','furniture-mobile','block-55717-2','pdf\\ProductElement','',2),(55720,'117590','furniture-mobile','block-55717-2','pdf\\ProductElement','',1),(55721,'117591','furniture-mobile','block-55716','BlockBox','',1),(55722,'117592','furniture-mobile','block-55721','pdf\\ProductElement','',1),(55723,'117593','furniture-mobile','pdf_category','pdf\\CategoryName','',2),(55724,'117594','furniture-mobile','pdf_category','pdf\\CategoryImage','',1),(55725,'117595','furniture-mobile','pdf_cover','invoice\\Container','',1),(55726,'117596','furniture-mobile','block-55725','Logo','',1),(55727,'117597','furniture-mobile','block-55725','Text','',3),(55728,'117598','furniture-mobile','pdf_footer','BlockBox','',1),(55729,'117599','furniture-mobile','block-55728-2','pdf\\PageNumber','',1),(55730,'117600','furniture-mobile','pdf_header','pdf\\CategoryName','',1),(55731,'117601','furniture-mobile','personal_catalog','BlockBox','',1),(55732,'117602','furniture-mobile','block-55731','BlockBox','',1),(55733,'117603','furniture-mobile','block-55732','WidgetsAria','',1),(55753,'117604','furniture-mobile','block-55732-2','Html_box','',1),(55754,'117606','furniture-mobile','block-55732-2','account\\PersonalCatalog','',2),(55755,'117607','furniture-mobile','points_earnt_history','BlockBox','',1),(55756,'117608','furniture-mobile','block-55755','Html_box','',1),(55757,'117609','furniture-mobile','block-55755','account\\PointsEarntHistory','',2),(55758,'117610','furniture-mobile','posts','BlockBox','',1),(55759,'117611','furniture-mobile','block-55758','Breadcrumb','',2),(55760,'117612','furniture-mobile','block-55758','Html_box','',1),(55761,'117613','furniture-mobile','block-55758','Communication\\Post','',3),(55762,'117614','furniture-mobile','product','BlockBox','product-content',2),(55763,'120997','furniture-mobile','block-55762','BlockBox','',1),(55764,'117646','furniture-mobile','block-55763','Tabs','',2),(55765,'117647','furniture-mobile','block-55764-1','product\\Description','',2),(55766,'117648','furniture-mobile','block-55764-1','product\\Properties','',1),(55767,'121011','furniture-mobile','block-55764-2','Html_box','',1),(55768,'1638898052.8626','furniture-mobile','block-55764-3','product\\Attributes','',1),(55769,'117654','furniture-mobile','block-55763','product\\CrossSell','',1),(55770,'121002','furniture-mobile','block-55762','Tabs','',3),(55771,'117645','furniture-mobile','block-55770-1','product\\AlsoPurchased','10',1),(55772,'117641','furniture-mobile','block-55770-2','ViewedProducts','4',1),(55773,'121004','furniture-mobile','block-55762','BlockBox','',2),(55774,'121005','furniture-mobile','block-55773','Html_box','',1),(55775,'121006','furniture-mobile','block-55773-2','Html_box','',1),(55776,'121007','furniture-mobile','block-55773-3','Html_box','',1),(55777,'121010','furniture-mobile','block-55762','BlockBox','',4),(55778,'117649','furniture-mobile','block-55777','product\\Reviews','',1),(55779,'1639053401.678','furniture-mobile','product','BlockBox','',0),(55780,'117616','furniture-mobile','block-55779','BlockBox','product-image',5),(55781,'117618','furniture-mobile','block-55780','product\\Images','',2),(55782,'117620','furniture-mobile','block-55780','product\\PromotionIcons','',1),(55783,'1638463239.7427','furniture-mobile','block-55780','product\\QuantityDiscounts','',3),(55784,'1639416584.6039','furniture-mobile','block-55780','product\\PropertiesIcons','',4),(55785,'1639497493.4253','furniture-mobile','block-55780','ProductDesigner\\Designer','',8),(55786,'1639497522.4889','furniture-mobile','block-55780','ProductDesigner\\Button','',6),(55787,'1639497722.549','furniture-mobile','block-55780','ProductDesigner\\Picture','',5),(55788,'120988','furniture-mobile','block-55780-2','BlockBox','product-side',3),(55789,'121009','furniture-mobile','block-55788','BlockBox','',1),(55790,'117629','furniture-mobile','block-55789','product\\DescriptionShort','',2),(55791,'117638','furniture-mobile','block-55789','product\\Model','',1),(55792,'121016','furniture-mobile','block-55789','Html_box','',3),(55793,'1639414189.221','furniture-mobile','block-55789','WeddingRegistry\\Button','',4),(55794,'1639656190.5331','furniture-mobile','block-55789','product\\Groups','',5),(55795,'121008','furniture-mobile','block-55788-2','BlockBox','',1),(55796,'120991','furniture-mobile','block-55795','BlockBox','',1),(55797,'120989','furniture-mobile','block-55796','product\\SaleEnds','',2),(55798,'120990','furniture-mobile','block-55796','BlockBox','',3),(55799,'117622','furniture-mobile','block-55798','product\\ButtonsQuote','',7),(55800,'117624','furniture-mobile','block-55798','product\\Price','',3),(55801,'117625','furniture-mobile','block-55798','product\\Quantity','',4),(55802,'117627','furniture-mobile','block-55798','product\\Buttons','',5),(55803,'117628','furniture-mobile','block-55798','product\\ButtonsSample','',8),(55804,'117635','furniture-mobile','block-55798','product\\PersonalCatalogButton','',6),(55805,'117640','furniture-mobile','block-55798','product\\Stock','',2),(55806,'1642500303.417','furniture-mobile','block-55798','product\\Attributes','',1),(55807,'1639582674.022','furniture-mobile','block-55795','BlockBox','',3),(55808,'117626','furniture-mobile','block-55807','product\\BonusPoints','',1),(55809,'117639','furniture-mobile','block-55779','product\\Name','',2),(55810,'117644','furniture-mobile','block-55779','Breadcrumb','',1),(55811,'120996','furniture-mobile','block-55779','BlockBox','',6),(55812,'117651','furniture-mobile','block-55811','product\\InBundles','',2),(55813,'120995','furniture-mobile','block-55811','product\\Bundle','',1),(55814,'120998','furniture-mobile','block-55779','BlockBox','product-image',3),(55815,'121000','furniture-mobile','block-55814','product\\Rating','',2),(55816,'121001','furniture-mobile','block-55814','Html_box','',2),(55817,'1639053523.9657','furniture-mobile','product','BlockBox','',0),(55818,'1638963486.2331','furniture-mobile','block-55817','product\\Collection','',4),(55819,'1639149261.0383','furniture-mobile','block-55817','product\\CustomBundle','',3),(55820,'1639659357.0881','furniture-mobile','block-55817','BlockBox','',2),(55821,'1639659044.5523','furniture-mobile','block-55820','ObsoleteProducts\\ObsoleteReplacementProducts','',1),(55822,'117655','furniture-mobile','product-bottom','product\\Properties','',1),(55823,'117656','furniture-mobile','product-tabs','product\\Reviews','',2),(55824,'117657','furniture-mobile','product-tabs','product\\Description','',1),(55825,'117658','furniture-mobile','product-top-left','product\\Images','',1),(55826,'117659','furniture-mobile','product-top-right','product\\Price','',2),(55827,'117660','furniture-mobile','product-top-right','product\\Quantity','',5),(55828,'117661','furniture-mobile','product-top-right','product\\Quantity','',6),(55829,'117662','furniture-mobile','product-top-right','product\\Attributes','',3),(55830,'117663','furniture-mobile','product-top-right','product\\Name','',1),(55831,'117664','furniture-mobile','product-top-right','product\\Buttons','',6),(55832,'117665','furniture-mobile','productListing','BlockBox','listing-item',1),(55833,'120921','furniture-mobile','block-55832','BlockBox','',1),(55834,'120896','furniture-mobile','block-55833','BlockBox','',2),(55835,'117677','furniture-mobile','block-55834','productListing\\compare','',3),(55836,'120882','furniture-mobile','block-55834','productListing\\personalCatalog','',2),(55837,'120895','furniture-mobile','block-55834','productListing\\viewButton','',1),(55838,'120919','furniture-mobile','block-55833','BlockBox','',1),(55839,'117667','furniture-mobile','block-55838','productListing\\bonusPoints','',3),(55840,'117668','furniture-mobile','block-55838','productListing\\description','',7),(55841,'117670','furniture-mobile','block-55838','productListing\\rating','',8),(55842,'117671','furniture-mobile','block-55838','productListing\\image','',1),(55843,'117673','furniture-mobile','block-55838','productListing\\price','',5),(55844,'117675','furniture-mobile','block-55838','productListing\\name','',6),(55845,'117676','furniture-mobile','block-55838','productListing\\stock','',4),(55846,'120863','furniture-mobile','block-55838','productListing\\ratingCounts','',9),(55847,'1639645717.6681','furniture-mobile','block-55838','productListing\\productGroup','',2),(55848,'117678','furniture-mobile','products','BlockBox','catalog-content',1),(55849,'117679','furniture-mobile','block-55848','BlockBox','catalog-side',4),(55850,'117680','furniture-mobile','block-55849','Filters','',3),(55851,'117681','furniture-mobile','block-55849','HeaderStock','',4),(55852,'120916','furniture-mobile','block-55849','BlockBox','',1),(55853,'120918','furniture-mobile','block-55852','BlockBox','',3),(55854,'120884','furniture-mobile','block-55853','Menu','LeftCategories',2),(55855,'120917','furniture-mobile','block-55853','Html_box','',1),(55856,'117682','furniture-mobile','block-55849-2','catalog\\B2bAddButton','',5),(55857,'117683','furniture-mobile','block-55849-2','BlockBox','catalog-features',2),(55858,'117684','furniture-mobile','block-55857','catalog\\Sorting','',3),(55859,'117685','furniture-mobile','block-55857','catalog\\ListingLook','',1),(55860,'117686','furniture-mobile','block-55857','catalog\\ItemsOnPage','',4),(55861,'117687','furniture-mobile','block-55857','catalog\\CompareButton','',2),(55862,'117688','furniture-mobile','block-55849-2','BlockBox','',6),(55863,'117689','furniture-mobile','block-55862','catalog\\CountsItems','',1),(55864,'117690','furniture-mobile','block-55862-2','catalog\\Paging','',1),(55865,'117691','furniture-mobile','block-55849-2','Listing','',4),(55866,'120912','furniture-mobile','block-55849-2','BlockBox','',3),(55867,'120913','furniture-mobile','block-55866','catalog\\CountsItems','',1),(55868,'120914','furniture-mobile','block-55866-2','catalog\\Paging','',1),(55869,'1639760443.0645','furniture-mobile','block-55849-2','catalog\\AdditionalImages','',1),(55870,'117692','furniture-mobile','block-55848','catalog\\Title','',2),(55871,'117693','furniture-mobile','block-55848','BlockBox','',3),(55872,'117694','furniture-mobile','block-55871','catalog\\Image','',2),(55873,'1639415554.3073','furniture-mobile','block-55871','product\\WeddingRegistryButton','',3),(55874,'121018','furniture-mobile','products','Compare','',2),(55875,'117695','furniture-mobile','products-list','packingslip\\AllProductsList','',2),(55876,'117696','furniture-mobile','promotions','BlockBox','info-content',1),(55877,'117697','furniture-mobile','block-55876','promotions\\PromoList','',2),(55878,'117698','furniture-mobile','block-55876','Html_box','',1),(55879,'117699','furniture-mobile','purchase','invoice\\Container','',1),(55880,'117700','furniture-mobile','block-55879','invoice\\Products','',3),(55881,'117701','furniture-mobile','block-55879','BlockBox','',5),(55882,'117702','furniture-mobile','block-55881','Text','',1),(55883,'117703','furniture-mobile','block-55881','invoice\\StoreAddress','',8),(55884,'117704','furniture-mobile','block-55881-2','Text','',2),(55885,'117705','furniture-mobile','block-55881-2','Logo','',1),(55886,'117706','furniture-mobile','block-55881-3','BlockBox','',3),(55887,'117707','furniture-mobile','block-55886','Text','',1),(55888,'117708','furniture-mobile','block-55886-2','invoice\\StoreEmail','',1),(55889,'117709','furniture-mobile','block-55881-3','Text','',1),(55890,'117710','furniture-mobile','block-55881-3','BlockBox','',2),(55891,'117711','furniture-mobile','block-55890','Text','',1),(55892,'117712','furniture-mobile','block-55890-2','invoice\\StorePhone','',1),(55893,'117713','furniture-mobile','block-55879','BlockBox','',1),(55894,'117714','furniture-mobile','block-55893','Logo','',1),(55895,'117715','furniture-mobile','block-55893-2','BlockBox','',2),(55896,'117716','furniture-mobile','block-55895','Text','',1),(55897,'117717','furniture-mobile','block-55895-2','invoice\\StorePhone','',1),(55898,'117718','furniture-mobile','block-55893-2','BlockBox','',4),(55899,'117719','furniture-mobile','block-55898','Text','',1),(55900,'117720','furniture-mobile','block-55898-2','invoice\\StoreSite','',1),(55901,'117721','furniture-mobile','block-55893-2','BlockBox','',1),(55902,'117722','furniture-mobile','block-55901','invoice\\StoreAddress','',1),(55903,'117723','furniture-mobile','block-55893-2','BlockBox','',3),(55904,'117724','furniture-mobile','block-55903','Text','',1),(55905,'117725','furniture-mobile','block-55903-2','invoice\\StoreEmail','',1),(55906,'117726','furniture-mobile','block-55879','BlockBox','',2),(55907,'117727','furniture-mobile','block-55906','BlockBox','',7),(55908,'117728','furniture-mobile','block-55907','BlockBox','',1),(55909,'117729','furniture-mobile','block-55908','invoice\\BillingAddress','',2),(55910,'117730','furniture-mobile','block-55908','Text','',1),(55911,'117731','furniture-mobile','block-55907-2','BlockBox','',1),(55912,'117732','furniture-mobile','block-55911','invoice\\CustomerEmail','',6),(55913,'117733','furniture-mobile','block-55911','Text','',5),(55914,'117734','furniture-mobile','block-55911','invoice\\CustomerPhone','',4),(55915,'117735','furniture-mobile','block-55911','invoice\\CustomerName','',2),(55916,'117736','furniture-mobile','block-55911','Text','',3),(55917,'117737','furniture-mobile','block-55911','Text','',1),(55918,'117738','furniture-mobile','block-55906-2','invoice\\OrderId','',1),(55919,'117739','furniture-mobile','block-55906-2','Text','',2),(55920,'117740','furniture-mobile','block-55906-2','invoice\\PaymentDate','',3),(55921,'117741','furniture-mobile','block-55879','BlockBox','',4),(55922,'117742','furniture-mobile','block-55921','BlockBox','',1),(55923,'117743','furniture-mobile','block-55922','invoice\\ShippingAddress','',2),(55924,'117744','furniture-mobile','block-55922','Text','',1),(55928,'117745','furniture-mobile','quotations','BlockBox','',1),(55929,'117746','furniture-mobile','block-55928','BlockBox','',1),(55930,'117747','furniture-mobile','block-55929','WidgetsAria','',1),(55950,'117748','furniture-mobile','block-55929-2','Html_box','',1),(55951,'117749','furniture-mobile','block-55929-2','Quotations\\QuotationsHistory','',2),(55952,'117750','furniture-mobile','quotation_info','BlockBox','',1),(55953,'117751','furniture-mobile','block-55952','BlockBox','',1),(55954,'117752','furniture-mobile','block-55953','WidgetsAria','',1),(55974,'117753','furniture-mobile','block-55953-2','BlockBox','',5),(55975,'117754','furniture-mobile','block-55974','BlockBox','',1),(55976,'117755','furniture-mobile','block-55975','Quotations\\QuotationData','',2),(55977,'117756','furniture-mobile','block-55975','Html_box','',1),(55978,'117757','furniture-mobile','block-55974','BlockBox','',4),(55979,'117758','furniture-mobile','block-55978','Html_box','',1),(55980,'117759','furniture-mobile','block-55978','Quotations\\QuotationData','',2),(55981,'117760','furniture-mobile','block-55974-2','BlockBox','',2),(55982,'117761','furniture-mobile','block-55981','Html_box','',1),(55983,'117762','furniture-mobile','block-55981','Quotations\\QuotationData','',2),(55984,'117763','furniture-mobile','block-55974-2','BlockBox','',1),(55985,'117764','furniture-mobile','block-55984','Html_box','',1),(55986,'117765','furniture-mobile','block-55984','Quotations\\QuotationData','',2),(55987,'117766','furniture-mobile','block-55974-3','BlockBox','',1),(55988,'117767','furniture-mobile','block-55987','Quotations\\QuotationData','',2),(55989,'117768','furniture-mobile','block-55987','Html_box','',1),(55990,'117769','furniture-mobile','block-55974-3','BlockBox','',2),(55991,'117770','furniture-mobile','block-55990','Quotations\\QuotationData','',2),(55992,'117771','furniture-mobile','block-55990','Html_box','',1),(55993,'117772','furniture-mobile','block-55953-2','Html_box','',6),(55994,'117773','furniture-mobile','block-55953-2','Quotations\\QuotationHistory','',10),(55995,'117774','furniture-mobile','block-55953-2','Html_box','',9),(55996,'117775','furniture-mobile','block-55953-2','Quotations\\QuotationProducts','',7),(55997,'117776','furniture-mobile','block-55953-2','Quotations\\QuotationSubTotal','',8),(55998,'117777','furniture-mobile','block-55953-2','BlockBox','',12),(55999,'117778','furniture-mobile','block-55998','account\\AccountLink','',1),(56000,'117779','furniture-mobile','block-55953-2','Html_box','',4),(56001,'117780','furniture-mobile','quote','BlockBox','',1),(56002,'117781','furniture-mobile','block-56001','cart\\CartTabs','',1),(56003,'117782','furniture-mobile','block-56002','BlockBox','',1),(56004,'117783','furniture-mobile','block-56003','quote\\Products','',1),(56005,'117784','furniture-mobile','block-56003-2','BlockBox','',1),(56006,'117785','furniture-mobile','block-56005','BlockBox','',1),(56007,'117786','furniture-mobile','block-56006','quote\\CheckoutBtn','',2),(56008,'117787','furniture-mobile','block-56002','Quotations\\QuotationSubTotal','',2),(56009,'117788','furniture-mobile','review','BlockBox','',1),(56010,'117789','furniture-mobile','block-56009','BlockBox','',1),(56011,'117790','furniture-mobile','block-56010','WidgetsAria','',1),(56031,'117791','furniture-mobile','block-56010-2','Html_box','',1),(56032,'117792','furniture-mobile','block-56010-2','account\\Reviews','',2),(56033,'117793','furniture-mobile','reviews','BlockBox','info-content',1),(56034,'117794','furniture-mobile','block-56033','reviews\\Heading','',1),(56035,'117795','furniture-mobile','block-56033','reviews\\Content','',2),(56036,'117796','furniture-mobile','rma_document','invoice\\Container','',1),(56037,'117797','furniture-mobile','block-56036','BlockBox','',1),(56038,'117798','furniture-mobile','block-56037','BlockBox','',1),(56039,'117799','furniture-mobile','block-56038','BlockBox','',2),(56040,'117800','furniture-mobile','block-56039','Html_box','',1),(56041,'117801','furniture-mobile','block-56039-2','Html_box','',1),(56042,'117802','furniture-mobile','block-56038','BlockBox','',5),(56043,'117803','furniture-mobile','block-56042','Html_box','',1),(56044,'117804','furniture-mobile','block-56042-2','Html_box','',1),(56045,'117805','furniture-mobile','block-56038','BlockBox','',4),(56046,'117806','furniture-mobile','block-56045','Html_box','',1),(56047,'117807','furniture-mobile','block-56045-2','Html_box','',1),(56048,'117808','furniture-mobile','block-56038','BlockBox','',3),(56049,'117809','furniture-mobile','block-56048','Html_box','',1),(56050,'117810','furniture-mobile','block-56048-2','Html_box','',1),(56051,'117811','furniture-mobile','block-56038','BlockBox','',1),(56052,'117812','furniture-mobile','block-56051','Html_box','',1),(56053,'117813','furniture-mobile','block-56051','Html_box','',2),(56054,'117814','furniture-mobile','block-56037-2','BlockBox','',1),(56055,'117815','furniture-mobile','block-56054','Html_box','',2),(56056,'117816','furniture-mobile','block-56054','Logo','',1),(56057,'117817','furniture-mobile','block-56037-2','BlockBox','',2),(56058,'117818','furniture-mobile','block-56057','BlockBox','',5),(56059,'117819','furniture-mobile','block-56058','BlockBox','',1),(56060,'117820','furniture-mobile','block-56059','Html_box','',1),(56061,'117821','furniture-mobile','block-56059-2','Rma\\DocumentData','',1),(56062,'117822','furniture-mobile','block-56058-2','BlockBox','',1),(56063,'117823','furniture-mobile','block-56062','Html_box','',1),(56064,'117824','furniture-mobile','block-56062-2','Rma\\DocumentData','',1),(56065,'117825','furniture-mobile','block-56057','BlockBox','',4),(56066,'117826','furniture-mobile','block-56065','BlockBox','',1),(56067,'117827','furniture-mobile','block-56066','Html_box','',1),(56068,'117828','furniture-mobile','block-56066-2','Rma\\DocumentData','',1),(56069,'117829','furniture-mobile','block-56065-2','BlockBox','',1),(56070,'117830','furniture-mobile','block-56069','Html_box','',1),(56071,'117831','furniture-mobile','block-56069-2','Rma\\DocumentData','',1),(56072,'117832','furniture-mobile','block-56057','BlockBox','',3),(56073,'117833','furniture-mobile','block-56072','BlockBox','',1),(56074,'117834','furniture-mobile','block-56073','Html_box','',1),(56075,'117835','furniture-mobile','block-56073-2','Rma\\DocumentData','',1),(56076,'117836','furniture-mobile','block-56072-2','BlockBox','',1),(56077,'117837','furniture-mobile','block-56076','Html_box','',1),(56078,'117838','furniture-mobile','block-56076-2','Rma\\DocumentData','',1),(56079,'117839','furniture-mobile','block-56057','BlockBox','',2),(56080,'117840','furniture-mobile','block-56079','Html_box','',1),(56081,'117841','furniture-mobile','block-56079-2','Rma\\DocumentData','',1),(56082,'117842','furniture-mobile','block-56057','BlockBox','',1),(56083,'117843','furniture-mobile','block-56082','BlockBox','',1),(56084,'117844','furniture-mobile','block-56083','Html_box','',1),(56085,'117845','furniture-mobile','block-56083-2','Rma\\DocumentData','',1),(56086,'117846','furniture-mobile','block-56082-2','BlockBox','',1),(56087,'117847','furniture-mobile','block-56086','Html_box','',1),(56088,'117848','furniture-mobile','block-56086-2','Rma\\DocumentData','',1),(56089,'117849','furniture-mobile','block-56037-2','BlockBox','',3),(56090,'117850','furniture-mobile','block-56089','BlockBox','',1),(56091,'117851','furniture-mobile','block-56090','Html_box','',1),(56092,'117852','furniture-mobile','block-56090-2','Rma\\DocumentData','',1),(56093,'117853','furniture-mobile','block-56089-2','BlockBox','',1),(56094,'117854','furniture-mobile','block-56093','Html_box','',1),(56095,'117855','furniture-mobile','block-56093-2','Rma\\DocumentData','',1),(56096,'117856','furniture-mobile','block-56036','BlockBox','',2),(56097,'117857','furniture-mobile','block-56096','Html_box','',1),(56098,'117858','furniture-mobile','block-56096','Rma\\Products','',2),(56099,'117859','furniture-mobile','block-56036','BlockBox','',3),(56100,'117860','furniture-mobile','block-56099','BlockBox','',1),(56101,'117861','furniture-mobile','block-56100','BlockBox','',1),(56102,'117862','furniture-mobile','block-56101','BlockBox','',5),(56103,'117863','furniture-mobile','block-56102','Html_box','',1),(56104,'117864','furniture-mobile','block-56102-2','invoice\\StoreAddress','',2),(56105,'117865','furniture-mobile','block-56102-2','Html_box','',1),(56106,'117866','furniture-mobile','block-56101','BlockBox','',4),(56107,'117867','furniture-mobile','block-56106','Html_box','',1),(56108,'117868','furniture-mobile','block-56106-2','Html_box','',1),(56109,'117869','furniture-mobile','block-56101','BlockBox','',2),(56110,'117870','furniture-mobile','block-56109','Html_box','',1),(56111,'117871','furniture-mobile','block-56109-2','Html_box','',1),(56112,'117872','furniture-mobile','block-56101','BlockBox','',1),(56113,'117873','furniture-mobile','block-56112','Html_box','',1),(56114,'117874','furniture-mobile','block-56101','BlockBox','',3),(56115,'117875','furniture-mobile','block-56114','Html_box','',1),(56116,'117876','furniture-mobile','block-56114-2','Html_box','',1),(56117,'117877','furniture-mobile','block-56101','BlockBox','',6),(56118,'117878','furniture-mobile','block-56117','Html_box','',1),(56119,'117879','furniture-mobile','block-56100-2','BlockBox','',1),(56120,'117880','furniture-mobile','block-56119','BlockBox','',1),(56121,'117881','furniture-mobile','block-56120','BlockBox','',1),(56122,'117882','furniture-mobile','block-56121','Rma\\DocumentData','',2),(56123,'117883','furniture-mobile','block-56121-3','BlockBox','',1),(56124,'117884','furniture-mobile','block-56123','Html_box','',1),(56125,'117885','furniture-mobile','block-56123-2','Rma\\DocumentData','',1),(56126,'117886','furniture-mobile','block-56120','BlockBox','',2),(56127,'117887','furniture-mobile','block-56126-2','invoice\\StoreAddress','',1),(56128,'117888','furniture-mobile','block-56100-2','BlockBox','',2),(56129,'117889','furniture-mobile','block-56128','Html_box','',1),(56130,'117890','furniture-mobile','block-56128','Html_box','',2),(56131,'117891','furniture-mobile','block-56128','Html_box','',3),(56132,'117892','furniture-mobile','block-56128','Html_box','',4),(56133,'117893','furniture-mobile','block-56128','Html_box','',5),(56134,'117894','furniture-mobile','block-56100-2','BlockBox','',4),(56135,'117895','furniture-mobile','block-56134','Html_box','',1),(56136,'117896','furniture-mobile','block-56134-2','Html_box','',1),(56137,'117897','furniture-mobile','block-56134-3','BlockBox','',1),(56138,'117898','furniture-mobile','block-56137','Html_box','',1),(56139,'117899','furniture-mobile','block-56137-2','Html_box','',1),(56140,'117900','furniture-mobile','block-56100-2','BlockBox','',3),(56141,'117901','furniture-mobile','block-56140','Html_box','',1),(56142,'117902','furniture-mobile','block-56140-2','Html_box','',1),(56143,'117903','furniture-mobile','block-56140-3','BlockBox','',1),(56144,'117904','furniture-mobile','block-56143','Html_box','',1),(56145,'117905','furniture-mobile','block-56143-2','Html_box','',1),(56146,'117906','furniture-mobile','rows','BlockBox','listing-item',1),(56147,'117907','furniture-mobile','block-56146','BlockBox','',2),(56148,'117908','furniture-mobile','block-56147','BlockBox','',2),(56149,'117909','furniture-mobile','block-56148','productListing\\bonusPoints','',2),(56150,'117910','furniture-mobile','block-56148','productListing\\image','',1),(56151,'117914','furniture-mobile','block-56148-2','productListing\\name','',1),(56152,'117915','furniture-mobile','block-56148-2','productListing\\description','',2),(56153,'117916','furniture-mobile','block-56148-2','productListing\\model','',4),(56154,'117917','furniture-mobile','block-56148-2','productListing\\attributes','',5),(56155,'120922','furniture-mobile','block-56148-2','productListing\\properties','',3),(56156,'1639146806.7019','furniture-mobile','block-56148-2','productListing\\productGroup','',6),(56157,'117918','furniture-mobile','block-56147-2','BlockBox','listing-item',1),(56158,'117911','furniture-mobile','block-56157','BlockBox','',3),(56159,'117912','furniture-mobile','block-56158','productListing\\rating','',1),(56160,'117913','furniture-mobile','block-56158','productListing\\ratingCounts','',2),(56161,'117919','furniture-mobile','block-56157','productListing\\qtyInput','',4),(56162,'117920','furniture-mobile','block-56157','productListing\\price','',2),(56163,'117922','furniture-mobile','block-56157','productListing\\buyButton','',5),(56164,'117924','furniture-mobile','block-56157','productListing\\stock','',1),(56165,'120924','furniture-mobile','block-56157','BlockBox','',8),(56166,'120925','furniture-mobile','block-56165','productListing\\compare','',3),(56167,'120926','furniture-mobile','block-56165','productListing\\personalCatalog','',2),(56168,'120927','furniture-mobile','block-56165','productListing\\viewButton','',1),(56169,'117925','furniture-mobile','sample','BlockBox','',1),(56170,'117926','furniture-mobile','block-56169','cart\\CartTabs','',1),(56171,'117927','furniture-mobile','block-56170','BlockBox','',1),(56172,'117928','furniture-mobile','block-56171','sample\\Products','',1),(56173,'117929','furniture-mobile','block-56171-2','BlockBox','',1),(56174,'117930','furniture-mobile','block-56173','BlockBox','',1),(56175,'117931','furniture-mobile','block-56174','sample\\CheckoutBtn','',1),(56176,'117932','furniture-mobile','samples','BlockBox','',1),(56177,'117933','furniture-mobile','block-56176','BlockBox','',1),(56178,'117934','furniture-mobile','block-56177','WidgetsAria','',1),(56198,'117935','furniture-mobile','block-56177-2','Html_box','',1),(56199,'117936','furniture-mobile','block-56177-2','Samples\\SamplesHistory','',2),(56200,'117937','furniture-mobile','sample_info','BlockBox','',1),(56201,'117938','furniture-mobile','block-56200','BlockBox','',1),(56202,'117939','furniture-mobile','block-56201','WidgetsAria','',1),(56222,'117940','furniture-mobile','block-56201-2','Html_box','',1),(56223,'117941','furniture-mobile','block-56201-2','BlockBox','',8),(56224,'117942','furniture-mobile','block-56223','account\\AccountLink','',1),(56225,'117943','furniture-mobile','block-56201-2','Samples\\SampleHistory','',7),(56226,'117944','furniture-mobile','block-56201-2','Html_box','',3),(56227,'117945','furniture-mobile','block-56201-2','Samples\\SampleSubTotal','',5),(56228,'117946','furniture-mobile','block-56201-2','Samples\\SampleProducts','',4),(56229,'117947','furniture-mobile','block-56201-2','Html_box','',6),(56230,'117948','furniture-mobile','block-56201-2','BlockBox','',2),(56231,'117949','furniture-mobile','block-56230','BlockBox','',4),(56232,'117950','furniture-mobile','block-56231','Html_box','',1),(56233,'117951','furniture-mobile','block-56231','Samples\\SampleData','',2),(56234,'117952','furniture-mobile','block-56230','BlockBox','',1),(56235,'117953','furniture-mobile','block-56234','Samples\\SampleData','',2),(56236,'117954','furniture-mobile','block-56234','Html_box','',1),(56237,'117955','furniture-mobile','block-56230-2','BlockBox','',2),(56238,'117956','furniture-mobile','block-56237','Samples\\SampleData','',2),(56239,'117957','furniture-mobile','block-56237','Html_box','',1),(56240,'117958','furniture-mobile','block-56230-2','BlockBox','',1),(56241,'117959','furniture-mobile','block-56240','Samples\\SampleData','',2),(56242,'117960','furniture-mobile','block-56240','Html_box','',1),(56243,'117961','furniture-mobile','block-56230-3','BlockBox','',2),(56244,'117962','furniture-mobile','block-56243','Samples\\SampleData','',2),(56245,'117963','furniture-mobile','block-56243','Html_box','',1),(56246,'117964','furniture-mobile','block-56230-3','BlockBox','',1),(56247,'117965','furniture-mobile','block-56246','Samples\\SampleData','',2),(56248,'117966','furniture-mobile','block-56246','Html_box','',1),(56249,'117967','furniture-mobile','sitemap','BlockBox','info-content',1),(56250,'117968','furniture-mobile','block-56249','Html_box','',1),(56251,'117969','furniture-mobile','block-56249','BlockBox','',2),(56252,'117970','furniture-mobile','block-56251','Html_box','',1),(56253,'117971','furniture-mobile','block-56251','Html_box','',5),(56254,'117972','furniture-mobile','block-56251','Html_box','',3),(56255,'117973','furniture-mobile','block-56251','sitemap\\InfoPages','',2),(56256,'117974','furniture-mobile','block-56251','sitemap\\Categories','',4),(56257,'117975','furniture-mobile','block-56251','Menu','Account box',6),(56258,'117976','furniture-mobile','block-56251-2','sitemap\\DeliveryLocation','',2),(56259,'117977','furniture-mobile','block-56251-2','Html_box','',1),(56260,'120878','furniture-mobile','social','SocialLinks','',1),(56261,'117978','furniture-mobile','subscribe','BlockBox','',1),(56262,'117979','furniture-mobile','block-56261','Html_box','',3),(56263,'117980','furniture-mobile','block-56261','subscribers\\UnsubscribeForm','',4),(56264,'117981','furniture-mobile','block-56261','Html_box','',1),(56265,'117982','furniture-mobile','block-56261','subscribers\\SubscribeForm','',2),(56266,'117983','furniture-mobile','subscribed','BlockBox','',1),(56267,'117984','furniture-mobile','block-56266','Html_box','',1),(56268,'117985','furniture-mobile','subscription','BlockBox','',2),(56269,'117986','furniture-mobile','block-56268','BlockBox','',1),(56270,'117987','furniture-mobile','block-56269','WidgetsAria','',1),(56290,'117988','furniture-mobile','block-56269-2','Html_box','',2),(56291,'117989','furniture-mobile','block-56269-2','Html_box','',3),(56292,'117990','furniture-mobile','block-56269-2','account\\Subscription','',4),(56293,'117991','furniture-mobile','success','BlockBox','',2),(56294,'117992','furniture-mobile','block-56293','BlockBox','',1),(56295,'117993','furniture-mobile','block-56294','Html_box','',1),(56296,'117994','furniture-mobile','block-56294','BlockBox','',2),(56297,'117995','furniture-mobile','block-56296','success\\PrintBtn','',1),(56298,'117996','furniture-mobile','block-56296','success\\ContinueBtn','',2),(56299,'1639413072.5477','furniture-mobile','block-56296','success\\Download','',3),(56300,'117997','furniture-mobile','success_q','BlockBox','',1),(56301,'117998','furniture-mobile','block-56300','BlockBox','',1),(56302,'117999','furniture-mobile','block-56301','BlockBox','',2),(56303,'118000','furniture-mobile','block-56302','success\\ContinueBtn','',2),(56304,'118001','furniture-mobile','block-56302','success\\PrintBtn','',1),(56305,'118002','furniture-mobile','block-56301','Html_box','',1),(56310,'118007','furniture-mobile','ticket','invoice\\Container','',1),(56311,'118008','furniture-mobile','block-56310','BlockBox','',4),(56312,'118009','furniture-mobile','block-56311','BlockBox','',1),(56313,'118010','furniture-mobile','block-56312','invoice\\ShippingAddress','',2),(56314,'118011','furniture-mobile','block-56312','Text','',1),(56315,'118012','furniture-mobile','block-56311-2','BlockBox','',1),(56316,'118013','furniture-mobile','block-56315','invoice\\Totals','',1),(56317,'118014','furniture-mobile','block-56310','BlockBox','',5),(56318,'118015','furniture-mobile','block-56317','Text','',1),(56319,'118016','furniture-mobile','block-56317','invoice\\StoreAddress','',8),(56320,'118018','furniture-mobile','block-56317-2','Text','',2),(56321,'118019','furniture-mobile','block-56317-3','Text','',1),(56322,'118020','furniture-mobile','block-56317-3','BlockBox','',3),(56323,'118021','furniture-mobile','block-56322','Text','',1),(56324,'118022','furniture-mobile','block-56322-2','invoice\\StoreEmail','',1),(56325,'118023','furniture-mobile','block-56317-3','BlockBox','',2),(56326,'118024','furniture-mobile','block-56325','Text','',1),(56327,'118025','furniture-mobile','block-56325-2','invoice\\StorePhone','',1),(56328,'118026','furniture-mobile','block-56310','invoice\\Products','',3),(56329,'118027','furniture-mobile','block-56310','BlockBox','',1),(56330,'118028','furniture-mobile','block-56329-2','BlockBox','',3),(56331,'118029','furniture-mobile','block-56330','Text','',1),(56332,'118030','furniture-mobile','block-56330-2','invoice\\StoreEmail','',1),(56333,'118031','furniture-mobile','block-56329-2','BlockBox','',4),(56334,'118032','furniture-mobile','block-56333','Text','',1),(56335,'118033','furniture-mobile','block-56333-2','invoice\\StoreSite','',1),(56336,'118034','furniture-mobile','block-56329-2','BlockBox','',1),(56337,'118035','furniture-mobile','block-56336','invoice\\StoreAddress','',1),(56338,'118036','furniture-mobile','block-56329-2','BlockBox','',2),(56339,'118037','furniture-mobile','block-56338','Text','',1),(56340,'118038','furniture-mobile','block-56338-2','invoice\\StorePhone','',1),(56341,'118039','furniture-mobile','block-56310','BlockBox','',2),(56342,'118040','furniture-mobile','block-56341','BlockBox','',8),(56343,'118041','furniture-mobile','block-56342','BlockBox','',1),(56344,'118042','furniture-mobile','block-56343','Text','',1),(56345,'118043','furniture-mobile','block-56343','invoice\\ShippingMethod','',2),(56346,'118044','furniture-mobile','block-56342-2','BlockBox','',1),(56347,'118045','furniture-mobile','block-56346','Text','',1),(56348,'118046','furniture-mobile','block-56346','invoice\\ShippingMethod','',2),(56349,'118047','furniture-mobile','block-56341','BlockBox','',7),(56350,'118048','furniture-mobile','block-56349','BlockBox','',1),(56351,'118049','furniture-mobile','block-56350','invoice\\BillingAddress','',2),(56352,'118050','furniture-mobile','block-56350','Text','',1),(56353,'118051','furniture-mobile','block-56349-2','BlockBox','',1),(56354,'118052','furniture-mobile','block-56353','invoice\\CustomerName','',2),(56355,'118053','furniture-mobile','block-56353','Text','',3),(56356,'118054','furniture-mobile','block-56353','invoice\\CustomerEmail','',6),(56357,'118055','furniture-mobile','block-56353','invoice\\CustomerPhone','',4),(56358,'118056','furniture-mobile','block-56353','Text','',5),(56359,'118057','furniture-mobile','block-56353','Text','',1),(56360,'118058','furniture-mobile','block-56341-2','invoice\\PaymentDate','',3),(56361,'118059','furniture-mobile','block-56341-2','Text','',2),(56362,'118060','furniture-mobile','block-56341-2','Text','',4),(56363,'118061','furniture-mobile','block-56341-2','invoice\\OrderId','',1),(56364,'118062','furniture-mobile','block-56341-2','invoice\\PaymentMethod','',5),(56365,'118063','furniture-mobile','block-56341-2','invoice\\OrderBarcode','',6),(56366,'118064','furniture-mobile','tl_blog_category','BlockBox','',1),(56367,'118065','furniture-mobile','block-56366','BlockBox','',1),(56368,'118066','furniture-mobile','block-56367','BlockBox','',1),(56369,'118067','furniture-mobile','block-56368','Blog\\widget\\PostListing','',1),(56370,'118068','furniture-mobile','block-56368','catalog\\Paging','',2),(56371,'118069','furniture-mobile','block-56367-2','WidgetsAria','',1),(56376,'118070','furniture-mobile','tl_blog_index','BlockBox','',2),(56377,'118071','furniture-mobile','block-56376','Banner','',1),(56378,'118072','furniture-mobile','block-56376','BlockBox','',2),(56379,'118073','furniture-mobile','block-56378','BlockBox','',1),(56380,'118074','furniture-mobile','block-56379','catalog\\Paging','',2),(56381,'118075','furniture-mobile','block-56379','Blog\\widget\\PostListing','',1),(56382,'118076','furniture-mobile','block-56378-2','WidgetsAria','',1),(56387,'118077','furniture-mobile','tl_blog_post','BlockBox','',1),(56388,'118078','furniture-mobile','block-56387','BlockBox','',3),(56389,'118079','furniture-mobile','block-56388','Blog\\widget\\PostLinkedProducts','',4),(56390,'118080','furniture-mobile','block-56388','BlockBox','',1),(56391,'118081','furniture-mobile','block-56390','Blog\\widget\\PostImage','',1),(56392,'118082','furniture-mobile','block-56390','Blog\\widget\\PostDate','',2),(56393,'118083','furniture-mobile','block-56390','Blog\\widget\\PostTitle','',3),(56394,'118084','furniture-mobile','block-56390','Blog\\widget\\PostDescription','',4),(56395,'118085','furniture-mobile','block-56390','BlockBox','',5),(56396,'118086','furniture-mobile','block-56395','Blog\\widget\\PostViewed','',1),(56397,'118087','furniture-mobile','block-56388-2','WidgetsAria','',1),(56402,'118088','furniture-mobile','tl_blog_tags','BlockBox','',1),(56403,'118089','furniture-mobile','block-56402','BlockBox','',1),(56404,'118090','furniture-mobile','block-56403','BlockBox','',1),(56405,'118091','furniture-mobile','block-56404','Blog\\widget\\PostListing','',1),(56406,'118092','furniture-mobile','block-56404','catalog\\Paging','',2),(56407,'118093','furniture-mobile','block-56403-2','WidgetsAria','',1),(56408,'116208','furniture-mobile','blogsidebar','BlockBox','',1),(56409,'116209','furniture-mobile','block-56408','Blog\\widget\\MostPopularPosts','',3),(56410,'116210','furniture-mobile','block-56408','Blog\\widget\\TagCloud','',2),(56411,'116211','furniture-mobile','block-56408','Blog\\widget\\CategoriesList','',1),(56412,'118094','furniture-mobile','tracking_numbers','BlockBox','',1),(56413,'118095','furniture-mobile','block-56412','Html_box','',1),(56414,'118096','furniture-mobile','block-56412','account\\OrderTracking','',2),(56415,'118097','furniture-mobile','trade_form','BlockBox','',1),(56416,'118098','furniture-mobile','block-56415','Html_box','',6),(56417,'118099','furniture-mobile','block-56415','BlockBox','',7),(56418,'118100','furniture-mobile','block-56417','BlockBox','',1),(56419,'118101','furniture-mobile','block-56418','account\\CustomerAdditionalField','',2),(56420,'118102','furniture-mobile','block-56418','account\\CustomerAdditionalField','',1),(56421,'118103','furniture-mobile','block-56417-2','BlockBox','',1),(56422,'118104','furniture-mobile','block-56421','account\\CustomerAdditionalField','',2),(56423,'118105','furniture-mobile','block-56421','account\\CustomerAdditionalField','',1),(56424,'118106','furniture-mobile','block-56415','BlockBox','',5),(56425,'118107','furniture-mobile','block-56424','BlockBox','',1),(56426,'118108','furniture-mobile','block-56425','account\\CustomerAdditionalField','',1),(56427,'118109','furniture-mobile','block-56425','account\\CustomerAdditionalField','',2),(56428,'118110','furniture-mobile','block-56415','Html_box','',2),(56429,'118111','furniture-mobile','block-56415','BlockBox','',4),(56430,'118112','furniture-mobile','block-56429','BlockBox','',1),(56431,'118113','furniture-mobile','block-56430','account\\AddressesList','',2),(56432,'118114','furniture-mobile','block-56430','BlockBox','',4),(56433,'118115','furniture-mobile','block-56432','BlockBox','',1),(56434,'118116','furniture-mobile','block-56433','account\\CustomerAdditionalField','',3),(56435,'118117','furniture-mobile','block-56433','account\\CustomerAdditionalField','',1),(56436,'118118','furniture-mobile','block-56433','account\\CustomerAdditionalField','',2),(56437,'118119','furniture-mobile','block-56433','account\\CustomerAdditionalField','',4),(56438,'118120','furniture-mobile','block-56432-2','BlockBox','',1),(56439,'118121','furniture-mobile','block-56438','account\\CustomerAdditionalField','',4),(56440,'118122','furniture-mobile','block-56438','account\\CustomerAdditionalField','',1),(56441,'118123','furniture-mobile','block-56438','account\\CustomerAdditionalField','',2),(56442,'118124','furniture-mobile','block-56438','account\\CustomerAdditionalField','',3),(56443,'118125','furniture-mobile','block-56430','BlockBox','',3),(56444,'118126','furniture-mobile','block-56443','account\\CustomerAdditionalField','',1),(56445,'118127','furniture-mobile','block-56430','Html_box','',1),(56446,'118128','furniture-mobile','block-56429-2','BlockBox','',1),(56447,'118129','furniture-mobile','block-56446','account\\AddressesList','',2),(56448,'118130','furniture-mobile','block-56446','Html_box','',1),(56449,'118131','furniture-mobile','block-56446','BlockBox','',4),(56450,'118132','furniture-mobile','block-56449','BlockBox','',1),(56451,'118133','furniture-mobile','block-56450','account\\CustomerAdditionalField','',3),(56452,'118134','furniture-mobile','block-56450','account\\CustomerAdditionalField','',1),(56453,'118135','furniture-mobile','block-56450','account\\CustomerAdditionalField','',2),(56454,'118136','furniture-mobile','block-56449-2','BlockBox','',1),(56455,'118137','furniture-mobile','block-56454','account\\CustomerAdditionalField','',1),(56456,'118138','furniture-mobile','block-56454','account\\CustomerAdditionalField','',3),(56457,'118139','furniture-mobile','block-56454','account\\CustomerAdditionalField','',2),(56458,'118140','furniture-mobile','block-56446','BlockBox','',3),(56459,'118141','furniture-mobile','block-56458','BlockBox','',1),(56460,'118142','furniture-mobile','block-56459','account\\CustomerAdditionalField','',2),(56461,'118143','furniture-mobile','block-56459','account\\CustomerAdditionalField','',1),(56462,'118144','furniture-mobile','block-56458-2','BlockBox','',1),(56463,'118145','furniture-mobile','block-56462','account\\CustomerAdditionalField','',1),(56464,'118146','furniture-mobile','block-56415','Html_box','',1),(56465,'118147','furniture-mobile','block-56415','BlockBox','',9),(56466,'118148','furniture-mobile','block-56465','BlockBox','',1),(56467,'118149','furniture-mobile','block-56466','account\\CustomerAdditionalField','',2),(56468,'118150','furniture-mobile','block-56466','account\\CustomerAdditionalField','',1),(56469,'118151','furniture-mobile','block-56465-2','BlockBox','',1),(56470,'118152','furniture-mobile','block-56469','account\\CustomerAdditionalField','',1),(56471,'118153','furniture-mobile','block-56415','Html_box','',10),(56472,'118154','furniture-mobile','block-56415','Html_box','',8),(56473,'118155','furniture-mobile','block-56415','BlockBox','',11),(56474,'118156','furniture-mobile','block-56473','BlockBox','',1),(56475,'118157','furniture-mobile','block-56474','Html_box','',1),(56476,'118158','furniture-mobile','block-56474','account\\CustomerAdditionalField','',2),(56477,'118159','furniture-mobile','block-56474','account\\CustomerAdditionalField','',4),(56478,'118160','furniture-mobile','block-56474','account\\CustomerAdditionalField','',3),(56479,'118161','furniture-mobile','block-56473-2','BlockBox','',1),(56480,'118162','furniture-mobile','block-56479','Html_box','',1),(56481,'118163','furniture-mobile','block-56479','account\\CustomerAdditionalField','',2),(56482,'118164','furniture-mobile','block-56479','account\\CustomerAdditionalField','',3),(56483,'118165','furniture-mobile','block-56479','account\\CustomerAdditionalField','',4),(56484,'118166','furniture-mobile','block-56415','Html_box','',12),(56485,'118167','furniture-mobile','block-56415','BlockBox','',13),(56486,'118168','furniture-mobile','block-56485','BlockBox','',1),(56487,'118169','furniture-mobile','block-56486','account\\CustomerAdditionalField','',1),(56488,'118170','furniture-mobile','block-56485-2','BlockBox','',1),(56489,'118171','furniture-mobile','block-56488','account\\CustomerAdditionalField','',1),(56490,'118172','furniture-mobile','block-56415','BlockBox','',14),(56491,'118173','furniture-mobile','block-56490','account\\BackButton','',1),(56492,'118174','furniture-mobile','block-56490-2','account\\SaveButton','',1),(56493,'118175','furniture-mobile','block-56490-2','account\\PdfButton','',2),(56494,'118176','furniture-mobile','block-56415','BlockBox','',3),(56495,'118177','furniture-mobile','block-56494','BlockBox','',1),(56496,'118178','furniture-mobile','block-56495','account\\CustomerAdditionalField','',2),(56497,'118179','furniture-mobile','block-56495','account\\CustomerAdditionalField','',1),(56498,'118180','furniture-mobile','trade_form_pdf','BlockBox','',1),(56499,'118181','furniture-mobile','block-56498','BlockBox','',29),(56500,'118182','furniture-mobile','block-56499','Html_box','',2),(56501,'118183','furniture-mobile','block-56498','BlockBox','',28),(56502,'118184','furniture-mobile','block-56501','Html_box','',1),(56503,'118185','furniture-mobile','block-56501-2','account\\CustomerAdditionalField','',1),(56504,'118186','furniture-mobile','block-56501-3','Html_box','',1),(56505,'118187','furniture-mobile','block-56501-4','account\\CustomerAdditionalField','',1),(56506,'118188','furniture-mobile','block-56498','BlockBox','',27),(56507,'118189','furniture-mobile','block-56506','Html_box','',1),(56508,'118190','furniture-mobile','block-56506-2','Html_box','',1),(56509,'118191','furniture-mobile','block-56506-3','Html_box','',1),(56510,'118192','furniture-mobile','block-56506-4','Html_box','',1),(56511,'118193','furniture-mobile','block-56498','BlockBox','',22),(56512,'118194','furniture-mobile','block-56511','Html_box','',1),(56513,'118195','furniture-mobile','block-56511-2','account\\CustomerAdditionalField','',1),(56514,'118196','furniture-mobile','block-56498','BlockBox','',26),(56515,'118197','furniture-mobile','block-56514','Html_box','',1),(56516,'118198','furniture-mobile','block-56498','BlockBox','',24),(56517,'118199','furniture-mobile','block-56516','Html_box','',1),(56518,'118200','furniture-mobile','block-56516-2','account\\CustomerAdditionalField','',1),(56519,'118201','furniture-mobile','block-56498','BlockBox','',25),(56520,'118202','furniture-mobile','block-56519','Html_box','',1),(56521,'118203','furniture-mobile','block-56498','BlockBox','',21),(56522,'118204','furniture-mobile','block-56521','Html_box','',1),(56523,'118205','furniture-mobile','block-56498','BlockBox','',23),(56524,'118206','furniture-mobile','block-56523','Html_box','',1),(56525,'118207','furniture-mobile','block-56523-2','account\\CustomerAdditionalField','',1),(56526,'118208','furniture-mobile','block-56498','BlockBox','',19),(56527,'118209','furniture-mobile','block-56526','Html_box','',1),(56528,'118210','furniture-mobile','block-56526-2','account\\CustomerAdditionalField','',1),(56529,'118211','furniture-mobile','block-56498','BlockBox','',16),(56530,'118212','furniture-mobile','block-56529','Html_box','',1),(56531,'118213','furniture-mobile','block-56529-2','BlockBox','',1),(56532,'118214','furniture-mobile','block-56531','account\\CustomerAdditionalField','',1),(56533,'118215','furniture-mobile','block-56531-2','Html_box','',1),(56534,'118216','furniture-mobile','block-56531-3','account\\CustomerAdditionalField','',1),(56535,'118217','furniture-mobile','block-56529-3','BlockBox','',1),(56536,'118218','furniture-mobile','block-56498','BlockBox','',18),(56537,'118219','furniture-mobile','block-56536','Html_box','',1),(56538,'118220','furniture-mobile','block-56536-2','account\\CustomerAdditionalField','',1),(56539,'118221','furniture-mobile','block-56498','BlockBox','',15),(56540,'118222','furniture-mobile','block-56539','Html_box','',1),(56541,'118223','furniture-mobile','block-56498','BlockBox','',20),(56542,'118224','furniture-mobile','block-56541','Html_box','',1),(56543,'118225','furniture-mobile','block-56541-2','account\\CustomerAdditionalField','',1),(56544,'118226','furniture-mobile','block-56498','BlockBox','',17),(56545,'118227','furniture-mobile','block-56544','Html_box','',1),(56546,'118228','furniture-mobile','block-56498','BlockBox','',10),(56547,'118229','furniture-mobile','block-56546','Html_box','',1),(56548,'118230','furniture-mobile','block-56546-2','account\\CustomerAdditionalField','',1),(56549,'118231','furniture-mobile','block-56498','BlockBox','',14),(56550,'118232','furniture-mobile','block-56549','Html_box','',1),(56551,'118233','furniture-mobile','block-56549-2','account\\CustomerAdditionalField','',1),(56552,'118234','furniture-mobile','block-56498','BlockBox','',6),(56553,'118235','furniture-mobile','block-56552','Html_box','',1),(56554,'118236','furniture-mobile','block-56552-2','account\\CombinedField','',2),(56555,'118237','furniture-mobile','block-56498','BlockBox','',13),(56556,'118238','furniture-mobile','block-56555','Html_box','',1),(56557,'118239','furniture-mobile','block-56555-2','account\\CustomerAdditionalField','',1),(56558,'118240','furniture-mobile','block-56498','BlockBox','',12),(56559,'118241','furniture-mobile','block-56558','Html_box','',1),(56560,'118242','furniture-mobile','block-56558-2','account\\CombinedField','',2),(56561,'118243','furniture-mobile','block-56498','BlockBox','',9),(56562,'118244','furniture-mobile','block-56561','Html_box','',1),(56563,'118245','furniture-mobile','block-56561-2','account\\CustomerAdditionalField','',1),(56564,'118246','furniture-mobile','block-56498','BlockBox','',11),(56565,'118247','furniture-mobile','block-56564','Html_box','',1),(56566,'118248','furniture-mobile','block-56564-2','account\\CombinedField','',1),(56567,'118249','furniture-mobile','block-56498','BlockBox','',8),(56568,'118250','furniture-mobile','block-56567','Html_box','',1),(56569,'118251','furniture-mobile','block-56567-2','BlockBox','',1),(56570,'118252','furniture-mobile','block-56569','account\\CustomerAdditionalField','',1),(56571,'118253','furniture-mobile','block-56569-2','BlockBox','',1),(56572,'118254','furniture-mobile','block-56571','Html_box','',2),(56573,'118255','furniture-mobile','block-56571-2','account\\CustomerAdditionalField','',1),(56574,'118256','furniture-mobile','block-56498','BlockBox','',3),(56575,'118257','furniture-mobile','block-56574','Html_box','',1),(56576,'118258','furniture-mobile','block-56498','BlockBox','',4),(56577,'118259','furniture-mobile','block-56576-2','BlockBox','',1),(56578,'118260','furniture-mobile','block-56577','BlockBox','',1),(56579,'118261','furniture-mobile','block-56578','Html_box','',2),(56580,'118262','furniture-mobile','block-56578-2','account\\CustomerAdditionalField','',1),(56581,'118263','furniture-mobile','block-56577-2','BlockBox','',1),(56582,'118264','furniture-mobile','block-56581','Html_box','',1),(56583,'118265','furniture-mobile','block-56581-2','account\\CustomerAdditionalField','',1),(56584,'118266','furniture-mobile','block-56498','BlockBox','',1),(56585,'118267','furniture-mobile','block-56584','Contacts','',1),(56586,'118268','furniture-mobile','block-56584-2','Html_box','',1),(56587,'118269','furniture-mobile','block-56498','BlockBox','',2),(56588,'118270','furniture-mobile','block-56587','Contacts','',1),(56589,'118271','furniture-mobile','block-56498','BlockBox','',5),(56590,'118272','furniture-mobile','block-56589','Html_box','',1),(56591,'118273','furniture-mobile','block-56589-2','account\\CustomerAdditionalField','',1),(56592,'118274','furniture-mobile','block-56498','BlockBox','',7),(56593,'118275','furniture-mobile','block-56592','Html_box','',1),(56594,'118276','furniture-mobile','block-56592-2','account\\CustomerAdditionalField','',1),(56597,'118279','furniture-mobile','block-56596-1','product\\Description','',2),(56598,'118280','furniture-mobile','block-56596-1','product\\Properties','',1),(56636,'118318','furniture-mobile','unsubscribed','BlockBox','',1),(56637,'118319','furniture-mobile','block-56636','Html_box','',1),(56638,'118320','furniture-mobile','update-and-pay-order_confirmation','BlockBox','',1),(56639,'118321','furniture-mobile','block-56638','BlockBox','',3),(56640,'118322','furniture-mobile','block-56639','BlockBox','',1),(56641,'118323','furniture-mobile','block-56640','BlockBox','',1),(56642,'118324','furniture-mobile','block-56641','BlockBox','',1),(56643,'118325','furniture-mobile','block-56642','order\\ShippingMethod','',5),(56644,'118326','furniture-mobile','block-56642','Html_box','',2),(56645,'118327','furniture-mobile','block-56642','Html_box','',4),(56646,'118328','furniture-mobile','block-56642','Html_box','',1),(56647,'118329','furniture-mobile','block-56642','order\\Telephone','',8),(56648,'118330','furniture-mobile','block-56642','Html_box','',6),(56649,'118331','furniture-mobile','block-56642','order\\Name','',7),(56650,'118332','furniture-mobile','block-56642','order\\Email','',9),(56651,'118333','furniture-mobile','block-56642','order\\DeliveryAddress','',3),(56652,'118334','furniture-mobile','block-56641-2','BlockBox','',1),(56653,'118335','furniture-mobile','block-56652','order\\BillingAddress','',3),(56654,'118336','furniture-mobile','block-56652','UpdateAndPay\\PayConfirm','',5),(56655,'118337','furniture-mobile','block-56652','Html_box','',1),(56656,'118338','furniture-mobile','block-56652','Html_box','',2),(56657,'118339','furniture-mobile','block-56652','Html_box','',4),(56658,'118340','furniture-mobile','block-56640','BlockBox','',3),(56659,'118341','furniture-mobile','block-56658','order\\Products','',2),(56660,'118342','furniture-mobile','block-56658','Html_box','',1),(56661,'118343','furniture-mobile','block-56639-2','BlockBox','',1),(56662,'118344','furniture-mobile','block-56661','Html_box','',1),(56663,'118345','furniture-mobile','block-56661','checkout\\ContinueBtn','',3),(56664,'118346','furniture-mobile','block-56661','order\\Totals','',2),(56665,'118347','furniture-mobile','block-56638','account\\OrderHeading','',1),(56666,'118348','furniture-mobile','update-and-pay-order_pay','BlockBox','',1),(56667,'118349','furniture-mobile','block-56666','BlockBox','',3),(56668,'118350','furniture-mobile','block-56667','BlockBox','',1),(56669,'118351','furniture-mobile','block-56668','BlockBox','',1),(56670,'118352','furniture-mobile','block-56669','BlockBox','',1),(56671,'118353','furniture-mobile','block-56670','order\\DeliveryAddress','',4),(56672,'118354','furniture-mobile','block-56670','order\\Email','',10),(56673,'118355','furniture-mobile','block-56670','order\\Name','',8),(56674,'118356','furniture-mobile','block-56670','Html_box','',7),(56675,'118357','furniture-mobile','block-56670','order\\Telephone','',9),(56676,'118358','furniture-mobile','block-56670','Html_box','',5),(56677,'118359','furniture-mobile','block-56670','order\\ShippingMethod','',6),(56678,'118360','furniture-mobile','block-56670','Html_box','',2),(56679,'118361','furniture-mobile','block-56670','Html_box','',3),(56680,'1639647774.7838','furniture-mobile','block-56670','DelayedDespatch\\OrderPay','',1),(56681,'118362','furniture-mobile','block-56669-2','BlockBox','',1),(56682,'118363','furniture-mobile','block-56681','Html_box','',1),(56683,'118364','furniture-mobile','block-56681','Html_box','',2),(56684,'118365','furniture-mobile','block-56681','Html_box','',4),(56685,'118366','furniture-mobile','block-56681','order\\BillingAddress','',3),(56686,'118367','furniture-mobile','block-56681','UpdateAndPay\\PayForm','',5),(56687,'118368','furniture-mobile','block-56668','BlockBox','',3),(56688,'118369','furniture-mobile','block-56687','Html_box','',1),(56689,'118370','furniture-mobile','block-56687','order\\Products','',2),(56690,'118371','furniture-mobile','block-56667-2','BlockBox','',1),(56691,'118372','furniture-mobile','block-56690','order\\Totals','',2),(56692,'118373','furniture-mobile','block-56690','checkout\\ContinueBtn','',3),(56693,'118374','furniture-mobile','block-56690','Html_box','',1),(56694,'118375','furniture-mobile','block-56666','account\\OrderHeading','',1),(56695,'118392','furniture-mobile','wedding_manage','WeddingRegistry\\widgets\\ManageBanner','',1),(56696,'1639406339.5675','furniture-mobile','wedding_manage','BlockBox','',3),(56697,'118381','furniture-mobile','block-56696','WeddingRegistry\\widgets\\Products','',3),(56698,'118382','furniture-mobile','block-56696','WeddingRegistry\\widgets\\AddItemsLink','',2),(56699,'118383','furniture-mobile','block-56696','BlockBox','',1),(56700,'118384','furniture-mobile','block-56699','WeddingRegistry\\widgets\\Photos','',1),(56701,'118385','furniture-mobile','block-56699-2','WeddingRegistry\\widgets\\ManageDate','',2),(56702,'118386','furniture-mobile','block-56699-2','WeddingRegistry\\widgets\\ManageNames','',1),(56703,'118387','furniture-mobile','block-56699-2','BlockBox','',3),(56704,'118388','furniture-mobile','block-56703','WeddingRegistry\\widgets\\EditLink','',1),(56705,'118389','furniture-mobile','block-56703','WeddingRegistry\\widgets\\ShareLink','',3),(56706,'118390','furniture-mobile','block-56703','WeddingRegistry\\widgets\\DeleteLink','',2),(56707,'118391','furniture-mobile','block-56699-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(56711,'118396','furniture-mobile','wedding_search','BlockBox','',1),(56712,'118397','furniture-mobile','block-56711','BlockBox','',1),(56713,'118398','furniture-mobile','block-56712','BlockBox','',1),(56714,'118399','furniture-mobile','block-56713','WeddingRegistry\\widgets\\SearchForm','',2),(56715,'118400','furniture-mobile','block-56713','Html_box','',1),(56716,'118401','furniture-mobile','block-56711','WeddingRegistry\\widgets\\SearchList','',2),(56717,'118402','furniture-mobile','block-56711','WeddingRegistry\\widgets\\SearchPaging','',3),(56718,'118403','furniture-mobile','wedding_share','BlockBox','',2),(56719,'118404','furniture-mobile','block-56718','BlockBox','',4),(56720,'1639410195.9973','furniture-mobile','block-56719','Html_box','',0),(56721,'118405','furniture-mobile','block-56719-2','Html_box','',1),(56722,'118406','furniture-mobile','block-56719-2','WeddingRegistry\\widgets\\InviteList','',4),(56723,'118407','furniture-mobile','block-56719-2','Html_box','',3),(56724,'118408','furniture-mobile','block-56719-2','WeddingRegistry\\widgets\\ShareUrl','',2),(56725,'118410','furniture-mobile','block-56718','WeddingRegistry\\widgets\\Photos','',2),(56726,'118411','furniture-mobile','block-56718','Html_box','',3),(56727,'118409','furniture-mobile','wedding_share','WeddingRegistry\\widgets\\ManageBanner','',1),(56728,'1639405874.8749','furniture-mobile','wedding_success','BlockBox','',0),(56729,'118412','furniture-mobile','block-56728','WeddingRegistry\\widgets\\BackButton','',2),(56730,'118413','furniture-mobile','block-56728','Html_box','',1),(56731,'1639393156.401','furniture-mobile','wedding_update','BlockBox','',0),(56732,'118414','furniture-mobile','block-56731','BlockBox','',2),(56733,'118415','furniture-mobile','block-56732','BlockBox','',1),(56734,'118416','furniture-mobile','block-56733','Html_box','',5),(56735,'118417','furniture-mobile','block-56733','WeddingRegistry\\widgets\\ShareRegistry','',6),(56736,'118418','furniture-mobile','block-56733','Html_box','',3),(56737,'118419','furniture-mobile','block-56733','Html_box','',1),(56738,'118420','furniture-mobile','block-56733','WeddingRegistry\\widgets\\Names','',2),(56739,'118421','furniture-mobile','block-56733','WeddingRegistry\\widgets\\Details','',4),(56740,'118422','furniture-mobile','block-56732-2','BlockBox','',1),(56741,'118423','furniture-mobile','block-56740','WeddingRegistry\\widgets\\InformationText','',4),(56742,'118424','furniture-mobile','block-56740','Html_box','',5),(56743,'118425','furniture-mobile','block-56740','WeddingRegistry\\widgets\\ShippingDetails','',2),(56744,'118426','furniture-mobile','block-56740','WeddingRegistry\\widgets\\Photos','',6),(56745,'118427','furniture-mobile','block-56740','Html_box','',1),(56746,'118428','furniture-mobile','block-56740','Html_box','',3),(56747,'118429','furniture-mobile','block-56731','BlockBox','',3),(56748,'118430','furniture-mobile','block-56747','WeddingRegistry\\widgets\\BackButton','',1),(56749,'118431','furniture-mobile','block-56747-2','WeddingRegistry\\widgets\\SaveButton','',1),(56750,'118432','furniture-mobile','block-56731','Html_box','',1),(56751,'118439','furniture-mobile','wedding_view','WeddingRegistry\\widgets\\ManageBanner','',1),(56752,'1639500465.781','furniture-mobile','wedding_view','BlockBox','',2),(56753,'118433','furniture-mobile','block-56752','BlockBox','',1),(56754,'118434','furniture-mobile','block-56753','WeddingRegistry\\widgets\\Photos','',1),(56755,'118435','furniture-mobile','block-56753-2','WeddingRegistry\\widgets\\ManageDate','',2),(56756,'118436','furniture-mobile','block-56753-2','WeddingRegistry\\widgets\\ManageNames','',1),(56757,'118437','furniture-mobile','block-56753-3','WeddingRegistry\\widgets\\SearchRegistryButton','',1),(56758,'118438','furniture-mobile','block-56752','WeddingRegistry\\widgets\\Products','',2),(56759,'118440','furniture-mobile','wishlist','BlockBox','',1),(56760,'118441','furniture-mobile','block-56759','BlockBox','',1),(56761,'118442','furniture-mobile','block-56760','WidgetsAria','',1),(56762,'116126','furniture-mobile','account-menu','BlockBox','',1),(56763,'116127','furniture-mobile','block-56762','BlockBox','account-side',1),(56764,'116128','furniture-mobile','block-56763','Html_box','',16),(56765,'116129','furniture-mobile','block-56763','account\\AccountLink','',17),(56766,'116130','furniture-mobile','block-56763','account\\AccountLink','',18),(56767,'116131','furniture-mobile','block-56763','account\\AccountLink','',1),(56768,'116132','furniture-mobile','block-56763','Html_box','',2),(56769,'116133','furniture-mobile','block-56763','account\\AccountLink','',4),(56770,'116134','furniture-mobile','block-56763','account\\AccountLink','',7),(56771,'116135','furniture-mobile','block-56763','account\\AccountLink','',11),(56772,'116136','furniture-mobile','block-56763','Html_box','',6),(56773,'116137','furniture-mobile','block-56763','account\\AccountLink','',3),(56774,'116138','furniture-mobile','block-56763','account\\AccountLink','',14),(56775,'116139','furniture-mobile','block-56763','account\\AccountLink','',8),(56776,'116140','furniture-mobile','block-56763','account\\AccountLink','',5),(56777,'116141','furniture-mobile','block-56763','account\\AccountLink','',9),(56778,'116142','furniture-mobile','block-56763','account\\AccountLink','',12),(56779,'116143','furniture-mobile','block-56763','Html_box','',10),(56780,'116144','furniture-mobile','block-56763','account\\AccountLink','',15),(56781,'118443','furniture-mobile','block-56760-2','account\\Wishlist','',2),(56782,'118444','furniture-mobile','block-56760-2','Html_box','',1),(56783,'118445','furniture-mobile','wishlist-cart','BlockBox','',1),(56784,'118446','furniture-mobile','block-56783','cart\\CartTabs','',1),(56785,'118447','furniture-mobile','block-56784','account\\Wishlist','',1),(56789,'1694453786.292251','watch-mobile','block-3356','checkout\\ShippingAddress','',2),(108861,'117044','splash','email','email\\BlockBox','',1),(108862,'117045','splash','block-108861','email\\BlockBox','',1),(108863,'117046','splash','block-108862','Copyright','',4),(108864,'117047','splash','block-108862','email\\Content','',3),(108865,'117048','splash','block-108862','email\\BlockBox','',2),(108866,'117049','splash','block-108865','email\\Title','',1),(108867,'117050','splash','block-108865-2','email\\Date','',1),(108868,'117051','splash','block-108862','Logo','',1),(108869,'1661353033.436213','splash','info','BlockBox','',1),(108870,'1661353033.440468','splash','block-108869','info\\Title','',0),(108871,'1661353033.44440','splash','block-108869','info\\Content','',0),(108872,'1661353032.24842','splash','invoice','invoice\\Container','',1),(108873,'1661353032.270236','splash','block-108872','BlockBox','',4),(108874,'1661353032.296769','splash','block-108873','BlockBox','',8),(108875,'1661353032.306393','splash','block-108874','BlockBox','',1),(108876,'1661353032.318453','splash','block-108875','invoice\\ShippingMethod','',2),(108877,'1661353032.323757','splash','block-108875','Html_box','',0),(108878,'1661353032.337230','splash','block-108874-2','BlockBox','',1),(108879,'1661353032.346115','splash','block-108878','invoice\\ShippingMethod','',2),(108880,'1661353032.34962','splash','block-108878','Html_box','',0),(108881,'1661353032.356416','splash','block-108873','BlockBox','',7),(108882,'1661353032.363923','splash','block-108881','BlockBox','',2),(108883,'1661353032.374368','splash','block-108882','invoice\\BillingAddress','',3),(108884,'1661353032.380968','splash','block-108882','Html_box','',0),(108885,'1661353032.389876','splash','block-108881','GiftWrapMessage\\ShowInfo','',1),(108886,'1661353032.39417','splash','block-108881-2','BlockBox','',1),(108887,'1661353032.40481','splash','block-108886','invoice\\CustomerName','',2),(108888,'1661353032.410660','splash','block-108886','invoice\\CustomerPhone','',4),(108889,'1661353032.416141','splash','block-108886','invoice\\CustomerEmail','',7),(108890,'1661353032.4242','splash','block-108886','Html_box','',1),(108891,'1661353032.430173','splash','block-108886','Html_box','',3),(108892,'1661353032.440350','splash','block-108886','Html_box','',5),(108893,'1661353032.449537','splash','block-108873-2','invoice\\PaymentMethod','',6),(108894,'1661353032.456412','splash','block-108873-2','invoice\\OrderId','',1),(108895,'1661353032.464888','splash','block-108873-2','invoice\\PaymentDate','',3),(108896,'1661353032.471888','splash','block-108873-2','invoice\\OrderBarcode','',7),(108897,'1661353032.47812','splash','block-108873-2','Html_box','',2),(108898,'1661353032.486692','splash','block-108873-2','Html_box','',5),(108899,'1661353032.495713','splash','block-108872','BlockBox','',8),(108900,'1661353032.50157','splash','block-108899','invoice\\StoreAddress','',8),(108901,'1661353032.50664','splash','block-108899','Html_box','',0),(108902,'1661353032.514429','splash','block-108899-2','Html_box','',1),(108903,'1661353032.527783','splash','block-108899-3','BlockBox','',4),(108904,'1661353032.533932','splash','block-108903','Html_box','',0),(108905,'1661353032.54216','splash','block-108903-2','invoice\\StoreEmail','',1),(108906,'1661353032.549414','splash','block-108899-3','BlockBox','',3),(108907,'1661353032.556356','splash','block-108906','Html_box','',0),(108908,'1661353032.56487','splash','block-108906-2','invoice\\StorePhone','',1),(108909,'1661353032.572983','splash','block-108899-3','Html_box','',1),(108910,'1661353032.588254','splash','block-108872','invoice\\Products','',5),(108911,'1661353032.596366','splash','block-108872','BlockBox','',7),(108912,'1661353032.616225','splash','block-108911','BlockBox','',1),(108913,'1661353032.624746','splash','block-108912','invoice\\ShippingAddress','',2),(108914,'1661353032.6344','splash','block-108912','Html_box','',0),(108915,'1661353032.645291','splash','block-108911-2','BlockBox','',1),(108916,'1661353032.656840','splash','block-108915','invoice\\Totals','',1),(108917,'1661353032.665237','splash','block-108872','BlockBox','',2),(108918,'1661353032.672459','splash','block-108917','Logo','',0),(108919,'1661353032.693794','splash','block-108917-2','BlockBox','',4),(108920,'1661353032.699666','splash','block-108919','Html_box','',0),(108921,'1661353032.705757','splash','block-108919-2','invoice\\StoreSite','',1),(108922,'1661353032.712713','splash','block-108917-2','BlockBox','',3),(108923,'1661353032.717779','splash','block-108922','Html_box','',0),(108924,'1661353032.724733','splash','block-108922-2','invoice\\StoreEmail','',1),(108925,'1661353032.729329','splash','block-108917-2','BlockBox','',1),(108926,'1661353032.73418','splash','block-108925','invoice\\StoreAddress','',2),(108927,'1661353032.745349','splash','block-108917-2','BlockBox','',2),(108928,'1661353032.752179','splash','block-108927','Html_box','',0),(108929,'1661353032.759958','splash','block-108927-2','invoice\\StorePhone','',1),(108930,'1661353032.765438','splash','block-108872','invoice\\StructuredProducts','',6),(108931,'1640168549.8258','splash','main','BlockBox','',0),(108932,'1640168603.5833','splash','block-108931','BlockBox','',1),(108933,'1640168618.7708','splash','block-108932','Image','',0),(108934,'1640181569.3506','splash','block-108931','BlockBox','',2),(108935,'1640168851.5282','splash','block-108934','BlockBox','',1),(108936,'1640169872.1589','splash','block-108935','Image','',1),(108937,'1640276640.1123','splash','block-108935-2','Text','',1),(108938,'1640170154.7803','splash','block-108935-3','Image','',1),(108939,'1645204049.8114','splash','block-108931','BlockBox','',3),(108940,'1640170023.0001','splash','block-108939','Image','',1),(108941,'1640170023.1491','splash','block-108939-2','Image','',2),(108942,'1640170023','splash','block-108939-3','Image','',1),(108943,'1661353032.958564','splash','packingslip','invoice\\Container','',1),(108944,'1661353032.968771','splash','block-108943','BlockBox','',2),(108945,'1661353032.975845','splash','block-108944','Logo','',1),(108946,'1661353032.991276','splash','block-108944-2','BlockBox','',3),(108947,'1661353032.99777','splash','block-108946','Html_box','',0),(108948,'1661353033.00539','splash','block-108946-2','invoice\\StoreEmail','',1),(108949,'1661353033.010798','splash','block-108944-2','BlockBox','',2),(108950,'1661353033.017634','splash','block-108949','Html_box','',0),(108951,'1661353033.027946','splash','block-108949-2','invoice\\StorePhone','',1),(108952,'1661353033.033296','splash','block-108944-2','BlockBox','',1),(108953,'1661353033.03754','splash','block-108952','invoice\\StoreAddress','',1),(108954,'1661353033.046342','splash','block-108944-2','BlockBox','',4),(108955,'1661353033.052669','splash','block-108954','Html_box','',0),(108956,'1661353033.060721','splash','block-108954-2','invoice\\StoreSite','',1),(108957,'1661353033.065977','splash','block-108943','packingslip\\Products','',5),(108958,'1661353033.073678','splash','block-108943','BlockBox','',6),(108959,'1661353033.081543','splash','block-108958','invoice\\StoreAddress','',2),(108960,'1661353033.085331','splash','block-108958','Html_box','',0),(108961,'1661353033.093224','splash','block-108943','BlockBox','',3),(108962,'1661353033.108992','splash','block-108961','BlockBox','',2),(108963,'1661353033.11758','splash','block-108962','BlockBox','',1),(108964,'1661353033.129825','splash','block-108963','invoice\\ShippingAddress','',2),(108965,'1661353033.136397','splash','block-108963','Html_box','',0),(108966,'1661353033.145276','splash','block-108962-2','BlockBox','',1),(108967,'1661353033.15637','splash','block-108966','invoice\\CustomerName','',2),(108968,'1661353033.16030','splash','block-108966','invoice\\CustomerEmail','',6),(108969,'1661353033.16397','splash','block-108966','invoice\\CustomerPhone','',4),(108970,'1661353033.168995','splash','block-108966','Html_box','',1),(108971,'1661353033.176872','splash','block-108966','Html_box','',3),(108972,'1661353033.185817','splash','block-108966','Html_box','',5),(108973,'1661353033.197558','splash','block-108961','BlockBox','',3),(108974,'1661353033.208111','splash','block-108973','BlockBox','',1),(108975,'1661353033.219882','splash','block-108974','invoice\\ShippingMethod','',2),(108976,'1661353033.22360','splash','block-108974','Html_box','',0),(108977,'1661353033.2314','splash','block-108973-2','BlockBox','',1),(108978,'1661353033.240139','splash','block-108977','invoice\\ShippingMethod','',2),(108979,'1661353033.243986','splash','block-108977','Html_box','',0),(108980,'1661353033.250617','splash','block-108961-2','invoice\\AddressQrcode','',1),(108981,'1661353033.258425','splash','block-108943','Neighbour\\PackingSlipInfo','',4),(108982,'74683','splash','pdf','invoice\\Container','',1),(108983,'74684','splash','block-108982','BlockBox','',1),(108984,'74685','splash','block-108983','BlockBox','',1),(108985,'74686','splash','block-108984','BlockBox','',1),(108986,'74687','splash','block-108985','pdf\\ProductElement','',1),(108987,'74688','splash','block-108984','BlockBox','',2),(108988,'74689','splash','block-108987','pdf\\ProductElement','',1),(108989,'74690','splash','block-108987-2','pdf\\ProductElement','',2),(108990,'74691','splash','block-108987-2','pdf\\ProductElement','',1),(108991,'74692','splash','block-108983-2','BlockBox','',1),(108992,'74693','splash','block-108991','BlockBox','',2),(108993,'74694','splash','block-108992','pdf\\ProductElement','',1),(108994,'74695','splash','block-108992-2','pdf\\ProductElement','',2),(108995,'74696','splash','block-108992-2','pdf\\ProductElement','',1),(108996,'74697','splash','block-108991','BlockBox','',1),(108997,'74698','splash','block-108996','pdf\\ProductElement','',1),(108998,'74700','splash','pdf_category','pdf\\CategoryImage','',1),(108999,'74699','splash','pdf_category','pdf\\CategoryName','',2),(109000,'74701','splash','pdf_cover','invoice\\Container','',1),(109001,'74702','splash','block-109000','Logo','',1),(109002,'74703','splash','block-109000','Text','',3),(109003,'74704','splash','pdf_footer','BlockBox','',1),(109004,'74705','splash','block-109003-2','pdf\\PageNumber','',1),(109005,'74706','splash','pdf_header','pdf\\CategoryName','',1),(109007,'116005','furniture','404','Html_box','',1),(109240,'117906.000001','furniture','b2b','BlockBox','listing-item',1),(109241,'117907.000001','furniture','block-109240','BlockBox','',2),(109242,'117908.000001','furniture','block-109241','BlockBox','',2),(109243,'117909.000001','furniture','block-109242','productListing\\bonusPoints','',2),(109244,'117910.000001','furniture','block-109242','productListing\\image','',1),(109245,'117914.000001','furniture','block-109242-2','productListing\\name','',1),(109246,'117915.000001','furniture','block-109242-2','productListing\\description','',2),(109247,'117916.000001','furniture','block-109242-2','productListing\\model','',4),(109248,'117917.000001','furniture','block-109242-2','productListing\\attributes','',5),(109249,'120922.000001','furniture','block-109242-2','productListing\\properties','',3),(109250,'117918.000001','furniture','block-109241-2','BlockBox','',1),(109251,'117911.000001','furniture','block-109250','BlockBox','',3),(109252,'117912.000001','furniture','block-109251','productListing\\rating','',1),(109253,'117913.000001','furniture','block-109251','productListing\\ratingCounts','',2),(109254,'117919.000001','furniture','block-109250','productListing\\qtyInput','',4),(109255,'117920.000001','furniture','block-109250','productListing\\price','',2),(109256,'117922.000001','furniture','block-109250','productListing\\buyButton','',5),(109257,'117924.000001','furniture','block-109250','productListing\\stock','',1),(109258,'120924.000001','furniture','block-109250','BlockBox','',8),(109259,'120925.000001','furniture','block-109258','productListing\\compare','',3),(109260,'120926.000001','furniture','block-109258','productListing\\personalCatalog','',2),(109261,'120927.000001','furniture','block-109258','productListing\\viewButton','',1),(109262,'116176','furniture','batch','BlockBox','',1),(109263,'116177','furniture','block-109262','productListing\\attributes','',5),(109264,'116178','furniture','block-109262','productListing\\price','',6),(109265,'116179','furniture','block-109262','productListing\\name','',4),(109266,'116180','furniture','block-109262','productListing\\image','',2),(109267,'116181','furniture','block-109262','batchSelect','',1),(109268,'116182','furniture','batch_selected','BlockBox','',1),(109269,'116183','furniture','block-109268','BlockBox','',13),(109270,'116184','furniture','block-109269','productListing\\image','',1),(109271,'116185','furniture','block-109269-2','batchRemove','',1),(109272,'116186','furniture','block-109269-2','productListing\\price','',3),(109273,'116187','furniture','block-109269-2','productListing\\name','',2),(109274,'116188','furniture','bbbbb','BlockBox','',1),(109275,'116189','furniture','block-109274','BlockBox','',2),(109276,'116190','furniture','block-109275','Filters','',1),(109277,'116191','furniture','block-109275-2','BlockBox','',6),(109278,'116192','furniture','block-109277','catalog\\CountsItems','',1),(109279,'116193','furniture','block-109277-2','catalog\\Paging','',1),(109280,'116194','furniture','block-109275-2','catalog\\Image','',1),(109281,'116195','furniture','block-109275-2','Listing','',5),(109282,'116196','furniture','block-109275-2','catalog\\ImageMapCategory','',3),(109283,'116197','furniture','block-109275-2','BlockBox','',4),(109284,'116198','furniture','block-109283','catalog\\ListingLook','',1),(109285,'116199','furniture','block-109283','catalog\\CompareButton','',2),(109286,'116200','furniture','block-109283','catalog\\ItemsOnPage','',4),(109287,'116201','furniture','block-109283','catalog\\Sorting','',3),(109288,'116202','furniture','block-109275-2','Categories','',2),(109289,'116203','furniture','block-109274','catalog\\Title','',1),(109290,'1683103176.926637','furniture','cart','BlockBox','',1),(109291,'1683103176.947325','furniture','block-109290','BlockBox','',3),(109292,'1683103176.971768','furniture','block-109291','BlockBox','cart-content',1),(109293,'1683103176.974446','furniture','block-109292','cart\\Products','',4),(109294,'1683103176.975161','furniture','block-109292','BlockBox','',3),(109295,'1683103176.976938','furniture','block-109294','MultiCart\\CartSwitcher','',1),(109296,'1683103176.977748','furniture','block-109294','MultiCart\\SaveCart','',2),(109297,'1683103176.9792','furniture','block-109294-2','MultiCart\\Actions','',1),(109298,'1683103176.9841','furniture','block-109292','BlockBox','',5),(109299,'1683103176.98248','furniture','block-109298','cart\\CreditAmount','',1),(109300,'1683103176.982975','furniture','block-109298-2','cart\\BonusPoints','',3),(109301,'1683103176.983866','furniture','block-109298-3','cart\\FreeDelivery','',2),(109302,'1683103176.985151','furniture','block-109292','Html_box','',2),(109303,'1683103176.987818','furniture','block-109291','BlockBox','',3),(109304,'1683103176.989631','furniture','block-109303','cart\\GiveAway','',2),(109305,'1683103176.99020','furniture','block-109303','Html_box','',1),(109306,'1683103176.992136','furniture','block-109291','BlockBox','',5),(109307,'1683103176.99416','furniture','block-109306','Html_box','',1),(109308,'1683103176.995796','furniture','block-109306','cart\\ShippingEstimator','',2),(109309,'1683103176.996373','furniture','block-109291','cart\\DependedProducts','8',2),(109310,'1683103176.999540','furniture','block-109291-2','BlockBox','cart-side',1),(109311,'1683103177.002177','furniture','block-109310','BlockBox','',2),(109312,'1683103177.003296','furniture','block-109311','cart\\DiscountCoupon','',2),(109313,'1683103177.016825','furniture','block-109311','cart\\CheckoutBtn','',4),(109314,'1683103177.018382','furniture','block-109311','cart\\OrderTotal','',1),(109315,'1683103177.018993','furniture','block-109311','cart\\OrderTotal','',3),(109316,'1683103177.019577','furniture','block-109310','Html_box','',1),(109327,'116272','furniture','categories','BlockBox','catalog-content',1),(109328,'116273','furniture','block-109327','BlockBox','',2),(109329,'116274','furniture','block-109328','Filters','',3),(109330,'1639749663.0229','furniture','block-109328','ShowInactive\\ShowInactive','',1),(109331,'116275','furniture','block-109328-2','Listing','',8),(109332,'116276','furniture','block-109328-2','catalog\\Image','',3),(109333,'116277','furniture','block-109328-2','BlockBox','',9),(109334,'116278','furniture','block-109333','catalog\\CountsItems','',1),(109335,'116279','furniture','block-109333-2','catalog\\Paging','',1),(109336,'116280','furniture','block-109328-2','catalog\\ImageMapCategory','',6),(109337,'116281','furniture','block-109328-2','Categories','',4),(109338,'116282','furniture','block-109328-2','BlockBox','catalog-features',7),(109339,'116283','furniture','block-109338','catalog\\ListingLook','',1),(109340,'116284','furniture','block-109338','catalog\\CompareButton','',2),(109341,'116285','furniture','block-109338','catalog\\ItemsOnPage','',4),(109342,'116286','furniture','block-109338','catalog\\Sorting','',3),(109343,'116287','furniture','block-109327','catalog\\Title','',1),(109344,'116288','furniture','category','Categories','',1),(109345,'116289','furniture','category','Listing','',4),(109346,'116290','furniture','category','ListingFunctionality','',2),(109347,'116291','furniture','category','PagingBar','',3),(109348,'116292','furniture','category','PagingBar','',5),(109349,'116293','furniture','category_2','BlockBox','',1),(109350,'116294','furniture','block-109349','catalog\\Title','',1),(109351,'116295','furniture','block-109349','BlockBox','',2),(109352,'116296','furniture','block-109351','Filters','',1),(109353,'116297','furniture','block-109351-2','catalog\\Image','',1),(109354,'116298','furniture','block-109351-2','Listing','',5),(109355,'116299','furniture','block-109351-2','BlockBox','',4),(109356,'116300','furniture','block-109355','catalog\\Sorting','',3),(109357,'116301','furniture','block-109355','catalog\\ItemsOnPage','',4),(109358,'116302','furniture','block-109355','catalog\\CompareButton','',2),(109359,'116303','furniture','block-109355','catalog\\ListingLook','',1),(109360,'116304','furniture','block-109351-2','catalog\\ImageMapCategory','',3),(109361,'116305','furniture','block-109351-2','Categories','',2),(109362,'116306','furniture','block-109351-2','BlockBox','',6),(109363,'116307','furniture','block-109362','catalog\\CountsItems','',1),(109364,'116308','furniture','block-109362-2','catalog\\Paging','',1),(109365,'116309','furniture','category_no_filters','BlockBox','catalog-content',1),(109366,'116310','furniture','block-109365','catalog\\Title','',1),(109367,'116311','furniture','block-109365','Categories','',3),(109368,'116312','furniture','block-109365','BlockBox','catalog-features',4),(109369,'116313','furniture','block-109368','catalog\\ItemsOnPage','',4),(109370,'116314','furniture','block-109368','catalog\\Sorting','',3),(109371,'116315','furniture','block-109368','catalog\\CompareButton','',2),(109372,'116316','furniture','block-109368','catalog\\ListingLook','',1),(109373,'116317','furniture','block-109368','HeaderStock','',5),(109374,'116318','furniture','block-109365','BlockBox','',6),(109375,'116319','furniture','block-109374','catalog\\CountsItems','',1),(109376,'116320','furniture','block-109374-2','catalog\\Paging','',1),(109377,'116321','furniture','block-109365','Listing','',5),(109378,'116322','furniture','block-109365','catalog\\Image','',2),(109379,'116323','furniture','block-109365','catalog\\B2bAddButton','',7),(109380,'1693847444.869439','furniture','checkout','BlockBox','',1),(109381,'1693847444.885847','furniture','block-109380','BlockBox','',2),(109382,'1693847444.888529','furniture','block-109381','BlockBox','',2),(109383,'1693847444.8951','furniture','block-109382','BlockBox','checkout-comments',5),(109384,'1693847444.891978','furniture','block-109383','checkout\\Comments','',2),(109385,'1693847444.893451','furniture','block-109383','Html_box','',1),(109386,'1693847444.898927','furniture','block-109382','BlockBox','checkout-discount',4),(109387,'1693847444.90129','furniture','block-109386','Html_box','',1),(109388,'1693847444.902745','furniture','block-109386','BlockBox','',2),(109389,'1693847444.904471','furniture','block-109388','CouponsAndVauchers\\Checkout','',1),(109390,'1693847444.906639','furniture','block-109388-2','checkout\\CreditAmount','',1),(109391,'1693847444.908631','furniture','block-109388-2','checkout\\BonusPoints','',2),(109392,'1693847444.910474','furniture','block-109382','BlockBox','checkout-shipping',2),(109393,'1693847444.912443','furniture','block-109392','BlockBox','',3),(109394,'1693847444.914967','furniture','block-109393','checkout\\ShippingChoice','',1),(109395,'1693847444.921382','furniture','block-109392','Neighbour\\Checkout','',5),(109396,'1693847444.923161','furniture','block-109392','BlockBox','',4),(109397,'1693847444.924488','furniture','block-109396','BlockBox','',1),(109398,'1693847444.926170','furniture','block-109397','checkout\\ShippingAddress','',2),(109399,'1693847444.928743','furniture','block-109397','Html_box','',3),(109400,'1693847444.930224','furniture','block-109397','checkout\\ContactInformation','',4),(109401,'1693847444.93149','furniture','block-109397','UploadCustomerId\\UploadCustomerIdForm','',5),(109402,'1693847444.934659','furniture','block-109396-2','BlockBox','',1),(109403,'1693847444.936512','furniture','block-109402','checkout\\Shipping','',2),(109404,'1693847444.9487','furniture','block-109402','DelayedDespatch\\Checkout','',4),(109405,'1693847444.942192','furniture','block-109402','Html_box','',1),(109406,'1693847444.946113','furniture','block-109402','DeliveryDay','',3),(109408,'1693847444.95160','furniture','block-109392','Html_box','',2),(109409,'1693847444.954571','furniture','block-109382','BlockBox','',6),(109410,'1693847444.956524','furniture','block-109409','cart\\Products','',1),(109411,'1693847444.960635','furniture','block-109409','checkout\\CreateAccount','',2),(109412,'1693847444.963447','furniture','block-109409','DeliveryOptions\\Checkout','',0),(109413,'1693847444.965195','furniture','block-109382','BlockBox','checkout-payment',3),(109414,'1693847444.967253','furniture','block-109413','Html_box','',1),(109415,'1693847444.96852','furniture','block-109413','BlockBox','',2),(109416,'1693847444.969566','furniture','block-109415','Html_box','',1),(109417,'1693847444.97077','furniture','block-109415','checkout\\BillingAddress','',2),(109418,'1693847444.97415','furniture','block-109415-2','BlockBox','',1),(109419,'1693847444.975198','furniture','block-109418','checkout\\PaymentMethod','',2),(109420,'1693847444.97623','furniture','block-109418','Html_box','',1),(109421,'1693847444.977354','furniture','block-109382','BlockBox','',0),(109422,'1693847444.978759','furniture','block-109421','checkout\\LoginOnForm','',0),(109423,'1693847444.979723','furniture','block-109381-2','BlockBox','checkout-side',1),(109424,'1693847444.98495','furniture','block-109423','Html_box','',5),(109425,'1693847444.986544','furniture','block-109423','Html_box','',1),(109426,'1693847444.987613','furniture','block-109423','checkout\\Terms','',4),(109427,'1693847444.988926','furniture','block-109423','checkout\\Totals','',2),(109428,'1693847444.989754','furniture','block-109423','checkout\\ContinueBtn','',3),(109429,'116368','furniture','checkout_confirmation','BlockBox','',1),(109430,'116369','furniture','block-109429','checkout\\Totals','',7),(109431,'116370','furniture','block-109429','Html_box','',4),(109432,'116371','furniture','block-109429','checkout\\EditBtn','',5),(109433,'116372','furniture','block-109429','BlockBox','',2),(109434,'116373','furniture','block-109433','BlockBox','',1),(109435,'116374','furniture','block-109434','Html_box','',1),(109436,'116375','furniture','block-109434','checkout\\ShippingConfirm','',3),(109437,'116376','furniture','block-109433-2','BlockBox','',1),(109438,'116377','furniture','block-109437','checkout\\PaymentMethodConfirm','',3),(109439,'116378','furniture','block-109437','Html_box','',1),(109440,'116380','furniture','block-109429','BlockBox','',1),(109441,'116381','furniture','block-109440','BlockBox','',1),(109442,'116382','furniture','block-109441','checkout\\ShippingAddressConfirm','',3),(109443,'116383','furniture','block-109441','Html_box','',1),(109444,'116384','furniture','block-109440-2','BlockBox','',1),(109445,'116385','furniture','block-109444','Html_box','',1),(109446,'116386','furniture','block-109444','checkout\\BillingAddressConfirm','',3),(109447,'116387','furniture','block-109429','checkout\\ConfirmBtn','',3),(109448,'116388','furniture','block-109429','cart\\Products','',6),(109449,'116379','furniture','checkout_confirmation','checkout\\ConfirmBtn','',2),(109450,'116402','furniture','checkout_confirmation_no_shipping','BlockBox','',1),(109451,'116403','furniture','block-109450','checkout\\ConfirmBtn','',9),(109452,'116404','furniture','block-109450','BlockBox','',2),(109453,'116405','furniture','block-109452','BlockBox','',1),(109454,'116406','furniture','block-109453','Html_box','',1),(109455,'116407','furniture','block-109453','checkout\\BillingAddressConfirm','',3),(109456,'116408','furniture','block-109452-2','BlockBox','',1),(109457,'116409','furniture','block-109456','Html_box','',1),(109458,'116410','furniture','block-109456','checkout\\PaymentMethodConfirm','',3),(109459,'116411','furniture','block-109450','checkout\\ConfirmBtn','',4),(109460,'116412','furniture','block-109450','checkout\\Totals','',8),(109461,'116413','furniture','block-109450','cart\\Products','',7),(109462,'116414','furniture','block-109450','Html_box','',5),(109463,'116389','furniture','checkout_confirmation_no_shipping_q','BlockBox','',1),(109464,'116390','furniture','block-109463','quote\\Products','',4),(109465,'116391','furniture','block-109463','checkout\\ConfirmBtn','',2),(109466,'116392','furniture','block-109463','checkout\\ConfirmBtn','',6),(109467,'116393','furniture','block-109463','BlockBox','',1),(109468,'116394','furniture','block-109467','BlockBox','',1),(109469,'116395','furniture','block-109468','checkout\\BillingAddressConfirm','',3),(109470,'116396','furniture','block-109468','Html_box','',1),(109471,'116397','furniture','block-109467-2','BlockBox','',1),(109472,'116398','furniture','block-109471','checkout\\PaymentMethodConfirm','',3),(109473,'116399','furniture','block-109471','Html_box','',1),(109474,'116400','furniture','block-109463','Html_box','',3),(109475,'116401','furniture','block-109463','checkout\\Totals','',5),(109476,'116415','furniture','checkout_confirmation_q','BlockBox','',1),(109477,'116416','furniture','block-109476','BlockBox','',1),(109478,'116417','furniture','block-109477','BlockBox','',1),(109479,'116418','furniture','block-109478','checkout\\ShippingAddressConfirm','',3),(109480,'116419','furniture','block-109478','Html_box','',1),(109481,'116420','furniture','block-109477-2','BlockBox','',1),(109482,'116421','furniture','block-109481','checkout\\BillingAddressConfirm','',3),(109483,'116422','furniture','block-109481','Html_box','',1),(109484,'116423','furniture','block-109476','checkout\\Totals','',7),(109485,'116424','furniture','block-109476','quote\\Products','',6),(109486,'116425','furniture','block-109476','Html_box','',4),(109487,'116426','furniture','block-109476','checkout\\EditBtn','',5),(109488,'116427','furniture','block-109476','checkout\\ConfirmBtn','',8),(109489,'116428','furniture','block-109476','checkout\\ConfirmBtn','',3),(109490,'116429','furniture','block-109476','BlockBox','',2),(109491,'116430','furniture','block-109490','BlockBox','',1),(109492,'116431','furniture','block-109491','Html_box','',1),(109493,'116432','furniture','block-109491','checkout\\ShippingConfirm','',3),(109494,'116433','furniture','block-109490-2','BlockBox','',1),(109495,'116434','furniture','block-109494','Html_box','',1),(109496,'116435','furniture','block-109494','checkout\\PaymentMethodConfirm','',3),(109497,'116436','furniture','checkout_confirmation_title','Html_box','',1),(109498,'116437','furniture','checkout_confirmation_title_g','Html_box','',1),(109499,'116439','furniture','checkout_confirmation_title_no_shipping','Html_box','',1),(109500,'116438','furniture','checkout_confirmation_title_no_shipping_g','Html_box','',1),(109501,'116440','furniture','checkout_confirmation_title_q','Html_box','',1),(109502,'116441','furniture','checkout_confirmation_title_s','Html_box','',1),(109503,'116442','furniture','checkout_delivery','BlockBox','',2),(109504,'116443','furniture','block-109503','BlockBox','',1),(109505,'116444','furniture','block-109504','Html_box','',1),(109506,'116445','furniture','block-109504','checkout\\ContactInformation','',2),(109507,'116446','furniture','block-109503-2','BlockBox','',1),(109508,'116447','furniture','block-109507','Html_box','',1),(109509,'116448','furniture','block-109507','checkout\\Comments','',2),(109510,'116449','furniture','checkout_delivery','BlockBox','',3),(109511,'116450','furniture','block-109510','Html_box','',1),(109512,'116451','furniture','block-109510-2','checkout\\ContinueBtn','',1),(109513,'116452','furniture','checkout_delivery','BlockBox','',1),(109514,'116453','furniture','block-109513','BlockBox','',1),(109515,'116455','furniture','block-109514','checkout\\ShippingAddress','',2),(109516,'116456','furniture','block-109513-2','BlockBox','',1),(109517,'116457','furniture','block-109516','DelayedDespatch\\Checkout','',3),(109518,'116458','furniture','block-109516','checkout\\Shipping','',2),(109519,'116459','furniture','block-109516','Html_box','',1),(109520,'116460','furniture','block-109516','Neighbour\\Checkout','',4),(109521,'116461','furniture','checkout_delivery_g','BlockBox','',2),(109522,'116462','furniture','block-109521','BlockBox','',1),(109523,'116463','furniture','block-109522','checkout\\ContactInformation','',2),(109524,'116464','furniture','block-109522','Html_box','',1),(109525,'116465','furniture','block-109521-2','BlockBox','',1),(109526,'116466','furniture','block-109525','Html_box','',1),(109527,'116467','furniture','block-109525','checkout\\Comments','',2),(109528,'116468','furniture','checkout_delivery_g','BlockBox','',3),(109529,'116469','furniture','block-109528','Html_box','',1),(109530,'116470','furniture','block-109528-2','checkout\\ContinueBtn','',1),(109531,'116471','furniture','checkout_delivery_g','BlockBox','',1),(109532,'116472','furniture','block-109531','BlockBox','',1),(109533,'116473','furniture','block-109532','checkout\\ShippingAddress','',2),(109534,'116474','furniture','block-109532','Html_box','',1),(109535,'116475','furniture','block-109531-2','BlockBox','',1),(109536,'116476','furniture','block-109535','checkout\\Shipping','',2),(109537,'116477','furniture','block-109535','Html_box','',1),(109538,'116478','furniture','block-109535','DelayedDespatch\\Checkout','',3),(109539,'116479','furniture','block-109535','Neighbour\\Checkout','',4),(109540,'116480','furniture','checkout_delivery_no_shipping','BlockBox','',2),(109541,'116481','furniture','block-109540','Html_box','',1),(109542,'116482','furniture','block-109540-2','checkout\\ContinueBtn','',1),(109543,'116483','furniture','checkout_delivery_no_shipping','BlockBox','',1),(109544,'116484','furniture','block-109543','BlockBox','',1),(109545,'116485','furniture','block-109544','checkout\\ContactInformation','',2),(109546,'116486','furniture','block-109543-2','BlockBox','',1),(109547,'116487','furniture','block-109546','Html_box','',1),(109548,'116488','furniture','block-109546','checkout\\Comments','',2),(109549,'116489','furniture','checkout_delivery_no_shipping_g','BlockBox','',2),(109550,'116490','furniture','block-109549','Html_box','',1),(109551,'116491','furniture','block-109549-2','checkout\\ContinueBtn','',1),(109552,'116492','furniture','checkout_delivery_no_shipping_g','BlockBox','',1),(109553,'116493','furniture','block-109552','BlockBox','',1),(109554,'116494','furniture','block-109553','checkout\\ContactInformation','',2),(109555,'116495','furniture','block-109552-2','BlockBox','',1),(109556,'116496','furniture','block-109555','checkout\\Comments','',2),(109557,'116497','furniture','block-109555','Html_box','',1),(109558,'116498','furniture','checkout_delivery_title','Html_box','',1),(109559,'116499','furniture','checkout_delivery_title_g','Html_box','',1),(109560,'116501','furniture','checkout_delivery_title_no_shipping','Html_box','',1),(109561,'116500','furniture','checkout_delivery_title_no_shipping_g','Html_box','',1),(109562,'116502','furniture','checkout_delivery_title_q','Html_box','',1),(109563,'116503','furniture','checkout_delivery_title_s','Html_box','',1),(109564,'116504','furniture','checkout_free_s','BlockBox','',1),(109565,'116505','furniture','block-109564','BlockBox','',2),(109566,'116506','furniture','block-109565','BlockBox','',2),(109567,'116508','furniture','block-109566','BlockBox','',6),(109568,'116509','furniture','block-109567','sample\\Products','',1),(109569,'116510','furniture','block-109567','checkout\\CreateAccount','',3),(109570,'116511','furniture','block-109566','BlockBox','',5),(109571,'116512','furniture','block-109570','Html_box','',1),(109572,'116513','furniture','block-109570','checkout\\Comments','',2),(109573,'116514','furniture','block-109566','BlockBox','',2),(109574,'116515','furniture','block-109573','BlockBox','',2),(109575,'116516','furniture','block-109574','checkout\\ShippingChoice','',1),(109576,'116517','furniture','block-109573','Html_box','',1),(109577,'116518','furniture','block-109573','BlockBox','',3),(109578,'116519','furniture','block-109577','BlockBox','',1),(109579,'116520','furniture','block-109578','checkout\\ContactInformation','',4),(109580,'116521','furniture','block-109578','checkout\\ShippingAddress','',2),(109581,'116522','furniture','block-109578','Html_box','',3),(109582,'116523','furniture','block-109577-2','BlockBox','',1),(109583,'116524','furniture','block-109582','DelayedDespatch\\Checkout','',3),(109584,'116525','furniture','block-109573','Neighbour\\Checkout','',4),(109585,'116526','furniture','block-109565-2','BlockBox','',1),(109586,'116527','furniture','block-109585','Html_box','',3),(109587,'116528','furniture','block-109585','checkout\\ContinueBtn','',1),(109588,'1638956949.0762','furniture','block-109585','checkout\\Terms','',2),(109589,'1638957135.2709','furniture','block-109585','Html_box','',0),(109590,'116529','furniture','checkout_no_shipping','BlockBox','',1),(109591,'116530','furniture','block-109590','BlockBox','',2),(109592,'116531','furniture','block-109591','BlockBox','',1),(109593,'116532','furniture','block-109592','BlockBox','',6),(109594,'116533','furniture','block-109593','checkout\\CreateAccount','',2),(109595,'116534','furniture','block-109593','cart\\Products','',1),(109596,'116535','furniture','block-109592','BlockBox','',3),(109597,'116536','furniture','block-109596','Html_box','',1),(109598,'116537','furniture','block-109596','BlockBox','',2),(109599,'116538','furniture','block-109598','checkout\\BillingAddress','',2),(109600,'116539','furniture','block-109598','Html_box','',1),(109601,'116540','furniture','block-109598-2','BlockBox','',1),(109602,'116541','furniture','block-109601','Html_box','',1),(109603,'116542','furniture','block-109601','checkout\\PaymentMethod','',2),(109604,'116543','furniture','block-109592','BlockBox','',4),(109605,'116544','furniture','block-109604','BlockBox','',2),(109606,'116545','furniture','block-109605','CouponsAndVauchers\\Checkout','',1),(109607,'116546','furniture','block-109605-2','checkout\\CreditAmount','',1),(109608,'116547','furniture','block-109605-2','checkout\\BonusPoints','',2),(109609,'116548','furniture','block-109604','Html_box','',1),(109610,'116549','furniture','block-109592','BlockBox','',5),(109611,'116550','furniture','block-109610','checkout\\Comments','',2),(109612,'116551','furniture','block-109610','Html_box','',1),(109613,'116552','furniture','block-109591-2','BlockBox','',1),(109614,'116553','furniture','block-109613','Html_box','',1),(109615,'116554','furniture','block-109613','Html_box','',5),(109616,'116555','furniture','block-109613','checkout\\Totals','',2),(109617,'116556','furniture','block-109613','checkout\\ContinueBtn','',3),(109618,'116557','furniture','block-109613','checkout\\Terms','',4),(109619,'116558','furniture','checkout_no_shipping_g','BlockBox','',1),(109620,'116559','furniture','block-109619','checkout\\Totals','',5),(109621,'116560','furniture','block-109619','BlockBox','',6),(109622,'116561','furniture','block-109621','Html_box','',1),(109623,'116562','furniture','block-109621-2','checkout\\ContinueBtn','',1),(109624,'116563','furniture','block-109619','BlockBox','',2),(109625,'116564','furniture','block-109624','BlockBox','',1),(109626,'116565','furniture','block-109625','checkout\\ContactInformation','',2),(109627,'116566','furniture','block-109625','Html_box','',1),(109628,'116567','furniture','block-109624-2','BlockBox','',1),(109629,'116568','furniture','block-109628','checkout\\Comments','',2),(109630,'116569','furniture','block-109628','Html_box','',1),(109631,'116570','furniture','block-109619','BlockBox','',1),(109632,'116571','furniture','block-109631','BlockBox','',1),(109633,'116572','furniture','block-109632','Html_box','',1),(109634,'116573','furniture','block-109632','checkout\\BillingAddress','',2),(109635,'116574','furniture','block-109631-2','BlockBox','',1),(109636,'116575','furniture','block-109635','checkout\\BonusPoints','',4),(109637,'116576','furniture','block-109635','CouponsAndVauchers\\Checkout','',5),(109638,'116577','furniture','block-109635','checkout\\PaymentMethod','',2),(109639,'116578','furniture','block-109635','checkout\\CreditAmount','',3),(109640,'116579','furniture','block-109635','Html_box','',1),(109641,'116580','furniture','block-109619','quote\\Products','',3),(109642,'116581','furniture','checkout_no_shipping_q','BlockBox','',1),(109643,'116582','furniture','block-109642','BlockBox','',2),(109644,'116583','furniture','block-109643','BlockBox','',2),(109645,'116585','furniture','block-109644','BlockBox','',5),(109646,'116586','furniture','block-109645','checkout\\Comments','',2),(109647,'116587','furniture','block-109645','Html_box','',1),(109648,'116588','furniture','block-109644','BlockBox','',6),(109649,'116589','furniture','block-109648','checkout\\CreateAccount','',3),(109650,'116590','furniture','block-109648','quote\\Products','',2),(109651,'116591','furniture','block-109644','BlockBox','',3),(109652,'116592','furniture','block-109651','Html_box','',1),(109653,'116593','furniture','block-109651','BlockBox','',2),(109654,'116594','furniture','block-109653','Html_box','',1),(109655,'116595','furniture','block-109653','checkout\\BillingAddress','',2),(109656,'116596','furniture','block-109653-2','BlockBox','',1),(109657,'116597','furniture','block-109656','checkout\\PaymentMethod','',2),(109658,'116598','furniture','block-109656','Html_box','',1),(109659,'116599','furniture','block-109643-2','BlockBox','',1),(109660,'116600','furniture','block-109659','checkout\\ContinueBtn','',3),(109661,'116601','furniture','block-109659','Html_box','',5),(109662,'116602','furniture','block-109659','Html_box','',1),(109663,'116603','furniture','block-109659','checkout\\Totals','',2),(109664,'120984','furniture','block-109659','checkout\\Terms','',4),(109665,'116604','furniture','checkout_payment','BlockBox','',1),(109666,'116605','furniture','block-109665','BlockBox','',1),(109667,'116606','furniture','block-109666','checkout\\BillingAddress','',2),(109668,'116607','furniture','block-109666','Html_box','',1),(109669,'116608','furniture','block-109665-2','BlockBox','',1),(109670,'116609','furniture','block-109669','checkout\\CreditAmount','',3),(109671,'116610','furniture','block-109669','checkout\\BonusPoints','',4),(109672,'116611','furniture','block-109669','CouponsAndVauchers\\Checkout','',5),(109673,'116612','furniture','block-109669','checkout\\PaymentMethod','',2),(109674,'116613','furniture','block-109669','Html_box','',1),(109675,'116614','furniture','checkout_payment','BlockBox','',2),(109676,'116615','furniture','block-109675','Html_box','',1),(109677,'116616','furniture','block-109675-2','checkout\\ContinueBtn','',1),(109678,'116617','furniture','checkout_payment_g','BlockBox','',1),(109679,'116618','furniture','block-109678','BlockBox','',1),(109680,'116619','furniture','block-109679','checkout\\BillingAddress','',2),(109681,'116620','furniture','block-109679','Html_box','',1),(109682,'116621','furniture','block-109678-2','BlockBox','',1),(109683,'116622','furniture','block-109682','checkout\\CreditAmount','',3),(109684,'116623','furniture','block-109682','Html_box','',1),(109685,'116624','furniture','block-109682','checkout\\PaymentMethod','',2),(109686,'116625','furniture','block-109682','CouponsAndVauchers\\Checkout','',5),(109687,'116626','furniture','block-109682','checkout\\BonusPoints','',4),(109688,'116627','furniture','checkout_payment_g','BlockBox','',2),(109689,'116628','furniture','block-109688','Html_box','',1),(109690,'116629','furniture','block-109688-2','checkout\\ContinueBtn','',1),(109691,'116630','furniture','checkout_payment_no_shipping','BlockBox','',2),(109692,'116631','furniture','block-109691','Html_box','',1),(109693,'116632','furniture','block-109691-2','checkout\\ContinueBtn','',1),(109694,'116633','furniture','checkout_payment_no_shipping','BlockBox','',1),(109695,'116634','furniture','block-109694','BlockBox','',1),(109696,'116635','furniture','block-109695','Html_box','',1),(109697,'116636','furniture','block-109695','checkout\\BillingAddress','',2),(109698,'116637','furniture','block-109694-2','BlockBox','',1),(109699,'116638','furniture','block-109698','checkout\\BonusPoints','',4),(109700,'116639','furniture','block-109698','CouponsAndVauchers\\Checkout','',5),(109701,'116640','furniture','block-109698','checkout\\PaymentMethod','',2),(109702,'116641','furniture','block-109698','checkout\\CreditAmount','',3),(109703,'116642','furniture','block-109698','Html_box','',1),(109704,'116643','furniture','checkout_payment_no_shipping_g','BlockBox','',2),(109705,'116644','furniture','block-109704','Html_box','',1),(109706,'116645','furniture','block-109704-2','checkout\\ContinueBtn','',1),(109707,'116646','furniture','checkout_payment_no_shipping_g','BlockBox','',1),(109708,'116647','furniture','block-109707','BlockBox','',1),(109709,'116648','furniture','block-109708','checkout\\BillingAddress','',2),(109710,'116649','furniture','block-109708','Html_box','',1),(109711,'116650','furniture','block-109707-2','BlockBox','',1),(109712,'116651','furniture','block-109711','checkout\\BonusPoints','',4),(109713,'116652','furniture','block-109711','checkout\\CreditAmount','',3),(109714,'116653','furniture','block-109711','checkout\\PaymentMethod','',2),(109715,'116654','furniture','block-109711','Html_box','',1),(109716,'116655','furniture','block-109711','CouponsAndVauchers\\Checkout','',5),(109717,'116656','furniture','checkout_payment_title','Html_box','',1),(109718,'116657','furniture','checkout_payment_title_g','Html_box','',1),(109719,'116658','furniture','checkout_payment_title_no_shipping','Html_box','',1),(109720,'116659','furniture','checkout_payment_title_no_shipping_g','Html_box','',1),(109721,'116660','furniture','checkout_payment_title_q','Html_box','',1),(109722,'116661','furniture','checkout_payment_title_s','Html_box','',1),(109723,'120947','furniture','checkout_q','BlockBox','',1),(109724,'120948','furniture','block-109723','BlockBox','',2),(109725,'120949','furniture','block-109724','BlockBox','',2),(109726,'120950','furniture','block-109725','BlockBox','',6),(109727,'120951','furniture','block-109726','checkout\\CreateAccount','',3),(109728,'120952','furniture','block-109726','quote\\Products','',2),(109729,'120953','furniture','block-109725','BlockBox','',2),(109730,'120954','furniture','block-109729','BlockBox','',2),(109731,'120955','furniture','block-109730','checkout\\ShippingChoice','',1),(109732,'120956','furniture','block-109729','Neighbour\\Checkout','',4),(109733,'120957','furniture','block-109729','Html_box','',1),(109734,'120958','furniture','block-109729','BlockBox','',3),(109735,'120959','furniture','block-109734','BlockBox','',1),(109736,'120960','furniture','block-109735','checkout\\ContactInformation','',4),(109737,'120961','furniture','block-109735','checkout\\ShippingAddress','',2),(109738,'120962','furniture','block-109735','Html_box','',3),(109739,'120963','furniture','block-109734-2','BlockBox','',1),(109740,'120964','furniture','block-109739','checkout\\Shipping','',2),(109741,'120965','furniture','block-109739','Html_box','',1),(109742,'120966','furniture','block-109739','DelayedDespatch\\Checkout','',3),(109743,'120967','furniture','block-109725','BlockBox','',5),(109744,'120968','furniture','block-109743','Html_box','',1),(109745,'120969','furniture','block-109743','checkout\\Comments','',2),(109746,'120970','furniture','block-109725','BlockBox','',3),(109747,'120971','furniture','block-109746','Html_box','',1),(109748,'120972','furniture','block-109746','BlockBox','',2),(109749,'120973','furniture','block-109748','checkout\\BillingAddress','',2),(109750,'120974','furniture','block-109748','Html_box','',1),(109751,'120975','furniture','block-109748-2','BlockBox','',1),(109752,'120976','furniture','block-109751','checkout\\PaymentMethod','',2),(109753,'120977','furniture','block-109751','Html_box','',1),(109754,'120978','furniture','block-109724-2','BlockBox','',1),(109755,'120979','furniture','block-109754','Html_box','',1),(109756,'120980','furniture','block-109754','Html_box','',5),(109757,'120981','furniture','block-109754','checkout\\Totals','',2),(109758,'120982','furniture','block-109754','checkout\\ContinueBtn','',3),(109759,'120983','furniture','block-109754','checkout\\Terms','',4),(109760,'116699','furniture','checkout_s','BlockBox','',1),(109761,'116700','furniture','block-109760','BlockBox','',2),(109762,'116701','furniture','block-109761','BlockBox','',2),(109763,'116703','furniture','block-109762','BlockBox','',6),(109764,'116704','furniture','block-109763','sample\\Products','',1),(109765,'116705','furniture','block-109763','checkout\\CreateAccount','',3),(109766,'116706','furniture','block-109762','BlockBox','',2),(109767,'116707','furniture','block-109766','Html_box','',1),(109768,'116708','furniture','block-109766','Neighbour\\Checkout','',4),(109769,'116709','furniture','block-109766','BlockBox','',2),(109770,'116710','furniture','block-109769','checkout\\ShippingChoice','',1),(109771,'116711','furniture','block-109766','BlockBox','',3),(109772,'116712','furniture','block-109771','BlockBox','',1),(109773,'116713','furniture','block-109772','checkout\\ShippingAddress','',2),(109774,'116714','furniture','block-109772','checkout\\ContactInformation','',4),(109775,'116715','furniture','block-109772','Html_box','',3),(109776,'116716','furniture','block-109771-2','BlockBox','',1),(109777,'116717','furniture','block-109776','checkout\\Shipping','',2),(109778,'116718','furniture','block-109776','DelayedDespatch\\Checkout','',3),(109779,'116719','furniture','block-109776','Html_box','',1),(109780,'116720','furniture','block-109762','BlockBox','',3),(109781,'116721','furniture','block-109780','BlockBox','',2),(109782,'116722','furniture','block-109781','Html_box','',1),(109783,'116723','furniture','block-109781','checkout\\BillingAddress','',2),(109784,'116724','furniture','block-109781-2','BlockBox','',1),(109785,'116725','furniture','block-109784','Html_box','',1),(109786,'116726','furniture','block-109784','checkout\\PaymentMethod','',2),(109787,'116727','furniture','block-109780','Html_box','',1),(109788,'116728','furniture','block-109762','BlockBox','',5),(109789,'116729','furniture','block-109788','Html_box','',1),(109790,'116730','furniture','block-109788','checkout\\Comments','',2),(109791,'116731','furniture','block-109762','BlockBox','',4),(109792,'116732','furniture','block-109791','BlockBox','',2),(109793,'116733','furniture','block-109792','CouponsAndVauchers\\Checkout','',1),(109794,'116734','furniture','block-109792-2','checkout\\BonusPoints','',2),(109795,'116735','furniture','block-109792-2','checkout\\CreditAmount','',1),(109796,'116736','furniture','block-109791','Html_box','',1),(109797,'116737','furniture','block-109761-2','BlockBox','',1),(109798,'116738','furniture','block-109797','checkout\\Totals','',2),(109799,'116739','furniture','block-109797','Html_box','',5),(109800,'116740','furniture','block-109797','Html_box','',1),(109801,'116741','furniture','block-109797','checkout\\ContinueBtn','',3),(109802,'120986','furniture','block-109797','checkout\\Terms','',4),(109803,'116742','furniture','checkout_step_bottom','Html_box','',1),(109804,'116743','furniture','checkout_step_bottom','cart\\Products','',2),(109805,'116744','furniture','checkout_step_bottom','checkout\\Totals','',3),(109806,'116745','furniture','checkout_step_bottom_g','checkout\\Totals','',3),(109807,'116746','furniture','checkout_step_bottom_g','quote\\Products','',2),(109808,'116747','furniture','checkout_step_bottom_g','Html_box','',1),(109809,'116749','furniture','checkout_step_bottom_no_shipping','Html_box','',1),(109810,'116750','furniture','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(109811,'116753','furniture','checkout_step_bottom_no_shipping','cart\\Products','',2),(109812,'116748','furniture','checkout_step_bottom_no_shipping_g','Html_box','',1),(109813,'116751','furniture','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(109814,'116752','furniture','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(109815,'116754','furniture','communication','BlockBox','',1),(109816,'116755','furniture','block-109815','Html_box','',2),(109817,'116756','furniture','block-109815','Communication\\NewTopicButton','',1),(109818,'116757','furniture','block-109815','Communication\\Topic','',3),(109819,'116758','furniture','compare','BlockBox','',1),(109820,'116759','furniture','block-109819','catalog\\Compare','',1),(109821,'117665.000001','furniture','compareproduct','BlockBox','listing-item',1),(109822,'120921.000001','furniture','block-109821','BlockBox','',1),(109823,'120919.000001','furniture','block-109822','BlockBox','listing-item',1),(109824,'1638872990.9609','furniture','block-109823','BlockBox','',2),(109825,'117671.000001','furniture','block-109824','productListing\\image','',1),(109826,'117677.000001','furniture','block-109824-2','productListing\\compare','',1),(109827,'117675.000001','furniture','block-109824-2','productListing\\name','',2),(109828,'117676.000001','furniture','block-109824-2','productListing\\stock','',3),(109829,'1638873112.0384','furniture','block-109824-2','BlockBox','',4),(109830,'117670.000001','furniture','block-109829','productListing\\rating','',2),(109831,'117673.000001','furniture','block-109829-2','productListing\\price','',1),(109832,'116760','furniture','compare_products','BlockBox','',2),(109833,'116761','furniture','block-109832','productListing\\rating','',4),(109834,'116762','furniture','block-109832','productListing\\model','',5),(109835,'116763','furniture','block-109832','productListing\\compare','',1),(109836,'116764','furniture','block-109832','BlockBox','',2),(109837,'116765','furniture','block-109836','productListing\\image','',1),(109838,'116766','furniture','block-109836-2','productListing\\name','',2),(109839,'116767','furniture','block-109832','BlockBox','',3),(109840,'116768','furniture','block-109839','productListing\\price','',1),(109841,'116769','furniture','block-109839-2','productListing\\buyButton','',1),(109842,'116770','furniture','confirmation','BlockBox','',1),(109843,'116771','furniture','block-109842','BlockBox','',2),(109844,'116772','furniture','block-109843','BlockBox','',2),(109845,'116773','furniture','block-109844','BlockBox','',4),(109846,'116774','furniture','block-109845','checkout\\EditBtn','',2),(109847,'116775','furniture','block-109845','cart\\Products','',3),(109848,'116776','furniture','block-109845','Html_box','',1),(109849,'116777','furniture','block-109844','BlockBox','',3),(109850,'116778','furniture','block-109849','checkout\\EditBtn','',2),(109851,'116779','furniture','block-109849','Html_box','',1),(109852,'116780','furniture','block-109849','checkout\\CommentsConfirm','',3),(109853,'116781','furniture','block-109844','BlockBox','',1),(109854,'116782','furniture','block-109853','BlockBox','',1),(109855,'116783','furniture','block-109854','checkout\\EditBtn','',6),(109856,'116784','furniture','block-109854','DelayedDespatch\\CheckoutConfirm','',8),(109857,'116785','furniture','block-109854','Html_box','',9),(109858,'116786','furniture','block-109854','checkout\\EditBtn','',10),(109859,'116787','furniture','block-109854','Html_box','',5),(109860,'116788','furniture','block-109854','checkout\\ShippingConfirm','',7),(109861,'116789','furniture','block-109854','Html_box','',1),(109862,'116790','furniture','block-109854','checkout\\EditBtn','',3),(109863,'116791','furniture','block-109854','checkout\\ContactConfirm','',11),(109864,'116792','furniture','block-109854','Html_box','',2),(109865,'116793','furniture','block-109854','checkout\\ShippingAddressConfirm','',4),(109866,'116794','furniture','block-109853-2','BlockBox','',1),(109867,'116795','furniture','block-109866','checkout\\EditBtn','',6),(109868,'116796','furniture','block-109866','checkout\\EditBtn','',3),(109869,'116797','furniture','block-109866','checkout\\PaymentMethodConfirm','',7),(109870,'116798','furniture','block-109866','Html_box','',5),(109871,'116799','furniture','block-109866','Html_box','',1),(109872,'116800','furniture','block-109866','checkout\\BillingAddressConfirm','',4),(109873,'116801','furniture','block-109866','Html_box','',2),(109874,'116802','furniture','block-109843','UploadCustomerId\\UploadCustomerIdForm','',1),(109875,'116803','furniture','block-109843-2','BlockBox','',1),(109876,'116804','furniture','block-109875','Html_box','',1),(109877,'116805','furniture','block-109875','checkout\\ConfirmBtn','',3),(109878,'116806','furniture','block-109875','checkout\\Totals','',2),(109879,'116807','furniture','block-109842','Html_box','',1),(109880,'116808','furniture','confirmation_free_s','BlockBox','',1),(109881,'116809','furniture','block-109880','BlockBox','',2),(109882,'116810','furniture','block-109881','BlockBox','',1),(109883,'116811','furniture','block-109882','BlockBox','',2),(109884,'116812','furniture','block-109883','checkout\\CommentsConfirm','',3),(109885,'116813','furniture','block-109883','checkout\\EditBtn','',2),(109886,'116814','furniture','block-109883','Html_box','',1),(109887,'116815','furniture','block-109882','BlockBox','',3),(109888,'116816','furniture','block-109887','checkout\\EditBtn','',3),(109889,'116817','furniture','block-109887','Html_box','',1),(109890,'116818','furniture','block-109887','sample\\Products','',2),(109891,'116819','furniture','block-109882','BlockBox','',1),(109892,'116820','furniture','block-109891','BlockBox','',1),(109893,'116821','furniture','block-109892','checkout\\EditBtn','',3),(109894,'116822','furniture','block-109892','checkout\\ShippingConfirm','',7),(109895,'116823','furniture','block-109892','Html_box','',5),(109896,'116824','furniture','block-109892','checkout\\EditBtn','',6),(109897,'116825','furniture','block-109892','Html_box','',2),(109898,'116826','furniture','block-109892','checkout\\ShippingAddressConfirm','',4),(109899,'116827','furniture','block-109891-2','BlockBox','',1),(109900,'116828','furniture','block-109899','checkout\\ContactConfirm','',3),(109901,'116829','furniture','block-109899','DelayedDespatch\\CheckoutConfirm','',4),(109902,'116830','furniture','block-109899','checkout\\EditBtn','',2),(109903,'116831','furniture','block-109899','Html_box','',1),(109904,'116832','furniture','block-109881-2','BlockBox','',1),(109905,'116833','furniture','block-109904','checkout\\ConfirmBtn','',3),(109906,'116834','furniture','block-109880','Html_box','',1),(109907,'116835','furniture','confirmation_no_shipping','BlockBox','',1),(109908,'116836','furniture','block-109907','Html_box','',1),(109909,'116837','furniture','block-109907','BlockBox','',2),(109910,'116838','furniture','block-109909','BlockBox','',1),(109911,'116839','furniture','block-109910','BlockBox','',1),(109912,'116840','furniture','block-109911','BlockBox','',1),(109913,'116841','furniture','block-109912','checkout\\EditBtn','',10),(109914,'116842','furniture','block-109912','Html_box','',9),(109915,'116843','furniture','block-109912','checkout\\ContactConfirm','',11),(109916,'116844','furniture','block-109911-2','BlockBox','',1),(109917,'116845','furniture','block-109916','checkout\\PaymentMethodConfirm','',7),(109918,'116846','furniture','block-109916','checkout\\EditBtn','',6),(109919,'116847','furniture','block-109916','Html_box','',5),(109920,'116848','furniture','block-109916','Html_box','',1),(109921,'116849','furniture','block-109916','checkout\\EditBtn','',3),(109922,'116850','furniture','block-109916','checkout\\BillingAddressConfirm','',4),(109923,'116851','furniture','block-109916','Html_box','',2),(109924,'116852','furniture','block-109910','BlockBox','',2),(109925,'116853','furniture','block-109924','Html_box','',1),(109926,'116854','furniture','block-109924','checkout\\CommentsConfirm','',3),(109927,'116855','furniture','block-109924','checkout\\EditBtn','',2),(109928,'116856','furniture','block-109910','BlockBox','',3),(109929,'116857','furniture','block-109928','Html_box','',1),(109930,'116858','furniture','block-109928','checkout\\EditBtn','',2),(109931,'116859','furniture','block-109928','cart\\Products','',3),(109932,'116860','furniture','block-109909-2','BlockBox','',1),(109933,'116861','furniture','block-109932','checkout\\ConfirmBtn','',3),(109934,'116862','furniture','block-109932','Html_box','',1),(109935,'116863','furniture','block-109932','checkout\\Totals','',2),(109936,'116864','furniture','confirmation_no_shipping_q','BlockBox','',2),(109937,'116865','furniture','block-109936','Html_box','',1),(109938,'116866','furniture','block-109936','BlockBox','',2),(109939,'116867','furniture','block-109938','BlockBox','',1),(109940,'116868','furniture','block-109939','BlockBox','',2),(109941,'116869','furniture','block-109940','Html_box','',1),(109942,'116870','furniture','block-109940','checkout\\CommentsConfirm','',3),(109943,'116871','furniture','block-109940','checkout\\EditBtn','',2),(109944,'116872','furniture','block-109939','BlockBox','',1),(109945,'116873','furniture','block-109944','BlockBox','',1),(109946,'116874','furniture','block-109945','checkout\\EditBtn','',5),(109947,'116875','furniture','block-109945','checkout\\ContactConfirm','',6),(109948,'116876','furniture','block-109945','checkout\\PaymentMethodConfirm','',3),(109949,'116877','furniture','block-109945','checkout\\EditBtn','',2),(109950,'116878','furniture','block-109945','Html_box','',4),(109951,'116879','furniture','block-109945','Html_box','',1),(109952,'116880','furniture','block-109944-2','BlockBox','',1),(109953,'116881','furniture','block-109952','checkout\\BillingAddressConfirm','',4),(109954,'116882','furniture','block-109952','checkout\\EditBtn','',3),(109955,'116883','furniture','block-109952','Html_box','',2),(109956,'116884','furniture','block-109939','BlockBox','',3),(109957,'116885','furniture','block-109956','checkout\\EditBtn','',2),(109958,'116886','furniture','block-109956','Html_box','',1),(109959,'116887','furniture','block-109956','quote\\Products','',3),(109960,'116888','furniture','block-109938-2','BlockBox','',1),(109961,'116889','furniture','block-109960','checkout\\ConfirmBtn','',3),(109962,'116890','furniture','block-109960','checkout\\Totals','',2),(109963,'116891','furniture','block-109960','Html_box','',1),(109964,'116892','furniture','confirmation_q','BlockBox','',1),(109965,'116893','furniture','block-109964','Html_box','',1),(109966,'116894','furniture','block-109964','BlockBox','',2),(109967,'116895','furniture','block-109966','BlockBox','',1),(109968,'116896','furniture','block-109967','BlockBox','',3),(109969,'116897','furniture','block-109968','quote\\Products','',3),(109970,'116898','furniture','block-109968','Html_box','',1),(109971,'116899','furniture','block-109968','checkout\\EditBtn','',2),(109972,'116900','furniture','block-109967','BlockBox','',1),(109973,'116901','furniture','block-109972','BlockBox','',1),(109974,'116902','furniture','block-109973','Html_box','',1),(109975,'116903','furniture','block-109973','checkout\\EditBtn','',10),(109976,'116904','furniture','block-109973','Html_box','',2),(109977,'116905','furniture','block-109973','checkout\\ContactConfirm','',11),(109978,'116906','furniture','block-109973','checkout\\ShippingAddressConfirm','',4),(109979,'116907','furniture','block-109973','checkout\\ShippingConfirm','',7),(109980,'116908','furniture','block-109973','checkout\\EditBtn','',3),(109981,'116909','furniture','block-109973','DelayedDespatch\\CheckoutConfirm','',8),(109982,'116910','furniture','block-109973','Html_box','',9),(109983,'116911','furniture','block-109973','Html_box','',5),(109984,'116912','furniture','block-109973','checkout\\EditBtn','',6),(109985,'116913','furniture','block-109972-2','BlockBox','',1),(109986,'116914','furniture','block-109985','checkout\\EditBtn','',3),(109987,'116915','furniture','block-109985','checkout\\BillingAddressConfirm','',4),(109988,'116916','furniture','block-109985','checkout\\PaymentMethodConfirm','',7),(109989,'116917','furniture','block-109985','Html_box','',1),(109990,'116918','furniture','block-109985','Html_box','',2),(109991,'116919','furniture','block-109985','checkout\\EditBtn','',6),(109992,'116920','furniture','block-109985','Html_box','',5),(109993,'116921','furniture','block-109967','BlockBox','',2),(109994,'116922','furniture','block-109993','checkout\\CommentsConfirm','',3),(109995,'116923','furniture','block-109993','Html_box','',1),(109996,'116924','furniture','block-109993','checkout\\EditBtn','',2),(109997,'116925','furniture','block-109966-2','BlockBox','',1),(109998,'116926','furniture','block-109997','Html_box','',1),(109999,'116927','furniture','block-109997','checkout\\Totals','',2),(110000,'116928','furniture','block-109997','checkout\\ConfirmBtn','',3),(110001,'116929','furniture','confirmation_s','BlockBox','',1),(110002,'116930','furniture','block-110001','BlockBox','',2),(110003,'116931','furniture','block-110002','BlockBox','',1),(110004,'116932','furniture','block-110003','BlockBox','',1),(110005,'116933','furniture','block-110004','BlockBox','',1),(110006,'116934','furniture','block-110005','checkout\\ShippingAddressConfirm','',4),(110007,'116935','furniture','block-110005','checkout\\EditBtn','',3),(110008,'116936','furniture','block-110005','Html_box','',2),(110009,'116937','furniture','block-110005','DelayedDespatch\\CheckoutConfirm','',8),(110010,'116938','furniture','block-110005','checkout\\ShippingConfirm','',7),(110011,'116939','furniture','block-110005','Html_box','',1),(110012,'116940','furniture','block-110005','Html_box','',5),(110013,'116941','furniture','block-110005','Html_box','',9),(110014,'116942','furniture','block-110005','checkout\\ContactConfirm','',11),(110015,'116943','furniture','block-110005','checkout\\EditBtn','',6),(110016,'116944','furniture','block-110005','checkout\\EditBtn','',10),(110017,'116945','furniture','block-110004-2','BlockBox','',1),(110018,'116946','furniture','block-110017','Html_box','',2),(110019,'116947','furniture','block-110017','checkout\\BillingAddressConfirm','',4),(110020,'116948','furniture','block-110017','checkout\\EditBtn','',3),(110021,'116949','furniture','block-110017','checkout\\PaymentMethodConfirm','',7),(110022,'116950','furniture','block-110017','checkout\\EditBtn','',6),(110023,'116951','furniture','block-110017','Html_box','',1),(110024,'116952','furniture','block-110017','Html_box','',5),(110025,'116953','furniture','block-110003','BlockBox','',3),(110026,'116954','furniture','block-110025','checkout\\EditBtn','',3),(110027,'116955','furniture','block-110025','Html_box','',1),(110028,'116956','furniture','block-110025','sample\\Products','',2),(110029,'116957','furniture','block-110003','BlockBox','',2),(110030,'116958','furniture','block-110029','Html_box','',1),(110031,'116959','furniture','block-110029','checkout\\EditBtn','',2),(110032,'116960','furniture','block-110029','checkout\\CommentsConfirm','',3),(110033,'116961','furniture','block-110002-2','BlockBox','',1),(110034,'116962','furniture','block-110033','checkout\\Totals','',2),(110035,'116963','furniture','block-110033','checkout\\ConfirmBtn','',3),(110036,'116964','furniture','block-110033','Html_box','',1),(110037,'116965','furniture','block-110001','Html_box','',1),(110038,'116966','furniture','contact','BlockBox','info-content',1),(110039,'116967','furniture','block-110038','info\\Title','',1),(110040,'116968','furniture','block-110038','BlockBox','',2),(110041,'116969','furniture','block-110040','contact\\ContactForm','',1),(110042,'116970','furniture','block-110040-2','contact\\Contacts','',1),(110043,'116971','furniture','created_success','BlockBox','',1),(110044,'116972','furniture','block-110043','Html_box','',1),(110045,'116973','furniture','block-110043','Html_box','',2),(110046,'116102.000001','furniture','credit_amount_history','BlockBox','',1),(110047,'116103.000001','furniture','block-110046','BlockBox','',1),(110048,'116104.000001','furniture','block-110047','WidgetsAria','',1),(110068,'116109.000001','furniture','block-110047-2','Html_box','',1),(110069,'1638895944.9672','furniture','block-110047-2','account\\CreditAmountHistory','',2),(110070,'116974','furniture','credit_note','invoice\\Container','',1),(110071,'116975','furniture','block-110070','BlockBox','',5),(110072,'116976','furniture','block-110071','invoice\\StoreAddress','',8),(110073,'116977','furniture','block-110071','Text','',1),(110074,'116978','furniture','block-110071-2','Text','',2),(110075,'116979','furniture','block-110071-2','Logo','',1),(110076,'116980','furniture','block-110071-3','Text','',1),(110077,'116981','furniture','block-110071-3','BlockBox','',3),(110078,'116982','furniture','block-110077','Text','',1),(110079,'116983','furniture','block-110077-2','invoice\\StoreEmail','',1),(110080,'116984','furniture','block-110071-3','BlockBox','',2),(110081,'116985','furniture','block-110080','Text','',1),(110082,'116986','furniture','block-110080-2','invoice\\StorePhone','',1),(110083,'116987','furniture','block-110070','invoice\\Products','',3),(110084,'116988','furniture','block-110070','BlockBox','',1),(110085,'116989','furniture','block-110084','Logo','',1),(110086,'116990','furniture','block-110084-2','BlockBox','',4),(110087,'116991','furniture','block-110086','Text','',1),(110088,'116992','furniture','block-110086-2','invoice\\StoreSite','',1),(110089,'116993','furniture','block-110084-2','BlockBox','',2),(110090,'116994','furniture','block-110089','Text','',1),(110091,'116995','furniture','block-110089-2','invoice\\StorePhone','',1),(110092,'116996','furniture','block-110084-2','BlockBox','',3),(110093,'116997','furniture','block-110092','Text','',1),(110094,'116998','furniture','block-110092-2','invoice\\StoreEmail','',1),(110095,'116999','furniture','block-110084-2','BlockBox','',1),(110096,'117000','furniture','block-110095','invoice\\StoreAddress','',1),(110097,'117001','furniture','block-110070','BlockBox','',4),(110098,'117002','furniture','block-110097','BlockBox','',1),(110099,'117003','furniture','block-110098','invoice\\ShippingAddress','',2),(110100,'117004','furniture','block-110098','Text','',1),(110101,'117005','furniture','block-110097-2','BlockBox','',1),(110102,'117006','furniture','block-110070','BlockBox','',2),(110103,'117007','furniture','block-110102','BlockBox','',7),(110104,'117008','furniture','block-110103','BlockBox','',1),(110105,'117009','furniture','block-110104','Text','',1),(110106,'117010','furniture','block-110104','invoice\\BillingAddress','',2),(110107,'117011','furniture','block-110103-2','BlockBox','',1),(110108,'117012','furniture','block-110107','invoice\\CustomerPhone','',4),(110109,'117013','furniture','block-110107','Text','',1),(110110,'117014','furniture','block-110107','Text','',3),(110111,'117015','furniture','block-110107','invoice\\CustomerName','',2),(110112,'117016','furniture','block-110107','invoice\\CustomerEmail','',6),(110113,'117017','furniture','block-110107','Text','',5),(110114,'117018','furniture','block-110102','BlockBox','',8),(110115,'117019','furniture','block-110114','BlockBox','',1),(110116,'117020','furniture','block-110115','invoice\\ShippingMethod','',2),(110117,'117021','furniture','block-110115','Text','',1),(110118,'117022','furniture','block-110114-2','BlockBox','',1),(110119,'117023','furniture','block-110118','Text','',1),(110120,'117024','furniture','block-110118','invoice\\ShippingMethod','',2),(110121,'117025','furniture','block-110102-2','invoice\\OrderId','',1),(110122,'117026','furniture','block-110102-2','Text','',2),(110123,'117027','furniture','block-110102-2','invoice\\PaymentDate','',3),(110124,'117034','furniture','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(110125,'1639155816.3893','furniture','delivery-location','BlockBox','',2),(110126,'117028','furniture','block-110125','DeliveryLocation\\FeaturedList','',6),(110127,'117029','furniture','block-110125','DeliveryLocation\\LocationLongDescription','',3),(110128,'117030','furniture','block-110125','DeliveryLocation\\LocationList','',4),(110129,'117031','furniture','block-110125','DeliveryLocation\\LocationTitle','',1),(110130,'117032','furniture','block-110125','DeliveryLocation\\LocationProducts','',7),(110131,'117033','furniture','block-110125','DeliveryLocation\\LocationDescription','',2),(110132,'1639485067.5512','furniture','block-110125','DeliveryLocation\\CrossPages','',0),(110133,'1639485089.2227','furniture','block-110125','DeliveryLocation\\ProductCategories','',0),(110134,'1639154415.2739','furniture','delivery-location-default','BlockBox','',2),(110135,'117035','furniture','block-110134','DeliveryLocation\\TopLocationList','',2),(110136,'117036','furniture','block-110134','Heading','',1),(110137,'1639419797.9718','furniture','block-110134','DeliveryLocation\\ListByPage','',3),(110138,'117037','furniture','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(110139,'117038','furniture','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(110140,'117039','furniture','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(110141,'117040','furniture','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(110142,'117041','furniture','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(110143,'117042','furniture','delivery_loc_2','DeliveryLocation\\LocationList','',7),(110144,'117043','furniture','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(110145,'117044','furniture','email','email\\BlockBox','',1),(110146,'117045','furniture','block-110145','email\\BlockBox','',1),(110147,'117046','furniture','block-110146','Copyright','',4),(110148,'117047','furniture','block-110146','email\\Content','',3),(110149,'117048','furniture','block-110146','email\\BlockBox','',2),(110150,'117049','furniture','block-110149','email\\Title','',1),(110151,'117050','furniture','block-110149-2','email\\Date','',1),(110152,'117051','furniture','block-110146','Logo','',1),(110153,'117052','furniture','email_2','email\\BlockBox','',1),(110154,'117053','furniture','block-110153','email\\BlockBox','',1),(110155,'117054','furniture','block-110154','Copyright','',4),(110156,'117055','furniture','block-110154','Logo','',1),(110157,'117056','furniture','block-110154','email\\Content','',3),(110158,'117057','furniture','block-110154','email\\BlockBox','',2),(110159,'117058','furniture','block-110158','email\\Title','',1),(110160,'117059','furniture','block-110158-2','email\\Date','',1),(110161,'117060','furniture','email_3','email\\BlockBox','',1),(110162,'117061','furniture','block-110161','email\\BlockBox','',1),(110163,'117062','furniture','block-110162','email\\BlockBox','',2),(110164,'117063','furniture','block-110163','email\\Content','',2),(110165,'117064','furniture','block-110163','email\\BlockBox','',1),(110166,'117065','furniture','block-110165','email\\Title','',1),(110167,'117066','furniture','block-110165-2','email\\Date','',1),(110168,'117067','furniture','block-110162','Copyright','',3),(110169,'117068','furniture','block-110162','Logo','',1),(110170,'117069','furniture','email_4','email\\BlockBox','',1),(110171,'117070','furniture','block-110170','email\\BlockBox','',1),(110172,'117071','furniture','block-110171','Copyright','',2),(110173,'117072','furniture','block-110171','email\\BlockBox','',1),(110174,'117073','furniture','block-110173','email\\BlockBox','',1),(110175,'117074','furniture','block-110174','Logo','',1),(110176,'117075','furniture','block-110174-2','email\\Date','',2),(110177,'117076','furniture','block-110174-2','email\\Title','',1),(110178,'117077','furniture','block-110173','email\\Content','',2),(110179,'121029','furniture','filescatalog_category','BlockBox','',1),(110180,'121030','furniture','block-110179','FilesCatalog\\widgets\\FilesList','',3),(110181,'121031','furniture','block-110179','FilesCatalog\\widgets\\Title','',1),(110182,'121032','furniture','block-110179','FilesCatalog\\widgets\\Description','',2),(110183,'121025','furniture','filescatalog_index','BlockBox','',1),(110184,'121026','furniture','block-110183','Html_box','',1),(110185,'121027','furniture','block-110183','FilesCatalog\\widgets\\FilesCatalog','',2),(110186,'117078','furniture','footer','BlockBox','footer-content',1),(110187,'120866','furniture','block-110186','BlockBox','',3),(110188,'117091','furniture','block-110187','Contacts','',2),(110189,'120868','furniture','block-110187','Logo','',1),(110190,'120871','furniture','block-110187-2','BlockBox','',1),(110191,'117085','furniture','block-110190','Menu','Footer',2),(110192,'120869','furniture','block-110190','BlockBox','',3),(110193,'120870','furniture','block-110192','Image','',3),(110194,'120872','furniture','block-110192','Banner','',1),(110195,'120873','furniture','block-110192','Html_box','',2),(110196,'117093','furniture','footer','BlockBox','',2),(110197,'117094','furniture','block-110196','Copyright','',1),(110198,'117096','furniture','for_menu','BlockBox','',1),(110199,'117097','furniture','block-110198','Html_box','',1),(110200,'117098','furniture','block-110198-2','Languages','',1),(110201,'117099','furniture','for_menu','BlockBox','',3),(110202,'117100','furniture','block-110201','Html_box','',1),(110203,'117101','furniture','block-110201-2','Currencies','',1),(110204,'117102','furniture','gift','BlockBox','',1),(110205,'117103','furniture','block-110204','BlockBox','',3),(110206,'117104','furniture','block-110205','BlockBox','',1),(110207,'117105','furniture','block-110206','gift\\Card','',1),(110208,'117106','furniture','block-110205-2','gift\\Form','',2),(110209,'117107','furniture','block-110205-2','Text','',1),(110210,'117108','furniture','block-110204','info\\Title','',1),(110211,'117109','furniture','gift_card','BlockBox','',1),(110212,'117110','furniture','block-110211','BlockBox','',11),(110213,'117111','furniture','block-110212','invoice\\StoreEmail','',3),(110214,'117112','furniture','block-110212','Text','',1),(110215,'117113','furniture','block-110212','invoice\\StorePhone','',2),(110216,'117114','furniture','block-110211','Text','',8),(110217,'117115','furniture','block-110211','Text','',3),(110218,'117116','furniture','block-110211','BlockBox','',10),(110219,'117117','furniture','block-110218','Text','',1),(110220,'117118','furniture','block-110218-2','gift\\CodeView','',1),(110221,'117119','furniture','block-110211','gift\\MessageView','',7),(110222,'117120','furniture','block-110211','gift\\AmountView','',5),(110223,'117121','furniture','block-110211','Text','',6),(110224,'117123','furniture','block-110211','Logo','',1),(110225,'117124','furniture','block-110211','Text','',4),(110226,'117125','furniture','block-110211','Text','',9),(110227,'117126','furniture','gift_card_2','BlockBox','',1),(110228,'117127','furniture','block-110227','gift\\AmountView','',4),(110229,'117128','furniture','block-110227','BlockBox','',9),(110230,'117129','furniture','block-110229','Text','',1),(110231,'117130','furniture','block-110229-2','gift\\CodeView','',1),(110232,'117131','furniture','block-110227','BlockBox','',10),(110233,'117132','furniture','block-110232','invoice\\StoreEmail','',3),(110234,'117133','furniture','block-110232','Text','',1),(110235,'117134','furniture','block-110232','invoice\\StorePhone','',2),(110236,'117135','furniture','block-110227','gift\\MessageView','',6),(110237,'117136','furniture','block-110227','Text','',5),(110238,'117137','furniture','block-110227','Text','',8),(110239,'117138','furniture','block-110227','Text','',3),(110240,'117139','furniture','block-110227','Text','',7),(110241,'1638804282.8587','furniture','block-110227','Logo','',1),(110242,'117141','furniture','gift_card_2_pdf','BlockBox','',1),(110243,'117142','furniture','block-110242','BlockBox','',12),(110244,'117143','furniture','block-110243','invoice\\StoreEmail','',4),(110245,'117144','furniture','block-110243','invoice\\StorePhone','',3),(110246,'117145','furniture','block-110243','Html_box','',1),(110247,'117146','furniture','block-110242','BlockBox','',11),(110248,'117147','furniture','block-110247','Html_box','',1),(110249,'117148','furniture','block-110247-2','gift\\CodeViewPdf','',1),(110250,'117149','furniture','block-110242','BlockBox','',1),(110251,'117150','furniture','block-110250','Text','',4),(110252,'117151','furniture','block-110250','Html_box','',1),(110253,'117152','furniture','block-110250','Html_box','',2),(110254,'117153','furniture','block-110250','gift\\AmountViewPdf','',3),(110255,'117154','furniture','block-110250','gift\\MessageViewPdf','',5),(110256,'117155','furniture','block-110250','Html_box','',7),(110257,'117156','furniture','block-110250','Html_box','',6),(110258,'117157','furniture','gift_card_2_pdf','Import','',1),(110259,'117158','furniture','gift_card_pdf','BlockBox','',1),(110260,'117159','furniture','block-110259','BlockBox','',12),(110261,'117160','furniture','block-110260','invoice\\StoreEmail','',4),(110262,'117161','furniture','block-110260','invoice\\StorePhone','',3),(110263,'117162','furniture','block-110260','Html_box','',1),(110264,'117163','furniture','block-110259','BlockBox','',11),(110265,'117164','furniture','block-110264','Html_box','',1),(110266,'117165','furniture','block-110264-2','gift\\CodeViewPdf','',1),(110267,'117166','furniture','block-110259','BlockBox','',1),(110268,'117167','furniture','block-110267','Text','',5),(110269,'117169','furniture','block-110267','Html_box','',3),(110270,'117170','furniture','block-110267','gift\\AmountViewPdf','',4),(110271,'117171','furniture','block-110267','gift\\MessageViewPdf','',6),(110272,'117172','furniture','block-110267','Html_box','',8),(110273,'117173','furniture','block-110267','Html_box','',7),(110274,'1638978695.8384','furniture','block-110267','Logo','',2),(110275,'117175','furniture','gift_certificate','BlockBox','',1),(110276,'117176','furniture','block-110275','account\\ApplyCertificate','',2),(110277,'117177','furniture','block-110275','Html_box','',1),(110278,'117178','furniture','gigt_card_3','BlockBox','',1),(110279,'117179','furniture','block-110278','BlockBox','',9),(110280,'117180','furniture','block-110279','Text','',1),(110281,'117181','furniture','block-110279-2','gift\\CodeView','',1),(110282,'117182','furniture','block-110278','Text','',7),(110283,'117184','furniture','block-110278','BlockBox','',10),(110284,'117185','furniture','block-110283','Text','',1),(110285,'117186','furniture','block-110283','invoice\\StoreEmail','',3),(110286,'117187','furniture','block-110283','invoice\\StorePhone','',2),(110287,'117188','furniture','block-110278','gift\\MessageView','',6),(110288,'117189','furniture','block-110278','Text','',3),(110289,'117190','furniture','block-110278','Text','',5),(110290,'117191','furniture','block-110278','gift\\AmountView','',4),(110291,'117192','furniture','block-110278','Text','',8),(110292,'1638804328.7281','furniture','block-110278','Logo','',1),(110293,'117193','furniture','gigt_card_3_pdf','BlockBox','',1),(110294,'117194','furniture','block-110293','BlockBox','',12),(110295,'117195','furniture','block-110294','invoice\\StoreEmail','',4),(110296,'117196','furniture','block-110294','invoice\\StorePhone','',3),(110297,'117197','furniture','block-110294','Html_box','',1),(110298,'117198','furniture','block-110293','BlockBox','',11),(110299,'117199','furniture','block-110298','Html_box','',1),(110300,'117200','furniture','block-110298-2','gift\\CodeViewPdf','',1),(110301,'117201','furniture','block-110293','BlockBox','',1),(110302,'117202','furniture','block-110301','Text','',4),(110303,'117203','furniture','block-110301','Html_box','',1),(110304,'117204','furniture','block-110301','Html_box','',2),(110305,'117205','furniture','block-110301','gift\\AmountViewPdf','',3),(110306,'117206','furniture','block-110301','gift\\MessageViewPdf','',5),(110307,'117207','furniture','block-110301','Html_box','',7),(110308,'117208','furniture','block-110301','Html_box','',6),(110326,'120887','furniture','header_menu','Currencies','',2),(110327,'120888','furniture','header_menu','Languages','',1),(110328,'117224','furniture','info','BlockBox','info-content',1),(110329,'117225','furniture','block-110328','info\\DescriptionShort','',3),(110330,'117226','furniture','block-110328','info\\Content','',6),(110331,'117227','furniture','block-110328','info\\Title','',1),(110332,'117228','furniture','block-110328','info\\Image','',4),(110333,'1638467467.3028','furniture','block-110328','info\\DescriptionShort','',5),(110334,'117229','furniture','invoice','invoice\\Container','',1),(110335,'117230','furniture','block-110334','BlockBox','',4),(110336,'117231','furniture','block-110335','BlockBox','',8),(110337,'117232','furniture','block-110336','BlockBox','',1),(110338,'117233','furniture','block-110337','invoice\\ShippingMethod','',2),(110339,'117234','furniture','block-110337','Text','',1),(110340,'117235','furniture','block-110336-2','BlockBox','',1),(110341,'117236','furniture','block-110340','Text','',1),(110342,'117237','furniture','block-110340','invoice\\ShippingMethod','',2),(110343,'117238','furniture','block-110335','BlockBox','',7),(110344,'117239','furniture','block-110343','BlockBox','',2),(110345,'117240','furniture','block-110344','Text','',1),(110346,'117241','furniture','block-110344','invoice\\BillingAddress','',2),(110347,'1639659760.0392','furniture','block-110344','GiftWrapMessage\\ShowInfo','',3),(110348,'117242','furniture','block-110343-2','BlockBox','',1),(110349,'117243','furniture','block-110348','Text','',5),(110350,'117244','furniture','block-110348','invoice\\CustomerName','',2),(110351,'117245','furniture','block-110348','invoice\\CustomerPhone','',4),(110352,'117246','furniture','block-110348','Text','',1),(110353,'117247','furniture','block-110348','Text','',3),(110354,'117248','furniture','block-110348','invoice\\CustomerEmail','',6),(110355,'117249','furniture','block-110335-2','invoice\\PaymentMethod','',6),(110356,'117250','furniture','block-110335-2','Text','',5),(110357,'117251','furniture','block-110335-2','Text','',3),(110358,'117252','furniture','block-110335-2','invoice\\OrderId','',2),(110359,'117253','furniture','block-110335-2','invoice\\PaymentDate','',4),(110360,'117254','furniture','block-110335-2','invoice\\OrderBarcode','',7),(110361,'117255','furniture','block-110334','BlockBox','',8),(110362,'117256','furniture','block-110361','invoice\\StoreAddress','',8),(110363,'117257','furniture','block-110361','Text','',1),(110364,'117258','furniture','block-110361-2','Text','',2),(110365,'117260','furniture','block-110361-3','BlockBox','',3),(110366,'117261','furniture','block-110365','Text','',1),(110367,'117262','furniture','block-110365-2','invoice\\StoreEmail','',1),(110368,'117263','furniture','block-110361-3','BlockBox','',2),(110369,'117264','furniture','block-110368','Text','',1),(110370,'117265','furniture','block-110368-2','invoice\\StorePhone','',1),(110371,'117266','furniture','block-110361-3','Text','',1),(110372,'117267','furniture','block-110334','invoice\\Products','',5),(110373,'117268','furniture','block-110334','BlockBox','',7),(110374,'117269','furniture','block-110373','BlockBox','',1),(110375,'117270','furniture','block-110374','invoice\\ShippingAddress','',2),(110376,'117271','furniture','block-110374','Text','',1),(110377,'117272','furniture','block-110373-2','BlockBox','',1),(110378,'117273','furniture','block-110377','invoice\\Totals','',1),(110379,'117274','furniture','block-110334','BlockBox','',2),(110380,'117275','furniture','block-110379','Logo','',1),(110381,'117276','furniture','block-110379-2','BlockBox','',4),(110382,'117277','furniture','block-110381','Text','',1),(110383,'117278','furniture','block-110381-2','invoice\\StoreSite','',1),(110384,'117279','furniture','block-110379-2','BlockBox','',3),(110385,'117280','furniture','block-110384','Text','',1),(110386,'117281','furniture','block-110384-2','invoice\\StoreEmail','',1),(110387,'117282','furniture','block-110379-2','BlockBox','',1),(110388,'117283','furniture','block-110387','invoice\\StoreAddress','',2),(110389,'117284','furniture','block-110379-2','BlockBox','',2),(110390,'117285','furniture','block-110389','Text','',1),(110391,'117286','furniture','block-110389-2','invoice\\StorePhone','',1),(110392,'1640103567.8175','furniture','block-110334','invoice\\StructuredProducts','',6),(110393,'117287','furniture','login_account','BlockBox','',1),(110394,'117288','furniture','block-110393','Tabs','',2),(110395,'117289','furniture','block-110394-1','login\\Returning','',1),(110396,'117290','furniture','block-110394-2','BlockBox','',1),(110397,'117291','furniture','block-110396','Html_box','',1),(110398,'117292','furniture','block-110396-2','BlockBox','',1),(110399,'117293','furniture','block-110398','Html_box','',2),(110400,'117294','furniture','block-110398','login\\Register','',1),(110401,'117295','furniture','block-110393','BlockBox','',1),(110402,'117296','furniture','block-110401','Html_box','',5),(110403,'117297','furniture','block-110401','Html_box','',1),(110404,'117298','furniture','block-110401','login\\Socials','',4),(110405,'117299','furniture','login_checkout','BlockBox','',1),(110406,'117300','furniture','block-110405','BlockBox','',1),(110407,'117301','furniture','block-110406','checkout\\CreateBtn','',4),(110408,'117302','furniture','block-110406','checkout\\GuestBtn','',2),(110409,'117303','furniture','block-110406','Html_box','',3),(110410,'117304','furniture','block-110406','BlockBox','',5),(110411,'117305','furniture','block-110410','Html_box','',1),(110412,'117306','furniture','block-110410','login\\Socials','',2),(110413,'117307','furniture','block-110406','Html_box','',1),(110414,'117308','furniture','block-110406-2','login\\Returning','',2),(110415,'117309','furniture','block-110406-2','Html_box','',1),(110416,'117310','furniture','login_checkout2','BlockBox','',1),(110417,'117311','furniture','block-110416','Tabs','',4),(110418,'117312','furniture','block-110417-1','BlockBox','',1),(110419,'117313','furniture','block-110418','Html_box','',1),(110420,'117314','furniture','block-110418-2','BlockBox','',1),(110421,'117315','furniture','block-110420','login\\Guest','',1),(110422,'117316','furniture','block-110420','Html_box','',2),(110423,'117317','furniture','block-110417-2','login\\Returning','',1),(110424,'117318','furniture','block-110417-3','BlockBox','',1),(110425,'117319','furniture','block-110424','Html_box','',1),(110426,'117320','furniture','block-110424-2','BlockBox','',1),(110427,'117321','furniture','block-110426','Html_box','',2),(110428,'117322','furniture','block-110426','login\\Register','',1),(110429,'117323','furniture','block-110416','login\\Socials','',2),(110430,'117324','furniture','block-110416','Html_box','',3),(110431,'117325','furniture','block-110416','Html_box','',1),(110432,'117326','furniture','login_checkout2_q','BlockBox','',1),(110433,'117327','furniture','block-110432','Tabs','',4),(110434,'117328','furniture','block-110433-1','BlockBox','',1),(110435,'117329','furniture','block-110434','Html_box','',1),(110436,'117330','furniture','block-110434-2','quote\\FastOrder','',1),(110437,'117331','furniture','block-110433-2','login\\Returning','',1),(110438,'117332','furniture','block-110433-3','BlockBox','',1),(110439,'117333','furniture','block-110438','Html_box','',1),(110440,'117334','furniture','block-110438','Import','',2),(110441,'117335','furniture','block-110438-2','BlockBox','',1),(110442,'117336','furniture','block-110441','login\\Register','',1),(110443,'117337','furniture','block-110441','Html_box','',2),(110444,'117338','furniture','block-110432','Html_box','',3),(110445,'117339','furniture','block-110432','Html_box','',1),(110446,'117340','furniture','block-110432','login\\Socials','',2),(110447,'117341','furniture','login_checkout2_s','BlockBox','',1),(110448,'117342','furniture','block-110447','login\\Socials','',2),(110449,'117343','furniture','block-110447','Html_box','',3),(110450,'117344','furniture','block-110447','Tabs','',4),(110451,'117345','furniture','block-110450-1','BlockBox','',1),(110452,'117346','furniture','block-110451','Html_box','',1),(110453,'117347','furniture','block-110451-2','quote\\FastOrder','',1),(110454,'117348','furniture','block-110450-2','login\\Returning','',1),(110455,'117349','furniture','block-110450-3','BlockBox','',1),(110456,'117350','furniture','block-110455','Html_box','',1),(110457,'117351','furniture','block-110455-2','BlockBox','',1),(110458,'117352','furniture','block-110457','login\\Register','',1),(110459,'117353','furniture','block-110457','Html_box','',2),(110460,'117354','furniture','block-110447','Html_box','',1),(110461,'117355','furniture','login_checkout_q','BlockBox','',1),(110462,'117356','furniture','block-110461','BlockBox','',1),(110463,'117357','furniture','block-110462','BlockBox','',5),(110464,'117358','furniture','block-110463','Html_box','',1),(110465,'117359','furniture','block-110463','login\\Socials','',2),(110466,'117360','furniture','block-110462','checkout\\GuestBtn','',2),(110467,'117361','furniture','block-110462','checkout\\CreateBtn','',4),(110468,'117362','furniture','block-110462','Html_box','',3),(110469,'117363','furniture','block-110462','Html_box','',1),(110470,'117364','furniture','block-110462-2','Html_box','',1),(110471,'117365','furniture','block-110462-2','login\\Returning','',2),(110472,'117366','furniture','login_checkout_s','BlockBox','',1),(110473,'117367','furniture','block-110472','BlockBox','',1),(110474,'117368','furniture','block-110473','Html_box','',1),(110475,'117369','furniture','block-110473','checkout\\GuestBtn','',2),(110476,'117370','furniture','block-110473','checkout\\CreateBtn','',4),(110477,'117371','furniture','block-110473','Html_box','',3),(110478,'117372','furniture','block-110473','BlockBox','',5),(110479,'117373','furniture','block-110478','Html_box','',1),(110480,'117374','furniture','block-110478','login\\Socials','',2),(110481,'117375','furniture','block-110473-2','Html_box','',1),(110482,'117376','furniture','block-110473-2','login\\Returning','',2),(110483,'117377','furniture','logoff','BlockBox','',1),(110484,'117378','furniture','block-110483','Html_box','',1),(110485,'117379','furniture','logoff_forever','BlockBox','',1),(110486,'117380','furniture','block-110485','Html_box','',1),(110487,'1683019393.8433','furniture','main','BlockBox','',1),(110488,'1683018455.4659','furniture','block-110487','Banner','',1),(110489,'1703584951.8917','furniture','main','BlockBox','',5),(110490,'1705058746.79624','furniture','main','BlockBox','main-content',3),(110491,'1705058746.808883','furniture','block-110490','BlockBox','',1),(110492,'1705058746.898727','furniture','block-110491','Banner','',2),(110493,'1705058747.047682','furniture','block-110490','BlockBox','',2),(110494,'1705058747.07661','furniture','block-110493','Html_box','',1),(110495,'1705058747.089734','furniture','block-110493-2','Html_box','',1),(110496,'1705058747.092420','furniture','block-110493-3','Html_box','',1),(110497,'1705058747.094689','furniture','block-110490','BlockBox','',3),(110498,'1705058747.096170','furniture','block-110497','NewProducts','8',3),(110499,'1705058747.101394','furniture','block-110497','Html_box','',2),(110500,'1705058747.103997','furniture','block-110490','BlockBox','',4),(110501,'1705058747.131252','furniture','block-110500','Banner','',2),(110502,'1705058747.202374','furniture','block-110500','Html_box','',1),(110504,'117394','furniture','manufacturers','BlockBox','',1),(110505,'117395','furniture','block-110504','Html_box','',1),(110506,'117396','furniture','block-110504','Brands','',2),(110507,'117397','furniture','messages-index','BlockBox','',1),(110508,'117398','furniture','block-110507','BlockBox','',1),(110509,'117399','furniture','block-110508','BlockBox','',1),(110510,'117400','furniture','block-110509','Messages\\Sidebar','',1),(110511,'117401','furniture','block-110508-2','Messages\\Listing','',1),(110512,'117402','furniture','messages-new','BlockBox','',1),(110513,'117403','furniture','block-110512','BlockBox','',1),(110514,'117404','furniture','block-110513','Messages\\Sidebar','',1),(110515,'117405','furniture','block-110513-2','Messages\\NewMessage','',1),(110516,'117406','furniture','messages-view','BlockBox','',1),(110517,'117407','furniture','block-110516','BlockBox','',1),(110518,'117408','furniture','block-110517','Messages\\Sidebar','',1),(110519,'117409','furniture','block-110517-2','Messages\\Message','',1),(110520,'117410','furniture','my_password','BlockBox','',1),(110521,'117411','furniture','block-110520','BlockBox','',1),(110522,'117412','furniture','block-110521','WidgetsAria','',1),(110542,'117413','furniture','block-110521-2','account\\ChangePassword','',2),(110543,'117414','furniture','block-110521-2','Html_box','',1),(110544,'117415','furniture','need_login','BlockBox','',1),(110545,'117416','furniture','block-110544','Tabs','',2),(110546,'117417','furniture','block-110545-1','login\\Returning','',1),(110547,'117418','furniture','block-110545-2','BlockBox','',1),(110548,'117419','furniture','block-110547','Html_box','',2),(110549,'117420','furniture','block-110547-2','BlockBox','',1),(110550,'117421','furniture','block-110549','login\\Register','',1),(110551,'117422','furniture','block-110549','Html_box','',2),(110552,'117423','furniture','block-110544','BlockBox','',1),(110553,'117424','furniture','new-topic','BlockBox','',1),(110554,'117425','furniture','block-110553','Breadcrumb','',2),(110555,'117426','furniture','block-110553','Communication\\NewTopic','',3),(110556,'117427','furniture','block-110553','Html_box','',1),(110557,'117428','furniture','nnnn','BlockBox','',1),(110558,'117429','furniture','block-110557','catalog\\Title','',1),(110559,'117430','furniture','block-110557','BlockBox','',2),(110560,'117431','furniture','block-110559','Filters','',1),(110561,'117432','furniture','block-110559-2','Listing','',5),(110562,'117433','furniture','block-110559-2','catalog\\Image','',1),(110563,'117434','furniture','block-110559-2','BlockBox','',6),(110564,'117435','furniture','block-110563','catalog\\CountsItems','',1),(110565,'117436','furniture','block-110563-2','catalog\\Paging','',1),(110566,'117437','furniture','block-110559-2','catalog\\ImageMapCategory','',3),(110567,'117438','furniture','block-110559-2','Categories','',2),(110568,'117439','furniture','block-110559-2','BlockBox','',4),(110569,'117440','furniture','block-110568','catalog\\ListingLook','',1),(110570,'117441','furniture','block-110568','catalog\\ItemsOnPage','',4),(110571,'117442','furniture','block-110568','catalog\\CompareButton','',2),(110572,'117443','furniture','block-110568','catalog\\Sorting','',3),(110573,'117444','furniture','no-logged','BlockBox','',1),(110574,'117445','furniture','block-110573','Communication\\NewTopic','',2),(110575,'117446','furniture','block-110573','Html_box','',1),(110576,'117447','furniture','no_filters','BlockBox','catalog-content',1),(110577,'117448','furniture','block-110576','BlockBox','',4),(110578,'117449','furniture','block-110577','catalog\\CountsItems','',1),(110579,'117450','furniture','block-110577-2','catalog\\Paging','',1),(110580,'117451','furniture','block-110576','Listing','',3),(110581,'117452','furniture','block-110576','catalog\\Title','',1),(110582,'117453','furniture','block-110576','catalog\\B2bAddButton','',5),(110583,'117454','furniture','block-110576','BlockBox','catalog-features',2),(110584,'117455','furniture','block-110583','BlockBox','',2),(110585,'117456','furniture','block-110584','HeaderStock','',5),(110586,'117457','furniture','block-110584','catalog\\ListingLook','',1),(110587,'117458','furniture','block-110584','catalog\\CompareButton','',2),(110588,'117459','furniture','block-110584','catalog\\ItemsOnPage','',4),(110589,'117460','furniture','block-110584','catalog\\Sorting','',3),(110590,'117461','furniture','block-110583','catalog\\Image','',1),(110674,'117507','furniture','order_pay','BlockBox','',1),(110675,'117508','furniture','block-110674','BlockBox','',1),(110676,'117509','furniture','block-110675','WidgetsAria','',1),(110696,'117510','furniture','block-110675-2','account\\OrderProducts','',4),(110697,'117511','furniture','block-110675-2','BlockBox','',2),(110698,'117512','furniture','block-110697','BlockBox','',1),(110699,'117513','furniture','block-110698','Html_box','',1),(110700,'117514','furniture','block-110698','account\\OrderData','',2),(110701,'117515','furniture','block-110697','BlockBox','',4),(110702,'117516','furniture','block-110701','account\\OrderData','',2),(110703,'117517','furniture','block-110701','Html_box','',1),(110704,'117518','furniture','block-110697-2','BlockBox','',1),(110705,'117519','furniture','block-110704','Html_box','',1),(110706,'117520','furniture','block-110704','account\\OrderData','',2),(110707,'117521','furniture','block-110697-2','BlockBox','',2),(110708,'117522','furniture','block-110707','account\\OrderData','',2),(110709,'117523','furniture','block-110707','Html_box','',1),(110710,'117524','furniture','block-110697-3','BlockBox','',2),(110711,'117525','furniture','block-110710','Html_box','',1),(110712,'117526','furniture','block-110710','account\\OrderData','',2),(110713,'117527','furniture','block-110697-3','BlockBox','',1),(110714,'117528','furniture','block-110713','account\\OrderData','',2),(110715,'117529','furniture','block-110713','Html_box','',1),(110716,'117530','furniture','block-110675-2','UpdateAndPay\\PayForm','',6),(110717,'117531','furniture','block-110675-2','Html_box','',3),(110718,'117532','furniture','block-110675-2','account\\OrderHeading','',1),(110719,'117533','furniture','block-110675-2','account\\OrderSubTotals','',5),(110720,'117534','furniture','packingslip','invoice\\Container','',2),(110721,'117535','furniture','block-110720','BlockBox','',2),(110722,'117536','furniture','block-110721','Logo','',1),(110723,'117537','furniture','block-110721-2','BlockBox','',3),(110724,'117538','furniture','block-110723','Text','',2),(110725,'117539','furniture','block-110723-2','invoice\\StoreEmail','',1),(110726,'117540','furniture','block-110721-2','BlockBox','',2),(110727,'117541','furniture','block-110726','Text','',2),(110728,'117542','furniture','block-110726-2','invoice\\StorePhone','',1),(110729,'117543','furniture','block-110721-2','BlockBox','',1),(110730,'117544','furniture','block-110729','invoice\\StoreAddress','',1),(110731,'117545','furniture','block-110721-2','BlockBox','',4),(110732,'117546','furniture','block-110731','Text','',2),(110733,'117547','furniture','block-110731-2','invoice\\StoreSite','',1),(110734,'117548','furniture','block-110720','packingslip\\Products','',5),(110735,'117549','furniture','block-110720','BlockBox','',6),(110736,'117550','furniture','block-110735','invoice\\StoreAddress','',2),(110737,'117551','furniture','block-110735','Text','',1),(110738,'117552','furniture','block-110720','BlockBox','',3),(110739,'117553','furniture','block-110738','BlockBox','',2),(110740,'117554','furniture','block-110739','BlockBox','',1),(110741,'117555','furniture','block-110740','invoice\\ShippingAddress','',2),(110742,'117556','furniture','block-110740','Text','',1),(110743,'117557','furniture','block-110739-2','BlockBox','',1),(110744,'117558','furniture','block-110743','Text','',1),(110745,'117559','furniture','block-110743','invoice\\CustomerName','',2),(110746,'117560','furniture','block-110743','invoice\\CustomerEmail','',6),(110747,'117561','furniture','block-110743','Text','',3),(110748,'117562','furniture','block-110743','invoice\\CustomerPhone','',4),(110749,'117563','furniture','block-110743','Text','',5),(110750,'117564','furniture','block-110738','BlockBox','',3),(110751,'117565','furniture','block-110750','BlockBox','',1),(110752,'117566','furniture','block-110751','invoice\\ShippingMethod','',2),(110753,'117567','furniture','block-110751','Text','',1),(110754,'117568','furniture','block-110750-2','BlockBox','',1),(110755,'117569','furniture','block-110754','invoice\\ShippingMethod','',2),(110756,'117570','furniture','block-110754','Text','',1),(110757,'117571','furniture','block-110738-2','invoice\\AddressQrcode','',1),(110758,'1639660991.8692','furniture','block-110720','Neighbour\\PackingSlipInfo','',1),(110759,'1639661081.5616','furniture','block-110720','Neighbour\\PackingSlipInfo','',4),(110760,'117572','furniture','password_forgotten','BlockBox','',1),(110761,'117573','furniture','block-110760','BlockBox','',2),(110762,'1638807246.6206','furniture','block-110761','Html_box','',1),(110763,'117574','furniture','block-110761-2','Html_box','',1),(110764,'117575','furniture','block-110761-2','login\\PasswordForgotten','',2),(110765,'117576','furniture','block-110760','Html_box','',1),(110766,'117577','furniture','pdf','invoice\\Container','',1),(110767,'117578','furniture','block-110766','BlockBox','',1),(110768,'117579','furniture','block-110767','BlockBox','',1),(110769,'117580','furniture','block-110768','BlockBox','',1),(110770,'117581','furniture','block-110769','pdf\\ProductElement','',1),(110771,'117582','furniture','block-110768','BlockBox','',2),(110772,'117583','furniture','block-110771','pdf\\ProductElement','',1),(110773,'117584','furniture','block-110771-2','pdf\\ProductElement','',2),(110774,'117585','furniture','block-110771-2','pdf\\ProductElement','',1),(110775,'117586','furniture','block-110767-2','BlockBox','',1),(110776,'117587','furniture','block-110775','BlockBox','',2),(110777,'117588','furniture','block-110776','pdf\\ProductElement','',1),(110778,'117589','furniture','block-110776-2','pdf\\ProductElement','',2),(110779,'117590','furniture','block-110776-2','pdf\\ProductElement','',1),(110780,'117591','furniture','block-110775','BlockBox','',1),(110781,'117592','furniture','block-110780','pdf\\ProductElement','',1),(110782,'117593','furniture','pdf_category','pdf\\CategoryName','',2),(110783,'117594','furniture','pdf_category','pdf\\CategoryImage','',1),(110784,'117595','furniture','pdf_cover','invoice\\Container','',1),(110785,'117596','furniture','block-110784','Logo','',1),(110786,'117597','furniture','block-110784','Text','',3),(110787,'117598','furniture','pdf_footer','BlockBox','',1),(110788,'117599','furniture','block-110787-2','pdf\\PageNumber','',1),(110789,'117600','furniture','pdf_header','pdf\\CategoryName','',1),(110790,'117601','furniture','personal_catalog','BlockBox','',1),(110791,'117602','furniture','block-110790','BlockBox','',1),(110792,'117603','furniture','block-110791','WidgetsAria','',1),(110812,'117604','furniture','block-110791-2','Html_box','',1),(110813,'117606','furniture','block-110791-2','account\\PersonalCatalog','',2),(110814,'117607','furniture','points_earnt_history','BlockBox','',1),(110815,'117608','furniture','block-110814','Html_box','',1),(110816,'117609','furniture','block-110814','account\\PointsEarntHistory','',2),(110817,'117610','furniture','posts','BlockBox','',1),(110818,'117611','furniture','block-110817','Breadcrumb','',2),(110819,'117612','furniture','block-110817','Html_box','',1),(110820,'117613','furniture','block-110817','Communication\\Post','',3),(110821,'1683109599.245213','furniture','product','BlockBox','',1),(110822,'1683109599.255978','furniture','block-110821','BlockBox','',4),(110823,'1683109599.25889','furniture','block-110822','BlockBox','product-image',1),(110824,'1683109599.25915','furniture','block-110823','product\\Images','',2),(110825,'1683109599.2678','furniture','block-110823','Promotions\\widgets\\PromotionIcons','',1),(110826,'1683109599.261153','furniture','block-110823','product\\PropertiesIcons','',3),(110827,'1683109599.261571','furniture','block-110823','ProductDesigner\\Designer','',6),(110828,'1683109599.261910','furniture','block-110823','ProductDesigner\\Button','',5),(110829,'1683109599.262388','furniture','block-110823','ProductDesigner\\Picture','',4),(110830,'1683109599.263173','furniture','block-110822-2','BlockBox','product-side',3),(110831,'1683109599.264430','furniture','block-110830','BlockBox','',1),(110832,'1683109599.26556','furniture','block-110831','product\\DescriptionShort','',2),(110833,'1683109599.26782','furniture','block-110831','product\\Model','',1),(110834,'1683109599.267742','furniture','block-110831','Html_box','',3),(110835,'1683109599.27259','furniture','block-110831','product\\Groups','',6),(110836,'1683109599.272734','furniture','block-110830','BlockBox','',3),(110837,'1683109599.273896','furniture','block-110836','Promotions\\widgets\\PromotionIconsDesc','',2),(110838,'1683109599.292170','furniture','block-110830-2','BlockBox','',1),(110839,'1683109599.294458','furniture','block-110838','BlockBox','',1),(110840,'1683109599.297231','furniture','block-110839','product\\SaleEnds','',2),(110841,'1683109599.30758','furniture','block-110839','BlockBox','',3),(110842,'1683109599.30990','furniture','block-110841','product\\QuantityDiscounts','',5),(110843,'1683109599.310437','furniture','block-110841','product\\ButtonsQuote','',8),(110844,'1683109599.313121','furniture','block-110841','product\\Price','',3),(110845,'1683109599.315738','furniture','block-110841','product\\Quantity','',4),(110846,'1683109599.322597','furniture','block-110841','product\\Buttons','',6),(110847,'1683109599.325422','furniture','block-110841','product\\ButtonsSample','',9),(110848,'1683109599.326754','furniture','block-110841','product\\PersonalCatalogButton','',7),(110849,'1683109599.329949','furniture','block-110841','product\\Stock','',2),(110850,'1683109599.331551','furniture','block-110841','product\\Attributes','',1),(110851,'1683109599.334184','furniture','block-110838','BlockBox','',3),(110852,'1683109599.335484','furniture','block-110851','product\\BonusPoints','',1),(110853,'1683109599.33824','furniture','block-110821','product\\Name','',2),(110854,'1683109599.338931','furniture','block-110821','Breadcrumb','',1),(110855,'1683109599.343489','furniture','block-110821','BlockBox','',3),(110856,'1683109599.345520','furniture','block-110855','product\\Rating','',2),(110857,'1683109599.348715','furniture','block-110855','Html_box','',2),(110858,'1683109648.23241','furniture','product','BlockBox','',3),(110859,'1683109648.239129','furniture','block-110858','product\\InBundles','',3),(110860,'1683109648.244334','furniture','block-110858','product\\Bundle','',2),(110861,'1683109666.978945','furniture','product','BlockBox','product-content',4),(110862,'1683109666.985380','furniture','block-110861','BlockBox','',1),(110863,'1683109666.986680','furniture','block-110862','Tabs','',3),(110864,'1683109666.994221','furniture','block-110863-1','product\\Description','',2),(110865,'1683109666.99570','furniture','block-110863-1','product\\Properties','',1),(110866,'1683109666.999888','furniture','block-110863-2','InfoPage','',1),(110867,'1683109667.001793','furniture','block-110861','Tabs','',3),(110868,'1683109667.003150','furniture','block-110867-1','product\\AlsoPurchased','10',1),(110869,'1683109667.007130','furniture','block-110867-2','ViewedProducts','4',1),(110870,'1683109667.010748','furniture','block-110861','BlockBox','',2),(110871,'1683109667.01353','furniture','block-110870','Html_box','',1),(110872,'1683109667.014986','furniture','block-110870-2','Html_box','',1),(110873,'1683109667.016871','furniture','block-110870-3','Html_box','',1),(110874,'1683109667.01857','furniture','block-110861','BlockBox','',4),(110875,'1683109667.019642','furniture','block-110874','product\\Reviews','',1),(110876,'1707919218.1062','furniture','block-110861','UpSell\\widgets\\CrossSellProducts','',5),(110877,'117655','furniture','product-bottom','product\\Properties','',1),(110878,'117656','furniture','product-tabs','product\\Reviews','',2),(110879,'117657','furniture','product-tabs','product\\Description','',1),(110880,'117658','furniture','product-top-left','product\\Images','',1),(110881,'117659','furniture','product-top-right','product\\Price','',2),(110882,'117660','furniture','product-top-right','product\\Quantity','',5),(110883,'117661','furniture','product-top-right','product\\Quantity','',6),(110884,'117662','furniture','product-top-right','product\\Attributes','',3),(110885,'117663','furniture','product-top-right','product\\Name','',1),(110886,'117664','furniture','product-top-right','product\\Buttons','',6),(110887,'117665','furniture','productListing','BlockBox','listing-item',1),(110888,'120921','furniture','block-110887','BlockBox','',1),(110889,'120896','furniture','block-110888','BlockBox','',2),(110890,'117677','furniture','block-110889','productListing\\compare','',3),(110891,'120882','furniture','block-110889','productListing\\personalCatalog','',2),(110892,'120895','furniture','block-110889','productListing\\viewButton','',1),(110893,'120919','furniture','block-110888','BlockBox','',1),(110894,'117667','furniture','block-110893','productListing\\bonusPoints','',3),(110895,'117668','furniture','block-110893','productListing\\description','',7),(110896,'117670','furniture','block-110893','productListing\\rating','',8),(110897,'117671','furniture','block-110893','productListing\\image','',1),(110898,'117673','furniture','block-110893','productListing\\price','',5),(110899,'117675','furniture','block-110893','productListing\\name','',6),(110900,'117676','furniture','block-110893','productListing\\stock','',4),(110901,'120863','furniture','block-110893','productListing\\ratingCounts','',9),(110902,'1639645717.6681','furniture','block-110893','productListing\\productGroup','',2),(110903,'117678','furniture','products','BlockBox','catalog-content',1),(110904,'117679','furniture','block-110903','BlockBox','catalog-side',4),(110905,'117680','furniture','block-110904','Filters','',3),(110906,'117681','furniture','block-110904','HeaderStock','',4),(110907,'120916','furniture','block-110904','BlockBox','',1),(110908,'120918','furniture','block-110907','BlockBox','',3),(110909,'120884','furniture','block-110908','Menu','LeftCategories',2),(110910,'120917','furniture','block-110908','Html_box','',1),(110911,'117682','furniture','block-110904-2','catalog\\B2bAddButton','',5),(110912,'117683','furniture','block-110904-2','BlockBox','catalog-features',2),(110913,'117684','furniture','block-110912','catalog\\Sorting','',3),(110914,'117685','furniture','block-110912','catalog\\ListingLook','',1),(110915,'117686','furniture','block-110912','catalog\\ItemsOnPage','',4),(110916,'117687','furniture','block-110912','catalog\\CompareButton','',2),(110917,'117688','furniture','block-110904-2','BlockBox','',6),(110918,'117689','furniture','block-110917','catalog\\CountsItems','',1),(110919,'117690','furniture','block-110917-2','catalog\\Paging','',1),(110920,'117691','furniture','block-110904-2','Listing','',4),(110921,'120912','furniture','block-110904-2','BlockBox','',3),(110922,'120913','furniture','block-110921','catalog\\CountsItems','',1),(110923,'120914','furniture','block-110921-2','catalog\\Paging','',1),(110924,'1639760443.0645','furniture','block-110904-2','catalog\\AdditionalImages','',1),(110925,'117692','furniture','block-110903','catalog\\Title','',2),(110926,'117693','furniture','block-110903','BlockBox','',3),(110927,'117694','furniture','block-110926','catalog\\Image','',2),(110928,'1639415554.3073','furniture','block-110926','product\\WeddingRegistryButton','',3),(110929,'121018','furniture','products','Compare','',2),(110930,'117695','furniture','products-list','packingslip\\AllProductsList','',2),(110931,'117696','furniture','promotions','BlockBox','info-content',1),(110932,'117697','furniture','block-110931','promotions\\PromoList','',2),(110933,'117698','furniture','block-110931','Html_box','',1),(110934,'117699','furniture','purchase','invoice\\Container','',1),(110935,'117700','furniture','block-110934','invoice\\Products','',3),(110936,'117701','furniture','block-110934','BlockBox','',5),(110937,'117702','furniture','block-110936','Text','',1),(110938,'117703','furniture','block-110936','invoice\\StoreAddress','',8),(110939,'117704','furniture','block-110936-2','Text','',2),(110940,'117705','furniture','block-110936-2','Logo','',1),(110941,'117706','furniture','block-110936-3','BlockBox','',3),(110942,'117707','furniture','block-110941','Text','',1),(110943,'117708','furniture','block-110941-2','invoice\\StoreEmail','',1),(110944,'117709','furniture','block-110936-3','Text','',1),(110945,'117710','furniture','block-110936-3','BlockBox','',2),(110946,'117711','furniture','block-110945','Text','',1),(110947,'117712','furniture','block-110945-2','invoice\\StorePhone','',1),(110948,'117713','furniture','block-110934','BlockBox','',1),(110949,'117714','furniture','block-110948','Logo','',1),(110950,'117715','furniture','block-110948-2','BlockBox','',2),(110951,'117716','furniture','block-110950','Text','',1),(110952,'117717','furniture','block-110950-2','invoice\\StorePhone','',1),(110953,'117718','furniture','block-110948-2','BlockBox','',4),(110954,'117719','furniture','block-110953','Text','',1),(110955,'117720','furniture','block-110953-2','invoice\\StoreSite','',1),(110956,'117721','furniture','block-110948-2','BlockBox','',1),(110957,'117722','furniture','block-110956','invoice\\StoreAddress','',1),(110958,'117723','furniture','block-110948-2','BlockBox','',3),(110959,'117724','furniture','block-110958','Text','',1),(110960,'117725','furniture','block-110958-2','invoice\\StoreEmail','',1),(110961,'117726','furniture','block-110934','BlockBox','',2),(110962,'117727','furniture','block-110961','BlockBox','',7),(110963,'117728','furniture','block-110962','BlockBox','',1),(110964,'117729','furniture','block-110963','invoice\\BillingAddress','',2),(110965,'117730','furniture','block-110963','Text','',1),(110966,'117731','furniture','block-110962-2','BlockBox','',1),(110967,'117732','furniture','block-110966','invoice\\CustomerEmail','',6),(110968,'117733','furniture','block-110966','Text','',5),(110969,'117734','furniture','block-110966','invoice\\CustomerPhone','',4),(110970,'117735','furniture','block-110966','invoice\\CustomerName','',2),(110971,'117736','furniture','block-110966','Text','',3),(110972,'117737','furniture','block-110966','Text','',1),(110973,'117738','furniture','block-110961-2','invoice\\OrderId','',1),(110974,'117739','furniture','block-110961-2','Text','',2),(110975,'117740','furniture','block-110961-2','invoice\\PaymentDate','',3),(110976,'117741','furniture','block-110934','BlockBox','',4),(110977,'117742','furniture','block-110976','BlockBox','',1),(110978,'117743','furniture','block-110977','invoice\\ShippingAddress','',2),(110979,'117744','furniture','block-110977','Text','',1),(110983,'117745','furniture','quotations','BlockBox','',1),(110984,'117746','furniture','block-110983','BlockBox','',1),(110985,'117747','furniture','block-110984','WidgetsAria','',1),(111005,'117748','furniture','block-110984-2','Html_box','',1),(111006,'117749','furniture','block-110984-2','Quotations\\QuotationsHistory','',2),(111007,'117750','furniture','quotation_info','BlockBox','',1),(111008,'117751','furniture','block-111007','BlockBox','',1),(111009,'117752','furniture','block-111008','WidgetsAria','',1),(111029,'117753','furniture','block-111008-2','BlockBox','',5),(111030,'117754','furniture','block-111029','BlockBox','',1),(111031,'117755','furniture','block-111030','Quotations\\QuotationData','',2),(111032,'117756','furniture','block-111030','Html_box','',1),(111033,'117757','furniture','block-111029','BlockBox','',4),(111034,'117758','furniture','block-111033','Html_box','',1),(111035,'117759','furniture','block-111033','Quotations\\QuotationData','',2),(111036,'117760','furniture','block-111029-2','BlockBox','',2),(111037,'117761','furniture','block-111036','Html_box','',1),(111038,'117762','furniture','block-111036','Quotations\\QuotationData','',2),(111039,'117763','furniture','block-111029-2','BlockBox','',1),(111040,'117764','furniture','block-111039','Html_box','',1),(111041,'117765','furniture','block-111039','Quotations\\QuotationData','',2),(111042,'117766','furniture','block-111029-3','BlockBox','',1),(111043,'117767','furniture','block-111042','Quotations\\QuotationData','',2),(111044,'117768','furniture','block-111042','Html_box','',1),(111045,'117769','furniture','block-111029-3','BlockBox','',2),(111046,'117770','furniture','block-111045','Quotations\\QuotationData','',2),(111047,'117771','furniture','block-111045','Html_box','',1),(111048,'117772','furniture','block-111008-2','Html_box','',6),(111049,'117773','furniture','block-111008-2','Quotations\\QuotationHistory','',10),(111050,'117774','furniture','block-111008-2','Html_box','',9),(111051,'117775','furniture','block-111008-2','Quotations\\QuotationProducts','',7),(111052,'117776','furniture','block-111008-2','Quotations\\QuotationSubTotal','',8),(111053,'117777','furniture','block-111008-2','BlockBox','',12),(111054,'117778','furniture','block-111053','account\\AccountLink','',1),(111055,'117779','furniture','block-111008-2','Html_box','',4),(111056,'117780','furniture','quote','BlockBox','',1),(111057,'117781','furniture','block-111056','cart\\CartTabs','',1),(111058,'117782','furniture','block-111057','BlockBox','',1),(111059,'117783','furniture','block-111058','quote\\Products','',1),(111060,'117784','furniture','block-111058-2','BlockBox','',1),(111061,'117785','furniture','block-111060','BlockBox','',1),(111062,'117786','furniture','block-111061','quote\\CheckoutBtn','',2),(111063,'117787','furniture','block-111057','Quotations\\QuotationSubTotal','',2),(111088,'117793','furniture','reviews','BlockBox','info-content',1),(111089,'117794','furniture','block-111088','reviews\\Heading','',1),(111090,'117795','furniture','block-111088','reviews\\Content','',2),(111091,'117796','furniture','rma_document','invoice\\Container','',1),(111092,'117797','furniture','block-111091','BlockBox','',1),(111093,'117798','furniture','block-111092','BlockBox','',1),(111094,'117799','furniture','block-111093','BlockBox','',2),(111095,'117800','furniture','block-111094','Html_box','',1),(111096,'117801','furniture','block-111094-2','Html_box','',1),(111097,'117802','furniture','block-111093','BlockBox','',5),(111098,'117803','furniture','block-111097','Html_box','',1),(111099,'117804','furniture','block-111097-2','Html_box','',1),(111100,'117805','furniture','block-111093','BlockBox','',4),(111101,'117806','furniture','block-111100','Html_box','',1),(111102,'117807','furniture','block-111100-2','Html_box','',1),(111103,'117808','furniture','block-111093','BlockBox','',3),(111104,'117809','furniture','block-111103','Html_box','',1),(111105,'117810','furniture','block-111103-2','Html_box','',1),(111106,'117811','furniture','block-111093','BlockBox','',1),(111107,'117812','furniture','block-111106','Html_box','',1),(111108,'117813','furniture','block-111106','Html_box','',2),(111109,'117814','furniture','block-111092-2','BlockBox','',1),(111110,'117815','furniture','block-111109','Html_box','',2),(111111,'117816','furniture','block-111109','Logo','',1),(111112,'117817','furniture','block-111092-2','BlockBox','',2),(111113,'117818','furniture','block-111112','BlockBox','',5),(111114,'117819','furniture','block-111113','BlockBox','',1),(111115,'117820','furniture','block-111114','Html_box','',1),(111116,'117821','furniture','block-111114-2','Rma\\DocumentData','',1),(111117,'117822','furniture','block-111113-2','BlockBox','',1),(111118,'117823','furniture','block-111117','Html_box','',1),(111119,'117824','furniture','block-111117-2','Rma\\DocumentData','',1),(111120,'117825','furniture','block-111112','BlockBox','',4),(111121,'117826','furniture','block-111120','BlockBox','',1),(111122,'117827','furniture','block-111121','Html_box','',1),(111123,'117828','furniture','block-111121-2','Rma\\DocumentData','',1),(111124,'117829','furniture','block-111120-2','BlockBox','',1),(111125,'117830','furniture','block-111124','Html_box','',1),(111126,'117831','furniture','block-111124-2','Rma\\DocumentData','',1),(111127,'117832','furniture','block-111112','BlockBox','',3),(111128,'117833','furniture','block-111127','BlockBox','',1),(111129,'117834','furniture','block-111128','Html_box','',1),(111130,'117835','furniture','block-111128-2','Rma\\DocumentData','',1),(111131,'117836','furniture','block-111127-2','BlockBox','',1),(111132,'117837','furniture','block-111131','Html_box','',1),(111133,'117838','furniture','block-111131-2','Rma\\DocumentData','',1),(111134,'117839','furniture','block-111112','BlockBox','',2),(111135,'117840','furniture','block-111134','Html_box','',1),(111136,'117841','furniture','block-111134-2','Rma\\DocumentData','',1),(111137,'117842','furniture','block-111112','BlockBox','',1),(111138,'117843','furniture','block-111137','BlockBox','',1),(111139,'117844','furniture','block-111138','Html_box','',1),(111140,'117845','furniture','block-111138-2','Rma\\DocumentData','',1),(111141,'117846','furniture','block-111137-2','BlockBox','',1),(111142,'117847','furniture','block-111141','Html_box','',1),(111143,'117848','furniture','block-111141-2','Rma\\DocumentData','',1),(111144,'117849','furniture','block-111092-2','BlockBox','',3),(111145,'117850','furniture','block-111144','BlockBox','',1),(111146,'117851','furniture','block-111145','Html_box','',1),(111147,'117852','furniture','block-111145-2','Rma\\DocumentData','',1),(111148,'117853','furniture','block-111144-2','BlockBox','',1),(111149,'117854','furniture','block-111148','Html_box','',1),(111150,'117855','furniture','block-111148-2','Rma\\DocumentData','',1),(111151,'117856','furniture','block-111091','BlockBox','',2),(111152,'117857','furniture','block-111151','Html_box','',1),(111153,'117858','furniture','block-111151','Rma\\Products','',2),(111154,'117859','furniture','block-111091','BlockBox','',3),(111155,'117860','furniture','block-111154','BlockBox','',1),(111156,'117861','furniture','block-111155','BlockBox','',1),(111157,'117862','furniture','block-111156','BlockBox','',5),(111158,'117863','furniture','block-111157','Html_box','',1),(111159,'117864','furniture','block-111157-2','invoice\\StoreAddress','',2),(111160,'117865','furniture','block-111157-2','Html_box','',1),(111161,'117866','furniture','block-111156','BlockBox','',4),(111162,'117867','furniture','block-111161','Html_box','',1),(111163,'117868','furniture','block-111161-2','Html_box','',1),(111164,'117869','furniture','block-111156','BlockBox','',2),(111165,'117870','furniture','block-111164','Html_box','',1),(111166,'117871','furniture','block-111164-2','Html_box','',1),(111167,'117872','furniture','block-111156','BlockBox','',1),(111168,'117873','furniture','block-111167','Html_box','',1),(111169,'117874','furniture','block-111156','BlockBox','',3),(111170,'117875','furniture','block-111169','Html_box','',1),(111171,'117876','furniture','block-111169-2','Html_box','',1),(111172,'117877','furniture','block-111156','BlockBox','',6),(111173,'117878','furniture','block-111172','Html_box','',1),(111174,'117879','furniture','block-111155-2','BlockBox','',1),(111175,'117880','furniture','block-111174','BlockBox','',1),(111176,'117881','furniture','block-111175','BlockBox','',1),(111177,'117882','furniture','block-111176','Rma\\DocumentData','',2),(111178,'117883','furniture','block-111176-3','BlockBox','',1),(111179,'117884','furniture','block-111178','Html_box','',1),(111180,'117885','furniture','block-111178-2','Rma\\DocumentData','',1),(111181,'117886','furniture','block-111175','BlockBox','',2),(111182,'117887','furniture','block-111181-2','invoice\\StoreAddress','',1),(111183,'117888','furniture','block-111155-2','BlockBox','',2),(111184,'117889','furniture','block-111183','Html_box','',1),(111185,'117890','furniture','block-111183','Html_box','',2),(111186,'117891','furniture','block-111183','Html_box','',3),(111187,'117892','furniture','block-111183','Html_box','',4),(111188,'117893','furniture','block-111183','Html_box','',5),(111189,'117894','furniture','block-111155-2','BlockBox','',4),(111190,'117895','furniture','block-111189','Html_box','',1),(111191,'117896','furniture','block-111189-2','Html_box','',1),(111192,'117897','furniture','block-111189-3','BlockBox','',1),(111193,'117898','furniture','block-111192','Html_box','',1),(111194,'117899','furniture','block-111192-2','Html_box','',1),(111195,'117900','furniture','block-111155-2','BlockBox','',3),(111196,'117901','furniture','block-111195','Html_box','',1),(111197,'117902','furniture','block-111195-2','Html_box','',1),(111198,'117903','furniture','block-111195-3','BlockBox','',1),(111199,'117904','furniture','block-111198','Html_box','',1),(111200,'117905','furniture','block-111198-2','Html_box','',1),(111201,'117906','furniture','rows','BlockBox','listing-item',1),(111202,'117907','furniture','block-111201','BlockBox','',2),(111203,'117908','furniture','block-111202','BlockBox','',2),(111204,'117909','furniture','block-111203','productListing\\bonusPoints','',2),(111205,'117910','furniture','block-111203','productListing\\image','',1),(111206,'117914','furniture','block-111203-2','productListing\\name','',1),(111207,'117915','furniture','block-111203-2','productListing\\description','',2),(111208,'117916','furniture','block-111203-2','productListing\\model','',4),(111209,'117917','furniture','block-111203-2','productListing\\attributes','',5),(111210,'120922','furniture','block-111203-2','productListing\\properties','',3),(111211,'1639146806.7019','furniture','block-111203-2','productListing\\productGroup','',6),(111212,'117918','furniture','block-111202-2','BlockBox','listing-item',1),(111213,'117911','furniture','block-111212','BlockBox','',3),(111214,'117912','furniture','block-111213','productListing\\rating','',1),(111215,'117913','furniture','block-111213','productListing\\ratingCounts','',2),(111216,'117919','furniture','block-111212','productListing\\qtyInput','',4),(111217,'117920','furniture','block-111212','productListing\\price','',2),(111218,'117922','furniture','block-111212','productListing\\buyButton','',5),(111219,'117924','furniture','block-111212','productListing\\stock','',1),(111220,'120924','furniture','block-111212','BlockBox','',8),(111221,'120925','furniture','block-111220','productListing\\compare','',3),(111222,'120926','furniture','block-111220','productListing\\personalCatalog','',2),(111223,'120927','furniture','block-111220','productListing\\viewButton','',1),(111224,'117925','furniture','sample','BlockBox','',1),(111225,'117926','furniture','block-111224','cart\\CartTabs','',1),(111226,'117927','furniture','block-111225','BlockBox','',1),(111227,'117928','furniture','block-111226','sample\\Products','',1),(111228,'117929','furniture','block-111226-2','BlockBox','',1),(111229,'117930','furniture','block-111228','BlockBox','',1),(111230,'117931','furniture','block-111229','sample\\CheckoutBtn','',1),(111231,'117932','furniture','samples','BlockBox','',1),(111232,'117933','furniture','block-111231','BlockBox','',1),(111233,'117934','furniture','block-111232','WidgetsAria','',1),(111253,'117935','furniture','block-111232-2','Html_box','',1),(111254,'117936','furniture','block-111232-2','Samples\\SamplesHistory','',2),(111255,'117937','furniture','sample_info','BlockBox','',1),(111256,'117938','furniture','block-111255','BlockBox','',1),(111257,'117939','furniture','block-111256','WidgetsAria','',1),(111277,'117940','furniture','block-111256-2','Html_box','',1),(111278,'117941','furniture','block-111256-2','BlockBox','',8),(111279,'117942','furniture','block-111278','account\\AccountLink','',1),(111280,'117943','furniture','block-111256-2','Samples\\SampleHistory','',7),(111281,'117944','furniture','block-111256-2','Html_box','',3),(111282,'117945','furniture','block-111256-2','Samples\\SampleSubTotal','',5),(111283,'117946','furniture','block-111256-2','Samples\\SampleProducts','',4),(111284,'117947','furniture','block-111256-2','Html_box','',6),(111285,'117948','furniture','block-111256-2','BlockBox','',2),(111286,'117949','furniture','block-111285','BlockBox','',4),(111287,'117950','furniture','block-111286','Html_box','',1),(111288,'117951','furniture','block-111286','Samples\\SampleData','',2),(111289,'117952','furniture','block-111285','BlockBox','',1),(111290,'117953','furniture','block-111289','Samples\\SampleData','',2),(111291,'117954','furniture','block-111289','Html_box','',1),(111292,'117955','furniture','block-111285-2','BlockBox','',2),(111293,'117956','furniture','block-111292','Samples\\SampleData','',2),(111294,'117957','furniture','block-111292','Html_box','',1),(111295,'117958','furniture','block-111285-2','BlockBox','',1),(111296,'117959','furniture','block-111295','Samples\\SampleData','',2),(111297,'117960','furniture','block-111295','Html_box','',1),(111298,'117961','furniture','block-111285-3','BlockBox','',2),(111299,'117962','furniture','block-111298','Samples\\SampleData','',2),(111300,'117963','furniture','block-111298','Html_box','',1),(111301,'117964','furniture','block-111285-3','BlockBox','',1),(111302,'117965','furniture','block-111301','Samples\\SampleData','',2),(111303,'117966','furniture','block-111301','Html_box','',1),(111304,'117967','furniture','sitemap','BlockBox','info-content',1),(111305,'117968','furniture','block-111304','Html_box','',1),(111306,'117969','furniture','block-111304','BlockBox','',2),(111307,'117970','furniture','block-111306','Html_box','',1),(111308,'117971','furniture','block-111306','Html_box','',5),(111309,'117972','furniture','block-111306','Html_box','',3),(111310,'117973','furniture','block-111306','sitemap\\InfoPages','',2),(111311,'117974','furniture','block-111306','sitemap\\Categories','',4),(111312,'117975','furniture','block-111306','Menu','Account box',6),(111313,'117976','furniture','block-111306-2','sitemap\\DeliveryLocation','',2),(111314,'117977','furniture','block-111306-2','Html_box','',1),(111315,'120878','furniture','social','SocialLinks','',1),(111316,'117978','furniture','subscribe','BlockBox','',1),(111317,'117979','furniture','block-111316','Html_box','',3),(111318,'117980','furniture','block-111316','subscribers\\UnsubscribeForm','',4),(111319,'117981','furniture','block-111316','Html_box','',1),(111320,'117982','furniture','block-111316','subscribers\\SubscribeForm','',2),(111321,'117983','furniture','subscribed','BlockBox','',1),(111322,'117984','furniture','block-111321','Html_box','',1),(111323,'117985','furniture','subscription','BlockBox','',2),(111324,'117986','furniture','block-111323','BlockBox','',1),(111325,'117987','furniture','block-111324','WidgetsAria','',1),(111345,'117988','furniture','block-111324-2','Html_box','',2),(111346,'117989','furniture','block-111324-2','Html_box','',3),(111347,'117990','furniture','block-111324-2','account\\Subscription','',4),(111348,'1695216662.204376','furniture','success','BlockBox','',1),(111349,'1695216662.283842','furniture','block-111348','BlockBox','',2),(111350,'1695216662.28679','furniture','block-111349','BlockBox','',3),(111351,'1695216662.287367','furniture','block-111350','BlockBox','',2),(111352,'1695216662.28994','furniture','block-111351','BlockBox','',1),(111353,'1695216662.291839','furniture','block-111352','order\\ShippingMethod','',6),(111354,'1695216662.293199','furniture','block-111352','order\\DeliveryAddress','',3),(111355,'1695216662.294382','furniture','block-111352','Html_box','',7),(111356,'1695216662.301223','furniture','block-111352','Html_box','',5),(111357,'1695216662.303717','furniture','block-111352','Html_box','',1),(111358,'1695216662.305529','furniture','block-111352','checkout\\ContactConfirm','',9),(111359,'1695216662.306549','furniture','block-111352','Html_box','',2),(111360,'1695216662.308881','furniture','block-111351-2','BlockBox','',1),(111361,'1695216662.310724','furniture','block-111360','order\\PaymentMethod','',6),(111362,'1695216662.311766','furniture','block-111360','order\\BillingAddress','',3),(111363,'1695216662.312915','furniture','block-111360','Html_box','',5),(111364,'1695216662.314711','furniture','block-111360','Html_box','',1),(111365,'1695216662.316646','furniture','block-111360','Html_box','',2),(111366,'1695216662.31980','furniture','block-111350','Html_box','',1),(111367,'1695216662.322253','furniture','block-111349-2','BlockBox','',1),(111368,'1695216662.323587','furniture','block-111367','success\\PrintBtn','',3),(111369,'1695216662.325129','furniture','block-111367','success\\ContinueBtn','',4),(111370,'1695216662.333192','furniture','block-111367','order\\Products','',1),(111371,'1695216662.334266','furniture','block-111367','order\\Totals','',2),(111372,'1695216662.335222','furniture','block-111348','BlockBox','',1),(111373,'1695216662.336556','furniture','block-111372','Html_box','',2),(111374,'1695216662.338898','furniture','block-111372','order\\OrderNumber','',1),(111375,'117997','furniture','success_q','BlockBox','',1),(111376,'117998','furniture','block-111375','BlockBox','',1),(111377,'117999','furniture','block-111376','BlockBox','',2),(111378,'118000','furniture','block-111377','success\\ContinueBtn','',2),(111379,'118001','furniture','block-111377','success\\PrintBtn','',1),(111380,'118002','furniture','block-111376','Html_box','',1),(111385,'118007','furniture','ticket','invoice\\Container','',1),(111386,'118008','furniture','block-111385','BlockBox','',4),(111387,'118009','furniture','block-111386','BlockBox','',1),(111388,'118010','furniture','block-111387','invoice\\ShippingAddress','',2),(111389,'118011','furniture','block-111387','Text','',1),(111390,'118012','furniture','block-111386-2','BlockBox','',1),(111391,'118013','furniture','block-111390','invoice\\Totals','',1),(111392,'118014','furniture','block-111385','BlockBox','',5),(111393,'118015','furniture','block-111392','Text','',1),(111394,'118016','furniture','block-111392','invoice\\StoreAddress','',8),(111395,'118018','furniture','block-111392-2','Text','',2),(111396,'118019','furniture','block-111392-3','Text','',1),(111397,'118020','furniture','block-111392-3','BlockBox','',3),(111398,'118021','furniture','block-111397','Text','',1),(111399,'118022','furniture','block-111397-2','invoice\\StoreEmail','',1),(111400,'118023','furniture','block-111392-3','BlockBox','',2),(111401,'118024','furniture','block-111400','Text','',1),(111402,'118025','furniture','block-111400-2','invoice\\StorePhone','',1),(111403,'118026','furniture','block-111385','invoice\\Products','',3),(111404,'118027','furniture','block-111385','BlockBox','',1),(111405,'118028','furniture','block-111404-2','BlockBox','',3),(111406,'118029','furniture','block-111405','Text','',1),(111407,'118030','furniture','block-111405-2','invoice\\StoreEmail','',1),(111408,'118031','furniture','block-111404-2','BlockBox','',4),(111409,'118032','furniture','block-111408','Text','',1),(111410,'118033','furniture','block-111408-2','invoice\\StoreSite','',1),(111411,'118034','furniture','block-111404-2','BlockBox','',1),(111412,'118035','furniture','block-111411','invoice\\StoreAddress','',1),(111413,'118036','furniture','block-111404-2','BlockBox','',2),(111414,'118037','furniture','block-111413','Text','',1),(111415,'118038','furniture','block-111413-2','invoice\\StorePhone','',1),(111416,'118039','furniture','block-111385','BlockBox','',2),(111417,'118040','furniture','block-111416','BlockBox','',8),(111418,'118041','furniture','block-111417','BlockBox','',1),(111419,'118042','furniture','block-111418','Text','',1),(111420,'118043','furniture','block-111418','invoice\\ShippingMethod','',2),(111421,'118044','furniture','block-111417-2','BlockBox','',1),(111422,'118045','furniture','block-111421','Text','',1),(111423,'118046','furniture','block-111421','invoice\\ShippingMethod','',2),(111424,'118047','furniture','block-111416','BlockBox','',7),(111425,'118048','furniture','block-111424','BlockBox','',1),(111426,'118049','furniture','block-111425','invoice\\BillingAddress','',2),(111427,'118050','furniture','block-111425','Text','',1),(111428,'118051','furniture','block-111424-2','BlockBox','',1),(111429,'118052','furniture','block-111428','invoice\\CustomerName','',2),(111430,'118053','furniture','block-111428','Text','',3),(111431,'118054','furniture','block-111428','invoice\\CustomerEmail','',6),(111432,'118055','furniture','block-111428','invoice\\CustomerPhone','',4),(111433,'118056','furniture','block-111428','Text','',5),(111434,'118057','furniture','block-111428','Text','',1),(111435,'118058','furniture','block-111416-2','invoice\\PaymentDate','',3),(111436,'118059','furniture','block-111416-2','Text','',2),(111437,'118060','furniture','block-111416-2','Text','',4),(111438,'118061','furniture','block-111416-2','invoice\\OrderId','',1),(111439,'118062','furniture','block-111416-2','invoice\\PaymentMethod','',5),(111440,'118063','furniture','block-111416-2','invoice\\OrderBarcode','',6),(111441,'118094','furniture','tracking_numbers','BlockBox','',1),(111442,'118095','furniture','block-111441','Html_box','',1),(111443,'118096','furniture','block-111441','account\\OrderTracking','',2),(111444,'118318','furniture','unsubscribed','BlockBox','',1),(111445,'118319','furniture','block-111444','Html_box','',1),(111446,'118320','furniture','update-and-pay-order_confirmation','BlockBox','',1),(111447,'118321','furniture','block-111446','BlockBox','',3),(111448,'118322','furniture','block-111447','BlockBox','',1),(111449,'118323','furniture','block-111448','BlockBox','',1),(111450,'118324','furniture','block-111449','BlockBox','',1),(111451,'118325','furniture','block-111450','order\\ShippingMethod','',5),(111452,'118326','furniture','block-111450','Html_box','',2),(111453,'118327','furniture','block-111450','Html_box','',4),(111454,'118328','furniture','block-111450','Html_box','',1),(111455,'118329','furniture','block-111450','order\\Telephone','',8),(111456,'118330','furniture','block-111450','Html_box','',6),(111457,'118331','furniture','block-111450','order\\Name','',7),(111458,'118332','furniture','block-111450','order\\Email','',9),(111459,'118333','furniture','block-111450','order\\DeliveryAddress','',3),(111460,'118334','furniture','block-111449-2','BlockBox','',1),(111461,'118335','furniture','block-111460','order\\BillingAddress','',3),(111462,'118336','furniture','block-111460','UpdateAndPay\\PayConfirm','',5),(111463,'118337','furniture','block-111460','Html_box','',1),(111464,'118338','furniture','block-111460','Html_box','',2),(111465,'118339','furniture','block-111460','Html_box','',4),(111466,'118340','furniture','block-111448','BlockBox','',3),(111467,'118341','furniture','block-111466','order\\Products','',2),(111468,'118342','furniture','block-111466','Html_box','',1),(111469,'118343','furniture','block-111447-2','BlockBox','',1),(111470,'118344','furniture','block-111469','Html_box','',1),(111471,'118345','furniture','block-111469','checkout\\ContinueBtn','',3),(111472,'118346','furniture','block-111469','order\\Totals','',2),(111473,'118347','furniture','block-111446','account\\OrderHeading','',1),(111474,'118348','furniture','update-and-pay-order_pay','BlockBox','',1),(111475,'118349','furniture','block-111474','BlockBox','',3),(111476,'118350','furniture','block-111475','BlockBox','',1),(111477,'118351','furniture','block-111476','BlockBox','',1),(111478,'118352','furniture','block-111477','BlockBox','',1),(111479,'118353','furniture','block-111478','order\\DeliveryAddress','',4),(111480,'118354','furniture','block-111478','order\\Email','',10),(111481,'118355','furniture','block-111478','order\\Name','',8),(111482,'118356','furniture','block-111478','Html_box','',7),(111483,'118357','furniture','block-111478','order\\Telephone','',9),(111484,'118358','furniture','block-111478','Html_box','',5),(111485,'118359','furniture','block-111478','order\\ShippingMethod','',6),(111486,'118360','furniture','block-111478','Html_box','',2),(111487,'118361','furniture','block-111478','Html_box','',3),(111488,'1639647774.7838','furniture','block-111478','DelayedDespatch\\OrderPay','',1),(111489,'118362','furniture','block-111477-2','BlockBox','',1),(111490,'118363','furniture','block-111489','Html_box','',1),(111491,'118364','furniture','block-111489','Html_box','',2),(111492,'118365','furniture','block-111489','Html_box','',4),(111493,'118366','furniture','block-111489','order\\BillingAddress','',3),(111494,'118367','furniture','block-111489','UpdateAndPay\\PayForm','',5),(111495,'118368','furniture','block-111476','BlockBox','',3),(111496,'118369','furniture','block-111495','Html_box','',1),(111497,'118370','furniture','block-111495','order\\Products','',2),(111498,'118371','furniture','block-111475-2','BlockBox','',1),(111499,'118372','furniture','block-111498','order\\Totals','',2),(111500,'118373','furniture','block-111498','checkout\\ContinueBtn','',3),(111501,'118374','furniture','block-111498','Html_box','',1),(111502,'118375','furniture','block-111474','account\\OrderHeading','',1),(111503,'118440','furniture','wishlist','BlockBox','',1),(111504,'118441','furniture','block-111503','BlockBox','',1),(111505,'118442','furniture','block-111504','WidgetsAria','',1),(111525,'118443','furniture','block-111504-2','account\\Wishlist','',2),(111526,'118444','furniture','block-111504-2','Html_box','',1),(111527,'118445','furniture','wishlist-cart','BlockBox','',1),(111528,'118446','furniture','block-111527','cart\\CartTabs','',1),(111529,'118447','furniture','block-111528','account\\Wishlist','',1),(111530,'73349','watch','404','Html_box','',1),(111764,'73409','watch','b2b','BlockBox','listing-item',1),(111765,'73410','watch','block-111764','BlockBox','',1),(111766,'73411','watch','block-111765','productListing\\image','',1),(111767,'73412','watch','block-111765-2','productListing\\description','',6),(111768,'73413','watch','block-111765-2','productListing\\model','',5),(111769,'73414','watch','block-111765-2','productListing\\attributes','',3),(111770,'73415','watch','block-111765-2','BlockBox','',4),(111771,'73416','watch','block-111770','BlockBox','',1),(111772,'73417','watch','block-111771','productListing\\price','',1),(111773,'73418','watch','block-111771-2','BonusActions\\widgets\\BonusPointsProductListing','',1),(111774,'73419','watch','block-111770-2','productListing\\qtyInput','',1),(111775,'73420','watch','block-111765-2','productListing\\name','',1),(111776,'73421','watch','block-111765-2','BlockBox','',2),(111777,'73422','watch','block-111776','productListing\\stock','',1),(111778,'73423','watch','block-111776-2','productListing\\rating','',1),(111779,'76000','watch','batch','BlockBox','',1),(111780,'76001','watch','block-111779','productListing\\attributes','',5),(111781,'76002','watch','block-111779','productListing\\price','',6),(111782,'76003','watch','block-111779','productListing\\name','',4),(111783,'76004','watch','block-111779','productListing\\image','',2),(111784,'76005','watch','block-111779','batchSelect','',1),(111785,'76006','watch','batch_selected','BlockBox','',1),(111786,'76007','watch','block-111785','BlockBox','',13),(111787,'76008','watch','block-111786','productListing\\image','',1),(111788,'76009','watch','block-111786-2','batchRemove','',1),(111789,'76010','watch','block-111786-2','productListing\\price','',3),(111790,'76011','watch','block-111786-2','productListing\\name','',2),(111791,'76012','watch','bbbbb','BlockBox','',1),(111792,'76013','watch','block-111791','BlockBox','',2),(111793,'76014','watch','block-111792','Filters','',1),(111794,'76015','watch','block-111792-2','BlockBox','',6),(111795,'76016','watch','block-111794','catalog\\CountsItems','',1),(111796,'76017','watch','block-111794-2','catalog\\Paging','',1),(111797,'76018','watch','block-111792-2','catalog\\Image','',1),(111798,'76019','watch','block-111792-2','Listing','',5),(111799,'76020','watch','block-111792-2','catalog\\ImageMapCategory','',3),(111800,'76021','watch','block-111792-2','BlockBox','',4),(111801,'76022','watch','block-111800','catalog\\ListingLook','',1),(111802,'76023','watch','block-111800','catalog\\CompareButton','',2),(111803,'76024','watch','block-111800','catalog\\ItemsOnPage','',4),(111804,'76025','watch','block-111800','catalog\\Sorting','',3),(111805,'76026','watch','block-111792-2','Categories','',2),(111806,'76027','watch','block-111791','catalog\\Title','',1),(111807,'1683124632.767746','watch','cart','BlockBox','',1),(111808,'1683124632.80670','watch','block-111807','BlockBox','',2),(111809,'1683124632.809680','watch','block-111808','BlockBox','cart-content',4),(111810,'1683124632.816335','watch','block-111808','BlockBox','',1),(111811,'1683124632.817623','watch','block-111810','cart\\Products','',2),(111812,'1683124632.818551','watch','block-111810','BlockBox','',1),(111813,'1683124632.820317','watch','block-111812','MultiCart\\CartSwitcher','',1),(111814,'1683124632.820914','watch','block-111812','MultiCart\\SaveCart','',2),(111815,'1683124632.822588','watch','block-111812-2','MultiCart\\Actions','',1),(111816,'1683124632.823175','watch','block-111810','BlockBox','',3),(111817,'1683124632.825245','watch','block-111816','cart\\CreditAmount','',1),(111818,'1683124632.825649','watch','block-111816-2','BonusActions\\widgets\\BonusPointsCart','',1),(111819,'1683124632.82683','watch','block-111808','BlockBox','',3),(111820,'1683124632.827413','watch','block-111819','cart\\GiveAway','',2),(111821,'1683124632.828374','watch','block-111819','Html_box','',1),(111822,'1683124632.829840','watch','block-111808','BlockBox','',5),(111823,'1683124632.831459','watch','block-111822','Html_box','',1),(111824,'1683124632.832592','watch','block-111822','cart\\ShippingEstimator','',2),(111825,'1683124632.833353','watch','block-111808-2','BlockBox','',1),(111826,'1683124632.834715','watch','block-111825','BlockBox','',2),(111827,'1683124632.835884','watch','block-111826','cart\\DiscountCoupon','',1),(111828,'1683124632.836532','watch','block-111826','Image','',4),(111829,'1683124632.844829','watch','block-111826','cart\\CheckoutBtn','',3),(111830,'1683124632.84681','watch','block-111826','cart\\OrderTotal','',2),(111831,'1683124632.846538','watch','block-111826','cart\\OrderTotal','',0),(111832,'1683124632.84726','watch','block-111825','Html_box','',1),(111833,'94658','watch','cart2','BlockBox','',2),(111834,'94659','watch','block-111833','cart\\CartTabs','',2),(111835,'94660','watch','block-111834','BlockBox','',1),(111836,'94661','watch','block-111835','BlockBox','',4),(111837,'94662','watch','block-111836','cart\\UpSell','6',2),(111838,'94663','watch','block-111836','Html_box','',1),(111839,'94664','watch','block-111835','BlockBox','',1),(111840,'94665','watch','block-111839','cart\\Products','',3),(111841,'94666','watch','block-111839','BlockBox','',2),(111842,'94667','watch','block-111841','MultiCart\\CartSwitcher','',1),(111843,'94668','watch','block-111841','MultiCart\\SaveCart','',2),(111844,'94669','watch','block-111841-2','MultiCart\\Actions','',1),(111845,'94670','watch','block-111835','BlockBox','',3),(111846,'94671','watch','block-111845','cart\\GiveAway','',2),(111847,'94672','watch','block-111845','Html_box','',1),(111848,'94673','watch','block-111835','BlockBox','',2),(111849,'94674','watch','block-111848','Html_box','',1),(111850,'94675','watch','block-111848','BlockBox','',2),(111851,'94676','watch','block-111850','cart\\DiscountCoupon','',1),(111852,'94677','watch','block-111850-2','cart\\CreditAmount','',1),(111853,'94678','watch','block-111850-3','BonusActions\\widgets\\BonusPointsCart','',1),(111854,'94679','watch','block-111835','BlockBox','',5),(111855,'94680','watch','block-111854','Html_box','',1),(111856,'94681','watch','block-111854','cart\\ShippingEstimator','',2),(111857,'94682','watch','block-111835-2','BlockBox','',1),(111858,'94683','watch','block-111857','Html_box','',1),(111859,'94684','watch','block-111857','BlockBox','',2),(111860,'94685','watch','block-111859','Image','',4),(111861,'94686','watch','block-111859','cart\\CheckoutBtn','',2),(111862,'94687','watch','block-111859','cart\\OrderTotal','',1),(111863,'73462','watch','categories','BlockBox','catalog-content',1),(111864,'73463','watch','block-111863','BlockBox','catalog-side',2),(111865,'73464','watch','block-111864','Filters','',1),(111866,'73465','watch','block-111864-2','Listing','',5),(111867,'73466','watch','block-111864-2','catalog\\Image','',1),(111868,'73467','watch','block-111864-2','BlockBox','',6),(111869,'73468','watch','block-111868','catalog\\CountsItems','',1),(111870,'73469','watch','block-111868-2','catalog\\Paging','',1),(111871,'73470','watch','block-111864-2','catalog\\ImageMapCategory','',3),(111872,'73471','watch','block-111864-2','Categories','',2),(111873,'73472','watch','block-111864-2','BlockBox','catalog-features',4),(111874,'73473','watch','block-111873','catalog\\ListingLook','',1),(111875,'73474','watch','block-111873','catalog\\CompareButton','',2),(111876,'73475','watch','block-111873','catalog\\ItemsOnPage','',4),(111877,'73476','watch','block-111873','catalog\\Sorting','',3),(111878,'73477','watch','block-111863','catalog\\Title','',1),(111879,'73478','watch','category','Categories','',1),(111880,'73479','watch','category','Listing','',4),(111881,'73480','watch','category','ListingFunctionality','',2),(111882,'73481','watch','category','PagingBar','',3),(111883,'73482','watch','category','PagingBar','',5),(111884,'94688','watch','category_2','BlockBox','',1),(111885,'94689','watch','block-111884','catalog\\Title','',1),(111886,'94690','watch','block-111884','BlockBox','',2),(111887,'94691','watch','block-111886','Filters','',1),(111888,'94692','watch','block-111886-2','catalog\\Image','',1),(111889,'94693','watch','block-111886-2','Listing','',5),(111890,'94694','watch','block-111886-2','BlockBox','',4),(111891,'94695','watch','block-111890','catalog\\Sorting','',3),(111892,'94696','watch','block-111890','catalog\\ItemsOnPage','',4),(111893,'94697','watch','block-111890','catalog\\CompareButton','',2),(111894,'94698','watch','block-111890','catalog\\ListingLook','',1),(111895,'94699','watch','block-111886-2','catalog\\ImageMapCategory','',3),(111896,'94700','watch','block-111886-2','Categories','',2),(111897,'94701','watch','block-111886-2','BlockBox','',6),(111898,'94702','watch','block-111897','catalog\\CountsItems','',1),(111899,'94703','watch','block-111897-2','catalog\\Paging','',1),(111900,'73483','watch','category_no_filters','BlockBox','',1),(111901,'73484','watch','block-111900','catalog\\Title','',1),(111902,'73485','watch','block-111900','Categories','',3),(111903,'73486','watch','block-111900','BlockBox','catalog-features',4),(111904,'73487','watch','block-111903','catalog\\ItemsOnPage','',4),(111905,'73488','watch','block-111903','catalog\\Sorting','',3),(111906,'73489','watch','block-111903','catalog\\CompareButton','',2),(111907,'73490','watch','block-111903','catalog\\ListingLook','',1),(111908,'73491','watch','block-111903','HeaderStock','',5),(111909,'73492','watch','block-111900','BlockBox','',6),(111910,'73493','watch','block-111909','catalog\\CountsItems','',1),(111911,'73494','watch','block-111909-2','catalog\\Paging','',1),(111912,'73495','watch','block-111900','Listing','',5),(111913,'73496','watch','block-111900','catalog\\Image','',2),(111914,'73497','watch','block-111900','catalog\\B2bAddButton','',7),(111915,'1683125852.345798','watch','checkout','BlockBox','',1),(111916,'1683125852.356555','watch','block-111915','BlockBox','',2),(111917,'1683125852.358412','watch','block-111916','BlockBox','',2),(111918,'1683125852.35982','watch','block-111917','BlockBox','checkout-comments',5),(111919,'1683125852.361569','watch','block-111918','checkout\\Comments','',2),(111920,'1683125852.362847','watch','block-111918','Html_box','',1),(111921,'1683125852.36485','watch','block-111917','BlockBox','checkout-discount',4),(111922,'1683125852.366422','watch','block-111921','Html_box','',1),(111923,'1683125852.367732','watch','block-111921','BlockBox','',2),(111924,'1683125852.36968','watch','block-111923','CouponsAndVauchers\\Checkout','',1),(111925,'1683125852.369745','watch','block-111923-2','checkout\\CreditAmount','',1),(111926,'1683125852.37045','watch','block-111923-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(111927,'1683125852.371233','watch','block-111917','BlockBox','checkout-shipping',2),(111928,'1683125852.37350','watch','block-111927','BlockBox','',3),(111929,'1683125852.374899','watch','block-111928','checkout\\ShippingChoice','',1),(111930,'1683125852.375685','watch','block-111927','Neighbour\\Checkout','',5),(111931,'1683125852.376557','watch','block-111927','BlockBox','',4),(111932,'1683125852.377637','watch','block-111931','BlockBox','',1),(111933,'1683125852.378829','watch','block-111932','checkout\\ShippingAddress','',2),(111934,'1683125852.379375','watch','block-111932','Html_box','',3),(111935,'1683125852.380323','watch','block-111932','checkout\\ContactInformation','',4),(111936,'1683125852.380722','watch','block-111932','UploadCustomerId\\UploadCustomerIdForm','',4),(111937,'1683125852.381183','watch','block-111931-2','BlockBox','',1),(111938,'1683125852.382226','watch','block-111937','checkout\\Shipping','',2),(111939,'1683125852.382635','watch','block-111937','DelayedDespatch\\Checkout','',3),(111940,'1683125852.383516','watch','block-111937','Html_box','',1),(111941,'1683125852.385278','watch','block-111927','Html_box','',2),(111942,'1683125852.386397','watch','block-111917','cart\\Products','',6),(111943,'1683125852.386970','watch','block-111917','checkout\\CreateAccount','',7),(111944,'1683125852.38820','watch','block-111917','BlockBox','checkout-payment',3),(111945,'1683125852.390244','watch','block-111944','Html_box','',1),(111946,'1683125852.391810','watch','block-111944','BlockBox','',2),(111947,'1683125852.393320','watch','block-111946','Html_box','',1),(111948,'1683125852.394747','watch','block-111946','checkout\\BillingAddress','',2),(111949,'1683125852.395767','watch','block-111946-2','BlockBox','',1),(111950,'1683125852.397129','watch','block-111949','checkout\\PaymentMethod','',2),(111951,'1683125852.398588','watch','block-111949','Html_box','',1),(111952,'1683125852.400291','watch','block-111917','BlockBox','',1),(111953,'1683125852.402237','watch','block-111952','checkout\\LoginOnForm','',0),(111954,'1683128325.0836','watch','block-111952','BlockBox','',1),(111955,'1683125852.403563','watch','block-111916-2','BlockBox','checkout-side',1),(111956,'1683125852.405625','watch','block-111955','Html_box','',6),(111957,'1683125852.407666','watch','block-111955','Html_box','',1),(111958,'1683125852.40885','watch','block-111955','checkout\\Terms','',5),(111959,'1683125852.409688','watch','block-111955','checkout\\Totals','',3),(111960,'1683125852.410151','watch','block-111955','checkout\\ContinueBtn','',4),(111961,'1683125852.412647','watch','block-111955','cart\\Products','',2),(111962,'73542','watch','checkout_confirmation','BlockBox','',1),(111963,'73543','watch','block-111962','checkout\\Totals','',8),(111964,'73544','watch','block-111962','Html_box','',5),(111965,'73545','watch','block-111962','checkout\\EditBtn','',6),(111966,'73546','watch','block-111962','BlockBox','',3),(111967,'73547','watch','block-111966','BlockBox','',1),(111968,'73548','watch','block-111967','Html_box','',1),(111969,'73549','watch','block-111967','checkout\\ShippingConfirm','',3),(111970,'73550','watch','block-111966-2','BlockBox','',1),(111971,'73551','watch','block-111970','checkout\\PaymentMethodConfirm','',3),(111972,'73552','watch','block-111970','Html_box','',1),(111973,'73553','watch','block-111962','checkout\\ConfirmBtn','',9),(111974,'73554','watch','block-111962','BlockBox','',2),(111975,'73555','watch','block-111974','BlockBox','',1),(111976,'73556','watch','block-111975','checkout\\ShippingAddressConfirm','',3),(111977,'73557','watch','block-111975','Html_box','',1),(111978,'73558','watch','block-111974-2','BlockBox','',1),(111979,'73559','watch','block-111978','Html_box','',1),(111980,'73560','watch','block-111978','checkout\\BillingAddressConfirm','',3),(111981,'73561','watch','block-111962','checkout\\ConfirmBtn','',4),(111982,'73562','watch','block-111962','cart\\Products','',7),(111983,'73576','watch','checkout_confirmation_no_shipping','BlockBox','',1),(111984,'73577','watch','block-111983','checkout\\ConfirmBtn','',9),(111985,'73578','watch','block-111983','BlockBox','',2),(111986,'73579','watch','block-111985','BlockBox','',1),(111987,'73580','watch','block-111986','Html_box','',1),(111988,'73581','watch','block-111986','checkout\\BillingAddressConfirm','',3),(111989,'73582','watch','block-111985-2','BlockBox','',1),(111990,'73583','watch','block-111989','Html_box','',1),(111991,'73584','watch','block-111989','checkout\\PaymentMethodConfirm','',3),(111992,'73585','watch','block-111983','checkout\\ConfirmBtn','',4),(111993,'73586','watch','block-111983','checkout\\Totals','',8),(111994,'73587','watch','block-111983','cart\\Products','',7),(111995,'73588','watch','block-111983','Html_box','',5),(111996,'73563','watch','checkout_confirmation_no_shipping_q','BlockBox','',1),(111997,'73564','watch','block-111996','quote\\Products','',4),(111998,'73565','watch','block-111996','checkout\\ConfirmBtn','',2),(111999,'73566','watch','block-111996','checkout\\ConfirmBtn','',6),(112000,'73567','watch','block-111996','BlockBox','',1),(112001,'73568','watch','block-112000','BlockBox','',1),(112002,'73569','watch','block-112001','checkout\\BillingAddressConfirm','',3),(112003,'73570','watch','block-112001','Html_box','',1),(112004,'73571','watch','block-112000-2','BlockBox','',1),(112005,'73572','watch','block-112004','checkout\\PaymentMethodConfirm','',3),(112006,'73573','watch','block-112004','Html_box','',1),(112007,'73574','watch','block-111996','Html_box','',3),(112008,'73575','watch','block-111996','checkout\\Totals','',5),(112009,'73589','watch','checkout_confirmation_q','BlockBox','',1),(112010,'73590','watch','block-112009','BlockBox','',1),(112011,'73591','watch','block-112010','BlockBox','',1),(112012,'73592','watch','block-112011','checkout\\ShippingAddressConfirm','',3),(112013,'73593','watch','block-112011','Html_box','',1),(112014,'73594','watch','block-112010-2','BlockBox','',1),(112015,'73595','watch','block-112014','checkout\\BillingAddressConfirm','',3),(112016,'73596','watch','block-112014','Html_box','',1),(112017,'73597','watch','block-112009','checkout\\Totals','',7),(112018,'73598','watch','block-112009','quote\\Products','',6),(112019,'73599','watch','block-112009','Html_box','',4),(112020,'73600','watch','block-112009','checkout\\EditBtn','',5),(112021,'73601','watch','block-112009','checkout\\ConfirmBtn','',8),(112022,'73602','watch','block-112009','checkout\\ConfirmBtn','',3),(112023,'73603','watch','block-112009','BlockBox','',2),(112024,'73604','watch','block-112023','BlockBox','',1),(112025,'73605','watch','block-112024','Html_box','',1),(112026,'73606','watch','block-112024','checkout\\ShippingConfirm','',3),(112027,'73607','watch','block-112023-2','BlockBox','',1),(112028,'73608','watch','block-112027','Html_box','',1),(112029,'73609','watch','block-112027','checkout\\PaymentMethodConfirm','',3),(112030,'73610','watch','checkout_confirmation_title','Html_box','',1),(112031,'73611','watch','checkout_confirmation_title_g','Html_box','',1),(112032,'73613','watch','checkout_confirmation_title_no_shipping','Html_box','',1),(112033,'73612','watch','checkout_confirmation_title_no_shipping_g','Html_box','',1),(112034,'73614','watch','checkout_confirmation_title_q','Html_box','',1),(112035,'73615','watch','checkout_confirmation_title_s','Html_box','',1),(112036,'73616','watch','checkout_delivery','BlockBox','',2),(112037,'73617','watch','block-112036','BlockBox','',1),(112038,'73618','watch','block-112037','Html_box','',1),(112039,'73619','watch','block-112037','checkout\\ContactInformation','',2),(112040,'73620','watch','block-112036-2','BlockBox','',1),(112041,'73621','watch','block-112040','Html_box','',1),(112042,'73622','watch','block-112040','checkout\\Comments','',2),(112043,'73623','watch','checkout_delivery','BlockBox','',3),(112044,'73624','watch','block-112043','Html_box','',1),(112045,'73625','watch','block-112043-2','checkout\\ContinueBtn','',1),(112046,'73626','watch','checkout_delivery','BlockBox','',1),(112047,'73627','watch','block-112046','BlockBox','',1),(112048,'73628','watch','block-112047','Html_box','',1),(112049,'73629','watch','block-112047','checkout\\ShippingAddress','',2),(112050,'73630','watch','block-112046-2','BlockBox','',1),(112051,'73631','watch','block-112050','DelayedDespatch\\Checkout','',3),(112052,'73632','watch','block-112050','checkout\\Shipping','',2),(112053,'73633','watch','block-112050','Html_box','',1),(112054,'73634','watch','block-112050','Neighbour\\Checkout','',4),(112055,'73635','watch','checkout_delivery_g','BlockBox','',2),(112056,'73636','watch','block-112055','BlockBox','',1),(112057,'73637','watch','block-112056','checkout\\ContactInformation','',2),(112058,'73638','watch','block-112056','Html_box','',1),(112059,'73639','watch','block-112055-2','BlockBox','',1),(112060,'73640','watch','block-112059','Html_box','',1),(112061,'73641','watch','block-112059','checkout\\Comments','',2),(112062,'73642','watch','checkout_delivery_g','BlockBox','',3),(112063,'73643','watch','block-112062','Html_box','',1),(112064,'73644','watch','block-112062-2','checkout\\ContinueBtn','',1),(112065,'73645','watch','checkout_delivery_g','BlockBox','',1),(112066,'73646','watch','block-112065','BlockBox','',1),(112067,'73647','watch','block-112066','checkout\\ShippingAddress','',2),(112068,'73648','watch','block-112066','Html_box','',1),(112069,'73649','watch','block-112065-2','BlockBox','',1),(112070,'73650','watch','block-112069','checkout\\Shipping','',2),(112071,'73651','watch','block-112069','Html_box','',1),(112072,'73652','watch','block-112069','DelayedDespatch\\Checkout','',3),(112073,'73653','watch','block-112069','Neighbour\\Checkout','',4),(112074,'73654','watch','checkout_delivery_no_shipping','BlockBox','',2),(112075,'73655','watch','block-112074','Html_box','',1),(112076,'73656','watch','block-112074-2','checkout\\ContinueBtn','',1),(112077,'73657','watch','checkout_delivery_no_shipping','BlockBox','',1),(112078,'73658','watch','block-112077','BlockBox','',1),(112079,'73659','watch','block-112078','checkout\\ContactInformation','',2),(112080,'73660','watch','block-112077-2','BlockBox','',1),(112081,'73661','watch','block-112080','Html_box','',1),(112082,'73662','watch','block-112080','checkout\\Comments','',2),(112083,'73663','watch','checkout_delivery_no_shipping_g','BlockBox','',2),(112084,'73664','watch','block-112083','Html_box','',1),(112085,'73665','watch','block-112083-2','checkout\\ContinueBtn','',1),(112086,'73666','watch','checkout_delivery_no_shipping_g','BlockBox','',1),(112087,'73667','watch','block-112086','BlockBox','',1),(112088,'73668','watch','block-112087','checkout\\ContactInformation','',2),(112089,'73669','watch','block-112086-2','BlockBox','',1),(112090,'73670','watch','block-112089','checkout\\Comments','',2),(112091,'73671','watch','block-112089','Html_box','',1),(112092,'73672','watch','checkout_delivery_title','Html_box','',1),(112093,'73673','watch','checkout_delivery_title_g','Html_box','',1),(112094,'73675','watch','checkout_delivery_title_no_shipping','Html_box','',1),(112095,'73674','watch','checkout_delivery_title_no_shipping_g','Html_box','',1),(112096,'73676','watch','checkout_delivery_title_q','Html_box','',1),(112097,'73677','watch','checkout_delivery_title_s','Html_box','',1),(112098,'73678','watch','checkout_free_s','BlockBox','',1),(112099,'73679','watch','block-112098','BlockBox','',2),(112100,'73680','watch','block-112099','BlockBox','',2),(112101,'73682','watch','block-112100','BlockBox','',6),(112102,'73683','watch','block-112101','sample\\Products','',1),(112103,'73684','watch','block-112101','checkout\\CreateAccount','',3),(112104,'73685','watch','block-112100','BlockBox','',5),(112105,'73686','watch','block-112104','Html_box','',1),(112106,'73687','watch','block-112104','checkout\\Comments','',2),(112107,'73688','watch','block-112100','BlockBox','',2),(112108,'73689','watch','block-112107','BlockBox','',2),(112109,'73690','watch','block-112108','checkout\\ShippingChoice','',1),(112110,'73691','watch','block-112107','Html_box','',1),(112111,'73692','watch','block-112107','BlockBox','',3),(112112,'73693','watch','block-112111','BlockBox','',1),(112113,'73694','watch','block-112112','checkout\\ContactInformation','',4),(112114,'73695','watch','block-112112','checkout\\ShippingAddress','',2),(112115,'73696','watch','block-112112','Html_box','',3),(112116,'73697','watch','block-112111-2','BlockBox','',1),(112117,'73698','watch','block-112116','DelayedDespatch\\Checkout','',3),(112118,'73699','watch','block-112107','Neighbour\\Checkout','',4),(112119,'73700','watch','block-112099-2','BlockBox','',1),(112120,'73701','watch','block-112119','Html_box','',3),(112121,'73702','watch','block-112119','checkout\\ContinueBtn','',1),(112122,'115999','watch','block-112119','checkout\\Terms','',2),(112123,'73703','watch','checkout_no_shipping','BlockBox','',1),(112124,'73704','watch','block-112123','BlockBox','',2),(112125,'73705','watch','block-112124','BlockBox','',1),(112126,'73706','watch','block-112125','BlockBox','',6),(112127,'73707','watch','block-112126','checkout\\CreateAccount','',2),(112128,'73708','watch','block-112126','cart\\Products','',1),(112129,'73709','watch','block-112125','BlockBox','',3),(112130,'73710','watch','block-112129','Html_box','',1),(112131,'73711','watch','block-112129','BlockBox','',2),(112132,'73712','watch','block-112131','checkout\\BillingAddress','',2),(112133,'73713','watch','block-112131','Html_box','',1),(112134,'73714','watch','block-112131-2','BlockBox','',1),(112135,'73715','watch','block-112134','Html_box','',1),(112136,'73716','watch','block-112134','checkout\\PaymentMethod','',2),(112137,'73717','watch','block-112125','BlockBox','',4),(112138,'73718','watch','block-112137','BlockBox','',2),(112139,'73719','watch','block-112138','CouponsAndVauchers\\Checkout','',1),(112140,'73720','watch','block-112138-2','checkout\\CreditAmount','',1),(112141,'73721','watch','block-112138-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(112142,'73722','watch','block-112137','Html_box','',1),(112143,'73723','watch','block-112125','BlockBox','',5),(112144,'73724','watch','block-112143','checkout\\Comments','',2),(112145,'73725','watch','block-112143','Html_box','',1),(112146,'73726','watch','block-112124-2','BlockBox','',1),(112147,'73727','watch','block-112146','Html_box','',1),(112148,'73728','watch','block-112146','Html_box','',5),(112149,'73729','watch','block-112146','checkout\\Totals','',2),(112150,'73730','watch','block-112146','checkout\\ContinueBtn','',3),(112151,'73731','watch','block-112146','checkout\\Terms','',4),(112152,'73732','watch','checkout_no_shipping_g','BlockBox','',1),(112153,'73733','watch','block-112152','checkout\\Totals','',5),(112154,'73734','watch','block-112152','BlockBox','',6),(112155,'73735','watch','block-112154','Html_box','',1),(112156,'73736','watch','block-112154-2','checkout\\ContinueBtn','',1),(112157,'73737','watch','block-112152','BlockBox','',2),(112158,'73738','watch','block-112157','BlockBox','',1),(112159,'73739','watch','block-112158','checkout\\ContactInformation','',2),(112160,'73740','watch','block-112158','Html_box','',1),(112161,'73741','watch','block-112157-2','BlockBox','',1),(112162,'73742','watch','block-112161','checkout\\Comments','',2),(112163,'73743','watch','block-112161','Html_box','',1),(112164,'73744','watch','block-112152','BlockBox','',1),(112165,'73745','watch','block-112164','BlockBox','',1),(112166,'73746','watch','block-112165','Html_box','',1),(112167,'73747','watch','block-112165','checkout\\BillingAddress','',2),(112168,'73748','watch','block-112164-2','BlockBox','',1),(112169,'73749','watch','block-112168','BonusActions\\widgets\\BonusPointsCheckout','',4),(112170,'73750','watch','block-112168','CouponsAndVauchers\\Checkout','',5),(112171,'73751','watch','block-112168','checkout\\PaymentMethod','',2),(112172,'73752','watch','block-112168','checkout\\CreditAmount','',3),(112173,'73753','watch','block-112168','Html_box','',1),(112174,'73754','watch','block-112152','quote\\Products','',3),(112175,'73755','watch','checkout_no_shipping_q','BlockBox','',1),(112176,'73756','watch','block-112175','BlockBox','',2),(112177,'73757','watch','block-112176','BlockBox','',2),(112178,'73758','watch','block-112177','checkout\\Gdpr','',1),(112179,'73759','watch','block-112177','BlockBox','',5),(112180,'73760','watch','block-112179','checkout\\Comments','',2),(112181,'73761','watch','block-112179','Html_box','',1),(112182,'73762','watch','block-112177','BlockBox','',6),(112183,'73763','watch','block-112182','checkout\\CreateAccount','',3),(112184,'73764','watch','block-112182','quote\\Products','',2),(112185,'73765','watch','block-112177','BlockBox','',3),(112186,'73766','watch','block-112185','Html_box','',1),(112187,'73767','watch','block-112185','BlockBox','',2),(112188,'73768','watch','block-112187','Html_box','',1),(112189,'73769','watch','block-112187','checkout\\BillingAddress','',2),(112190,'73770','watch','block-112187-2','BlockBox','',1),(112191,'73771','watch','block-112190','checkout\\PaymentMethod','',2),(112192,'73772','watch','block-112190','Html_box','',1),(112193,'73773','watch','block-112176-2','BlockBox','',1),(112194,'73774','watch','block-112193','checkout\\ContinueBtn','',3),(112195,'73775','watch','block-112193','Html_box','',4),(112196,'73776','watch','block-112193','Html_box','',1),(112197,'73777','watch','block-112193','checkout\\Totals','',2),(112198,'73778','watch','checkout_payment','BlockBox','',1),(112199,'73779','watch','block-112198','BlockBox','',1),(112200,'73780','watch','block-112199','checkout\\BillingAddress','',2),(112201,'73781','watch','block-112199','Html_box','',1),(112202,'73782','watch','block-112198-2','BlockBox','',1),(112203,'73783','watch','block-112202','checkout\\CreditAmount','',3),(112204,'73784','watch','block-112202','BonusActions\\widgets\\BonusPointsCheckout','',4),(112205,'73785','watch','block-112202','CouponsAndVauchers\\Checkout','',5),(112206,'73786','watch','block-112202','checkout\\PaymentMethod','',2),(112207,'73787','watch','block-112202','Html_box','',1),(112208,'73788','watch','checkout_payment','BlockBox','',2),(112209,'73789','watch','block-112208','Html_box','',1),(112210,'73790','watch','block-112208-2','checkout\\ContinueBtn','',1),(112211,'73791','watch','checkout_payment_g','BlockBox','',1),(112212,'73792','watch','block-112211','BlockBox','',1),(112213,'73793','watch','block-112212','checkout\\BillingAddress','',2),(112214,'73794','watch','block-112212','Html_box','',1),(112215,'73795','watch','block-112211-2','BlockBox','',1),(112216,'73796','watch','block-112215','checkout\\CreditAmount','',3),(112217,'73797','watch','block-112215','Html_box','',1),(112218,'73798','watch','block-112215','checkout\\PaymentMethod','',2),(112219,'73799','watch','block-112215','CouponsAndVauchers\\Checkout','',5),(112220,'73800','watch','block-112215','BonusActions\\widgets\\BonusPointsCheckout','',4),(112221,'73801','watch','checkout_payment_g','BlockBox','',2),(112222,'73802','watch','block-112221','Html_box','',1),(112223,'73803','watch','block-112221-2','checkout\\ContinueBtn','',1),(112224,'73804','watch','checkout_payment_no_shipping','BlockBox','',2),(112225,'73805','watch','block-112224','Html_box','',1),(112226,'73806','watch','block-112224-2','checkout\\ContinueBtn','',1),(112227,'73807','watch','checkout_payment_no_shipping','BlockBox','',1),(112228,'73808','watch','block-112227','BlockBox','',1),(112229,'73809','watch','block-112228','Html_box','',1),(112230,'73810','watch','block-112228','checkout\\BillingAddress','',2),(112231,'73811','watch','block-112227-2','BlockBox','',1),(112232,'73812','watch','block-112231','BonusActions\\widgets\\BonusPointsCheckout','',4),(112233,'73813','watch','block-112231','CouponsAndVauchers\\Checkout','',5),(112234,'73814','watch','block-112231','checkout\\PaymentMethod','',2),(112235,'73815','watch','block-112231','checkout\\CreditAmount','',3),(112236,'73816','watch','block-112231','Html_box','',1),(112237,'73817','watch','checkout_payment_no_shipping_g','BlockBox','',2),(112238,'73818','watch','block-112237','Html_box','',1),(112239,'73819','watch','block-112237-2','checkout\\ContinueBtn','',1),(112240,'73820','watch','checkout_payment_no_shipping_g','BlockBox','',1),(112241,'73821','watch','block-112240','BlockBox','',1),(112242,'73822','watch','block-112241','checkout\\BillingAddress','',2),(112243,'73823','watch','block-112241','Html_box','',1),(112244,'73824','watch','block-112240-2','BlockBox','',1),(112245,'73825','watch','block-112244','BonusActions\\widgets\\BonusPointsCheckout','',4),(112246,'73826','watch','block-112244','checkout\\CreditAmount','',3),(112247,'73827','watch','block-112244','checkout\\PaymentMethod','',2),(112248,'73828','watch','block-112244','Html_box','',1),(112249,'73829','watch','block-112244','CouponsAndVauchers\\Checkout','',5),(112250,'73830','watch','checkout_payment_title','Html_box','',1),(112251,'73831','watch','checkout_payment_title_g','Html_box','',1),(112252,'73832','watch','checkout_payment_title_no_shipping','Html_box','',1),(112253,'73833','watch','checkout_payment_title_no_shipping_g','Html_box','',1),(112254,'73834','watch','checkout_payment_title_q','Html_box','',1),(112255,'73835','watch','checkout_payment_title_s','Html_box','',1),(112256,'73836','watch','checkout_q','BlockBox','',1),(112257,'73837','watch','block-112256','BlockBox','',2),(112258,'73838','watch','block-112257','BlockBox','',2),(112259,'73839','watch','block-112258','BlockBox','',6),(112260,'73840','watch','block-112259','checkout\\CreateAccount','',3),(112261,'73841','watch','block-112259','quote\\Products','',2),(112262,'73842','watch','block-112258','BlockBox','',2),(112263,'73843','watch','block-112262','BlockBox','',2),(112264,'73844','watch','block-112263','checkout\\ShippingChoice','',1),(112265,'73845','watch','block-112262','Neighbour\\Checkout','',4),(112266,'73846','watch','block-112262','Html_box','',1),(112267,'73847','watch','block-112262','BlockBox','',3),(112268,'73848','watch','block-112267','BlockBox','',1),(112269,'73849','watch','block-112268','checkout\\ContactInformation','',4),(112270,'73850','watch','block-112268','checkout\\ShippingAddress','',2),(112271,'73851','watch','block-112268','Html_box','',3),(112272,'73852','watch','block-112267-2','BlockBox','',1),(112273,'73853','watch','block-112272','checkout\\Shipping','',2),(112274,'73854','watch','block-112272','Html_box','',1),(112275,'73855','watch','block-112272','DelayedDespatch\\Checkout','',3),(112276,'73856','watch','block-112258','BlockBox','',5),(112277,'73857','watch','block-112276','Html_box','',1),(112278,'73858','watch','block-112276','checkout\\Comments','',2),(112279,'73860','watch','block-112258','BlockBox','',3),(112280,'73861','watch','block-112279','Html_box','',1),(112281,'73862','watch','block-112279','BlockBox','',2),(112282,'73863','watch','block-112281','checkout\\BillingAddress','',2),(112283,'73864','watch','block-112281','Html_box','',1),(112284,'73865','watch','block-112281-2','BlockBox','',1),(112285,'73866','watch','block-112284','checkout\\PaymentMethod','',2),(112286,'73867','watch','block-112284','Html_box','',1),(112287,'73868','watch','block-112257-2','BlockBox','',1),(112288,'73869','watch','block-112287','Html_box','',1),(112289,'73870','watch','block-112287','Html_box','',5),(112290,'73871','watch','block-112287','checkout\\Totals','',2),(112291,'73872','watch','block-112287','checkout\\ContinueBtn','',3),(112292,'115996','watch','block-112287','checkout\\Terms','',4),(112293,'73873','watch','checkout_s','BlockBox','',1),(112294,'73874','watch','block-112293','BlockBox','',2),(112295,'73875','watch','block-112294','BlockBox','',2),(112296,'73876','watch','block-112295','checkout\\Gdpr','',1),(112297,'73877','watch','block-112295','BlockBox','',6),(112298,'73878','watch','block-112297','sample\\Products','',1),(112299,'73879','watch','block-112297','checkout\\CreateAccount','',3),(112300,'73880','watch','block-112295','BlockBox','',2),(112301,'73881','watch','block-112300','Html_box','',1),(112302,'73882','watch','block-112300','Neighbour\\Checkout','',4),(112303,'73883','watch','block-112300','BlockBox','',2),(112304,'73884','watch','block-112303','checkout\\ShippingChoice','',1),(112305,'73885','watch','block-112300','BlockBox','',3),(112306,'73886','watch','block-112305','BlockBox','',1),(112307,'73887','watch','block-112306','checkout\\ShippingAddress','',2),(112308,'73888','watch','block-112306','checkout\\ContactInformation','',4),(112309,'73889','watch','block-112306','Html_box','',3),(112310,'73890','watch','block-112305-2','BlockBox','',1),(112311,'73891','watch','block-112310','checkout\\Shipping','',2),(112312,'73892','watch','block-112310','DelayedDespatch\\Checkout','',3),(112313,'73893','watch','block-112310','Html_box','',1),(112314,'73894','watch','block-112295','BlockBox','',3),(112315,'73895','watch','block-112314','BlockBox','',2),(112316,'73896','watch','block-112315','Html_box','',1),(112317,'73897','watch','block-112315','checkout\\BillingAddress','',2),(112318,'73898','watch','block-112315-2','BlockBox','',1),(112319,'73899','watch','block-112318','Html_box','',1),(112320,'73900','watch','block-112318','checkout\\PaymentMethod','',2),(112321,'73901','watch','block-112314','Html_box','',1),(112322,'73902','watch','block-112295','BlockBox','',5),(112323,'73903','watch','block-112322','Html_box','',1),(112324,'73904','watch','block-112322','checkout\\Comments','',2),(112325,'73905','watch','block-112295','BlockBox','',4),(112326,'73906','watch','block-112325','BlockBox','',2),(112327,'73907','watch','block-112326','CouponsAndVauchers\\Checkout','',1),(112328,'73908','watch','block-112326-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(112329,'73909','watch','block-112326-2','checkout\\CreditAmount','',1),(112330,'73910','watch','block-112325','Html_box','',1),(112331,'73911','watch','block-112294-2','BlockBox','',1),(112332,'73912','watch','block-112331','checkout\\Totals','',2),(112333,'73913','watch','block-112331','Html_box','',5),(112334,'73914','watch','block-112331','Html_box','',1),(112335,'73915','watch','block-112331','checkout\\ContinueBtn','',3),(112336,'115998','watch','block-112331','checkout\\Terms','',4),(112337,'73916','watch','checkout_step_bottom','Html_box','',1),(112338,'73917','watch','checkout_step_bottom','cart\\Products','',2),(112339,'73918','watch','checkout_step_bottom','checkout\\Totals','',3),(112340,'73919','watch','checkout_step_bottom_g','checkout\\Totals','',3),(112341,'73920','watch','checkout_step_bottom_g','quote\\Products','',2),(112342,'73921','watch','checkout_step_bottom_g','Html_box','',1),(112343,'73923','watch','checkout_step_bottom_no_shipping','Html_box','',1),(112344,'73924','watch','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(112345,'73927','watch','checkout_step_bottom_no_shipping','cart\\Products','',2),(112346,'73922','watch','checkout_step_bottom_no_shipping_g','Html_box','',1),(112347,'73925','watch','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(112348,'73926','watch','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(112349,'73928','watch','communication','BlockBox','',1),(112350,'73929','watch','block-112349','Html_box','',2),(112351,'73930','watch','block-112349','Communication\\NewTopicButton','',1),(112352,'73931','watch','block-112349','Communication\\Topic','',3),(112353,'94704','watch','compare','BlockBox','',1),(112354,'94705','watch','block-112353','catalog\\Compare','',1),(112355,'94706','watch','compare_products','BlockBox','',2),(112356,'94707','watch','block-112355','productListing\\rating','',4),(112357,'94708','watch','block-112355','productListing\\model','',5),(112358,'94709','watch','block-112355','productListing\\compare','',1),(112359,'94710','watch','block-112355','BlockBox','',2),(112360,'94711','watch','block-112359','productListing\\image','',1),(112361,'94712','watch','block-112359-2','productListing\\name','',2),(112362,'94713','watch','block-112355','BlockBox','',3),(112363,'94714','watch','block-112362','productListing\\price','',1),(112364,'94715','watch','block-112362-2','productListing\\buyButton','',1),(112365,'73932','watch','confirmation','BlockBox','',1),(112366,'73933','watch','block-112365','BlockBox','',2),(112367,'73934','watch','block-112366','BlockBox','',2),(112368,'73935','watch','block-112367','BlockBox','',3),(112369,'73936','watch','block-112368','checkout\\EditBtn','',2),(112370,'73937','watch','block-112368','cart\\Products','',3),(112371,'73938','watch','block-112368','Html_box','',1),(112372,'73939','watch','block-112367','BlockBox','',2),(112373,'73940','watch','block-112372','checkout\\EditBtn','',2),(112374,'73941','watch','block-112372','Html_box','',1),(112375,'73942','watch','block-112372','checkout\\CommentsConfirm','',3),(112376,'73943','watch','block-112367','BlockBox','',1),(112377,'73944','watch','block-112376','BlockBox','',1),(112378,'73945','watch','block-112377','checkout\\EditBtn','',6),(112379,'73946','watch','block-112377','DelayedDespatch\\CheckoutConfirm','',8),(112380,'73947','watch','block-112377','Html_box','',9),(112381,'73948','watch','block-112377','checkout\\EditBtn','',10),(112382,'73949','watch','block-112377','Html_box','',5),(112383,'73950','watch','block-112377','checkout\\ShippingConfirm','',7),(112384,'73951','watch','block-112377','Html_box','',1),(112385,'73952','watch','block-112377','checkout\\EditBtn','',3),(112386,'73953','watch','block-112377','checkout\\ContactConfirm','',11),(112387,'73954','watch','block-112377','Html_box','',2),(112388,'73955','watch','block-112377','checkout\\ShippingAddressConfirm','',4),(112389,'73956','watch','block-112376-2','BlockBox','',1),(112390,'73957','watch','block-112389','checkout\\EditBtn','',6),(112391,'73958','watch','block-112389','checkout\\EditBtn','',3),(112392,'73959','watch','block-112389','checkout\\PaymentMethodConfirm','',7),(112393,'73960','watch','block-112389','Html_box','',5),(112394,'73961','watch','block-112389','Html_box','',1),(112395,'73962','watch','block-112389','checkout\\BillingAddressConfirm','',4),(112396,'73963','watch','block-112389','Html_box','',2),(112397,'73964','watch','block-112366','UploadCustomerId\\UploadCustomerIdForm','',1),(112398,'73965','watch','block-112366-2','BlockBox','',1),(112399,'73966','watch','block-112398','Html_box','',1),(112400,'73967','watch','block-112398','checkout\\ConfirmBtn','',3),(112401,'73968','watch','block-112398','checkout\\Totals','',2),(112402,'73969','watch','block-112365','Html_box','',1),(112403,'73970','watch','confirmation_free_s','BlockBox','',1),(112404,'73971','watch','block-112403','BlockBox','',2),(112405,'73972','watch','block-112404','BlockBox','',1),(112406,'73973','watch','block-112405','BlockBox','',2),(112407,'73974','watch','block-112406','checkout\\CommentsConfirm','',3),(112408,'73975','watch','block-112406','checkout\\EditBtn','',2),(112409,'73976','watch','block-112406','Html_box','',1),(112410,'73977','watch','block-112405','BlockBox','',3),(112411,'73978','watch','block-112410','checkout\\EditBtn','',3),(112412,'73979','watch','block-112410','Html_box','',1),(112413,'73980','watch','block-112410','sample\\Products','',2),(112414,'73981','watch','block-112405','BlockBox','',1),(112415,'73982','watch','block-112414','BlockBox','',1),(112416,'73983','watch','block-112415','checkout\\EditBtn','',3),(112417,'73984','watch','block-112415','checkout\\ShippingConfirm','',7),(112418,'73985','watch','block-112415','Html_box','',5),(112419,'73986','watch','block-112415','checkout\\EditBtn','',6),(112420,'73987','watch','block-112415','Html_box','',2),(112421,'73988','watch','block-112415','checkout\\ShippingAddressConfirm','',4),(112422,'73989','watch','block-112414-2','BlockBox','',1),(112423,'73990','watch','block-112422','checkout\\ContactConfirm','',3),(112424,'73991','watch','block-112422','DelayedDespatch\\CheckoutConfirm','',4),(112425,'73992','watch','block-112422','checkout\\EditBtn','',2),(112426,'73993','watch','block-112422','Html_box','',1),(112427,'73994','watch','block-112404-2','BlockBox','',1),(112428,'73995','watch','block-112427','checkout\\ConfirmBtn','',3),(112429,'73996','watch','block-112403','Html_box','',1),(112430,'73997','watch','confirmation_no_shipping','BlockBox','',1),(112431,'73998','watch','block-112430','Html_box','',1),(112432,'73999','watch','block-112430','BlockBox','',2),(112433,'74000','watch','block-112432','BlockBox','',1),(112434,'74001','watch','block-112433','BlockBox','',1),(112435,'74002','watch','block-112434','BlockBox','',1),(112436,'74003','watch','block-112435','checkout\\EditBtn','',10),(112437,'74004','watch','block-112435','Html_box','',9),(112438,'74005','watch','block-112435','checkout\\ContactConfirm','',11),(112439,'74006','watch','block-112434-2','BlockBox','',1),(112440,'74007','watch','block-112439','checkout\\PaymentMethodConfirm','',7),(112441,'74008','watch','block-112439','checkout\\EditBtn','',6),(112442,'74009','watch','block-112439','Html_box','',5),(112443,'74010','watch','block-112439','Html_box','',1),(112444,'74011','watch','block-112439','checkout\\EditBtn','',3),(112445,'74012','watch','block-112439','checkout\\BillingAddressConfirm','',4),(112446,'74013','watch','block-112439','Html_box','',2),(112447,'74014','watch','block-112433','BlockBox','',2),(112448,'74015','watch','block-112447','Html_box','',1),(112449,'74016','watch','block-112447','checkout\\CommentsConfirm','',3),(112450,'74017','watch','block-112447','checkout\\EditBtn','',2),(112451,'74018','watch','block-112433','BlockBox','',3),(112452,'74019','watch','block-112451','Html_box','',1),(112453,'74020','watch','block-112451','checkout\\EditBtn','',2),(112454,'74021','watch','block-112451','cart\\Products','',3),(112455,'74022','watch','block-112432-2','BlockBox','',1),(112456,'74023','watch','block-112455','checkout\\ConfirmBtn','',3),(112457,'74024','watch','block-112455','Html_box','',1),(112458,'74025','watch','block-112455','checkout\\Totals','',2),(112459,'74026','watch','confirmation_no_shipping_q','BlockBox','',2),(112460,'74027','watch','block-112459','Html_box','',1),(112461,'74028','watch','block-112459','BlockBox','',2),(112462,'74029','watch','block-112461','BlockBox','',1),(112463,'74030','watch','block-112462','BlockBox','',2),(112464,'74031','watch','block-112463','Html_box','',1),(112465,'74032','watch','block-112463','checkout\\CommentsConfirm','',3),(112466,'74033','watch','block-112463','checkout\\EditBtn','',2),(112467,'74034','watch','block-112462','BlockBox','',1),(112468,'74035','watch','block-112467','BlockBox','',1),(112469,'74036','watch','block-112468','checkout\\EditBtn','',5),(112470,'74037','watch','block-112468','checkout\\ContactConfirm','',6),(112471,'74038','watch','block-112468','checkout\\PaymentMethodConfirm','',3),(112472,'74039','watch','block-112468','checkout\\EditBtn','',2),(112473,'74040','watch','block-112468','Html_box','',4),(112474,'74041','watch','block-112468','Html_box','',1),(112475,'74042','watch','block-112467-2','BlockBox','',1),(112476,'74043','watch','block-112475','checkout\\BillingAddressConfirm','',4),(112477,'74044','watch','block-112475','checkout\\EditBtn','',3),(112478,'74045','watch','block-112475','Html_box','',2),(112479,'74046','watch','block-112462','BlockBox','',3),(112480,'74047','watch','block-112479','checkout\\EditBtn','',2),(112481,'74048','watch','block-112479','Html_box','',1),(112482,'74049','watch','block-112479','quote\\Products','',3),(112483,'74050','watch','block-112461-2','BlockBox','',1),(112484,'74051','watch','block-112483','checkout\\ConfirmBtn','',3),(112485,'74052','watch','block-112483','checkout\\Totals','',2),(112486,'74053','watch','block-112483','Html_box','',1),(112487,'74054','watch','confirmation_q','BlockBox','',1),(112488,'74055','watch','block-112487','Html_box','',1),(112489,'74056','watch','block-112487','BlockBox','',2),(112490,'74057','watch','block-112489','BlockBox','',1),(112491,'74058','watch','block-112490','BlockBox','',3),(112492,'74059','watch','block-112491','quote\\Products','',3),(112493,'74060','watch','block-112491','Html_box','',1),(112494,'74061','watch','block-112491','checkout\\EditBtn','',2),(112495,'74062','watch','block-112490','BlockBox','',1),(112496,'74063','watch','block-112495','BlockBox','',1),(112497,'74064','watch','block-112496','Html_box','',1),(112498,'74065','watch','block-112496','checkout\\EditBtn','',10),(112499,'74066','watch','block-112496','Html_box','',2),(112500,'74067','watch','block-112496','checkout\\ContactConfirm','',11),(112501,'74068','watch','block-112496','checkout\\ShippingAddressConfirm','',4),(112502,'74069','watch','block-112496','checkout\\ShippingConfirm','',7),(112503,'74070','watch','block-112496','checkout\\EditBtn','',3),(112504,'74071','watch','block-112496','DelayedDespatch\\CheckoutConfirm','',8),(112505,'74072','watch','block-112496','Html_box','',9),(112506,'74073','watch','block-112496','Html_box','',5),(112507,'74074','watch','block-112496','checkout\\EditBtn','',6),(112508,'74075','watch','block-112495-2','BlockBox','',1),(112509,'74076','watch','block-112508','checkout\\EditBtn','',3),(112510,'74077','watch','block-112508','checkout\\BillingAddressConfirm','',4),(112511,'74078','watch','block-112508','checkout\\PaymentMethodConfirm','',7),(112512,'74079','watch','block-112508','Html_box','',1),(112513,'74080','watch','block-112508','Html_box','',2),(112514,'74081','watch','block-112508','checkout\\EditBtn','',6),(112515,'74082','watch','block-112508','Html_box','',5),(112516,'74083','watch','block-112490','BlockBox','',2),(112517,'74084','watch','block-112516','checkout\\CommentsConfirm','',3),(112518,'74085','watch','block-112516','Html_box','',1),(112519,'74086','watch','block-112516','checkout\\EditBtn','',2),(112520,'74087','watch','block-112489-2','BlockBox','',1),(112521,'74088','watch','block-112520','Html_box','',1),(112522,'74089','watch','block-112520','checkout\\Totals','',2),(112523,'74090','watch','block-112520','checkout\\ConfirmBtn','',3),(112524,'74091','watch','confirmation_s','BlockBox','',1),(112525,'74092','watch','block-112524','BlockBox','',2),(112526,'74093','watch','block-112525','BlockBox','',1),(112527,'74094','watch','block-112526','BlockBox','',1),(112528,'74095','watch','block-112527','BlockBox','',1),(112529,'74096','watch','block-112528','checkout\\ShippingAddressConfirm','',4),(112530,'74097','watch','block-112528','checkout\\EditBtn','',3),(112531,'74098','watch','block-112528','Html_box','',2),(112532,'74099','watch','block-112528','DelayedDespatch\\CheckoutConfirm','',8),(112533,'74100','watch','block-112528','checkout\\ShippingConfirm','',7),(112534,'74101','watch','block-112528','Html_box','',1),(112535,'74102','watch','block-112528','Html_box','',5),(112536,'74103','watch','block-112528','Html_box','',9),(112537,'74104','watch','block-112528','checkout\\ContactConfirm','',11),(112538,'74105','watch','block-112528','checkout\\EditBtn','',6),(112539,'74106','watch','block-112528','checkout\\EditBtn','',10),(112540,'74107','watch','block-112527-2','BlockBox','',1),(112541,'74108','watch','block-112540','Html_box','',2),(112542,'74109','watch','block-112540','checkout\\BillingAddressConfirm','',4),(112543,'74110','watch','block-112540','checkout\\EditBtn','',3),(112544,'74111','watch','block-112540','checkout\\PaymentMethodConfirm','',7),(112545,'74112','watch','block-112540','checkout\\EditBtn','',6),(112546,'74113','watch','block-112540','Html_box','',1),(112547,'74114','watch','block-112540','Html_box','',5),(112548,'74115','watch','block-112526','BlockBox','',3),(112549,'74116','watch','block-112548','checkout\\EditBtn','',3),(112550,'74117','watch','block-112548','Html_box','',1),(112551,'74118','watch','block-112548','sample\\Products','',2),(112552,'74119','watch','block-112526','BlockBox','',2),(112553,'74120','watch','block-112552','Html_box','',1),(112554,'74121','watch','block-112552','checkout\\EditBtn','',2),(112555,'74122','watch','block-112552','checkout\\CommentsConfirm','',3),(112556,'74123','watch','block-112525-2','BlockBox','',1),(112557,'74124','watch','block-112556','checkout\\Totals','',2),(112558,'74125','watch','block-112556','checkout\\ConfirmBtn','',3),(112559,'74126','watch','block-112556','Html_box','',1),(112560,'74127','watch','block-112524','Html_box','',1),(112561,'74128','watch','contact','BlockBox','',1),(112562,'74132','watch','block-112561','info\\Title','',1),(112563,'74133','watch','block-112561','BlockBox','',3),(112564,'74134','watch','block-112563','contact\\ContactForm','',1),(112565,'74135','watch','block-112563-2','contact\\Contacts','',1),(112566,'74136','watch','created_success','BlockBox','',1),(112567,'74137','watch','block-112566','Html_box','',1),(112568,'74138','watch','block-112566','Html_box','',2),(112569,'74139','watch','credit_note','invoice\\Container','',1),(112570,'74140','watch','block-112569','BlockBox','',5),(112571,'74141','watch','block-112570','invoice\\StoreAddress','',8),(112572,'74142','watch','block-112570','Text','',1),(112573,'74143','watch','block-112570-2','Text','',2),(112574,'74144','watch','block-112570-2','Logo','',1),(112575,'74145','watch','block-112570-3','Text','',1),(112576,'74146','watch','block-112570-3','BlockBox','',3),(112577,'74147','watch','block-112576','Text','',1),(112578,'74148','watch','block-112576-2','invoice\\StoreEmail','',1),(112579,'74149','watch','block-112570-3','BlockBox','',2),(112580,'74150','watch','block-112579','Text','',1),(112581,'74151','watch','block-112579-2','invoice\\StorePhone','',1),(112582,'74152','watch','block-112569','invoice\\Products','',3),(112583,'74153','watch','block-112569','BlockBox','',1),(112584,'74154','watch','block-112583','Logo','',1),(112585,'74155','watch','block-112583-2','BlockBox','',4),(112586,'74156','watch','block-112585','Text','',1),(112587,'74157','watch','block-112585-2','invoice\\StoreSite','',1),(112588,'74158','watch','block-112583-2','BlockBox','',2),(112589,'74159','watch','block-112588','Text','',1),(112590,'74160','watch','block-112588-2','invoice\\StorePhone','',1),(112591,'74161','watch','block-112583-2','BlockBox','',3),(112592,'74162','watch','block-112591','Text','',1),(112593,'74163','watch','block-112591-2','invoice\\StoreEmail','',1),(112594,'74164','watch','block-112583-2','BlockBox','',1),(112595,'74165','watch','block-112594','invoice\\StoreAddress','',1),(112596,'74166','watch','block-112569','BlockBox','',4),(112597,'74167','watch','block-112596','BlockBox','',1),(112598,'74168','watch','block-112597','invoice\\ShippingAddress','',2),(112599,'74169','watch','block-112597','Text','',1),(112600,'74170','watch','block-112596-2','BlockBox','',1),(112601,'74171','watch','block-112569','BlockBox','',2),(112602,'74172','watch','block-112601','BlockBox','',7),(112603,'74173','watch','block-112602','BlockBox','',1),(112604,'74174','watch','block-112603','Text','',1),(112605,'74175','watch','block-112603','invoice\\BillingAddress','',2),(112606,'74176','watch','block-112602-2','BlockBox','',1),(112607,'74177','watch','block-112606','invoice\\CustomerPhone','',4),(112608,'74178','watch','block-112606','Text','',1),(112609,'74179','watch','block-112606','Text','',3),(112610,'74180','watch','block-112606','invoice\\CustomerName','',2),(112611,'74181','watch','block-112606','invoice\\CustomerEmail','',6),(112612,'74182','watch','block-112606','Text','',5),(112613,'74183','watch','block-112601','BlockBox','',8),(112614,'74184','watch','block-112613','BlockBox','',1),(112615,'74185','watch','block-112614','invoice\\ShippingMethod','',2),(112616,'74186','watch','block-112614','Text','',1),(112617,'74187','watch','block-112613-2','BlockBox','',1),(112618,'74188','watch','block-112617','Text','',1),(112619,'74189','watch','block-112617','invoice\\ShippingMethod','',2),(112620,'74190','watch','block-112601-2','invoice\\OrderId','',1),(112621,'74191','watch','block-112601-2','Text','',2),(112622,'74192','watch','block-112601-2','invoice\\PaymentDate','',3),(112623,'74193','watch','delivery-location','DeliveryLocation\\FeaturedList','',6),(112624,'74194','watch','delivery-location','DeliveryLocation\\LocationLongDescription','',5),(112625,'74195','watch','delivery-location','DeliveryLocation\\LocationList','',7),(112626,'74196','watch','delivery-location','DeliveryLocation\\LocationTitle','',2),(112627,'74197','watch','delivery-location','DeliveryLocation\\LocationProducts','',8),(112628,'74198','watch','delivery-location','DeliveryLocation\\LocationDescription','',3),(112629,'74199','watch','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(112630,'74200','watch','delivery-location-default','DeliveryLocation\\TopLocationList','',2),(112631,'74201','watch','delivery-location-default','Heading','',1),(112632,'94716','watch','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(112633,'94717','watch','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(112634,'94718','watch','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(112635,'94719','watch','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(112636,'94720','watch','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(112637,'94721','watch','delivery_loc_2','DeliveryLocation\\LocationList','',7),(112638,'94722','watch','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(112639,'74202','watch','email','email\\BlockBox','',1),(112640,'74203','watch','block-112639','email\\BlockBox','',1),(112641,'74204','watch','block-112640','Copyright','',4),(112642,'74205','watch','block-112640','email\\Content','',3),(112643,'74206','watch','block-112640','email\\BlockBox','',2),(112644,'74207','watch','block-112643','email\\Title','',1),(112645,'74208','watch','block-112643-2','email\\Date','',1),(112646,'74209','watch','block-112640','Logo','',1),(112647,'74210','watch','email_2','email\\BlockBox','',1),(112648,'74211','watch','block-112647','email\\BlockBox','',1),(112649,'74212','watch','block-112648','Copyright','',4),(112650,'74213','watch','block-112648','Logo','',1),(112651,'74214','watch','block-112648','email\\Content','',3),(112652,'74215','watch','block-112648','email\\BlockBox','',2),(112653,'74216','watch','block-112652','email\\Title','',1),(112654,'74217','watch','block-112652-2','email\\Date','',1),(112655,'74218','watch','email_3','email\\BlockBox','',1),(112656,'74219','watch','block-112655','email\\BlockBox','',1),(112657,'74220','watch','block-112656','email\\BlockBox','',2),(112658,'74221','watch','block-112657','email\\Content','',2),(112659,'74222','watch','block-112657','email\\BlockBox','',1),(112660,'74223','watch','block-112659','email\\Title','',1),(112661,'74224','watch','block-112659-2','email\\Date','',1),(112662,'74225','watch','block-112656','Copyright','',3),(112663,'74226','watch','block-112656','Logo','',1),(112664,'74227','watch','email_4','email\\BlockBox','',1),(112665,'74228','watch','block-112664','email\\BlockBox','',1),(112666,'74229','watch','block-112665','Copyright','',2),(112667,'74230','watch','block-112665','email\\BlockBox','',1),(112668,'74231','watch','block-112667','email\\BlockBox','',1),(112669,'74232','watch','block-112668','Logo','',1),(112670,'74233','watch','block-112668-2','email\\Date','',2),(112671,'74234','watch','block-112668-2','email\\Title','',1),(112672,'74235','watch','block-112667','email\\Content','',2),(112673,'74236','watch','footer','BlockBox','',1),(112674,'74237','watch','block-112673','BlockBox','',1),(112675,'74238','watch','block-112674','BlockBox','',1),(112676,'74239','watch','block-112675','Menu','footer3',3),(112677,'1695906739.5696','watch','block-112675','Html_box','',2),(112678,'74241','watch','block-112674-2','BlockBox','',1),(112679,'74243','watch','block-112678','Menu','footer1',3),(112680,'1695906751.0591','watch','block-112678','Html_box','',2),(112681,'74244','watch','block-112674-3','BlockBox','',1),(112682,'74246','watch','block-112681','Menu','footer2',3),(112683,'1695906756.0887','watch','block-112681','Html_box','',2),(112684,'74247','watch','block-112674-4','BlockBox','',1),(112685,'74248','watch','block-112684','Contacts','',4),(112686,'74249','watch','block-112684','Contacts','',3),(112687,'1695906761.6568','watch','block-112684','Html_box','',2),(112688,'74256','watch','block-112673','BlockBox','footer-content',4),(112689,'74257','watch','block-112688','Copyright','',1),(112690,'74258','watch','block-112688-2','invoice\\StoreAddress','',1),(112691,'94723','watch','for_menu','BlockBox','',1),(112692,'94724','watch','block-112691','Html_box','',1),(112693,'94725','watch','block-112691-2','Languages','',1),(112694,'94726','watch','for_menu','BlockBox','',3),(112695,'94727','watch','block-112694','Html_box','',1),(112696,'94728','watch','block-112694-2','Currencies','',1),(112697,'74263','watch','gift','BlockBox','',1),(112698,'74264','watch','block-112697','BlockBox','',3),(112699,'74265','watch','block-112698','BlockBox','',1),(112700,'74266','watch','block-112699','gift\\Card','',1),(112701,'74267','watch','block-112698-2','gift\\Form','',2),(112702,'74268','watch','block-112698-2','Text','',1),(112703,'74269','watch','block-112697','info\\Title','',1),(112704,'74270','watch','gift_card','BlockBox','',1),(112705,'74271','watch','block-112704','BlockBox','',11),(112706,'74272','watch','block-112705','invoice\\StoreEmail','',3),(112707,'74273','watch','block-112705','Text','',1),(112708,'74274','watch','block-112705','invoice\\StorePhone','',2),(112709,'74275','watch','block-112704','Text','',8),(112710,'74276','watch','block-112704','Text','',3),(112711,'74277','watch','block-112704','BlockBox','',10),(112712,'74278','watch','block-112711','Text','',1),(112713,'74279','watch','block-112711-2','gift\\CodeView','',1),(112714,'74280','watch','block-112704','gift\\MessageView','',7),(112715,'74281','watch','block-112704','gift\\AmountView','',5),(112716,'74282','watch','block-112704','Text','',6),(112717,'74284','watch','block-112704','Logo','',1),(112718,'74285','watch','block-112704','Text','',4),(112719,'74286','watch','block-112704','Text','',9),(112720,'74287','watch','gift_card_2','BlockBox','',1),(112721,'74288','watch','block-112720','gift\\AmountView','',3),(112722,'74289','watch','block-112720','BlockBox','',8),(112723,'74290','watch','block-112722','Text','',1),(112724,'74291','watch','block-112722-2','gift\\CodeView','',1),(112725,'74292','watch','block-112720','BlockBox','',9),(112726,'74293','watch','block-112725','invoice\\StoreEmail','',3),(112727,'74294','watch','block-112725','Text','',1),(112728,'74295','watch','block-112725','invoice\\StorePhone','',2),(112729,'74296','watch','block-112720','gift\\MessageView','',5),(112730,'74297','watch','block-112720','Text','',4),(112731,'74298','watch','block-112720','Text','',7),(112732,'74299','watch','block-112720','Text','',2),(112733,'74300','watch','block-112720','Text','',6),(112734,'74301','watch','block-112720','Text','',1),(112735,'94729','watch','gift_card_2_pdf','BlockBox','',1),(112736,'94730','watch','block-112735','BlockBox','',12),(112737,'94731','watch','block-112736','invoice\\StoreEmail','',4),(112738,'94732','watch','block-112736','invoice\\StorePhone','',3),(112739,'94733','watch','block-112736','Html_box','',1),(112740,'94734','watch','block-112735','BlockBox','',11),(112741,'94735','watch','block-112740','Html_box','',1),(112742,'94736','watch','block-112740-2','gift\\CodeViewPdf','',1),(112743,'94737','watch','block-112735','BlockBox','',1),(112744,'94738','watch','block-112743','Text','',4),(112745,'94739','watch','block-112743','Html_box','',1),(112746,'94740','watch','block-112743','Html_box','',2),(112747,'94741','watch','block-112743','gift\\AmountViewPdf','',3),(112748,'94742','watch','block-112743','gift\\MessageViewPdf','',5),(112749,'94743','watch','block-112743','Html_box','',7),(112750,'94744','watch','block-112743','Html_box','',6),(112751,'94746','watch','gift_card_pdf','BlockBox','',1),(112752,'94747','watch','block-112751','BlockBox','',12),(112753,'94748','watch','block-112752','invoice\\StoreEmail','',4),(112754,'94749','watch','block-112752','invoice\\StorePhone','',3),(112755,'94750','watch','block-112752','Html_box','',1),(112756,'94751','watch','block-112751','BlockBox','',11),(112757,'94752','watch','block-112756','Html_box','',1),(112758,'94753','watch','block-112756-2','gift\\CodeViewPdf','',1),(112759,'94754','watch','block-112751','BlockBox','',1),(112760,'94755','watch','block-112759','Text','',5),(112761,'94757','watch','block-112759','Html_box','',3),(112762,'94758','watch','block-112759','gift\\AmountViewPdf','',4),(112763,'94759','watch','block-112759','gift\\MessageViewPdf','',6),(112764,'94760','watch','block-112759','Html_box','',8),(112765,'94761','watch','block-112759','Html_box','',7),(112766,'1707902674.2595','watch','block-112759','Logo','',2),(112767,'94762','watch','gift_card_pdf','Import','',1),(112768,'74302','watch','gift_certificate','BlockBox','',1),(112769,'74303','watch','block-112768','account\\ApplyCertificate','',2),(112770,'74304','watch','block-112768','Html_box','',1),(112771,'74305','watch','gigt_card_3','BlockBox','',1),(112772,'74306','watch','block-112771','BlockBox','',8),(112773,'74307','watch','block-112772','Text','',1),(112774,'74308','watch','block-112772-2','gift\\CodeView','',1),(112775,'74309','watch','block-112771','Text','',6),(112776,'74310','watch','block-112771','Text','',1),(112777,'74311','watch','block-112771','BlockBox','',9),(112778,'74312','watch','block-112777','Text','',1),(112779,'74313','watch','block-112777','invoice\\StoreEmail','',3),(112780,'74314','watch','block-112777','invoice\\StorePhone','',2),(112781,'74315','watch','block-112771','gift\\MessageView','',5),(112782,'74316','watch','block-112771','Text','',2),(112783,'74317','watch','block-112771','Text','',4),(112784,'74318','watch','block-112771','gift\\AmountView','',3),(112785,'74319','watch','block-112771','Text','',7),(112786,'94763','watch','gigt_card_3_pdf','BlockBox','',1),(112787,'94764','watch','block-112786','BlockBox','',12),(112788,'94765','watch','block-112787','invoice\\StoreEmail','',4),(112789,'94766','watch','block-112787','invoice\\StorePhone','',3),(112790,'94767','watch','block-112787','Html_box','',1),(112791,'94768','watch','block-112786','BlockBox','',11),(112792,'94769','watch','block-112791','Html_box','',1),(112793,'94770','watch','block-112791-2','gift\\CodeViewPdf','',1),(112794,'94771','watch','block-112786','BlockBox','',1),(112795,'94772','watch','block-112794','Text','',4),(112796,'94773','watch','block-112794','Html_box','',1),(112797,'94774','watch','block-112794','Html_box','',2),(112798,'94775','watch','block-112794','gift\\AmountViewPdf','',3),(112799,'94776','watch','block-112794','gift\\MessageViewPdf','',5),(112800,'94777','watch','block-112794','Html_box','',7),(112801,'94778','watch','block-112794','Html_box','',6),(112821,'74346','watch','info','BlockBox','info-content',1),(112822,'74347','watch','block-112821','info\\DescriptionShort','',2),(112823,'74348','watch','block-112821','info\\Content','',4),(112824,'74349','watch','block-112821','info\\Title','',1),(112825,'74350','watch','block-112821','info\\Image','',3),(112826,'74351','watch','invoice','invoice\\Container','',1),(112827,'74352','watch','block-112826','BlockBox','',3),(112828,'74353','watch','block-112827','BlockBox','',8),(112829,'74354','watch','block-112828','BlockBox','',1),(112830,'74355','watch','block-112829','invoice\\ShippingMethod','',2),(112831,'74356','watch','block-112829','Text','',1),(112832,'74357','watch','block-112828-2','BlockBox','',1),(112833,'74358','watch','block-112832','Text','',1),(112834,'74359','watch','block-112832','invoice\\ShippingMethod','',2),(112835,'74360','watch','block-112827','BlockBox','',7),(112836,'74361','watch','block-112835','BlockBox','',1),(112837,'74362','watch','block-112836','Text','',1),(112838,'74363','watch','block-112836','invoice\\BillingAddress','',2),(112839,'74364','watch','block-112835-2','BlockBox','',1),(112840,'74365','watch','block-112839','Text','',5),(112841,'74366','watch','block-112839','invoice\\CustomerName','',2),(112842,'74367','watch','block-112839','invoice\\CustomerPhone','',4),(112843,'74368','watch','block-112839','Text','',1),(112844,'74369','watch','block-112839','Text','',3),(112845,'74370','watch','block-112839','invoice\\CustomerEmail','',6),(112846,'74371','watch','block-112827-2','invoice\\PaymentMethod','',5),(112847,'74372','watch','block-112827-2','Text','',4),(112848,'74373','watch','block-112827-2','Text','',2),(112849,'74374','watch','block-112827-2','invoice\\OrderId','',1),(112850,'74375','watch','block-112827-2','invoice\\PaymentDate','',3),(112851,'74376','watch','block-112827-2','invoice\\OrderBarcode','',6),(112852,'74377','watch','block-112826','BlockBox','',6),(112853,'74378','watch','block-112852','invoice\\StoreAddress','',8),(112854,'74379','watch','block-112852','Text','',1),(112855,'74380','watch','block-112852-2','Text','',2),(112856,'74381','watch','block-112852-2','Logo','',1),(112857,'74382','watch','block-112852-3','BlockBox','',3),(112858,'74383','watch','block-112857','Text','',1),(112859,'74384','watch','block-112857-2','invoice\\StoreEmail','',1),(112860,'74385','watch','block-112852-3','BlockBox','',2),(112861,'74386','watch','block-112860','Text','',1),(112862,'74387','watch','block-112860-2','invoice\\StorePhone','',1),(112863,'74388','watch','block-112852-3','Text','',1),(112864,'74389','watch','block-112826','invoice\\Products','',4),(112865,'74390','watch','block-112826','BlockBox','',5),(112866,'74391','watch','block-112865','BlockBox','',1),(112867,'74392','watch','block-112866','invoice\\ShippingAddress','',2),(112868,'74393','watch','block-112866','Text','',1),(112869,'74394','watch','block-112865-2','BlockBox','',1),(112870,'74395','watch','block-112869','invoice\\Totals','',1),(112871,'74396','watch','block-112826','BlockBox','',2),(112872,'74397','watch','block-112871','Logo','',1),(112873,'74398','watch','block-112871-2','BlockBox','',4),(112874,'74399','watch','block-112873','Text','',1),(112875,'74400','watch','block-112873-2','invoice\\StoreSite','',1),(112876,'74401','watch','block-112871-2','BlockBox','',3),(112877,'74402','watch','block-112876','Text','',1),(112878,'74403','watch','block-112876-2','invoice\\StoreEmail','',1),(112879,'74404','watch','block-112871-2','BlockBox','',1),(112880,'74405','watch','block-112879','invoice\\StoreAddress','',3),(112881,'74406','watch','block-112871-2','BlockBox','',2),(112882,'74407','watch','block-112881','Text','',1),(112883,'74408','watch','block-112881-2','invoice\\StorePhone','',1),(112884,'74409','watch','login_account','BlockBox','',1),(112885,'74410','watch','block-112884','Tabs','',2),(112886,'74411','watch','block-112885-1','login\\Returning','',1),(112887,'74412','watch','block-112885-2','BlockBox','',1),(112888,'74413','watch','block-112887','Html_box','',1),(112889,'74414','watch','block-112887-2','BlockBox','',1),(112890,'74415','watch','block-112889','Html_box','',2),(112891,'74416','watch','block-112889','login\\Register','',1),(112892,'74417','watch','block-112884','BlockBox','',1),(112893,'74418','watch','block-112892','Html_box','',3),(112894,'74419','watch','block-112892','Html_box','',1),(112895,'74420','watch','block-112892','login\\Socials','',2),(112896,'74421','watch','login_checkout','BlockBox','',1),(112897,'74422','watch','block-112896','BlockBox','',1),(112898,'74423','watch','block-112897','checkout\\CreateBtn','',4),(112899,'74424','watch','block-112897','checkout\\GuestBtn','',2),(112900,'74425','watch','block-112897','Html_box','',3),(112901,'74426','watch','block-112897','BlockBox','',5),(112902,'74427','watch','block-112901','Html_box','',1),(112903,'74428','watch','block-112901','login\\Socials','',2),(112904,'74429','watch','block-112897','Html_box','',1),(112905,'74430','watch','block-112897-2','login\\Returning','',2),(112906,'74431','watch','block-112897-2','Html_box','',1),(112907,'74432','watch','login_checkout2','BlockBox','',1),(112908,'74433','watch','block-112907','Tabs','',4),(112909,'74434','watch','block-112908-1','BlockBox','',1),(112910,'74435','watch','block-112909','Html_box','',1),(112911,'74436','watch','block-112909-2','BlockBox','',1),(112912,'74437','watch','block-112911','login\\Guest','',1),(112913,'74438','watch','block-112911','Html_box','',2),(112914,'74439','watch','block-112908-2','login\\Returning','',1),(112915,'74440','watch','block-112908-3','BlockBox','',1),(112916,'74441','watch','block-112915','Html_box','',1),(112917,'74442','watch','block-112915-2','BlockBox','',1),(112918,'74443','watch','block-112917','Html_box','',2),(112919,'74444','watch','block-112917','login\\Register','',1),(112920,'74445','watch','block-112907','login\\Socials','',2),(112921,'74446','watch','block-112907','Html_box','',3),(112922,'74447','watch','block-112907','Html_box','',1),(112923,'74448','watch','login_checkout2_q','BlockBox','',1),(112924,'74449','watch','block-112923','Tabs','',4),(112925,'74450','watch','block-112924-1','BlockBox','',1),(112926,'74451','watch','block-112925','Html_box','',1),(112927,'74452','watch','block-112925-2','quote\\FastOrder','',1),(112928,'74453','watch','block-112924-2','login\\Returning','',1),(112929,'74454','watch','block-112924-3','BlockBox','',1),(112930,'74455','watch','block-112929','Html_box','',1),(112931,'74456','watch','block-112929','Import','',2),(112932,'74457','watch','block-112929-2','BlockBox','',1),(112933,'74458','watch','block-112932','login\\Register','',1),(112934,'74459','watch','block-112932','Html_box','',2),(112935,'74460','watch','block-112923','Html_box','',3),(112936,'74461','watch','block-112923','Html_box','',1),(112937,'74462','watch','block-112923','login\\Socials','',2),(112938,'74463','watch','login_checkout2_s','BlockBox','',1),(112939,'74464','watch','block-112938','login\\Socials','',2),(112940,'74465','watch','block-112938','Html_box','',3),(112941,'74466','watch','block-112938','Tabs','',4),(112942,'74467','watch','block-112941-1','BlockBox','',1),(112943,'74468','watch','block-112942','Html_box','',1),(112944,'74469','watch','block-112942-2','quote\\FastOrder','',1),(112945,'74470','watch','block-112941-2','login\\Returning','',1),(112946,'74471','watch','block-112941-3','BlockBox','',1),(112947,'74472','watch','block-112946','Html_box','',1),(112948,'74473','watch','block-112946-2','BlockBox','',1),(112949,'74474','watch','block-112948','login\\Register','',1),(112950,'74475','watch','block-112948','Html_box','',2),(112951,'74476','watch','block-112938','Html_box','',1),(112952,'74477','watch','login_checkout_q','BlockBox','',1),(112953,'74478','watch','block-112952','BlockBox','',1),(112954,'74479','watch','block-112953','BlockBox','',6),(112955,'74480','watch','block-112954','Html_box','',1),(112956,'74481','watch','block-112954','login\\Socials','',2),(112957,'74482','watch','block-112953','checkout\\GuestBtn','',2),(112958,'74483','watch','block-112953','checkout\\CreateBtn','',5),(112959,'74484','watch','block-112953','Html_box','',4),(112960,'74485','watch','block-112953','Html_box','',1),(112961,'74486','watch','block-112953-2','Html_box','',1),(112962,'74487','watch','block-112953-2','login\\Returning','',2),(112963,'74488','watch','login_checkout_s','BlockBox','',1),(112964,'74489','watch','block-112963','BlockBox','',1),(112965,'74490','watch','block-112964','Html_box','',1),(112966,'74491','watch','block-112964','checkout\\GuestBtn','',2),(112967,'74492','watch','block-112964','checkout\\CreateBtn','',4),(112968,'74493','watch','block-112964','Html_box','',3),(112969,'74494','watch','block-112964','BlockBox','',5),(112970,'74495','watch','block-112969','Html_box','',1),(112971,'74496','watch','block-112969','login\\Socials','',2),(112972,'74497','watch','block-112964-2','Html_box','',1),(112973,'74498','watch','block-112964-2','login\\Returning','',2),(112974,'74499','watch','logoff','BlockBox','',1),(112975,'74500','watch','block-112974','Html_box','',1),(112976,'74501','watch','logoff_forever','BlockBox','',1),(112977,'74502','watch','block-112976','Html_box','',1),(112978,'74503','watch','main','BlockBox','',5),(112979,'74504','watch','block-112978','BlockBox','',1),(112980,'74505','watch','block-112979','Bestsellers','10',1),(112981,'74506','watch','block-112979-2','Reviews','3',1),(112982,'74507','watch','main','Banner','',2),(112983,'74508','watch','main','BlockBox','main-content',4),(112984,'74510','watch','block-112983','Tabs','',3),(112985,'74511','watch','block-112984-1','NewProducts','8',1),(112986,'74512','watch','block-112984-2','SpecialsProducts','',2),(112987,'74513','watch','block-112984-3','FeaturedProducts','4',2),(112988,'74514','watch','block-112983','TopCategories','',2),(112989,'1708695037.0808','watch','block-112983','FormBuilder\\widgets\\Form','',1),(112990,'74515','watch','main','Heading','',3),(112992,'74516','watch','manufacturers','BlockBox','',1),(112993,'74517','watch','block-112992','Html_box','',1),(112994,'74518','watch','block-112992','Brands','',2),(112995,'74519','watch','messages-index','BlockBox','',1),(112996,'74520','watch','block-112995','BlockBox','',1),(112997,'74521','watch','block-112996','BlockBox','',1),(112998,'74522','watch','block-112997','Messages\\Sidebar','',1),(112999,'74523','watch','block-112996-2','Messages\\Listing','',1),(113000,'74524','watch','messages-new','BlockBox','',1),(113001,'74525','watch','block-113000','BlockBox','',1),(113002,'74526','watch','block-113001','Messages\\Sidebar','',1),(113003,'74527','watch','block-113001-2','Messages\\NewMessage','',1),(113004,'74528','watch','messages-view','BlockBox','',1),(113005,'74529','watch','block-113004','BlockBox','',1),(113006,'74530','watch','block-113005','Messages\\Sidebar','',1),(113007,'74531','watch','block-113005-2','Messages\\Message','',1),(113008,'74532','watch','my_password','BlockBox','',1),(113009,'74533','watch','block-113008','BlockBox','',1),(113010,'74534','watch','block-113009','WidgetsAria','',1),(113030,'74535','watch','block-113009-2','account\\ChangePassword','',2),(113031,'74536','watch','block-113009-2','Html_box','',1),(113032,'74537','watch','need_login','BlockBox','',1),(113033,'74538','watch','block-113032','Tabs','',2),(113034,'74539','watch','block-113033-1','login\\Returning','',1),(113035,'74540','watch','block-113033-2','BlockBox','',1),(113036,'74541','watch','block-113035','Html_box','',1),(113037,'74542','watch','block-113035-2','BlockBox','',1),(113038,'74543','watch','block-113037','login\\Register','',1),(113039,'74544','watch','block-113037','Html_box','',2),(113040,'74545','watch','block-113032','BlockBox','',1),(113041,'74546','watch','new-topic','BlockBox','',1),(113042,'74547','watch','block-113041','Breadcrumb','',2),(113043,'74548','watch','block-113041','Communication\\NewTopic','',3),(113044,'74549','watch','block-113041','Html_box','',1),(113045,'94779','watch','nnnn','BlockBox','',1),(113046,'94780','watch','block-113045','catalog\\Title','',1),(113047,'94781','watch','block-113045','BlockBox','',2),(113048,'94782','watch','block-113047','Filters','',1),(113049,'94783','watch','block-113047-2','Listing','',5),(113050,'94784','watch','block-113047-2','catalog\\Image','',1),(113051,'94785','watch','block-113047-2','BlockBox','',6),(113052,'94786','watch','block-113051','catalog\\CountsItems','',1),(113053,'94787','watch','block-113051-2','catalog\\Paging','',1),(113054,'94788','watch','block-113047-2','catalog\\ImageMapCategory','',3),(113055,'94789','watch','block-113047-2','Categories','',2),(113056,'94790','watch','block-113047-2','BlockBox','',4),(113057,'94791','watch','block-113056','catalog\\ListingLook','',1),(113058,'94792','watch','block-113056','catalog\\ItemsOnPage','',4),(113059,'94793','watch','block-113056','catalog\\CompareButton','',2),(113060,'94794','watch','block-113056','catalog\\Sorting','',3),(113061,'74550','watch','no-logged','BlockBox','',1),(113062,'74551','watch','block-113061','Communication\\NewTopic','',2),(113063,'74552','watch','block-113061','Html_box','',1),(113064,'74553','watch','no_filters','BlockBox','catalog-content',1),(113065,'74554','watch','block-113064','BlockBox','',4),(113066,'74555','watch','block-113065','catalog\\CountsItems','',1),(113067,'74556','watch','block-113065-2','catalog\\Paging','',1),(113068,'74557','watch','block-113064','Listing','',3),(113069,'74558','watch','block-113064','catalog\\Title','',1),(113070,'74559','watch','block-113064','catalog\\B2bAddButton','',5),(113071,'74560','watch','block-113064','BlockBox','',2),(113072,'74561','watch','block-113071','BlockBox','catalog-features',2),(113073,'74562','watch','block-113072','HeaderStock','',5),(113074,'74563','watch','block-113072','catalog\\ListingLook','',1),(113075,'74564','watch','block-113072','catalog\\CompareButton','',2),(113076,'74565','watch','block-113072','catalog\\ItemsOnPage','',4),(113077,'74566','watch','block-113072','catalog\\Sorting','',3),(113078,'74567','watch','block-113071','catalog\\Image','',1),(113162,'74613','watch','order_pay','BlockBox','',1),(113163,'74614','watch','block-113162','BlockBox','',1),(113164,'74615','watch','block-113163','WidgetsAria','',1),(113184,'74616','watch','block-113163-2','account\\OrderProducts','',4),(113185,'74617','watch','block-113163-2','BlockBox','',2),(113186,'74618','watch','block-113185','BlockBox','',1),(113187,'74619','watch','block-113186','Html_box','',1),(113188,'74620','watch','block-113186','account\\OrderData','',2),(113189,'74621','watch','block-113185','BlockBox','',4),(113190,'74622','watch','block-113189','account\\OrderData','',2),(113191,'74623','watch','block-113189','Html_box','',1),(113192,'74624','watch','block-113185-2','BlockBox','',1),(113193,'74625','watch','block-113192','Html_box','',1),(113194,'74626','watch','block-113192','account\\OrderData','',2),(113195,'74627','watch','block-113185-2','BlockBox','',2),(113196,'74628','watch','block-113195','account\\OrderData','',2),(113197,'74629','watch','block-113195','Html_box','',1),(113198,'74630','watch','block-113185-3','BlockBox','',2),(113199,'74631','watch','block-113198','Html_box','',1),(113200,'74632','watch','block-113198','account\\OrderData','',2),(113201,'74633','watch','block-113185-3','BlockBox','',1),(113202,'74634','watch','block-113201','account\\OrderData','',2),(113203,'74635','watch','block-113201','Html_box','',1),(113204,'74636','watch','block-113163-2','UpdateAndPay\\PayForm','',6),(113205,'74637','watch','block-113163-2','Html_box','',3),(113206,'74638','watch','block-113163-2','account\\OrderHeading','',1),(113207,'74639','watch','block-113163-2','account\\OrderSubTotals','',5),(113208,'74640','watch','packingslip','invoice\\Container','',2),(113209,'74641','watch','block-113208','BlockBox','',1),(113210,'74642','watch','block-113209','Logo','',1),(113211,'74643','watch','block-113209-2','BlockBox','',3),(113212,'74644','watch','block-113211','Text','',2),(113213,'74645','watch','block-113211-2','invoice\\StoreEmail','',1),(113214,'74646','watch','block-113209-2','BlockBox','',2),(113215,'74647','watch','block-113214','Text','',2),(113216,'74648','watch','block-113214-2','invoice\\StorePhone','',1),(113217,'74649','watch','block-113209-2','BlockBox','',1),(113218,'74650','watch','block-113217','invoice\\StoreAddress','',1),(113219,'74651','watch','block-113209-2','BlockBox','',4),(113220,'74652','watch','block-113219','Text','',2),(113221,'74653','watch','block-113219-2','invoice\\StoreSite','',1),(113222,'74654','watch','block-113208','packingslip\\Products','',3),(113223,'74655','watch','block-113208','BlockBox','',4),(113224,'74656','watch','block-113223','invoice\\StoreAddress','',2),(113225,'74657','watch','block-113223','Text','',1),(113226,'74658','watch','block-113208','BlockBox','',2),(113227,'74659','watch','block-113226','BlockBox','',2),(113228,'74660','watch','block-113227','BlockBox','',1),(113229,'74661','watch','block-113228','invoice\\ShippingAddress','',2),(113230,'74662','watch','block-113228','Text','',1),(113231,'74663','watch','block-113227-2','BlockBox','',1),(113232,'74664','watch','block-113231','Text','',1),(113233,'74665','watch','block-113231','invoice\\CustomerName','',2),(113234,'74666','watch','block-113231','invoice\\CustomerEmail','',6),(113235,'74667','watch','block-113231','Text','',3),(113236,'74668','watch','block-113231','invoice\\CustomerPhone','',4),(113237,'74669','watch','block-113231','Text','',5),(113238,'74670','watch','block-113226','BlockBox','',3),(113239,'74671','watch','block-113238','BlockBox','',1),(113240,'74672','watch','block-113239','invoice\\ShippingMethod','',2),(113241,'74673','watch','block-113239','Text','',1),(113242,'74674','watch','block-113238-2','BlockBox','',1),(113243,'74675','watch','block-113242','invoice\\ShippingMethod','',2),(113244,'74676','watch','block-113242','Text','',1),(113245,'74677','watch','block-113226-2','invoice\\AddressQrcode','',1),(113246,'74678','watch','password_forgotten','BlockBox','',1),(113247,'74679','watch','block-113246','BlockBox','',2),(113248,'74680','watch','block-113247-2','Html_box','',1),(113249,'74681','watch','block-113247-2','login\\PasswordForgotten','',2),(113250,'74682','watch','block-113246','Html_box','',1),(113251,'74683','watch','pdf','invoice\\Container','',1),(113252,'74684','watch','block-113251','BlockBox','',1),(113253,'74685','watch','block-113252','BlockBox','',1),(113254,'74686','watch','block-113253','BlockBox','',1),(113255,'74687','watch','block-113254','pdf\\ProductElement','',1),(113256,'74688','watch','block-113253','BlockBox','',2),(113257,'74689','watch','block-113256','pdf\\ProductElement','',1),(113258,'74690','watch','block-113256-2','pdf\\ProductElement','',2),(113259,'74691','watch','block-113256-2','pdf\\ProductElement','',1),(113260,'74692','watch','block-113252-2','BlockBox','',1),(113261,'74693','watch','block-113260','BlockBox','',2),(113262,'74694','watch','block-113261','pdf\\ProductElement','',1),(113263,'74695','watch','block-113261-2','pdf\\ProductElement','',2),(113264,'74696','watch','block-113261-2','pdf\\ProductElement','',1),(113265,'74697','watch','block-113260','BlockBox','',1),(113266,'74698','watch','block-113265','pdf\\ProductElement','',1),(113267,'74699','watch','pdf_category','pdf\\CategoryName','',2),(113268,'74700','watch','pdf_category','pdf\\CategoryImage','',1),(113269,'74701','watch','pdf_cover','invoice\\Container','',1),(113270,'74702','watch','block-113269','Logo','',1),(113271,'74703','watch','block-113269','Text','',3),(113272,'74704','watch','pdf_footer','BlockBox','',1),(113273,'74705','watch','block-113272-2','pdf\\PageNumber','',1),(113274,'74706','watch','pdf_header','pdf\\CategoryName','',1),(113275,'74707','watch','personal_catalog','BlockBox','',1),(113276,'74708','watch','block-113275','BlockBox','',1),(113277,'74709','watch','block-113276','WidgetsAria','',1),(113297,'74710','watch','block-113276-2','Html_box','',1),(113298,'74711','watch','block-113276-2','account\\AccountLink','',3),(113299,'74712','watch','block-113276-2','account\\PersonalCatalog','',2),(113300,'74713','watch','points_earnt_history','BlockBox','',1),(113301,'74714','watch','block-113300','Html_box','',1),(113302,'74715','watch','block-113300','BonusActions\\widgets\\PointsEarntHistory','',2),(113303,'74716','watch','posts','BlockBox','',1),(113304,'74717','watch','block-113303','Breadcrumb','',2),(113305,'74718','watch','block-113303','Html_box','',1),(113306,'74719','watch','block-113303','Communication\\Post','',3),(113307,'74720','watch','product','BlockBox','product-content',2),(113308,'74721','watch','block-113307','product\\CustomersActivity','',11),(113309,'74722','watch','block-113307','BlockBox','product-image',2),(113310,'74724','watch','block-113309','product\\Images','',2),(113311,'74725','watch','block-113309','product\\ImageMapProduct','',4),(113312,'74726','watch','block-113309','product\\PromotionIcons','',1),(113313,'74727','watch','block-113309-2','BlockBox','product-side',10),(113314,'74728','watch','block-113313','product\\ButtonsQuote','',3),(113315,'74729','watch','block-113313','BlockBox','',1),(113316,'74730','watch','block-113315','product\\Price','',1),(113317,'74731','watch','block-113315-2','product\\Quantity','',1),(113318,'74732','watch','block-113313','BonusActions\\widgets\\BonusPointsProduct','',4),(113319,'1694165842.4776','watch','block-113313','product\\QuantityDiscounts','',2),(113320,'74733','watch','block-113313-2','product\\Buttons','',1),(113321,'74734','watch','block-113313-2','product\\ButtonsSample','',2),(113322,'74735','watch','block-113309-2','product\\DescriptionShort','',6),(113323,'74737','watch','block-113309-2','product\\Documents','',5),(113324,'74738','watch','block-113309-2','product\\AvailableInWarehouses','',9),(113325,'74739','watch','block-113309-2','BlockBox','',11),(113326,'74741','watch','block-113325','product\\PersonalCatalogButton','',1),(113327,'74743','watch','block-113309-2','product\\Brand','',4),(113328,'74744','watch','block-113309-2','product\\Model','',3),(113329,'74745','watch','block-113309-2','product\\Name','',2),(113330,'74746','watch','block-113309-2','product\\Stock','',1),(113331,'1642500646.3623','watch','block-113309-2','product\\Attributes','',7),(113332,'74749','watch','block-113307','product\\Configurator','',5),(113333,'74750','watch','block-113307','Breadcrumb','',1),(113334,'74752','watch','block-113307','Tabs','',6),(113335,'74753','watch','block-113334-1','product\\Description','',2),(113336,'74754','watch','block-113334-1','product\\Properties','',1),(113337,'74755','watch','block-113334-2','product\\Reviews','',1),(113338,'74757','watch','block-113307','product\\InBundles','',4),(113339,'74758','watch','block-113307','product\\Bundle','',3),(113340,'1694166186.2638','watch','block-113307','BlockBox','',7),(113341,'74751','watch','block-113340','product\\AlsoPurchased','10',2),(113342,'1694166209.3278','watch','block-113340','Html_box','',1),(113343,'1694166191.5684','watch','block-113307','BlockBox','',9),(113344,'74747','watch','block-113343','ViewedProducts','4',2),(113345,'1694166222.3382','watch','block-113343','Html_box','',1),(113346,'74761','watch','product-bottom','product\\Properties','',1),(113347,'74762','watch','product-tabs','product\\Reviews','',2),(113348,'74763','watch','product-tabs','product\\Description','',1),(113349,'74764','watch','product-top-left','product\\Images','',1),(113350,'74765','watch','product-top-right','product\\Price','',2),(113351,'74766','watch','product-top-right','product\\Quantity','',5),(113352,'74767','watch','product-top-right','product\\Quantity','',6),(113353,'74768','watch','product-top-right','product\\Attributes','',3),(113354,'74769','watch','product-top-right','product\\Name','',1),(113355,'74770','watch','product-top-right','product\\Buttons','',6),(113356,'74771','watch','productListing','BlockBox','listing-item',1),(113357,'74773','watch','block-113356','productListing\\model','',7),(113358,'74774','watch','block-113356','BonusActions\\widgets\\BonusPointsProductListing','',6),(113359,'74775','watch','block-113356','productListing\\description','',5),(113360,'74776','watch','block-113356','productListing\\buyButton','',9),(113361,'74777','watch','block-113356','productListing\\rating','',3),(113362,'74778','watch','block-113356','productListing\\image','',1),(113363,'74779','watch','block-113356','BlockBox','',8),(113364,'74780','watch','block-113363','productListing\\price','',1),(113365,'74781','watch','block-113363-2','productListing\\qtyInput','',1),(113366,'74782','watch','block-113356','productListing\\name','',4),(113367,'74783','watch','block-113356','productListing\\stock','',2),(113368,'75903','watch','block-113356','productListing\\compare','',10),(113369,'74785','watch','products','BlockBox','catalog-content',1),(113370,'74786','watch','block-113369','BlockBox','catalog-side',4),(113371,'74787','watch','block-113370','Filters','',1),(113372,'74788','watch','block-113370','HeaderStock','',2),(113373,'74789','watch','block-113370-2','catalog\\B2bAddButton','',4),(113374,'74790','watch','block-113370-2','BlockBox','catalog-features',2),(113375,'74791','watch','block-113374','catalog\\Sorting','',3),(113376,'74792','watch','block-113374','catalog\\ListingLook','',1),(113377,'74793','watch','block-113374','catalog\\ItemsOnPage','',4),(113378,'74794','watch','block-113374','catalog\\CompareButton','',2),(113379,'74795','watch','block-113370-2','BlockBox','',5),(113380,'74796','watch','block-113379','catalog\\CountsItems','',1),(113381,'74797','watch','block-113379-2','catalog\\Paging','',1),(113382,'74798','watch','block-113370-2','Listing','',3),(113383,'74799','watch','block-113369','catalog\\Title','',1),(113384,'74800','watch','block-113369','BlockBox','',3),(113385,'74801','watch','block-113384','catalog\\Image','',1),(113386,'75886','watch','products-list','packingslip\\AllProductsList','',2),(113387,'74802','watch','promotions','BlockBox','',1),(113388,'74803','watch','block-113387','promotions\\PromoList','',2),(113389,'74804','watch','block-113387','Html_box','',1),(113390,'74805','watch','purchase','invoice\\Container','',1),(113391,'74806','watch','block-113390','invoice\\Products','',3),(113392,'74807','watch','block-113390','BlockBox','',5),(113393,'74808','watch','block-113392','Text','',1),(113394,'74809','watch','block-113392','invoice\\StoreAddress','',8),(113395,'74810','watch','block-113392-2','Text','',2),(113396,'74811','watch','block-113392-2','Logo','',1),(113397,'74812','watch','block-113392-3','BlockBox','',3),(113398,'74813','watch','block-113397','Text','',1),(113399,'74814','watch','block-113397-2','invoice\\StoreEmail','',1),(113400,'74815','watch','block-113392-3','Text','',1),(113401,'74816','watch','block-113392-3','BlockBox','',2),(113402,'74817','watch','block-113401','Text','',1),(113403,'74818','watch','block-113401-2','invoice\\StorePhone','',1),(113404,'74819','watch','block-113390','BlockBox','',1),(113405,'74820','watch','block-113404','Logo','',1),(113406,'74821','watch','block-113404-2','BlockBox','',2),(113407,'74822','watch','block-113406','Text','',1),(113408,'74823','watch','block-113406-2','invoice\\StorePhone','',1),(113409,'74824','watch','block-113404-2','BlockBox','',4),(113410,'74825','watch','block-113409','Text','',1),(113411,'74826','watch','block-113409-2','invoice\\StoreSite','',1),(113412,'74827','watch','block-113404-2','BlockBox','',1),(113413,'74828','watch','block-113412','invoice\\StoreAddress','',1),(113414,'74829','watch','block-113404-2','BlockBox','',3),(113415,'74830','watch','block-113414','Text','',1),(113416,'74831','watch','block-113414-2','invoice\\StoreEmail','',1),(113417,'74832','watch','block-113390','BlockBox','',2),(113418,'74833','watch','block-113417','BlockBox','',7),(113419,'74834','watch','block-113418','BlockBox','',1),(113420,'74835','watch','block-113419','invoice\\BillingAddress','',2),(113421,'74836','watch','block-113419','Text','',1),(113422,'74837','watch','block-113418-2','BlockBox','',1),(113423,'74838','watch','block-113422','invoice\\CustomerEmail','',6),(113424,'74839','watch','block-113422','Text','',5),(113425,'74840','watch','block-113422','invoice\\CustomerPhone','',4),(113426,'74841','watch','block-113422','invoice\\CustomerName','',2),(113427,'74842','watch','block-113422','Text','',3),(113428,'74843','watch','block-113422','Text','',1),(113429,'74844','watch','block-113417-2','invoice\\OrderId','',1),(113430,'74845','watch','block-113417-2','Text','',2),(113431,'74846','watch','block-113417-2','invoice\\PaymentDate','',3),(113432,'74847','watch','block-113390','BlockBox','',4),(113433,'74848','watch','block-113432','BlockBox','',1),(113434,'74849','watch','block-113433','invoice\\ShippingAddress','',2),(113435,'74850','watch','block-113433','Text','',1),(113436,'74851','watch','quotations','BlockBox','',1),(113437,'74852','watch','block-113436','BlockBox','',1),(113438,'74853','watch','block-113437','WidgetsAria','',1),(113458,'74854','watch','block-113437-2','Html_box','',1),(113459,'74855','watch','block-113437-2','Quotations\\QuotationsHistory','',2),(113460,'74856','watch','quotation_info','BlockBox','',1),(113461,'74857','watch','block-113460','BlockBox','',1),(113462,'74858','watch','block-113461','WidgetsAria','',1),(113482,'74859','watch','block-113461-2','BlockBox','',5),(113483,'74860','watch','block-113482','BlockBox','',1),(113484,'74861','watch','block-113483','Quotations\\QuotationData','',2),(113485,'74862','watch','block-113483','Html_box','',1),(113486,'74863','watch','block-113482','BlockBox','',4),(113487,'74864','watch','block-113486','Html_box','',1),(113488,'74865','watch','block-113486','Quotations\\QuotationData','',2),(113489,'74866','watch','block-113482-2','BlockBox','',2),(113490,'74867','watch','block-113489','Html_box','',1),(113491,'74868','watch','block-113489','Quotations\\QuotationData','',2),(113492,'74869','watch','block-113482-2','BlockBox','',1),(113493,'74870','watch','block-113492','Html_box','',1),(113494,'74871','watch','block-113492','Quotations\\QuotationData','',2),(113495,'74872','watch','block-113482-3','BlockBox','',1),(113496,'74873','watch','block-113495','Quotations\\QuotationData','',2),(113497,'74874','watch','block-113495','Html_box','',1),(113498,'74875','watch','block-113482-3','BlockBox','',2),(113499,'74876','watch','block-113498','Quotations\\QuotationData','',2),(113500,'74877','watch','block-113498','Html_box','',1),(113501,'74878','watch','block-113461-2','Html_box','',6),(113502,'74879','watch','block-113461-2','Quotations\\QuotationHistory','',10),(113503,'74880','watch','block-113461-2','Html_box','',9),(113504,'74881','watch','block-113461-2','Quotations\\QuotationProducts','',7),(113505,'74882','watch','block-113461-2','Quotations\\QuotationSubTotal','',8),(113506,'74883','watch','block-113461-2','BlockBox','',12),(113507,'74884','watch','block-113506','account\\AccountLink','',1),(113508,'74885','watch','block-113461-2','Html_box','',4),(113509,'74886','watch','quote','BlockBox','',1),(113510,'74887','watch','block-113509','cart\\CartTabs','',1),(113511,'74888','watch','block-113510','BlockBox','',1),(113512,'74889','watch','block-113511','quote\\Products','',1),(113513,'74890','watch','block-113511-2','BlockBox','',1),(113514,'74891','watch','block-113513','BlockBox','',1),(113515,'74892','watch','block-113514','quote\\CheckoutBtn','',2),(113516,'74893','watch','block-113510','Quotations\\QuotationSubTotal','',2),(113541,'74899','watch','reviews','BlockBox','',1),(113542,'74900','watch','block-113541','reviews\\Heading','',1),(113543,'74901','watch','block-113541','reviews\\Content','',2),(113544,'74902','watch','rma_document','invoice\\Container','',1),(113545,'74903','watch','block-113544','BlockBox','',1),(113546,'74904','watch','block-113545','BlockBox','',1),(113547,'74905','watch','block-113546','BlockBox','',2),(113548,'74906','watch','block-113547','Html_box','',1),(113549,'74907','watch','block-113547-2','Html_box','',1),(113550,'74908','watch','block-113546','BlockBox','',5),(113551,'74909','watch','block-113550','Html_box','',1),(113552,'74910','watch','block-113550-2','Html_box','',1),(113553,'74911','watch','block-113546','BlockBox','',4),(113554,'74912','watch','block-113553','Html_box','',1),(113555,'74913','watch','block-113553-2','Html_box','',1),(113556,'74914','watch','block-113546','BlockBox','',3),(113557,'74915','watch','block-113556','Html_box','',1),(113558,'74916','watch','block-113556-2','Html_box','',1),(113559,'74917','watch','block-113546','BlockBox','',1),(113560,'74918','watch','block-113559','Html_box','',1),(113561,'74919','watch','block-113559','Html_box','',2),(113562,'74920','watch','block-113545-2','BlockBox','',1),(113563,'74921','watch','block-113562','Html_box','',2),(113564,'74922','watch','block-113562','Logo','',1),(113565,'74923','watch','block-113545-2','BlockBox','',2),(113566,'74924','watch','block-113565','BlockBox','',5),(113567,'74925','watch','block-113566','BlockBox','',1),(113568,'74926','watch','block-113567','Html_box','',1),(113569,'74927','watch','block-113567-2','Rma\\DocumentData','',1),(113570,'74928','watch','block-113566-2','BlockBox','',1),(113571,'74929','watch','block-113570','Html_box','',1),(113572,'74930','watch','block-113570-2','Rma\\DocumentData','',1),(113573,'74931','watch','block-113565','BlockBox','',4),(113574,'74932','watch','block-113573','BlockBox','',1),(113575,'74933','watch','block-113574','Html_box','',1),(113576,'74934','watch','block-113574-2','Rma\\DocumentData','',1),(113577,'74935','watch','block-113573-2','BlockBox','',1),(113578,'74936','watch','block-113577','Html_box','',1),(113579,'74937','watch','block-113577-2','Rma\\DocumentData','',1),(113580,'74938','watch','block-113565','BlockBox','',3),(113581,'74939','watch','block-113580','BlockBox','',1),(113582,'74940','watch','block-113581','Html_box','',1),(113583,'74941','watch','block-113581-2','Rma\\DocumentData','',1),(113584,'74942','watch','block-113580-2','BlockBox','',1),(113585,'74943','watch','block-113584','Html_box','',1),(113586,'74944','watch','block-113584-2','Rma\\DocumentData','',1),(113587,'74945','watch','block-113565','BlockBox','',2),(113588,'74946','watch','block-113587','Html_box','',1),(113589,'74947','watch','block-113587-2','Rma\\DocumentData','',1),(113590,'74948','watch','block-113565','BlockBox','',1),(113591,'74949','watch','block-113590','BlockBox','',1),(113592,'74950','watch','block-113591','Html_box','',1),(113593,'74951','watch','block-113591-2','Rma\\DocumentData','',1),(113594,'74952','watch','block-113590-2','BlockBox','',1),(113595,'74953','watch','block-113594','Html_box','',1),(113596,'74954','watch','block-113594-2','Rma\\DocumentData','',1),(113597,'74955','watch','block-113545-2','BlockBox','',3),(113598,'74956','watch','block-113597','BlockBox','',1),(113599,'74957','watch','block-113598','Html_box','',1),(113600,'74958','watch','block-113598-2','Rma\\DocumentData','',1),(113601,'74959','watch','block-113597-2','BlockBox','',1),(113602,'74960','watch','block-113601','Html_box','',1),(113603,'74961','watch','block-113601-2','Rma\\DocumentData','',1),(113604,'74962','watch','block-113544','BlockBox','',2),(113605,'74963','watch','block-113604','Html_box','',1),(113606,'74964','watch','block-113604','Rma\\Products','',2),(113607,'74965','watch','block-113544','BlockBox','',3),(113608,'74966','watch','block-113607','BlockBox','',1),(113609,'74967','watch','block-113608','BlockBox','',1),(113610,'74968','watch','block-113609','BlockBox','',5),(113611,'74969','watch','block-113610','Html_box','',1),(113612,'74970','watch','block-113610-2','invoice\\StoreAddress','',2),(113613,'74971','watch','block-113610-2','Html_box','',1),(113614,'74972','watch','block-113609','BlockBox','',4),(113615,'74973','watch','block-113614','Html_box','',1),(113616,'74974','watch','block-113614-2','Html_box','',1),(113617,'74975','watch','block-113609','BlockBox','',2),(113618,'74976','watch','block-113617','Html_box','',1),(113619,'74977','watch','block-113617-2','Html_box','',1),(113620,'74978','watch','block-113609','BlockBox','',1),(113621,'74979','watch','block-113620','Html_box','',1),(113622,'74980','watch','block-113609','BlockBox','',3),(113623,'74981','watch','block-113622','Html_box','',1),(113624,'74982','watch','block-113622-2','Html_box','',1),(113625,'74983','watch','block-113609','BlockBox','',6),(113626,'74984','watch','block-113625','Html_box','',1),(113627,'74985','watch','block-113608-2','BlockBox','',1),(113628,'74986','watch','block-113627','BlockBox','',1),(113629,'74987','watch','block-113628','BlockBox','',1),(113630,'74988','watch','block-113629','Rma\\DocumentData','',2),(113631,'74989','watch','block-113629-3','BlockBox','',1),(113632,'74990','watch','block-113631','Html_box','',1),(113633,'74991','watch','block-113631-2','Rma\\DocumentData','',1),(113634,'74992','watch','block-113628','BlockBox','',2),(113635,'74993','watch','block-113634-2','invoice\\StoreAddress','',1),(113636,'74994','watch','block-113608-2','BlockBox','',2),(113637,'74995','watch','block-113636','Html_box','',1),(113638,'74996','watch','block-113636','Html_box','',2),(113639,'74997','watch','block-113636','Html_box','',3),(113640,'74998','watch','block-113636','Html_box','',4),(113641,'74999','watch','block-113636','Html_box','',5),(113642,'75000','watch','block-113608-2','BlockBox','',4),(113643,'75001','watch','block-113642','Html_box','',1),(113644,'75002','watch','block-113642-2','Html_box','',1),(113645,'75003','watch','block-113642-3','BlockBox','',1),(113646,'75004','watch','block-113645','Html_box','',1),(113647,'75005','watch','block-113645-2','Html_box','',1),(113648,'75006','watch','block-113608-2','BlockBox','',3),(113649,'75007','watch','block-113648','Html_box','',1),(113650,'75008','watch','block-113648-2','Html_box','',1),(113651,'75009','watch','block-113648-3','BlockBox','',1),(113652,'75010','watch','block-113651','Html_box','',1),(113653,'75011','watch','block-113651-2','Html_box','',1),(113654,'75012','watch','rows','BlockBox','',1),(113655,'75013','watch','block-113654','BlockBox','',2),(113656,'75014','watch','block-113655','BlockBox','',2),(113657,'75015','watch','block-113656','BonusActions\\widgets\\BonusPointsProductListing','',1),(113658,'75016','watch','block-113656','productListing\\image','',2),(113659,'75017','watch','block-113656','BlockBox','',3),(113660,'75018','watch','block-113659','productListing\\rating','',1),(113661,'75019','watch','block-113659','productListing\\ratingCounts','',2),(113662,'75020','watch','block-113656-2','productListing\\name','',1),(113663,'75021','watch','block-113656-2','productListing\\description','',2),(113664,'75022','watch','block-113656-2','productListing\\model','',3),(113665,'75023','watch','block-113656-2','productListing\\attributes','',4),(113666,'75024','watch','block-113655-2','BlockBox','listing-item',1),(113667,'75025','watch','block-113666','productListing\\qtyInput','',3),(113668,'75026','watch','block-113666','productListing\\price','',2),(113669,'75027','watch','block-113666','productListing\\compare','',5),(113670,'75028','watch','block-113666','productListing\\buyButton','',4),(113671,'75030','watch','block-113666','productListing\\stock','',1),(113672,'75031','watch','sample','BlockBox','',1),(113673,'75032','watch','block-113672','cart\\CartTabs','',1),(113674,'75033','watch','block-113673','BlockBox','',1),(113675,'75034','watch','block-113674','sample\\Products','',1),(113676,'75035','watch','block-113674-2','BlockBox','',1),(113677,'75036','watch','block-113676','BlockBox','',1),(113678,'75037','watch','block-113677','sample\\CheckoutBtn','',1),(113679,'75038','watch','samples','BlockBox','',1),(113680,'75039','watch','block-113679','BlockBox','',1),(113681,'75040','watch','block-113680','WidgetsAria','',1),(113701,'75041','watch','block-113680-2','Html_box','',1),(113702,'75042','watch','block-113680-2','Samples\\SamplesHistory','',2),(113703,'75043','watch','sample_info','BlockBox','',1),(113704,'75044','watch','block-113703','BlockBox','',1),(113705,'75045','watch','block-113704','WidgetsAria','',1),(113725,'75046','watch','block-113704-2','Html_box','',1),(113726,'75047','watch','block-113704-2','BlockBox','',8),(113727,'75048','watch','block-113726','account\\AccountLink','',1),(113728,'75049','watch','block-113704-2','Samples\\SampleHistory','',7),(113729,'75050','watch','block-113704-2','Html_box','',3),(113730,'75051','watch','block-113704-2','Samples\\SampleSubTotal','',5),(113731,'75052','watch','block-113704-2','Samples\\SampleProducts','',4),(113732,'75053','watch','block-113704-2','Html_box','',6),(113733,'75054','watch','block-113704-2','BlockBox','',2),(113734,'75055','watch','block-113733','BlockBox','',4),(113735,'75056','watch','block-113734','Html_box','',1),(113736,'75057','watch','block-113734','Samples\\SampleData','',2),(113737,'75058','watch','block-113733','BlockBox','',1),(113738,'75059','watch','block-113737','Samples\\SampleData','',2),(113739,'75060','watch','block-113737','Html_box','',1),(113740,'75061','watch','block-113733-2','BlockBox','',2),(113741,'75062','watch','block-113740','Samples\\SampleData','',2),(113742,'75063','watch','block-113740','Html_box','',1),(113743,'75064','watch','block-113733-2','BlockBox','',1),(113744,'75065','watch','block-113743','Samples\\SampleData','',2),(113745,'75066','watch','block-113743','Html_box','',1),(113746,'75067','watch','block-113733-3','BlockBox','',2),(113747,'75068','watch','block-113746','Samples\\SampleData','',2),(113748,'75069','watch','block-113746','Html_box','',1),(113749,'75070','watch','block-113733-3','BlockBox','',1),(113750,'75071','watch','block-113749','Samples\\SampleData','',2),(113751,'75072','watch','block-113749','Html_box','',1),(113752,'75073','watch','sitemap','BlockBox','',1),(113753,'75074','watch','block-113752','Html_box','',1),(113754,'75075','watch','block-113752','BlockBox','',2),(113755,'75076','watch','block-113754','Html_box','',1),(113756,'75077','watch','block-113754','Html_box','',5),(113757,'75078','watch','block-113754','Html_box','',3),(113758,'75079','watch','block-113754','sitemap\\InfoPages','',2),(113759,'75080','watch','block-113754','sitemap\\Categories','',4),(113760,'75081','watch','block-113754','Menu','Account box',6),(113761,'75082','watch','block-113754-2','sitemap\\DeliveryLocation','',2),(113762,'75083','watch','block-113754-2','Html_box','',1),(113763,'75084','watch','subscribe','BlockBox','',1),(113764,'75085','watch','block-113763','Html_box','',3),(113765,'75086','watch','block-113763','subscribers\\UnsubscribeForm','',4),(113766,'75087','watch','block-113763','Html_box','',1),(113767,'75088','watch','block-113763','subscribers\\SubscribeForm','',2),(113768,'75089','watch','subscribed','BlockBox','',1),(113769,'75090','watch','block-113768','Html_box','',1),(113770,'94795','watch','subscription','BlockBox','',2),(113771,'94796','watch','block-113770','BlockBox','',1),(113772,'94797','watch','block-113771','WidgetsAria','',1),(113792,'94798','watch','block-113771-2','Html_box','',2),(113793,'94799','watch','block-113771-2','Html_box','',3),(113794,'94800','watch','block-113771-2','account\\Subscription','',4),(113795,'1694099590.22143','watch','success','BlockBox','',1),(113796,'1694099590.340695','watch','block-113795','BlockBox','',2),(113797,'1694099590.343733','watch','block-113796','BlockBox','',3),(113798,'1694099590.345212','watch','block-113797','BlockBox','',2),(113799,'1694099590.34749','watch','block-113798','BlockBox','',1),(113800,'1694099590.3531','watch','block-113799','order\\ShippingMethod','',6),(113801,'1694099590.351567','watch','block-113799','order\\DeliveryAddress','',3),(113802,'1694099590.35337','watch','block-113799','Html_box','',7),(113803,'1694099590.360420','watch','block-113799','Html_box','',5),(113804,'1694099590.362714','watch','block-113799','Html_box','',1),(113805,'1694099590.36422','watch','block-113799','checkout\\ContactConfirm','',9),(113806,'1694099590.365625','watch','block-113799','Html_box','',2),(113807,'1694099590.367789','watch','block-113798-2','BlockBox','',1),(113808,'1694099590.369488','watch','block-113807','order\\PaymentMethod','',6),(113809,'1694099590.370690','watch','block-113807','order\\BillingAddress','',3),(113810,'1694099590.371953','watch','block-113807','Html_box','',5),(113811,'1694099590.373633','watch','block-113807','Html_box','',1),(113812,'1694099590.37590','watch','block-113807','Html_box','',2),(113813,'1694099590.376747','watch','block-113797','Html_box','',1),(113814,'1694099590.38020','watch','block-113796-2','BlockBox','',1),(113815,'1694099590.381373','watch','block-113814','success\\PrintBtn','',3),(113816,'1694099590.382864','watch','block-113814','success\\ContinueBtn','',4),(113817,'1694099590.384241','watch','block-113814','order\\Products','',1),(113818,'1694099590.385486','watch','block-113814','order\\Totals','',2),(113819,'1694099590.386683','watch','block-113795','BlockBox','',1),(113820,'1694099590.387673','watch','block-113819','Html_box','',2),(113821,'1694099590.389337','watch','block-113819','order\\OrderNumber','',1),(113822,'75097','watch','success_q','BlockBox','',1),(113823,'75098','watch','block-113822','BlockBox','',1),(113824,'75099','watch','block-113823','BlockBox','',2),(113825,'75100','watch','block-113824','success\\ContinueBtn','',2),(113826,'75101','watch','block-113824','success\\PrintBtn','',1),(113827,'75102','watch','block-113823','Html_box','',1),(113832,'75107','watch','ticket','invoice\\Container','',1),(113833,'75108','watch','block-113832','BlockBox','',4),(113834,'75109','watch','block-113833','BlockBox','',1),(113835,'75110','watch','block-113834','invoice\\ShippingAddress','',2),(113836,'75111','watch','block-113834','Text','',1),(113837,'75112','watch','block-113833-2','BlockBox','',1),(113838,'75113','watch','block-113837','invoice\\Totals','',1),(113839,'75114','watch','block-113832','BlockBox','',5),(113840,'75115','watch','block-113839','Text','',1),(113841,'75116','watch','block-113839','invoice\\StoreAddress','',8),(113842,'75117','watch','block-113839-2','Logo','',1),(113843,'75118','watch','block-113839-2','Text','',2),(113844,'75119','watch','block-113839-3','Text','',1),(113845,'75120','watch','block-113839-3','BlockBox','',3),(113846,'75121','watch','block-113845','Text','',1),(113847,'75122','watch','block-113845-2','invoice\\StoreEmail','',1),(113848,'75123','watch','block-113839-3','BlockBox','',2),(113849,'75124','watch','block-113848','Text','',1),(113850,'75125','watch','block-113848-2','invoice\\StorePhone','',1),(113851,'75126','watch','block-113832','invoice\\Products','',3),(113852,'75127','watch','block-113832','BlockBox','',1),(113853,'75128','watch','block-113852-2','BlockBox','',3),(113854,'75129','watch','block-113853','Text','',1),(113855,'75130','watch','block-113853-2','invoice\\StoreEmail','',1),(113856,'75131','watch','block-113852-2','BlockBox','',4),(113857,'75132','watch','block-113856','Text','',1),(113858,'75133','watch','block-113856-2','invoice\\StoreSite','',1),(113859,'75134','watch','block-113852-2','BlockBox','',1),(113860,'75135','watch','block-113859','invoice\\StoreAddress','',1),(113861,'75136','watch','block-113852-2','BlockBox','',2),(113862,'75137','watch','block-113861','Text','',1),(113863,'75138','watch','block-113861-2','invoice\\StorePhone','',1),(113864,'75139','watch','block-113832','BlockBox','',2),(113865,'75140','watch','block-113864','BlockBox','',8),(113866,'75141','watch','block-113865','BlockBox','',1),(113867,'75142','watch','block-113866','Text','',1),(113868,'75143','watch','block-113866','invoice\\ShippingMethod','',2),(113869,'75144','watch','block-113865-2','BlockBox','',1),(113870,'75145','watch','block-113869','Text','',1),(113871,'75146','watch','block-113869','invoice\\ShippingMethod','',2),(113872,'75147','watch','block-113864','BlockBox','',7),(113873,'75148','watch','block-113872','BlockBox','',1),(113874,'75149','watch','block-113873','invoice\\BillingAddress','',2),(113875,'75150','watch','block-113873','Text','',1),(113876,'75151','watch','block-113872-2','BlockBox','',1),(113877,'75152','watch','block-113876','invoice\\CustomerName','',2),(113878,'75153','watch','block-113876','Text','',3),(113879,'75154','watch','block-113876','invoice\\CustomerEmail','',6),(113880,'75155','watch','block-113876','invoice\\CustomerPhone','',4),(113881,'75156','watch','block-113876','Text','',5),(113882,'75157','watch','block-113876','Text','',1),(113883,'75158','watch','block-113864-2','invoice\\PaymentDate','',3),(113884,'75159','watch','block-113864-2','Text','',2),(113885,'75160','watch','block-113864-2','Text','',4),(113886,'75161','watch','block-113864-2','invoice\\OrderId','',1),(113887,'75162','watch','block-113864-2','invoice\\PaymentMethod','',5),(113888,'75163','watch','block-113864-2','invoice\\OrderBarcode','',6),(113889,'75194','watch','tracking_numbers','BlockBox','',1),(113890,'75195','watch','block-113889','Html_box','',1),(113891,'75196','watch','block-113889','account\\OrderTracking','',2),(113892,'75418','watch','unsubscribed','BlockBox','',1),(113893,'75419','watch','block-113892','Html_box','',1),(113894,'75420','watch','update-and-pay-order_confirmation','BlockBox','',1),(113895,'75421','watch','block-113894','BlockBox','',3),(113896,'75422','watch','block-113895','BlockBox','',1),(113897,'75423','watch','block-113896','BlockBox','',1),(113898,'75424','watch','block-113897','BlockBox','',1),(113899,'75425','watch','block-113898','order\\ShippingMethod','',5),(113900,'75426','watch','block-113898','Html_box','',2),(113901,'75427','watch','block-113898','Html_box','',4),(113902,'75428','watch','block-113898','Html_box','',1),(113903,'75429','watch','block-113898','order\\Telephone','',8),(113904,'75430','watch','block-113898','Html_box','',6),(113905,'75431','watch','block-113898','order\\Name','',7),(113906,'75432','watch','block-113898','order\\Email','',9),(113907,'75433','watch','block-113898','order\\DeliveryAddress','',3),(113908,'75434','watch','block-113897-2','BlockBox','',1),(113909,'75435','watch','block-113908','order\\BillingAddress','',3),(113910,'75436','watch','block-113908','UpdateAndPay\\PayConfirm','',5),(113911,'75437','watch','block-113908','Html_box','',1),(113912,'75438','watch','block-113908','Html_box','',2),(113913,'75439','watch','block-113908','Html_box','',4),(113914,'75440','watch','block-113896','BlockBox','',3),(113915,'75441','watch','block-113914','order\\Products','',2),(113916,'75442','watch','block-113914','Html_box','',1),(113917,'75443','watch','block-113895-2','BlockBox','',1),(113918,'75444','watch','block-113917','Html_box','',1),(113919,'75445','watch','block-113917','checkout\\ContinueBtn','',3),(113920,'75446','watch','block-113917','order\\Totals','',2),(113921,'75447','watch','block-113894','account\\OrderHeading','',1),(113922,'75448','watch','update-and-pay-order_pay','BlockBox','',1),(113923,'75449','watch','block-113922','BlockBox','',3),(113924,'75450','watch','block-113923','BlockBox','',1),(113925,'75451','watch','block-113924','BlockBox','',1),(113926,'75452','watch','block-113925','BlockBox','',1),(113927,'75453','watch','block-113926','order\\DeliveryAddress','',3),(113928,'75454','watch','block-113926','order\\Email','',9),(113929,'75455','watch','block-113926','order\\Name','',7),(113930,'75456','watch','block-113926','Html_box','',6),(113931,'75457','watch','block-113926','order\\Telephone','',8),(113932,'75458','watch','block-113926','Html_box','',4),(113933,'75459','watch','block-113926','order\\ShippingMethod','',5),(113934,'75460','watch','block-113926','Html_box','',1),(113935,'75461','watch','block-113926','Html_box','',2),(113936,'75462','watch','block-113925-2','BlockBox','',1),(113937,'75463','watch','block-113936','Html_box','',1),(113938,'75464','watch','block-113936','Html_box','',2),(113939,'75465','watch','block-113936','Html_box','',4),(113940,'75466','watch','block-113936','order\\BillingAddress','',3),(113941,'75467','watch','block-113936','UpdateAndPay\\PayForm','',5),(113942,'75468','watch','block-113924','BlockBox','',3),(113943,'75469','watch','block-113942','Html_box','',1),(113944,'75470','watch','block-113942','order\\Products','',2),(113945,'75471','watch','block-113923-2','BlockBox','',1),(113946,'75472','watch','block-113945','order\\Totals','',2),(113947,'75473','watch','block-113945','checkout\\ContinueBtn','',3),(113948,'75474','watch','block-113945','Html_box','',1),(113949,'75475','watch','block-113922','account\\OrderHeading','',1),(113950,'75540','watch','wishlist','BlockBox','',1),(113951,'75541','watch','block-113950','BlockBox','',1),(113952,'75542','watch','block-113951','WidgetsAria','',1),(113972,'75543','watch','block-113951-2','account\\Wishlist','',2),(113973,'75544','watch','block-113951-2','Html_box','',1),(113974,'75545','watch','wishlist-cart','BlockBox','',1),(113975,'75546','watch','block-113974','cart\\CartTabs','',1),(113976,'75547','watch','block-113975','account\\Wishlist','',1),(113977,'116005','printshop','404','Html_box','',1),(114205,'117906.000001','printshop','b2b','BlockBox','listing-item',1),(114206,'117907.000001','printshop','block-114205','BlockBox','',2),(114207,'117908.000001','printshop','block-114206','BlockBox','',2),(114208,'117909.000001','printshop','block-114207','productListing\\bonusPoints','',2),(114209,'117910.000001','printshop','block-114207','productListing\\image','',1),(114210,'117914.000001','printshop','block-114207-2','productListing\\name','',1),(114211,'117915.000001','printshop','block-114207-2','productListing\\description','',2),(114212,'117916.000001','printshop','block-114207-2','productListing\\model','',4),(114213,'117917.000001','printshop','block-114207-2','productListing\\attributes','',5),(114214,'120922.000001','printshop','block-114207-2','productListing\\properties','',3),(114215,'117918.000001','printshop','block-114206-2','BlockBox','',1),(114216,'117911.000001','printshop','block-114215','BlockBox','',3),(114217,'117912.000001','printshop','block-114216','productListing\\rating','',1),(114218,'117913.000001','printshop','block-114216','productListing\\ratingCounts','',2),(114219,'117919.000001','printshop','block-114215','productListing\\qtyInput','',4),(114220,'117920.000001','printshop','block-114215','productListing\\price','',2),(114221,'117922.000001','printshop','block-114215','productListing\\buyButton','',5),(114222,'117924.000001','printshop','block-114215','productListing\\stock','',1),(114223,'120925.000001','printshop','block-114215','productListing\\compare','',8),(114224,'120926.000001','printshop','block-114215','productListing\\personalCatalog','',7),(114225,'120927.000001','printshop','block-114215','productListing\\viewButton','',6),(114226,'116176','printshop','batch','BlockBox','',1),(114227,'116177','printshop','block-114226','productListing\\attributes','',5),(114228,'116178','printshop','block-114226','productListing\\price','',6),(114229,'116179','printshop','block-114226','productListing\\name','',4),(114230,'116180','printshop','block-114226','productListing\\image','',2),(114231,'116181','printshop','block-114226','batchSelect','',1),(114232,'116182','printshop','batch_selected','BlockBox','',1),(114233,'116183','printshop','block-114232','BlockBox','',13),(114234,'116184','printshop','block-114233','productListing\\image','',1),(114235,'116185','printshop','block-114233-2','batchRemove','',1),(114236,'116186','printshop','block-114233-2','productListing\\price','',3),(114237,'116187','printshop','block-114233-2','productListing\\name','',2),(114238,'116188','printshop','bbbbb','BlockBox','',1),(114239,'116189','printshop','block-114238','BlockBox','',2),(114240,'116190','printshop','block-114239','Filters','',1),(114241,'116191','printshop','block-114239-2','BlockBox','',6),(114242,'116192','printshop','block-114241','catalog\\CountsItems','',1),(114243,'116193','printshop','block-114241-2','catalog\\Paging','',1),(114244,'116194','printshop','block-114239-2','catalog\\Image','',1),(114245,'116195','printshop','block-114239-2','Listing','',5),(114246,'116196','printshop','block-114239-2','catalog\\ImageMapCategory','',3),(114247,'116197','printshop','block-114239-2','BlockBox','',4),(114248,'116198','printshop','block-114247','catalog\\ListingLook','',1),(114249,'116199','printshop','block-114247','catalog\\CompareButton','',2),(114250,'116200','printshop','block-114247','catalog\\ItemsOnPage','',4),(114251,'116201','printshop','block-114247','catalog\\Sorting','',3),(114252,'116202','printshop','block-114239-2','Categories','',2),(114253,'116203','printshop','block-114238','catalog\\Title','',1),(114254,'1683121571.054367','printshop','cart','BlockBox','',1),(114255,'1683121571.06664','printshop','block-114254','BlockBox','',2),(114256,'1683121571.069437','printshop','block-114255','BlockBox','cart-content',4),(114257,'1683121571.078735','printshop','block-114255','BlockBox','',1),(114258,'1683121571.080729','printshop','block-114257','cart\\Products','',4),(114259,'1683121571.081549','printshop','block-114257','BlockBox','',3),(114260,'1683121571.08463','printshop','block-114259','MultiCart\\CartSwitcher','',1),(114261,'1683121571.085411','printshop','block-114259','MultiCart\\SaveCart','',2),(114262,'1683121571.086647','printshop','block-114259-2','MultiCart\\Actions','',1),(114263,'1683121571.087562','printshop','block-114257','BlockBox','',5),(114264,'1683121571.088844','printshop','block-114263','BlockBox','',3),(114265,'1683121571.089839','printshop','block-114264','cart\\CreditAmount','',2),(114266,'1683121571.09021','printshop','block-114264-2','cart\\BonusPoints','',1),(114267,'1683121571.090954','printshop','block-114257','Html_box','',2),(114268,'1683121571.092944','printshop','block-114255','cart\\ShippingEstimator','',5),(114269,'1683121571.09410','printshop','block-114255-2','BlockBox','',1),(114270,'1683121571.095515','printshop','block-114269','BlockBox','',2),(114271,'1683121571.096422','printshop','block-114270','cart\\DiscountCoupon','',1),(114272,'1683121571.107437','printshop','block-114270','cart\\CheckoutBtn','',3),(114273,'1683121571.108775','printshop','block-114270','cart\\OrderTotal','',2),(114274,'1683121571.109664','printshop','block-114270','cart\\OrderTotal','',0),(114275,'1683121571.110832','printshop','block-114269','Html_box','',1),(114276,'116242','printshop','cart2','BlockBox','',2),(114277,'116243','printshop','block-114276','cart\\CartTabs','',2),(114278,'116244','printshop','block-114277','BlockBox','',1),(114279,'116245','printshop','block-114278','BlockBox','',4),(114280,'116246','printshop','block-114279','cart\\UpSell','6',2),(114281,'116247','printshop','block-114279','Html_box','',1),(114282,'116248','printshop','block-114278','BlockBox','',1),(114283,'116249','printshop','block-114282','cart\\Products','',3),(114284,'116250','printshop','block-114282','BlockBox','',2),(114285,'116251','printshop','block-114284','MultiCart\\CartSwitcher','',1),(114286,'116252','printshop','block-114284','MultiCart\\SaveCart','',2),(114287,'116253','printshop','block-114284-2','MultiCart\\Actions','',1),(114288,'116254','printshop','block-114278','BlockBox','',3),(114289,'116255','printshop','block-114288','cart\\GiveAway','',2),(114290,'116256','printshop','block-114288','Html_box','',1),(114291,'116257','printshop','block-114278','BlockBox','',2),(114292,'116258','printshop','block-114291','Html_box','',1),(114293,'116259','printshop','block-114291','BlockBox','',2),(114294,'116260','printshop','block-114293','cart\\DiscountCoupon','',1),(114295,'116261','printshop','block-114293-2','cart\\CreditAmount','',1),(114296,'116262','printshop','block-114293-3','cart\\BonusPoints','',1),(114297,'116263','printshop','block-114278','BlockBox','',5),(114298,'116264','printshop','block-114297','Html_box','',1),(114299,'116265','printshop','block-114297','cart\\ShippingEstimator','',2),(114300,'116266','printshop','block-114278-2','BlockBox','',1),(114301,'116267','printshop','block-114300','Html_box','',1),(114302,'116268','printshop','block-114300','BlockBox','',2),(114303,'116269','printshop','block-114302','Image','',4),(114304,'116270','printshop','block-114302','cart\\CheckoutBtn','',2),(114305,'116271','printshop','block-114302','cart\\OrderTotal','',1),(114316,'116272','printshop','categories','BlockBox','catalog-content',2),(114317,'116281','printshop','block-114316','Categories','',2),(114318,'116287','printshop','block-114316','catalog\\Title','',1),(114319,'1644410221.0341','printshop','categories','BlockBox','',1),(114320,'1644410246.7393','printshop','block-114319','Breadcrumb','',0),(114321,'116288','printshop','category','Categories','',1),(114322,'116289','printshop','category','Listing','',4),(114323,'116290','printshop','category','ListingFunctionality','',2),(114324,'116291','printshop','category','PagingBar','',3),(114325,'116292','printshop','category','PagingBar','',5),(114326,'116293','printshop','category_2','BlockBox','',1),(114327,'116294','printshop','block-114326','catalog\\Title','',1),(114328,'116295','printshop','block-114326','BlockBox','',2),(114329,'116296','printshop','block-114328','Filters','',1),(114330,'116297','printshop','block-114328-2','catalog\\Image','',1),(114331,'116298','printshop','block-114328-2','Listing','',5),(114332,'116299','printshop','block-114328-2','BlockBox','',4),(114333,'116300','printshop','block-114332','catalog\\Sorting','',3),(114334,'116301','printshop','block-114332','catalog\\ItemsOnPage','',4),(114335,'116302','printshop','block-114332','catalog\\CompareButton','',2),(114336,'116303','printshop','block-114332','catalog\\ListingLook','',1),(114337,'116304','printshop','block-114328-2','catalog\\ImageMapCategory','',3),(114338,'116305','printshop','block-114328-2','Categories','',2),(114339,'116306','printshop','block-114328-2','BlockBox','',6),(114340,'116307','printshop','block-114339','catalog\\CountsItems','',1),(114341,'116308','printshop','block-114339-2','catalog\\Paging','',1),(114342,'116309','printshop','category_no_filters','BlockBox','catalog-content',2),(114343,'116310','printshop','block-114342','catalog\\Title','',2),(114344,'116311','printshop','block-114342','Categories','',4),(114345,'116312','printshop','block-114342','BlockBox','catalog-features',5),(114346,'116313','printshop','block-114345','catalog\\ItemsOnPage','',4),(114347,'116314','printshop','block-114345','catalog\\Sorting','',3),(114348,'116315','printshop','block-114345','catalog\\CompareButton','',2),(114349,'116316','printshop','block-114345','catalog\\ListingLook','',1),(114350,'116317','printshop','block-114345','HeaderStock','',5),(114351,'116318','printshop','block-114342','BlockBox','',7),(114352,'116319','printshop','block-114351','catalog\\CountsItems','',1),(114353,'116320','printshop','block-114351-2','catalog\\Paging','',1),(114354,'116321','printshop','block-114342','Listing','',6),(114355,'116322','printshop','block-114342','catalog\\Image','',3),(114356,'116323','printshop','block-114342','catalog\\B2bAddButton','',8),(114357,'1645199413.4466','printshop','category_no_filters','BlockBox','',1),(114358,'1645199453.4261','printshop','block-114357','Breadcrumb','',0),(114359,'1683123155.763578','printshop','checkout','BlockBox','',2),(114360,'1683123155.780265','printshop','block-114359','BlockBox','',2),(114361,'1683123155.783425','printshop','block-114360','BlockBox','',2),(114362,'1683123155.78537','printshop','block-114361','BlockBox','checkout-comments',4),(114363,'1683123155.788891','printshop','block-114362','checkout\\Comments','',2),(114364,'1683123155.790851','printshop','block-114362','Html_box','',1),(114365,'1683123155.79411','printshop','block-114361','BlockBox','checkout-discount',3),(114366,'1683123155.797477','printshop','block-114365','Html_box','',1),(114367,'1683123155.799115','printshop','block-114365','BlockBox','',2),(114368,'1683123155.800526','printshop','block-114367','CouponsAndVauchers\\Checkout','',1),(114369,'1683123155.802510','printshop','block-114367-2','checkout\\CreditAmount','',1),(114370,'1683123155.804496','printshop','block-114367-2','checkout\\BonusPoints','',2),(114371,'1683123155.806347','printshop','block-114361','BlockBox','checkout-shipping',1),(114372,'1683123155.808713','printshop','block-114371','BlockBox','',3),(114373,'1683123155.81126','printshop','block-114372','checkout\\ShippingChoice','',1),(114374,'1683123155.81663','printshop','block-114371','Neighbour\\Checkout','',5),(114375,'1683123155.81847','printshop','block-114371','BlockBox','',4),(114376,'1683123155.819772','printshop','block-114375','BlockBox','',1),(114377,'1683123155.821777','printshop','block-114376','checkout\\ShippingAddress','',2),(114378,'1683123155.824396','printshop','block-114376','Html_box','',3),(114379,'1683123155.825857','printshop','block-114376','checkout\\ContactInformation','',4),(114380,'1683123155.827441','printshop','block-114376','UploadCustomerId\\UploadCustomerIdForm','',5),(114381,'1683123155.830610','printshop','block-114375-2','BlockBox','',1),(114382,'1683123155.83245','printshop','block-114381','checkout\\Shipping','',2),(114383,'1683123155.833668','printshop','block-114381','DelayedDespatch\\Checkout','',4),(114384,'1683123155.835296','printshop','block-114381','Html_box','',1),(114385,'1683123155.83711','printshop','block-114381','DeliveryDay','',3),(114386,'1683123155.840722','printshop','block-114371','Html_box','',2),(114387,'1683123155.842595','printshop','block-114361','cart\\Products','',6),(114388,'1683123155.846131','printshop','block-114361','checkout\\CreateAccount','',7),(114389,'1683123155.849743','printshop','block-114361','DeliveryOptions\\Checkout','',5),(114390,'1683123155.851776','printshop','block-114361','BlockBox','checkout-payment',2),(114391,'1683123155.855125','printshop','block-114390','Html_box','',1),(114392,'1683123155.856899','printshop','block-114390','BlockBox','',2),(114393,'1683123155.858186','printshop','block-114392','Html_box','',1),(114394,'1683123155.859329','printshop','block-114392','checkout\\BillingAddress','',2),(114395,'1683123155.863160','printshop','block-114392-2','BlockBox','',1),(114396,'1683123155.864648','printshop','block-114395','checkout\\PaymentMethod','',2),(114397,'1683123155.866124','printshop','block-114395','Html_box','',1),(114398,'1683123155.867656','printshop','block-114361','BlockBox','',0),(114399,'1683123155.869487','printshop','block-114398','checkout\\LoginOnForm','',0),(114400,'1683123155.87110','printshop','block-114360-2','BlockBox','checkout-side',1),(114401,'1683123155.877884','printshop','block-114400','Html_box','',6),(114402,'1683123155.879734','printshop','block-114400','Html_box','',1),(114403,'1683123155.881441','printshop','block-114400','checkout\\Terms','',5),(114404,'1683123155.883138','printshop','block-114400','checkout\\Totals','',3),(114405,'1683123155.88477','printshop','block-114400','checkout\\ContinueBtn','',4),(114406,'1683123155.887325','printshop','block-114400','cart\\Products','',2),(114407,'116368','printshop','checkout_confirmation','BlockBox','',1),(114408,'116369','printshop','block-114407','checkout\\Totals','',8),(114409,'116370','printshop','block-114407','Html_box','',5),(114410,'116371','printshop','block-114407','checkout\\EditBtn','',6),(114411,'116372','printshop','block-114407','BlockBox','',3),(114412,'116373','printshop','block-114411','BlockBox','',1),(114413,'116374','printshop','block-114412','Html_box','',1),(114414,'116375','printshop','block-114412','checkout\\ShippingConfirm','',3),(114415,'116376','printshop','block-114411-2','BlockBox','',1),(114416,'116377','printshop','block-114415','checkout\\PaymentMethodConfirm','',3),(114417,'116378','printshop','block-114415','Html_box','',1),(114418,'116379','printshop','block-114407','checkout\\ConfirmBtn','',9),(114419,'116380','printshop','block-114407','BlockBox','',2),(114420,'116381','printshop','block-114419','BlockBox','',1),(114421,'116382','printshop','block-114420','checkout\\ShippingAddressConfirm','',3),(114422,'116383','printshop','block-114420','Html_box','',1),(114423,'116384','printshop','block-114419-2','BlockBox','',1),(114424,'116385','printshop','block-114423','Html_box','',1),(114425,'116386','printshop','block-114423','checkout\\BillingAddressConfirm','',3),(114426,'116387','printshop','block-114407','checkout\\ConfirmBtn','',4),(114427,'116388','printshop','block-114407','cart\\Products','',7),(114428,'116402','printshop','checkout_confirmation_no_shipping','BlockBox','',1),(114429,'116403','printshop','block-114428','checkout\\ConfirmBtn','',9),(114430,'116404','printshop','block-114428','BlockBox','',2),(114431,'116405','printshop','block-114430','BlockBox','',1),(114432,'116406','printshop','block-114431','Html_box','',1),(114433,'116407','printshop','block-114431','checkout\\BillingAddressConfirm','',3),(114434,'116408','printshop','block-114430-2','BlockBox','',1),(114435,'116409','printshop','block-114434','Html_box','',1),(114436,'116410','printshop','block-114434','checkout\\PaymentMethodConfirm','',3),(114437,'116411','printshop','block-114428','checkout\\ConfirmBtn','',4),(114438,'116412','printshop','block-114428','checkout\\Totals','',8),(114439,'116413','printshop','block-114428','cart\\Products','',7),(114440,'116414','printshop','block-114428','Html_box','',5),(114441,'116389','printshop','checkout_confirmation_no_shipping_q','BlockBox','',1),(114442,'116390','printshop','block-114441','quote\\Products','',4),(114443,'116391','printshop','block-114441','checkout\\ConfirmBtn','',2),(114444,'116392','printshop','block-114441','checkout\\ConfirmBtn','',6),(114445,'116393','printshop','block-114441','BlockBox','',1),(114446,'116394','printshop','block-114445','BlockBox','',1),(114447,'116395','printshop','block-114446','checkout\\BillingAddressConfirm','',3),(114448,'116396','printshop','block-114446','Html_box','',1),(114449,'116397','printshop','block-114445-2','BlockBox','',1),(114450,'116398','printshop','block-114449','checkout\\PaymentMethodConfirm','',3),(114451,'116399','printshop','block-114449','Html_box','',1),(114452,'116400','printshop','block-114441','Html_box','',3),(114453,'116401','printshop','block-114441','checkout\\Totals','',5),(114454,'116415','printshop','checkout_confirmation_q','BlockBox','',1),(114455,'116416','printshop','block-114454','BlockBox','',1),(114456,'116417','printshop','block-114455','BlockBox','',1),(114457,'116418','printshop','block-114456','checkout\\ShippingAddressConfirm','',3),(114458,'116419','printshop','block-114456','Html_box','',1),(114459,'116420','printshop','block-114455-2','BlockBox','',1),(114460,'116421','printshop','block-114459','checkout\\BillingAddressConfirm','',3),(114461,'116422','printshop','block-114459','Html_box','',1),(114462,'116423','printshop','block-114454','checkout\\Totals','',7),(114463,'116424','printshop','block-114454','quote\\Products','',6),(114464,'116425','printshop','block-114454','Html_box','',4),(114465,'116426','printshop','block-114454','checkout\\EditBtn','',5),(114466,'116427','printshop','block-114454','checkout\\ConfirmBtn','',8),(114467,'116428','printshop','block-114454','checkout\\ConfirmBtn','',3),(114468,'116429','printshop','block-114454','BlockBox','',2),(114469,'116430','printshop','block-114468','BlockBox','',1),(114470,'116431','printshop','block-114469','Html_box','',1),(114471,'116432','printshop','block-114469','checkout\\ShippingConfirm','',3),(114472,'116433','printshop','block-114468-2','BlockBox','',1),(114473,'116434','printshop','block-114472','Html_box','',1),(114474,'116435','printshop','block-114472','checkout\\PaymentMethodConfirm','',3),(114475,'116436','printshop','checkout_confirmation_title','Html_box','',1),(114476,'116437','printshop','checkout_confirmation_title_g','Html_box','',1),(114477,'116439','printshop','checkout_confirmation_title_no_shipping','Html_box','',1),(114478,'116438','printshop','checkout_confirmation_title_no_shipping_g','Html_box','',1),(114479,'116440','printshop','checkout_confirmation_title_q','Html_box','',1),(114480,'116441','printshop','checkout_confirmation_title_s','Html_box','',1),(114481,'116442','printshop','checkout_delivery','BlockBox','',2),(114482,'116443','printshop','block-114481','BlockBox','',1),(114483,'116444','printshop','block-114482','Html_box','',1),(114484,'116445','printshop','block-114482','checkout\\ContactInformation','',2),(114485,'116446','printshop','block-114481-2','BlockBox','',1),(114486,'116447','printshop','block-114485','Html_box','',1),(114487,'116448','printshop','block-114485','checkout\\Comments','',2),(114488,'116449','printshop','checkout_delivery','BlockBox','',3),(114489,'116450','printshop','block-114488','Html_box','',1),(114490,'116451','printshop','block-114488-2','checkout\\ContinueBtn','',1),(114491,'116452','printshop','checkout_delivery','BlockBox','',1),(114492,'116453','printshop','block-114491','BlockBox','',1),(114493,'116454','printshop','block-114492','Html_box','',1),(114494,'116455','printshop','block-114492','checkout\\ShippingAddress','',2),(114495,'116456','printshop','block-114491-2','BlockBox','',1),(114496,'116457','printshop','block-114495','DelayedDespatch\\Checkout','',3),(114497,'116458','printshop','block-114495','checkout\\Shipping','',2),(114498,'116459','printshop','block-114495','Html_box','',1),(114499,'116460','printshop','block-114495','Neighbour\\Checkout','',4),(114500,'116461','printshop','checkout_delivery_g','BlockBox','',2),(114501,'116462','printshop','block-114500','BlockBox','',1),(114502,'116463','printshop','block-114501','checkout\\ContactInformation','',2),(114503,'116464','printshop','block-114501','Html_box','',1),(114504,'116465','printshop','block-114500-2','BlockBox','',1),(114505,'116466','printshop','block-114504','Html_box','',1),(114506,'116467','printshop','block-114504','checkout\\Comments','',2),(114507,'116468','printshop','checkout_delivery_g','BlockBox','',3),(114508,'116469','printshop','block-114507','Html_box','',1),(114509,'116470','printshop','block-114507-2','checkout\\ContinueBtn','',1),(114510,'116471','printshop','checkout_delivery_g','BlockBox','',1),(114511,'116472','printshop','block-114510','BlockBox','',1),(114512,'116473','printshop','block-114511','checkout\\ShippingAddress','',2),(114513,'116474','printshop','block-114511','Html_box','',1),(114514,'116475','printshop','block-114510-2','BlockBox','',1),(114515,'116476','printshop','block-114514','checkout\\Shipping','',2),(114516,'116477','printshop','block-114514','Html_box','',1),(114517,'116478','printshop','block-114514','DelayedDespatch\\Checkout','',3),(114518,'116479','printshop','block-114514','Neighbour\\Checkout','',4),(114519,'116480','printshop','checkout_delivery_no_shipping','BlockBox','',2),(114520,'116481','printshop','block-114519','Html_box','',1),(114521,'116482','printshop','block-114519-2','checkout\\ContinueBtn','',1),(114522,'116483','printshop','checkout_delivery_no_shipping','BlockBox','',1),(114523,'116484','printshop','block-114522','BlockBox','',1),(114524,'116485','printshop','block-114523','checkout\\ContactInformation','',2),(114525,'116486','printshop','block-114522-2','BlockBox','',1),(114526,'116487','printshop','block-114525','Html_box','',1),(114527,'116488','printshop','block-114525','checkout\\Comments','',2),(114528,'116489','printshop','checkout_delivery_no_shipping_g','BlockBox','',2),(114529,'116490','printshop','block-114528','Html_box','',1),(114530,'116491','printshop','block-114528-2','checkout\\ContinueBtn','',1),(114531,'116492','printshop','checkout_delivery_no_shipping_g','BlockBox','',1),(114532,'116493','printshop','block-114531','BlockBox','',1),(114533,'116494','printshop','block-114532','checkout\\ContactInformation','',2),(114534,'116495','printshop','block-114531-2','BlockBox','',1),(114535,'116496','printshop','block-114534','checkout\\Comments','',2),(114536,'116497','printshop','block-114534','Html_box','',1),(114537,'116498','printshop','checkout_delivery_title','Html_box','',1),(114538,'116499','printshop','checkout_delivery_title_g','Html_box','',1),(114539,'116501','printshop','checkout_delivery_title_no_shipping','Html_box','',1),(114540,'116500','printshop','checkout_delivery_title_no_shipping_g','Html_box','',1),(114541,'116502','printshop','checkout_delivery_title_q','Html_box','',1),(114542,'116503','printshop','checkout_delivery_title_s','Html_box','',1),(114543,'116504','printshop','checkout_free_s','BlockBox','',1),(114544,'116505','printshop','block-114543','BlockBox','',2),(114545,'116506','printshop','block-114544','BlockBox','',2),(114546,'116508','printshop','block-114545','BlockBox','',6),(114547,'116509','printshop','block-114546','sample\\Products','',1),(114548,'116510','printshop','block-114546','checkout\\CreateAccount','',3),(114549,'116511','printshop','block-114545','BlockBox','',5),(114550,'116512','printshop','block-114549','Html_box','',1),(114551,'116513','printshop','block-114549','checkout\\Comments','',2),(114552,'116514','printshop','block-114545','BlockBox','',2),(114553,'116515','printshop','block-114552','BlockBox','',2),(114554,'116516','printshop','block-114553','checkout\\ShippingChoice','',1),(114555,'116517','printshop','block-114552','Html_box','',1),(114556,'116518','printshop','block-114552','BlockBox','',3),(114557,'116519','printshop','block-114556','BlockBox','',1),(114558,'116520','printshop','block-114557','checkout\\ContactInformation','',4),(114559,'116521','printshop','block-114557','checkout\\ShippingAddress','',2),(114560,'116522','printshop','block-114557','Html_box','',3),(114561,'116523','printshop','block-114556-2','BlockBox','',1),(114562,'116524','printshop','block-114561','DelayedDespatch\\Checkout','',3),(114563,'116525','printshop','block-114552','Neighbour\\Checkout','',4),(114564,'116526','printshop','block-114544-2','BlockBox','',1),(114565,'116527','printshop','block-114564','Html_box','',3),(114566,'116528','printshop','block-114564','checkout\\ContinueBtn','',1),(114567,'1638956949.0762','printshop','block-114564','checkout\\Terms','',2),(114568,'1638957135.2709','printshop','block-114564','Html_box','',0),(114569,'116529','printshop','checkout_no_shipping','BlockBox','',1),(114570,'116530','printshop','block-114569','BlockBox','',2),(114571,'116531','printshop','block-114570','BlockBox','',1),(114572,'116532','printshop','block-114571','BlockBox','',6),(114573,'116533','printshop','block-114572','checkout\\CreateAccount','',2),(114574,'116534','printshop','block-114572','cart\\Products','',1),(114575,'116535','printshop','block-114571','BlockBox','',3),(114576,'116536','printshop','block-114575','Html_box','',1),(114577,'116537','printshop','block-114575','BlockBox','',2),(114578,'116538','printshop','block-114577','checkout\\BillingAddress','',2),(114579,'116539','printshop','block-114577','Html_box','',1),(114580,'116540','printshop','block-114577-2','BlockBox','',1),(114581,'116541','printshop','block-114580','Html_box','',1),(114582,'116542','printshop','block-114580','checkout\\PaymentMethod','',2),(114583,'116543','printshop','block-114571','BlockBox','',4),(114584,'116544','printshop','block-114583','BlockBox','',2),(114585,'116545','printshop','block-114584','CouponsAndVauchers\\Checkout','',1),(114586,'116546','printshop','block-114584-2','checkout\\CreditAmount','',1),(114587,'116547','printshop','block-114584-2','checkout\\BonusPoints','',2),(114588,'116548','printshop','block-114583','Html_box','',1),(114589,'116549','printshop','block-114571','BlockBox','',5),(114590,'116550','printshop','block-114589','checkout\\Comments','',2),(114591,'116551','printshop','block-114589','Html_box','',1),(114592,'116552','printshop','block-114570-2','BlockBox','',1),(114593,'116553','printshop','block-114592','Html_box','',1),(114594,'116554','printshop','block-114592','Html_box','',5),(114595,'116555','printshop','block-114592','checkout\\Totals','',2),(114596,'116556','printshop','block-114592','checkout\\ContinueBtn','',3),(114597,'116557','printshop','block-114592','checkout\\Terms','',4),(114598,'116558','printshop','checkout_no_shipping_g','BlockBox','',1),(114599,'116559','printshop','block-114598','checkout\\Totals','',5),(114600,'116560','printshop','block-114598','BlockBox','',6),(114601,'116561','printshop','block-114600','Html_box','',1),(114602,'116562','printshop','block-114600-2','checkout\\ContinueBtn','',1),(114603,'116563','printshop','block-114598','BlockBox','',2),(114604,'116564','printshop','block-114603','BlockBox','',1),(114605,'116565','printshop','block-114604','checkout\\ContactInformation','',2),(114606,'116566','printshop','block-114604','Html_box','',1),(114607,'116567','printshop','block-114603-2','BlockBox','',1),(114608,'116568','printshop','block-114607','checkout\\Comments','',2),(114609,'116569','printshop','block-114607','Html_box','',1),(114610,'116570','printshop','block-114598','BlockBox','',1),(114611,'116571','printshop','block-114610','BlockBox','',1),(114612,'116572','printshop','block-114611','Html_box','',1),(114613,'116573','printshop','block-114611','checkout\\BillingAddress','',2),(114614,'116574','printshop','block-114610-2','BlockBox','',1),(114615,'116575','printshop','block-114614','checkout\\BonusPoints','',4),(114616,'116576','printshop','block-114614','CouponsAndVauchers\\Checkout','',5),(114617,'116577','printshop','block-114614','checkout\\PaymentMethod','',2),(114618,'116578','printshop','block-114614','checkout\\CreditAmount','',3),(114619,'116579','printshop','block-114614','Html_box','',1),(114620,'116580','printshop','block-114598','quote\\Products','',3),(114621,'116581','printshop','checkout_no_shipping_q','BlockBox','',1),(114622,'116582','printshop','block-114621','BlockBox','',2),(114623,'116583','printshop','block-114622','BlockBox','',2),(114624,'116585','printshop','block-114623','BlockBox','',5),(114625,'116586','printshop','block-114624','checkout\\Comments','',2),(114626,'116587','printshop','block-114624','Html_box','',1),(114627,'116588','printshop','block-114623','BlockBox','',6),(114628,'116589','printshop','block-114627','checkout\\CreateAccount','',3),(114629,'116590','printshop','block-114627','quote\\Products','',2),(114630,'116591','printshop','block-114623','BlockBox','',3),(114631,'116592','printshop','block-114630','Html_box','',1),(114632,'116593','printshop','block-114630','BlockBox','',2),(114633,'116594','printshop','block-114632','Html_box','',1),(114634,'116595','printshop','block-114632','checkout\\BillingAddress','',2),(114635,'116596','printshop','block-114632-2','BlockBox','',1),(114636,'116597','printshop','block-114635','checkout\\PaymentMethod','',2),(114637,'116598','printshop','block-114635','Html_box','',1),(114638,'116599','printshop','block-114622-2','BlockBox','',1),(114639,'116600','printshop','block-114638','checkout\\ContinueBtn','',3),(114640,'116601','printshop','block-114638','Html_box','',5),(114641,'116602','printshop','block-114638','Html_box','',1),(114642,'116603','printshop','block-114638','checkout\\Totals','',2),(114643,'120984','printshop','block-114638','checkout\\Terms','',4),(114644,'116604','printshop','checkout_payment','BlockBox','',1),(114645,'116605','printshop','block-114644','BlockBox','',1),(114646,'116606','printshop','block-114645','checkout\\BillingAddress','',2),(114647,'116607','printshop','block-114645','Html_box','',1),(114648,'116608','printshop','block-114644-2','BlockBox','',1),(114649,'116609','printshop','block-114648','checkout\\CreditAmount','',3),(114650,'116610','printshop','block-114648','checkout\\BonusPoints','',4),(114651,'116611','printshop','block-114648','CouponsAndVauchers\\Checkout','',5),(114652,'116612','printshop','block-114648','checkout\\PaymentMethod','',2),(114653,'116613','printshop','block-114648','Html_box','',1),(114654,'116614','printshop','checkout_payment','BlockBox','',2),(114655,'116615','printshop','block-114654','Html_box','',1),(114656,'116616','printshop','block-114654-2','checkout\\ContinueBtn','',1),(114657,'116617','printshop','checkout_payment_g','BlockBox','',1),(114658,'116618','printshop','block-114657','BlockBox','',1),(114659,'116619','printshop','block-114658','checkout\\BillingAddress','',2),(114660,'116620','printshop','block-114658','Html_box','',1),(114661,'116621','printshop','block-114657-2','BlockBox','',1),(114662,'116622','printshop','block-114661','checkout\\CreditAmount','',3),(114663,'116623','printshop','block-114661','Html_box','',1),(114664,'116624','printshop','block-114661','checkout\\PaymentMethod','',2),(114665,'116625','printshop','block-114661','CouponsAndVauchers\\Checkout','',5),(114666,'116626','printshop','block-114661','checkout\\BonusPoints','',4),(114667,'116627','printshop','checkout_payment_g','BlockBox','',2),(114668,'116628','printshop','block-114667','Html_box','',1),(114669,'116629','printshop','block-114667-2','checkout\\ContinueBtn','',1),(114670,'116630','printshop','checkout_payment_no_shipping','BlockBox','',2),(114671,'116631','printshop','block-114670','Html_box','',1),(114672,'116632','printshop','block-114670-2','checkout\\ContinueBtn','',1),(114673,'116633','printshop','checkout_payment_no_shipping','BlockBox','',1),(114674,'116634','printshop','block-114673','BlockBox','',1),(114675,'116635','printshop','block-114674','Html_box','',1),(114676,'116636','printshop','block-114674','checkout\\BillingAddress','',2),(114677,'116637','printshop','block-114673-2','BlockBox','',1),(114678,'116638','printshop','block-114677','checkout\\BonusPoints','',4),(114679,'116639','printshop','block-114677','CouponsAndVauchers\\Checkout','',5),(114680,'116640','printshop','block-114677','checkout\\PaymentMethod','',2),(114681,'116641','printshop','block-114677','checkout\\CreditAmount','',3),(114682,'116642','printshop','block-114677','Html_box','',1),(114683,'116643','printshop','checkout_payment_no_shipping_g','BlockBox','',2),(114684,'116644','printshop','block-114683','Html_box','',1),(114685,'116645','printshop','block-114683-2','checkout\\ContinueBtn','',1),(114686,'116646','printshop','checkout_payment_no_shipping_g','BlockBox','',1),(114687,'116647','printshop','block-114686','BlockBox','',1),(114688,'116648','printshop','block-114687','checkout\\BillingAddress','',2),(114689,'116649','printshop','block-114687','Html_box','',1),(114690,'116650','printshop','block-114686-2','BlockBox','',1),(114691,'116651','printshop','block-114690','checkout\\BonusPoints','',4),(114692,'116652','printshop','block-114690','checkout\\CreditAmount','',3),(114693,'116653','printshop','block-114690','checkout\\PaymentMethod','',2),(114694,'116654','printshop','block-114690','Html_box','',1),(114695,'116655','printshop','block-114690','CouponsAndVauchers\\Checkout','',5),(114696,'116656','printshop','checkout_payment_title','Html_box','',1),(114697,'116657','printshop','checkout_payment_title_g','Html_box','',1),(114698,'116658','printshop','checkout_payment_title_no_shipping','Html_box','',1),(114699,'116659','printshop','checkout_payment_title_no_shipping_g','Html_box','',1),(114700,'116660','printshop','checkout_payment_title_q','Html_box','',1),(114701,'116661','printshop','checkout_payment_title_s','Html_box','',1),(114702,'120947','printshop','checkout_q','BlockBox','',1),(114703,'120948','printshop','block-114702','BlockBox','',2),(114704,'120949','printshop','block-114703','BlockBox','',2),(114705,'120950','printshop','block-114704','BlockBox','',6),(114706,'120951','printshop','block-114705','checkout\\CreateAccount','',3),(114707,'120952','printshop','block-114705','quote\\Products','',2),(114708,'120953','printshop','block-114704','BlockBox','',2),(114709,'120954','printshop','block-114708','BlockBox','',2),(114710,'120955','printshop','block-114709','checkout\\ShippingChoice','',1),(114711,'120956','printshop','block-114708','Neighbour\\Checkout','',4),(114712,'120957','printshop','block-114708','Html_box','',1),(114713,'120958','printshop','block-114708','BlockBox','',3),(114714,'120959','printshop','block-114713','BlockBox','',1),(114715,'120960','printshop','block-114714','checkout\\ContactInformation','',4),(114716,'120961','printshop','block-114714','checkout\\ShippingAddress','',2),(114717,'120962','printshop','block-114714','Html_box','',3),(114718,'120963','printshop','block-114713-2','BlockBox','',1),(114719,'120964','printshop','block-114718','checkout\\Shipping','',2),(114720,'120965','printshop','block-114718','Html_box','',1),(114721,'120966','printshop','block-114718','DelayedDespatch\\Checkout','',3),(114722,'120967','printshop','block-114704','BlockBox','',5),(114723,'120968','printshop','block-114722','Html_box','',1),(114724,'120969','printshop','block-114722','checkout\\Comments','',2),(114725,'120970','printshop','block-114704','BlockBox','',3),(114726,'120971','printshop','block-114725','Html_box','',1),(114727,'120972','printshop','block-114725','BlockBox','',2),(114728,'120973','printshop','block-114727','checkout\\BillingAddress','',2),(114729,'120974','printshop','block-114727','Html_box','',1),(114730,'120975','printshop','block-114727-2','BlockBox','',1),(114731,'120976','printshop','block-114730','checkout\\PaymentMethod','',2),(114732,'120977','printshop','block-114730','Html_box','',1),(114733,'120978','printshop','block-114703-2','BlockBox','',1),(114734,'120979','printshop','block-114733','Html_box','',1),(114735,'120980','printshop','block-114733','Html_box','',5),(114736,'120981','printshop','block-114733','checkout\\Totals','',2),(114737,'120982','printshop','block-114733','checkout\\ContinueBtn','',3),(114738,'120983','printshop','block-114733','checkout\\Terms','',4),(114739,'116699','printshop','checkout_s','BlockBox','',1),(114740,'116700','printshop','block-114739','BlockBox','',2),(114741,'116701','printshop','block-114740','BlockBox','',2),(114742,'116703','printshop','block-114741','BlockBox','',6),(114743,'116704','printshop','block-114742','sample\\Products','',1),(114744,'116705','printshop','block-114742','checkout\\CreateAccount','',3),(114745,'116706','printshop','block-114741','BlockBox','',2),(114746,'116707','printshop','block-114745','Html_box','',1),(114747,'116708','printshop','block-114745','Neighbour\\Checkout','',4),(114748,'116709','printshop','block-114745','BlockBox','',2),(114749,'116710','printshop','block-114748','checkout\\ShippingChoice','',1),(114750,'116711','printshop','block-114745','BlockBox','',3),(114751,'116712','printshop','block-114750','BlockBox','',1),(114752,'116713','printshop','block-114751','checkout\\ShippingAddress','',2),(114753,'116714','printshop','block-114751','checkout\\ContactInformation','',4),(114754,'116715','printshop','block-114751','Html_box','',3),(114755,'116716','printshop','block-114750-2','BlockBox','',1),(114756,'116717','printshop','block-114755','checkout\\Shipping','',2),(114757,'116718','printshop','block-114755','DelayedDespatch\\Checkout','',3),(114758,'116719','printshop','block-114755','Html_box','',1),(114759,'116720','printshop','block-114741','BlockBox','',3),(114760,'116721','printshop','block-114759','BlockBox','',2),(114761,'116722','printshop','block-114760','Html_box','',1),(114762,'116723','printshop','block-114760','checkout\\BillingAddress','',2),(114763,'116724','printshop','block-114760-2','BlockBox','',1),(114764,'116725','printshop','block-114763','Html_box','',1),(114765,'116726','printshop','block-114763','checkout\\PaymentMethod','',2),(114766,'116727','printshop','block-114759','Html_box','',1),(114767,'116728','printshop','block-114741','BlockBox','',5),(114768,'116729','printshop','block-114767','Html_box','',1),(114769,'116730','printshop','block-114767','checkout\\Comments','',2),(114770,'116731','printshop','block-114741','BlockBox','',4),(114771,'116732','printshop','block-114770','BlockBox','',2),(114772,'116733','printshop','block-114771','CouponsAndVauchers\\Checkout','',1),(114773,'116734','printshop','block-114771-2','checkout\\BonusPoints','',2),(114774,'116735','printshop','block-114771-2','checkout\\CreditAmount','',1),(114775,'116736','printshop','block-114770','Html_box','',1),(114776,'116737','printshop','block-114740-2','BlockBox','',1),(114777,'116738','printshop','block-114776','checkout\\Totals','',2),(114778,'116739','printshop','block-114776','Html_box','',5),(114779,'116740','printshop','block-114776','Html_box','',1),(114780,'116741','printshop','block-114776','checkout\\ContinueBtn','',3),(114781,'120986','printshop','block-114776','checkout\\Terms','',4),(114782,'116742','printshop','checkout_step_bottom','Html_box','',1),(114783,'116743','printshop','checkout_step_bottom','cart\\Products','',2),(114784,'116744','printshop','checkout_step_bottom','checkout\\Totals','',3),(114785,'116745','printshop','checkout_step_bottom_g','checkout\\Totals','',3),(114786,'116746','printshop','checkout_step_bottom_g','quote\\Products','',2),(114787,'116747','printshop','checkout_step_bottom_g','Html_box','',1),(114788,'116749','printshop','checkout_step_bottom_no_shipping','Html_box','',1),(114789,'116750','printshop','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(114790,'116753','printshop','checkout_step_bottom_no_shipping','cart\\Products','',2),(114791,'116748','printshop','checkout_step_bottom_no_shipping_g','Html_box','',1),(114792,'116751','printshop','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(114793,'116752','printshop','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(114794,'116754','printshop','communication','BlockBox','',1),(114795,'116755','printshop','block-114794','Html_box','',2),(114796,'116756','printshop','block-114794','Communication\\NewTopicButton','',1),(114797,'116757','printshop','block-114794','Communication\\Topic','',3),(114798,'116758','printshop','compare','BlockBox','',1),(114799,'116759','printshop','block-114798','catalog\\Compare','',1),(114800,'117665.000001','printshop','compareproduct','BlockBox','listing-item',1),(114801,'120921.000001','printshop','block-114800','BlockBox','',1),(114802,'120919.000001','printshop','block-114801','BlockBox','listing-item',1),(114803,'1638872990.9609','printshop','block-114802','BlockBox','',2),(114804,'117671.000001','printshop','block-114803','productListing\\image','',1),(114805,'117677.000001','printshop','block-114803-2','productListing\\compare','',1),(114806,'117675.000001','printshop','block-114803-2','productListing\\name','',2),(114807,'117676.000001','printshop','block-114803-2','productListing\\stock','',3),(114808,'1638873112.0384','printshop','block-114803-2','BlockBox','',4),(114809,'117670.000001','printshop','block-114808','productListing\\rating','',2),(114810,'117673.000001','printshop','block-114808-2','productListing\\price','',1),(114811,'116760','printshop','compare_products','BlockBox','',2),(114812,'116761','printshop','block-114811','productListing\\rating','',4),(114813,'116762','printshop','block-114811','productListing\\model','',5),(114814,'116763','printshop','block-114811','productListing\\compare','',1),(114815,'116764','printshop','block-114811','BlockBox','',2),(114816,'116765','printshop','block-114815','productListing\\image','',1),(114817,'116766','printshop','block-114815-2','productListing\\name','',2),(114818,'116767','printshop','block-114811','BlockBox','',3),(114819,'116768','printshop','block-114818','productListing\\price','',1),(114820,'116769','printshop','block-114818-2','productListing\\buyButton','',1),(114821,'116770','printshop','confirmation','BlockBox','',1),(114822,'116771','printshop','block-114821','BlockBox','',2),(114823,'116772','printshop','block-114822','BlockBox','',2),(114824,'116773','printshop','block-114823','BlockBox','',4),(114825,'116774','printshop','block-114824','checkout\\EditBtn','',2),(114826,'116775','printshop','block-114824','cart\\Products','',3),(114827,'116776','printshop','block-114824','Html_box','',1),(114828,'116777','printshop','block-114823','BlockBox','',3),(114829,'116778','printshop','block-114828','checkout\\EditBtn','',2),(114830,'116779','printshop','block-114828','Html_box','',1),(114831,'116780','printshop','block-114828','checkout\\CommentsConfirm','',3),(114832,'116781','printshop','block-114823','BlockBox','',1),(114833,'116782','printshop','block-114832','BlockBox','',1),(114834,'116783','printshop','block-114833','checkout\\EditBtn','',6),(114835,'116784','printshop','block-114833','DelayedDespatch\\CheckoutConfirm','',8),(114836,'116785','printshop','block-114833','Html_box','',9),(114837,'116786','printshop','block-114833','checkout\\EditBtn','',10),(114838,'116787','printshop','block-114833','Html_box','',5),(114839,'116788','printshop','block-114833','checkout\\ShippingConfirm','',7),(114840,'116789','printshop','block-114833','Html_box','',1),(114841,'116790','printshop','block-114833','checkout\\EditBtn','',3),(114842,'116791','printshop','block-114833','checkout\\ContactConfirm','',11),(114843,'116792','printshop','block-114833','Html_box','',2),(114844,'116793','printshop','block-114833','checkout\\ShippingAddressConfirm','',4),(114845,'116794','printshop','block-114832-2','BlockBox','',1),(114846,'116795','printshop','block-114845','checkout\\EditBtn','',6),(114847,'116796','printshop','block-114845','checkout\\EditBtn','',3),(114848,'116797','printshop','block-114845','checkout\\PaymentMethodConfirm','',7),(114849,'116798','printshop','block-114845','Html_box','',5),(114850,'116799','printshop','block-114845','Html_box','',1),(114851,'116800','printshop','block-114845','checkout\\BillingAddressConfirm','',4),(114852,'116801','printshop','block-114845','Html_box','',2),(114853,'116802','printshop','block-114822','UploadCustomerId\\UploadCustomerIdForm','',1),(114854,'116803','printshop','block-114822-2','BlockBox','',1),(114855,'116804','printshop','block-114854','Html_box','',1),(114856,'116805','printshop','block-114854','checkout\\ConfirmBtn','',3),(114857,'116806','printshop','block-114854','checkout\\Totals','',2),(114858,'116807','printshop','block-114821','Html_box','',1),(114859,'116808','printshop','confirmation_free_s','BlockBox','',1),(114860,'116809','printshop','block-114859','BlockBox','',2),(114861,'116810','printshop','block-114860','BlockBox','',1),(114862,'116811','printshop','block-114861','BlockBox','',2),(114863,'116812','printshop','block-114862','checkout\\CommentsConfirm','',3),(114864,'116813','printshop','block-114862','checkout\\EditBtn','',2),(114865,'116814','printshop','block-114862','Html_box','',1),(114866,'116815','printshop','block-114861','BlockBox','',3),(114867,'116816','printshop','block-114866','checkout\\EditBtn','',3),(114868,'116817','printshop','block-114866','Html_box','',1),(114869,'116818','printshop','block-114866','sample\\Products','',2),(114870,'116819','printshop','block-114861','BlockBox','',1),(114871,'116820','printshop','block-114870','BlockBox','',1),(114872,'116821','printshop','block-114871','checkout\\EditBtn','',3),(114873,'116822','printshop','block-114871','checkout\\ShippingConfirm','',7),(114874,'116823','printshop','block-114871','Html_box','',5),(114875,'116824','printshop','block-114871','checkout\\EditBtn','',6),(114876,'116825','printshop','block-114871','Html_box','',2),(114877,'116826','printshop','block-114871','checkout\\ShippingAddressConfirm','',4),(114878,'116827','printshop','block-114870-2','BlockBox','',1),(114879,'116828','printshop','block-114878','checkout\\ContactConfirm','',3),(114880,'116829','printshop','block-114878','DelayedDespatch\\CheckoutConfirm','',4),(114881,'116830','printshop','block-114878','checkout\\EditBtn','',2),(114882,'116831','printshop','block-114878','Html_box','',1),(114883,'116832','printshop','block-114860-2','BlockBox','',1),(114884,'116833','printshop','block-114883','checkout\\ConfirmBtn','',3),(114885,'116834','printshop','block-114859','Html_box','',1),(114886,'116835','printshop','confirmation_no_shipping','BlockBox','',1),(114887,'116836','printshop','block-114886','Html_box','',1),(114888,'116837','printshop','block-114886','BlockBox','',2),(114889,'116838','printshop','block-114888','BlockBox','',1),(114890,'116839','printshop','block-114889','BlockBox','',1),(114891,'116840','printshop','block-114890','BlockBox','',1),(114892,'116841','printshop','block-114891','checkout\\EditBtn','',10),(114893,'116842','printshop','block-114891','Html_box','',9),(114894,'116843','printshop','block-114891','checkout\\ContactConfirm','',11),(114895,'116844','printshop','block-114890-2','BlockBox','',1),(114896,'116845','printshop','block-114895','checkout\\PaymentMethodConfirm','',7),(114897,'116846','printshop','block-114895','checkout\\EditBtn','',6),(114898,'116847','printshop','block-114895','Html_box','',5),(114899,'116848','printshop','block-114895','Html_box','',1),(114900,'116849','printshop','block-114895','checkout\\EditBtn','',3),(114901,'116850','printshop','block-114895','checkout\\BillingAddressConfirm','',4),(114902,'116851','printshop','block-114895','Html_box','',2),(114903,'116852','printshop','block-114889','BlockBox','',2),(114904,'116853','printshop','block-114903','Html_box','',1),(114905,'116854','printshop','block-114903','checkout\\CommentsConfirm','',3),(114906,'116855','printshop','block-114903','checkout\\EditBtn','',2),(114907,'116856','printshop','block-114889','BlockBox','',3),(114908,'116857','printshop','block-114907','Html_box','',1),(114909,'116858','printshop','block-114907','checkout\\EditBtn','',2),(114910,'116859','printshop','block-114907','cart\\Products','',3),(114911,'116860','printshop','block-114888-2','BlockBox','',1),(114912,'116861','printshop','block-114911','checkout\\ConfirmBtn','',3),(114913,'116862','printshop','block-114911','Html_box','',1),(114914,'116863','printshop','block-114911','checkout\\Totals','',2),(114915,'116864','printshop','confirmation_no_shipping_q','BlockBox','',2),(114916,'116865','printshop','block-114915','Html_box','',1),(114917,'116866','printshop','block-114915','BlockBox','',2),(114918,'116867','printshop','block-114917','BlockBox','',1),(114919,'116868','printshop','block-114918','BlockBox','',2),(114920,'116869','printshop','block-114919','Html_box','',1),(114921,'116870','printshop','block-114919','checkout\\CommentsConfirm','',3),(114922,'116871','printshop','block-114919','checkout\\EditBtn','',2),(114923,'116872','printshop','block-114918','BlockBox','',1),(114924,'116873','printshop','block-114923','BlockBox','',1),(114925,'116874','printshop','block-114924','checkout\\EditBtn','',5),(114926,'116875','printshop','block-114924','checkout\\ContactConfirm','',6),(114927,'116876','printshop','block-114924','checkout\\PaymentMethodConfirm','',3),(114928,'116877','printshop','block-114924','checkout\\EditBtn','',2),(114929,'116878','printshop','block-114924','Html_box','',4),(114930,'116879','printshop','block-114924','Html_box','',1),(114931,'116880','printshop','block-114923-2','BlockBox','',1),(114932,'116881','printshop','block-114931','checkout\\BillingAddressConfirm','',4),(114933,'116882','printshop','block-114931','checkout\\EditBtn','',3),(114934,'116883','printshop','block-114931','Html_box','',2),(114935,'116884','printshop','block-114918','BlockBox','',3),(114936,'116885','printshop','block-114935','checkout\\EditBtn','',2),(114937,'116886','printshop','block-114935','Html_box','',1),(114938,'116887','printshop','block-114935','quote\\Products','',3),(114939,'116888','printshop','block-114917-2','BlockBox','',1),(114940,'116889','printshop','block-114939','checkout\\ConfirmBtn','',3),(114941,'116890','printshop','block-114939','checkout\\Totals','',2),(114942,'116891','printshop','block-114939','Html_box','',1),(114943,'116892','printshop','confirmation_q','BlockBox','',1),(114944,'116893','printshop','block-114943','Html_box','',1),(114945,'116894','printshop','block-114943','BlockBox','',2),(114946,'116895','printshop','block-114945','BlockBox','',1),(114947,'116896','printshop','block-114946','BlockBox','',3),(114948,'116897','printshop','block-114947','quote\\Products','',3),(114949,'116898','printshop','block-114947','Html_box','',1),(114950,'116899','printshop','block-114947','checkout\\EditBtn','',2),(114951,'116900','printshop','block-114946','BlockBox','',1),(114952,'116901','printshop','block-114951','BlockBox','',1),(114953,'116902','printshop','block-114952','Html_box','',1),(114954,'116903','printshop','block-114952','checkout\\EditBtn','',10),(114955,'116904','printshop','block-114952','Html_box','',2),(114956,'116905','printshop','block-114952','checkout\\ContactConfirm','',11),(114957,'116906','printshop','block-114952','checkout\\ShippingAddressConfirm','',4),(114958,'116907','printshop','block-114952','checkout\\ShippingConfirm','',7),(114959,'116908','printshop','block-114952','checkout\\EditBtn','',3),(114960,'116909','printshop','block-114952','DelayedDespatch\\CheckoutConfirm','',8),(114961,'116910','printshop','block-114952','Html_box','',9),(114962,'116911','printshop','block-114952','Html_box','',5),(114963,'116912','printshop','block-114952','checkout\\EditBtn','',6),(114964,'116913','printshop','block-114951-2','BlockBox','',1),(114965,'116914','printshop','block-114964','checkout\\EditBtn','',3),(114966,'116915','printshop','block-114964','checkout\\BillingAddressConfirm','',4),(114967,'116916','printshop','block-114964','checkout\\PaymentMethodConfirm','',7),(114968,'116917','printshop','block-114964','Html_box','',1),(114969,'116918','printshop','block-114964','Html_box','',2),(114970,'116919','printshop','block-114964','checkout\\EditBtn','',6),(114971,'116920','printshop','block-114964','Html_box','',5),(114972,'116921','printshop','block-114946','BlockBox','',2),(114973,'116922','printshop','block-114972','checkout\\CommentsConfirm','',3),(114974,'116923','printshop','block-114972','Html_box','',1),(114975,'116924','printshop','block-114972','checkout\\EditBtn','',2),(114976,'116925','printshop','block-114945-2','BlockBox','',1),(114977,'116926','printshop','block-114976','Html_box','',1),(114978,'116927','printshop','block-114976','checkout\\Totals','',2),(114979,'116928','printshop','block-114976','checkout\\ConfirmBtn','',3),(114980,'116929','printshop','confirmation_s','BlockBox','',1),(114981,'116930','printshop','block-114980','BlockBox','',2),(114982,'116931','printshop','block-114981','BlockBox','',1),(114983,'116932','printshop','block-114982','BlockBox','',1),(114984,'116933','printshop','block-114983','BlockBox','',1),(114985,'116934','printshop','block-114984','checkout\\ShippingAddressConfirm','',4),(114986,'116935','printshop','block-114984','checkout\\EditBtn','',3),(114987,'116936','printshop','block-114984','Html_box','',2),(114988,'116937','printshop','block-114984','DelayedDespatch\\CheckoutConfirm','',8),(114989,'116938','printshop','block-114984','checkout\\ShippingConfirm','',7),(114990,'116939','printshop','block-114984','Html_box','',1),(114991,'116940','printshop','block-114984','Html_box','',5),(114992,'116941','printshop','block-114984','Html_box','',9),(114993,'116942','printshop','block-114984','checkout\\ContactConfirm','',11),(114994,'116943','printshop','block-114984','checkout\\EditBtn','',6),(114995,'116944','printshop','block-114984','checkout\\EditBtn','',10),(114996,'116945','printshop','block-114983-2','BlockBox','',1),(114997,'116946','printshop','block-114996','Html_box','',2),(114998,'116947','printshop','block-114996','checkout\\BillingAddressConfirm','',4),(114999,'116948','printshop','block-114996','checkout\\EditBtn','',3),(115000,'116949','printshop','block-114996','checkout\\PaymentMethodConfirm','',7),(115001,'116950','printshop','block-114996','checkout\\EditBtn','',6),(115002,'116951','printshop','block-114996','Html_box','',1),(115003,'116952','printshop','block-114996','Html_box','',5),(115004,'116953','printshop','block-114982','BlockBox','',3),(115005,'116954','printshop','block-115004','checkout\\EditBtn','',3),(115006,'116955','printshop','block-115004','Html_box','',1),(115007,'116956','printshop','block-115004','sample\\Products','',2),(115008,'116957','printshop','block-114982','BlockBox','',2),(115009,'116958','printshop','block-115008','Html_box','',1),(115010,'116959','printshop','block-115008','checkout\\EditBtn','',2),(115011,'116960','printshop','block-115008','checkout\\CommentsConfirm','',3),(115012,'116961','printshop','block-114981-2','BlockBox','',1),(115013,'116962','printshop','block-115012','checkout\\Totals','',2),(115014,'116963','printshop','block-115012','checkout\\ConfirmBtn','',3),(115015,'116964','printshop','block-115012','Html_box','',1),(115016,'116965','printshop','block-114980','Html_box','',1),(115017,'116966','printshop','contact','BlockBox','info-content',1),(115018,'116967','printshop','block-115017','info\\Title','',1),(115019,'116968','printshop','block-115017','BlockBox','',2),(115020,'116969','printshop','block-115019','contact\\ContactForm','',1),(115021,'116970','printshop','block-115019-2','contact\\Contacts','',1),(115022,'116971','printshop','created_success','BlockBox','',1),(115023,'116972','printshop','block-115022','Html_box','',1),(115024,'116973','printshop','block-115022','Html_box','',2),(115025,'116102.000001','printshop','credit_amount_history','BlockBox','',1),(115026,'116103.000001','printshop','block-115025','BlockBox','',1),(115027,'116104.000001','printshop','block-115026','WidgetsAria','',1),(115047,'116109.000001','printshop','block-115026-2','Html_box','',1),(115048,'1638895944.9672','printshop','block-115026-2','account\\CreditAmountHistory','',2),(115049,'116974','printshop','credit_note','invoice\\Container','',1),(115050,'116975','printshop','block-115049','BlockBox','',5),(115051,'116976','printshop','block-115050','invoice\\StoreAddress','',8),(115052,'116977','printshop','block-115050','Text','',1),(115053,'116978','printshop','block-115050-2','Text','',2),(115054,'116979','printshop','block-115050-2','Logo','',1),(115055,'116980','printshop','block-115050-3','Text','',1),(115056,'116981','printshop','block-115050-3','BlockBox','',3),(115057,'116982','printshop','block-115056','Text','',1),(115058,'116983','printshop','block-115056-2','invoice\\StoreEmail','',1),(115059,'116984','printshop','block-115050-3','BlockBox','',2),(115060,'116985','printshop','block-115059','Text','',1),(115061,'116986','printshop','block-115059-2','invoice\\StorePhone','',1),(115062,'116987','printshop','block-115049','invoice\\Products','',3),(115063,'116988','printshop','block-115049','BlockBox','',1),(115064,'116989','printshop','block-115063','Logo','',1),(115065,'116990','printshop','block-115063-2','BlockBox','',4),(115066,'116991','printshop','block-115065','Text','',1),(115067,'116992','printshop','block-115065-2','invoice\\StoreSite','',1),(115068,'116993','printshop','block-115063-2','BlockBox','',2),(115069,'116994','printshop','block-115068','Text','',1),(115070,'116995','printshop','block-115068-2','invoice\\StorePhone','',1),(115071,'116996','printshop','block-115063-2','BlockBox','',3),(115072,'116997','printshop','block-115071','Text','',1),(115073,'116998','printshop','block-115071-2','invoice\\StoreEmail','',1),(115074,'116999','printshop','block-115063-2','BlockBox','',1),(115075,'117000','printshop','block-115074','invoice\\StoreAddress','',1),(115076,'117001','printshop','block-115049','BlockBox','',4),(115077,'117002','printshop','block-115076','BlockBox','',1),(115078,'117003','printshop','block-115077','invoice\\ShippingAddress','',2),(115079,'117004','printshop','block-115077','Text','',1),(115080,'117005','printshop','block-115076-2','BlockBox','',1),(115081,'117006','printshop','block-115049','BlockBox','',2),(115082,'117007','printshop','block-115081','BlockBox','',7),(115083,'117008','printshop','block-115082','BlockBox','',1),(115084,'117009','printshop','block-115083','Text','',1),(115085,'117010','printshop','block-115083','invoice\\BillingAddress','',2),(115086,'117011','printshop','block-115082-2','BlockBox','',1),(115087,'117012','printshop','block-115086','invoice\\CustomerPhone','',4),(115088,'117013','printshop','block-115086','Text','',1),(115089,'117014','printshop','block-115086','Text','',3),(115090,'117015','printshop','block-115086','invoice\\CustomerName','',2),(115091,'117016','printshop','block-115086','invoice\\CustomerEmail','',6),(115092,'117017','printshop','block-115086','Text','',5),(115093,'117018','printshop','block-115081','BlockBox','',8),(115094,'117019','printshop','block-115093','BlockBox','',1),(115095,'117020','printshop','block-115094','invoice\\ShippingMethod','',2),(115096,'117021','printshop','block-115094','Text','',1),(115097,'117022','printshop','block-115093-2','BlockBox','',1),(115098,'117023','printshop','block-115097','Text','',1),(115099,'117024','printshop','block-115097','invoice\\ShippingMethod','',2),(115100,'117025','printshop','block-115081-2','invoice\\OrderId','',1),(115101,'117026','printshop','block-115081-2','Text','',2),(115102,'117027','printshop','block-115081-2','invoice\\PaymentDate','',3),(115103,'117034','printshop','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(115104,'1639155816.3893','printshop','delivery-location','BlockBox','',2),(115105,'117028','printshop','block-115104','DeliveryLocation\\FeaturedList','',6),(115106,'117029','printshop','block-115104','DeliveryLocation\\LocationLongDescription','',3),(115107,'117030','printshop','block-115104','DeliveryLocation\\LocationList','',4),(115108,'117031','printshop','block-115104','DeliveryLocation\\LocationTitle','',1),(115109,'117032','printshop','block-115104','DeliveryLocation\\LocationProducts','',7),(115110,'117033','printshop','block-115104','DeliveryLocation\\LocationDescription','',2),(115111,'1639485067.5512','printshop','block-115104','DeliveryLocation\\CrossPages','',0),(115112,'1639485089.2227','printshop','block-115104','DeliveryLocation\\ProductCategories','',0),(115113,'1639154415.2739','printshop','delivery-location-default','BlockBox','',2),(115114,'117035','printshop','block-115113','DeliveryLocation\\TopLocationList','',2),(115115,'117036','printshop','block-115113','Heading','',1),(115116,'1639419797.9718','printshop','block-115113','DeliveryLocation\\ListByPage','',3),(115117,'117037','printshop','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(115118,'117038','printshop','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(115119,'117039','printshop','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(115120,'117040','printshop','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(115121,'117041','printshop','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(115122,'117042','printshop','delivery_loc_2','DeliveryLocation\\LocationList','',7),(115123,'117043','printshop','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(115124,'117044','printshop','email','email\\BlockBox','',1),(115125,'117045','printshop','block-115124','email\\BlockBox','',1),(115126,'117046','printshop','block-115125','Copyright','',4),(115127,'117047','printshop','block-115125','email\\Content','',3),(115128,'117048','printshop','block-115125','email\\BlockBox','',2),(115129,'117049','printshop','block-115128','email\\Title','',1),(115130,'117050','printshop','block-115128-2','email\\Date','',1),(115131,'117051','printshop','block-115125','Logo','',1),(115132,'117052','printshop','email_2','email\\BlockBox','',1),(115133,'117053','printshop','block-115132','email\\BlockBox','',1),(115134,'117054','printshop','block-115133','Copyright','',4),(115135,'117055','printshop','block-115133','Logo','',1),(115136,'117056','printshop','block-115133','email\\Content','',3),(115137,'117057','printshop','block-115133','email\\BlockBox','',2),(115138,'117058','printshop','block-115137','email\\Title','',1),(115139,'117059','printshop','block-115137-2','email\\Date','',1),(115140,'117060','printshop','email_3','email\\BlockBox','',1),(115141,'117061','printshop','block-115140','email\\BlockBox','',1),(115142,'117062','printshop','block-115141','email\\BlockBox','',2),(115143,'117063','printshop','block-115142','email\\Content','',2),(115144,'117064','printshop','block-115142','email\\BlockBox','',1),(115145,'117065','printshop','block-115144','email\\Title','',1),(115146,'117066','printshop','block-115144-2','email\\Date','',1),(115147,'117067','printshop','block-115141','Copyright','',3),(115148,'117068','printshop','block-115141','Logo','',1),(115149,'117069','printshop','email_4','email\\BlockBox','',1),(115150,'117070','printshop','block-115149','email\\BlockBox','',1),(115151,'117071','printshop','block-115150','Copyright','',2),(115152,'117072','printshop','block-115150','email\\BlockBox','',1),(115153,'117073','printshop','block-115152','email\\BlockBox','',1),(115154,'117074','printshop','block-115153','Logo','',1),(115155,'117075','printshop','block-115153-2','email\\Date','',2),(115156,'117076','printshop','block-115153-2','email\\Title','',1),(115157,'117077','printshop','block-115152','email\\Content','',2),(115158,'121029','printshop','filescatalog_category','BlockBox','',1),(115159,'121030','printshop','block-115158','FilesCatalog\\widgets\\FilesList','',3),(115160,'121031','printshop','block-115158','FilesCatalog\\widgets\\Title','',1),(115161,'121032','printshop','block-115158','FilesCatalog\\widgets\\Description','',2),(115162,'121025','printshop','filescatalog_index','BlockBox','',1),(115163,'121026','printshop','block-115162','Html_box','',1),(115164,'121027','printshop','block-115162','FilesCatalog\\widgets\\FilesCatalog','',2),(115165,'117078','printshop','footer','BlockBox','footer-content',1),(115166,'120869','printshop','block-115165','BlockBox','',2),(115167,'120870','printshop','block-115166','Image','',3),(115168,'1644341222.4626','printshop','block-115166-2','SocialLinks','',1),(115169,'1644573331.7071','printshop','block-115166-3','Image','',1),(115170,'1644340895.1318','printshop','block-115165','BlockBox','',1),(115171,'117085','printshop','block-115170','Menu','Footer',1),(115172,'1644342832.3703','printshop','block-115170-2','BlockBox','',2),(115173,'117091','printshop','block-115172','Contacts','',1),(115174,'1644406988.3921','printshop','block-115172','Text','',0),(115175,'1644406713.4425','printshop','block-115172-2','Contacts','',1),(115176,'1644406751.9542','printshop','block-115172-2','Contacts','',2),(115177,'117093','printshop','footer','BlockBox','',2),(115178,'117094','printshop','block-115177','Copyright','',1),(115179,'117096','printshop','for_menu','BlockBox','',1),(115180,'117097','printshop','block-115179','Html_box','',1),(115181,'117098','printshop','block-115179-2','Languages','',1),(115182,'117099','printshop','for_menu','BlockBox','',3),(115183,'117100','printshop','block-115182','Html_box','',1),(115184,'117101','printshop','block-115182-2','Currencies','',1),(115185,'117102','printshop','gift','BlockBox','',1),(115186,'117103','printshop','block-115185','BlockBox','',3),(115187,'117104','printshop','block-115186','BlockBox','',1),(115188,'117105','printshop','block-115187','gift\\Card','',1),(115189,'117106','printshop','block-115186-2','gift\\Form','',2),(115190,'117107','printshop','block-115186-2','Text','',1),(115191,'117108','printshop','block-115185','info\\Title','',1),(115192,'117109','printshop','gift_card','BlockBox','',1),(115193,'117110','printshop','block-115192','BlockBox','',11),(115194,'117111','printshop','block-115193','invoice\\StoreEmail','',3),(115195,'117112','printshop','block-115193','Text','',1),(115196,'117113','printshop','block-115193','invoice\\StorePhone','',2),(115197,'117114','printshop','block-115192','Text','',8),(115198,'117115','printshop','block-115192','Text','',3),(115199,'117116','printshop','block-115192','BlockBox','',10),(115200,'117117','printshop','block-115199','Text','',1),(115201,'117118','printshop','block-115199-2','gift\\CodeView','',1),(115202,'117119','printshop','block-115192','gift\\MessageView','',7),(115203,'117120','printshop','block-115192','gift\\AmountView','',5),(115204,'117121','printshop','block-115192','Text','',6),(115205,'117123','printshop','block-115192','Logo','',1),(115206,'117124','printshop','block-115192','Text','',4),(115207,'117125','printshop','block-115192','Text','',9),(115208,'117126','printshop','gift_card_2','BlockBox','',1),(115209,'117127','printshop','block-115208','gift\\AmountView','',4),(115210,'117128','printshop','block-115208','BlockBox','',9),(115211,'117129','printshop','block-115210','Text','',1),(115212,'117130','printshop','block-115210-2','gift\\CodeView','',1),(115213,'117131','printshop','block-115208','BlockBox','',10),(115214,'117132','printshop','block-115213','invoice\\StoreEmail','',3),(115215,'117133','printshop','block-115213','Text','',1),(115216,'117134','printshop','block-115213','invoice\\StorePhone','',2),(115217,'117135','printshop','block-115208','gift\\MessageView','',6),(115218,'117136','printshop','block-115208','Text','',5),(115219,'117137','printshop','block-115208','Text','',8),(115220,'117138','printshop','block-115208','Text','',3),(115221,'117139','printshop','block-115208','Text','',7),(115222,'1638804282.8587','printshop','block-115208','Logo','',1),(115223,'117141','printshop','gift_card_2_pdf','BlockBox','',1),(115224,'117142','printshop','block-115223','BlockBox','',12),(115225,'117143','printshop','block-115224','invoice\\StoreEmail','',4),(115226,'117144','printshop','block-115224','invoice\\StorePhone','',3),(115227,'117145','printshop','block-115224','Html_box','',1),(115228,'117146','printshop','block-115223','BlockBox','',11),(115229,'117147','printshop','block-115228','Html_box','',1),(115230,'117148','printshop','block-115228-2','gift\\CodeViewPdf','',1),(115231,'117149','printshop','block-115223','BlockBox','',1),(115232,'117150','printshop','block-115231','Text','',4),(115233,'117151','printshop','block-115231','Html_box','',1),(115234,'117152','printshop','block-115231','Html_box','',2),(115235,'117153','printshop','block-115231','gift\\AmountViewPdf','',3),(115236,'117154','printshop','block-115231','gift\\MessageViewPdf','',5),(115237,'117155','printshop','block-115231','Html_box','',7),(115238,'117156','printshop','block-115231','Html_box','',6),(115239,'117158','printshop','gift_card_pdf','BlockBox','',1),(115240,'117159','printshop','block-115239','BlockBox','',12),(115241,'117160','printshop','block-115240','invoice\\StoreEmail','',4),(115242,'117161','printshop','block-115240','invoice\\StorePhone','',3),(115243,'117162','printshop','block-115240','Html_box','',1),(115244,'117163','printshop','block-115239','BlockBox','',11),(115245,'117164','printshop','block-115244','Html_box','',1),(115246,'117165','printshop','block-115244-2','gift\\CodeViewPdf','',1),(115247,'117166','printshop','block-115239','BlockBox','',1),(115248,'117167','printshop','block-115247','Text','',5),(115249,'117169','printshop','block-115247','Html_box','',3),(115250,'117170','printshop','block-115247','gift\\AmountViewPdf','',4),(115251,'117171','printshop','block-115247','gift\\MessageViewPdf','',6),(115252,'117172','printshop','block-115247','Html_box','',8),(115253,'117173','printshop','block-115247','Html_box','',7),(115254,'1638978695.8384','printshop','block-115247','Logo','',2),(115255,'117175','printshop','gift_certificate','BlockBox','',1),(115256,'117176','printshop','block-115255','account\\ApplyCertificate','',2),(115257,'117177','printshop','block-115255','Html_box','',1),(115258,'117178','printshop','gigt_card_3','BlockBox','',1),(115259,'117179','printshop','block-115258','BlockBox','',9),(115260,'117180','printshop','block-115259','Text','',1),(115261,'117181','printshop','block-115259-2','gift\\CodeView','',1),(115262,'117182','printshop','block-115258','Text','',7),(115263,'117184','printshop','block-115258','BlockBox','',10),(115264,'117185','printshop','block-115263','Text','',1),(115265,'117186','printshop','block-115263','invoice\\StoreEmail','',3),(115266,'117187','printshop','block-115263','invoice\\StorePhone','',2),(115267,'117188','printshop','block-115258','gift\\MessageView','',6),(115268,'117189','printshop','block-115258','Text','',3),(115269,'117190','printshop','block-115258','Text','',5),(115270,'117191','printshop','block-115258','gift\\AmountView','',4),(115271,'117192','printshop','block-115258','Text','',8),(115272,'1638804328.7281','printshop','block-115258','Logo','',1),(115273,'117193','printshop','gigt_card_3_pdf','BlockBox','',1),(115274,'117194','printshop','block-115273','BlockBox','',12),(115275,'117195','printshop','block-115274','invoice\\StoreEmail','',4),(115276,'117196','printshop','block-115274','invoice\\StorePhone','',3),(115277,'117197','printshop','block-115274','Html_box','',1),(115278,'117198','printshop','block-115273','BlockBox','',11),(115279,'117199','printshop','block-115278','Html_box','',1),(115280,'117200','printshop','block-115278-2','gift\\CodeViewPdf','',1),(115281,'117201','printshop','block-115273','BlockBox','',1),(115282,'117202','printshop','block-115281','Text','',4),(115283,'117203','printshop','block-115281','Html_box','',1),(115284,'117204','printshop','block-115281','Html_box','',2),(115285,'117205','printshop','block-115281','gift\\AmountViewPdf','',3),(115286,'117206','printshop','block-115281','gift\\MessageViewPdf','',5),(115287,'117207','printshop','block-115281','Html_box','',7),(115288,'117208','printshop','block-115281','Html_box','',6),(115306,'117224','printshop','info','BlockBox','info-content',1),(115307,'117225','printshop','block-115306','info\\DescriptionShort','',3),(115308,'117226','printshop','block-115306','info\\Content','',6),(115309,'117227','printshop','block-115306','info\\Title','',1),(115310,'117228','printshop','block-115306','info\\Image','',4),(115311,'1638467467.3028','printshop','block-115306','info\\DescriptionShort','',5),(115312,'117229','printshop','invoice','invoice\\Container','',1),(115313,'117230','printshop','block-115312','BlockBox','',4),(115314,'117231','printshop','block-115313','BlockBox','',8),(115315,'117232','printshop','block-115314','BlockBox','',1),(115316,'117233','printshop','block-115315','invoice\\ShippingMethod','',2),(115317,'117234','printshop','block-115315','Text','',1),(115318,'117235','printshop','block-115314-2','BlockBox','',1),(115319,'117236','printshop','block-115318','Text','',1),(115320,'117237','printshop','block-115318','invoice\\ShippingMethod','',2),(115321,'117238','printshop','block-115313','BlockBox','',7),(115322,'117239','printshop','block-115321','BlockBox','',1),(115323,'117240','printshop','block-115322','Text','',1),(115324,'117241','printshop','block-115322','invoice\\BillingAddress','',2),(115325,'1639659760.0392','printshop','block-115322','GiftWrapMessage\\ShowInfo','',3),(115326,'117242','printshop','block-115321-2','BlockBox','',1),(115327,'117243','printshop','block-115326','Text','',5),(115328,'117244','printshop','block-115326','invoice\\CustomerName','',2),(115329,'117245','printshop','block-115326','invoice\\CustomerPhone','',4),(115330,'117246','printshop','block-115326','Text','',1),(115331,'117247','printshop','block-115326','Text','',3),(115332,'117248','printshop','block-115326','invoice\\CustomerEmail','',6),(115333,'117249','printshop','block-115313-2','invoice\\PaymentMethod','',6),(115334,'117250','printshop','block-115313-2','Text','',5),(115335,'117251','printshop','block-115313-2','Text','',3),(115336,'117252','printshop','block-115313-2','invoice\\OrderId','',2),(115337,'117253','printshop','block-115313-2','invoice\\PaymentDate','',4),(115338,'117254','printshop','block-115313-2','invoice\\OrderBarcode','',7),(115339,'117255','printshop','block-115312','BlockBox','',8),(115340,'117256','printshop','block-115339','invoice\\StoreAddress','',8),(115341,'117257','printshop','block-115339','Text','',1),(115342,'117258','printshop','block-115339-2','Text','',2),(115343,'117260','printshop','block-115339-3','BlockBox','',3),(115344,'117261','printshop','block-115343','Text','',1),(115345,'117262','printshop','block-115343-2','invoice\\StoreEmail','',1),(115346,'117263','printshop','block-115339-3','BlockBox','',2),(115347,'117264','printshop','block-115346','Text','',1),(115348,'117265','printshop','block-115346-2','invoice\\StorePhone','',1),(115349,'117266','printshop','block-115339-3','Text','',1),(115350,'117267','printshop','block-115312','invoice\\Products','',5),(115351,'117268','printshop','block-115312','BlockBox','',7),(115352,'117269','printshop','block-115351','BlockBox','',1),(115353,'117270','printshop','block-115352','invoice\\ShippingAddress','',2),(115354,'117271','printshop','block-115352','Text','',1),(115355,'117272','printshop','block-115351-2','BlockBox','',1),(115356,'117273','printshop','block-115355','invoice\\Totals','',1),(115357,'117274','printshop','block-115312','BlockBox','',2),(115358,'117275','printshop','block-115357','Logo','',1),(115359,'117276','printshop','block-115357-2','BlockBox','',4),(115360,'117277','printshop','block-115359','Text','',1),(115361,'117278','printshop','block-115359-2','invoice\\StoreSite','',1),(115362,'117279','printshop','block-115357-2','BlockBox','',3),(115363,'117280','printshop','block-115362','Text','',1),(115364,'117281','printshop','block-115362-2','invoice\\StoreEmail','',1),(115365,'117282','printshop','block-115357-2','BlockBox','',1),(115366,'117283','printshop','block-115365','invoice\\StoreAddress','',2),(115367,'117284','printshop','block-115357-2','BlockBox','',2),(115368,'117285','printshop','block-115367','Text','',1),(115369,'117286','printshop','block-115367-2','invoice\\StorePhone','',1),(115370,'1640103567.8175','printshop','block-115312','invoice\\StructuredProducts','',6),(115371,'117287','printshop','login_account','BlockBox','',1),(115372,'117288','printshop','block-115371','Tabs','',2),(115373,'117289','printshop','block-115372-1','login\\Returning','',1),(115374,'117290','printshop','block-115372-2','BlockBox','',1),(115375,'117291','printshop','block-115374','Html_box','',1),(115376,'117292','printshop','block-115374-2','BlockBox','',1),(115377,'117293','printshop','block-115376','Html_box','',2),(115378,'117294','printshop','block-115376','login\\Register','',1),(115379,'117295','printshop','block-115371','BlockBox','',1),(115380,'117296','printshop','block-115379','Html_box','',5),(115381,'117297','printshop','block-115379','Html_box','',1),(115382,'117298','printshop','block-115379','login\\Socials','',4),(115383,'117299','printshop','login_checkout','BlockBox','',1),(115384,'117300','printshop','block-115383','BlockBox','',1),(115385,'1644496194.7022','printshop','block-115384','BlockBox','',0),(115386,'117301','printshop','block-115385','checkout\\CreateBtn','',4),(115387,'117302','printshop','block-115385','checkout\\GuestBtn','',2),(115388,'117303','printshop','block-115385','Html_box','',3),(115389,'117304','printshop','block-115385','BlockBox','',5),(115390,'117305','printshop','block-115389','Html_box','',1),(115391,'117306','printshop','block-115389','login\\Socials','',2),(115392,'117307','printshop','block-115385','Html_box','',1),(115393,'1644496248.7478','printshop','block-115384-2','BlockBox','',2),(115394,'117308','printshop','block-115393','login\\Returning','',2),(115395,'117309','printshop','block-115393','Html_box','',1),(115396,'117310','printshop','login_checkout2','BlockBox','',1),(115397,'117311','printshop','block-115396','Tabs','',4),(115398,'117312','printshop','block-115397-1','BlockBox','',1),(115399,'117313','printshop','block-115398','Html_box','',1),(115400,'117314','printshop','block-115398-2','BlockBox','',1),(115401,'117315','printshop','block-115400','login\\Guest','',1),(115402,'117316','printshop','block-115400','Html_box','',2),(115403,'117317','printshop','block-115397-2','login\\Returning','',1),(115404,'117318','printshop','block-115397-3','BlockBox','',1),(115405,'117319','printshop','block-115404','Html_box','',1),(115406,'117320','printshop','block-115404-2','BlockBox','',1),(115407,'117321','printshop','block-115406','Html_box','',2),(115408,'117322','printshop','block-115406','login\\Register','',1),(115409,'117323','printshop','block-115396','login\\Socials','',2),(115410,'117324','printshop','block-115396','Html_box','',3),(115411,'117325','printshop','block-115396','Html_box','',1),(115412,'117326','printshop','login_checkout2_q','BlockBox','',1),(115413,'117327','printshop','block-115412','Tabs','',4),(115414,'117328','printshop','block-115413-1','BlockBox','',1),(115415,'117329','printshop','block-115414','Html_box','',1),(115416,'117330','printshop','block-115414-2','quote\\FastOrder','',1),(115417,'117331','printshop','block-115413-2','login\\Returning','',1),(115418,'117332','printshop','block-115413-3','BlockBox','',1),(115419,'117333','printshop','block-115418','Html_box','',1),(115420,'117334','printshop','block-115418','Import','',2),(115421,'117335','printshop','block-115418-2','BlockBox','',1),(115422,'117336','printshop','block-115421','login\\Register','',1),(115423,'117337','printshop','block-115421','Html_box','',2),(115424,'117338','printshop','block-115412','Html_box','',3),(115425,'117339','printshop','block-115412','Html_box','',1),(115426,'117340','printshop','block-115412','login\\Socials','',2),(115427,'117341','printshop','login_checkout2_s','BlockBox','',1),(115428,'117342','printshop','block-115427','login\\Socials','',2),(115429,'117343','printshop','block-115427','Html_box','',3),(115430,'117344','printshop','block-115427','Tabs','',4),(115431,'117345','printshop','block-115430-1','BlockBox','',1),(115432,'117346','printshop','block-115431','Html_box','',1),(115433,'117347','printshop','block-115431-2','quote\\FastOrder','',1),(115434,'117348','printshop','block-115430-2','login\\Returning','',1),(115435,'117349','printshop','block-115430-3','BlockBox','',1),(115436,'117350','printshop','block-115435','Html_box','',1),(115437,'117351','printshop','block-115435-2','BlockBox','',1),(115438,'117352','printshop','block-115437','login\\Register','',1),(115439,'117353','printshop','block-115437','Html_box','',2),(115440,'117354','printshop','block-115427','Html_box','',1),(115441,'117355','printshop','login_checkout_q','BlockBox','',1),(115442,'117356','printshop','block-115441','BlockBox','',1),(115443,'117357','printshop','block-115442','BlockBox','',5),(115444,'117358','printshop','block-115443','Html_box','',1),(115445,'117359','printshop','block-115443','login\\Socials','',2),(115446,'117360','printshop','block-115442','checkout\\GuestBtn','',2),(115447,'117361','printshop','block-115442','checkout\\CreateBtn','',4),(115448,'117362','printshop','block-115442','Html_box','',3),(115449,'117363','printshop','block-115442','Html_box','',1),(115450,'117364','printshop','block-115442-2','Html_box','',1),(115451,'117365','printshop','block-115442-2','login\\Returning','',2),(115452,'117366','printshop','login_checkout_s','BlockBox','',1),(115453,'117367','printshop','block-115452','BlockBox','',1),(115454,'117368','printshop','block-115453','Html_box','',1),(115455,'117369','printshop','block-115453','checkout\\GuestBtn','',2),(115456,'117370','printshop','block-115453','checkout\\CreateBtn','',4),(115457,'117371','printshop','block-115453','Html_box','',3),(115458,'117372','printshop','block-115453','BlockBox','',5),(115459,'117373','printshop','block-115458','Html_box','',1),(115460,'117374','printshop','block-115458','login\\Socials','',2),(115461,'117375','printshop','block-115453-2','Html_box','',1),(115462,'117376','printshop','block-115453-2','login\\Returning','',2),(115463,'117377','printshop','logoff','BlockBox','',1),(115464,'117378','printshop','block-115463','Html_box','',1),(115465,'117379','printshop','logoff_forever','BlockBox','',1),(115466,'117380','printshop','block-115465','Html_box','',1),(115467,'117386','printshop','main','BlockBox','main-content',3),(115468,'120856','printshop','block-115467','BlockBox','',1),(115469,'120857','printshop','block-115468','Banner','',1),(115470,'120862','printshop','block-115467','BlockBox','',3),(115471,'117389','printshop','block-115470','NewProducts','4',2),(115472,'121014','printshop','block-115470','Html_box','',1),(115473,'1644485886.0558','printshop','block-115467','BlockBox','',7),(115474,'1644486520.9017','printshop','block-115473','Banner','',2),(115475,'1644577826.0002','printshop','block-115467','BlockBox','',2),(115476,'1644321730.7025','printshop','block-115475','Banner','',1),(115477,'1644580572.4789','printshop','block-115467','BlockBox','',6),(115478,'1644580744.5807','printshop','block-115477','Banner','',0),(115479,'1644580721.7097','printshop','block-115467','BlockBox','',5),(115480,'120865','printshop','block-115479','Banner','',1),(115481,'1644601798.7155','printshop','main','BlockBox','',2),(115482,'1683025508.153','printshop','block-115481','Banner','',2),(115483,'1708693902.95','printshop','main','FormBuilder\\widgets\\Form','',4),(115484,'117394','printshop','manufacturers','BlockBox','',1),(115485,'117395','printshop','block-115484','Html_box','',1),(115486,'117396','printshop','block-115484','Brands','',2),(115487,'117397','printshop','messages-index','BlockBox','',1),(115488,'117398','printshop','block-115487','BlockBox','',1),(115489,'117399','printshop','block-115488','BlockBox','',1),(115490,'117400','printshop','block-115489','Messages\\Sidebar','',1),(115491,'117401','printshop','block-115488-2','Messages\\Listing','',1),(115492,'117402','printshop','messages-new','BlockBox','',1),(115493,'117403','printshop','block-115492','BlockBox','',1),(115494,'117404','printshop','block-115493','Messages\\Sidebar','',1),(115495,'117405','printshop','block-115493-2','Messages\\NewMessage','',1),(115496,'117406','printshop','messages-view','BlockBox','',1),(115497,'117407','printshop','block-115496','BlockBox','',1),(115498,'117408','printshop','block-115497','Messages\\Sidebar','',1),(115499,'117409','printshop','block-115497-2','Messages\\Message','',1),(115500,'117410','printshop','my_password','BlockBox','',1),(115501,'117411','printshop','block-115500','BlockBox','',2),(115502,'117412','printshop','block-115501','WidgetsAria','',1),(115522,'117413','printshop','block-115501-2','account\\ChangePassword','',2),(115523,'117414','printshop','block-115500','Html_box','',1),(115524,'117415','printshop','need_login','BlockBox','',1),(115525,'117416','printshop','block-115524','Tabs','',2),(115526,'117417','printshop','block-115525-1','login\\Returning','',1),(115527,'117418','printshop','block-115525-2','BlockBox','',1),(115528,'117419','printshop','block-115527','Html_box','',2),(115529,'117420','printshop','block-115527-2','BlockBox','',1),(115530,'117421','printshop','block-115529','login\\Register','',1),(115531,'117422','printshop','block-115529','Html_box','',2),(115532,'117423','printshop','block-115524','BlockBox','',1),(115533,'117424','printshop','new-topic','BlockBox','',1),(115534,'117425','printshop','block-115533','Breadcrumb','',2),(115535,'117426','printshop','block-115533','Communication\\NewTopic','',3),(115536,'117427','printshop','block-115533','Html_box','',1),(115537,'117428','printshop','nnnn','BlockBox','',1),(115538,'117429','printshop','block-115537','catalog\\Title','',1),(115539,'117430','printshop','block-115537','BlockBox','',2),(115540,'117431','printshop','block-115539','Filters','',1),(115541,'117432','printshop','block-115539-2','Listing','',5),(115542,'117433','printshop','block-115539-2','catalog\\Image','',1),(115543,'117434','printshop','block-115539-2','BlockBox','',6),(115544,'117435','printshop','block-115543','catalog\\CountsItems','',1),(115545,'117436','printshop','block-115543-2','catalog\\Paging','',1),(115546,'117437','printshop','block-115539-2','catalog\\ImageMapCategory','',3),(115547,'117438','printshop','block-115539-2','Categories','',2),(115548,'117439','printshop','block-115539-2','BlockBox','',4),(115549,'117440','printshop','block-115548','catalog\\ListingLook','',1),(115550,'117441','printshop','block-115548','catalog\\ItemsOnPage','',4),(115551,'117442','printshop','block-115548','catalog\\CompareButton','',2),(115552,'117443','printshop','block-115548','catalog\\Sorting','',3),(115553,'117444','printshop','no-logged','BlockBox','',1),(115554,'117445','printshop','block-115553','Communication\\NewTopic','',2),(115555,'117446','printshop','block-115553','Html_box','',1),(115556,'117447','printshop','no_filters','BlockBox','catalog-content',2),(115557,'117448','printshop','block-115556','BlockBox','',4),(115558,'117449','printshop','block-115557','catalog\\CountsItems','',1),(115559,'117450','printshop','block-115557-2','catalog\\Paging','',1),(115560,'117451','printshop','block-115556','Listing','',3),(115561,'117452','printshop','block-115556','catalog\\Title','',1),(115562,'117453','printshop','block-115556','catalog\\B2bAddButton','',5),(115563,'117454','printshop','block-115556','BlockBox','catalog-features',2),(115564,'117455','printshop','block-115563','BlockBox','',2),(115565,'117456','printshop','block-115564','HeaderStock','',5),(115566,'117457','printshop','block-115564','catalog\\ListingLook','',1),(115567,'117458','printshop','block-115564','catalog\\CompareButton','',2),(115568,'117459','printshop','block-115564','catalog\\ItemsOnPage','',4),(115569,'117460','printshop','block-115564','catalog\\Sorting','',3),(115570,'117461','printshop','block-115563','catalog\\Image','',1),(115571,'1645199275.381','printshop','no_filters','BlockBox','',1),(115572,'1645199299.5233','printshop','block-115571','Breadcrumb','',0),(115656,'117507','printshop','order_pay','BlockBox','',1),(115657,'117508','printshop','block-115656','BlockBox','',1),(115658,'117509','printshop','block-115657','WidgetsAria','',1),(115678,'117510','printshop','block-115657-2','account\\OrderProducts','',4),(115679,'117511','printshop','block-115657-2','BlockBox','',2),(115680,'117512','printshop','block-115679','BlockBox','',1),(115681,'117513','printshop','block-115680','Html_box','',1),(115682,'117514','printshop','block-115680','account\\OrderData','',2),(115683,'117515','printshop','block-115679','BlockBox','',4),(115684,'117516','printshop','block-115683','account\\OrderData','',2),(115685,'117517','printshop','block-115683','Html_box','',1),(115686,'117518','printshop','block-115679-2','BlockBox','',1),(115687,'117519','printshop','block-115686','Html_box','',1),(115688,'117520','printshop','block-115686','account\\OrderData','',2),(115689,'117521','printshop','block-115679-2','BlockBox','',2),(115690,'117522','printshop','block-115689','account\\OrderData','',2),(115691,'117523','printshop','block-115689','Html_box','',1),(115692,'117524','printshop','block-115679-3','BlockBox','',2),(115693,'117525','printshop','block-115692','Html_box','',1),(115694,'117526','printshop','block-115692','account\\OrderData','',2),(115695,'117527','printshop','block-115679-3','BlockBox','',1),(115696,'117528','printshop','block-115695','account\\OrderData','',2),(115697,'117529','printshop','block-115695','Html_box','',1),(115698,'117530','printshop','block-115657-2','UpdateAndPay\\PayForm','',6),(115699,'117531','printshop','block-115657-2','Html_box','',3),(115700,'117532','printshop','block-115657-2','account\\OrderHeading','',1),(115701,'117533','printshop','block-115657-2','account\\OrderSubTotals','',5),(115702,'117534','printshop','packingslip','invoice\\Container','',2),(115703,'117535','printshop','block-115702','BlockBox','',2),(115704,'117536','printshop','block-115703','Logo','',1),(115705,'117537','printshop','block-115703-2','BlockBox','',3),(115706,'117538','printshop','block-115705','Text','',2),(115707,'117539','printshop','block-115705-2','invoice\\StoreEmail','',1),(115708,'117540','printshop','block-115703-2','BlockBox','',2),(115709,'117541','printshop','block-115708','Text','',2),(115710,'117542','printshop','block-115708-2','invoice\\StorePhone','',1),(115711,'117543','printshop','block-115703-2','BlockBox','',1),(115712,'117544','printshop','block-115711','invoice\\StoreAddress','',1),(115713,'117545','printshop','block-115703-2','BlockBox','',4),(115714,'117546','printshop','block-115713','Text','',2),(115715,'117547','printshop','block-115713-2','invoice\\StoreSite','',1),(115716,'117548','printshop','block-115702','packingslip\\Products','',5),(115717,'117549','printshop','block-115702','BlockBox','',6),(115718,'117550','printshop','block-115717','invoice\\StoreAddress','',2),(115719,'117551','printshop','block-115717','Text','',1),(115720,'117552','printshop','block-115702','BlockBox','',3),(115721,'117553','printshop','block-115720','BlockBox','',2),(115722,'117554','printshop','block-115721','BlockBox','',1),(115723,'117555','printshop','block-115722','invoice\\ShippingAddress','',2),(115724,'117556','printshop','block-115722','Text','',1),(115725,'117557','printshop','block-115721-2','BlockBox','',1),(115726,'117558','printshop','block-115725','Text','',1),(115727,'117559','printshop','block-115725','invoice\\CustomerName','',2),(115728,'117560','printshop','block-115725','invoice\\CustomerEmail','',6),(115729,'117561','printshop','block-115725','Text','',3),(115730,'117562','printshop','block-115725','invoice\\CustomerPhone','',4),(115731,'117563','printshop','block-115725','Text','',5),(115732,'117564','printshop','block-115720','BlockBox','',3),(115733,'117565','printshop','block-115732','BlockBox','',1),(115734,'117566','printshop','block-115733','invoice\\ShippingMethod','',2),(115735,'117567','printshop','block-115733','Text','',1),(115736,'117568','printshop','block-115732-2','BlockBox','',1),(115737,'117569','printshop','block-115736','invoice\\ShippingMethod','',2),(115738,'117570','printshop','block-115736','Text','',1),(115739,'117571','printshop','block-115720-2','invoice\\AddressQrcode','',1),(115740,'1639660991.8692','printshop','block-115702','Neighbour\\PackingSlipInfo','',1),(115741,'1639661081.5616','printshop','block-115702','Neighbour\\PackingSlipInfo','',4),(115742,'117572','printshop','password_forgotten','BlockBox','',1),(115743,'117573','printshop','block-115742','BlockBox','',2),(115744,'1638807246.6206','printshop','block-115743','Html_box','',2),(115745,'117574','printshop','block-115743','Html_box','',1),(115746,'117575','printshop','block-115743','login\\PasswordForgotten','',3),(115747,'117576','printshop','block-115742','Html_box','',1),(115748,'117577','printshop','pdf','invoice\\Container','',1),(115749,'117578','printshop','block-115748','BlockBox','',1),(115750,'117579','printshop','block-115749','BlockBox','',1),(115751,'117580','printshop','block-115750','BlockBox','',1),(115752,'117581','printshop','block-115751','pdf\\ProductElement','',1),(115753,'117582','printshop','block-115750','BlockBox','',2),(115754,'117583','printshop','block-115753','pdf\\ProductElement','',1),(115755,'117584','printshop','block-115753-2','pdf\\ProductElement','',2),(115756,'117585','printshop','block-115753-2','pdf\\ProductElement','',1),(115757,'117586','printshop','block-115749-2','BlockBox','',1),(115758,'117587','printshop','block-115757','BlockBox','',2),(115759,'117588','printshop','block-115758','pdf\\ProductElement','',1),(115760,'117589','printshop','block-115758-2','pdf\\ProductElement','',2),(115761,'117590','printshop','block-115758-2','pdf\\ProductElement','',1),(115762,'117591','printshop','block-115757','BlockBox','',1),(115763,'117592','printshop','block-115762','pdf\\ProductElement','',1),(115764,'117593','printshop','pdf_category','pdf\\CategoryName','',2),(115765,'117594','printshop','pdf_category','pdf\\CategoryImage','',1),(115766,'117595','printshop','pdf_cover','invoice\\Container','',1),(115767,'117596','printshop','block-115766','Logo','',1),(115768,'117597','printshop','block-115766','Text','',3),(115769,'117598','printshop','pdf_footer','BlockBox','',1),(115770,'117599','printshop','block-115769-2','pdf\\PageNumber','',1),(115771,'117600','printshop','pdf_header','pdf\\CategoryName','',1),(115772,'117601','printshop','personal_catalog','BlockBox','',1),(115773,'117602','printshop','block-115772','BlockBox','',2),(115774,'117603','printshop','block-115773','WidgetsAria','',1),(115794,'117606','printshop','block-115773-2','account\\PersonalCatalog','',2),(115795,'117604','printshop','block-115772','Html_box','',1),(115796,'117607','printshop','points_earnt_history','BlockBox','',1),(115797,'117608','printshop','block-115796','Html_box','',1),(115798,'117609','printshop','block-115796','account\\PointsEarntHistory','',2),(115799,'117610','printshop','posts','BlockBox','',1),(115800,'117611','printshop','block-115799','Breadcrumb','',2),(115801,'117612','printshop','block-115799','Html_box','',1),(115802,'117613','printshop','block-115799','Communication\\Post','',3),(115803,'1639053523.9657','printshop','product','BlockBox','',4),(115804,'1638963486.2331','printshop','block-115803','product\\Collection','',4),(115805,'1639659357.0881','printshop','block-115803','BlockBox','',2),(115806,'1639659044.5523','printshop','block-115805','ObsoleteProducts\\ObsoleteReplacementProducts','',1),(115807,'1644421585.0243','printshop','product','BlockBox','',1),(115808,'117644','printshop','block-115807','Breadcrumb','',1),(115809,'1683120066.375199','printshop','product','BlockBox','',2),(115810,'1683120066.40840','printshop','block-115809','BlockBox','',1),(115811,'1683120066.411537','printshop','block-115810','product\\Images','',2),(115812,'1683120066.412741','printshop','block-115810','Promotions\\widgets\\PromotionIcons','',1),(115813,'1683120066.41444','printshop','block-115810','product\\PropertiesIcons','',4),(115814,'1696601788.1354','printshop','block-115810-2','BlockBox','',1),(115815,'1683120066.4157','printshop','block-115814','BlockBox','',2),(115816,'1683120066.416580','printshop','block-115815','product\\Properties','',2),(115817,'1683120066.417385','printshop','block-115815','BlockBox','',1),(115818,'1683120066.41899','printshop','block-115817','product\\MultiInventory','',3),(115819,'1683120066.41955','printshop','block-115817','product\\DescriptionShort','',2),(115820,'1683120066.42249','printshop','block-115817','product\\Model','',1),(115821,'1683120066.423672','printshop','block-115817','product\\Groups','',4),(115822,'1683120066.42445','printshop','block-115815','Promotions\\widgets\\PromotionIconsDesc','',3),(115823,'1683120066.432243','printshop','block-115815-2','BlockBox','',1),(115824,'1683120066.43441','printshop','block-115823','BlockBox','',1),(115825,'1683120066.437271','printshop','block-115824','product\\SaleEnds','',1),(115826,'1683120066.450387','printshop','block-115824','BlockBox','',2),(115827,'1683120066.452834','printshop','block-115826','product\\QuantityDiscounts','',2),(115828,'1683120066.454686','printshop','block-115826','product\\PersonalCatalogButton','',5),(115829,'1683120066.458637','printshop','block-115826','BlockBox','',1),(115830,'1683120066.460688','printshop','block-115829','product\\Price','',1),(115831,'1683120066.46336','printshop','block-115829','product\\Stock','',2),(115832,'1683120066.465283','printshop','block-115826','BlockBox','',3),(115833,'1683120066.468523','printshop','block-115832','product\\Buttons','',1),(115834,'1683120066.472391','printshop','block-115832-2','product\\Quantity','',1),(115835,'1683120066.480552','printshop','block-115826','BlockBox','',4),(115836,'1683120066.48186','printshop','block-115835','product\\ButtonsQuote','',1),(115837,'1683120066.483821','printshop','block-115835-2','product\\ButtonsSample','',1),(115838,'1683120066.485594','printshop','block-115823','product\\BonusPoints','',2),(115839,'1683120066.488481','printshop','block-115814','product\\Name','',1),(115840,'1683120066.489437','printshop','block-115809','BlockBox','',3),(115841,'1683120066.490651','printshop','block-115840','product\\InBundles','',2),(115842,'1683120066.494682','printshop','block-115840','product\\Bundle','',1),(115843,'1683120087.08448','printshop','product','BlockBox','',5),(115844,'1683120087.116193','printshop','block-115843','BlockBox','',1),(115845,'1683120087.118690','printshop','block-115844','Tabs','',3),(115846,'1683120087.12923','printshop','block-115845-1','product\\Description','',2),(115847,'1683120087.13141','printshop','block-115845-2','InfoPage','',1),(115848,'1683120087.133123','printshop','block-115845-3','product\\Attributes','',1),(115849,'1683120087.14498','printshop','block-115843','Tabs','',3),(115850,'1683120087.145578','printshop','block-115849-1','product\\AlsoPurchased','10',1),(115851,'1683120087.150199','printshop','block-115849-2','ViewedProducts','4',1),(115852,'1683120087.154258','printshop','block-115843','BlockBox','',4),(115853,'1683120087.155397','printshop','block-115852','product\\Reviews','',1),(115854,'1683120087.157963','printshop','block-115843','BlockBox','',2),(115855,'1683120087.159777','printshop','block-115854','Banner','',0),(115856,'117655','printshop','product-bottom','product\\Properties','',1),(115857,'117656','printshop','product-tabs','product\\Reviews','',2),(115858,'117657','printshop','product-tabs','product\\Description','',1),(115859,'117658','printshop','product-top-left','product\\Images','',1),(115860,'117659','printshop','product-top-right','product\\Price','',2),(115861,'117660','printshop','product-top-right','product\\Quantity','',5),(115862,'117661','printshop','product-top-right','product\\Quantity','',6),(115863,'117662','printshop','product-top-right','product\\Attributes','',3),(115864,'117663','printshop','product-top-right','product\\Name','',1),(115865,'117664','printshop','product-top-right','product\\Buttons','',6),(115866,'117665','printshop','productListing','BlockBox','listing-item',1),(115867,'120921','printshop','block-115866','BlockBox','',1),(115868,'117667','printshop','block-115867','productListing\\bonusPoints','',3),(115869,'117671','printshop','block-115867','productListing\\image','',1),(115870,'1639645717.6681','printshop','block-115867','productListing\\productGroup','',4),(115871,'117677','printshop','block-115867','productListing\\compare','',2),(115872,'120919','printshop','block-115867-2','BlockBox','',1),(115873,'117668','printshop','block-115872','productListing\\description','',2),(115874,'117675','printshop','block-115872','productListing\\name','',1),(115875,'1644336042.3199','printshop','block-115872','BlockBox','',3),(115876,'117676','printshop','block-115875','productListing\\stock','',1),(115877,'117670','printshop','block-115875-2','productListing\\rating','',1),(115878,'120863','printshop','block-115875-2','productListing\\ratingCounts','',2),(115879,'1644336088.4429','printshop','block-115872','BlockBox','',4),(115880,'117673','printshop','block-115879','productListing\\price','',1),(115881,'120895','printshop','block-115879-2','productListing\\viewButton','',1),(115882,'1644336183.1139','printshop','block-115872','BlockBox','',6),(115883,'120882','printshop','block-115882','productListing\\personalCatalog','',1),(115884,'117678','printshop','products','BlockBox','catalog-content',2),(115885,'117679','printshop','block-115884','BlockBox','catalog-side',4),(115886,'117680','printshop','block-115885','Filters','',3),(115887,'117681','printshop','block-115885','HeaderStock','',4),(115888,'117682','printshop','block-115885-2','catalog\\B2bAddButton','',5),(115889,'117683','printshop','block-115885-2','BlockBox','catalog-features',2),(115890,'117684','printshop','block-115889','catalog\\Sorting','',3),(115891,'117685','printshop','block-115889','catalog\\ListingLook','',1),(115892,'117686','printshop','block-115889','catalog\\ItemsOnPage','',4),(115893,'117687','printshop','block-115889','catalog\\CompareButton','',2),(115894,'117688','printshop','block-115885-2','BlockBox','',6),(115895,'117689','printshop','block-115894','catalog\\CountsItems','',1),(115896,'117690','printshop','block-115894-2','catalog\\Paging','',1),(115897,'117691','printshop','block-115885-2','Listing','',4),(115898,'1639760443.0645','printshop','block-115885-2','catalog\\AdditionalImages','',1),(115899,'117692','printshop','block-115884','catalog\\Title','',2),(115900,'117693','printshop','block-115884','BlockBox','',3),(115901,'117694','printshop','block-115900','catalog\\Image','',2),(115902,'1639415554.3073','printshop','block-115900','product\\WeddingRegistryButton','',3),(115903,'121018','printshop','products','Compare','',3),(115904,'1645192276.9329','printshop','products','BlockBox','',1),(115905,'1645192301.6776','printshop','block-115904','Breadcrumb','',0),(115906,'117695','printshop','products-list','packingslip\\AllProductsList','',2),(115907,'117696','printshop','promotions','BlockBox','info-content',1),(115908,'117697','printshop','block-115907','promotions\\PromoList','',2),(115909,'117698','printshop','block-115907','Html_box','',1),(115910,'117699','printshop','purchase','invoice\\Container','',1),(115911,'117700','printshop','block-115910','invoice\\Products','',3),(115912,'117701','printshop','block-115910','BlockBox','',5),(115913,'117702','printshop','block-115912','Text','',1),(115914,'117703','printshop','block-115912','invoice\\StoreAddress','',8),(115915,'117704','printshop','block-115912-2','Text','',2),(115916,'117705','printshop','block-115912-2','Logo','',1),(115917,'117706','printshop','block-115912-3','BlockBox','',3),(115918,'117707','printshop','block-115917','Text','',1),(115919,'117708','printshop','block-115917-2','invoice\\StoreEmail','',1),(115920,'117709','printshop','block-115912-3','Text','',1),(115921,'117710','printshop','block-115912-3','BlockBox','',2),(115922,'117711','printshop','block-115921','Text','',1),(115923,'117712','printshop','block-115921-2','invoice\\StorePhone','',1),(115924,'117713','printshop','block-115910','BlockBox','',1),(115925,'117714','printshop','block-115924','Logo','',1),(115926,'117715','printshop','block-115924-2','BlockBox','',2),(115927,'117716','printshop','block-115926','Text','',1),(115928,'117717','printshop','block-115926-2','invoice\\StorePhone','',1),(115929,'117718','printshop','block-115924-2','BlockBox','',4),(115930,'117719','printshop','block-115929','Text','',1),(115931,'117720','printshop','block-115929-2','invoice\\StoreSite','',1),(115932,'117721','printshop','block-115924-2','BlockBox','',1),(115933,'117722','printshop','block-115932','invoice\\StoreAddress','',1),(115934,'117723','printshop','block-115924-2','BlockBox','',3),(115935,'117724','printshop','block-115934','Text','',1),(115936,'117725','printshop','block-115934-2','invoice\\StoreEmail','',1),(115937,'117726','printshop','block-115910','BlockBox','',2),(115938,'117727','printshop','block-115937','BlockBox','',7),(115939,'117728','printshop','block-115938','BlockBox','',1),(115940,'117729','printshop','block-115939','invoice\\BillingAddress','',2),(115941,'117730','printshop','block-115939','Text','',1),(115942,'117731','printshop','block-115938-2','BlockBox','',1),(115943,'117732','printshop','block-115942','invoice\\CustomerEmail','',6),(115944,'117733','printshop','block-115942','Text','',5),(115945,'117734','printshop','block-115942','invoice\\CustomerPhone','',4),(115946,'117735','printshop','block-115942','invoice\\CustomerName','',2),(115947,'117736','printshop','block-115942','Text','',3),(115948,'117737','printshop','block-115942','Text','',1),(115949,'117738','printshop','block-115937-2','invoice\\OrderId','',1),(115950,'117739','printshop','block-115937-2','Text','',2),(115951,'117740','printshop','block-115937-2','invoice\\PaymentDate','',3),(115952,'117741','printshop','block-115910','BlockBox','',4),(115953,'117742','printshop','block-115952','BlockBox','',1),(115954,'117743','printshop','block-115953','invoice\\ShippingAddress','',2),(115955,'117744','printshop','block-115953','Text','',1),(115959,'117745','printshop','quotations','BlockBox','',1),(115960,'117746','printshop','block-115959','BlockBox','',1),(115961,'117747','printshop','block-115960','WidgetsAria','',1),(115981,'117748','printshop','block-115960-2','Html_box','',1),(115982,'117749','printshop','block-115960-2','Quotations\\QuotationsHistory','',2),(115983,'117750','printshop','quotation_info','BlockBox','',1),(115984,'117751','printshop','block-115983','BlockBox','',1),(115985,'117752','printshop','block-115984','WidgetsAria','',1),(116005,'117753','printshop','block-115984-2','BlockBox','',5),(116006,'117754','printshop','block-116005','BlockBox','',1),(116007,'117755','printshop','block-116006','Quotations\\QuotationData','',2),(116008,'117756','printshop','block-116006','Html_box','',1),(116009,'117757','printshop','block-116005','BlockBox','',4),(116010,'117758','printshop','block-116009','Html_box','',1),(116011,'117759','printshop','block-116009','Quotations\\QuotationData','',2),(116012,'117760','printshop','block-116005-2','BlockBox','',2),(116013,'117761','printshop','block-116012','Html_box','',1),(116014,'117762','printshop','block-116012','Quotations\\QuotationData','',2),(116015,'117763','printshop','block-116005-2','BlockBox','',1),(116016,'117764','printshop','block-116015','Html_box','',1),(116017,'117765','printshop','block-116015','Quotations\\QuotationData','',2),(116018,'117766','printshop','block-116005-3','BlockBox','',1),(116019,'117767','printshop','block-116018','Quotations\\QuotationData','',2),(116020,'117768','printshop','block-116018','Html_box','',1),(116021,'117769','printshop','block-116005-3','BlockBox','',2),(116022,'117770','printshop','block-116021','Quotations\\QuotationData','',2),(116023,'117771','printshop','block-116021','Html_box','',1),(116024,'117772','printshop','block-115984-2','Html_box','',6),(116025,'117773','printshop','block-115984-2','Quotations\\QuotationHistory','',10),(116026,'117774','printshop','block-115984-2','Html_box','',9),(116027,'117775','printshop','block-115984-2','Quotations\\QuotationProducts','',7),(116028,'117776','printshop','block-115984-2','Quotations\\QuotationSubTotal','',8),(116029,'117777','printshop','block-115984-2','BlockBox','',12),(116030,'117778','printshop','block-116029','account\\AccountLink','',1),(116031,'117779','printshop','block-115984-2','Html_box','',4),(116032,'117780','printshop','quote','BlockBox','',1),(116033,'117781','printshop','block-116032','cart\\CartTabs','',1),(116034,'117782','printshop','block-116033','BlockBox','',1),(116035,'117783','printshop','block-116034','quote\\Products','',1),(116036,'117784','printshop','block-116034-2','BlockBox','',1),(116037,'117785','printshop','block-116036','BlockBox','',1),(116038,'117786','printshop','block-116037','quote\\CheckoutBtn','',2),(116039,'117787','printshop','block-116033','Quotations\\QuotationSubTotal','',2),(116064,'117793','printshop','reviews','BlockBox','info-content',1),(116065,'117794','printshop','block-116064','reviews\\Heading','',1),(116066,'117795','printshop','block-116064','reviews\\Content','',2),(116067,'117796','printshop','rma_document','invoice\\Container','',1),(116068,'117797','printshop','block-116067','BlockBox','',1),(116069,'117798','printshop','block-116068','BlockBox','',1),(116070,'117799','printshop','block-116069','BlockBox','',2),(116071,'117800','printshop','block-116070','Html_box','',1),(116072,'117801','printshop','block-116070-2','Html_box','',1),(116073,'117802','printshop','block-116069','BlockBox','',5),(116074,'117803','printshop','block-116073','Html_box','',1),(116075,'117804','printshop','block-116073-2','Html_box','',1),(116076,'117805','printshop','block-116069','BlockBox','',4),(116077,'117806','printshop','block-116076','Html_box','',1),(116078,'117807','printshop','block-116076-2','Html_box','',1),(116079,'117808','printshop','block-116069','BlockBox','',3),(116080,'117809','printshop','block-116079','Html_box','',1),(116081,'117810','printshop','block-116079-2','Html_box','',1),(116082,'117811','printshop','block-116069','BlockBox','',1),(116083,'117812','printshop','block-116082','Html_box','',1),(116084,'117813','printshop','block-116082','Html_box','',2),(116085,'117814','printshop','block-116068-2','BlockBox','',1),(116086,'117815','printshop','block-116085','Html_box','',2),(116087,'117816','printshop','block-116085','Logo','',1),(116088,'117817','printshop','block-116068-2','BlockBox','',2),(116089,'117818','printshop','block-116088','BlockBox','',5),(116090,'117819','printshop','block-116089','BlockBox','',1),(116091,'117820','printshop','block-116090','Html_box','',1),(116092,'117821','printshop','block-116090-2','Rma\\DocumentData','',1),(116093,'117822','printshop','block-116089-2','BlockBox','',1),(116094,'117823','printshop','block-116093','Html_box','',1),(116095,'117824','printshop','block-116093-2','Rma\\DocumentData','',1),(116096,'117825','printshop','block-116088','BlockBox','',4),(116097,'117826','printshop','block-116096','BlockBox','',1),(116098,'117827','printshop','block-116097','Html_box','',1),(116099,'117828','printshop','block-116097-2','Rma\\DocumentData','',1),(116100,'117829','printshop','block-116096-2','BlockBox','',1),(116101,'117830','printshop','block-116100','Html_box','',1),(116102,'117831','printshop','block-116100-2','Rma\\DocumentData','',1),(116103,'117832','printshop','block-116088','BlockBox','',3),(116104,'117833','printshop','block-116103','BlockBox','',1),(116105,'117834','printshop','block-116104','Html_box','',1),(116106,'117835','printshop','block-116104-2','Rma\\DocumentData','',1),(116107,'117836','printshop','block-116103-2','BlockBox','',1),(116108,'117837','printshop','block-116107','Html_box','',1),(116109,'117838','printshop','block-116107-2','Rma\\DocumentData','',1),(116110,'117839','printshop','block-116088','BlockBox','',2),(116111,'117840','printshop','block-116110','Html_box','',1),(116112,'117841','printshop','block-116110-2','Rma\\DocumentData','',1),(116113,'117842','printshop','block-116088','BlockBox','',1),(116114,'117843','printshop','block-116113','BlockBox','',1),(116115,'117844','printshop','block-116114','Html_box','',1),(116116,'117845','printshop','block-116114-2','Rma\\DocumentData','',1),(116117,'117846','printshop','block-116113-2','BlockBox','',1),(116118,'117847','printshop','block-116117','Html_box','',1),(116119,'117848','printshop','block-116117-2','Rma\\DocumentData','',1),(116120,'117849','printshop','block-116068-2','BlockBox','',3),(116121,'117850','printshop','block-116120','BlockBox','',1),(116122,'117851','printshop','block-116121','Html_box','',1),(116123,'117852','printshop','block-116121-2','Rma\\DocumentData','',1),(116124,'117853','printshop','block-116120-2','BlockBox','',1),(116125,'117854','printshop','block-116124','Html_box','',1),(116126,'117855','printshop','block-116124-2','Rma\\DocumentData','',1),(116127,'117856','printshop','block-116067','BlockBox','',2),(116128,'117857','printshop','block-116127','Html_box','',1),(116129,'117858','printshop','block-116127','Rma\\Products','',2),(116130,'117859','printshop','block-116067','BlockBox','',3),(116131,'117860','printshop','block-116130','BlockBox','',1),(116132,'117861','printshop','block-116131','BlockBox','',1),(116133,'117862','printshop','block-116132','BlockBox','',5),(116134,'117863','printshop','block-116133','Html_box','',1),(116135,'117864','printshop','block-116133-2','invoice\\StoreAddress','',2),(116136,'117865','printshop','block-116133-2','Html_box','',1),(116137,'117866','printshop','block-116132','BlockBox','',4),(116138,'117867','printshop','block-116137','Html_box','',1),(116139,'117868','printshop','block-116137-2','Html_box','',1),(116140,'117869','printshop','block-116132','BlockBox','',2),(116141,'117870','printshop','block-116140','Html_box','',1),(116142,'117871','printshop','block-116140-2','Html_box','',1),(116143,'117872','printshop','block-116132','BlockBox','',1),(116144,'117873','printshop','block-116143','Html_box','',1),(116145,'117874','printshop','block-116132','BlockBox','',3),(116146,'117875','printshop','block-116145','Html_box','',1),(116147,'117876','printshop','block-116145-2','Html_box','',1),(116148,'117877','printshop','block-116132','BlockBox','',6),(116149,'117878','printshop','block-116148','Html_box','',1),(116150,'117879','printshop','block-116131-2','BlockBox','',1),(116151,'117880','printshop','block-116150','BlockBox','',1),(116152,'117881','printshop','block-116151','BlockBox','',1),(116153,'117882','printshop','block-116152','Rma\\DocumentData','',2),(116154,'117883','printshop','block-116152-3','BlockBox','',1),(116155,'117884','printshop','block-116154','Html_box','',1),(116156,'117885','printshop','block-116154-2','Rma\\DocumentData','',1),(116157,'117886','printshop','block-116151','BlockBox','',2),(116158,'117887','printshop','block-116157-2','invoice\\StoreAddress','',1),(116159,'117888','printshop','block-116131-2','BlockBox','',2),(116160,'117889','printshop','block-116159','Html_box','',1),(116161,'117890','printshop','block-116159','Html_box','',2),(116162,'117891','printshop','block-116159','Html_box','',3),(116163,'117892','printshop','block-116159','Html_box','',4),(116164,'117893','printshop','block-116159','Html_box','',5),(116165,'117894','printshop','block-116131-2','BlockBox','',4),(116166,'117895','printshop','block-116165','Html_box','',1),(116167,'117896','printshop','block-116165-2','Html_box','',1),(116168,'117897','printshop','block-116165-3','BlockBox','',1),(116169,'117898','printshop','block-116168','Html_box','',1),(116170,'117899','printshop','block-116168-2','Html_box','',1),(116171,'117900','printshop','block-116131-2','BlockBox','',3),(116172,'117901','printshop','block-116171','Html_box','',1),(116173,'117902','printshop','block-116171-2','Html_box','',1),(116174,'117903','printshop','block-116171-3','BlockBox','',1),(116175,'117904','printshop','block-116174','Html_box','',1),(116176,'117905','printshop','block-116174-2','Html_box','',1),(116177,'117906','printshop','rows','BlockBox','listing-item',1),(116178,'117907','printshop','block-116177','BlockBox','',2),(116179,'117908','printshop','block-116178','BlockBox','',2),(116180,'117909','printshop','block-116179','productListing\\bonusPoints','',2),(116181,'117910','printshop','block-116179','productListing\\image','',1),(116182,'117914','printshop','block-116179-2','productListing\\name','',1),(116183,'117915','printshop','block-116179-2','productListing\\description','',2),(116184,'117916','printshop','block-116179-2','productListing\\model','',4),(116185,'117917','printshop','block-116179-2','productListing\\attributes','',5),(116186,'120922','printshop','block-116179-2','productListing\\properties','',3),(116187,'1639146806.7019','printshop','block-116179-2','productListing\\productGroup','',6),(116188,'117918','printshop','block-116178-2','BlockBox','listing-item',1),(116189,'117911','printshop','block-116188','BlockBox','',3),(116190,'117912','printshop','block-116189','productListing\\rating','',1),(116191,'117913','printshop','block-116189','productListing\\ratingCounts','',2),(116192,'117919','printshop','block-116188','productListing\\qtyInput','',4),(116193,'117920','printshop','block-116188','productListing\\price','',2),(116194,'117922','printshop','block-116188','productListing\\buyButton','',5),(116195,'117924','printshop','block-116188','productListing\\stock','',1),(116196,'120925','printshop','block-116188','productListing\\compare','',8),(116197,'120926','printshop','block-116188','productListing\\personalCatalog','',7),(116198,'120927','printshop','block-116188','productListing\\viewButton','',6),(116199,'117925','printshop','sample','BlockBox','',1),(116200,'117926','printshop','block-116199','cart\\CartTabs','',1),(116201,'117927','printshop','block-116200','BlockBox','',1),(116202,'117928','printshop','block-116201','sample\\Products','',1),(116203,'117929','printshop','block-116201-2','BlockBox','',1),(116204,'117930','printshop','block-116203','BlockBox','',1),(116205,'117931','printshop','block-116204','sample\\CheckoutBtn','',1),(116206,'117932','printshop','samples','BlockBox','',1),(116207,'117933','printshop','block-116206','BlockBox','',1),(116208,'117934','printshop','block-116207','WidgetsAria','',1),(116228,'117935','printshop','block-116207-2','Html_box','',1),(116229,'117936','printshop','block-116207-2','Samples\\SamplesHistory','',2),(116230,'117937','printshop','sample_info','BlockBox','',1),(116231,'117938','printshop','block-116230','BlockBox','',1),(116232,'117939','printshop','block-116231','WidgetsAria','',1),(116252,'117940','printshop','block-116231-2','Html_box','',1),(116253,'117941','printshop','block-116231-2','BlockBox','',8),(116254,'117942','printshop','block-116253','account\\AccountLink','',1),(116255,'117943','printshop','block-116231-2','Samples\\SampleHistory','',7),(116256,'117944','printshop','block-116231-2','Html_box','',3),(116257,'117945','printshop','block-116231-2','Samples\\SampleSubTotal','',5),(116258,'117946','printshop','block-116231-2','Samples\\SampleProducts','',4),(116259,'117947','printshop','block-116231-2','Html_box','',6),(116260,'117948','printshop','block-116231-2','BlockBox','',2),(116261,'117949','printshop','block-116260','BlockBox','',4),(116262,'117950','printshop','block-116261','Html_box','',1),(116263,'117951','printshop','block-116261','Samples\\SampleData','',2),(116264,'117952','printshop','block-116260','BlockBox','',1),(116265,'117953','printshop','block-116264','Samples\\SampleData','',2),(116266,'117954','printshop','block-116264','Html_box','',1),(116267,'117955','printshop','block-116260-2','BlockBox','',2),(116268,'117956','printshop','block-116267','Samples\\SampleData','',2),(116269,'117957','printshop','block-116267','Html_box','',1),(116270,'117958','printshop','block-116260-2','BlockBox','',1);
INSERT INTO `design_boxes_tmp` VALUES (116271,'117959','printshop','block-116270','Samples\\SampleData','',2),(116272,'117960','printshop','block-116270','Html_box','',1),(116273,'117961','printshop','block-116260-3','BlockBox','',2),(116274,'117962','printshop','block-116273','Samples\\SampleData','',2),(116275,'117963','printshop','block-116273','Html_box','',1),(116276,'117964','printshop','block-116260-3','BlockBox','',1),(116277,'117965','printshop','block-116276','Samples\\SampleData','',2),(116278,'117966','printshop','block-116276','Html_box','',1),(116279,'117967','printshop','sitemap','BlockBox','info-content',1),(116280,'117968','printshop','block-116279','Html_box','',1),(116281,'117969','printshop','block-116279','BlockBox','',2),(116282,'117970','printshop','block-116281','Html_box','',1),(116283,'117971','printshop','block-116281','Html_box','',5),(116284,'117972','printshop','block-116281','Html_box','',3),(116285,'117973','printshop','block-116281','sitemap\\InfoPages','',2),(116286,'117974','printshop','block-116281','sitemap\\Categories','',4),(116287,'117975','printshop','block-116281','Menu','Account box',6),(116288,'117976','printshop','block-116281-2','sitemap\\DeliveryLocation','',2),(116289,'117977','printshop','block-116281-2','Html_box','',1),(116290,'120878','printshop','social','SocialLinks','',1),(116291,'117978','printshop','subscribe','BlockBox','',1),(116292,'117979','printshop','block-116291','Html_box','',3),(116293,'117980','printshop','block-116291','subscribers\\UnsubscribeForm','',4),(116294,'117981','printshop','block-116291','Html_box','',1),(116295,'117982','printshop','block-116291','subscribers\\SubscribeForm','',2),(116296,'117983','printshop','subscribed','BlockBox','',1),(116297,'117984','printshop','block-116296','Html_box','',1),(116298,'117985','printshop','subscription','BlockBox','',2),(116299,'117986','printshop','block-116298','BlockBox','',1),(116300,'117987','printshop','block-116299','WidgetsAria','',1),(116320,'117988','printshop','block-116299-2','Html_box','',2),(116321,'117989','printshop','block-116299-2','Html_box','',3),(116322,'117990','printshop','block-116299-2','account\\Subscription','',4),(116323,'1694162315.037980','printshop','success','BlockBox','',1),(116324,'1694162315.120936','printshop','block-116323','BlockBox','',2),(116325,'1694162315.123135','printshop','block-116324','BlockBox','',3),(116326,'1694162315.12436','printshop','block-116325','BlockBox','',2),(116327,'1694162315.125735','printshop','block-116326','BlockBox','',1),(116328,'1694162315.12826','printshop','block-116327','order\\ShippingMethod','',6),(116329,'1694162315.128991','printshop','block-116327','order\\DeliveryAddress','',3),(116330,'1694162315.136','printshop','block-116327','Html_box','',7),(116331,'1694162315.143264','printshop','block-116327','Html_box','',5),(116332,'1694162315.14584','printshop','block-116327','Html_box','',1),(116333,'1694162315.146322','printshop','block-116327','checkout\\ContactConfirm','',9),(116334,'1694162315.147338','printshop','block-116327','Html_box','',2),(116335,'1694162315.14989','printshop','block-116326-2','BlockBox','',1),(116336,'1694162315.150471','printshop','block-116335','order\\PaymentMethod','',6),(116337,'1694162315.151341','printshop','block-116335','order\\BillingAddress','',3),(116338,'1694162315.152381','printshop','block-116335','Html_box','',5),(116339,'1694162315.153514','printshop','block-116335','Html_box','',1),(116340,'1694162315.154777','printshop','block-116335','Html_box','',2),(116341,'1694162315.155812','printshop','block-116325','Html_box','',1),(116342,'1694162315.15769','printshop','block-116324-2','BlockBox','',1),(116343,'1694162315.158534','printshop','block-116342','success\\PrintBtn','',3),(116344,'1694162315.1668','printshop','block-116342','success\\ContinueBtn','',4),(116345,'1694162315.16157','printshop','block-116342','order\\Products','',1),(116346,'1694162315.162213','printshop','block-116342','order\\Totals','',2),(116347,'1694162315.163184','printshop','block-116323','BlockBox','',1),(116348,'1694162315.16467','printshop','block-116347','Html_box','',2),(116349,'1694162315.165266','printshop','block-116347','order\\OrderNumber','',1),(116350,'117997','printshop','success_q','BlockBox','',1),(116351,'117998','printshop','block-116350','BlockBox','',1),(116352,'117999','printshop','block-116351','BlockBox','',2),(116353,'118000','printshop','block-116352','success\\ContinueBtn','',2),(116354,'118001','printshop','block-116352','success\\PrintBtn','',1),(116355,'118002','printshop','block-116351','Html_box','',1),(116360,'118007','printshop','ticket','invoice\\Container','',1),(116361,'118008','printshop','block-116360','BlockBox','',4),(116362,'118009','printshop','block-116361','BlockBox','',1),(116363,'118010','printshop','block-116362','invoice\\ShippingAddress','',2),(116364,'118011','printshop','block-116362','Text','',1),(116365,'118012','printshop','block-116361-2','BlockBox','',1),(116366,'118013','printshop','block-116365','invoice\\Totals','',1),(116367,'118014','printshop','block-116360','BlockBox','',5),(116368,'118015','printshop','block-116367','Text','',1),(116369,'118016','printshop','block-116367','invoice\\StoreAddress','',8),(116370,'118018','printshop','block-116367-2','Text','',2),(116371,'118019','printshop','block-116367-3','Text','',1),(116372,'118020','printshop','block-116367-3','BlockBox','',3),(116373,'118021','printshop','block-116372','Text','',1),(116374,'118022','printshop','block-116372-2','invoice\\StoreEmail','',1),(116375,'118023','printshop','block-116367-3','BlockBox','',2),(116376,'118024','printshop','block-116375','Text','',1),(116377,'118025','printshop','block-116375-2','invoice\\StorePhone','',1),(116378,'118026','printshop','block-116360','invoice\\Products','',3),(116379,'118027','printshop','block-116360','BlockBox','',1),(116380,'118028','printshop','block-116379-2','BlockBox','',3),(116381,'118029','printshop','block-116380','Text','',1),(116382,'118030','printshop','block-116380-2','invoice\\StoreEmail','',1),(116383,'118031','printshop','block-116379-2','BlockBox','',4),(116384,'118032','printshop','block-116383','Text','',1),(116385,'118033','printshop','block-116383-2','invoice\\StoreSite','',1),(116386,'118034','printshop','block-116379-2','BlockBox','',1),(116387,'118035','printshop','block-116386','invoice\\StoreAddress','',1),(116388,'118036','printshop','block-116379-2','BlockBox','',2),(116389,'118037','printshop','block-116388','Text','',1),(116390,'118038','printshop','block-116388-2','invoice\\StorePhone','',1),(116391,'118039','printshop','block-116360','BlockBox','',2),(116392,'118040','printshop','block-116391','BlockBox','',8),(116393,'118041','printshop','block-116392','BlockBox','',1),(116394,'118042','printshop','block-116393','Text','',1),(116395,'118043','printshop','block-116393','invoice\\ShippingMethod','',2),(116396,'118044','printshop','block-116392-2','BlockBox','',1),(116397,'118045','printshop','block-116396','Text','',1),(116398,'118046','printshop','block-116396','invoice\\ShippingMethod','',2),(116399,'118047','printshop','block-116391','BlockBox','',7),(116400,'118048','printshop','block-116399','BlockBox','',1),(116401,'118049','printshop','block-116400','invoice\\BillingAddress','',2),(116402,'118050','printshop','block-116400','Text','',1),(116403,'118051','printshop','block-116399-2','BlockBox','',1),(116404,'118052','printshop','block-116403','invoice\\CustomerName','',2),(116405,'118053','printshop','block-116403','Text','',3),(116406,'118054','printshop','block-116403','invoice\\CustomerEmail','',6),(116407,'118055','printshop','block-116403','invoice\\CustomerPhone','',4),(116408,'118056','printshop','block-116403','Text','',5),(116409,'118057','printshop','block-116403','Text','',1),(116410,'118058','printshop','block-116391-2','invoice\\PaymentDate','',3),(116411,'118059','printshop','block-116391-2','Text','',2),(116412,'118060','printshop','block-116391-2','Text','',4),(116413,'118061','printshop','block-116391-2','invoice\\OrderId','',1),(116414,'118062','printshop','block-116391-2','invoice\\PaymentMethod','',5),(116415,'118063','printshop','block-116391-2','invoice\\OrderBarcode','',6),(116416,'118094','printshop','tracking_numbers','BlockBox','',1),(116417,'118095','printshop','block-116416','Html_box','',1),(116418,'118096','printshop','block-116416','account\\OrderTracking','',2),(116419,'118318','printshop','unsubscribed','BlockBox','',1),(116420,'118319','printshop','block-116419','Html_box','',1),(116421,'118320','printshop','update-and-pay-order_confirmation','BlockBox','',1),(116422,'118321','printshop','block-116421','BlockBox','',3),(116423,'118322','printshop','block-116422','BlockBox','',1),(116424,'118323','printshop','block-116423','BlockBox','',1),(116425,'118324','printshop','block-116424','BlockBox','',1),(116426,'118325','printshop','block-116425','order\\ShippingMethod','',5),(116427,'118326','printshop','block-116425','Html_box','',2),(116428,'118327','printshop','block-116425','Html_box','',4),(116429,'118328','printshop','block-116425','Html_box','',1),(116430,'118329','printshop','block-116425','order\\Telephone','',8),(116431,'118330','printshop','block-116425','Html_box','',6),(116432,'118331','printshop','block-116425','order\\Name','',7),(116433,'118332','printshop','block-116425','order\\Email','',9),(116434,'118333','printshop','block-116425','order\\DeliveryAddress','',3),(116435,'118334','printshop','block-116424-2','BlockBox','',1),(116436,'118335','printshop','block-116435','order\\BillingAddress','',3),(116437,'118336','printshop','block-116435','UpdateAndPay\\PayConfirm','',5),(116438,'118337','printshop','block-116435','Html_box','',1),(116439,'118338','printshop','block-116435','Html_box','',2),(116440,'118339','printshop','block-116435','Html_box','',4),(116441,'118340','printshop','block-116423','BlockBox','',3),(116442,'118341','printshop','block-116441','order\\Products','',2),(116443,'118342','printshop','block-116441','Html_box','',1),(116444,'118343','printshop','block-116422-2','BlockBox','',1),(116445,'118344','printshop','block-116444','Html_box','',1),(116446,'118345','printshop','block-116444','checkout\\ContinueBtn','',3),(116447,'118346','printshop','block-116444','order\\Totals','',2),(116448,'118347','printshop','block-116421','account\\OrderHeading','',1),(116449,'118348','printshop','update-and-pay-order_pay','BlockBox','',1),(116450,'118349','printshop','block-116449','BlockBox','',3),(116451,'118350','printshop','block-116450','BlockBox','',1),(116452,'118351','printshop','block-116451','BlockBox','',1),(116453,'118352','printshop','block-116452','BlockBox','',1),(116454,'118353','printshop','block-116453','order\\DeliveryAddress','',4),(116455,'118354','printshop','block-116453','order\\Email','',10),(116456,'118355','printshop','block-116453','order\\Name','',8),(116457,'118356','printshop','block-116453','Html_box','',7),(116458,'118357','printshop','block-116453','order\\Telephone','',9),(116459,'118358','printshop','block-116453','Html_box','',5),(116460,'118359','printshop','block-116453','order\\ShippingMethod','',6),(116461,'118360','printshop','block-116453','Html_box','',2),(116462,'118361','printshop','block-116453','Html_box','',3),(116463,'1639647774.7838','printshop','block-116453','DelayedDespatch\\OrderPay','',1),(116464,'118362','printshop','block-116452-2','BlockBox','',1),(116465,'118363','printshop','block-116464','Html_box','',1),(116466,'118364','printshop','block-116464','Html_box','',2),(116467,'118365','printshop','block-116464','Html_box','',4),(116468,'118366','printshop','block-116464','order\\BillingAddress','',3),(116469,'118367','printshop','block-116464','UpdateAndPay\\PayForm','',5),(116470,'118368','printshop','block-116451','BlockBox','',3),(116471,'118369','printshop','block-116470','Html_box','',1),(116472,'118370','printshop','block-116470','order\\Products','',2),(116473,'118371','printshop','block-116450-2','BlockBox','',1),(116474,'118372','printshop','block-116473','order\\Totals','',2),(116475,'118373','printshop','block-116473','checkout\\ContinueBtn','',3),(116476,'118374','printshop','block-116473','Html_box','',1),(116477,'118375','printshop','block-116449','account\\OrderHeading','',1),(116478,'118440','printshop','wishlist','BlockBox','',1),(116479,'118441','printshop','block-116478','BlockBox','',1),(116480,'118442','printshop','block-116479','WidgetsAria','',1),(116500,'118443','printshop','block-116479-2','account\\Wishlist','',2),(116501,'118444','printshop','block-116479-2','Html_box','',1),(116502,'118445','printshop','wishlist-cart','BlockBox','',1),(116503,'118446','printshop','block-116502','cart\\CartTabs','',1),(116504,'118447','printshop','block-116503','account\\Wishlist','',1),(121477,'116005','deals','404','Html_box','',1),(121705,'117906','deals','b2b','BlockBox','listing-item',1),(121706,'117907','deals','block-121705','BlockBox','',2),(121707,'117908','deals','block-121706','BlockBox','',2),(121708,'117909','deals','block-121707','productListing\\bonusPoints','',2),(121709,'117910','deals','block-121707','productListing\\image','',1),(121710,'117914','deals','block-121707-2','productListing\\name','',1),(121711,'117915','deals','block-121707-2','productListing\\description','',2),(121712,'117916','deals','block-121707-2','productListing\\model','',4),(121713,'117917','deals','block-121707-2','productListing\\attributes','',5),(121714,'120922','deals','block-121707-2','productListing\\properties','',3),(121715,'117918','deals','block-121706-2','BlockBox','listing-item',1),(121716,'117911','deals','block-121715','BlockBox','',3),(121717,'117912','deals','block-121716','productListing\\rating','',1),(121718,'117913','deals','block-121716','productListing\\ratingCounts','',2),(121719,'117919','deals','block-121715','productListing\\qtyInput','',4),(121720,'117920','deals','block-121715','productListing\\price','',2),(121721,'117924','deals','block-121715','productListing\\stock','',1),(121722,'120924','deals','block-121715','BlockBox','',8),(121723,'120925','deals','block-121722','productListing\\compare','',3),(121724,'120926','deals','block-121722','productListing\\personalCatalog','',2),(121725,'120927','deals','block-121722','productListing\\viewButton','',1),(121726,'116176','deals','batch','BlockBox','',1),(121727,'116177','deals','block-121726','productListing\\attributes','',5),(121728,'116178','deals','block-121726','productListing\\price','',6),(121729,'116179','deals','block-121726','productListing\\name','',4),(121730,'116180','deals','block-121726','productListing\\image','',2),(121731,'116181','deals','block-121726','batchSelect','',1),(121732,'116182','deals','batch_selected','BlockBox','',1),(121733,'116183','deals','block-121732','BlockBox','',13),(121734,'116184','deals','block-121733','productListing\\image','',1),(121735,'116185','deals','block-121733-2','batchRemove','',1),(121736,'116186','deals','block-121733-2','productListing\\price','',3),(121737,'116187','deals','block-121733-2','productListing\\name','',2),(121738,'116188','deals','bbbbb','BlockBox','',1),(121739,'116189','deals','block-121738','BlockBox','',2),(121740,'116190','deals','block-121739','Filters','',1),(121741,'116191','deals','block-121739-2','BlockBox','',6),(121742,'116192','deals','block-121741','catalog\\CountsItems','',1),(121743,'116193','deals','block-121741-2','catalog\\Paging','',1),(121744,'116194','deals','block-121739-2','catalog\\Image','',1),(121745,'116195','deals','block-121739-2','Listing','',5),(121746,'116196','deals','block-121739-2','catalog\\ImageMapCategory','',3),(121747,'116197','deals','block-121739-2','BlockBox','',4),(121748,'116198','deals','block-121747','catalog\\ListingLook','',1),(121749,'116199','deals','block-121747','catalog\\CompareButton','',2),(121750,'116200','deals','block-121747','catalog\\ItemsOnPage','',4),(121751,'116201','deals','block-121747','catalog\\Sorting','',3),(121752,'116202','deals','block-121739-2','Categories','',2),(121753,'116203','deals','block-121738','catalog\\Title','',1),(121754,'1683114704.562135','deals','cart','BlockBox','',1),(121755,'1683114704.57226','deals','block-121754','BlockBox','',2),(121756,'1683114704.58194','deals','block-121755','BlockBox','cart-top',1),(121757,'1683114704.582420','deals','block-121756','cart\\Products','',3),(121758,'1683114704.583230','deals','block-121756','BlockBox','',2),(121759,'1683114704.585598','deals','block-121758','MultiCart\\CartSwitcher','',1),(121760,'1683114704.586389','deals','block-121758','MultiCart\\SaveCart','',2),(121761,'1683114704.587718','deals','block-121758-2','MultiCart\\Actions','',1),(121762,'1683114704.58974','deals','block-121756','Html_box','',1),(121763,'1683114704.594755','deals','block-121755','cart\\ShippingEstimator','',6),(121764,'1683114704.595625','deals','block-121755','cart\\DependedProducts','8',3),(121765,'1683114704.601126','deals','block-121755','BlockBox','cart-content',2),(121766,'1683114704.602943','deals','block-121765','BlockBox','',2),(121767,'1683114704.604593','deals','block-121766','cart\\CreditAmount','',1),(121768,'1683114704.605124','deals','block-121766-2','cart\\BonusPoints','',1),(121769,'1683114704.606118','deals','block-121755-2','BlockBox','cart-side',1),(121770,'1683114704.608683','deals','block-121769','BlockBox','',3),(121771,'1683114704.609838','deals','block-121770','cart\\DiscountCoupon','',2),(121772,'1683114704.623818','deals','block-121770','cart\\CheckoutBtn','',4),(121773,'1683114704.62578','deals','block-121770','cart\\OrderTotal','',3),(121774,'1683114704.626342','deals','block-121770','cart\\OrderTotal','',1),(121775,'1683114704.62755','deals','block-121769','Html_box','',1),(121776,'116242','deals','cart2','BlockBox','',2),(121777,'116243','deals','block-121776','cart\\CartTabs','',2),(121778,'116244','deals','block-121777','BlockBox','',1),(121779,'116245','deals','block-121778','BlockBox','',4),(121780,'116246','deals','block-121779','cart\\UpSell','6',2),(121781,'116247','deals','block-121779','Html_box','',1),(121782,'116248','deals','block-121778','BlockBox','',1),(121783,'116249','deals','block-121782','cart\\Products','',3),(121784,'116250','deals','block-121782','BlockBox','',2),(121785,'116251','deals','block-121784','MultiCart\\CartSwitcher','',1),(121786,'116252','deals','block-121784','MultiCart\\SaveCart','',2),(121787,'116253','deals','block-121784-2','MultiCart\\Actions','',1),(121788,'116254','deals','block-121778','BlockBox','',3),(121789,'116255','deals','block-121788','cart\\GiveAway','',2),(121790,'116256','deals','block-121788','Html_box','',1),(121791,'116257','deals','block-121778','BlockBox','',2),(121792,'116258','deals','block-121791','Html_box','',1),(121793,'116259','deals','block-121791','BlockBox','',2),(121794,'116260','deals','block-121793','cart\\DiscountCoupon','',1),(121795,'116261','deals','block-121793-2','cart\\CreditAmount','',1),(121796,'116262','deals','block-121793-3','cart\\BonusPoints','',1),(121797,'116263','deals','block-121778','BlockBox','',5),(121798,'116264','deals','block-121797','Html_box','',1),(121799,'116265','deals','block-121797','cart\\ShippingEstimator','',2),(121800,'116266','deals','block-121778-2','BlockBox','',1),(121801,'116267','deals','block-121800','Html_box','',1),(121802,'116268','deals','block-121800','BlockBox','',2),(121803,'116269','deals','block-121802','Image','',4),(121804,'116270','deals','block-121802','cart\\CheckoutBtn','',2),(121805,'116271','deals','block-121802','cart\\OrderTotal','',1),(121816,'116272','deals','categories','BlockBox','catalog-content',2),(121817,'116275','deals','block-121816','Listing','',6),(121818,'116277','deals','block-121816','BlockBox','',7),(121819,'116278','deals','block-121818','catalog\\CountsItems','',1),(121820,'116279','deals','block-121818-2','catalog\\Paging','',1),(121821,'116281','deals','block-121816','Categories','',3),(121822,'116282','deals','block-121816','BlockBox','catalog-features',5),(121823,'116283','deals','block-121822','catalog\\ListingLook','',1),(121824,'116287','deals','block-121816','catalog\\Title','',2),(121825,'1641809968','deals','block-121816','BlockBox','',4),(121826,'116286','deals','block-121825','catalog\\Sorting','',2),(121827,'1641810239','deals','block-121825','Filters','',1),(121828,'116288','deals','category','Categories','',1),(121829,'116289','deals','category','Listing','',4),(121830,'116290','deals','category','ListingFunctionality','',2),(121831,'116291','deals','category','PagingBar','',3),(121832,'116292','deals','category','PagingBar','',5),(121833,'116293','deals','category_2','BlockBox','',1),(121834,'116294','deals','block-121833','catalog\\Title','',1),(121835,'116295','deals','block-121833','BlockBox','',2),(121836,'116296','deals','block-121835','Filters','',1),(121837,'116297','deals','block-121835-2','catalog\\Image','',1),(121838,'116298','deals','block-121835-2','Listing','',5),(121839,'116299','deals','block-121835-2','BlockBox','',4),(121840,'116300','deals','block-121839','catalog\\Sorting','',3),(121841,'116301','deals','block-121839','catalog\\ItemsOnPage','',4),(121842,'116302','deals','block-121839','catalog\\CompareButton','',2),(121843,'116303','deals','block-121839','catalog\\ListingLook','',1),(121844,'116304','deals','block-121835-2','catalog\\ImageMapCategory','',3),(121845,'116305','deals','block-121835-2','Categories','',2),(121846,'116306','deals','block-121835-2','BlockBox','',6),(121847,'116307','deals','block-121846','catalog\\CountsItems','',1),(121848,'116308','deals','block-121846-2','catalog\\Paging','',1),(121849,'116309','deals','category_no_filters','BlockBox','catalog-content',1),(121850,'116310','deals','block-121849','catalog\\Title','',1),(121851,'116311','deals','block-121849','Categories','',3),(121852,'116312','deals','block-121849','BlockBox','catalog-features',4),(121853,'116313','deals','block-121852','catalog\\ItemsOnPage','',4),(121854,'116314','deals','block-121852','catalog\\Sorting','',3),(121855,'116315','deals','block-121852','catalog\\CompareButton','',2),(121856,'116316','deals','block-121852','catalog\\ListingLook','',1),(121857,'116318','deals','block-121849','BlockBox','',6),(121858,'116319','deals','block-121857','catalog\\CountsItems','',1),(121859,'116320','deals','block-121857-2','catalog\\Paging','',1),(121860,'116321','deals','block-121849','Listing','',5),(121861,'116322','deals','block-121849','catalog\\Image','',2),(121862,'116323','deals','block-121849','catalog\\B2bAddButton','',7),(121863,'1683116708.492798','deals','checkout','BlockBox','',1),(121864,'1683116708.500294','deals','block-121863','BlockBox','',2),(121865,'1683116708.502483','deals','block-121864','BlockBox','checkout-content',2),(121866,'1683116708.503841','deals','block-121865','BlockBox','checkout-comments',5),(121867,'1683116708.507547','deals','block-121866','checkout\\Comments','',2),(121868,'1683116708.50914','deals','block-121866','Html_box','',1),(121869,'1683116708.511660','deals','block-121865','BlockBox','checkout-discount',4),(121870,'1683116708.515882','deals','block-121869','Html_box','',1),(121871,'1683116708.517470','deals','block-121869','BlockBox','',2),(121872,'1683116708.518949','deals','block-121871','CouponsAndVauchers\\Checkout','',1),(121873,'1683116708.519823','deals','block-121871-2','checkout\\CreditAmount','',1),(121874,'1683116708.52078','deals','block-121871-2','checkout\\BonusPoints','',2),(121875,'1683116708.521619','deals','block-121865','BlockBox','checkout-shipping',2),(121876,'1683116708.52521','deals','block-121875','BlockBox','',3),(121877,'1683116708.527559','deals','block-121876','checkout\\ShippingChoice','',1),(121878,'1683116708.528597','deals','block-121875','Neighbour\\Checkout','',5),(121879,'1683116708.529860','deals','block-121875','BlockBox','',4),(121880,'1683116708.531118','deals','block-121879','BlockBox','',1),(121881,'1683116708.532686','deals','block-121880','checkout\\ShippingAddress','',2),(121882,'1683116708.533279','deals','block-121880','Html_box','',3),(121883,'1683116708.534524','deals','block-121880','checkout\\ContactInformation','',4),(121884,'1683116708.534947','deals','block-121880','UploadCustomerId\\UploadCustomerIdForm','',5),(121885,'1683116708.535390','deals','block-121879-2','BlockBox','',1),(121886,'1683116708.536845','deals','block-121885','checkout\\Shipping','',2),(121887,'1683116708.537397','deals','block-121885','DelayedDespatch\\Checkout','',4),(121888,'1683116708.538283','deals','block-121885','Html_box','',1),(121889,'1683116708.539729','deals','block-121885','DeliveryDay','',3),(121890,'1683116708.540444','deals','block-121875','Html_box','',2),(121891,'1683116708.541679','deals','block-121865','BlockBox','',8),(121892,'1683116708.544887','deals','block-121891','DeliveryOptions\\Checkout','',0),(121893,'1683116708.545373','deals','block-121865','cart\\Products','',6),(121894,'1683116708.547120','deals','block-121865','checkout\\CreateAccount','',7),(121895,'1683116708.548247','deals','block-121865','BlockBox','checkout-payment',3),(121896,'1683116708.551273','deals','block-121895','Html_box','',1),(121897,'1683116708.552428','deals','block-121895','BlockBox','',2),(121898,'1683116708.553758','deals','block-121897','Html_box','',1),(121899,'1683116708.55521','deals','block-121897','checkout\\BillingAddress','',2),(121900,'1683116708.5566','deals','block-121897-2','BlockBox','',1),(121901,'1683116708.557237','deals','block-121900','checkout\\PaymentMethod','',2),(121902,'1683116708.558367','deals','block-121900','Html_box','',1),(121903,'1683116708.559513','deals','block-121865','BlockBox','',1),(121904,'1683116708.562121','deals','block-121903','checkout\\LoginOnForm','',1),(121905,'1683116708.563392','deals','block-121864-2','BlockBox','checkout-side',1),(121906,'1683116708.56533','deals','block-121905','Html_box','',6),(121907,'1683116708.56713','deals','block-121905','Html_box','',1),(121908,'1683116708.568362','deals','block-121905','checkout\\Terms','',5),(121909,'1683116708.568971','deals','block-121905','checkout\\Totals','',3),(121910,'1683116708.569560','deals','block-121905','checkout\\ContinueBtn','',4),(121911,'1683116708.572798','deals','block-121905','cart\\Products','',2),(121912,'116368','deals','checkout_confirmation','BlockBox','',1),(121913,'116369','deals','block-121912','checkout\\Totals','',8),(121914,'116370','deals','block-121912','Html_box','',5),(121915,'116371','deals','block-121912','checkout\\EditBtn','',6),(121916,'116372','deals','block-121912','BlockBox','',3),(121917,'116373','deals','block-121916','BlockBox','',1),(121918,'116374','deals','block-121917','Html_box','',1),(121919,'116375','deals','block-121917','checkout\\ShippingConfirm','',3),(121920,'116376','deals','block-121916-2','BlockBox','',1),(121921,'116377','deals','block-121920','checkout\\PaymentMethodConfirm','',3),(121922,'116378','deals','block-121920','Html_box','',1),(121923,'116379','deals','block-121912','checkout\\ConfirmBtn','',9),(121924,'116380','deals','block-121912','BlockBox','',2),(121925,'116381','deals','block-121924','BlockBox','',1),(121926,'116382','deals','block-121925','checkout\\ShippingAddressConfirm','',3),(121927,'116383','deals','block-121925','Html_box','',1),(121928,'116384','deals','block-121924-2','BlockBox','',1),(121929,'116385','deals','block-121928','Html_box','',1),(121930,'116386','deals','block-121928','checkout\\BillingAddressConfirm','',3),(121931,'116387','deals','block-121912','checkout\\ConfirmBtn','',4),(121932,'116388','deals','block-121912','cart\\Products','',7),(121933,'116402','deals','checkout_confirmation_no_shipping','BlockBox','',1),(121934,'116403','deals','block-121933','checkout\\ConfirmBtn','',9),(121935,'116404','deals','block-121933','BlockBox','',2),(121936,'116405','deals','block-121935','BlockBox','',1),(121937,'116406','deals','block-121936','Html_box','',1),(121938,'116407','deals','block-121936','checkout\\BillingAddressConfirm','',3),(121939,'116408','deals','block-121935-2','BlockBox','',1),(121940,'116409','deals','block-121939','Html_box','',1),(121941,'116410','deals','block-121939','checkout\\PaymentMethodConfirm','',3),(121942,'116411','deals','block-121933','checkout\\ConfirmBtn','',4),(121943,'116412','deals','block-121933','checkout\\Totals','',8),(121944,'116413','deals','block-121933','cart\\Products','',7),(121945,'116414','deals','block-121933','Html_box','',5),(121946,'116389','deals','checkout_confirmation_no_shipping_q','BlockBox','',1),(121947,'116390','deals','block-121946','quote\\Products','',4),(121948,'116391','deals','block-121946','checkout\\ConfirmBtn','',2),(121949,'116392','deals','block-121946','checkout\\ConfirmBtn','',6),(121950,'116393','deals','block-121946','BlockBox','',1),(121951,'116394','deals','block-121950','BlockBox','',1),(121952,'116395','deals','block-121951','checkout\\BillingAddressConfirm','',3),(121953,'116396','deals','block-121951','Html_box','',1),(121954,'116397','deals','block-121950-2','BlockBox','',1),(121955,'116398','deals','block-121954','checkout\\PaymentMethodConfirm','',3),(121956,'116399','deals','block-121954','Html_box','',1),(121957,'116400','deals','block-121946','Html_box','',3),(121958,'116401','deals','block-121946','checkout\\Totals','',5),(121959,'116415','deals','checkout_confirmation_q','BlockBox','',1),(121960,'116416','deals','block-121959','BlockBox','',1),(121961,'116417','deals','block-121960','BlockBox','',1),(121962,'116418','deals','block-121961','checkout\\ShippingAddressConfirm','',3),(121963,'116419','deals','block-121961','Html_box','',1),(121964,'116420','deals','block-121960-2','BlockBox','',1),(121965,'116421','deals','block-121964','checkout\\BillingAddressConfirm','',3),(121966,'116422','deals','block-121964','Html_box','',1),(121967,'116423','deals','block-121959','checkout\\Totals','',7),(121968,'116424','deals','block-121959','quote\\Products','',6),(121969,'116425','deals','block-121959','Html_box','',4),(121970,'116426','deals','block-121959','checkout\\EditBtn','',5),(121971,'116427','deals','block-121959','checkout\\ConfirmBtn','',8),(121972,'116428','deals','block-121959','checkout\\ConfirmBtn','',3),(121973,'116429','deals','block-121959','BlockBox','',2),(121974,'116430','deals','block-121973','BlockBox','',1),(121975,'116431','deals','block-121974','Html_box','',1),(121976,'116432','deals','block-121974','checkout\\ShippingConfirm','',3),(121977,'116433','deals','block-121973-2','BlockBox','',1),(121978,'116434','deals','block-121977','Html_box','',1),(121979,'116435','deals','block-121977','checkout\\PaymentMethodConfirm','',3),(121980,'116436','deals','checkout_confirmation_title','Html_box','',1),(121981,'116437','deals','checkout_confirmation_title_g','Html_box','',1),(121982,'116439','deals','checkout_confirmation_title_no_shipping','Html_box','',1),(121983,'116438','deals','checkout_confirmation_title_no_shipping_g','Html_box','',1),(121984,'116440','deals','checkout_confirmation_title_q','Html_box','',1),(121985,'116441','deals','checkout_confirmation_title_s','Html_box','',1),(121986,'116442','deals','checkout_delivery','BlockBox','',2),(121987,'116443','deals','block-121986','BlockBox','',1),(121988,'116444','deals','block-121987','Html_box','',1),(121989,'116445','deals','block-121987','checkout\\ContactInformation','',2),(121990,'116446','deals','block-121986-2','BlockBox','',1),(121991,'116447','deals','block-121990','Html_box','',1),(121992,'116448','deals','block-121990','checkout\\Comments','',2),(121993,'116449','deals','checkout_delivery','BlockBox','',3),(121994,'116450','deals','block-121993','Html_box','',1),(121995,'116451','deals','block-121993-2','checkout\\ContinueBtn','',1),(121996,'116452','deals','checkout_delivery','BlockBox','',1),(121997,'116453','deals','block-121996','BlockBox','',1),(121998,'116455','deals','block-121997','checkout\\ShippingAddress','',2),(121999,'116456','deals','block-121996-2','BlockBox','',1),(122000,'116457','deals','block-121999','DelayedDespatch\\Checkout','',3),(122001,'116458','deals','block-121999','checkout\\Shipping','',2),(122002,'116459','deals','block-121999','Html_box','',1),(122003,'116460','deals','block-121999','Neighbour\\Checkout','',4),(122004,'116461','deals','checkout_delivery_g','BlockBox','',2),(122005,'116462','deals','block-122004','BlockBox','',1),(122006,'116463','deals','block-122005','checkout\\ContactInformation','',2),(122007,'116464','deals','block-122005','Html_box','',1),(122008,'116465','deals','block-122004-2','BlockBox','',1),(122009,'116466','deals','block-122008','Html_box','',1),(122010,'116467','deals','block-122008','checkout\\Comments','',2),(122011,'116468','deals','checkout_delivery_g','BlockBox','',3),(122012,'116469','deals','block-122011','Html_box','',1),(122013,'116470','deals','block-122011-2','checkout\\ContinueBtn','',1),(122014,'116471','deals','checkout_delivery_g','BlockBox','',1),(122015,'116472','deals','block-122014','BlockBox','',1),(122016,'116473','deals','block-122015','checkout\\ShippingAddress','',2),(122017,'116474','deals','block-122015','Html_box','',1),(122018,'116475','deals','block-122014-2','BlockBox','',1),(122019,'116476','deals','block-122018','checkout\\Shipping','',2),(122020,'116477','deals','block-122018','Html_box','',1),(122021,'116478','deals','block-122018','DelayedDespatch\\Checkout','',3),(122022,'116479','deals','block-122018','Neighbour\\Checkout','',4),(122023,'116480','deals','checkout_delivery_no_shipping','BlockBox','',2),(122024,'116481','deals','block-122023','Html_box','',1),(122025,'116482','deals','block-122023-2','checkout\\ContinueBtn','',1),(122026,'116483','deals','checkout_delivery_no_shipping','BlockBox','',1),(122027,'116484','deals','block-122026','BlockBox','',1),(122028,'116485','deals','block-122027','checkout\\ContactInformation','',2),(122029,'116486','deals','block-122026-2','BlockBox','',1),(122030,'116487','deals','block-122029','Html_box','',1),(122031,'116488','deals','block-122029','checkout\\Comments','',2),(122032,'116489','deals','checkout_delivery_no_shipping_g','BlockBox','',2),(122033,'116490','deals','block-122032','Html_box','',1),(122034,'116491','deals','block-122032-2','checkout\\ContinueBtn','',1),(122035,'116492','deals','checkout_delivery_no_shipping_g','BlockBox','',1),(122036,'116493','deals','block-122035','BlockBox','',1),(122037,'116494','deals','block-122036','checkout\\ContactInformation','',2),(122038,'116495','deals','block-122035-2','BlockBox','',1),(122039,'116496','deals','block-122038','checkout\\Comments','',2),(122040,'116497','deals','block-122038','Html_box','',1),(122041,'116498','deals','checkout_delivery_title','Html_box','',1),(122042,'116499','deals','checkout_delivery_title_g','Html_box','',1),(122043,'116501','deals','checkout_delivery_title_no_shipping','Html_box','',1),(122044,'116500','deals','checkout_delivery_title_no_shipping_g','Html_box','',1),(122045,'116502','deals','checkout_delivery_title_q','Html_box','',1),(122046,'116503','deals','checkout_delivery_title_s','Html_box','',1),(122047,'116504','deals','checkout_free_s','BlockBox','',1),(122048,'116505','deals','block-122047','BlockBox','',2),(122049,'116506','deals','block-122048','BlockBox','',2),(122050,'116508','deals','block-122049','BlockBox','',6),(122051,'116509','deals','block-122050','sample\\Products','',1),(122052,'116510','deals','block-122050','checkout\\CreateAccount','',3),(122053,'116511','deals','block-122049','BlockBox','',5),(122054,'116512','deals','block-122053','Html_box','',1),(122055,'116513','deals','block-122053','checkout\\Comments','',2),(122056,'116514','deals','block-122049','BlockBox','',2),(122057,'116515','deals','block-122056','BlockBox','',2),(122058,'116516','deals','block-122057','checkout\\ShippingChoice','',1),(122059,'116517','deals','block-122056','Html_box','',1),(122060,'116518','deals','block-122056','BlockBox','',3),(122061,'116519','deals','block-122060','BlockBox','',1),(122062,'116520','deals','block-122061','checkout\\ContactInformation','',4),(122063,'116521','deals','block-122061','checkout\\ShippingAddress','',2),(122064,'116522','deals','block-122061','Html_box','',3),(122065,'116523','deals','block-122060-2','BlockBox','',1),(122066,'116524','deals','block-122065','DelayedDespatch\\Checkout','',3),(122067,'116525','deals','block-122056','Neighbour\\Checkout','',4),(122068,'116526','deals','block-122048-2','BlockBox','',1),(122069,'116527','deals','block-122068','Html_box','',3),(122070,'116528','deals','block-122068','checkout\\ContinueBtn','',1),(122071,'1638956949','deals','block-122068','checkout\\Terms','',2),(122072,'1638957135','deals','block-122068','Html_box','',0),(122073,'116529','deals','checkout_no_shipping','BlockBox','',1),(122074,'116530','deals','block-122073','BlockBox','',2),(122075,'116531','deals','block-122074','BlockBox','',1),(122076,'116532','deals','block-122075','BlockBox','',6),(122077,'116533','deals','block-122076','checkout\\CreateAccount','',2),(122078,'116534','deals','block-122076','cart\\Products','',1),(122079,'116535','deals','block-122075','BlockBox','',3),(122080,'116536','deals','block-122079','Html_box','',1),(122081,'116537','deals','block-122079','BlockBox','',2),(122082,'116538','deals','block-122081','checkout\\BillingAddress','',2),(122083,'116539','deals','block-122081','Html_box','',1),(122084,'116540','deals','block-122081-2','BlockBox','',1),(122085,'116541','deals','block-122084','Html_box','',1),(122086,'116542','deals','block-122084','checkout\\PaymentMethod','',2),(122087,'116543','deals','block-122075','BlockBox','',4),(122088,'116544','deals','block-122087','BlockBox','',2),(122089,'116545','deals','block-122088','CouponsAndVauchers\\Checkout','',1),(122090,'116546','deals','block-122088-2','checkout\\CreditAmount','',1),(122091,'116547','deals','block-122088-2','checkout\\BonusPoints','',2),(122092,'116548','deals','block-122087','Html_box','',1),(122093,'116549','deals','block-122075','BlockBox','',5),(122094,'116550','deals','block-122093','checkout\\Comments','',2),(122095,'116551','deals','block-122093','Html_box','',1),(122096,'116552','deals','block-122074-2','BlockBox','',1),(122097,'116553','deals','block-122096','Html_box','',1),(122098,'116554','deals','block-122096','Html_box','',5),(122099,'116555','deals','block-122096','checkout\\Totals','',2),(122100,'116556','deals','block-122096','checkout\\ContinueBtn','',3),(122101,'116557','deals','block-122096','checkout\\Terms','',4),(122102,'116558','deals','checkout_no_shipping_g','BlockBox','',1),(122103,'116559','deals','block-122102','checkout\\Totals','',5),(122104,'116560','deals','block-122102','BlockBox','',6),(122105,'116561','deals','block-122104','Html_box','',1),(122106,'116562','deals','block-122104-2','checkout\\ContinueBtn','',1),(122107,'116563','deals','block-122102','BlockBox','',2),(122108,'116564','deals','block-122107','BlockBox','',1),(122109,'116565','deals','block-122108','checkout\\ContactInformation','',2),(122110,'116566','deals','block-122108','Html_box','',1),(122111,'116567','deals','block-122107-2','BlockBox','',1),(122112,'116568','deals','block-122111','checkout\\Comments','',2),(122113,'116569','deals','block-122111','Html_box','',1),(122114,'116570','deals','block-122102','BlockBox','',1),(122115,'116571','deals','block-122114','BlockBox','',1),(122116,'116572','deals','block-122115','Html_box','',1),(122117,'116573','deals','block-122115','checkout\\BillingAddress','',2),(122118,'116574','deals','block-122114-2','BlockBox','',1),(122119,'116575','deals','block-122118','checkout\\BonusPoints','',4),(122120,'116576','deals','block-122118','CouponsAndVauchers\\Checkout','',5),(122121,'116577','deals','block-122118','checkout\\PaymentMethod','',2),(122122,'116578','deals','block-122118','checkout\\CreditAmount','',3),(122123,'116579','deals','block-122118','Html_box','',1),(122124,'116580','deals','block-122102','quote\\Products','',3),(122125,'116581','deals','checkout_no_shipping_q','BlockBox','',1),(122126,'116582','deals','block-122125','BlockBox','',2),(122127,'116583','deals','block-122126','BlockBox','',2),(122128,'116585','deals','block-122127','BlockBox','',5),(122129,'116586','deals','block-122128','checkout\\Comments','',2),(122130,'116587','deals','block-122128','Html_box','',1),(122131,'116588','deals','block-122127','BlockBox','',6),(122132,'116589','deals','block-122131','checkout\\CreateAccount','',3),(122133,'116590','deals','block-122131','quote\\Products','',2),(122134,'116591','deals','block-122127','BlockBox','',3),(122135,'116592','deals','block-122134','Html_box','',1),(122136,'116593','deals','block-122134','BlockBox','',2),(122137,'116594','deals','block-122136','Html_box','',1),(122138,'116595','deals','block-122136','checkout\\BillingAddress','',2),(122139,'116596','deals','block-122136-2','BlockBox','',1),(122140,'116597','deals','block-122139','checkout\\PaymentMethod','',2),(122141,'116598','deals','block-122139','Html_box','',1),(122142,'116599','deals','block-122126-2','BlockBox','',1),(122143,'116600','deals','block-122142','checkout\\ContinueBtn','',3),(122144,'116601','deals','block-122142','Html_box','',5),(122145,'116602','deals','block-122142','Html_box','',1),(122146,'116603','deals','block-122142','checkout\\Totals','',2),(122147,'120984','deals','block-122142','checkout\\Terms','',4),(122148,'116604','deals','checkout_payment','BlockBox','',1),(122149,'116605','deals','block-122148','BlockBox','',1),(122150,'116606','deals','block-122149','checkout\\BillingAddress','',2),(122151,'116607','deals','block-122149','Html_box','',1),(122152,'116608','deals','block-122148-2','BlockBox','',1),(122153,'116609','deals','block-122152','checkout\\CreditAmount','',3),(122154,'116610','deals','block-122152','checkout\\BonusPoints','',4),(122155,'116611','deals','block-122152','CouponsAndVauchers\\Checkout','',5),(122156,'116612','deals','block-122152','checkout\\PaymentMethod','',2),(122157,'116613','deals','block-122152','Html_box','',1),(122158,'116614','deals','checkout_payment','BlockBox','',2),(122159,'116615','deals','block-122158','Html_box','',1),(122160,'116616','deals','block-122158-2','checkout\\ContinueBtn','',1),(122161,'116617','deals','checkout_payment_g','BlockBox','',1),(122162,'116618','deals','block-122161','BlockBox','',1),(122163,'116619','deals','block-122162','checkout\\BillingAddress','',2),(122164,'116620','deals','block-122162','Html_box','',1),(122165,'116621','deals','block-122161-2','BlockBox','',1),(122166,'116622','deals','block-122165','checkout\\CreditAmount','',3),(122167,'116623','deals','block-122165','Html_box','',1),(122168,'116624','deals','block-122165','checkout\\PaymentMethod','',2),(122169,'116625','deals','block-122165','CouponsAndVauchers\\Checkout','',5),(122170,'116626','deals','block-122165','checkout\\BonusPoints','',4),(122171,'116627','deals','checkout_payment_g','BlockBox','',2),(122172,'116628','deals','block-122171','Html_box','',1),(122173,'116629','deals','block-122171-2','checkout\\ContinueBtn','',1),(122174,'116630','deals','checkout_payment_no_shipping','BlockBox','',2),(122175,'116631','deals','block-122174','Html_box','',1),(122176,'116632','deals','block-122174-2','checkout\\ContinueBtn','',1),(122177,'116633','deals','checkout_payment_no_shipping','BlockBox','',1),(122178,'116634','deals','block-122177','BlockBox','',1),(122179,'116635','deals','block-122178','Html_box','',1),(122180,'116636','deals','block-122178','checkout\\BillingAddress','',2),(122181,'116637','deals','block-122177-2','BlockBox','',1),(122182,'116638','deals','block-122181','checkout\\BonusPoints','',4),(122183,'116639','deals','block-122181','CouponsAndVauchers\\Checkout','',5),(122184,'116640','deals','block-122181','checkout\\PaymentMethod','',2),(122185,'116641','deals','block-122181','checkout\\CreditAmount','',3),(122186,'116642','deals','block-122181','Html_box','',1),(122187,'116643','deals','checkout_payment_no_shipping_g','BlockBox','',2),(122188,'116644','deals','block-122187','Html_box','',1),(122189,'116645','deals','block-122187-2','checkout\\ContinueBtn','',1),(122190,'116646','deals','checkout_payment_no_shipping_g','BlockBox','',1),(122191,'116647','deals','block-122190','BlockBox','',1),(122192,'116648','deals','block-122191','checkout\\BillingAddress','',2),(122193,'116649','deals','block-122191','Html_box','',1),(122194,'116650','deals','block-122190-2','BlockBox','',1),(122195,'116651','deals','block-122194','checkout\\BonusPoints','',4),(122196,'116652','deals','block-122194','checkout\\CreditAmount','',3),(122197,'116653','deals','block-122194','checkout\\PaymentMethod','',2),(122198,'116654','deals','block-122194','Html_box','',1),(122199,'116655','deals','block-122194','CouponsAndVauchers\\Checkout','',5),(122200,'116656','deals','checkout_payment_title','Html_box','',1),(122201,'116657','deals','checkout_payment_title_g','Html_box','',1),(122202,'116658','deals','checkout_payment_title_no_shipping','Html_box','',1),(122203,'116659','deals','checkout_payment_title_no_shipping_g','Html_box','',1),(122204,'116660','deals','checkout_payment_title_q','Html_box','',1),(122205,'116661','deals','checkout_payment_title_s','Html_box','',1),(122206,'120947','deals','checkout_q','BlockBox','',1),(122207,'120948','deals','block-122206','BlockBox','',2),(122208,'120949','deals','block-122207','BlockBox','',2),(122209,'120950','deals','block-122208','BlockBox','',6),(122210,'120951','deals','block-122209','checkout\\CreateAccount','',3),(122211,'120952','deals','block-122209','quote\\Products','',2),(122212,'120953','deals','block-122208','BlockBox','',2),(122213,'120954','deals','block-122212','BlockBox','',2),(122214,'120955','deals','block-122213','checkout\\ShippingChoice','',1),(122215,'120956','deals','block-122212','Neighbour\\Checkout','',4),(122216,'120957','deals','block-122212','Html_box','',1),(122217,'120958','deals','block-122212','BlockBox','',3),(122218,'120959','deals','block-122217','BlockBox','',1),(122219,'120960','deals','block-122218','checkout\\ContactInformation','',4),(122220,'120961','deals','block-122218','checkout\\ShippingAddress','',2),(122221,'120962','deals','block-122218','Html_box','',3),(122222,'120963','deals','block-122217-2','BlockBox','',1),(122223,'120964','deals','block-122222','checkout\\Shipping','',2),(122224,'120965','deals','block-122222','Html_box','',1),(122225,'120966','deals','block-122222','DelayedDespatch\\Checkout','',3),(122226,'120967','deals','block-122208','BlockBox','',5),(122227,'120968','deals','block-122226','Html_box','',1),(122228,'120969','deals','block-122226','checkout\\Comments','',2),(122229,'120970','deals','block-122208','BlockBox','',3),(122230,'120971','deals','block-122229','Html_box','',1),(122231,'120972','deals','block-122229','BlockBox','',2),(122232,'120973','deals','block-122231','checkout\\BillingAddress','',2),(122233,'120974','deals','block-122231','Html_box','',1),(122234,'120975','deals','block-122231-2','BlockBox','',1),(122235,'120976','deals','block-122234','checkout\\PaymentMethod','',2),(122236,'120977','deals','block-122234','Html_box','',1),(122237,'120978','deals','block-122207-2','BlockBox','',1),(122238,'120979','deals','block-122237','Html_box','',1),(122239,'120980','deals','block-122237','Html_box','',5),(122240,'120981','deals','block-122237','checkout\\Totals','',2),(122241,'120982','deals','block-122237','checkout\\ContinueBtn','',3),(122242,'120983','deals','block-122237','checkout\\Terms','',4),(122243,'116699','deals','checkout_s','BlockBox','',1),(122244,'116700','deals','block-122243','BlockBox','',2),(122245,'116701','deals','block-122244','BlockBox','',2),(122246,'116703','deals','block-122245','BlockBox','',6),(122247,'116704','deals','block-122246','sample\\Products','',1),(122248,'116705','deals','block-122246','checkout\\CreateAccount','',3),(122249,'116706','deals','block-122245','BlockBox','',2),(122250,'116707','deals','block-122249','Html_box','',1),(122251,'116708','deals','block-122249','Neighbour\\Checkout','',4),(122252,'116709','deals','block-122249','BlockBox','',2),(122253,'116710','deals','block-122252','checkout\\ShippingChoice','',1),(122254,'116711','deals','block-122249','BlockBox','',3),(122255,'116712','deals','block-122254','BlockBox','',1),(122256,'116713','deals','block-122255','checkout\\ShippingAddress','',2),(122257,'116714','deals','block-122255','checkout\\ContactInformation','',4),(122258,'116715','deals','block-122255','Html_box','',3),(122259,'116716','deals','block-122254-2','BlockBox','',1),(122260,'116717','deals','block-122259','checkout\\Shipping','',2),(122261,'116718','deals','block-122259','DelayedDespatch\\Checkout','',3),(122262,'116719','deals','block-122259','Html_box','',1),(122263,'116720','deals','block-122245','BlockBox','',3),(122264,'116721','deals','block-122263','BlockBox','',2),(122265,'116722','deals','block-122264','Html_box','',1),(122266,'116723','deals','block-122264','checkout\\BillingAddress','',2),(122267,'116724','deals','block-122264-2','BlockBox','',1),(122268,'116725','deals','block-122267','Html_box','',1),(122269,'116726','deals','block-122267','checkout\\PaymentMethod','',2),(122270,'116727','deals','block-122263','Html_box','',1),(122271,'116728','deals','block-122245','BlockBox','',5),(122272,'116729','deals','block-122271','Html_box','',1),(122273,'116730','deals','block-122271','checkout\\Comments','',2),(122274,'116731','deals','block-122245','BlockBox','',4),(122275,'116732','deals','block-122274','BlockBox','',2),(122276,'116733','deals','block-122275','CouponsAndVauchers\\Checkout','',1),(122277,'116734','deals','block-122275-2','checkout\\BonusPoints','',2),(122278,'116735','deals','block-122275-2','checkout\\CreditAmount','',1),(122279,'116736','deals','block-122274','Html_box','',1),(122280,'116737','deals','block-122244-2','BlockBox','',1),(122281,'116738','deals','block-122280','checkout\\Totals','',2),(122282,'116739','deals','block-122280','Html_box','',5),(122283,'116740','deals','block-122280','Html_box','',1),(122284,'116741','deals','block-122280','checkout\\ContinueBtn','',3),(122285,'120986','deals','block-122280','checkout\\Terms','',4),(122286,'116742','deals','checkout_step_bottom','Html_box','',1),(122287,'116743','deals','checkout_step_bottom','cart\\Products','',2),(122288,'116744','deals','checkout_step_bottom','checkout\\Totals','',3),(122289,'116745','deals','checkout_step_bottom_g','checkout\\Totals','',3),(122290,'116746','deals','checkout_step_bottom_g','quote\\Products','',2),(122291,'116747','deals','checkout_step_bottom_g','Html_box','',1),(122292,'116749','deals','checkout_step_bottom_no_shipping','Html_box','',1),(122293,'116750','deals','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(122294,'116753','deals','checkout_step_bottom_no_shipping','cart\\Products','',2),(122295,'116748','deals','checkout_step_bottom_no_shipping_g','Html_box','',1),(122296,'116751','deals','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(122297,'116752','deals','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(122298,'116754','deals','communication','BlockBox','',1),(122299,'116755','deals','block-122298','Html_box','',2),(122300,'116756','deals','block-122298','Communication\\NewTopicButton','',1),(122301,'116757','deals','block-122298','Communication\\Topic','',3),(122302,'116758','deals','compare','BlockBox','',1),(122303,'116759','deals','block-122302','catalog\\Compare','',1),(122304,'117665','deals','compareproduct','BlockBox','listing-item',1),(122305,'120921','deals','block-122304','BlockBox','',1),(122306,'120919','deals','block-122305','BlockBox','',1),(122307,'1638872990','deals','block-122306','BlockBox','',2),(122308,'117671','deals','block-122307','productListing\\image','',1),(122309,'117677','deals','block-122307-2','productListing\\compare','',1),(122310,'117675','deals','block-122307-2','productListing\\name','',2),(122311,'117676','deals','block-122307-2','productListing\\stock','',3),(122312,'1638873112','deals','block-122307-2','BlockBox','',4),(122313,'117670','deals','block-122312','productListing\\rating','',2),(122314,'117673','deals','block-122312-2','productListing\\price','',1),(122315,'116760','deals','compare_products','BlockBox','',2),(122316,'116761','deals','block-122315','productListing\\rating','',4),(122317,'116762','deals','block-122315','productListing\\model','',5),(122318,'116763','deals','block-122315','productListing\\compare','',1),(122319,'116764','deals','block-122315','BlockBox','',2),(122320,'116765','deals','block-122319','productListing\\image','',1),(122321,'116766','deals','block-122319-2','productListing\\name','',2),(122322,'116767','deals','block-122315','BlockBox','',3),(122323,'116768','deals','block-122322','productListing\\price','',1),(122324,'116769','deals','block-122322-2','productListing\\buyButton','',1),(122325,'116770','deals','confirmation','BlockBox','',1),(122326,'116771','deals','block-122325','BlockBox','',2),(122327,'116772','deals','block-122326','BlockBox','',4),(122328,'116773','deals','block-122327','BlockBox','',4),(122329,'116774','deals','block-122328','checkout\\EditBtn','',2),(122330,'116775','deals','block-122328','cart\\Products','',3),(122331,'116776','deals','block-122328','Html_box','',1),(122332,'116777','deals','block-122327','BlockBox','',3),(122333,'116778','deals','block-122332','checkout\\EditBtn','',2),(122334,'116779','deals','block-122332','Html_box','',1),(122335,'116780','deals','block-122332','checkout\\CommentsConfirm','',3),(122336,'116782','deals','block-122326','BlockBox','',2),(122337,'116789','deals','block-122336','Html_box','',1),(122338,'1643301641','deals','block-122336','BlockBox','',2),(122339,'116785','deals','block-122338','Html_box','',4),(122340,'116786','deals','block-122338','checkout\\EditBtn','',5),(122341,'116790','deals','block-122338','checkout\\EditBtn','',2),(122342,'116791','deals','block-122338','checkout\\ContactConfirm','',6),(122343,'116792','deals','block-122338','Html_box','',1),(122344,'116793','deals','block-122338','checkout\\ShippingAddressConfirm','',3),(122345,'116783','deals','block-122338-2','checkout\\EditBtn','',2),(122346,'116784','deals','block-122338-2','DelayedDespatch\\CheckoutConfirm','',4),(122347,'116787','deals','block-122338-2','Html_box','',1),(122348,'116788','deals','block-122338-2','checkout\\ShippingConfirm','',3),(122349,'116794','deals','block-122326','BlockBox','',3),(122350,'116799','deals','block-122349','Html_box','',1),(122351,'1643301813','deals','block-122349','BlockBox','',3),(122352,'116796','deals','block-122351','checkout\\EditBtn','',2),(122353,'116800','deals','block-122351','checkout\\BillingAddressConfirm','',3),(122354,'116801','deals','block-122351','Html_box','',1),(122355,'116795','deals','block-122351-2','checkout\\EditBtn','',2),(122356,'116797','deals','block-122351-2','checkout\\PaymentMethodConfirm','',3),(122357,'116798','deals','block-122351-2','Html_box','',1),(122358,'116802','deals','block-122326','UploadCustomerId\\UploadCustomerIdForm','',1),(122359,'116803','deals','block-122326-2','BlockBox','',1),(122360,'116804','deals','block-122359','Html_box','',1),(122361,'116805','deals','block-122359','checkout\\ConfirmBtn','',3),(122362,'116806','deals','block-122359','checkout\\Totals','',2),(122363,'116807','deals','block-122325','Html_box','',1),(122364,'116808','deals','confirmation_free_s','BlockBox','',1),(122365,'116809','deals','block-122364','BlockBox','',2),(122366,'116810','deals','block-122365','BlockBox','',1),(122367,'116811','deals','block-122366','BlockBox','',2),(122368,'116812','deals','block-122367','checkout\\CommentsConfirm','',3),(122369,'116813','deals','block-122367','checkout\\EditBtn','',2),(122370,'116814','deals','block-122367','Html_box','',1),(122371,'116815','deals','block-122366','BlockBox','',3),(122372,'116816','deals','block-122371','checkout\\EditBtn','',3),(122373,'116817','deals','block-122371','Html_box','',1),(122374,'116818','deals','block-122371','sample\\Products','',2),(122375,'116819','deals','block-122366','BlockBox','',1),(122376,'116820','deals','block-122375','BlockBox','',1),(122377,'116821','deals','block-122376','checkout\\EditBtn','',3),(122378,'116822','deals','block-122376','checkout\\ShippingConfirm','',7),(122379,'116823','deals','block-122376','Html_box','',5),(122380,'116824','deals','block-122376','checkout\\EditBtn','',6),(122381,'116825','deals','block-122376','Html_box','',2),(122382,'116826','deals','block-122376','checkout\\ShippingAddressConfirm','',4),(122383,'116827','deals','block-122375-2','BlockBox','',1),(122384,'116828','deals','block-122383','checkout\\ContactConfirm','',3),(122385,'116829','deals','block-122383','DelayedDespatch\\CheckoutConfirm','',4),(122386,'116830','deals','block-122383','checkout\\EditBtn','',2),(122387,'116831','deals','block-122383','Html_box','',1),(122388,'116832','deals','block-122365-2','BlockBox','',1),(122389,'116833','deals','block-122388','checkout\\ConfirmBtn','',3),(122390,'116834','deals','block-122364','Html_box','',1),(122391,'116835','deals','confirmation_no_shipping','BlockBox','',1),(122392,'116836','deals','block-122391','Html_box','',1),(122393,'116837','deals','block-122391','BlockBox','',2),(122394,'116838','deals','block-122393','BlockBox','',1),(122395,'116839','deals','block-122394','BlockBox','',1),(122396,'116840','deals','block-122395','BlockBox','',1),(122397,'116841','deals','block-122396','checkout\\EditBtn','',10),(122398,'116842','deals','block-122396','Html_box','',9),(122399,'116843','deals','block-122396','checkout\\ContactConfirm','',11),(122400,'116844','deals','block-122395-2','BlockBox','',1),(122401,'116845','deals','block-122400','checkout\\PaymentMethodConfirm','',7),(122402,'116846','deals','block-122400','checkout\\EditBtn','',6),(122403,'116847','deals','block-122400','Html_box','',5),(122404,'116848','deals','block-122400','Html_box','',1),(122405,'116849','deals','block-122400','checkout\\EditBtn','',3),(122406,'116850','deals','block-122400','checkout\\BillingAddressConfirm','',4),(122407,'116851','deals','block-122400','Html_box','',2),(122408,'116852','deals','block-122394','BlockBox','',2),(122409,'116853','deals','block-122408','Html_box','',1),(122410,'116854','deals','block-122408','checkout\\CommentsConfirm','',3),(122411,'116855','deals','block-122408','checkout\\EditBtn','',2),(122412,'116856','deals','block-122394','BlockBox','',3),(122413,'116857','deals','block-122412','Html_box','',1),(122414,'116858','deals','block-122412','checkout\\EditBtn','',2),(122415,'116859','deals','block-122412','cart\\Products','',3),(122416,'116860','deals','block-122393-2','BlockBox','',1),(122417,'116861','deals','block-122416','checkout\\ConfirmBtn','',3),(122418,'116862','deals','block-122416','Html_box','',1),(122419,'116863','deals','block-122416','checkout\\Totals','',2),(122420,'116864','deals','confirmation_no_shipping_q','BlockBox','',2),(122421,'116865','deals','block-122420','Html_box','',1),(122422,'116866','deals','block-122420','BlockBox','',2),(122423,'116867','deals','block-122422','BlockBox','',1),(122424,'116868','deals','block-122423','BlockBox','',2),(122425,'116869','deals','block-122424','Html_box','',1),(122426,'116870','deals','block-122424','checkout\\CommentsConfirm','',3),(122427,'116871','deals','block-122424','checkout\\EditBtn','',2),(122428,'116872','deals','block-122423','BlockBox','',1),(122429,'116873','deals','block-122428','BlockBox','',1),(122430,'116874','deals','block-122429','checkout\\EditBtn','',5),(122431,'116875','deals','block-122429','checkout\\ContactConfirm','',6),(122432,'116876','deals','block-122429','checkout\\PaymentMethodConfirm','',3),(122433,'116877','deals','block-122429','checkout\\EditBtn','',2),(122434,'116878','deals','block-122429','Html_box','',4),(122435,'116879','deals','block-122429','Html_box','',1),(122436,'116880','deals','block-122428-2','BlockBox','',1),(122437,'116881','deals','block-122436','checkout\\BillingAddressConfirm','',4),(122438,'116882','deals','block-122436','checkout\\EditBtn','',3),(122439,'116883','deals','block-122436','Html_box','',2),(122440,'116884','deals','block-122423','BlockBox','',3),(122441,'116885','deals','block-122440','checkout\\EditBtn','',2),(122442,'116886','deals','block-122440','Html_box','',1),(122443,'116887','deals','block-122440','quote\\Products','',3),(122444,'116888','deals','block-122422-2','BlockBox','',1),(122445,'116889','deals','block-122444','checkout\\ConfirmBtn','',3),(122446,'116890','deals','block-122444','checkout\\Totals','',2),(122447,'116891','deals','block-122444','Html_box','',1),(122448,'116892','deals','confirmation_q','BlockBox','',1),(122449,'116893','deals','block-122448','Html_box','',1),(122450,'116894','deals','block-122448','BlockBox','',2),(122451,'116895','deals','block-122450','BlockBox','',1),(122452,'116896','deals','block-122451','BlockBox','',3),(122453,'116897','deals','block-122452','quote\\Products','',3),(122454,'116898','deals','block-122452','Html_box','',1),(122455,'116899','deals','block-122452','checkout\\EditBtn','',2),(122456,'116900','deals','block-122451','BlockBox','',1),(122457,'116901','deals','block-122456','BlockBox','',1),(122458,'116902','deals','block-122457','Html_box','',1),(122459,'116903','deals','block-122457','checkout\\EditBtn','',10),(122460,'116904','deals','block-122457','Html_box','',2),(122461,'116905','deals','block-122457','checkout\\ContactConfirm','',11),(122462,'116906','deals','block-122457','checkout\\ShippingAddressConfirm','',4),(122463,'116907','deals','block-122457','checkout\\ShippingConfirm','',7),(122464,'116908','deals','block-122457','checkout\\EditBtn','',3),(122465,'116909','deals','block-122457','DelayedDespatch\\CheckoutConfirm','',8),(122466,'116910','deals','block-122457','Html_box','',9),(122467,'116911','deals','block-122457','Html_box','',5),(122468,'116912','deals','block-122457','checkout\\EditBtn','',6),(122469,'116913','deals','block-122456-2','BlockBox','',1),(122470,'116914','deals','block-122469','checkout\\EditBtn','',3),(122471,'116915','deals','block-122469','checkout\\BillingAddressConfirm','',4),(122472,'116916','deals','block-122469','checkout\\PaymentMethodConfirm','',7),(122473,'116917','deals','block-122469','Html_box','',1),(122474,'116918','deals','block-122469','Html_box','',2),(122475,'116919','deals','block-122469','checkout\\EditBtn','',6),(122476,'116920','deals','block-122469','Html_box','',5),(122477,'116921','deals','block-122451','BlockBox','',2),(122478,'116922','deals','block-122477','checkout\\CommentsConfirm','',3),(122479,'116923','deals','block-122477','Html_box','',1),(122480,'116924','deals','block-122477','checkout\\EditBtn','',2),(122481,'116925','deals','block-122450-2','BlockBox','',1),(122482,'116926','deals','block-122481','Html_box','',1),(122483,'116927','deals','block-122481','checkout\\Totals','',2),(122484,'116928','deals','block-122481','checkout\\ConfirmBtn','',3),(122485,'116929','deals','confirmation_s','BlockBox','',1),(122486,'116930','deals','block-122485','BlockBox','',2),(122487,'116931','deals','block-122486','BlockBox','',1),(122488,'116932','deals','block-122487','BlockBox','',1),(122489,'116933','deals','block-122488','BlockBox','',1),(122490,'116934','deals','block-122489','checkout\\ShippingAddressConfirm','',4),(122491,'116935','deals','block-122489','checkout\\EditBtn','',3),(122492,'116936','deals','block-122489','Html_box','',2),(122493,'116937','deals','block-122489','DelayedDespatch\\CheckoutConfirm','',8),(122494,'116938','deals','block-122489','checkout\\ShippingConfirm','',7),(122495,'116939','deals','block-122489','Html_box','',1),(122496,'116940','deals','block-122489','Html_box','',5),(122497,'116941','deals','block-122489','Html_box','',9),(122498,'116942','deals','block-122489','checkout\\ContactConfirm','',11),(122499,'116943','deals','block-122489','checkout\\EditBtn','',6),(122500,'116944','deals','block-122489','checkout\\EditBtn','',10),(122501,'116945','deals','block-122488-2','BlockBox','',1),(122502,'116946','deals','block-122501','Html_box','',2),(122503,'116947','deals','block-122501','checkout\\BillingAddressConfirm','',4),(122504,'116948','deals','block-122501','checkout\\EditBtn','',3),(122505,'116949','deals','block-122501','checkout\\PaymentMethodConfirm','',7),(122506,'116950','deals','block-122501','checkout\\EditBtn','',6),(122507,'116951','deals','block-122501','Html_box','',1),(122508,'116952','deals','block-122501','Html_box','',5),(122509,'116953','deals','block-122487','BlockBox','',3),(122510,'116954','deals','block-122509','checkout\\EditBtn','',3),(122511,'116955','deals','block-122509','Html_box','',1),(122512,'116956','deals','block-122509','sample\\Products','',2),(122513,'116957','deals','block-122487','BlockBox','',2),(122514,'116958','deals','block-122513','Html_box','',1),(122515,'116959','deals','block-122513','checkout\\EditBtn','',2),(122516,'116960','deals','block-122513','checkout\\CommentsConfirm','',3),(122517,'116961','deals','block-122486-2','BlockBox','',1),(122518,'116962','deals','block-122517','checkout\\Totals','',2),(122519,'116963','deals','block-122517','checkout\\ConfirmBtn','',3),(122520,'116964','deals','block-122517','Html_box','',1),(122521,'116965','deals','block-122485','Html_box','',1),(122522,'116966','deals','contact','BlockBox','info-content',1),(122523,'116967','deals','block-122522','info\\Title','',1),(122524,'116968','deals','block-122522','BlockBox','',2),(122525,'116969','deals','block-122524','contact\\ContactForm','',1),(122526,'116970','deals','block-122524-2','contact\\Contacts','',1),(122527,'116971','deals','created_success','BlockBox','',1),(122528,'116972','deals','block-122527','Html_box','',1),(122529,'116973','deals','block-122527','Html_box','',2),(122530,'116102.000001','deals','credit_amount_history','BlockBox','',1),(122531,'116103.000001','deals','block-122530','BlockBox','',1),(122532,'116104.000001','deals','block-122531','WidgetsAria','',1),(122552,'116109.000001','deals','block-122531-2','Html_box','',1),(122553,'1638895944','deals','block-122531-2','account\\CreditAmountHistory','',2),(122554,'116974','deals','credit_note','invoice\\Container','',1),(122555,'116975','deals','block-122554','BlockBox','',5),(122556,'116976','deals','block-122555','invoice\\StoreAddress','',8),(122557,'116977','deals','block-122555','Text','',1),(122558,'116978','deals','block-122555-2','Text','',2),(122559,'116979','deals','block-122555-2','Logo','',1),(122560,'116980','deals','block-122555-3','Text','',1),(122561,'116981','deals','block-122555-3','BlockBox','',3),(122562,'116982','deals','block-122561','Text','',1),(122563,'116983','deals','block-122561-2','invoice\\StoreEmail','',1),(122564,'116984','deals','block-122555-3','BlockBox','',2),(122565,'116985','deals','block-122564','Text','',1),(122566,'116986','deals','block-122564-2','invoice\\StorePhone','',1),(122567,'116987','deals','block-122554','invoice\\Products','',3),(122568,'116988','deals','block-122554','BlockBox','',1),(122569,'116989','deals','block-122568','Logo','',1),(122570,'116990','deals','block-122568-2','BlockBox','',4),(122571,'116991','deals','block-122570','Text','',1),(122572,'116992','deals','block-122570-2','invoice\\StoreSite','',1),(122573,'116993','deals','block-122568-2','BlockBox','',2),(122574,'116994','deals','block-122573','Text','',1),(122575,'116995','deals','block-122573-2','invoice\\StorePhone','',1),(122576,'116996','deals','block-122568-2','BlockBox','',3),(122577,'116997','deals','block-122576','Text','',1),(122578,'116998','deals','block-122576-2','invoice\\StoreEmail','',1),(122579,'116999','deals','block-122568-2','BlockBox','',1),(122580,'117000','deals','block-122579','invoice\\StoreAddress','',1),(122581,'117001','deals','block-122554','BlockBox','',4),(122582,'117002','deals','block-122581','BlockBox','',1),(122583,'117003','deals','block-122582','invoice\\ShippingAddress','',2),(122584,'117004','deals','block-122582','Text','',1),(122585,'117005','deals','block-122581-2','BlockBox','',1),(122586,'117006','deals','block-122554','BlockBox','',2),(122587,'117007','deals','block-122586','BlockBox','',7),(122588,'117008','deals','block-122587','BlockBox','',1),(122589,'117009','deals','block-122588','Text','',1),(122590,'117010','deals','block-122588','invoice\\BillingAddress','',2),(122591,'117011','deals','block-122587-2','BlockBox','',1),(122592,'117012','deals','block-122591','invoice\\CustomerPhone','',4),(122593,'117013','deals','block-122591','Text','',1),(122594,'117014','deals','block-122591','Text','',3),(122595,'117015','deals','block-122591','invoice\\CustomerName','',2),(122596,'117016','deals','block-122591','invoice\\CustomerEmail','',6),(122597,'117017','deals','block-122591','Text','',5),(122598,'117018','deals','block-122586','BlockBox','',8),(122599,'117019','deals','block-122598','BlockBox','',1),(122600,'117020','deals','block-122599','invoice\\ShippingMethod','',2),(122601,'117021','deals','block-122599','Text','',1),(122602,'117022','deals','block-122598-2','BlockBox','',1),(122603,'117023','deals','block-122602','Text','',1),(122604,'117024','deals','block-122602','invoice\\ShippingMethod','',2),(122605,'117025','deals','block-122586-2','invoice\\OrderId','',1),(122606,'117026','deals','block-122586-2','Text','',2),(122607,'117027','deals','block-122586-2','invoice\\PaymentDate','',3),(122608,'117034','deals','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(122609,'1639155816','deals','delivery-location','BlockBox','',2),(122610,'117028','deals','block-122609','DeliveryLocation\\FeaturedList','',6),(122611,'117029','deals','block-122609','DeliveryLocation\\LocationLongDescription','',3),(122612,'117030','deals','block-122609','DeliveryLocation\\LocationList','',4),(122613,'117031','deals','block-122609','DeliveryLocation\\LocationTitle','',1),(122614,'117032','deals','block-122609','DeliveryLocation\\LocationProducts','',7),(122615,'117033','deals','block-122609','DeliveryLocation\\LocationDescription','',2),(122616,'1639485067','deals','block-122609','DeliveryLocation\\CrossPages','',0),(122617,'1639485089','deals','block-122609','DeliveryLocation\\ProductCategories','',0),(122618,'1639154415','deals','delivery-location-default','BlockBox','',2),(122619,'117035','deals','block-122618','DeliveryLocation\\TopLocationList','',2),(122620,'117036','deals','block-122618','Heading','',1),(122621,'1639419797','deals','block-122618','DeliveryLocation\\ListByPage','',3),(122622,'117037','deals','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(122623,'117038','deals','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(122624,'117039','deals','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(122625,'117040','deals','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(122626,'117041','deals','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(122627,'117042','deals','delivery_loc_2','DeliveryLocation\\LocationList','',7),(122628,'117043','deals','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(122629,'117044','deals','email','email\\BlockBox','',1),(122630,'117045','deals','block-122629','email\\BlockBox','',1),(122631,'117046','deals','block-122630','Copyright','',4),(122632,'117047','deals','block-122630','email\\Content','',3),(122633,'117048','deals','block-122630','email\\BlockBox','',2),(122634,'117049','deals','block-122633','email\\Title','',1),(122635,'117050','deals','block-122633-2','email\\Date','',1),(122636,'117051','deals','block-122630','Logo','',1),(122637,'117052','deals','email_2','email\\BlockBox','',1),(122638,'117053','deals','block-122637','email\\BlockBox','',1),(122639,'117054','deals','block-122638','Copyright','',4),(122640,'117055','deals','block-122638','Logo','',1),(122641,'117056','deals','block-122638','email\\Content','',3),(122642,'117057','deals','block-122638','email\\BlockBox','',2),(122643,'117058','deals','block-122642','email\\Title','',1),(122644,'117059','deals','block-122642-2','email\\Date','',1),(122645,'117060','deals','email_3','email\\BlockBox','',1),(122646,'117061','deals','block-122645','email\\BlockBox','',1),(122647,'117062','deals','block-122646','email\\BlockBox','',2),(122648,'117063','deals','block-122647','email\\Content','',2),(122649,'117064','deals','block-122647','email\\BlockBox','',1),(122650,'117065','deals','block-122649','email\\Title','',1),(122651,'117066','deals','block-122649-2','email\\Date','',1),(122652,'117067','deals','block-122646','Copyright','',3),(122653,'117068','deals','block-122646','Logo','',1),(122654,'117069','deals','email_4','email\\BlockBox','',1),(122655,'117070','deals','block-122654','email\\BlockBox','',1),(122656,'117071','deals','block-122655','Copyright','',2),(122657,'117072','deals','block-122655','email\\BlockBox','',1),(122658,'117073','deals','block-122657','email\\BlockBox','',1),(122659,'117074','deals','block-122658','Logo','',1),(122660,'117075','deals','block-122658-2','email\\Date','',2),(122661,'117076','deals','block-122658-2','email\\Title','',1),(122662,'117077','deals','block-122657','email\\Content','',2),(122663,'121029','deals','filescatalog_category','BlockBox','',1),(122664,'121030','deals','block-122663','FilesCatalog\\widgets\\FilesList','',3),(122665,'121031','deals','block-122663','FilesCatalog\\widgets\\Title','',1),(122666,'121032','deals','block-122663','FilesCatalog\\widgets\\Description','',2),(122667,'121025','deals','filescatalog_index','BlockBox','',1),(122668,'121026','deals','block-122667','Html_box','',1),(122669,'121027','deals','block-122667','FilesCatalog\\widgets\\FilesCatalog','',2),(122670,'117078','deals','footer','BlockBox','footer-content',1),(122671,'120872','deals','block-122670','Banner','',2),(122672,'117094','deals','block-122670','Copyright','',3),(122673,'1641484988','deals','block-122670','BlockBox','footer-content',1),(122674,'117085','deals','block-122673','Menu','Footer',1),(122675,'117091','deals','block-122673-2','Contacts','',1),(122676,'120868','deals','block-122673-2','Logo','',2),(122677,'117096','deals','for_menu','BlockBox','',1),(122678,'117097','deals','block-122677','Html_box','',1),(122679,'117098','deals','block-122677-2','Languages','',1),(122680,'117099','deals','for_menu','BlockBox','',3),(122681,'117100','deals','block-122680','Html_box','',1),(122682,'117101','deals','block-122680-2','Currencies','',1),(122683,'117102','deals','gift','BlockBox','',1),(122684,'117103','deals','block-122683','BlockBox','',3),(122685,'117104','deals','block-122684','BlockBox','',1),(122686,'117105','deals','block-122685','gift\\Card','',1),(122687,'117106','deals','block-122684-2','gift\\Form','',2),(122688,'117107','deals','block-122684-2','Text','',1),(122689,'117108','deals','block-122683','info\\Title','',1),(122690,'117109','deals','gift_card','BlockBox','',1),(122691,'117110','deals','block-122690','BlockBox','',11),(122692,'117111','deals','block-122691','invoice\\StoreEmail','',3),(122693,'117112','deals','block-122691','Text','',1),(122694,'117113','deals','block-122691','invoice\\StorePhone','',2),(122695,'117114','deals','block-122690','Text','',8),(122696,'117115','deals','block-122690','Text','',3),(122697,'117116','deals','block-122690','BlockBox','',10),(122698,'117117','deals','block-122697','Text','',1),(122699,'117118','deals','block-122697-2','gift\\CodeView','',1),(122700,'117119','deals','block-122690','gift\\MessageView','',7),(122701,'117120','deals','block-122690','gift\\AmountView','',5),(122702,'117121','deals','block-122690','Text','',6),(122703,'117123','deals','block-122690','Logo','',1),(122704,'117124','deals','block-122690','Text','',4),(122705,'117125','deals','block-122690','Text','',9),(122706,'117126','deals','gift_card_2','BlockBox','',1),(122707,'117127','deals','block-122706','gift\\AmountView','',4),(122708,'117128','deals','block-122706','BlockBox','',9),(122709,'117129','deals','block-122708','Text','',1),(122710,'117130','deals','block-122708-2','gift\\CodeView','',1),(122711,'117131','deals','block-122706','BlockBox','',10),(122712,'117132','deals','block-122711','invoice\\StoreEmail','',3),(122713,'117133','deals','block-122711','Text','',1),(122714,'117134','deals','block-122711','invoice\\StorePhone','',2),(122715,'117135','deals','block-122706','gift\\MessageView','',6),(122716,'117136','deals','block-122706','Text','',5),(122717,'117137','deals','block-122706','Text','',8),(122718,'117138','deals','block-122706','Text','',3),(122719,'117139','deals','block-122706','Text','',7),(122720,'1638804282','deals','block-122706','Logo','',1),(122721,'117141','deals','gift_card_2_pdf','BlockBox','',1),(122722,'117142','deals','block-122721','BlockBox','',12),(122723,'117143','deals','block-122722','invoice\\StoreEmail','',4),(122724,'117144','deals','block-122722','invoice\\StorePhone','',3),(122725,'117145','deals','block-122722','Html_box','',1),(122726,'117146','deals','block-122721','BlockBox','',11),(122727,'117147','deals','block-122726','Html_box','',1),(122728,'117148','deals','block-122726-2','gift\\CodeViewPdf','',1),(122729,'117149','deals','block-122721','BlockBox','',1),(122730,'117150','deals','block-122729','Text','',4),(122731,'117151','deals','block-122729','Html_box','',1),(122732,'117152','deals','block-122729','Html_box','',2),(122733,'117153','deals','block-122729','gift\\AmountViewPdf','',3),(122734,'117154','deals','block-122729','gift\\MessageViewPdf','',5),(122735,'117155','deals','block-122729','Html_box','',7),(122736,'117156','deals','block-122729','Html_box','',6),(122737,'117158','deals','gift_card_pdf','BlockBox','',1),(122738,'117159','deals','block-122737','BlockBox','',12),(122739,'117160','deals','block-122738','invoice\\StoreEmail','',4),(122740,'117161','deals','block-122738','invoice\\StorePhone','',3),(122741,'117162','deals','block-122738','Html_box','',1),(122742,'117163','deals','block-122737','BlockBox','',11),(122743,'117164','deals','block-122742','Html_box','',1),(122744,'117165','deals','block-122742-2','gift\\CodeViewPdf','',1),(122745,'117166','deals','block-122737','BlockBox','',1),(122746,'117167','deals','block-122745','Text','',5),(122747,'117169','deals','block-122745','Html_box','',3),(122748,'117170','deals','block-122745','gift\\AmountViewPdf','',4),(122749,'117171','deals','block-122745','gift\\MessageViewPdf','',6),(122750,'117172','deals','block-122745','Html_box','',8),(122751,'117173','deals','block-122745','Html_box','',7),(122752,'1638978695','deals','block-122745','Logo','',2),(122753,'117175','deals','gift_certificate','BlockBox','',1),(122754,'117176','deals','block-122753','account\\ApplyCertificate','',2),(122755,'117177','deals','block-122753','Html_box','',1),(122756,'117178','deals','gigt_card_3','BlockBox','',1),(122757,'117179','deals','block-122756','BlockBox','',9),(122758,'117180','deals','block-122757','Text','',1),(122759,'117181','deals','block-122757-2','gift\\CodeView','',1),(122760,'117182','deals','block-122756','Text','',7),(122761,'117184','deals','block-122756','BlockBox','',10),(122762,'117185','deals','block-122761','Text','',1),(122763,'117186','deals','block-122761','invoice\\StoreEmail','',3),(122764,'117187','deals','block-122761','invoice\\StorePhone','',2),(122765,'117188','deals','block-122756','gift\\MessageView','',6),(122766,'117189','deals','block-122756','Text','',3),(122767,'117190','deals','block-122756','Text','',5),(122768,'117191','deals','block-122756','gift\\AmountView','',4),(122769,'117192','deals','block-122756','Text','',8),(122770,'1638804328','deals','block-122756','Logo','',1),(122771,'117193','deals','gigt_card_3_pdf','BlockBox','',1),(122772,'117194','deals','block-122771','BlockBox','',12),(122773,'117195','deals','block-122772','invoice\\StoreEmail','',4),(122774,'117196','deals','block-122772','invoice\\StorePhone','',3),(122775,'117197','deals','block-122772','Html_box','',1),(122776,'117198','deals','block-122771','BlockBox','',11),(122777,'117199','deals','block-122776','Html_box','',1),(122778,'117200','deals','block-122776-2','gift\\CodeViewPdf','',1),(122779,'117201','deals','block-122771','BlockBox','',1),(122780,'117202','deals','block-122779','Text','',4),(122781,'117203','deals','block-122779','Html_box','',1),(122782,'117204','deals','block-122779','Html_box','',2),(122783,'117205','deals','block-122779','gift\\AmountViewPdf','',3),(122784,'117206','deals','block-122779','gift\\MessageViewPdf','',5),(122785,'117207','deals','block-122779','Html_box','',7),(122786,'117208','deals','block-122779','Html_box','',6),(122800,'117224.000001','deals','info','BlockBox','info-content',1),(122801,'117225.000001','deals','block-122800','info\\DescriptionShort','',3),(122802,'117226','deals','block-122800','info\\Content','',6),(122803,'117227.000001','deals','block-122800','info\\Title','',1),(122804,'117228.000001','deals','block-122800','info\\Image','',4),(122805,'1638467467.0001','deals','block-122800','info\\DescriptionShort','',5),(122806,'117229','deals','invoice','invoice\\Container','',1),(122807,'117230','deals','block-122806','BlockBox','',4),(122808,'117231','deals','block-122807','BlockBox','',8),(122809,'117232','deals','block-122808','BlockBox','',1),(122810,'117233','deals','block-122809','invoice\\ShippingMethod','',2),(122811,'117234','deals','block-122809','Text','',1),(122812,'117235','deals','block-122808-2','BlockBox','',1),(122813,'117236','deals','block-122812','Text','',1),(122814,'117237','deals','block-122812','invoice\\ShippingMethod','',2),(122815,'117238','deals','block-122807','BlockBox','',7),(122816,'117239','deals','block-122815','BlockBox','',2),(122817,'117240','deals','block-122816','Text','',1),(122818,'117241','deals','block-122816','invoice\\BillingAddress','',2),(122819,'1639659760','deals','block-122816','GiftWrapMessage\\ShowInfo','',3),(122820,'117242','deals','block-122815-2','BlockBox','',1),(122821,'117243','deals','block-122820','Text','',5),(122822,'117244','deals','block-122820','invoice\\CustomerName','',2),(122823,'117245','deals','block-122820','invoice\\CustomerPhone','',4),(122824,'117246','deals','block-122820','Text','',1),(122825,'117247','deals','block-122820','Text','',3),(122826,'117248','deals','block-122820','invoice\\CustomerEmail','',6),(122827,'117249','deals','block-122807-2','invoice\\PaymentMethod','',6),(122828,'117250','deals','block-122807-2','Text','',5),(122829,'117251','deals','block-122807-2','Text','',3),(122830,'117252','deals','block-122807-2','invoice\\OrderId','',2),(122831,'117253','deals','block-122807-2','invoice\\PaymentDate','',4),(122832,'117254','deals','block-122807-2','invoice\\OrderBarcode','',7),(122833,'117255','deals','block-122806','BlockBox','',8),(122834,'117256','deals','block-122833','invoice\\StoreAddress','',8),(122835,'117257','deals','block-122833','Text','',1),(122836,'117258','deals','block-122833-2','Text','',2),(122837,'117260','deals','block-122833-3','BlockBox','',3),(122838,'117261','deals','block-122837','Text','',1),(122839,'117262','deals','block-122837-2','invoice\\StoreEmail','',1),(122840,'117263','deals','block-122833-3','BlockBox','',2),(122841,'117264','deals','block-122840','Text','',1),(122842,'117265','deals','block-122840-2','invoice\\StorePhone','',1),(122843,'117266','deals','block-122833-3','Text','',1),(122844,'117267','deals','block-122806','invoice\\Products','',5),(122845,'117268','deals','block-122806','BlockBox','',7),(122846,'117269','deals','block-122845','BlockBox','',1),(122847,'117270','deals','block-122846','invoice\\ShippingAddress','',2),(122848,'117271','deals','block-122846','Text','',1),(122849,'117272','deals','block-122845-2','BlockBox','',1),(122850,'117273','deals','block-122849','invoice\\Totals','',1),(122851,'117274','deals','block-122806','BlockBox','',2),(122852,'117275','deals','block-122851','Logo','',1),(122853,'117276','deals','block-122851-2','BlockBox','',4),(122854,'117277','deals','block-122853','Text','',1),(122855,'117278','deals','block-122853-2','invoice\\StoreSite','',1),(122856,'117279','deals','block-122851-2','BlockBox','',3),(122857,'117280','deals','block-122856','Text','',1),(122858,'117281','deals','block-122856-2','invoice\\StoreEmail','',1),(122859,'117282','deals','block-122851-2','BlockBox','',1),(122860,'117283','deals','block-122859','invoice\\StoreAddress','',2),(122861,'117284','deals','block-122851-2','BlockBox','',2),(122862,'117285','deals','block-122861','Text','',1),(122863,'117286','deals','block-122861-2','invoice\\StorePhone','',1),(122864,'1640103567','deals','block-122806','invoice\\StructuredProducts','',6),(122865,'117287','deals','login_account','BlockBox','',1),(122866,'117288','deals','block-122865','Tabs','',2),(122867,'117289','deals','block-122866-1','login\\Returning','',1),(122868,'117292','deals','block-122866-2','BlockBox','',2),(122869,'117293','deals','block-122868','Html_box','',2),(122870,'117294','deals','block-122868','login\\Register','',1),(122871,'117295','deals','block-122865','BlockBox','',1),(122872,'117296','deals','block-122871','Html_box','',5),(122873,'117297','deals','block-122871','Html_box','',1),(122874,'117298','deals','block-122871','login\\Socials','',4),(122875,'117299','deals','login_checkout','BlockBox','',1),(122876,'117300','deals','block-122875','BlockBox','',1),(122877,'117301','deals','block-122876','checkout\\CreateBtn','',4),(122878,'117302','deals','block-122876','checkout\\GuestBtn','',2),(122879,'117303','deals','block-122876','Html_box','',3),(122880,'117304','deals','block-122876','BlockBox','',5),(122881,'117305','deals','block-122880','Html_box','',1),(122882,'117306','deals','block-122880','login\\Socials','',2),(122883,'117307','deals','block-122876','Html_box','',1),(122884,'117308','deals','block-122876-2','login\\Returning','',2),(122885,'117309','deals','block-122876-2','Html_box','',1),(122886,'117310','deals','login_checkout2','BlockBox','',1),(122887,'117311','deals','block-122886','Tabs','',4),(122888,'117312','deals','block-122887-1','BlockBox','',1),(122889,'117313','deals','block-122888','Html_box','',1),(122890,'117314','deals','block-122888-2','BlockBox','',1),(122891,'117315','deals','block-122890','login\\Guest','',1),(122892,'117316','deals','block-122890','Html_box','',2),(122893,'117317','deals','block-122887-2','login\\Returning','',1),(122894,'117318','deals','block-122887-3','BlockBox','',1),(122895,'117319','deals','block-122894','Html_box','',1),(122896,'117320','deals','block-122894-2','BlockBox','',1),(122897,'117321','deals','block-122896','Html_box','',2),(122898,'117322','deals','block-122896','login\\Register','',1),(122899,'117323','deals','block-122886','login\\Socials','',2),(122900,'117324','deals','block-122886','Html_box','',3),(122901,'117325','deals','block-122886','Html_box','',1),(122902,'117326','deals','login_checkout2_q','BlockBox','',1),(122903,'117327','deals','block-122902','Tabs','',4),(122904,'117328','deals','block-122903-1','BlockBox','',1),(122905,'117329','deals','block-122904','Html_box','',1),(122906,'117330','deals','block-122904-2','quote\\FastOrder','',1),(122907,'117331','deals','block-122903-2','login\\Returning','',1),(122908,'117332','deals','block-122903-3','BlockBox','',1),(122909,'117333','deals','block-122908','Html_box','',1),(122910,'117334','deals','block-122908','Import','',2),(122911,'117335','deals','block-122908-2','BlockBox','',1),(122912,'117336','deals','block-122911','login\\Register','',1),(122913,'117337','deals','block-122911','Html_box','',2),(122914,'117338','deals','block-122902','Html_box','',3),(122915,'117339','deals','block-122902','Html_box','',1),(122916,'117340','deals','block-122902','login\\Socials','',2),(122917,'117341','deals','login_checkout2_s','BlockBox','',1),(122918,'117342','deals','block-122917','login\\Socials','',2),(122919,'117343','deals','block-122917','Html_box','',3),(122920,'117344','deals','block-122917','Tabs','',4),(122921,'117345','deals','block-122920-1','BlockBox','',1),(122922,'117346','deals','block-122921','Html_box','',1),(122923,'117347','deals','block-122921-2','quote\\FastOrder','',1),(122924,'117348','deals','block-122920-2','login\\Returning','',1),(122925,'117349','deals','block-122920-3','BlockBox','',1),(122926,'117350','deals','block-122925','Html_box','',1),(122927,'117351','deals','block-122925-2','BlockBox','',1),(122928,'117352','deals','block-122927','login\\Register','',1),(122929,'117353','deals','block-122927','Html_box','',2),(122930,'117354','deals','block-122917','Html_box','',1),(122931,'117355','deals','login_checkout_q','BlockBox','',1),(122932,'117356','deals','block-122931','BlockBox','',1),(122933,'117357','deals','block-122932','BlockBox','',5),(122934,'117358','deals','block-122933','Html_box','',1),(122935,'117359','deals','block-122933','login\\Socials','',2),(122936,'117360','deals','block-122932','checkout\\GuestBtn','',2),(122937,'117361','deals','block-122932','checkout\\CreateBtn','',4),(122938,'117362','deals','block-122932','Html_box','',3),(122939,'117363','deals','block-122932','Html_box','',1),(122940,'117364','deals','block-122932-2','Html_box','',1),(122941,'117365','deals','block-122932-2','login\\Returning','',2),(122942,'117366','deals','login_checkout_s','BlockBox','',1),(122943,'117367','deals','block-122942','BlockBox','',1),(122944,'117368','deals','block-122943','Html_box','',1),(122945,'117369','deals','block-122943','checkout\\GuestBtn','',2),(122946,'117370','deals','block-122943','checkout\\CreateBtn','',4),(122947,'117371','deals','block-122943','Html_box','',3),(122948,'117372','deals','block-122943','BlockBox','',5),(122949,'117373','deals','block-122948','Html_box','',1),(122950,'117374','deals','block-122948','login\\Socials','',2),(122951,'117375','deals','block-122943-2','Html_box','',1),(122952,'117376','deals','block-122943-2','login\\Returning','',2),(122953,'117377','deals','logoff','BlockBox','',1),(122954,'117378','deals','block-122953','Html_box','',1),(122955,'117379','deals','logoff_forever','BlockBox','',1),(122956,'117380','deals','block-122955','Html_box','',1),(122957,'1641480784','deals','main','BlockBox','',5),(122958,'1641480810','deals','block-122957','InfoPage','',0),(122959,'1641549359','deals','main','BlockBox','',3),(122960,'1641549444','deals','block-122959','BlockBox','',0),(122961,'1641549385','deals','block-122960','Banner','',1),(122962,'1641549553','deals','block-122960-2','Banner','',1),(122963,'1641570125','deals','main','BlockBox','main-content',4),(122964,'1641570075','deals','block-122963','TopCategories','',1),(122965,'1683024814.1915','deals','main','Banner','',1),(122967,'117394','deals','manufacturers','BlockBox','',1),(122968,'117395','deals','block-122967','Html_box','',1),(122969,'117396','deals','block-122967','Brands','',2),(122970,'117397','deals','messages-index','BlockBox','',1),(122971,'117398','deals','block-122970','BlockBox','',1),(122972,'117399','deals','block-122971','BlockBox','',1),(122973,'117400','deals','block-122972','Messages\\Sidebar','',1),(122974,'117401','deals','block-122971-2','Messages\\Listing','',1),(122975,'117402','deals','messages-new','BlockBox','',1),(122976,'117403','deals','block-122975','BlockBox','',1),(122977,'117404','deals','block-122976','Messages\\Sidebar','',1),(122978,'117405','deals','block-122976-2','Messages\\NewMessage','',1),(122979,'117406','deals','messages-view','BlockBox','',1),(122980,'117407','deals','block-122979','BlockBox','',1),(122981,'117408','deals','block-122980','Messages\\Sidebar','',1),(122982,'117409','deals','block-122980-2','Messages\\Message','',1),(122983,'117410','deals','my_password','BlockBox','',1),(122984,'117411','deals','block-122983','BlockBox','',1),(122985,'117412','deals','block-122984','WidgetsAria','',1),(123005,'117413','deals','block-122984-2','account\\ChangePassword','',2),(123006,'117414','deals','block-122984-2','Html_box','',1),(123007,'117415','deals','need_login','BlockBox','',1),(123008,'117416','deals','block-123007','Tabs','',2),(123009,'117417','deals','block-123008-1','login\\Returning','',1),(123010,'117418','deals','block-123008-2','BlockBox','',1),(123011,'117419','deals','block-123010','Html_box','',2),(123012,'117420','deals','block-123010-2','BlockBox','',1),(123013,'117421','deals','block-123012','login\\Register','',1),(123014,'117422','deals','block-123012','Html_box','',2),(123015,'117423','deals','block-123007','BlockBox','',1),(123016,'117424','deals','new-topic','BlockBox','',1),(123017,'117425','deals','block-123016','Breadcrumb','',2),(123018,'117426','deals','block-123016','Communication\\NewTopic','',3),(123019,'117427','deals','block-123016','Html_box','',1),(123020,'117428','deals','nnnn','BlockBox','',1),(123021,'117429','deals','block-123020','catalog\\Title','',1),(123022,'117430','deals','block-123020','BlockBox','',2),(123023,'117431','deals','block-123022','Filters','',1),(123024,'117432','deals','block-123022-2','Listing','',5),(123025,'117433','deals','block-123022-2','catalog\\Image','',1),(123026,'117434','deals','block-123022-2','BlockBox','',6),(123027,'117435','deals','block-123026','catalog\\CountsItems','',1),(123028,'117436','deals','block-123026-2','catalog\\Paging','',1),(123029,'117437','deals','block-123022-2','catalog\\ImageMapCategory','',3),(123030,'117438','deals','block-123022-2','Categories','',2),(123031,'117439','deals','block-123022-2','BlockBox','',4),(123032,'117440','deals','block-123031','catalog\\ListingLook','',1),(123033,'117441','deals','block-123031','catalog\\ItemsOnPage','',4),(123034,'117442','deals','block-123031','catalog\\CompareButton','',2),(123035,'117443','deals','block-123031','catalog\\Sorting','',3),(123036,'117444','deals','no-logged','BlockBox','',1),(123037,'117445','deals','block-123036','Communication\\NewTopic','',2),(123038,'117446','deals','block-123036','Html_box','',1),(123039,'117447','deals','no_filters','BlockBox','catalog-content',1),(123040,'117448','deals','block-123039','BlockBox','',4),(123041,'117449','deals','block-123040','catalog\\CountsItems','',1),(123042,'117450','deals','block-123040-2','catalog\\Paging','',1),(123043,'117451','deals','block-123039','Listing','',3),(123044,'117452','deals','block-123039','catalog\\Title','',1),(123045,'117453','deals','block-123039','catalog\\B2bAddButton','',5),(123046,'117454','deals','block-123039','BlockBox','catalog-features',2),(123047,'117455','deals','block-123046','BlockBox','',2),(123048,'117456','deals','block-123047','HeaderStock','',5),(123049,'117457','deals','block-123047','catalog\\ListingLook','',1),(123050,'117458','deals','block-123047','catalog\\CompareButton','',2),(123051,'117459','deals','block-123047','catalog\\ItemsOnPage','',4),(123052,'117460','deals','block-123047','catalog\\Sorting','',3),(123053,'117461','deals','block-123046','catalog\\Image','',1),(123054,'1645207289.476','deals','no_filters','Compare','',2),(123138,'117507','deals','order_pay','BlockBox','',1),(123139,'117508','deals','block-123138','BlockBox','',1),(123140,'117509','deals','block-123139','WidgetsAria','',1),(123160,'117510','deals','block-123139-2','account\\OrderProducts','',4),(123161,'117511','deals','block-123139-2','BlockBox','',2),(123162,'117512','deals','block-123161','BlockBox','',1),(123163,'117513','deals','block-123162','Html_box','',1),(123164,'117514','deals','block-123162','account\\OrderData','',2),(123165,'117515','deals','block-123161','BlockBox','',4),(123166,'117516','deals','block-123165','account\\OrderData','',2),(123167,'117517','deals','block-123165','Html_box','',1),(123168,'117518','deals','block-123161-2','BlockBox','',1),(123169,'117519','deals','block-123168','Html_box','',1),(123170,'117520','deals','block-123168','account\\OrderData','',2),(123171,'117521','deals','block-123161-2','BlockBox','',2),(123172,'117522','deals','block-123171','account\\OrderData','',2),(123173,'117523','deals','block-123171','Html_box','',1),(123174,'117524','deals','block-123161-3','BlockBox','',2),(123175,'117525','deals','block-123174','Html_box','',1),(123176,'117526','deals','block-123174','account\\OrderData','',2),(123177,'117527','deals','block-123161-3','BlockBox','',1),(123178,'117528','deals','block-123177','account\\OrderData','',2),(123179,'117529','deals','block-123177','Html_box','',1),(123180,'117530','deals','block-123139-2','UpdateAndPay\\PayForm','',6),(123181,'117531','deals','block-123139-2','Html_box','',3),(123182,'117532','deals','block-123139-2','account\\OrderHeading','',1),(123183,'117533','deals','block-123139-2','account\\OrderSubTotals','',5),(123184,'117534','deals','packingslip','invoice\\Container','',2),(123185,'117535','deals','block-123184','BlockBox','',2),(123186,'117536','deals','block-123185','Logo','',1),(123187,'117537','deals','block-123185-2','BlockBox','',3),(123188,'117538','deals','block-123187','Text','',2),(123189,'117539','deals','block-123187-2','invoice\\StoreEmail','',1),(123190,'117540','deals','block-123185-2','BlockBox','',2),(123191,'117541','deals','block-123190','Text','',2),(123192,'117542','deals','block-123190-2','invoice\\StorePhone','',1),(123193,'117543','deals','block-123185-2','BlockBox','',1),(123194,'117544','deals','block-123193','invoice\\StoreAddress','',1),(123195,'117545','deals','block-123185-2','BlockBox','',4),(123196,'117546','deals','block-123195','Text','',2),(123197,'117547','deals','block-123195-2','invoice\\StoreSite','',1),(123198,'117548','deals','block-123184','packingslip\\Products','',5),(123199,'117549','deals','block-123184','BlockBox','',6),(123200,'117550','deals','block-123199','invoice\\StoreAddress','',2),(123201,'117551','deals','block-123199','Text','',1),(123202,'117552','deals','block-123184','BlockBox','',3),(123203,'117553','deals','block-123202','BlockBox','',2),(123204,'117554','deals','block-123203','BlockBox','',1),(123205,'117555','deals','block-123204','invoice\\ShippingAddress','',2),(123206,'117556','deals','block-123204','Text','',1),(123207,'117557','deals','block-123203-2','BlockBox','',1),(123208,'117558','deals','block-123207','Text','',1),(123209,'117559','deals','block-123207','invoice\\CustomerName','',2),(123210,'117560','deals','block-123207','invoice\\CustomerEmail','',6),(123211,'117561','deals','block-123207','Text','',3),(123212,'117562','deals','block-123207','invoice\\CustomerPhone','',4),(123213,'117563','deals','block-123207','Text','',5),(123214,'117564','deals','block-123202','BlockBox','',3),(123215,'117565','deals','block-123214','BlockBox','',1),(123216,'117566','deals','block-123215','invoice\\ShippingMethod','',2),(123217,'117567','deals','block-123215','Text','',1),(123218,'117568','deals','block-123214-2','BlockBox','',1),(123219,'117569','deals','block-123218','invoice\\ShippingMethod','',2),(123220,'117570','deals','block-123218','Text','',1),(123221,'117571','deals','block-123202-2','invoice\\AddressQrcode','',1),(123222,'1639660991','deals','block-123184','Neighbour\\PackingSlipInfo','',1),(123223,'1639661081','deals','block-123184','Neighbour\\PackingSlipInfo','',4),(123224,'117572','deals','password_forgotten','BlockBox','',1),(123225,'117573','deals','block-123224','BlockBox','',2),(123226,'1638807246','deals','block-123225','Html_box','',1),(123227,'117574','deals','block-123225-2','Html_box','',1),(123228,'117575','deals','block-123225-2','login\\PasswordForgotten','',2),(123229,'117576','deals','block-123224','Html_box','',1),(123230,'117577','deals','pdf','invoice\\Container','',1),(123231,'117578','deals','block-123230','BlockBox','',1),(123232,'117579','deals','block-123231','BlockBox','',1),(123233,'117580','deals','block-123232','BlockBox','',1),(123234,'117581','deals','block-123233','pdf\\ProductElement','',1),(123235,'117582','deals','block-123232','BlockBox','',2),(123236,'117583','deals','block-123235','pdf\\ProductElement','',1),(123237,'117584','deals','block-123235-2','pdf\\ProductElement','',2),(123238,'117585','deals','block-123235-2','pdf\\ProductElement','',1),(123239,'117586','deals','block-123231-2','BlockBox','',1),(123240,'117587','deals','block-123239','BlockBox','',2),(123241,'117588','deals','block-123240','pdf\\ProductElement','',1),(123242,'117589','deals','block-123240-2','pdf\\ProductElement','',2),(123243,'117590','deals','block-123240-2','pdf\\ProductElement','',1),(123244,'117591','deals','block-123239','BlockBox','',1),(123245,'117592','deals','block-123244','pdf\\ProductElement','',1),(123246,'117593','deals','pdf_category','pdf\\CategoryName','',2),(123247,'117594','deals','pdf_category','pdf\\CategoryImage','',1),(123248,'117595','deals','pdf_cover','invoice\\Container','',1),(123249,'117596','deals','block-123248','Logo','',1),(123250,'117597','deals','block-123248','Text','',3),(123251,'117598','deals','pdf_footer','BlockBox','',1),(123252,'117599','deals','block-123251-2','pdf\\PageNumber','',1),(123253,'117600','deals','pdf_header','pdf\\CategoryName','',1),(123254,'117601','deals','personal_catalog','BlockBox','',1),(123255,'117602','deals','block-123254','BlockBox','',1),(123256,'117603','deals','block-123255','WidgetsAria','',1),(123276,'117604','deals','block-123255-2','Html_box','',1),(123277,'117606','deals','block-123255-2','account\\PersonalCatalog','',2),(123278,'117607','deals','points_earnt_history','BlockBox','',1),(123279,'117608','deals','block-123278','Html_box','',1),(123280,'117609','deals','block-123278','account\\PointsEarntHistory','',2),(123281,'117610','deals','posts','BlockBox','',1),(123282,'117611','deals','block-123281','Breadcrumb','',2),(123283,'117612','deals','block-123281','Html_box','',1),(123284,'117613','deals','block-123281','Communication\\Post','',3),(123285,'1683114469.26259','deals','product','BlockBox','',2),(123286,'1683114469.295895','deals','block-123285','product\\Name','',1),(123287,'1683114469.29722','deals','block-123285','BlockBox','product-content',2),(123288,'1683114469.299773','deals','block-123287','product\\Images','',2),(123289,'1683114469.301198','deals','block-123287','Promotions\\widgets\\PromotionIcons','',1),(123290,'1683114469.302537','deals','block-123287-2','product\\Groups','',3),(123291,'1683114469.30314','deals','block-123287-2','BlockBox','',1),(123292,'1683114469.304286','deals','block-123291','product\\Model','',2),(123293,'1683114469.304862','deals','block-123291','product\\Rating','',1),(123294,'1683114469.306253','deals','block-123291-2','product\\Stock','',2),(123295,'1683114469.307492','deals','block-123291-2','product\\PriceFrom','',1),(123296,'1683114469.3081','deals','block-123287-2','BlockBox','',4),(123297,'1683114469.309625','deals','block-123296','product\\QuantityDiscounts','',4),(123298,'1683114469.310518','deals','block-123296','Html_box','',5),(123299,'1683114469.31285','deals','block-123296','SupportSystem\\ProductFaq','',1),(123300,'1683114469.313585','deals','block-123296','product\\Properties','',6),(123301,'1683114469.319743','deals','block-123296','Promotions\\widgets\\PromotionIconsDesc','',7),(123302,'1683114469.328177','deals','block-123296','product\\Inventory','',3),(123303,'1683114469.329314','deals','block-123296','product\\Groups','',2),(123304,'1683114469.33265','deals','block-123296-2','BlockBox','',1),(123305,'1683114469.333690','deals','block-123304','product\\Price','',1),(123306,'1683114469.334771','deals','block-123304','product\\Quantity','',2),(123307,'1683114469.34343','deals','block-123304','product\\Buttons','',3),(123308,'1683114469.347391','deals','block-123304','product\\PersonalCatalogButton','',4),(123309,'1683114469.351242','deals','block-123287-2','product\\DescriptionShort','',2),(123310,'1683114493.817723','deals','product','BlockBox','',3),(123311,'1683114493.851867','deals','block-123310','product\\Description','',2),(123312,'1683114493.853236','deals','block-123310','product\\Reviews','',6),(123313,'1683114493.85674','deals','block-123310','BlockBox','product-bottom',5),(123314,'1683114493.857344','deals','block-123313','ViewedProducts','4',1),(123315,'1683114493.861475','deals','block-123313','Html_box','',0),(123316,'1683114493.86940','deals','block-123310','BlockBox','',4),(123317,'1683114493.870678','deals','block-123316','product\\Bundle','',1),(123318,'1683114493.875988','deals','block-123316','product\\InBundles','',2),(123319,'117655','deals','product-bottom','product\\Properties','',1),(123320,'117656','deals','product-tabs','product\\Reviews','',2),(123321,'117657','deals','product-tabs','product\\Description','',1),(123322,'117658','deals','product-top-left','product\\Images','',1),(123323,'117659','deals','product-top-right','product\\Price','',2),(123324,'117660','deals','product-top-right','product\\Quantity','',5),(123325,'117661','deals','product-top-right','product\\Quantity','',6),(123326,'117662','deals','product-top-right','product\\Attributes','',3),(123327,'117663','deals','product-top-right','product\\Name','',1),(123328,'117664','deals','product-top-right','product\\Buttons','',6),(123329,'120919.000001','deals','productListing','BlockBox','listing-item',2),(123330,'120895','deals','block-123329','productListing\\viewButton','',14),(123331,'117667','deals','block-123329','productListing\\bonusPoints','',2),(123332,'117668','deals','block-123329','productListing\\description','',10),(123333,'117670.000001','deals','block-123329','productListing\\rating','',11),(123334,'117671.000001','deals','block-123329','productListing\\image','',1),(123335,'117673.000001','deals','block-123329','productListing\\price','',5),(123336,'117675.000001','deals','block-123329','productListing\\name','',4),(123337,'117676.000001','deals','block-123329','productListing\\stock','',3),(123338,'120863','deals','block-123329','productListing\\ratingCounts','',12),(123339,'1639645717','deals','block-123329','productListing\\productGroup','',13),(123341,'1641901973','deals','block-123329','productListing\\compare','',16),(123342,'1641901997','deals','block-123329','productListing\\personalCatalog','',15),(123343,'1641903084','deals','block-123329','productListing\\model','',6),(123344,'1641903101','deals','block-123329','productListing\\properties','',9),(123346,'117678','deals','products','BlockBox','catalog-content',2),(123347,'117683','deals','block-123346','BlockBox','catalog-features',5),(123348,'117685','deals','block-123347','catalog\\ListingLook','',1),(123349,'117687','deals','block-123347','catalog\\CompareButton','',2),(123350,'117691','deals','block-123346','Listing','',6),(123351,'120912','deals','block-123346','BlockBox','',7),(123352,'120913','deals','block-123351','catalog\\CountsItems','',1),(123353,'120914','deals','block-123351-2','catalog\\Paging','',1),(123354,'117692','deals','block-123346','catalog\\Title','',2),(123355,'117693','deals','block-123346','BlockBox','',3),(123356,'117694','deals','block-123355','catalog\\Image','',2),(123357,'1641894402','deals','block-123346','BlockBox','',4),(123358,'1641809968.0001','deals','block-123357','BlockBox','',4),(123359,'116286.000001','deals','block-123358','catalog\\Sorting','',2),(123360,'1641810239.0001','deals','block-123358','Filters','',1),(123361,'121018','deals','products','Compare','',3),(123362,'117695','deals','products-list','packingslip\\AllProductsList','',2),(123363,'117696','deals','promotions','BlockBox','info-content',1),(123364,'117697','deals','block-123363','promotions\\PromoList','',2),(123365,'117698','deals','block-123363','Html_box','',1),(123366,'117699','deals','purchase','invoice\\Container','',1),(123367,'117700','deals','block-123366','invoice\\Products','',3),(123368,'117701','deals','block-123366','BlockBox','',5),(123369,'117702','deals','block-123368','Text','',1),(123370,'117703','deals','block-123368','invoice\\StoreAddress','',8),(123371,'117704','deals','block-123368-2','Text','',2),(123372,'117705','deals','block-123368-2','Logo','',1),(123373,'117706','deals','block-123368-3','BlockBox','',3),(123374,'117707','deals','block-123373','Text','',1),(123375,'117708','deals','block-123373-2','invoice\\StoreEmail','',1),(123376,'117709','deals','block-123368-3','Text','',1),(123377,'117710','deals','block-123368-3','BlockBox','',2),(123378,'117711','deals','block-123377','Text','',1),(123379,'117712','deals','block-123377-2','invoice\\StorePhone','',1),(123380,'117713','deals','block-123366','BlockBox','',1),(123381,'117714','deals','block-123380','Logo','',1),(123382,'117715','deals','block-123380-2','BlockBox','',2),(123383,'117716','deals','block-123382','Text','',1),(123384,'117717','deals','block-123382-2','invoice\\StorePhone','',1),(123385,'117718','deals','block-123380-2','BlockBox','',4),(123386,'117719','deals','block-123385','Text','',1),(123387,'117720','deals','block-123385-2','invoice\\StoreSite','',1),(123388,'117721','deals','block-123380-2','BlockBox','',1),(123389,'117722','deals','block-123388','invoice\\StoreAddress','',1),(123390,'117723','deals','block-123380-2','BlockBox','',3),(123391,'117724','deals','block-123390','Text','',1),(123392,'117725','deals','block-123390-2','invoice\\StoreEmail','',1),(123393,'117726','deals','block-123366','BlockBox','',2),(123394,'117727','deals','block-123393','BlockBox','',7),(123395,'117728','deals','block-123394','BlockBox','',1),(123396,'117729','deals','block-123395','invoice\\BillingAddress','',2),(123397,'117730','deals','block-123395','Text','',1),(123398,'117731','deals','block-123394-2','BlockBox','',1),(123399,'117732','deals','block-123398','invoice\\CustomerEmail','',6),(123400,'117733','deals','block-123398','Text','',5),(123401,'117734','deals','block-123398','invoice\\CustomerPhone','',4),(123402,'117735','deals','block-123398','invoice\\CustomerName','',2),(123403,'117736','deals','block-123398','Text','',3),(123404,'117737','deals','block-123398','Text','',1),(123405,'117738','deals','block-123393-2','invoice\\OrderId','',1),(123406,'117739','deals','block-123393-2','Text','',2),(123407,'117740','deals','block-123393-2','invoice\\PaymentDate','',3),(123408,'117741','deals','block-123366','BlockBox','',4),(123409,'117742','deals','block-123408','BlockBox','',1),(123410,'117743','deals','block-123409','invoice\\ShippingAddress','',2),(123411,'117744','deals','block-123409','Text','',1),(123415,'117745','deals','quotations','BlockBox','',1),(123416,'117746','deals','block-123415','BlockBox','',1),(123417,'117747','deals','block-123416','WidgetsAria','',1),(123437,'117748','deals','block-123416-2','Html_box','',1),(123438,'117749','deals','block-123416-2','Quotations\\QuotationsHistory','',2),(123439,'117750','deals','quotation_info','BlockBox','',1),(123440,'117751','deals','block-123439','BlockBox','',1),(123441,'117752','deals','block-123440','WidgetsAria','',1),(123461,'117753','deals','block-123440-2','BlockBox','',5),(123462,'117754','deals','block-123461','BlockBox','',1),(123463,'117755','deals','block-123462','Quotations\\QuotationData','',2),(123464,'117756','deals','block-123462','Html_box','',1),(123465,'117757','deals','block-123461','BlockBox','',4),(123466,'117758','deals','block-123465','Html_box','',1),(123467,'117759','deals','block-123465','Quotations\\QuotationData','',2),(123468,'117760','deals','block-123461-2','BlockBox','',2),(123469,'117761','deals','block-123468','Html_box','',1),(123470,'117762','deals','block-123468','Quotations\\QuotationData','',2),(123471,'117763','deals','block-123461-2','BlockBox','',1),(123472,'117764','deals','block-123471','Html_box','',1),(123473,'117765','deals','block-123471','Quotations\\QuotationData','',2),(123474,'117766','deals','block-123461-3','BlockBox','',1),(123475,'117767','deals','block-123474','Quotations\\QuotationData','',2),(123476,'117768','deals','block-123474','Html_box','',1),(123477,'117769','deals','block-123461-3','BlockBox','',2),(123478,'117770','deals','block-123477','Quotations\\QuotationData','',2),(123479,'117771','deals','block-123477','Html_box','',1),(123480,'117772','deals','block-123440-2','Html_box','',6),(123481,'117773','deals','block-123440-2','Quotations\\QuotationHistory','',10),(123482,'117774','deals','block-123440-2','Html_box','',9),(123483,'117775','deals','block-123440-2','Quotations\\QuotationProducts','',7),(123484,'117776','deals','block-123440-2','Quotations\\QuotationSubTotal','',8),(123485,'117777','deals','block-123440-2','BlockBox','',12),(123486,'117778','deals','block-123485','account\\AccountLink','',1),(123487,'117779','deals','block-123440-2','Html_box','',4),(123488,'117780','deals','quote','BlockBox','',1),(123489,'117781','deals','block-123488','cart\\CartTabs','',1),(123490,'117782','deals','block-123489','BlockBox','',1),(123491,'117783','deals','block-123490','quote\\Products','',1),(123492,'117784','deals','block-123490-2','BlockBox','',1),(123493,'117785','deals','block-123492','BlockBox','',1),(123494,'117786','deals','block-123493','quote\\CheckoutBtn','',2),(123495,'117787','deals','block-123489','Quotations\\QuotationSubTotal','',2),(123520,'117793','deals','reviews','BlockBox','info-content',1),(123521,'117794','deals','block-123520','reviews\\Heading','',1),(123522,'117795','deals','block-123520','reviews\\Content','',2),(123523,'117796','deals','rma_document','invoice\\Container','',1),(123524,'117797','deals','block-123523','BlockBox','',1),(123525,'117798','deals','block-123524','BlockBox','',1),(123526,'117799','deals','block-123525','BlockBox','',2),(123527,'117800','deals','block-123526','Html_box','',1),(123528,'117801','deals','block-123526-2','Html_box','',1),(123529,'117802','deals','block-123525','BlockBox','',5),(123530,'117803','deals','block-123529','Html_box','',1),(123531,'117804','deals','block-123529-2','Html_box','',1),(123532,'117805','deals','block-123525','BlockBox','',4),(123533,'117806','deals','block-123532','Html_box','',1),(123534,'117807','deals','block-123532-2','Html_box','',1),(123535,'117808','deals','block-123525','BlockBox','',3),(123536,'117809','deals','block-123535','Html_box','',1),(123537,'117810','deals','block-123535-2','Html_box','',1),(123538,'117811','deals','block-123525','BlockBox','',1),(123539,'117812','deals','block-123538','Html_box','',1),(123540,'117813','deals','block-123538','Html_box','',2),(123541,'117814','deals','block-123524-2','BlockBox','',1),(123542,'117815','deals','block-123541','Html_box','',2),(123543,'117816','deals','block-123541','Logo','',1),(123544,'117817','deals','block-123524-2','BlockBox','',2),(123545,'117818','deals','block-123544','BlockBox','',5),(123546,'117819','deals','block-123545','BlockBox','',1),(123547,'117820','deals','block-123546','Html_box','',1),(123548,'117821','deals','block-123546-2','Rma\\DocumentData','',1),(123549,'117822','deals','block-123545-2','BlockBox','',1),(123550,'117823','deals','block-123549','Html_box','',1),(123551,'117824','deals','block-123549-2','Rma\\DocumentData','',1),(123552,'117825','deals','block-123544','BlockBox','',4),(123553,'117826','deals','block-123552','BlockBox','',1),(123554,'117827','deals','block-123553','Html_box','',1),(123555,'117828','deals','block-123553-2','Rma\\DocumentData','',1),(123556,'117829','deals','block-123552-2','BlockBox','',1),(123557,'117830','deals','block-123556','Html_box','',1),(123558,'117831','deals','block-123556-2','Rma\\DocumentData','',1),(123559,'117832','deals','block-123544','BlockBox','',3),(123560,'117833','deals','block-123559','BlockBox','',1),(123561,'117834','deals','block-123560','Html_box','',1),(123562,'117835','deals','block-123560-2','Rma\\DocumentData','',1),(123563,'117836','deals','block-123559-2','BlockBox','',1),(123564,'117837','deals','block-123563','Html_box','',1),(123565,'117838','deals','block-123563-2','Rma\\DocumentData','',1),(123566,'117839','deals','block-123544','BlockBox','',2),(123567,'117840','deals','block-123566','Html_box','',1),(123568,'117841','deals','block-123566-2','Rma\\DocumentData','',1),(123569,'117842','deals','block-123544','BlockBox','',1),(123570,'117843','deals','block-123569','BlockBox','',1),(123571,'117844','deals','block-123570','Html_box','',1),(123572,'117845','deals','block-123570-2','Rma\\DocumentData','',1),(123573,'117846','deals','block-123569-2','BlockBox','',1),(123574,'117847','deals','block-123573','Html_box','',1),(123575,'117848','deals','block-123573-2','Rma\\DocumentData','',1),(123576,'117849','deals','block-123524-2','BlockBox','',3),(123577,'117850','deals','block-123576','BlockBox','',1),(123578,'117851','deals','block-123577','Html_box','',1),(123579,'117852','deals','block-123577-2','Rma\\DocumentData','',1),(123580,'117853','deals','block-123576-2','BlockBox','',1),(123581,'117854','deals','block-123580','Html_box','',1),(123582,'117855','deals','block-123580-2','Rma\\DocumentData','',1),(123583,'117856','deals','block-123523','BlockBox','',2),(123584,'117857','deals','block-123583','Html_box','',1),(123585,'117858','deals','block-123583','Rma\\Products','',2),(123586,'117859','deals','block-123523','BlockBox','',3),(123587,'117860','deals','block-123586','BlockBox','',1),(123588,'117861','deals','block-123587','BlockBox','',1),(123589,'117862','deals','block-123588','BlockBox','',5),(123590,'117863','deals','block-123589','Html_box','',1),(123591,'117864','deals','block-123589-2','invoice\\StoreAddress','',2),(123592,'117865','deals','block-123589-2','Html_box','',1),(123593,'117866','deals','block-123588','BlockBox','',4),(123594,'117867','deals','block-123593','Html_box','',1),(123595,'117868','deals','block-123593-2','Html_box','',1),(123596,'117869','deals','block-123588','BlockBox','',2),(123597,'117870','deals','block-123596','Html_box','',1),(123598,'117871','deals','block-123596-2','Html_box','',1),(123599,'117872','deals','block-123588','BlockBox','',1),(123600,'117873','deals','block-123599','Html_box','',1),(123601,'117874','deals','block-123588','BlockBox','',3),(123602,'117875','deals','block-123601','Html_box','',1),(123603,'117876','deals','block-123601-2','Html_box','',1),(123604,'117877','deals','block-123588','BlockBox','',6),(123605,'117878','deals','block-123604','Html_box','',1),(123606,'117879','deals','block-123587-2','BlockBox','',1),(123607,'117880','deals','block-123606','BlockBox','',1),(123608,'117881','deals','block-123607','BlockBox','',1),(123609,'117882','deals','block-123608','Rma\\DocumentData','',2),(123610,'117883','deals','block-123608-3','BlockBox','',1),(123611,'117884','deals','block-123610','Html_box','',1),(123612,'117885','deals','block-123610-2','Rma\\DocumentData','',1),(123613,'117886','deals','block-123607','BlockBox','',2),(123614,'117887','deals','block-123613-2','invoice\\StoreAddress','',1),(123615,'117888','deals','block-123587-2','BlockBox','',2),(123616,'117889','deals','block-123615','Html_box','',1),(123617,'117890','deals','block-123615','Html_box','',2),(123618,'117891','deals','block-123615','Html_box','',3),(123619,'117892','deals','block-123615','Html_box','',4),(123620,'117893','deals','block-123615','Html_box','',5),(123621,'117894','deals','block-123587-2','BlockBox','',4),(123622,'117895','deals','block-123621','Html_box','',1),(123623,'117896','deals','block-123621-2','Html_box','',1),(123624,'117897','deals','block-123621-3','BlockBox','',1),(123625,'117898','deals','block-123624','Html_box','',1),(123626,'117899','deals','block-123624-2','Html_box','',1),(123627,'117900','deals','block-123587-2','BlockBox','',3),(123628,'117901','deals','block-123627','Html_box','',1),(123629,'117902','deals','block-123627-2','Html_box','',1),(123630,'117903','deals','block-123627-3','BlockBox','',1),(123631,'117904','deals','block-123630','Html_box','',1),(123632,'117905','deals','block-123630-2','Html_box','',1),(123633,'117906.000001','deals','rows','BlockBox','listing-item',1),(123634,'117907.000001','deals','block-123633','BlockBox','',2),(123635,'117908.000001','deals','block-123634','BlockBox','',2),(123636,'117909.000001','deals','block-123635','productListing\\bonusPoints','',2),(123637,'117910.000001','deals','block-123635','productListing\\image','',1),(123638,'117914.000001','deals','block-123635-2','productListing\\name','',1),(123639,'117915.000001','deals','block-123635-2','productListing\\description','',2),(123640,'117916.000001','deals','block-123635-2','productListing\\model','',4),(123641,'117917.000001','deals','block-123635-2','productListing\\attributes','',5),(123642,'120922.000001','deals','block-123635-2','productListing\\properties','',3),(123643,'1639146806','deals','block-123635-2','productListing\\productGroup','',6),(123644,'117918.000001','deals','block-123634-2','BlockBox','',1),(123645,'117911.000001','deals','block-123644','BlockBox','',3),(123646,'117912.000001','deals','block-123645','productListing\\rating','',1),(123647,'117913.000001','deals','block-123645','productListing\\ratingCounts','',2),(123648,'117919.000001','deals','block-123644','productListing\\qtyInput','',4),(123649,'117920.000001','deals','block-123644','productListing\\price','',2),(123650,'117922.000001','deals','block-123644','productListing\\buyButton','',5),(123651,'117924.000001','deals','block-123644','productListing\\stock','',1),(123652,'120924.000001','deals','block-123644','BlockBox','',8),(123653,'120925.000001','deals','block-123652','productListing\\compare','',3),(123654,'120926.000001','deals','block-123652','productListing\\personalCatalog','',2),(123655,'120927.000001','deals','block-123652','productListing\\viewButton','',1),(123656,'117925','deals','sample','BlockBox','',1),(123657,'117926','deals','block-123656','cart\\CartTabs','',1),(123658,'117927','deals','block-123657','BlockBox','',1),(123659,'117928','deals','block-123658','sample\\Products','',1),(123660,'117929','deals','block-123658-2','BlockBox','',1),(123661,'117930','deals','block-123660','BlockBox','',1),(123662,'117931','deals','block-123661','sample\\CheckoutBtn','',1),(123663,'117932','deals','samples','BlockBox','',1),(123664,'117933','deals','block-123663','BlockBox','',1),(123665,'117934','deals','block-123664','WidgetsAria','',1),(123685,'117935','deals','block-123664-2','Html_box','',1),(123686,'117936','deals','block-123664-2','Samples\\SamplesHistory','',2),(123687,'117937','deals','sample_info','BlockBox','',1),(123688,'117938','deals','block-123687','BlockBox','',1),(123689,'117939','deals','block-123688','WidgetsAria','',1),(123709,'117940','deals','block-123688-2','Html_box','',1),(123710,'117941','deals','block-123688-2','BlockBox','',8),(123711,'117942','deals','block-123710','account\\AccountLink','',1),(123712,'117943','deals','block-123688-2','Samples\\SampleHistory','',7),(123713,'117944','deals','block-123688-2','Html_box','',3),(123714,'117945','deals','block-123688-2','Samples\\SampleSubTotal','',5),(123715,'117946','deals','block-123688-2','Samples\\SampleProducts','',4),(123716,'117947','deals','block-123688-2','Html_box','',6),(123717,'117948','deals','block-123688-2','BlockBox','',2),(123718,'117949','deals','block-123717','BlockBox','',4),(123719,'117950','deals','block-123718','Html_box','',1),(123720,'117951','deals','block-123718','Samples\\SampleData','',2),(123721,'117952','deals','block-123717','BlockBox','',1),(123722,'117953','deals','block-123721','Samples\\SampleData','',2),(123723,'117954','deals','block-123721','Html_box','',1),(123724,'117955','deals','block-123717-2','BlockBox','',2),(123725,'117956','deals','block-123724','Samples\\SampleData','',2),(123726,'117957','deals','block-123724','Html_box','',1),(123727,'117958','deals','block-123717-2','BlockBox','',1),(123728,'117959','deals','block-123727','Samples\\SampleData','',2),(123729,'117960','deals','block-123727','Html_box','',1),(123730,'117961','deals','block-123717-3','BlockBox','',2),(123731,'117962','deals','block-123730','Samples\\SampleData','',2),(123732,'117963','deals','block-123730','Html_box','',1),(123733,'117964','deals','block-123717-3','BlockBox','',1),(123734,'117965','deals','block-123733','Samples\\SampleData','',2),(123735,'117966','deals','block-123733','Html_box','',1),(123736,'117967','deals','sitemap','BlockBox','info-content',1),(123737,'117968','deals','block-123736','Html_box','',1),(123738,'117969','deals','block-123736','BlockBox','',2),(123739,'117970','deals','block-123738','Html_box','',1),(123740,'117971','deals','block-123738','Html_box','',5),(123741,'117972','deals','block-123738','Html_box','',3),(123742,'117973','deals','block-123738','sitemap\\InfoPages','',2),(123743,'117974','deals','block-123738','sitemap\\Categories','',4),(123744,'117975','deals','block-123738','Menu','Account box',6),(123745,'117976','deals','block-123738-2','sitemap\\DeliveryLocation','',2),(123746,'117977','deals','block-123738-2','Html_box','',1),(123747,'120878','deals','social','SocialLinks','',1),(123748,'117978','deals','subscribe','BlockBox','',1),(123749,'117979','deals','block-123748','Html_box','',3),(123750,'117980','deals','block-123748','subscribers\\UnsubscribeForm','',4),(123751,'117981','deals','block-123748','Html_box','',1),(123752,'117982','deals','block-123748','subscribers\\SubscribeForm','',2),(123753,'117983','deals','subscribed','BlockBox','',1),(123754,'117984','deals','block-123753','Html_box','',1),(123755,'117985','deals','subscription','BlockBox','',2),(123756,'117986','deals','block-123755','BlockBox','',1),(123757,'117987','deals','block-123756','WidgetsAria','',1),(123777,'117988','deals','block-123756-2','Html_box','',2),(123778,'117989','deals','block-123756-2','Html_box','',3),(123779,'117990','deals','block-123756-2','account\\Subscription','',4),(123780,'1694163942.487488','deals','success','BlockBox','',1),(123781,'1694163942.571966','deals','block-123780','BlockBox','',2),(123782,'1694163942.574743','deals','block-123781','BlockBox','',3),(123783,'1694163942.57618','deals','block-123782','BlockBox','',2),(123784,'1694163942.578938','deals','block-123783','BlockBox','',1),(123785,'1694163942.58174','deals','block-123784','order\\ShippingMethod','',6),(123786,'1694163942.582929','deals','block-123784','order\\DeliveryAddress','',3),(123787,'1694163942.58424','deals','block-123784','Html_box','',7),(123788,'1694163942.58813','deals','block-123784','Html_box','',5),(123789,'1694163942.590','deals','block-123784','Html_box','',1),(123790,'1694163942.591588','deals','block-123784','checkout\\ContactConfirm','',9),(123791,'1694163942.592641','deals','block-123784','Html_box','',2),(123792,'1694163942.594491','deals','block-123783-2','BlockBox','',1),(123793,'1694163942.59612','deals','block-123792','order\\PaymentMethod','',6),(123794,'1694163942.59754','deals','block-123792','order\\BillingAddress','',3),(123795,'1694163942.598173','deals','block-123792','Html_box','',5),(123796,'1694163942.599378','deals','block-123792','Html_box','',1),(123797,'1694163942.600432','deals','block-123792','Html_box','',2),(123798,'1694163942.601780','deals','block-123782','Html_box','',1),(123799,'1694163942.604213','deals','block-123781-2','BlockBox','',1),(123800,'1694163942.605131','deals','block-123799','success\\PrintBtn','',3),(123801,'1694163942.606115','deals','block-123799','success\\ContinueBtn','',4),(123802,'1694163942.607111','deals','block-123799','order\\Products','',1),(123803,'1694163942.608286','deals','block-123799','order\\Totals','',2),(123804,'1694163942.609249','deals','block-123780','BlockBox','',1),(123805,'1694163942.610273','deals','block-123804','Html_box','',2),(123806,'1694163942.611982','deals','block-123804','order\\OrderNumber','',1),(123807,'117997','deals','success_q','BlockBox','',1),(123808,'117998','deals','block-123807','BlockBox','',1),(123809,'117999','deals','block-123808','BlockBox','',2),(123810,'118000','deals','block-123809','success\\ContinueBtn','',2),(123811,'118001','deals','block-123809','success\\PrintBtn','',1),(123812,'118002','deals','block-123808','Html_box','',1),(123817,'118007','deals','ticket','invoice\\Container','',1),(123818,'118008','deals','block-123817','BlockBox','',4),(123819,'118009','deals','block-123818','BlockBox','',1),(123820,'118010','deals','block-123819','invoice\\ShippingAddress','',2),(123821,'118011','deals','block-123819','Text','',1),(123822,'118012','deals','block-123818-2','BlockBox','',1),(123823,'118013','deals','block-123822','invoice\\Totals','',1),(123824,'118014','deals','block-123817','BlockBox','',5),(123825,'118015','deals','block-123824','Text','',1),(123826,'118016','deals','block-123824','invoice\\StoreAddress','',8),(123827,'118018','deals','block-123824-2','Text','',2),(123828,'118019','deals','block-123824-3','Text','',1),(123829,'118020','deals','block-123824-3','BlockBox','',3),(123830,'118021','deals','block-123829','Text','',1),(123831,'118022','deals','block-123829-2','invoice\\StoreEmail','',1),(123832,'118023','deals','block-123824-3','BlockBox','',2),(123833,'118024','deals','block-123832','Text','',1),(123834,'118025','deals','block-123832-2','invoice\\StorePhone','',1),(123835,'118026','deals','block-123817','invoice\\Products','',3),(123836,'118027','deals','block-123817','BlockBox','',1),(123837,'1643890423','deals','block-123836','Logo','',0),(123838,'118028','deals','block-123836-2','BlockBox','',3),(123839,'118029','deals','block-123838','Text','',1),(123840,'118030','deals','block-123838-2','invoice\\StoreEmail','',1),(123841,'118031','deals','block-123836-2','BlockBox','',4),(123842,'118032','deals','block-123841','Text','',1),(123843,'118033','deals','block-123841-2','invoice\\StoreSite','',1),(123844,'118034','deals','block-123836-2','BlockBox','',1),(123845,'118035','deals','block-123844','invoice\\StoreAddress','',1),(123846,'118036','deals','block-123836-2','BlockBox','',2),(123847,'118037','deals','block-123846','Text','',1),(123848,'118038','deals','block-123846-2','invoice\\StorePhone','',1),(123849,'118039','deals','block-123817','BlockBox','',2),(123850,'118040','deals','block-123849','BlockBox','',8),(123851,'118041','deals','block-123850','BlockBox','',1),(123852,'118042','deals','block-123851','Text','',1),(123853,'118043','deals','block-123851','invoice\\ShippingMethod','',2),(123854,'118044','deals','block-123850-2','BlockBox','',1),(123855,'118045','deals','block-123854','Text','',1),(123856,'118046','deals','block-123854','invoice\\ShippingMethod','',2),(123857,'118047','deals','block-123849','BlockBox','',7),(123858,'118048','deals','block-123857','BlockBox','',1),(123859,'118049','deals','block-123858','invoice\\BillingAddress','',2),(123860,'118050','deals','block-123858','Text','',1),(123861,'118051','deals','block-123857-2','BlockBox','',1),(123862,'118052','deals','block-123861','invoice\\CustomerName','',2),(123863,'118053','deals','block-123861','Text','',3),(123864,'118054','deals','block-123861','invoice\\CustomerEmail','',6),(123865,'118055','deals','block-123861','invoice\\CustomerPhone','',4),(123866,'118056','deals','block-123861','Text','',5),(123867,'118057','deals','block-123861','Text','',1),(123868,'118058','deals','block-123849-2','invoice\\PaymentDate','',3),(123869,'118059','deals','block-123849-2','Text','',2),(123870,'118060','deals','block-123849-2','Text','',4),(123871,'118061','deals','block-123849-2','invoice\\OrderId','',1),(123872,'118062','deals','block-123849-2','invoice\\PaymentMethod','',5),(123873,'118063','deals','block-123849-2','invoice\\OrderBarcode','',6),(123874,'118094','deals','tracking_numbers','BlockBox','',1),(123875,'118095','deals','block-123874','Html_box','',1),(123876,'118096','deals','block-123874','account\\OrderTracking','',2),(123877,'118318','deals','unsubscribed','BlockBox','',1),(123878,'118319','deals','block-123877','Html_box','',1),(123879,'118320','deals','update-and-pay-order_confirmation','BlockBox','',1),(123880,'118321','deals','block-123879','BlockBox','',3),(123881,'118322','deals','block-123880','BlockBox','',1),(123882,'118323','deals','block-123881','BlockBox','',1),(123883,'118324','deals','block-123882','BlockBox','',1),(123884,'118325','deals','block-123883','order\\ShippingMethod','',5),(123885,'118326','deals','block-123883','Html_box','',2),(123886,'118327','deals','block-123883','Html_box','',4),(123887,'118328','deals','block-123883','Html_box','',1),(123888,'118329','deals','block-123883','order\\Telephone','',8),(123889,'118330','deals','block-123883','Html_box','',6),(123890,'118331','deals','block-123883','order\\Name','',7),(123891,'118332','deals','block-123883','order\\Email','',9),(123892,'118333','deals','block-123883','order\\DeliveryAddress','',3),(123893,'118334','deals','block-123882-2','BlockBox','',1),(123894,'118335','deals','block-123893','order\\BillingAddress','',3),(123895,'118336','deals','block-123893','UpdateAndPay\\PayConfirm','',5),(123896,'118337','deals','block-123893','Html_box','',1),(123897,'118338','deals','block-123893','Html_box','',2),(123898,'118339','deals','block-123893','Html_box','',4),(123899,'118340','deals','block-123881','BlockBox','',3),(123900,'118341','deals','block-123899','order\\Products','',2),(123901,'118342','deals','block-123899','Html_box','',1),(123902,'118343','deals','block-123880-2','BlockBox','',1),(123903,'118344','deals','block-123902','Html_box','',1),(123904,'118345','deals','block-123902','checkout\\ContinueBtn','',3),(123905,'118346','deals','block-123902','order\\Totals','',2),(123906,'118347','deals','block-123879','account\\OrderHeading','',1),(123907,'118348','deals','update-and-pay-order_pay','BlockBox','',1),(123908,'118349','deals','block-123907','BlockBox','',3),(123909,'118350','deals','block-123908','BlockBox','',1),(123910,'118351','deals','block-123909','BlockBox','',1),(123911,'118352','deals','block-123910','BlockBox','',1),(123912,'118353','deals','block-123911','order\\DeliveryAddress','',4),(123913,'118354','deals','block-123911','order\\Email','',10),(123914,'118355','deals','block-123911','order\\Name','',8),(123915,'118356','deals','block-123911','Html_box','',7),(123916,'118357','deals','block-123911','order\\Telephone','',9),(123917,'118358','deals','block-123911','Html_box','',5),(123918,'118359','deals','block-123911','order\\ShippingMethod','',6),(123919,'118360','deals','block-123911','Html_box','',2),(123920,'118361','deals','block-123911','Html_box','',3),(123921,'1639647774','deals','block-123911','DelayedDespatch\\OrderPay','',1),(123922,'118362','deals','block-123910-2','BlockBox','',1),(123923,'118363','deals','block-123922','Html_box','',1),(123924,'118364','deals','block-123922','Html_box','',2),(123925,'118365','deals','block-123922','Html_box','',4),(123926,'118366','deals','block-123922','order\\BillingAddress','',3),(123927,'118367','deals','block-123922','UpdateAndPay\\PayForm','',5),(123928,'118368','deals','block-123908','BlockBox','',2),(123929,'118369','deals','block-123928','Html_box','',1),(123930,'118370','deals','block-123928','order\\Products','',2),(123931,'118371','deals','block-123908-2','BlockBox','',1),(123932,'118372','deals','block-123931','order\\Totals','',2),(123933,'118373','deals','block-123931','checkout\\ContinueBtn','',3),(123934,'118374','deals','block-123931','Html_box','',1),(123935,'118375','deals','block-123907','account\\OrderHeading','',1),(123936,'118440','deals','wishlist','BlockBox','',1),(123937,'118441','deals','block-123936','BlockBox','',1),(123938,'118442','deals','block-123937','WidgetsAria','',1),(123958,'118443','deals','block-123937-2','account\\Wishlist','',2),(123959,'118444','deals','block-123937-2','Html_box','',1),(123960,'118445','deals','wishlist-cart','BlockBox','',1),(123961,'118446','deals','block-123960','cart\\CartTabs','',1),(123962,'118447','deals','block-123961','account\\Wishlist','',1),(179364,'1712674966.930853','furniture','header','UnsupportedBrowser','',1),(179365,'1712674966.934154','furniture','header','BlockBox','header-content-small',2),(179366,'1712674966.936778','furniture','block-179365','BlockBox','header-content-small-left',1),(179367,'1712674966.939493','furniture','block-179366','Menu','Header menu',1),(179368,'1712674967.04388','furniture','block-179366-2','BlockBox','header-content-small-right',1),(179369,'1712674967.045458','furniture','block-179368','Currencies','',2),(179370,'1712674967.072331','furniture','block-179368','Languages','',1),(179371,'1712674967.095974','furniture','header','BlockBox','header-content',3),(179372,'1712674967.104961','furniture','block-179371','Logo','',1),(179373,'1712674967.10848','furniture','block-179371','Search','',3),(179374,'1712674967.177380','furniture','block-179371','Cart','',4),(179375,'1712674967.300450','furniture','block-179371','Account','',5),(179376,'1712674967.356553','furniture','block-179371','Image','',2),(179377,'1712674967.37028','furniture','header','BlockBox','header-menu',4),(179378,'1712674967.380976','furniture','block-179377','Menu','Categories',1),(179379,'1712679985.656435','watch','header','CookieNotice','',1),(179380,'1712679985.659674','watch','header','BlockBox','header-content-small',2),(179381,'1712679985.661821','watch','block-179380','BlockBox','header-content-small-left',1),(179382,'1712679985.663776','watch','block-179381','Menu','Header menu',1),(179383,'1712679985.705953','watch','block-179381-2','BlockBox','header-content-small-right',5),(179384,'1712679985.707292','watch','block-179383','Cart','',1),(179385,'1712679985.760839','watch','block-179383','Account','',2),(179386,'1712679985.804792','watch','block-179383','Currencies','',4),(179387,'1712679985.832720','watch','block-179383','Languages','',3),(179388,'1712679985.861268','watch','header','BlockBox','header-content',3),(179389,'1712679985.873114','watch','block-179388','Logo','',1),(179390,'1712679985.87751','watch','block-179388','Search','',2),(179391,'1712679985.999727','watch','block-179388','Text','',3),(179392,'1712679986.031228','watch','header','BlockBox','header-menu',4),(179393,'1712679986.036538','watch','block-179392','Menu','Categories',1),(179426,'1712756007.569966','printshop','header','UnsupportedBrowser','',1),(179427,'1712756007.57315','printshop','header','BlockBox','header-content-small',2),(179428,'1712756007.585982','printshop','block-179427','BlockBox','header-content-small-left',1),(179429,'1712756007.5885','printshop','block-179428','Contacts','',2),(179430,'1712756007.589787','printshop','block-179428','Text','',1),(179431,'1712756007.62595','printshop','block-179428-2','BlockBox','header-content-small-right',1),(179432,'1712756007.627579','printshop','block-179431','Menu','Header menu',4),(179433,'1712756007.729922','printshop','block-179431','Chat','',3),(179434,'1712756007.738185','printshop','block-179431','Text','',2),(179435,'1712756007.772518','printshop','block-179431','Contacts','',1),(179436,'1712756007.774661','printshop','header','BlockBox','header-content',3),(179437,'1712756007.779822','printshop','block-179436','Logo','',1),(179438,'1712756007.783714','printshop','block-179436','Search','',4),(179439,'1712756007.85127','printshop','block-179436','Cart','',6),(179440,'1712756007.912178','printshop','block-179436','Account','',5),(179441,'1712756007.950557','printshop','block-179436','BlockBox','header-menu',3),(179442,'1712756007.953578','printshop','block-179441','Menu','Categories',1),(179458,'1712823935.978146','deals','header','BlockBox','',1),(179459,'1712823935.987731','deals','block-179458','BlockBox','header-content',1),(179460,'1712823935.994767','deals','block-179459','Logo','',1),(179461,'1712823935.997331','deals','block-179459','Search','',3),(179462,'1712823936.133379','deals','block-179459','Cart','',5),(179463,'1712823936.18733','deals','block-179459','Account','',4),(179464,'1712823936.243618','deals','block-179459','BlockBox','header-menu',2),(179465,'1712823936.245254','deals','block-179464','Menu','Categories',1),(189014,'1713774131.524999','watch','account','BlockBox','',0),(189015,'1713774131.631466','watch','block-189014','BlockBox','',1),(189016,'1713774131.633419','watch','block-189015','WidgetsAria','',1),(189036,'1713774131.989231','watch','block-189015-2','BlockBox','account-content',1),(189037,'1713774131.990525','watch','block-189036','account\\OrdersHistory','',5),(189038,'1713774131.992548','watch','block-189036','Html_box','',4),(189039,'1713774131.995359','watch','block-189036','Html_box','',1),(189040,'1713774132.011364','watch','block-189036','BlockBox','account-content-top',2),(189041,'1713774132.020828','watch','block-189040','BlockBox','',1),(189042,'1713774132.02226','watch','block-189041','Html_box','',1),(189043,'1713774132.02710','watch','block-189041','account\\LastOrder','',2),(189044,'1713774132.037763','watch','block-189040','BlockBox','',2),(189045,'1713774132.039110','watch','block-189044','Html_box','',1),(189046,'1713774132.04388','watch','block-189044','account\\OrderCount','',2),(189047,'1713774132.045662','watch','block-189044','account\\AccountLink','',3),(189048,'1713774132.047643','watch','block-189040','BlockBox','',3),(189049,'1713774132.048770','watch','block-189048','Html_box','',1),(189050,'1713774132.053414','watch','block-189048','account\\TotalOrdered','',2),(189051,'1713774132.055889','watch','block-189040','BlockBox','',4),(189052,'1713774132.05740','watch','block-189051','Html_box','',1),(189053,'1713774132.061556','watch','block-189051','account\\CreditAmount','',2),(189054,'1713774132.127825','watch','block-189051','account\\AccountLink','',3),(189055,'1713774132.130117','watch','block-189040','BlockBox','',5),(189056,'1713774132.131332','watch','block-189055','account\\AccountLink','',3),(189057,'1713774132.133341','watch','block-189055','BonusActions\\widgets\\PointsEarnt','',2),(189058,'1713774132.13514','watch','block-189055','Html_box','',1),(189059,'1713774132.139570','watch','review','BlockBox','',0),(189060,'1713774132.140834','watch','block-189059','BlockBox','',1),(189061,'1713774132.141911','watch','block-189060','WidgetsAria','',1),(189081,'1713774132.504954','watch','block-189060-2','Html_box','',1),(189082,'1713774132.508462','watch','block-189060-2','account\\Reviews','',2),(189083,'1713774132.514786','watch','order_history_info','BlockBox','',0),(189084,'1713774132.550697','watch','block-189083','BlockBox','',1),(189085,'1713774132.552317','watch','block-189084','WidgetsAria','',1),(189105,'1713774132.898941','watch','block-189084-2','account\\OrderInvoiceButton','',3),(189106,'1713774132.900330','watch','block-189084-2','account\\OrderSubTotals','',10),(189107,'1713774132.901231','watch','block-189084-2','account\\OrderPayButton','',5),(189108,'1713774132.902540','watch','block-189084-2','BlockBox','',13),(189109,'1713774132.903770','watch','block-189108','account\\AccountLink','',1),(189110,'1713774132.90524','watch','block-189108-2','account\\OrderInvoiceButton','',1),(189111,'1713774132.905816','watch','block-189084-2','Html_box','',8),(189112,'1713774132.908463','watch','block-189084-2','account\\OrderHistory','',12),(189113,'1713774132.910483','watch','block-189084-2','account\\OrderCancelAndReorder','',4),(189114,'1713774132.912272','watch','block-189084-2','account\\OrderHeading','',1),(189115,'1713774132.913316','watch','block-189084-2','account\\OrderDownload','',6),(189116,'1713774132.915188','watch','block-189084-2','Html_box','',11),(189117,'1713774132.917477','watch','block-189084-2','account\\OrderProducts','',9),(189118,'1713774132.918550','watch','block-189084-2','account\\OrderReorderButton','',2),(189119,'1713774132.919848','watch','block-189084-2','BlockBox','',7),(189120,'1713774132.921595','watch','block-189119','BlockBox','',2),(189121,'1713774132.92285','watch','block-189120','Html_box','',1),(189122,'1713774132.92519','watch','block-189120','account\\OrderData','',2),(189123,'1713774132.92663','watch','block-189119','BlockBox','',1),(189124,'1713774132.9280','watch','block-189123','Html_box','',1),(189125,'1713774132.932360','watch','block-189123','account\\OrderData','',2),(189126,'1713774132.933540','watch','block-189119','BlockBox','',3),(189127,'1713774132.93487','watch','block-189126','account\\OrderTracking','',2),(189128,'1713774132.936634','watch','block-189126','Html_box','',1),(189129,'1713774132.938818','watch','block-189126','account\\AccountLink','',3),(189130,'1713774132.940770','watch','block-189119-2','BlockBox','',2),(189131,'1713774132.941988','watch','block-189130','account\\OrderData','',2),(189132,'1713774132.94319','watch','block-189130','Html_box','',1),(189133,'1713774132.945272','watch','block-189119-2','BlockBox','',1),(189134,'1713774132.946358','watch','block-189133','account\\OrderData','',2),(189135,'1713774132.947328','watch','block-189133','Html_box','',1),(189136,'1713774132.949323','watch','block-189119-3','BlockBox','',2),(189137,'1713774132.950533','watch','block-189136','account\\OrderData','',2),(189138,'1713774132.951838','watch','block-189136','Html_box','',1),(189139,'1713774132.953990','watch','block-189119-3','BlockBox','',1),(189140,'1713774132.955210','watch','block-189139','Html_box','',1),(189141,'1713774132.957413','watch','block-189139','account\\OrderData','',2),(189142,'1713774132.958422','watch','address_book','BlockBox','',0),(189143,'1713774132.959666','watch','block-189142','BlockBox','',1),(189144,'1713774132.960615','watch','block-189143','WidgetsAria','',1),(189164,'1713774133.357999','watch','block-189143-2','account\\AddressBook','',3),(189165,'1713774133.369549','watch','block-189143-2','Html_box','',1),(189166,'1713774133.371715','watch','block-189143-2','Html_box','',2),(189167,'1713774133.3740','watch','account_edit','BlockBox','',0),(189168,'1713774133.377154','watch','block-189167','BlockBox','',1),(189169,'1713774133.37823','watch','block-189168','WidgetsAria','',1),(189189,'1713774133.709180','watch','block-189168-2','account\\AccountEdit','',2),(189190,'1713774133.710153','watch','block-189168-2','Html_box','',1),(189191,'1713774133.722971','watch','order_history','BlockBox','',0),(189192,'1713774133.772271','watch','block-189191','BlockBox','',1),(189193,'1713774133.773863','watch','block-189192','WidgetsAria','',1),(189213,'1713774134.186274','watch','block-189192-2','Html_box','',1),(189214,'1713774134.188218','watch','block-189192-2','account\\OrdersHistory','',2),(189215,'1713774134.189849','watch','address_book_process','BlockBox','',0),(189216,'1713774134.19293','watch','block-189215','BlockBox','',1),(189217,'1713774134.194197','watch','block-189216','WidgetsAria','',1),(189218,'73374','watch','account-menu','BlockBox','',1),(189219,'73375','watch','block-189218','BlockBox','account-side',1),(189220,'73376','watch','block-189219','Html_box','',16),(189221,'73377','watch','block-189219','account\\AccountLink','',17),(189222,'73378','watch','block-189219','account\\AccountLink','',18),(189223,'73379','watch','block-189219','account\\AccountLink','',1),(189224,'73380','watch','block-189219','Html_box','',2),(189225,'73381','watch','block-189219','account\\AccountLink','',4),(189226,'73382','watch','block-189219','account\\AccountLink','',7),(189227,'73383','watch','block-189219','account\\AccountLink','',11),(189228,'73384','watch','block-189219','Html_box','',6),(189229,'73385','watch','block-189219','account\\AccountLink','',3),(189230,'73386','watch','block-189219','account\\AccountLink','',14),(189231,'73387','watch','block-189219','account\\AccountLink','',8),(189232,'73388','watch','block-189219','account\\AccountLink','',5),(189233,'73389','watch','block-189219','account\\AccountLink','',9),(189234,'73390','watch','block-189219','account\\AccountLink','',12),(189235,'73391','watch','block-189219','Html_box','',10),(189236,'73392','watch','block-189219','account\\AccountLink','',15),(189237,'1713774134.555525','watch','block-189216-2','Html_box','',1),(189238,'1713774134.558117','watch','block-189216-2','account\\EditAddress','',2),(189239,'1713774279.864294','furniture','account','BlockBox','',0),(189240,'1713774279.969680','furniture','block-189239','BlockBox','',1),(189241,'1713774279.971753','furniture','block-189240','WidgetsAria','',1),(189261,'1713774280.297397','furniture','block-189240-2','BlockBox','account-content',1),(189262,'1713774280.298583','furniture','block-189261','account\\OrdersHistory','',5),(189263,'1713774280.300742','furniture','block-189261','Html_box','',4),(189264,'1713774280.304538','furniture','block-189261','Html_box','',1),(189265,'1713774280.32165','furniture','block-189261','BlockBox','account-content-top',2),(189266,'1713774280.334674','furniture','block-189265','BlockBox','',1),(189267,'1713774280.336154','furniture','block-189266','Html_box','',1),(189268,'1713774280.341288','furniture','block-189266','account\\LastOrder','',2),(189269,'1713774280.35188','furniture','block-189265','BlockBox','',2),(189270,'1713774280.352867','furniture','block-189269','Html_box','',1),(189271,'1713774280.356398','furniture','block-189269','account\\OrderCount','',2),(189272,'1713774280.357628','furniture','block-189269','account\\AccountLink','',3),(189273,'1713774280.359356','furniture','block-189265','BlockBox','',3),(189274,'1713774280.360175','furniture','block-189273','Html_box','',1),(189275,'1713774280.362861','furniture','block-189273','account\\TotalOrdered','',2),(189276,'1713774280.364168','furniture','block-189265','BlockBox','',4),(189277,'1713774280.36559','furniture','block-189276','Html_box','',1),(189278,'1713774280.367684','furniture','block-189276','account\\CreditAmount','',2),(189279,'1713774280.368994','furniture','block-189276','account\\AccountLink','',3),(189280,'1713774280.370288','furniture','block-189265','BlockBox','',5),(189281,'1713774280.3715','furniture','block-189280','account\\AccountLink','',3),(189282,'1713774280.372214','furniture','block-189280','BonusActions\\widgets\\PointsEarnt','',2),(189283,'1713774280.373397','furniture','block-189280','Html_box','',1),(189284,'1713774280.375920','furniture','review','BlockBox','',0),(189285,'1713774280.37681','furniture','block-189284','BlockBox','',1),(189286,'1713774280.377779','furniture','block-189285','WidgetsAria','',1),(189306,'1713774280.725312','furniture','block-189285-2','Html_box','',1),(189307,'1713774280.727712','furniture','block-189285-2','account\\Reviews','',2),(189308,'1713774280.733870','furniture','order_history_info','BlockBox','',0),(189309,'1713774280.76691','furniture','block-189308','BlockBox','',1),(189310,'1713774280.768459','furniture','block-189309','WidgetsAria','',1),(189330,'1713774281.071110','furniture','block-189309-2','account\\OrderInvoiceButton','',3),(189331,'1713774281.072459','furniture','block-189309-2','account\\OrderSubTotals','',10),(189332,'1713774281.073313','furniture','block-189309-2','account\\OrderPayButton','',5),(189333,'1713774281.074856','furniture','block-189309-2','BlockBox','',13),(189334,'1713774281.076345','furniture','block-189333','account\\AccountLink','',1),(189335,'1713774281.07759','furniture','block-189333-2','account\\OrderInvoiceButton','',1),(189336,'1713774281.078437','furniture','block-189309-2','Html_box','',8),(189337,'1713774281.080413','furniture','block-189309-2','account\\OrderHistory','',12),(189338,'1713774281.08131','furniture','block-189309-2','account\\OrderCancelAndReorder','',4),(189339,'1713774281.082594','furniture','block-189309-2','account\\OrderHeading','',1),(189340,'1713774281.083285','furniture','block-189309-2','account\\OrderDownload','',6),(189341,'1713774281.086740','furniture','block-189309-2','Html_box','',11),(189342,'1713774281.088888','furniture','block-189309-2','account\\OrderProducts','',9),(189343,'1713774281.089731','furniture','block-189309-2','account\\OrderReorderButton','',2),(189344,'1713774281.090797','furniture','block-189309-2','BlockBox','',7),(189345,'1713774281.092211','furniture','block-189344','BlockBox','',2),(189346,'1713774281.093966','furniture','block-189345','Html_box','',1),(189347,'1713774281.096334','furniture','block-189345','account\\OrderData','',2),(189348,'1713774281.097991','furniture','block-189344','BlockBox','',1),(189349,'1713774281.09931','furniture','block-189348','Html_box','',1),(189350,'1713774281.104376','furniture','block-189348','account\\OrderData','',2),(189351,'1713774281.105683','furniture','block-189344','BlockBox','',3),(189352,'1713774281.10733','furniture','block-189351','account\\OrderTracking','',2),(189353,'1713774281.108498','furniture','block-189351','Html_box','',1),(189354,'1713774281.11113','furniture','block-189351','account\\AccountLink','',3),(189355,'1713774281.113595','furniture','block-189344-2','BlockBox','',2),(189356,'1713774281.114856','furniture','block-189355','account\\OrderData','',2),(189357,'1713774281.116185','furniture','block-189355','Html_box','',1),(189358,'1713774281.118622','furniture','block-189344-2','BlockBox','',1),(189359,'1713774281.120129','furniture','block-189358','account\\OrderData','',2),(189360,'1713774281.121493','furniture','block-189358','Html_box','',1),(189361,'1713774281.123873','furniture','block-189344-3','BlockBox','',2),(189362,'1713774281.124980','furniture','block-189361','account\\OrderData','',2),(189363,'1713774281.126172','furniture','block-189361','Html_box','',1),(189364,'1713774281.128587','furniture','block-189344-3','BlockBox','',1),(189365,'1713774281.129973','furniture','block-189364','Html_box','',1),(189366,'1713774281.132385','furniture','block-189364','account\\OrderData','',2),(189367,'1713774281.133667','furniture','address_book','BlockBox','',0),(189368,'1713774281.13597','furniture','block-189367','BlockBox','',1),(189369,'1713774281.136347','furniture','block-189368','WidgetsAria','',1),(189389,'1713774281.475435','furniture','block-189368-2','account\\AddressBook','',3),(189390,'1713774281.489799','furniture','block-189368-2','Html_box','',1),(189391,'1713774281.493151','furniture','block-189368-2','Html_box','',2),(189392,'1713774281.496820','furniture','account_edit','BlockBox','',0),(189393,'1713774281.501632','furniture','block-189392','BlockBox','',1),(189394,'1713774281.503794','furniture','block-189393','WidgetsAria','',1),(189414,'1713774281.88924','furniture','block-189393-2','account\\AccountEdit','',2),(189415,'1713774281.890686','furniture','block-189393-2','Html_box','',1),(189416,'1713774281.907128','furniture','order_history','BlockBox','',0),(189417,'1713774281.953936','furniture','block-189416','BlockBox','',1),(189418,'1713774281.955250','furniture','block-189417','WidgetsAria','',1),(189438,'1713774282.25493','furniture','block-189417-2','Html_box','',1),(189439,'1713774282.257271','furniture','block-189417-2','account\\OrdersHistory','',2),(189440,'1713774282.2593','furniture','address_book_process','BlockBox','',0),(189441,'1713774282.263247','furniture','block-189440','BlockBox','',1),(189442,'1713774282.264620','furniture','block-189441','WidgetsAria','',1),(189443,'73374','furniture','account-menu','BlockBox','',1),(189444,'73375','furniture','block-189443','BlockBox','account-side',1),(189445,'73376','furniture','block-189444','Html_box','',16),(189446,'73377','furniture','block-189444','account\\AccountLink','',17),(189447,'73378','furniture','block-189444','account\\AccountLink','',18),(189448,'73379','furniture','block-189444','account\\AccountLink','',1),(189449,'73380','furniture','block-189444','Html_box','',2),(189450,'73381','furniture','block-189444','account\\AccountLink','',4),(189451,'73382','furniture','block-189444','account\\AccountLink','',7),(189452,'73383','furniture','block-189444','account\\AccountLink','',11),(189453,'73384','furniture','block-189444','Html_box','',6),(189454,'73385','furniture','block-189444','account\\AccountLink','',3),(189455,'73386','furniture','block-189444','account\\AccountLink','',14),(189456,'73387','furniture','block-189444','account\\AccountLink','',8),(189457,'73388','furniture','block-189444','account\\AccountLink','',5),(189458,'73389','furniture','block-189444','account\\AccountLink','',9),(189459,'73390','furniture','block-189444','account\\AccountLink','',12),(189460,'73391','furniture','block-189444','Html_box','',10),(189461,'73392','furniture','block-189444','account\\AccountLink','',15),(189462,'1713774282.668269','furniture','block-189441-2','Html_box','',1),(189463,'1713774282.671894','furniture','block-189441-2','account\\EditAddress','',2),(189464,'1713774291.283818','printshop','account','BlockBox','',0),(189465,'1713774291.388533','printshop','block-189464','BlockBox','',1),(189466,'1713774291.390348','printshop','block-189465','WidgetsAria','',1),(189486,'1713774291.784653','printshop','block-189465-2','BlockBox','account-content',1),(189487,'1713774291.785492','printshop','block-189486','account\\OrdersHistory','',5),(189488,'1713774291.78762','printshop','block-189486','Html_box','',4),(189489,'1713774291.78938','printshop','block-189486','Html_box','',1),(189490,'1713774291.799772','printshop','block-189486','BlockBox','account-content-top',2),(189491,'1713774291.806860','printshop','block-189490','BlockBox','',1),(189492,'1713774291.807965','printshop','block-189491','Html_box','',1),(189493,'1713774291.811922','printshop','block-189491','account\\LastOrder','',2),(189494,'1713774291.821577','printshop','block-189490','BlockBox','',2),(189495,'1713774291.822426','printshop','block-189494','Html_box','',1),(189496,'1713774291.82580','printshop','block-189494','account\\OrderCount','',2),(189497,'1713774291.82723','printshop','block-189494','account\\AccountLink','',3),(189498,'1713774291.829143','printshop','block-189490','BlockBox','',3),(189499,'1713774291.829944','printshop','block-189498','Html_box','',1),(189500,'1713774291.833740','printshop','block-189498','account\\TotalOrdered','',2),(189501,'1713774291.836366','printshop','block-189490','BlockBox','',4),(189502,'1713774291.837352','printshop','block-189501','Html_box','',1),(189503,'1713774291.840267','printshop','block-189501','account\\CreditAmount','',2),(189504,'1713774291.841825','printshop','block-189501','account\\AccountLink','',3),(189505,'1713774291.843244','printshop','block-189490','BlockBox','',5),(189506,'1713774291.844151','printshop','block-189505','account\\AccountLink','',3),(189507,'1713774291.84543','printshop','block-189505','BonusActions\\widgets\\PointsEarnt','',2),(189508,'1713774291.846868','printshop','block-189505','Html_box','',1),(189509,'1713774291.849925','printshop','review','BlockBox','',0),(189510,'1713774291.850917','printshop','block-189509','BlockBox','',1),(189511,'1713774291.851973','printshop','block-189510','WidgetsAria','',1),(189531,'1713774292.245647','printshop','block-189510-2','Html_box','',1),(189532,'1713774292.247937','printshop','block-189510-2','account\\Reviews','',2),(189533,'1713774292.252957','printshop','order_history_info','BlockBox','',0),(189534,'1713774292.285450','printshop','block-189533','BlockBox','',1),(189535,'1713774292.286894','printshop','block-189534','WidgetsAria','',1),(189555,'1713774292.692796','printshop','block-189534-2','account\\OrderInvoiceButton','',3),(189556,'1713774292.69390','printshop','block-189534-2','account\\OrderSubTotals','',10),(189557,'1713774292.69476','printshop','block-189534-2','account\\OrderPayButton','',5),(189558,'1713774292.695987','printshop','block-189534-2','BlockBox','',13),(189559,'1713774292.697287','printshop','block-189558','account\\AccountLink','',1),(189560,'1713774292.698396','printshop','block-189558-2','account\\OrderInvoiceButton','',1),(189561,'1713774292.699239','printshop','block-189534-2','Html_box','',8),(189562,'1713774292.701481','printshop','block-189534-2','account\\OrderHistory','',12),(189563,'1713774292.702227','printshop','block-189534-2','account\\OrderCancelAndReorder','',4),(189564,'1713774292.703612','printshop','block-189534-2','account\\OrderHeading','',1),(189565,'1713774292.70446','printshop','block-189534-2','account\\OrderDownload','',6),(189566,'1713774292.707596','printshop','block-189534-2','Html_box','',11),(189567,'1713774292.70989','printshop','block-189534-2','account\\OrderProducts','',9),(189568,'1713774292.71080','printshop','block-189534-2','account\\OrderReorderButton','',2),(189569,'1713774292.711955','printshop','block-189534-2','BlockBox','',7),(189570,'1713774292.713627','printshop','block-189569','BlockBox','',2),(189571,'1713774292.71538','printshop','block-189570','Html_box','',1),(189572,'1713774292.717332','printshop','block-189570','account\\OrderData','',2),(189573,'1713774292.718650','printshop','block-189569','BlockBox','',1),(189574,'1713774292.719949','printshop','block-189573','Html_box','',1),(189575,'1713774292.724311','printshop','block-189573','account\\OrderData','',2),(189576,'1713774292.725380','printshop','block-189569','BlockBox','',3),(189577,'1713774292.726372','printshop','block-189576','account\\OrderTracking','',2),(189578,'1713774292.727511','printshop','block-189576','Html_box','',1),(189579,'1713774292.729492','printshop','block-189576','account\\AccountLink','',3),(189580,'1713774292.731181','printshop','block-189569-2','BlockBox','',2),(189581,'1713774292.73246','printshop','block-189580','account\\OrderData','',2),(189582,'1713774292.733650','printshop','block-189580','Html_box','',1),(189583,'1713774292.735925','printshop','block-189569-2','BlockBox','',1),(189584,'1713774292.737241','printshop','block-189583','account\\OrderData','',2),(189585,'1713774292.73836','printshop','block-189583','Html_box','',1),(189586,'1713774292.740656','printshop','block-189569-3','BlockBox','',2),(189587,'1713774292.741632','printshop','block-189586','account\\OrderData','',2),(189588,'1713774292.742836','printshop','block-189586','Html_box','',1),(189589,'1713774292.744670','printshop','block-189569-3','BlockBox','',1),(189590,'1713774292.745537','printshop','block-189589','Html_box','',1),(189591,'1713774292.747421','printshop','block-189589','account\\OrderData','',2),(189592,'1713774292.748453','printshop','address_book','BlockBox','',0),(189593,'1713774292.749515','printshop','block-189592','BlockBox','',1),(189594,'1713774292.750418','printshop','block-189593','WidgetsAria','',1),(189614,'1713774293.082159','printshop','block-189593-2','account\\AddressBook','',3),(189615,'1713774293.096223','printshop','block-189593-2','Html_box','',1),(189616,'1713774293.098979','printshop','block-189593-2','Html_box','',2),(189617,'1713774293.102593','printshop','account_edit','BlockBox','',0),(189618,'1713774293.10637','printshop','block-189617','BlockBox','',1),(189619,'1713774293.107979','printshop','block-189618','WidgetsAria','',1),(189639,'1713774293.506233','printshop','block-189618-2','account\\AccountEdit','',2),(189640,'1713774293.507399','printshop','block-189618-2','Html_box','',1),(189641,'1713774293.523882','printshop','order_history','BlockBox','',0),(189642,'1713774293.577891','printshop','block-189641','BlockBox','',1),(189643,'1713774293.579253','printshop','block-189642','WidgetsAria','',1),(189663,'1713774293.893565','printshop','block-189642-2','Html_box','',1),(189664,'1713774293.895793','printshop','block-189642-2','account\\OrdersHistory','',2),(189665,'1713774293.897327','printshop','address_book_process','BlockBox','',0),(189666,'1713774293.900863','printshop','block-189665','BlockBox','',1),(189667,'1713774293.90289','printshop','block-189666','WidgetsAria','',1),(189668,'73374','printshop','account-menu','BlockBox','',1),(189669,'73375','printshop','block-189668','BlockBox','account-side',1),(189670,'73376','printshop','block-189669','Html_box','',16),(189671,'73377','printshop','block-189669','account\\AccountLink','',17),(189672,'73378','printshop','block-189669','account\\AccountLink','',18),(189673,'73379','printshop','block-189669','account\\AccountLink','',1),(189674,'73380','printshop','block-189669','Html_box','',2),(189675,'73381','printshop','block-189669','account\\AccountLink','',4),(189676,'73382','printshop','block-189669','account\\AccountLink','',7),(189677,'73383','printshop','block-189669','account\\AccountLink','',11),(189678,'73384','printshop','block-189669','Html_box','',6),(189679,'73385','printshop','block-189669','account\\AccountLink','',3),(189680,'73386','printshop','block-189669','account\\AccountLink','',14),(189681,'73387','printshop','block-189669','account\\AccountLink','',8),(189682,'73388','printshop','block-189669','account\\AccountLink','',5),(189683,'73389','printshop','block-189669','account\\AccountLink','',9),(189684,'73390','printshop','block-189669','account\\AccountLink','',12),(189685,'73391','printshop','block-189669','Html_box','',10),(189686,'73392','printshop','block-189669','account\\AccountLink','',15),(189687,'1713774294.238947','printshop','block-189666-2','Html_box','',1),(189688,'1713774294.241221','printshop','block-189666-2','account\\EditAddress','',2),(189689,'1713774302.070365','deals','account','BlockBox','',0),(189690,'1713774302.241660','deals','block-189689','BlockBox','',1),(189691,'1713774302.243252','deals','block-189690','WidgetsAria','',1),(189711,'1713774302.55728','deals','block-189690-2','BlockBox','account-content',1),(189712,'1713774302.558125','deals','block-189711','account\\OrdersHistory','',5),(189713,'1713774302.559810','deals','block-189711','Html_box','',4),(189714,'1713774302.562282','deals','block-189711','Html_box','',1),(189715,'1713774302.575318','deals','block-189711','BlockBox','account-content-top',2),(189716,'1713774302.583346','deals','block-189715','BlockBox','',1),(189717,'1713774302.584585','deals','block-189716','Html_box','',1),(189718,'1713774302.588956','deals','block-189716','account\\LastOrder','',2),(189719,'1713774302.599185','deals','block-189715','BlockBox','',2),(189720,'1713774302.600332','deals','block-189719','Html_box','',1),(189721,'1713774302.604146','deals','block-189719','account\\OrderCount','',2),(189722,'1713774302.605686','deals','block-189719','account\\AccountLink','',3),(189723,'1713774302.607525','deals','block-189715','BlockBox','',3),(189724,'1713774302.608552','deals','block-189723','Html_box','',1),(189725,'1713774302.611730','deals','block-189723','account\\TotalOrdered','',2),(189726,'1713774302.613318','deals','block-189715','BlockBox','',4),(189727,'1713774302.614257','deals','block-189726','Html_box','',1),(189728,'1713774302.618189','deals','block-189726','account\\CreditAmount','',2),(189729,'1713774302.619664','deals','block-189726','account\\AccountLink','',3),(189730,'1713774302.620964','deals','block-189715','BlockBox','',5),(189731,'1713774302.62216','deals','block-189730','account\\AccountLink','',3),(189732,'1713774302.623592','deals','block-189730','BonusActions\\widgets\\PointsEarnt','',2),(189733,'1713774302.625189','deals','block-189730','Html_box','',1),(189734,'1713774302.628368','deals','review','BlockBox','',0),(189735,'1713774302.629597','deals','block-189734','BlockBox','',1),(189736,'1713774302.630510','deals','block-189735','WidgetsAria','',1),(189756,'1713774302.942945','deals','block-189735-2','Html_box','',1),(189757,'1713774302.94546','deals','block-189735-2','account\\Reviews','',2),(189758,'1713774302.951148','deals','order_history_info','BlockBox','',0),(189759,'1713774302.98691','deals','block-189758','BlockBox','',1),(189760,'1713774302.987797','deals','block-189759','WidgetsAria','',1),(189780,'1713774303.355589','deals','block-189759-2','account\\OrderInvoiceButton','',3),(189781,'1713774303.356763','deals','block-189759-2','account\\OrderSubTotals','',10),(189782,'1713774303.357736','deals','block-189759-2','account\\OrderPayButton','',5),(189783,'1713774303.358932','deals','block-189759-2','BlockBox','',13),(189784,'1713774303.362185','deals','block-189783','account\\AccountLink','',1),(189785,'1713774303.365122','deals','block-189783-2','account\\OrderInvoiceButton','',1),(189786,'1713774303.366232','deals','block-189759-2','Html_box','',8),(189787,'1713774303.368612','deals','block-189759-2','account\\OrderHistory','',12),(189788,'1713774303.36967','deals','block-189759-2','account\\OrderCancelAndReorder','',4),(189789,'1713774303.371141','deals','block-189759-2','account\\OrderHeading','',1),(189790,'1713774303.372180','deals','block-189759-2','account\\OrderDownload','',6),(189791,'1713774303.374982','deals','block-189759-2','Html_box','',11),(189792,'1713774303.377716','deals','block-189759-2','account\\OrderProducts','',9),(189793,'1713774303.378529','deals','block-189759-2','account\\OrderReorderButton','',2),(189794,'1713774303.379873','deals','block-189759-2','BlockBox','',7),(189795,'1713774303.38143','deals','block-189794','BlockBox','',2),(189796,'1713774303.383169','deals','block-189795','Html_box','',1),(189797,'1713774303.385376','deals','block-189795','account\\OrderData','',2),(189798,'1713774303.386781','deals','block-189794','BlockBox','',1),(189799,'1713774303.387715','deals','block-189798','Html_box','',1),(189800,'1713774303.392348','deals','block-189798','account\\OrderData','',2),(189801,'1713774303.393461','deals','block-189794','BlockBox','',3),(189802,'1713774303.394715','deals','block-189801','account\\OrderTracking','',2),(189803,'1713774303.3963','deals','block-189801','Html_box','',1),(189804,'1713774303.39839','deals','block-189801','account\\AccountLink','',3),(189805,'1713774303.479','deals','block-189794-2','BlockBox','',2),(189806,'1713774303.401260','deals','block-189805','account\\OrderData','',2),(189807,'1713774303.402194','deals','block-189805','Html_box','',1),(189808,'1713774303.403789','deals','block-189794-2','BlockBox','',1),(189809,'1713774303.404787','deals','block-189808','account\\OrderData','',2),(189810,'1713774303.405697','deals','block-189808','Html_box','',1),(189811,'1713774303.407397','deals','block-189794-3','BlockBox','',2),(189812,'1713774303.408152','deals','block-189811','account\\OrderData','',2),(189813,'1713774303.409138','deals','block-189811','Html_box','',1),(189814,'1713774303.41090','deals','block-189794-3','BlockBox','',1),(189815,'1713774303.411821','deals','block-189814','Html_box','',1),(189816,'1713774303.413853','deals','block-189814','account\\OrderData','',2),(189817,'1713774303.414793','deals','address_book','BlockBox','',0),(189818,'1713774303.415755','deals','block-189817','BlockBox','',1),(189819,'1713774303.416744','deals','block-189818','WidgetsAria','',1),(189839,'1713774303.748485','deals','block-189818-2','account\\AddressBook','',3),(189840,'1713774303.759421','deals','block-189818-2','Html_box','',1),(189841,'1713774303.7624','deals','block-189818-2','Html_box','',2),(189842,'1713774303.76450','deals','account_edit','BlockBox','',0),(189843,'1713774303.768552','deals','block-189842','BlockBox','',1),(189844,'1713774303.770899','deals','block-189843','WidgetsAria','',1),(189864,'1713774304.060984','deals','block-189843-2','account\\AccountEdit','',2),(189865,'1713774304.061861','deals','block-189843-2','Html_box','',1),(189866,'1713774304.077962','deals','order_history','BlockBox','',0),(189867,'1713774304.184488','deals','block-189866','BlockBox','',1),(189868,'1713774304.186275','deals','block-189867','WidgetsAria','',1),(189888,'1713774304.463836','deals','block-189867-2','Html_box','',1),(189889,'1713774304.465929','deals','block-189867-2','account\\OrdersHistory','',2),(189890,'1713774304.467962','deals','address_book_process','BlockBox','',0),(189891,'1713774304.471135','deals','block-189890','BlockBox','',1),(189892,'1713774304.472570','deals','block-189891','WidgetsAria','',1),(189893,'73374','deals','account-menu','BlockBox','',1),(189894,'73375','deals','block-189893','BlockBox','account-side',1),(189895,'73376','deals','block-189894','Html_box','',16),(189896,'73377','deals','block-189894','account\\AccountLink','',17),(189897,'73378','deals','block-189894','account\\AccountLink','',18),(189898,'73379','deals','block-189894','account\\AccountLink','',1),(189899,'73380','deals','block-189894','Html_box','',2),(189900,'73381','deals','block-189894','account\\AccountLink','',4),(189901,'73382','deals','block-189894','account\\AccountLink','',7),(189902,'73383','deals','block-189894','account\\AccountLink','',11),(189903,'73384','deals','block-189894','Html_box','',6),(189904,'73385','deals','block-189894','account\\AccountLink','',3),(189905,'73386','deals','block-189894','account\\AccountLink','',14),(189906,'73387','deals','block-189894','account\\AccountLink','',8),(189907,'73388','deals','block-189894','account\\AccountLink','',5),(189908,'73389','deals','block-189894','account\\AccountLink','',9),(189909,'73390','deals','block-189894','account\\AccountLink','',12),(189910,'73391','deals','block-189894','Html_box','',10),(189911,'73392','deals','block-189894','account\\AccountLink','',15),(189912,'1713774304.752267','deals','block-189891-2','Html_box','',1),(189913,'1713774304.754680','deals','block-189891-2','account\\EditAddress','',2),(189914,'73349','origin','404','Html_box','',1),(189915,'73350','origin','account','BlockBox','',1),(189916,'73351','origin','block-189915','BlockBox','',1),(189917,'73352','origin','block-189916','WidgetsAria','',1),(189937,'1704978704.8413','origin','block-189916-2','BlockBox','account-content',1),(189938,'73353','origin','block-189937','account\\OrdersHistory','',5),(189939,'73354','origin','block-189937','Html_box','',4),(189940,'73357','origin','block-189937','Html_box','',1),(189941,'1705060269.3517','origin','block-189937','BlockBox','account-content-top',2),(189942,'1705060551.6998','origin','block-189941','BlockBox','',1),(189943,'73361','origin','block-189942','Html_box','',1),(189944,'73362','origin','block-189942','account\\LastOrder','',2),(189945,'1705060566.121','origin','block-189941','BlockBox','',2),(189946,'73363','origin','block-189945','Html_box','',1),(189947,'73364','origin','block-189945','account\\OrderCount','',2),(189948,'73365','origin','block-189945','account\\AccountLink','',3),(189949,'1705060582.9285','origin','block-189941','BlockBox','',3),(189950,'73366','origin','block-189949','Html_box','',1),(189951,'73367','origin','block-189949','account\\TotalOrdered','',2),(189952,'1705060591.4402','origin','block-189941','BlockBox','',4),(189953,'73368','origin','block-189952','Html_box','',1),(189954,'73369','origin','block-189952','account\\CreditAmount','',2),(189955,'73370','origin','block-189952','account\\AccountLink','',3),(189956,'1705060602.1936','origin','block-189941','BlockBox','',5),(189957,'73371','origin','block-189956','account\\AccountLink','',3),(189958,'73372','origin','block-189956','BonusActions\\widgets\\PointsEarnt','',2),(189959,'73373','origin','block-189956','Html_box','',1),(189979,'73393','origin','account_edit','BlockBox','',1),(189980,'73394','origin','block-189979','BlockBox','',1),(189981,'73395','origin','block-189980','WidgetsAria','',1),(190001,'73396','origin','block-189980-2','account\\AccountEdit','',2),(190002,'73397','origin','block-189980-2','Html_box','',1),(190003,'73398','origin','address_book','BlockBox','',1),(190004,'73399','origin','block-190003','BlockBox','',1),(190005,'73400','origin','block-190004','WidgetsAria','',1),(190025,'73401','origin','block-190004-2','account\\AddressBook','',3),(190026,'73402','origin','block-190004-2','Html_box','',1),(190027,'73403','origin','block-190004-2','Html_box','',2),(190028,'73404','origin','address_book_process','BlockBox','',1),(190029,'73405','origin','block-190028','BlockBox','',1),(190030,'73406','origin','block-190029','WidgetsAria','',1),(190050,'73407','origin','block-190029-2','Html_box','',1),(190051,'73408','origin','block-190029-2','account\\EditAddress','',2),(190052,'73409','origin','b2b','BlockBox','listing-item',1),(190053,'73410','origin','block-190052','BlockBox','',1),(190054,'73411','origin','block-190053','productListing\\image','',1),(190055,'73412','origin','block-190053-2','productListing\\description','',6),(190056,'73413','origin','block-190053-2','productListing\\model','',5),(190057,'73414','origin','block-190053-2','productListing\\attributes','',3),(190058,'73415','origin','block-190053-2','BlockBox','',4),(190059,'73416','origin','block-190058','BlockBox','',1),(190060,'73417','origin','block-190059','productListing\\price','',1),(190061,'73418','origin','block-190059-2','BonusActions\\widgets\\BonusPointsProductListing','',1),(190062,'73419','origin','block-190058-2','productListing\\qtyInput','',1),(190063,'73420','origin','block-190053-2','productListing\\name','',1),(190064,'73421','origin','block-190053-2','BlockBox','',2),(190065,'73422','origin','block-190064','productListing\\stock','',1),(190066,'73423','origin','block-190064-2','productListing\\rating','',1),(190067,'76000','origin','batch','BlockBox','',1),(190068,'76001','origin','block-190067','productListing\\attributes','',5),(190069,'76002','origin','block-190067','productListing\\price','',6),(190070,'76003','origin','block-190067','productListing\\name','',4),(190071,'76004','origin','block-190067','productListing\\image','',2),(190072,'76005','origin','block-190067','batchSelect','',1),(190073,'76006','origin','batch_selected','BlockBox','',1),(190074,'76007','origin','block-190073','BlockBox','',13),(190075,'76008','origin','block-190074','productListing\\image','',1),(190076,'76009','origin','block-190074-2','batchRemove','',1),(190077,'76010','origin','block-190074-2','productListing\\price','',3),(190078,'76011','origin','block-190074-2','productListing\\name','',2),(190079,'76012','origin','bbbbb','BlockBox','',1),(190080,'76013','origin','block-190079','BlockBox','',2),(190081,'76014','origin','block-190080','Filters','',1),(190082,'76015','origin','block-190080-2','BlockBox','',6),(190083,'76016','origin','block-190082','catalog\\CountsItems','',1),(190084,'76017','origin','block-190082-2','catalog\\Paging','',1),(190085,'76018','origin','block-190080-2','catalog\\Image','',1),(190086,'76019','origin','block-190080-2','Listing','',5),(190087,'76020','origin','block-190080-2','catalog\\ImageMapCategory','',3),(190088,'76021','origin','block-190080-2','BlockBox','',4),(190089,'76022','origin','block-190088','catalog\\ListingLook','',1),(190090,'76023','origin','block-190088','catalog\\CompareButton','',2),(190091,'76024','origin','block-190088','catalog\\ItemsOnPage','',4),(190092,'76025','origin','block-190088','catalog\\Sorting','',3),(190093,'76026','origin','block-190080-2','Categories','',2),(190094,'76027','origin','block-190079','catalog\\Title','',1),(190095,'1683124632.767746','origin','cart','BlockBox','',1),(190096,'1683124632.80670','origin','block-190095','BlockBox','',2),(190097,'1683124632.809680','origin','block-190096','BlockBox','cart-content',4),(190098,'1683124632.816335','origin','block-190096','BlockBox','',1),(190099,'1683124632.817623','origin','block-190098','cart\\Products','',2),(190100,'1683124632.818551','origin','block-190098','BlockBox','',1),(190101,'1683124632.820317','origin','block-190100','MultiCart\\CartSwitcher','',1),(190102,'1683124632.820914','origin','block-190100','MultiCart\\SaveCart','',2),(190103,'1683124632.822588','origin','block-190100-2','MultiCart\\Actions','',1),(190104,'1683124632.823175','origin','block-190098','BlockBox','',3),(190105,'1683124632.825245','origin','block-190104','cart\\CreditAmount','',1),(190106,'1683124632.825649','origin','block-190104-2','BonusActions\\widgets\\BonusPointsCart','',1),(190107,'1683124632.82683','origin','block-190096','BlockBox','',3),(190108,'1683124632.827413','origin','block-190107','cart\\GiveAway','',2),(190109,'1683124632.828374','origin','block-190107','Html_box','',1),(190110,'1683124632.829840','origin','block-190096','BlockBox','',5),(190111,'1683124632.831459','origin','block-190110','Html_box','',1),(190112,'1683124632.832592','origin','block-190110','cart\\ShippingEstimator','',2),(190113,'1683124632.833353','origin','block-190096-2','BlockBox','',1),(190114,'1683124632.834715','origin','block-190113','BlockBox','',2),(190115,'1683124632.835884','origin','block-190114','cart\\DiscountCoupon','',1),(190116,'1683124632.836532','origin','block-190114','Image','',4),(190117,'1683124632.844829','origin','block-190114','cart\\CheckoutBtn','',3),(190118,'1683124632.84681','origin','block-190114','cart\\OrderTotal','',2),(190119,'1683124632.846538','origin','block-190114','cart\\OrderTotal','',0),(190120,'1683124632.84726','origin','block-190113','Html_box','',1),(190121,'94658','origin','cart2','BlockBox','',2),(190122,'94659','origin','block-190121','cart\\CartTabs','',2),(190123,'94660','origin','block-190122','BlockBox','',1),(190124,'94661','origin','block-190123','BlockBox','',4),(190125,'94662','origin','block-190124','cart\\UpSell','6',2),(190126,'94663','origin','block-190124','Html_box','',1),(190127,'94664','origin','block-190123','BlockBox','',1),(190128,'94665','origin','block-190127','cart\\Products','',3),(190129,'94666','origin','block-190127','BlockBox','',2),(190130,'94667','origin','block-190129','MultiCart\\CartSwitcher','',1),(190131,'94668','origin','block-190129','MultiCart\\SaveCart','',2),(190132,'94669','origin','block-190129-2','MultiCart\\Actions','',1),(190133,'94670','origin','block-190123','BlockBox','',3),(190134,'94671','origin','block-190133','cart\\GiveAway','',2),(190135,'94672','origin','block-190133','Html_box','',1),(190136,'94673','origin','block-190123','BlockBox','',2),(190137,'94674','origin','block-190136','Html_box','',1),(190138,'94675','origin','block-190136','BlockBox','',2),(190139,'94676','origin','block-190138','cart\\DiscountCoupon','',1),(190140,'94677','origin','block-190138-2','cart\\CreditAmount','',1),(190141,'94678','origin','block-190138-3','BonusActions\\widgets\\BonusPointsCart','',1),(190142,'94679','origin','block-190123','BlockBox','',5),(190143,'94680','origin','block-190142','Html_box','',1),(190144,'94681','origin','block-190142','cart\\ShippingEstimator','',2),(190145,'94682','origin','block-190123-2','BlockBox','',1),(190146,'94683','origin','block-190145','Html_box','',1),(190147,'94684','origin','block-190145','BlockBox','',2),(190148,'94685','origin','block-190147','Image','',4),(190149,'94686','origin','block-190147','cart\\CheckoutBtn','',2),(190150,'94687','origin','block-190147','cart\\OrderTotal','',1),(190151,'73462','origin','categories','BlockBox','catalog-content',1),(190152,'73463','origin','block-190151','BlockBox','catalog-side',2),(190153,'73464','origin','block-190152','Filters','',1),(190154,'73465','origin','block-190152-2','Listing','',5),(190155,'73466','origin','block-190152-2','catalog\\Image','',1),(190156,'73467','origin','block-190152-2','BlockBox','',6),(190157,'73468','origin','block-190156','catalog\\CountsItems','',1),(190158,'73469','origin','block-190156-2','catalog\\Paging','',1),(190159,'73470','origin','block-190152-2','catalog\\ImageMapCategory','',3),(190160,'73471','origin','block-190152-2','Categories','',2),(190161,'73472','origin','block-190152-2','BlockBox','catalog-features',4),(190162,'73473','origin','block-190161','catalog\\ListingLook','',1),(190163,'73474','origin','block-190161','catalog\\CompareButton','',2),(190164,'73475','origin','block-190161','catalog\\ItemsOnPage','',4),(190165,'73476','origin','block-190161','catalog\\Sorting','',3),(190166,'73477','origin','block-190151','catalog\\Title','',1),(190167,'73478','origin','category','Categories','',1),(190168,'73479','origin','category','Listing','',4),(190169,'73480','origin','category','ListingFunctionality','',2),(190170,'73481','origin','category','PagingBar','',3),(190171,'73482','origin','category','PagingBar','',5),(190172,'94688','origin','category_2','BlockBox','',1),(190173,'94689','origin','block-190172','catalog\\Title','',1),(190174,'94690','origin','block-190172','BlockBox','',2),(190175,'94691','origin','block-190174','Filters','',1),(190176,'94692','origin','block-190174-2','catalog\\Image','',1),(190177,'94693','origin','block-190174-2','Listing','',5),(190178,'94694','origin','block-190174-2','BlockBox','',4),(190179,'94695','origin','block-190178','catalog\\Sorting','',3),(190180,'94696','origin','block-190178','catalog\\ItemsOnPage','',4),(190181,'94697','origin','block-190178','catalog\\CompareButton','',2),(190182,'94698','origin','block-190178','catalog\\ListingLook','',1),(190183,'94699','origin','block-190174-2','catalog\\ImageMapCategory','',3),(190184,'94700','origin','block-190174-2','Categories','',2),(190185,'94701','origin','block-190174-2','BlockBox','',6),(190186,'94702','origin','block-190185','catalog\\CountsItems','',1),(190187,'94703','origin','block-190185-2','catalog\\Paging','',1),(190188,'73483','origin','category_no_filters','BlockBox','',1),(190189,'73484','origin','block-190188','catalog\\Title','',1),(190190,'73485','origin','block-190188','Categories','',3),(190191,'73486','origin','block-190188','BlockBox','catalog-features',4),(190192,'73487','origin','block-190191','catalog\\ItemsOnPage','',4),(190193,'73488','origin','block-190191','catalog\\Sorting','',3),(190194,'73489','origin','block-190191','catalog\\CompareButton','',2),(190195,'73490','origin','block-190191','catalog\\ListingLook','',1),(190196,'73491','origin','block-190191','HeaderStock','',5),(190197,'73492','origin','block-190188','BlockBox','',6),(190198,'73493','origin','block-190197','catalog\\CountsItems','',1),(190199,'73494','origin','block-190197-2','catalog\\Paging','',1),(190200,'73495','origin','block-190188','Listing','',5),(190201,'73496','origin','block-190188','catalog\\Image','',2),(190202,'73497','origin','block-190188','catalog\\B2bAddButton','',7),(190203,'1683125852.345798','origin','checkout','BlockBox','',1),(190204,'1683125852.356555','origin','block-190203','BlockBox','',2),(190205,'1683125852.358412','origin','block-190204','BlockBox','',2),(190206,'1683125852.35982','origin','block-190205','BlockBox','checkout-comments',5),(190207,'1683125852.361569','origin','block-190206','checkout\\Comments','',2),(190208,'1683125852.362847','origin','block-190206','Html_box','',1),(190209,'1683125852.36485','origin','block-190205','BlockBox','checkout-discount',4),(190210,'1683125852.366422','origin','block-190209','Html_box','',1),(190211,'1683125852.367732','origin','block-190209','BlockBox','',2),(190212,'1683125852.36968','origin','block-190211','CouponsAndVauchers\\Checkout','',1),(190213,'1683125852.369745','origin','block-190211-2','checkout\\CreditAmount','',1),(190214,'1683125852.37045','origin','block-190211-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(190215,'1683125852.371233','origin','block-190205','BlockBox','checkout-shipping',2),(190216,'1683125852.37350','origin','block-190215','BlockBox','',3),(190217,'1683125852.374899','origin','block-190216','checkout\\ShippingChoice','',1),(190218,'1683125852.375685','origin','block-190215','Neighbour\\Checkout','',5),(190219,'1683125852.376557','origin','block-190215','BlockBox','',4),(190220,'1683125852.377637','origin','block-190219','BlockBox','',1),(190221,'1683125852.378829','origin','block-190220','checkout\\ShippingAddress','',2),(190222,'1683125852.379375','origin','block-190220','Html_box','',3),(190223,'1683125852.380323','origin','block-190220','checkout\\ContactInformation','',4),(190224,'1683125852.380722','origin','block-190220','UploadCustomerId\\UploadCustomerIdForm','',4),(190225,'1683125852.381183','origin','block-190219-2','BlockBox','',1),(190226,'1683125852.382226','origin','block-190225','checkout\\Shipping','',2),(190227,'1683125852.382635','origin','block-190225','DelayedDespatch\\Checkout','',3),(190228,'1683125852.383516','origin','block-190225','Html_box','',1),(190229,'1683125852.385278','origin','block-190215','Html_box','',2),(190230,'1683125852.386397','origin','block-190205','cart\\Products','',6),(190231,'1683125852.386970','origin','block-190205','checkout\\CreateAccount','',7),(190232,'1683125852.38820','origin','block-190205','BlockBox','checkout-payment',3),(190233,'1683125852.390244','origin','block-190232','Html_box','',1),(190234,'1683125852.391810','origin','block-190232','BlockBox','',2),(190235,'1683125852.393320','origin','block-190234','Html_box','',1),(190236,'1683125852.394747','origin','block-190234','checkout\\BillingAddress','',2),(190237,'1683125852.395767','origin','block-190234-2','BlockBox','',1),(190238,'1683125852.397129','origin','block-190237','checkout\\PaymentMethod','',2),(190239,'1683125852.398588','origin','block-190237','Html_box','',1),(190240,'1683125852.400291','origin','block-190205','BlockBox','',1),(190241,'1683125852.402237','origin','block-190240','checkout\\LoginOnForm','',0),(190242,'1683128325.0836','origin','block-190240','BlockBox','',1),(190243,'1683125852.403563','origin','block-190204-2','BlockBox','checkout-side',1),(190244,'1683125852.405625','origin','block-190243','Html_box','',6),(190245,'1683125852.407666','origin','block-190243','Html_box','',1),(190246,'1683125852.40885','origin','block-190243','checkout\\Terms','',5),(190247,'1683125852.409688','origin','block-190243','checkout\\Totals','',3),(190248,'1683125852.410151','origin','block-190243','checkout\\ContinueBtn','',4),(190249,'1683125852.412647','origin','block-190243','cart\\Products','',2),(190250,'73542','origin','checkout_confirmation','BlockBox','',1),(190251,'73543','origin','block-190250','checkout\\Totals','',8),(190252,'73544','origin','block-190250','Html_box','',5),(190253,'73545','origin','block-190250','checkout\\EditBtn','',6),(190254,'73546','origin','block-190250','BlockBox','',3),(190255,'73547','origin','block-190254','BlockBox','',1),(190256,'73548','origin','block-190255','Html_box','',1),(190257,'73549','origin','block-190255','checkout\\ShippingConfirm','',3),(190258,'73550','origin','block-190254-2','BlockBox','',1),(190259,'73551','origin','block-190258','checkout\\PaymentMethodConfirm','',3),(190260,'73552','origin','block-190258','Html_box','',1),(190261,'73553','origin','block-190250','checkout\\ConfirmBtn','',9),(190262,'73554','origin','block-190250','BlockBox','',2),(190263,'73555','origin','block-190262','BlockBox','',1),(190264,'73556','origin','block-190263','checkout\\ShippingAddressConfirm','',3),(190265,'73557','origin','block-190263','Html_box','',1),(190266,'73558','origin','block-190262-2','BlockBox','',1),(190267,'73559','origin','block-190266','Html_box','',1),(190268,'73560','origin','block-190266','checkout\\BillingAddressConfirm','',3),(190269,'73561','origin','block-190250','checkout\\ConfirmBtn','',4),(190270,'73562','origin','block-190250','cart\\Products','',7),(190271,'73576','origin','checkout_confirmation_no_shipping','BlockBox','',1),(190272,'73577','origin','block-190271','checkout\\ConfirmBtn','',9),(190273,'73578','origin','block-190271','BlockBox','',2),(190274,'73579','origin','block-190273','BlockBox','',1),(190275,'73580','origin','block-190274','Html_box','',1),(190276,'73581','origin','block-190274','checkout\\BillingAddressConfirm','',3),(190277,'73582','origin','block-190273-2','BlockBox','',1),(190278,'73583','origin','block-190277','Html_box','',1),(190279,'73584','origin','block-190277','checkout\\PaymentMethodConfirm','',3),(190280,'73585','origin','block-190271','checkout\\ConfirmBtn','',4),(190281,'73586','origin','block-190271','checkout\\Totals','',8),(190282,'73587','origin','block-190271','cart\\Products','',7),(190283,'73588','origin','block-190271','Html_box','',5),(190284,'73563','origin','checkout_confirmation_no_shipping_q','BlockBox','',1),(190285,'73564','origin','block-190284','quote\\Products','',4),(190286,'73565','origin','block-190284','checkout\\ConfirmBtn','',2),(190287,'73566','origin','block-190284','checkout\\ConfirmBtn','',6),(190288,'73567','origin','block-190284','BlockBox','',1),(190289,'73568','origin','block-190288','BlockBox','',1),(190290,'73569','origin','block-190289','checkout\\BillingAddressConfirm','',3),(190291,'73570','origin','block-190289','Html_box','',1),(190292,'73571','origin','block-190288-2','BlockBox','',1),(190293,'73572','origin','block-190292','checkout\\PaymentMethodConfirm','',3),(190294,'73573','origin','block-190292','Html_box','',1),(190295,'73574','origin','block-190284','Html_box','',3),(190296,'73575','origin','block-190284','checkout\\Totals','',5),(190297,'73589','origin','checkout_confirmation_q','BlockBox','',1),(190298,'73590','origin','block-190297','BlockBox','',1),(190299,'73591','origin','block-190298','BlockBox','',1),(190300,'73592','origin','block-190299','checkout\\ShippingAddressConfirm','',3),(190301,'73593','origin','block-190299','Html_box','',1),(190302,'73594','origin','block-190298-2','BlockBox','',1),(190303,'73595','origin','block-190302','checkout\\BillingAddressConfirm','',3),(190304,'73596','origin','block-190302','Html_box','',1),(190305,'73597','origin','block-190297','checkout\\Totals','',7),(190306,'73598','origin','block-190297','quote\\Products','',6),(190307,'73599','origin','block-190297','Html_box','',4),(190308,'73600','origin','block-190297','checkout\\EditBtn','',5),(190309,'73601','origin','block-190297','checkout\\ConfirmBtn','',8),(190310,'73602','origin','block-190297','checkout\\ConfirmBtn','',3),(190311,'73603','origin','block-190297','BlockBox','',2),(190312,'73604','origin','block-190311','BlockBox','',1),(190313,'73605','origin','block-190312','Html_box','',1),(190314,'73606','origin','block-190312','checkout\\ShippingConfirm','',3),(190315,'73607','origin','block-190311-2','BlockBox','',1),(190316,'73608','origin','block-190315','Html_box','',1),(190317,'73609','origin','block-190315','checkout\\PaymentMethodConfirm','',3),(190318,'73610','origin','checkout_confirmation_title','Html_box','',1),(190319,'73611','origin','checkout_confirmation_title_g','Html_box','',1),(190320,'73613','origin','checkout_confirmation_title_no_shipping','Html_box','',1),(190321,'73612','origin','checkout_confirmation_title_no_shipping_g','Html_box','',1),(190322,'73614','origin','checkout_confirmation_title_q','Html_box','',1),(190323,'73615','origin','checkout_confirmation_title_s','Html_box','',1),(190324,'73616','origin','checkout_delivery','BlockBox','',2),(190325,'73617','origin','block-190324','BlockBox','',1),(190326,'73618','origin','block-190325','Html_box','',1),(190327,'73619','origin','block-190325','checkout\\ContactInformation','',2),(190328,'73620','origin','block-190324-2','BlockBox','',1),(190329,'73621','origin','block-190328','Html_box','',1),(190330,'73622','origin','block-190328','checkout\\Comments','',2),(190331,'73623','origin','checkout_delivery','BlockBox','',3),(190332,'73624','origin','block-190331','Html_box','',1),(190333,'73625','origin','block-190331-2','checkout\\ContinueBtn','',1),(190334,'73626','origin','checkout_delivery','BlockBox','',1),(190335,'73627','origin','block-190334','BlockBox','',1),(190336,'73628','origin','block-190335','Html_box','',1),(190337,'73629','origin','block-190335','checkout\\ShippingAddress','',2),(190338,'73630','origin','block-190334-2','BlockBox','',1),(190339,'73631','origin','block-190338','DelayedDespatch\\Checkout','',3),(190340,'73632','origin','block-190338','checkout\\Shipping','',2),(190341,'73633','origin','block-190338','Html_box','',1),(190342,'73634','origin','block-190338','Neighbour\\Checkout','',4),(190343,'73635','origin','checkout_delivery_g','BlockBox','',2),(190344,'73636','origin','block-190343','BlockBox','',1),(190345,'73637','origin','block-190344','checkout\\ContactInformation','',2),(190346,'73638','origin','block-190344','Html_box','',1),(190347,'73639','origin','block-190343-2','BlockBox','',1),(190348,'73640','origin','block-190347','Html_box','',1),(190349,'73641','origin','block-190347','checkout\\Comments','',2),(190350,'73642','origin','checkout_delivery_g','BlockBox','',3),(190351,'73643','origin','block-190350','Html_box','',1),(190352,'73644','origin','block-190350-2','checkout\\ContinueBtn','',1),(190353,'73645','origin','checkout_delivery_g','BlockBox','',1),(190354,'73646','origin','block-190353','BlockBox','',1),(190355,'73647','origin','block-190354','checkout\\ShippingAddress','',2),(190356,'73648','origin','block-190354','Html_box','',1),(190357,'73649','origin','block-190353-2','BlockBox','',1),(190358,'73650','origin','block-190357','checkout\\Shipping','',2),(190359,'73651','origin','block-190357','Html_box','',1),(190360,'73652','origin','block-190357','DelayedDespatch\\Checkout','',3),(190361,'73653','origin','block-190357','Neighbour\\Checkout','',4),(190362,'73654','origin','checkout_delivery_no_shipping','BlockBox','',2),(190363,'73655','origin','block-190362','Html_box','',1),(190364,'73656','origin','block-190362-2','checkout\\ContinueBtn','',1),(190365,'73657','origin','checkout_delivery_no_shipping','BlockBox','',1),(190366,'73658','origin','block-190365','BlockBox','',1),(190367,'73659','origin','block-190366','checkout\\ContactInformation','',2),(190368,'73660','origin','block-190365-2','BlockBox','',1),(190369,'73661','origin','block-190368','Html_box','',1),(190370,'73662','origin','block-190368','checkout\\Comments','',2),(190371,'73663','origin','checkout_delivery_no_shipping_g','BlockBox','',2),(190372,'73664','origin','block-190371','Html_box','',1),(190373,'73665','origin','block-190371-2','checkout\\ContinueBtn','',1),(190374,'73666','origin','checkout_delivery_no_shipping_g','BlockBox','',1),(190375,'73667','origin','block-190374','BlockBox','',1),(190376,'73668','origin','block-190375','checkout\\ContactInformation','',2),(190377,'73669','origin','block-190374-2','BlockBox','',1),(190378,'73670','origin','block-190377','checkout\\Comments','',2),(190379,'73671','origin','block-190377','Html_box','',1),(190380,'73672','origin','checkout_delivery_title','Html_box','',1),(190381,'73673','origin','checkout_delivery_title_g','Html_box','',1),(190382,'73675','origin','checkout_delivery_title_no_shipping','Html_box','',1),(190383,'73674','origin','checkout_delivery_title_no_shipping_g','Html_box','',1),(190384,'73676','origin','checkout_delivery_title_q','Html_box','',1),(190385,'73677','origin','checkout_delivery_title_s','Html_box','',1),(190386,'73678','origin','checkout_free_s','BlockBox','',1),(190387,'73679','origin','block-190386','BlockBox','',2),(190388,'73680','origin','block-190387','BlockBox','',2),(190389,'73682','origin','block-190388','BlockBox','',6),(190390,'73683','origin','block-190389','sample\\Products','',1),(190391,'73684','origin','block-190389','checkout\\CreateAccount','',3),(190392,'73685','origin','block-190388','BlockBox','',5),(190393,'73686','origin','block-190392','Html_box','',1),(190394,'73687','origin','block-190392','checkout\\Comments','',2),(190395,'73688','origin','block-190388','BlockBox','',2),(190396,'73689','origin','block-190395','BlockBox','',2),(190397,'73690','origin','block-190396','checkout\\ShippingChoice','',1),(190398,'73691','origin','block-190395','Html_box','',1),(190399,'73692','origin','block-190395','BlockBox','',3),(190400,'73693','origin','block-190399','BlockBox','',1),(190401,'73694','origin','block-190400','checkout\\ContactInformation','',4),(190402,'73695','origin','block-190400','checkout\\ShippingAddress','',2),(190403,'73696','origin','block-190400','Html_box','',3),(190404,'73697','origin','block-190399-2','BlockBox','',1),(190405,'73698','origin','block-190404','DelayedDespatch\\Checkout','',3),(190406,'73699','origin','block-190395','Neighbour\\Checkout','',4),(190407,'73700','origin','block-190387-2','BlockBox','',1),(190408,'73701','origin','block-190407','Html_box','',3),(190409,'73702','origin','block-190407','checkout\\ContinueBtn','',1),(190410,'115999','origin','block-190407','checkout\\Terms','',2),(190411,'73703','origin','checkout_no_shipping','BlockBox','',1),(190412,'73704','origin','block-190411','BlockBox','',2),(190413,'73705','origin','block-190412','BlockBox','',1),(190414,'73706','origin','block-190413','BlockBox','',6),(190415,'73707','origin','block-190414','checkout\\CreateAccount','',2),(190416,'73708','origin','block-190414','cart\\Products','',1),(190417,'73709','origin','block-190413','BlockBox','',3),(190418,'73710','origin','block-190417','Html_box','',1),(190419,'73711','origin','block-190417','BlockBox','',2),(190420,'73712','origin','block-190419','checkout\\BillingAddress','',2),(190421,'73713','origin','block-190419','Html_box','',1),(190422,'73714','origin','block-190419-2','BlockBox','',1),(190423,'73715','origin','block-190422','Html_box','',1),(190424,'73716','origin','block-190422','checkout\\PaymentMethod','',2),(190425,'73717','origin','block-190413','BlockBox','',4),(190426,'73718','origin','block-190425','BlockBox','',2),(190427,'73719','origin','block-190426','CouponsAndVauchers\\Checkout','',1),(190428,'73720','origin','block-190426-2','checkout\\CreditAmount','',1),(190429,'73721','origin','block-190426-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(190430,'73722','origin','block-190425','Html_box','',1),(190431,'73723','origin','block-190413','BlockBox','',5),(190432,'73724','origin','block-190431','checkout\\Comments','',2),(190433,'73725','origin','block-190431','Html_box','',1),(190434,'73726','origin','block-190412-2','BlockBox','',1),(190435,'73727','origin','block-190434','Html_box','',1),(190436,'73728','origin','block-190434','Html_box','',5),(190437,'73729','origin','block-190434','checkout\\Totals','',2),(190438,'73730','origin','block-190434','checkout\\ContinueBtn','',3),(190439,'73731','origin','block-190434','checkout\\Terms','',4),(190440,'73732','origin','checkout_no_shipping_g','BlockBox','',1),(190441,'73733','origin','block-190440','checkout\\Totals','',5),(190442,'73734','origin','block-190440','BlockBox','',6),(190443,'73735','origin','block-190442','Html_box','',1),(190444,'73736','origin','block-190442-2','checkout\\ContinueBtn','',1),(190445,'73737','origin','block-190440','BlockBox','',2),(190446,'73738','origin','block-190445','BlockBox','',1),(190447,'73739','origin','block-190446','checkout\\ContactInformation','',2),(190448,'73740','origin','block-190446','Html_box','',1),(190449,'73741','origin','block-190445-2','BlockBox','',1),(190450,'73742','origin','block-190449','checkout\\Comments','',2),(190451,'73743','origin','block-190449','Html_box','',1),(190452,'73744','origin','block-190440','BlockBox','',1),(190453,'73745','origin','block-190452','BlockBox','',1),(190454,'73746','origin','block-190453','Html_box','',1),(190455,'73747','origin','block-190453','checkout\\BillingAddress','',2),(190456,'73748','origin','block-190452-2','BlockBox','',1),(190457,'73749','origin','block-190456','BonusActions\\widgets\\BonusPointsCheckout','',4),(190458,'73750','origin','block-190456','CouponsAndVauchers\\Checkout','',5),(190459,'73751','origin','block-190456','checkout\\PaymentMethod','',2),(190460,'73752','origin','block-190456','checkout\\CreditAmount','',3),(190461,'73753','origin','block-190456','Html_box','',1),(190462,'73754','origin','block-190440','quote\\Products','',3),(190463,'73755','origin','checkout_no_shipping_q','BlockBox','',1),(190464,'73756','origin','block-190463','BlockBox','',2),(190465,'73757','origin','block-190464','BlockBox','',2),(190466,'73758','origin','block-190465','checkout\\Gdpr','',1),(190467,'73759','origin','block-190465','BlockBox','',5),(190468,'73760','origin','block-190467','checkout\\Comments','',2),(190469,'73761','origin','block-190467','Html_box','',1),(190470,'73762','origin','block-190465','BlockBox','',6),(190471,'73763','origin','block-190470','checkout\\CreateAccount','',3),(190472,'73764','origin','block-190470','quote\\Products','',2),(190473,'73765','origin','block-190465','BlockBox','',3),(190474,'73766','origin','block-190473','Html_box','',1),(190475,'73767','origin','block-190473','BlockBox','',2),(190476,'73768','origin','block-190475','Html_box','',1),(190477,'73769','origin','block-190475','checkout\\BillingAddress','',2),(190478,'73770','origin','block-190475-2','BlockBox','',1),(190479,'73771','origin','block-190478','checkout\\PaymentMethod','',2),(190480,'73772','origin','block-190478','Html_box','',1),(190481,'73773','origin','block-190464-2','BlockBox','',1),(190482,'73774','origin','block-190481','checkout\\ContinueBtn','',3),(190483,'73775','origin','block-190481','Html_box','',4),(190484,'73776','origin','block-190481','Html_box','',1),(190485,'73777','origin','block-190481','checkout\\Totals','',2),(190486,'73778','origin','checkout_payment','BlockBox','',1),(190487,'73779','origin','block-190486','BlockBox','',1),(190488,'73780','origin','block-190487','checkout\\BillingAddress','',2),(190489,'73781','origin','block-190487','Html_box','',1),(190490,'73782','origin','block-190486-2','BlockBox','',1),(190491,'73783','origin','block-190490','checkout\\CreditAmount','',3),(190492,'73784','origin','block-190490','BonusActions\\widgets\\BonusPointsCheckout','',4),(190493,'73785','origin','block-190490','CouponsAndVauchers\\Checkout','',5),(190494,'73786','origin','block-190490','checkout\\PaymentMethod','',2),(190495,'73787','origin','block-190490','Html_box','',1),(190496,'73788','origin','checkout_payment','BlockBox','',2),(190497,'73789','origin','block-190496','Html_box','',1),(190498,'73790','origin','block-190496-2','checkout\\ContinueBtn','',1),(190499,'73791','origin','checkout_payment_g','BlockBox','',1),(190500,'73792','origin','block-190499','BlockBox','',1),(190501,'73793','origin','block-190500','checkout\\BillingAddress','',2),(190502,'73794','origin','block-190500','Html_box','',1),(190503,'73795','origin','block-190499-2','BlockBox','',1),(190504,'73796','origin','block-190503','checkout\\CreditAmount','',3),(190505,'73797','origin','block-190503','Html_box','',1),(190506,'73798','origin','block-190503','checkout\\PaymentMethod','',2),(190507,'73799','origin','block-190503','CouponsAndVauchers\\Checkout','',5),(190508,'73800','origin','block-190503','BonusActions\\widgets\\BonusPointsCheckout','',4),(190509,'73801','origin','checkout_payment_g','BlockBox','',2),(190510,'73802','origin','block-190509','Html_box','',1),(190511,'73803','origin','block-190509-2','checkout\\ContinueBtn','',1),(190512,'73804','origin','checkout_payment_no_shipping','BlockBox','',2),(190513,'73805','origin','block-190512','Html_box','',1),(190514,'73806','origin','block-190512-2','checkout\\ContinueBtn','',1),(190515,'73807','origin','checkout_payment_no_shipping','BlockBox','',1),(190516,'73808','origin','block-190515','BlockBox','',1),(190517,'73809','origin','block-190516','Html_box','',1),(190518,'73810','origin','block-190516','checkout\\BillingAddress','',2),(190519,'73811','origin','block-190515-2','BlockBox','',1),(190520,'73812','origin','block-190519','BonusActions\\widgets\\BonusPointsCheckout','',4),(190521,'73813','origin','block-190519','CouponsAndVauchers\\Checkout','',5),(190522,'73814','origin','block-190519','checkout\\PaymentMethod','',2),(190523,'73815','origin','block-190519','checkout\\CreditAmount','',3),(190524,'73816','origin','block-190519','Html_box','',1),(190525,'73817','origin','checkout_payment_no_shipping_g','BlockBox','',2),(190526,'73818','origin','block-190525','Html_box','',1),(190527,'73819','origin','block-190525-2','checkout\\ContinueBtn','',1),(190528,'73820','origin','checkout_payment_no_shipping_g','BlockBox','',1),(190529,'73821','origin','block-190528','BlockBox','',1),(190530,'73822','origin','block-190529','checkout\\BillingAddress','',2),(190531,'73823','origin','block-190529','Html_box','',1),(190532,'73824','origin','block-190528-2','BlockBox','',1),(190533,'73825','origin','block-190532','BonusActions\\widgets\\BonusPointsCheckout','',4),(190534,'73826','origin','block-190532','checkout\\CreditAmount','',3),(190535,'73827','origin','block-190532','checkout\\PaymentMethod','',2),(190536,'73828','origin','block-190532','Html_box','',1),(190537,'73829','origin','block-190532','CouponsAndVauchers\\Checkout','',5),(190538,'73830','origin','checkout_payment_title','Html_box','',1),(190539,'73831','origin','checkout_payment_title_g','Html_box','',1),(190540,'73832','origin','checkout_payment_title_no_shipping','Html_box','',1),(190541,'73833','origin','checkout_payment_title_no_shipping_g','Html_box','',1),(190542,'73834','origin','checkout_payment_title_q','Html_box','',1),(190543,'73835','origin','checkout_payment_title_s','Html_box','',1),(190544,'73836','origin','checkout_q','BlockBox','',1),(190545,'73837','origin','block-190544','BlockBox','',2),(190546,'73838','origin','block-190545','BlockBox','',2),(190547,'73839','origin','block-190546','BlockBox','',6),(190548,'73840','origin','block-190547','checkout\\CreateAccount','',3),(190549,'73841','origin','block-190547','quote\\Products','',2),(190550,'73842','origin','block-190546','BlockBox','',2),(190551,'73843','origin','block-190550','BlockBox','',2),(190552,'73844','origin','block-190551','checkout\\ShippingChoice','',1),(190553,'73845','origin','block-190550','Neighbour\\Checkout','',4),(190554,'73846','origin','block-190550','Html_box','',1),(190555,'73847','origin','block-190550','BlockBox','',3),(190556,'73848','origin','block-190555','BlockBox','',1),(190557,'73849','origin','block-190556','checkout\\ContactInformation','',4),(190558,'73850','origin','block-190556','checkout\\ShippingAddress','',2),(190559,'73851','origin','block-190556','Html_box','',3),(190560,'73852','origin','block-190555-2','BlockBox','',1),(190561,'73853','origin','block-190560','checkout\\Shipping','',2),(190562,'73854','origin','block-190560','Html_box','',1),(190563,'73855','origin','block-190560','DelayedDespatch\\Checkout','',3),(190564,'73856','origin','block-190546','BlockBox','',5),(190565,'73857','origin','block-190564','Html_box','',1),(190566,'73858','origin','block-190564','checkout\\Comments','',2),(190567,'73860','origin','block-190546','BlockBox','',3),(190568,'73861','origin','block-190567','Html_box','',1),(190569,'73862','origin','block-190567','BlockBox','',2),(190570,'73863','origin','block-190569','checkout\\BillingAddress','',2),(190571,'73864','origin','block-190569','Html_box','',1),(190572,'73865','origin','block-190569-2','BlockBox','',1),(190573,'73866','origin','block-190572','checkout\\PaymentMethod','',2),(190574,'73867','origin','block-190572','Html_box','',1),(190575,'73868','origin','block-190545-2','BlockBox','',1),(190576,'73869','origin','block-190575','Html_box','',1),(190577,'73870','origin','block-190575','Html_box','',5),(190578,'73871','origin','block-190575','checkout\\Totals','',2),(190579,'73872','origin','block-190575','checkout\\ContinueBtn','',3),(190580,'115996','origin','block-190575','checkout\\Terms','',4),(190581,'73873','origin','checkout_s','BlockBox','',1),(190582,'73874','origin','block-190581','BlockBox','',2),(190583,'73875','origin','block-190582','BlockBox','',2),(190584,'73876','origin','block-190583','checkout\\Gdpr','',1),(190585,'73877','origin','block-190583','BlockBox','',6),(190586,'73878','origin','block-190585','sample\\Products','',1),(190587,'73879','origin','block-190585','checkout\\CreateAccount','',3),(190588,'73880','origin','block-190583','BlockBox','',2),(190589,'73881','origin','block-190588','Html_box','',1),(190590,'73882','origin','block-190588','Neighbour\\Checkout','',4),(190591,'73883','origin','block-190588','BlockBox','',2),(190592,'73884','origin','block-190591','checkout\\ShippingChoice','',1),(190593,'73885','origin','block-190588','BlockBox','',3),(190594,'73886','origin','block-190593','BlockBox','',1),(190595,'73887','origin','block-190594','checkout\\ShippingAddress','',2),(190596,'73888','origin','block-190594','checkout\\ContactInformation','',4),(190597,'73889','origin','block-190594','Html_box','',3),(190598,'73890','origin','block-190593-2','BlockBox','',1),(190599,'73891','origin','block-190598','checkout\\Shipping','',2),(190600,'73892','origin','block-190598','DelayedDespatch\\Checkout','',3),(190601,'73893','origin','block-190598','Html_box','',1),(190602,'73894','origin','block-190583','BlockBox','',3),(190603,'73895','origin','block-190602','BlockBox','',2),(190604,'73896','origin','block-190603','Html_box','',1),(190605,'73897','origin','block-190603','checkout\\BillingAddress','',2),(190606,'73898','origin','block-190603-2','BlockBox','',1),(190607,'73899','origin','block-190606','Html_box','',1),(190608,'73900','origin','block-190606','checkout\\PaymentMethod','',2),(190609,'73901','origin','block-190602','Html_box','',1),(190610,'73902','origin','block-190583','BlockBox','',5),(190611,'73903','origin','block-190610','Html_box','',1),(190612,'73904','origin','block-190610','checkout\\Comments','',2),(190613,'73905','origin','block-190583','BlockBox','',4),(190614,'73906','origin','block-190613','BlockBox','',2),(190615,'73907','origin','block-190614','CouponsAndVauchers\\Checkout','',1),(190616,'73908','origin','block-190614-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(190617,'73909','origin','block-190614-2','checkout\\CreditAmount','',1),(190618,'73910','origin','block-190613','Html_box','',1),(190619,'73911','origin','block-190582-2','BlockBox','',1),(190620,'73912','origin','block-190619','checkout\\Totals','',2),(190621,'73913','origin','block-190619','Html_box','',5),(190622,'73914','origin','block-190619','Html_box','',1),(190623,'73915','origin','block-190619','checkout\\ContinueBtn','',3),(190624,'115998','origin','block-190619','checkout\\Terms','',4),(190625,'73916','origin','checkout_step_bottom','Html_box','',1),(190626,'73917','origin','checkout_step_bottom','cart\\Products','',2),(190627,'73918','origin','checkout_step_bottom','checkout\\Totals','',3),(190628,'73919','origin','checkout_step_bottom_g','checkout\\Totals','',3),(190629,'73920','origin','checkout_step_bottom_g','quote\\Products','',2),(190630,'73921','origin','checkout_step_bottom_g','Html_box','',1),(190631,'73923','origin','checkout_step_bottom_no_shipping','Html_box','',1),(190632,'73924','origin','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(190633,'73927','origin','checkout_step_bottom_no_shipping','cart\\Products','',2),(190634,'73922','origin','checkout_step_bottom_no_shipping_g','Html_box','',1),(190635,'73925','origin','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(190636,'73926','origin','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(190637,'73928','origin','communication','BlockBox','',1),(190638,'73929','origin','block-190637','Html_box','',2),(190639,'73930','origin','block-190637','Communication\\NewTopicButton','',1),(190640,'73931','origin','block-190637','Communication\\Topic','',3),(190641,'94704','origin','compare','BlockBox','',1),(190642,'94705','origin','block-190641','catalog\\Compare','',1),(190643,'94706','origin','compare_products','BlockBox','',2),(190644,'94707','origin','block-190643','productListing\\rating','',4),(190645,'94708','origin','block-190643','productListing\\model','',5),(190646,'94709','origin','block-190643','productListing\\compare','',1),(190647,'94710','origin','block-190643','BlockBox','',2),(190648,'94711','origin','block-190647','productListing\\image','',1),(190649,'94712','origin','block-190647-2','productListing\\name','',2),(190650,'94713','origin','block-190643','BlockBox','',3),(190651,'94714','origin','block-190650','productListing\\price','',1),(190652,'94715','origin','block-190650-2','productListing\\buyButton','',1),(190653,'73932','origin','confirmation','BlockBox','',1),(190654,'73933','origin','block-190653','BlockBox','',2),(190655,'73934','origin','block-190654','BlockBox','',2),(190656,'73935','origin','block-190655','BlockBox','',3),(190657,'73936','origin','block-190656','checkout\\EditBtn','',2),(190658,'73937','origin','block-190656','cart\\Products','',3),(190659,'73938','origin','block-190656','Html_box','',1),(190660,'73939','origin','block-190655','BlockBox','',2),(190661,'73940','origin','block-190660','checkout\\EditBtn','',2),(190662,'73941','origin','block-190660','Html_box','',1),(190663,'73942','origin','block-190660','checkout\\CommentsConfirm','',3),(190664,'73943','origin','block-190655','BlockBox','',1),(190665,'73944','origin','block-190664','BlockBox','',1),(190666,'73945','origin','block-190665','checkout\\EditBtn','',6),(190667,'73946','origin','block-190665','DelayedDespatch\\CheckoutConfirm','',8),(190668,'73947','origin','block-190665','Html_box','',9),(190669,'73948','origin','block-190665','checkout\\EditBtn','',10),(190670,'73949','origin','block-190665','Html_box','',5),(190671,'73950','origin','block-190665','checkout\\ShippingConfirm','',7),(190672,'73951','origin','block-190665','Html_box','',1),(190673,'73952','origin','block-190665','checkout\\EditBtn','',3),(190674,'73953','origin','block-190665','checkout\\ContactConfirm','',11),(190675,'73954','origin','block-190665','Html_box','',2),(190676,'73955','origin','block-190665','checkout\\ShippingAddressConfirm','',4),(190677,'73956','origin','block-190664-2','BlockBox','',1),(190678,'73957','origin','block-190677','checkout\\EditBtn','',6),(190679,'73958','origin','block-190677','checkout\\EditBtn','',3),(190680,'73959','origin','block-190677','checkout\\PaymentMethodConfirm','',7),(190681,'73960','origin','block-190677','Html_box','',5),(190682,'73961','origin','block-190677','Html_box','',1),(190683,'73962','origin','block-190677','checkout\\BillingAddressConfirm','',4),(190684,'73963','origin','block-190677','Html_box','',2),(190685,'73964','origin','block-190654','UploadCustomerId\\UploadCustomerIdForm','',1),(190686,'73965','origin','block-190654-2','BlockBox','',1),(190687,'73966','origin','block-190686','Html_box','',1),(190688,'73967','origin','block-190686','checkout\\ConfirmBtn','',3),(190689,'73968','origin','block-190686','checkout\\Totals','',2),(190690,'73969','origin','block-190653','Html_box','',1),(190691,'73970','origin','confirmation_free_s','BlockBox','',1),(190692,'73971','origin','block-190691','BlockBox','',2),(190693,'73972','origin','block-190692','BlockBox','',1),(190694,'73973','origin','block-190693','BlockBox','',2),(190695,'73974','origin','block-190694','checkout\\CommentsConfirm','',3),(190696,'73975','origin','block-190694','checkout\\EditBtn','',2),(190697,'73976','origin','block-190694','Html_box','',1),(190698,'73977','origin','block-190693','BlockBox','',3),(190699,'73978','origin','block-190698','checkout\\EditBtn','',3),(190700,'73979','origin','block-190698','Html_box','',1),(190701,'73980','origin','block-190698','sample\\Products','',2),(190702,'73981','origin','block-190693','BlockBox','',1),(190703,'73982','origin','block-190702','BlockBox','',1),(190704,'73983','origin','block-190703','checkout\\EditBtn','',3),(190705,'73984','origin','block-190703','checkout\\ShippingConfirm','',7),(190706,'73985','origin','block-190703','Html_box','',5),(190707,'73986','origin','block-190703','checkout\\EditBtn','',6),(190708,'73987','origin','block-190703','Html_box','',2),(190709,'73988','origin','block-190703','checkout\\ShippingAddressConfirm','',4),(190710,'73989','origin','block-190702-2','BlockBox','',1),(190711,'73990','origin','block-190710','checkout\\ContactConfirm','',3),(190712,'73991','origin','block-190710','DelayedDespatch\\CheckoutConfirm','',4),(190713,'73992','origin','block-190710','checkout\\EditBtn','',2),(190714,'73993','origin','block-190710','Html_box','',1),(190715,'73994','origin','block-190692-2','BlockBox','',1),(190716,'73995','origin','block-190715','checkout\\ConfirmBtn','',3),(190717,'73996','origin','block-190691','Html_box','',1),(190718,'73997','origin','confirmation_no_shipping','BlockBox','',1),(190719,'73998','origin','block-190718','Html_box','',1),(190720,'73999','origin','block-190718','BlockBox','',2),(190721,'74000','origin','block-190720','BlockBox','',1),(190722,'74001','origin','block-190721','BlockBox','',1),(190723,'74002','origin','block-190722','BlockBox','',1),(190724,'74003','origin','block-190723','checkout\\EditBtn','',10),(190725,'74004','origin','block-190723','Html_box','',9),(190726,'74005','origin','block-190723','checkout\\ContactConfirm','',11),(190727,'74006','origin','block-190722-2','BlockBox','',1),(190728,'74007','origin','block-190727','checkout\\PaymentMethodConfirm','',7),(190729,'74008','origin','block-190727','checkout\\EditBtn','',6),(190730,'74009','origin','block-190727','Html_box','',5),(190731,'74010','origin','block-190727','Html_box','',1),(190732,'74011','origin','block-190727','checkout\\EditBtn','',3),(190733,'74012','origin','block-190727','checkout\\BillingAddressConfirm','',4),(190734,'74013','origin','block-190727','Html_box','',2),(190735,'74014','origin','block-190721','BlockBox','',2),(190736,'74015','origin','block-190735','Html_box','',1),(190737,'74016','origin','block-190735','checkout\\CommentsConfirm','',3),(190738,'74017','origin','block-190735','checkout\\EditBtn','',2),(190739,'74018','origin','block-190721','BlockBox','',3),(190740,'74019','origin','block-190739','Html_box','',1),(190741,'74020','origin','block-190739','checkout\\EditBtn','',2),(190742,'74021','origin','block-190739','cart\\Products','',3),(190743,'74022','origin','block-190720-2','BlockBox','',1),(190744,'74023','origin','block-190743','checkout\\ConfirmBtn','',3),(190745,'74024','origin','block-190743','Html_box','',1),(190746,'74025','origin','block-190743','checkout\\Totals','',2),(190747,'74026','origin','confirmation_no_shipping_q','BlockBox','',2),(190748,'74027','origin','block-190747','Html_box','',1),(190749,'74028','origin','block-190747','BlockBox','',2),(190750,'74029','origin','block-190749','BlockBox','',1),(190751,'74030','origin','block-190750','BlockBox','',2),(190752,'74031','origin','block-190751','Html_box','',1),(190753,'74032','origin','block-190751','checkout\\CommentsConfirm','',3),(190754,'74033','origin','block-190751','checkout\\EditBtn','',2),(190755,'74034','origin','block-190750','BlockBox','',1),(190756,'74035','origin','block-190755','BlockBox','',1),(190757,'74036','origin','block-190756','checkout\\EditBtn','',5),(190758,'74037','origin','block-190756','checkout\\ContactConfirm','',6),(190759,'74038','origin','block-190756','checkout\\PaymentMethodConfirm','',3),(190760,'74039','origin','block-190756','checkout\\EditBtn','',2),(190761,'74040','origin','block-190756','Html_box','',4),(190762,'74041','origin','block-190756','Html_box','',1),(190763,'74042','origin','block-190755-2','BlockBox','',1),(190764,'74043','origin','block-190763','checkout\\BillingAddressConfirm','',4),(190765,'74044','origin','block-190763','checkout\\EditBtn','',3),(190766,'74045','origin','block-190763','Html_box','',2),(190767,'74046','origin','block-190750','BlockBox','',3),(190768,'74047','origin','block-190767','checkout\\EditBtn','',2),(190769,'74048','origin','block-190767','Html_box','',1),(190770,'74049','origin','block-190767','quote\\Products','',3),(190771,'74050','origin','block-190749-2','BlockBox','',1),(190772,'74051','origin','block-190771','checkout\\ConfirmBtn','',3),(190773,'74052','origin','block-190771','checkout\\Totals','',2),(190774,'74053','origin','block-190771','Html_box','',1),(190775,'74054','origin','confirmation_q','BlockBox','',1),(190776,'74055','origin','block-190775','Html_box','',1),(190777,'74056','origin','block-190775','BlockBox','',2),(190778,'74057','origin','block-190777','BlockBox','',1),(190779,'74058','origin','block-190778','BlockBox','',3),(190780,'74059','origin','block-190779','quote\\Products','',3),(190781,'74060','origin','block-190779','Html_box','',1),(190782,'74061','origin','block-190779','checkout\\EditBtn','',2),(190783,'74062','origin','block-190778','BlockBox','',1),(190784,'74063','origin','block-190783','BlockBox','',1),(190785,'74064','origin','block-190784','Html_box','',1),(190786,'74065','origin','block-190784','checkout\\EditBtn','',10),(190787,'74066','origin','block-190784','Html_box','',2),(190788,'74067','origin','block-190784','checkout\\ContactConfirm','',11),(190789,'74068','origin','block-190784','checkout\\ShippingAddressConfirm','',4),(190790,'74069','origin','block-190784','checkout\\ShippingConfirm','',7),(190791,'74070','origin','block-190784','checkout\\EditBtn','',3),(190792,'74071','origin','block-190784','DelayedDespatch\\CheckoutConfirm','',8),(190793,'74072','origin','block-190784','Html_box','',9),(190794,'74073','origin','block-190784','Html_box','',5),(190795,'74074','origin','block-190784','checkout\\EditBtn','',6),(190796,'74075','origin','block-190783-2','BlockBox','',1),(190797,'74076','origin','block-190796','checkout\\EditBtn','',3),(190798,'74077','origin','block-190796','checkout\\BillingAddressConfirm','',4),(190799,'74078','origin','block-190796','checkout\\PaymentMethodConfirm','',7),(190800,'74079','origin','block-190796','Html_box','',1),(190801,'74080','origin','block-190796','Html_box','',2),(190802,'74081','origin','block-190796','checkout\\EditBtn','',6),(190803,'74082','origin','block-190796','Html_box','',5),(190804,'74083','origin','block-190778','BlockBox','',2),(190805,'74084','origin','block-190804','checkout\\CommentsConfirm','',3),(190806,'74085','origin','block-190804','Html_box','',1),(190807,'74086','origin','block-190804','checkout\\EditBtn','',2),(190808,'74087','origin','block-190777-2','BlockBox','',1),(190809,'74088','origin','block-190808','Html_box','',1),(190810,'74089','origin','block-190808','checkout\\Totals','',2),(190811,'74090','origin','block-190808','checkout\\ConfirmBtn','',3),(190812,'74091','origin','confirmation_s','BlockBox','',1),(190813,'74092','origin','block-190812','BlockBox','',2),(190814,'74093','origin','block-190813','BlockBox','',1),(190815,'74094','origin','block-190814','BlockBox','',1),(190816,'74095','origin','block-190815','BlockBox','',1),(190817,'74096','origin','block-190816','checkout\\ShippingAddressConfirm','',4),(190818,'74097','origin','block-190816','checkout\\EditBtn','',3),(190819,'74098','origin','block-190816','Html_box','',2),(190820,'74099','origin','block-190816','DelayedDespatch\\CheckoutConfirm','',8),(190821,'74100','origin','block-190816','checkout\\ShippingConfirm','',7),(190822,'74101','origin','block-190816','Html_box','',1),(190823,'74102','origin','block-190816','Html_box','',5),(190824,'74103','origin','block-190816','Html_box','',9),(190825,'74104','origin','block-190816','checkout\\ContactConfirm','',11),(190826,'74105','origin','block-190816','checkout\\EditBtn','',6),(190827,'74106','origin','block-190816','checkout\\EditBtn','',10),(190828,'74107','origin','block-190815-2','BlockBox','',1),(190829,'74108','origin','block-190828','Html_box','',2),(190830,'74109','origin','block-190828','checkout\\BillingAddressConfirm','',4),(190831,'74110','origin','block-190828','checkout\\EditBtn','',3),(190832,'74111','origin','block-190828','checkout\\PaymentMethodConfirm','',7),(190833,'74112','origin','block-190828','checkout\\EditBtn','',6),(190834,'74113','origin','block-190828','Html_box','',1),(190835,'74114','origin','block-190828','Html_box','',5),(190836,'74115','origin','block-190814','BlockBox','',3),(190837,'74116','origin','block-190836','checkout\\EditBtn','',3),(190838,'74117','origin','block-190836','Html_box','',1),(190839,'74118','origin','block-190836','sample\\Products','',2),(190840,'74119','origin','block-190814','BlockBox','',2),(190841,'74120','origin','block-190840','Html_box','',1),(190842,'74121','origin','block-190840','checkout\\EditBtn','',2),(190843,'74122','origin','block-190840','checkout\\CommentsConfirm','',3),(190844,'74123','origin','block-190813-2','BlockBox','',1),(190845,'74124','origin','block-190844','checkout\\Totals','',2),(190846,'74125','origin','block-190844','checkout\\ConfirmBtn','',3),(190847,'74126','origin','block-190844','Html_box','',1),(190848,'74127','origin','block-190812','Html_box','',1),(190849,'74128','origin','contact','BlockBox','',1),(190850,'74132','origin','block-190849','info\\Title','',1),(190851,'74133','origin','block-190849','BlockBox','',3),(190852,'74134','origin','block-190851','contact\\ContactForm','',1),(190853,'74135','origin','block-190851-2','contact\\Contacts','',1),(190854,'74136','origin','created_success','BlockBox','',1),(190855,'74137','origin','block-190854','Html_box','',1),(190856,'74138','origin','block-190854','Html_box','',2),(190857,'74139','origin','credit_note','invoice\\Container','',1),(190858,'74140','origin','block-190857','BlockBox','',5),(190859,'74141','origin','block-190858','invoice\\StoreAddress','',8),(190860,'74142','origin','block-190858','Text','',1),(190861,'74143','origin','block-190858-2','Text','',2),(190862,'74144','origin','block-190858-2','Logo','',1),(190863,'74145','origin','block-190858-3','Text','',1),(190864,'74146','origin','block-190858-3','BlockBox','',3),(190865,'74147','origin','block-190864','Text','',1),(190866,'74148','origin','block-190864-2','invoice\\StoreEmail','',1),(190867,'74149','origin','block-190858-3','BlockBox','',2),(190868,'74150','origin','block-190867','Text','',1),(190869,'74151','origin','block-190867-2','invoice\\StorePhone','',1),(190870,'74152','origin','block-190857','invoice\\Products','',3),(190871,'74153','origin','block-190857','BlockBox','',1),(190872,'74154','origin','block-190871','Logo','',1),(190873,'74155','origin','block-190871-2','BlockBox','',4),(190874,'74156','origin','block-190873','Text','',1),(190875,'74157','origin','block-190873-2','invoice\\StoreSite','',1),(190876,'74158','origin','block-190871-2','BlockBox','',2),(190877,'74159','origin','block-190876','Text','',1),(190878,'74160','origin','block-190876-2','invoice\\StorePhone','',1),(190879,'74161','origin','block-190871-2','BlockBox','',3),(190880,'74162','origin','block-190879','Text','',1),(190881,'74163','origin','block-190879-2','invoice\\StoreEmail','',1),(190882,'74164','origin','block-190871-2','BlockBox','',1),(190883,'74165','origin','block-190882','invoice\\StoreAddress','',1),(190884,'74166','origin','block-190857','BlockBox','',4),(190885,'74167','origin','block-190884','BlockBox','',1),(190886,'74168','origin','block-190885','invoice\\ShippingAddress','',2),(190887,'74169','origin','block-190885','Text','',1),(190888,'74170','origin','block-190884-2','BlockBox','',1),(190889,'74171','origin','block-190857','BlockBox','',2),(190890,'74172','origin','block-190889','BlockBox','',7),(190891,'74173','origin','block-190890','BlockBox','',1),(190892,'74174','origin','block-190891','Text','',1),(190893,'74175','origin','block-190891','invoice\\BillingAddress','',2),(190894,'74176','origin','block-190890-2','BlockBox','',1),(190895,'74177','origin','block-190894','invoice\\CustomerPhone','',4),(190896,'74178','origin','block-190894','Text','',1),(190897,'74179','origin','block-190894','Text','',3),(190898,'74180','origin','block-190894','invoice\\CustomerName','',2),(190899,'74181','origin','block-190894','invoice\\CustomerEmail','',6),(190900,'74182','origin','block-190894','Text','',5),(190901,'74183','origin','block-190889','BlockBox','',8),(190902,'74184','origin','block-190901','BlockBox','',1),(190903,'74185','origin','block-190902','invoice\\ShippingMethod','',2),(190904,'74186','origin','block-190902','Text','',1),(190905,'74187','origin','block-190901-2','BlockBox','',1),(190906,'74188','origin','block-190905','Text','',1),(190907,'74189','origin','block-190905','invoice\\ShippingMethod','',2),(190908,'74190','origin','block-190889-2','invoice\\OrderId','',1),(190909,'74191','origin','block-190889-2','Text','',2),(190910,'74192','origin','block-190889-2','invoice\\PaymentDate','',3),(190911,'74193','origin','delivery-location','DeliveryLocation\\FeaturedList','',6),(190912,'74194','origin','delivery-location','DeliveryLocation\\LocationLongDescription','',5),(190913,'74195','origin','delivery-location','DeliveryLocation\\LocationList','',7),(190914,'74196','origin','delivery-location','DeliveryLocation\\LocationTitle','',2),(190915,'74197','origin','delivery-location','DeliveryLocation\\LocationProducts','',8),(190916,'74198','origin','delivery-location','DeliveryLocation\\LocationDescription','',3),(190917,'74199','origin','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(190918,'74200','origin','delivery-location-default','DeliveryLocation\\TopLocationList','',2),(190919,'74201','origin','delivery-location-default','Heading','',1),(190920,'94716','origin','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(190921,'94717','origin','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(190922,'94718','origin','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(190923,'94719','origin','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(190924,'94720','origin','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(190925,'94721','origin','delivery_loc_2','DeliveryLocation\\LocationList','',7),(190926,'94722','origin','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(190927,'74202','origin','email','email\\BlockBox','',1),(190928,'74203','origin','block-190927','email\\BlockBox','',1),(190929,'74204','origin','block-190928','Copyright','',4),(190930,'74205','origin','block-190928','email\\Content','',3),(190931,'74206','origin','block-190928','email\\BlockBox','',2),(190932,'74207','origin','block-190931','email\\Title','',1),(190933,'74208','origin','block-190931-2','email\\Date','',1),(190934,'74209','origin','block-190928','Logo','',1),(190935,'74210','origin','email_2','email\\BlockBox','',1),(190936,'74211','origin','block-190935','email\\BlockBox','',1),(190937,'74212','origin','block-190936','Copyright','',4),(190938,'74213','origin','block-190936','Logo','',1),(190939,'74214','origin','block-190936','email\\Content','',3),(190940,'74215','origin','block-190936','email\\BlockBox','',2),(190941,'74216','origin','block-190940','email\\Title','',1),(190942,'74217','origin','block-190940-2','email\\Date','',1),(190943,'74218','origin','email_3','email\\BlockBox','',1),(190944,'74219','origin','block-190943','email\\BlockBox','',1),(190945,'74220','origin','block-190944','email\\BlockBox','',2),(190946,'74221','origin','block-190945','email\\Content','',2),(190947,'74222','origin','block-190945','email\\BlockBox','',1),(190948,'74223','origin','block-190947','email\\Title','',1),(190949,'74224','origin','block-190947-2','email\\Date','',1),(190950,'74225','origin','block-190944','Copyright','',3),(190951,'74226','origin','block-190944','Logo','',1),(190952,'74227','origin','email_4','email\\BlockBox','',1),(190953,'74228','origin','block-190952','email\\BlockBox','',1),(190954,'74229','origin','block-190953','Copyright','',2),(190955,'74230','origin','block-190953','email\\BlockBox','',1),(190956,'74231','origin','block-190955','email\\BlockBox','',1),(190957,'74232','origin','block-190956','Logo','',1),(190958,'74233','origin','block-190956-2','email\\Date','',2),(190959,'74234','origin','block-190956-2','email\\Title','',1),(190960,'74235','origin','block-190955','email\\Content','',2),(190961,'74236','origin','footer','BlockBox','',1),(190962,'74237','origin','block-190961','BlockBox','',1),(190963,'74238','origin','block-190962','BlockBox','',1),(190964,'74239','origin','block-190963','Menu','footer3',3),(190965,'1695906739.5696','origin','block-190963','Html_box','',2),(190966,'74241','origin','block-190962-2','BlockBox','',1),(190967,'74243','origin','block-190966','Menu','footer1',3),(190968,'1695906751.0591','origin','block-190966','Html_box','',2),(190969,'74244','origin','block-190962-3','BlockBox','',1),(190970,'74246','origin','block-190969','Menu','footer2',3),(190971,'1695906756.0887','origin','block-190969','Html_box','',2),(190972,'74247','origin','block-190962-4','BlockBox','',1),(190973,'74248','origin','block-190972','Contacts','',4),(190974,'74249','origin','block-190972','Contacts','',3),(190975,'1695906761.6568','origin','block-190972','Html_box','',2),(190976,'74256','origin','block-190961','BlockBox','footer-content',4),(190977,'74257','origin','block-190976','Copyright','',1),(190978,'74258','origin','block-190976-2','invoice\\StoreAddress','',1),(190979,'94723','origin','for_menu','BlockBox','',1),(190980,'94724','origin','block-190979','Html_box','',1),(190981,'94725','origin','block-190979-2','Languages','',1),(190982,'94726','origin','for_menu','BlockBox','',3),(190983,'94727','origin','block-190982','Html_box','',1),(190984,'94728','origin','block-190982-2','Currencies','',1),(190985,'74263','origin','gift','BlockBox','',1),(190986,'74264','origin','block-190985','BlockBox','',3),(190987,'74265','origin','block-190986','BlockBox','',1),(190988,'74266','origin','block-190987','gift\\Card','',1),(190989,'74267','origin','block-190986-2','gift\\Form','',2),(190990,'74268','origin','block-190986-2','Text','',1),(190991,'74269','origin','block-190985','info\\Title','',1),(190992,'74270','origin','gift_card','BlockBox','',1),(190993,'74271','origin','block-190992','BlockBox','',11),(190994,'74272','origin','block-190993','invoice\\StoreEmail','',3),(190995,'74273','origin','block-190993','Text','',1),(190996,'74274','origin','block-190993','invoice\\StorePhone','',2),(190997,'74275','origin','block-190992','Text','',8),(190998,'74276','origin','block-190992','Text','',3),(190999,'74277','origin','block-190992','BlockBox','',10),(191000,'74278','origin','block-190999','Text','',1),(191001,'74279','origin','block-190999-2','gift\\CodeView','',1),(191002,'74280','origin','block-190992','gift\\MessageView','',7),(191003,'74281','origin','block-190992','gift\\AmountView','',5),(191004,'74282','origin','block-190992','Text','',6),(191005,'74284','origin','block-190992','Logo','',1),(191006,'74285','origin','block-190992','Text','',4),(191007,'74286','origin','block-190992','Text','',9),(191008,'74287','origin','gift_card_2','BlockBox','',1),(191009,'74288','origin','block-191008','gift\\AmountView','',3),(191010,'74289','origin','block-191008','BlockBox','',8),(191011,'74290','origin','block-191010','Text','',1),(191012,'74291','origin','block-191010-2','gift\\CodeView','',1),(191013,'74292','origin','block-191008','BlockBox','',9),(191014,'74293','origin','block-191013','invoice\\StoreEmail','',3),(191015,'74294','origin','block-191013','Text','',1),(191016,'74295','origin','block-191013','invoice\\StorePhone','',2),(191017,'74296','origin','block-191008','gift\\MessageView','',5),(191018,'74297','origin','block-191008','Text','',4),(191019,'74298','origin','block-191008','Text','',7),(191020,'74299','origin','block-191008','Text','',2),(191021,'74300','origin','block-191008','Text','',6),(191022,'74301','origin','block-191008','Text','',1),(191023,'94729','origin','gift_card_2_pdf','BlockBox','',1),(191024,'94730','origin','block-191023','BlockBox','',12),(191025,'94731','origin','block-191024','invoice\\StoreEmail','',4),(191026,'94732','origin','block-191024','invoice\\StorePhone','',3),(191027,'94733','origin','block-191024','Html_box','',1),(191028,'94734','origin','block-191023','BlockBox','',11),(191029,'94735','origin','block-191028','Html_box','',1),(191030,'94736','origin','block-191028-2','gift\\CodeViewPdf','',1),(191031,'94737','origin','block-191023','BlockBox','',1),(191032,'94738','origin','block-191031','Text','',4),(191033,'94739','origin','block-191031','Html_box','',1),(191034,'94740','origin','block-191031','Html_box','',2),(191035,'94741','origin','block-191031','gift\\AmountViewPdf','',3),(191036,'94742','origin','block-191031','gift\\MessageViewPdf','',5),(191037,'94743','origin','block-191031','Html_box','',7),(191038,'94744','origin','block-191031','Html_box','',6),(191039,'94746','origin','gift_card_pdf','BlockBox','',1),(191040,'94747','origin','block-191039','BlockBox','',12),(191041,'94748','origin','block-191040','invoice\\StoreEmail','',4),(191042,'94749','origin','block-191040','invoice\\StorePhone','',3),(191043,'94750','origin','block-191040','Html_box','',1),(191044,'94751','origin','block-191039','BlockBox','',11),(191045,'94752','origin','block-191044','Html_box','',1),(191046,'94753','origin','block-191044-2','gift\\CodeViewPdf','',1),(191047,'94754','origin','block-191039','BlockBox','',1),(191048,'94755','origin','block-191047','Text','',5),(191049,'94757','origin','block-191047','Html_box','',3),(191050,'94758','origin','block-191047','gift\\AmountViewPdf','',4),(191051,'94759','origin','block-191047','gift\\MessageViewPdf','',6),(191052,'94760','origin','block-191047','Html_box','',8),(191053,'94761','origin','block-191047','Html_box','',7),(191054,'1707902674.2595','origin','block-191047','Logo','',2),(191055,'94762','origin','gift_card_pdf','Import','',1),(191056,'74302','origin','gift_certificate','BlockBox','',1),(191057,'74303','origin','block-191056','account\\ApplyCertificate','',2),(191058,'74304','origin','block-191056','Html_box','',1),(191059,'74305','origin','gigt_card_3','BlockBox','',1),(191060,'74306','origin','block-191059','BlockBox','',8),(191061,'74307','origin','block-191060','Text','',1),(191062,'74308','origin','block-191060-2','gift\\CodeView','',1),(191063,'74309','origin','block-191059','Text','',6),(191064,'74310','origin','block-191059','Text','',1),(191065,'74311','origin','block-191059','BlockBox','',9),(191066,'74312','origin','block-191065','Text','',1),(191067,'74313','origin','block-191065','invoice\\StoreEmail','',3),(191068,'74314','origin','block-191065','invoice\\StorePhone','',2),(191069,'74315','origin','block-191059','gift\\MessageView','',5),(191070,'74316','origin','block-191059','Text','',2),(191071,'74317','origin','block-191059','Text','',4),(191072,'74318','origin','block-191059','gift\\AmountView','',3),(191073,'74319','origin','block-191059','Text','',7),(191074,'94763','origin','gigt_card_3_pdf','BlockBox','',1),(191075,'94764','origin','block-191074','BlockBox','',12),(191076,'94765','origin','block-191075','invoice\\StoreEmail','',4),(191077,'94766','origin','block-191075','invoice\\StorePhone','',3),(191078,'94767','origin','block-191075','Html_box','',1),(191079,'94768','origin','block-191074','BlockBox','',11),(191080,'94769','origin','block-191079','Html_box','',1),(191081,'94770','origin','block-191079-2','gift\\CodeViewPdf','',1),(191082,'94771','origin','block-191074','BlockBox','',1),(191083,'94772','origin','block-191082','Text','',4),(191084,'94773','origin','block-191082','Html_box','',1),(191085,'94774','origin','block-191082','Html_box','',2),(191086,'94775','origin','block-191082','gift\\AmountViewPdf','',3),(191087,'94776','origin','block-191082','gift\\MessageViewPdf','',5),(191088,'94777','origin','block-191082','Html_box','',7),(191089,'94778','origin','block-191082','Html_box','',6),(191090,'1713770938.449798','origin','header','CookieNotice','',1),(191091,'1713770938.464587','origin','header','BlockBox','header-content-small',2),(191092,'1713770938.467593','origin','block-191091','BlockBox','header-content-small-left',1),(191093,'1713770938.470248','origin','block-191092','Menu','Header menu',1),(191094,'1713770938.51635','origin','block-191092-2','BlockBox','header-content-small-right',5),(191095,'1713770938.51828','origin','block-191094','Cart','',1),(191096,'1713770938.573998','origin','block-191094','Account','',2),(191097,'1713770938.61982','origin','block-191094','Currencies','',4),(191098,'1713770938.663457','origin','block-191094','Languages','',3),(191099,'1713770938.697915','origin','header','BlockBox','header-content',3),(191100,'1713770938.706821','origin','block-191099','Logo','',1),(191101,'1713770938.709156','origin','block-191099','Search','',2),(191102,'1713770938.773998','origin','block-191099','Text','',3),(191103,'1713770938.811953','origin','header','BlockBox','header-menu',4),(191104,'1713770938.81834','origin','block-191103','Menu','Categories',1),(191105,'74346','origin','info','BlockBox','info-content',1),(191106,'74347','origin','block-191105','info\\DescriptionShort','',2),(191107,'74348','origin','block-191105','info\\Content','',4),(191108,'74349','origin','block-191105','info\\Title','',1),(191109,'74350','origin','block-191105','info\\Image','',3),(191110,'74351','origin','invoice','invoice\\Container','',1),(191111,'74352','origin','block-191110','BlockBox','',3),(191112,'74353','origin','block-191111','BlockBox','',8),(191113,'74354','origin','block-191112','BlockBox','',1),(191114,'74355','origin','block-191113','invoice\\ShippingMethod','',2),(191115,'74356','origin','block-191113','Text','',1),(191116,'74357','origin','block-191112-2','BlockBox','',1),(191117,'74358','origin','block-191116','Text','',1),(191118,'74359','origin','block-191116','invoice\\ShippingMethod','',2),(191119,'74360','origin','block-191111','BlockBox','',7),(191120,'74361','origin','block-191119','BlockBox','',1),(191121,'74362','origin','block-191120','Text','',1),(191122,'74363','origin','block-191120','invoice\\BillingAddress','',2),(191123,'74364','origin','block-191119-2','BlockBox','',1),(191124,'74365','origin','block-191123','Text','',5),(191125,'74366','origin','block-191123','invoice\\CustomerName','',2),(191126,'74367','origin','block-191123','invoice\\CustomerPhone','',4),(191127,'74368','origin','block-191123','Text','',1),(191128,'74369','origin','block-191123','Text','',3),(191129,'74370','origin','block-191123','invoice\\CustomerEmail','',6),(191130,'74371','origin','block-191111-2','invoice\\PaymentMethod','',5),(191131,'74372','origin','block-191111-2','Text','',4),(191132,'74373','origin','block-191111-2','Text','',2),(191133,'74374','origin','block-191111-2','invoice\\OrderId','',1),(191134,'74375','origin','block-191111-2','invoice\\PaymentDate','',3),(191135,'74376','origin','block-191111-2','invoice\\OrderBarcode','',6),(191136,'74377','origin','block-191110','BlockBox','',6),(191137,'74378','origin','block-191136','invoice\\StoreAddress','',8),(191138,'74379','origin','block-191136','Text','',1),(191139,'74380','origin','block-191136-2','Text','',2),(191140,'74381','origin','block-191136-2','Logo','',1),(191141,'74382','origin','block-191136-3','BlockBox','',3),(191142,'74383','origin','block-191141','Text','',1),(191143,'74384','origin','block-191141-2','invoice\\StoreEmail','',1),(191144,'74385','origin','block-191136-3','BlockBox','',2),(191145,'74386','origin','block-191144','Text','',1),(191146,'74387','origin','block-191144-2','invoice\\StorePhone','',1),(191147,'74388','origin','block-191136-3','Text','',1),(191148,'74389','origin','block-191110','invoice\\Products','',4),(191149,'74390','origin','block-191110','BlockBox','',5),(191150,'74391','origin','block-191149','BlockBox','',1),(191151,'74392','origin','block-191150','invoice\\ShippingAddress','',2),(191152,'74393','origin','block-191150','Text','',1),(191153,'74394','origin','block-191149-2','BlockBox','',1),(191154,'74395','origin','block-191153','invoice\\Totals','',1),(191155,'74396','origin','block-191110','BlockBox','',2),(191156,'74397','origin','block-191155','Logo','',1),(191157,'74398','origin','block-191155-2','BlockBox','',4),(191158,'74399','origin','block-191157','Text','',1),(191159,'74400','origin','block-191157-2','invoice\\StoreSite','',1),(191160,'74401','origin','block-191155-2','BlockBox','',3),(191161,'74402','origin','block-191160','Text','',1),(191162,'74403','origin','block-191160-2','invoice\\StoreEmail','',1),(191163,'74404','origin','block-191155-2','BlockBox','',1),(191164,'74405','origin','block-191163','invoice\\StoreAddress','',3),(191165,'74406','origin','block-191155-2','BlockBox','',2),(191166,'74407','origin','block-191165','Text','',1),(191167,'74408','origin','block-191165-2','invoice\\StorePhone','',1),(191168,'74409','origin','login_account','BlockBox','',1),(191169,'74410','origin','block-191168','Tabs','',2),(191170,'74411','origin','block-191169-1','login\\Returning','',1),(191171,'74412','origin','block-191169-2','BlockBox','',1),(191172,'74413','origin','block-191171','Html_box','',1),(191173,'74414','origin','block-191171-2','BlockBox','',1),(191174,'74415','origin','block-191173','Html_box','',2),(191175,'74416','origin','block-191173','login\\Register','',1),(191176,'74417','origin','block-191168','BlockBox','',1),(191177,'74418','origin','block-191176','Html_box','',3),(191178,'74419','origin','block-191176','Html_box','',1),(191179,'74420','origin','block-191176','login\\Socials','',2),(191180,'74421','origin','login_checkout','BlockBox','',1),(191181,'74422','origin','block-191180','BlockBox','',1),(191182,'74423','origin','block-191181','checkout\\CreateBtn','',4),(191183,'74424','origin','block-191181','checkout\\GuestBtn','',2),(191184,'74425','origin','block-191181','Html_box','',3),(191185,'74426','origin','block-191181','BlockBox','',5),(191186,'74427','origin','block-191185','Html_box','',1),(191187,'74428','origin','block-191185','login\\Socials','',2),(191188,'74429','origin','block-191181','Html_box','',1),(191189,'74430','origin','block-191181-2','login\\Returning','',2),(191190,'74431','origin','block-191181-2','Html_box','',1),(191191,'74432','origin','login_checkout2','BlockBox','',1),(191192,'74433','origin','block-191191','Tabs','',4),(191193,'74434','origin','block-191192-1','BlockBox','',1),(191194,'74435','origin','block-191193','Html_box','',1),(191195,'74436','origin','block-191193-2','BlockBox','',1),(191196,'74437','origin','block-191195','login\\Guest','',1),(191197,'74438','origin','block-191195','Html_box','',2),(191198,'74439','origin','block-191192-2','login\\Returning','',1),(191199,'74440','origin','block-191192-3','BlockBox','',1),(191200,'74441','origin','block-191199','Html_box','',1),(191201,'74442','origin','block-191199-2','BlockBox','',1),(191202,'74443','origin','block-191201','Html_box','',2),(191203,'74444','origin','block-191201','login\\Register','',1),(191204,'74445','origin','block-191191','login\\Socials','',2),(191205,'74446','origin','block-191191','Html_box','',3),(191206,'74447','origin','block-191191','Html_box','',1),(191207,'74448','origin','login_checkout2_q','BlockBox','',1),(191208,'74449','origin','block-191207','Tabs','',4),(191209,'74450','origin','block-191208-1','BlockBox','',1),(191210,'74451','origin','block-191209','Html_box','',1),(191211,'74452','origin','block-191209-2','quote\\FastOrder','',1),(191212,'74453','origin','block-191208-2','login\\Returning','',1),(191213,'74454','origin','block-191208-3','BlockBox','',1),(191214,'74455','origin','block-191213','Html_box','',1),(191215,'74456','origin','block-191213','Import','',2),(191216,'74457','origin','block-191213-2','BlockBox','',1),(191217,'74458','origin','block-191216','login\\Register','',1),(191218,'74459','origin','block-191216','Html_box','',2),(191219,'74460','origin','block-191207','Html_box','',3),(191220,'74461','origin','block-191207','Html_box','',1),(191221,'74462','origin','block-191207','login\\Socials','',2),(191222,'74463','origin','login_checkout2_s','BlockBox','',1),(191223,'74464','origin','block-191222','login\\Socials','',2),(191224,'74465','origin','block-191222','Html_box','',3),(191225,'74466','origin','block-191222','Tabs','',4),(191226,'74467','origin','block-191225-1','BlockBox','',1),(191227,'74468','origin','block-191226','Html_box','',1),(191228,'74469','origin','block-191226-2','quote\\FastOrder','',1),(191229,'74470','origin','block-191225-2','login\\Returning','',1),(191230,'74471','origin','block-191225-3','BlockBox','',1),(191231,'74472','origin','block-191230','Html_box','',1),(191232,'74473','origin','block-191230-2','BlockBox','',1),(191233,'74474','origin','block-191232','login\\Register','',1),(191234,'74475','origin','block-191232','Html_box','',2),(191235,'74476','origin','block-191222','Html_box','',1),(191236,'74477','origin','login_checkout_q','BlockBox','',1),(191237,'74478','origin','block-191236','BlockBox','',1),(191238,'74479','origin','block-191237','BlockBox','',6),(191239,'74480','origin','block-191238','Html_box','',1),(191240,'74481','origin','block-191238','login\\Socials','',2),(191241,'74482','origin','block-191237','checkout\\GuestBtn','',2),(191242,'74483','origin','block-191237','checkout\\CreateBtn','',5),(191243,'74484','origin','block-191237','Html_box','',4),(191244,'74485','origin','block-191237','Html_box','',1),(191245,'74486','origin','block-191237-2','Html_box','',1),(191246,'74487','origin','block-191237-2','login\\Returning','',2),(191247,'74488','origin','login_checkout_s','BlockBox','',1),(191248,'74489','origin','block-191247','BlockBox','',1),(191249,'74490','origin','block-191248','Html_box','',1),(191250,'74491','origin','block-191248','checkout\\GuestBtn','',2),(191251,'74492','origin','block-191248','checkout\\CreateBtn','',4),(191252,'74493','origin','block-191248','Html_box','',3),(191253,'74494','origin','block-191248','BlockBox','',5),(191254,'74495','origin','block-191253','Html_box','',1),(191255,'74496','origin','block-191253','login\\Socials','',2),(191256,'74497','origin','block-191248-2','Html_box','',1),(191257,'74498','origin','block-191248-2','login\\Returning','',2),(191258,'74499','origin','logoff','BlockBox','',1),(191259,'74500','origin','block-191258','Html_box','',1),(191260,'74501','origin','logoff_forever','BlockBox','',1),(191261,'74502','origin','block-191260','Html_box','',1),(191262,'74503','origin','main','BlockBox','',5),(191263,'74504','origin','block-191262','BlockBox','',1),(191264,'74505','origin','block-191263','Bestsellers','10',1),(191265,'74506','origin','block-191263-2','Reviews','3',1),(191266,'74507','origin','main','Banner','',2),(191267,'74508','origin','main','BlockBox','main-content',4),(191268,'74510','origin','block-191267','Tabs','',4),(191269,'74511','origin','block-191268-1','NewProducts','8',1),(191270,'74512','origin','block-191268-2','SpecialsProducts','',2),(191271,'74513','origin','block-191268-3','FeaturedProducts','4',2),(191272,'74514','origin','block-191267','TopCategories','',3),(191273,'74515','origin','main','Heading','',3),(191274,'1708693901.7617','origin','main','FormBuilder\\widgets\\Form','',6),(191275,'74516','origin','manufacturers','BlockBox','',1),(191276,'74517','origin','block-191275','Html_box','',1),(191277,'74518','origin','block-191275','Brands','',2),(191278,'74519','origin','messages-index','BlockBox','',1),(191279,'74520','origin','block-191278','BlockBox','',1),(191280,'74521','origin','block-191279','BlockBox','',1),(191281,'74522','origin','block-191280','Messages\\Sidebar','',1),(191282,'74523','origin','block-191279-2','Messages\\Listing','',1),(191283,'74524','origin','messages-new','BlockBox','',1),(191284,'74525','origin','block-191283','BlockBox','',1),(191285,'74526','origin','block-191284','Messages\\Sidebar','',1),(191286,'74527','origin','block-191284-2','Messages\\NewMessage','',1),(191287,'74528','origin','messages-view','BlockBox','',1),(191288,'74529','origin','block-191287','BlockBox','',1),(191289,'74530','origin','block-191288','Messages\\Sidebar','',1),(191290,'74531','origin','block-191288-2','Messages\\Message','',1),(191291,'74532','origin','my_password','BlockBox','',1),(191292,'74533','origin','block-191291','BlockBox','',1),(191293,'74534','origin','block-191292','WidgetsAria','',1),(191313,'74535','origin','block-191292-2','account\\ChangePassword','',2),(191314,'74536','origin','block-191292-2','Html_box','',1),(191315,'74537','origin','need_login','BlockBox','',1),(191316,'74538','origin','block-191315','Tabs','',2),(191317,'74539','origin','block-191316-1','login\\Returning','',1),(191318,'74540','origin','block-191316-2','BlockBox','',1),(191319,'74541','origin','block-191318','Html_box','',1),(191320,'74542','origin','block-191318-2','BlockBox','',1),(191321,'74543','origin','block-191320','login\\Register','',1),(191322,'74544','origin','block-191320','Html_box','',2),(191323,'74545','origin','block-191315','BlockBox','',1),(191324,'74546','origin','new-topic','BlockBox','',1),(191325,'74547','origin','block-191324','Breadcrumb','',2),(191326,'74548','origin','block-191324','Communication\\NewTopic','',3),(191327,'74549','origin','block-191324','Html_box','',1),(191328,'94779','origin','nnnn','BlockBox','',1),(191329,'94780','origin','block-191328','catalog\\Title','',1),(191330,'94781','origin','block-191328','BlockBox','',2),(191331,'94782','origin','block-191330','Filters','',1),(191332,'94783','origin','block-191330-2','Listing','',5),(191333,'94784','origin','block-191330-2','catalog\\Image','',1),(191334,'94785','origin','block-191330-2','BlockBox','',6),(191335,'94786','origin','block-191334','catalog\\CountsItems','',1),(191336,'94787','origin','block-191334-2','catalog\\Paging','',1),(191337,'94788','origin','block-191330-2','catalog\\ImageMapCategory','',3),(191338,'94789','origin','block-191330-2','Categories','',2),(191339,'94790','origin','block-191330-2','BlockBox','',4),(191340,'94791','origin','block-191339','catalog\\ListingLook','',1),(191341,'94792','origin','block-191339','catalog\\ItemsOnPage','',4),(191342,'94793','origin','block-191339','catalog\\CompareButton','',2),(191343,'94794','origin','block-191339','catalog\\Sorting','',3),(191344,'74550','origin','no-logged','BlockBox','',1),(191345,'74551','origin','block-191344','Communication\\NewTopic','',2),(191346,'74552','origin','block-191344','Html_box','',1),(191347,'74553','origin','no_filters','BlockBox','catalog-content',1),(191348,'74554','origin','block-191347','BlockBox','',4),(191349,'74555','origin','block-191348','catalog\\CountsItems','',1),(191350,'74556','origin','block-191348-2','catalog\\Paging','',1),(191351,'74557','origin','block-191347','Listing','',3),(191352,'74558','origin','block-191347','catalog\\Title','',1),(191353,'74559','origin','block-191347','catalog\\B2bAddButton','',5),(191354,'74560','origin','block-191347','BlockBox','',2),(191355,'74561','origin','block-191354','BlockBox','catalog-features',3),(191356,'74562','origin','block-191355','HeaderStock','',5),(191357,'74563','origin','block-191355','catalog\\ListingLook','',1),(191358,'74564','origin','block-191355','catalog\\CompareButton','',2),(191359,'74565','origin','block-191355','catalog\\ItemsOnPage','',4),(191360,'74566','origin','block-191355','catalog\\Sorting','',3),(191361,'74567','origin','block-191354','catalog\\Image','',1),(191362,'74568','origin','order_history','BlockBox','',1),(191363,'74569','origin','block-191362','BlockBox','',1),(191364,'74570','origin','block-191363','WidgetsAria','',1),(191384,'74571','origin','block-191363-2','Html_box','',1),(191385,'74572','origin','block-191363-2','account\\OrdersHistory','',2),(191386,'74573','origin','order_history_info','BlockBox','',1),(191387,'74574','origin','block-191386','BlockBox','',1),(191388,'74575','origin','block-191387','WidgetsAria','',1),(191408,'74576','origin','block-191387-2','account\\OrderInvoiceButton','',3),(191409,'74577','origin','block-191387-2','account\\OrderSubTotals','',10),(191410,'74578','origin','block-191387-2','account\\OrderPayButton','',5),(191411,'74579','origin','block-191387-2','BlockBox','',13),(191412,'74580','origin','block-191411','account\\AccountLink','',1),(191413,'74581','origin','block-191411-2','account\\OrderInvoiceButton','',1),(191414,'74582','origin','block-191387-2','Html_box','',8),(191415,'74583','origin','block-191387-2','account\\OrderHistory','',12),(191416,'74584','origin','block-191387-2','account\\OrderCancelAndReorder','',4),(191417,'74585','origin','block-191387-2','account\\OrderHeading','',1),(191418,'74586','origin','block-191387-2','account\\OrderDownload','',6),(191419,'74587','origin','block-191387-2','Html_box','',11),(191420,'74588','origin','block-191387-2','account\\OrderProducts','',9),(191421,'74589','origin','block-191387-2','account\\OrderReorderButton','',2),(191422,'74590','origin','block-191387-2','BlockBox','',7),(191423,'74591','origin','block-191422','BlockBox','',2),(191424,'74592','origin','block-191423','Html_box','',1),(191425,'74593','origin','block-191423','account\\OrderData','',2),(191426,'74594','origin','block-191422','BlockBox','',1),(191427,'74595','origin','block-191426','Html_box','',1),(191428,'74596','origin','block-191426','account\\OrderData','',2),(191429,'74597','origin','block-191422','BlockBox','',3),(191430,'74598','origin','block-191429','account\\OrderTracking','',2),(191431,'74599','origin','block-191429','Html_box','',1),(191432,'74600','origin','block-191429','account\\AccountLink','',3),(191433,'74601','origin','block-191422-2','BlockBox','',2),(191434,'74602','origin','block-191433','account\\OrderData','',2),(191435,'74603','origin','block-191433','Html_box','',1),(191436,'74604','origin','block-191422-2','BlockBox','',1),(191437,'74605','origin','block-191436','account\\OrderData','',2),(191438,'74606','origin','block-191436','Html_box','',1),(191439,'74607','origin','block-191422-3','BlockBox','',2),(191440,'74608','origin','block-191439','account\\OrderData','',2),(191441,'74609','origin','block-191439','Html_box','',1),(191442,'74610','origin','block-191422-3','BlockBox','',1),(191443,'74611','origin','block-191442','Html_box','',1),(191444,'74612','origin','block-191442','account\\OrderData','',2),(191445,'74613','origin','order_pay','BlockBox','',1),(191446,'74614','origin','block-191445','BlockBox','',1),(191447,'74615','origin','block-191446','WidgetsAria','',1),(191467,'74616','origin','block-191446-2','account\\OrderProducts','',4),(191468,'74617','origin','block-191446-2','BlockBox','',2),(191469,'74618','origin','block-191468','BlockBox','',1),(191470,'74619','origin','block-191469','Html_box','',1),(191471,'74620','origin','block-191469','account\\OrderData','',2),(191472,'74621','origin','block-191468','BlockBox','',4),(191473,'74622','origin','block-191472','account\\OrderData','',2),(191474,'74623','origin','block-191472','Html_box','',1),(191475,'74624','origin','block-191468-2','BlockBox','',1),(191476,'74625','origin','block-191475','Html_box','',1),(191477,'74626','origin','block-191475','account\\OrderData','',2),(191478,'74627','origin','block-191468-2','BlockBox','',2),(191479,'74628','origin','block-191478','account\\OrderData','',2),(191480,'74629','origin','block-191478','Html_box','',1),(191481,'74630','origin','block-191468-3','BlockBox','',2),(191482,'74631','origin','block-191481','Html_box','',1),(191483,'74632','origin','block-191481','account\\OrderData','',2),(191484,'74633','origin','block-191468-3','BlockBox','',1),(191485,'74634','origin','block-191484','account\\OrderData','',2),(191486,'74635','origin','block-191484','Html_box','',1),(191487,'74636','origin','block-191446-2','UpdateAndPay\\PayForm','',6),(191488,'74637','origin','block-191446-2','Html_box','',3),(191489,'74638','origin','block-191446-2','account\\OrderHeading','',1),(191490,'74639','origin','block-191446-2','account\\OrderSubTotals','',5),(191491,'74640','origin','packingslip','invoice\\Container','',2),(191492,'74641','origin','block-191491','BlockBox','',1),(191493,'74642','origin','block-191492','Logo','',1),(191494,'74643','origin','block-191492-2','BlockBox','',3),(191495,'74644','origin','block-191494','Text','',2),(191496,'74645','origin','block-191494-2','invoice\\StoreEmail','',1),(191497,'74646','origin','block-191492-2','BlockBox','',2),(191498,'74647','origin','block-191497','Text','',2),(191499,'74648','origin','block-191497-2','invoice\\StorePhone','',1),(191500,'74649','origin','block-191492-2','BlockBox','',1),(191501,'74650','origin','block-191500','invoice\\StoreAddress','',1),(191502,'74651','origin','block-191492-2','BlockBox','',4),(191503,'74652','origin','block-191502','Text','',2),(191504,'74653','origin','block-191502-2','invoice\\StoreSite','',1),(191505,'74654','origin','block-191491','packingslip\\Products','',3),(191506,'74655','origin','block-191491','BlockBox','',4),(191507,'74656','origin','block-191506','invoice\\StoreAddress','',2),(191508,'74657','origin','block-191506','Text','',1),(191509,'74658','origin','block-191491','BlockBox','',2),(191510,'74659','origin','block-191509','BlockBox','',2),(191511,'74660','origin','block-191510','BlockBox','',1),(191512,'74661','origin','block-191511','invoice\\ShippingAddress','',2),(191513,'74662','origin','block-191511','Text','',1),(191514,'74663','origin','block-191510-2','BlockBox','',1),(191515,'74664','origin','block-191514','Text','',1),(191516,'74665','origin','block-191514','invoice\\CustomerName','',2),(191517,'74666','origin','block-191514','invoice\\CustomerEmail','',6),(191518,'74667','origin','block-191514','Text','',3),(191519,'74668','origin','block-191514','invoice\\CustomerPhone','',4),(191520,'74669','origin','block-191514','Text','',5),(191521,'74670','origin','block-191509','BlockBox','',3),(191522,'74671','origin','block-191521','BlockBox','',1),(191523,'74672','origin','block-191522','invoice\\ShippingMethod','',2),(191524,'74673','origin','block-191522','Text','',1),(191525,'74674','origin','block-191521-2','BlockBox','',1),(191526,'74675','origin','block-191525','invoice\\ShippingMethod','',2),(191527,'74676','origin','block-191525','Text','',1),(191528,'74677','origin','block-191509-2','invoice\\AddressQrcode','',1),(191529,'74678','origin','password_forgotten','BlockBox','',1),(191530,'74679','origin','block-191529','BlockBox','',2),(191531,'74680','origin','block-191530-2','Html_box','',1),(191532,'74681','origin','block-191530-2','login\\PasswordForgotten','',2),(191533,'74682','origin','block-191529','Html_box','',1),(191534,'74683','origin','pdf','invoice\\Container','',1),(191535,'74684','origin','block-191534','BlockBox','',1),(191536,'74685','origin','block-191535','BlockBox','',1),(191537,'74686','origin','block-191536','BlockBox','',1),(191538,'74687','origin','block-191537','pdf\\ProductElement','',1),(191539,'74688','origin','block-191536','BlockBox','',2),(191540,'74689','origin','block-191539','pdf\\ProductElement','',1),(191541,'74690','origin','block-191539-2','pdf\\ProductElement','',2),(191542,'74691','origin','block-191539-2','pdf\\ProductElement','',1),(191543,'74692','origin','block-191535-2','BlockBox','',1),(191544,'74693','origin','block-191543','BlockBox','',2),(191545,'74694','origin','block-191544','pdf\\ProductElement','',1),(191546,'74695','origin','block-191544-2','pdf\\ProductElement','',2),(191547,'74696','origin','block-191544-2','pdf\\ProductElement','',1),(191548,'74697','origin','block-191543','BlockBox','',1),(191549,'74698','origin','block-191548','pdf\\ProductElement','',1),(191550,'74699','origin','pdf_category','pdf\\CategoryName','',2),(191551,'74700','origin','pdf_category','pdf\\CategoryImage','',1),(191552,'74701','origin','pdf_cover','invoice\\Container','',1),(191553,'74702','origin','block-191552','Logo','',1),(191554,'74703','origin','block-191552','Text','',3),(191555,'74704','origin','pdf_footer','BlockBox','',1),(191556,'74705','origin','block-191555-2','pdf\\PageNumber','',1),(191557,'74706','origin','pdf_header','pdf\\CategoryName','',1),(191558,'74707','origin','personal_catalog','BlockBox','',1),(191559,'74708','origin','block-191558','BlockBox','',1),(191560,'74709','origin','block-191559','WidgetsAria','',1),(191580,'74710','origin','block-191559-2','Html_box','',1),(191581,'74711','origin','block-191559-2','account\\AccountLink','',3),(191582,'74712','origin','block-191559-2','account\\PersonalCatalog','',2),(191583,'74713','origin','points_earnt_history','BlockBox','',1),(191584,'74714','origin','block-191583','Html_box','',1),(191585,'74715','origin','block-191583','BonusActions\\widgets\\PointsEarntHistory','',2),(191586,'74716','origin','posts','BlockBox','',1),(191587,'74717','origin','block-191586','Breadcrumb','',2),(191588,'74718','origin','block-191586','Html_box','',1),(191589,'74719','origin','block-191586','Communication\\Post','',3),(191590,'74720','origin','product','BlockBox','product-content',2),(191591,'74721','origin','block-191590','product\\CustomersActivity','',11),(191592,'74722','origin','block-191590','BlockBox','product-image',2),(191593,'74724','origin','block-191592','product\\Images','',2),(191594,'74725','origin','block-191592','product\\ImageMapProduct','',4),(191595,'74726','origin','block-191592','product\\PromotionIcons','',1),(191596,'74727','origin','block-191592-2','BlockBox','product-side',10),(191597,'74728','origin','block-191596','product\\ButtonsQuote','',3),(191598,'74729','origin','block-191596','BlockBox','',1),(191599,'74730','origin','block-191598','product\\Price','',1),(191600,'74731','origin','block-191598-2','product\\Quantity','',1),(191601,'74732','origin','block-191596','BonusActions\\widgets\\BonusPointsProduct','',4),(191602,'1694165842.4776','origin','block-191596','product\\QuantityDiscounts','',2),(191603,'74733','origin','block-191596-2','product\\Buttons','',1),(191604,'74734','origin','block-191596-2','product\\ButtonsSample','',2),(191605,'74735','origin','block-191592-2','product\\DescriptionShort','',6),(191606,'74737','origin','block-191592-2','product\\Documents','',5),(191607,'74738','origin','block-191592-2','product\\AvailableInWarehouses','',9),(191608,'74739','origin','block-191592-2','BlockBox','',11),(191609,'74741','origin','block-191608','product\\PersonalCatalogButton','',1),(191610,'74743','origin','block-191592-2','product\\Brand','',4),(191611,'74744','origin','block-191592-2','product\\Model','',3),(191612,'74745','origin','block-191592-2','product\\Name','',2),(191613,'74746','origin','block-191592-2','product\\Stock','',1),(191614,'1642500646.3623','origin','block-191592-2','product\\Attributes','',7),(191615,'74749','origin','block-191590','product\\Configurator','',5),(191616,'74750','origin','block-191590','Breadcrumb','',1),(191617,'74752','origin','block-191590','Tabs','',6),(191618,'74753','origin','block-191617-1','product\\Description','',2),(191619,'74754','origin','block-191617-1','product\\Properties','',1),(191620,'74755','origin','block-191617-2','product\\Reviews','',1),(191621,'74757','origin','block-191590','product\\InBundles','',4),(191622,'74758','origin','block-191590','product\\Bundle','',3),(191623,'1694166186.2638','origin','block-191590','BlockBox','',7),(191624,'74751','origin','block-191623','product\\AlsoPurchased','10',2),(191625,'1694166209.3278','origin','block-191623','Html_box','',1),(191626,'1694166191.5684','origin','block-191590','BlockBox','',9),(191627,'74747','origin','block-191626','ViewedProducts','4',2),(191628,'1694166222.3382','origin','block-191626','Html_box','',1),(191629,'74761','origin','product-bottom','product\\Properties','',1),(191630,'74762','origin','product-tabs','product\\Reviews','',2),(191631,'74763','origin','product-tabs','product\\Description','',1),(191632,'74764','origin','product-top-left','product\\Images','',1),(191633,'74765','origin','product-top-right','product\\Price','',2),(191634,'74766','origin','product-top-right','product\\Quantity','',5),(191635,'74767','origin','product-top-right','product\\Quantity','',6),(191636,'74768','origin','product-top-right','product\\Attributes','',3),(191637,'74769','origin','product-top-right','product\\Name','',1),(191638,'74770','origin','product-top-right','product\\Buttons','',6),(191639,'74771','origin','productListing','BlockBox','listing-item',1),(191640,'74773','origin','block-191639','productListing\\model','',7),(191641,'74774','origin','block-191639','BonusActions\\widgets\\BonusPointsProductListing','',6),(191642,'74775','origin','block-191639','productListing\\description','',5),(191643,'74776','origin','block-191639','productListing\\buyButton','',9),(191644,'74777','origin','block-191639','productListing\\rating','',3),(191645,'74778','origin','block-191639','productListing\\image','',1),(191646,'74779','origin','block-191639','BlockBox','',8),(191647,'74780','origin','block-191646','productListing\\price','',1),(191648,'74781','origin','block-191646-2','productListing\\qtyInput','',1),(191649,'74782','origin','block-191639','productListing\\name','',4),(191650,'74783','origin','block-191639','productListing\\stock','',2),(191651,'75903','origin','block-191639','productListing\\compare','',10),(191652,'74785','origin','products','BlockBox','catalog-content',1),(191653,'74786','origin','block-191652','BlockBox','catalog-side',4),(191654,'74787','origin','block-191653','Filters','',1),(191655,'74788','origin','block-191653','HeaderStock','',2),(191656,'74789','origin','block-191653-2','catalog\\B2bAddButton','',4),(191657,'74790','origin','block-191653-2','BlockBox','catalog-features',2),(191658,'74791','origin','block-191657','catalog\\Sorting','',3),(191659,'74792','origin','block-191657','catalog\\ListingLook','',1),(191660,'74793','origin','block-191657','catalog\\ItemsOnPage','',4),(191661,'74794','origin','block-191657','catalog\\CompareButton','',2),(191662,'74795','origin','block-191653-2','BlockBox','',5),(191663,'74796','origin','block-191662','catalog\\CountsItems','',1),(191664,'74797','origin','block-191662-2','catalog\\Paging','',1),(191665,'74798','origin','block-191653-2','Listing','',3),(191666,'74799','origin','block-191652','catalog\\Title','',1),(191667,'74800','origin','block-191652','BlockBox','',3),(191668,'74801','origin','block-191667','catalog\\Image','',1),(191669,'75886','origin','products-list','packingslip\\AllProductsList','',2),(191670,'74802','origin','promotions','BlockBox','',1),(191671,'74803','origin','block-191670','promotions\\PromoList','',2),(191672,'74804','origin','block-191670','Html_box','',1),(191673,'74805','origin','purchase','invoice\\Container','',1),(191674,'74806','origin','block-191673','invoice\\Products','',3),(191675,'74807','origin','block-191673','BlockBox','',5),(191676,'74808','origin','block-191675','Text','',1),(191677,'74809','origin','block-191675','invoice\\StoreAddress','',8),(191678,'74810','origin','block-191675-2','Text','',2),(191679,'74811','origin','block-191675-2','Logo','',1),(191680,'74812','origin','block-191675-3','BlockBox','',3),(191681,'74813','origin','block-191680','Text','',1),(191682,'74814','origin','block-191680-2','invoice\\StoreEmail','',1),(191683,'74815','origin','block-191675-3','Text','',1),(191684,'74816','origin','block-191675-3','BlockBox','',2),(191685,'74817','origin','block-191684','Text','',1),(191686,'74818','origin','block-191684-2','invoice\\StorePhone','',1),(191687,'74819','origin','block-191673','BlockBox','',1),(191688,'74820','origin','block-191687','Logo','',1),(191689,'74821','origin','block-191687-2','BlockBox','',2),(191690,'74822','origin','block-191689','Text','',1),(191691,'74823','origin','block-191689-2','invoice\\StorePhone','',1),(191692,'74824','origin','block-191687-2','BlockBox','',4),(191693,'74825','origin','block-191692','Text','',1),(191694,'74826','origin','block-191692-2','invoice\\StoreSite','',1),(191695,'74827','origin','block-191687-2','BlockBox','',1),(191696,'74828','origin','block-191695','invoice\\StoreAddress','',1),(191697,'74829','origin','block-191687-2','BlockBox','',3),(191698,'74830','origin','block-191697','Text','',1),(191699,'74831','origin','block-191697-2','invoice\\StoreEmail','',1),(191700,'74832','origin','block-191673','BlockBox','',2),(191701,'74833','origin','block-191700','BlockBox','',7),(191702,'74834','origin','block-191701','BlockBox','',1),(191703,'74835','origin','block-191702','invoice\\BillingAddress','',2),(191704,'74836','origin','block-191702','Text','',1),(191705,'74837','origin','block-191701-2','BlockBox','',1),(191706,'74838','origin','block-191705','invoice\\CustomerEmail','',6),(191707,'74839','origin','block-191705','Text','',5),(191708,'74840','origin','block-191705','invoice\\CustomerPhone','',4),(191709,'74841','origin','block-191705','invoice\\CustomerName','',2),(191710,'74842','origin','block-191705','Text','',3),(191711,'74843','origin','block-191705','Text','',1),(191712,'74844','origin','block-191700-2','invoice\\OrderId','',1),(191713,'74845','origin','block-191700-2','Text','',2),(191714,'74846','origin','block-191700-2','invoice\\PaymentDate','',3),(191715,'74847','origin','block-191673','BlockBox','',4),(191716,'74848','origin','block-191715','BlockBox','',1),(191717,'74849','origin','block-191716','invoice\\ShippingAddress','',2),(191718,'74850','origin','block-191716','Text','',1),(191719,'74851','origin','quotations','BlockBox','',1),(191720,'74852','origin','block-191719','BlockBox','',1),(191721,'74853','origin','block-191720','WidgetsAria','',1),(191741,'74854','origin','block-191720-2','Html_box','',1),(191742,'74855','origin','block-191720-2','Quotations\\QuotationsHistory','',2),(191743,'74856','origin','quotation_info','BlockBox','',1),(191744,'74857','origin','block-191743','BlockBox','',1),(191745,'74858','origin','block-191744','WidgetsAria','',1),(191765,'74859','origin','block-191744-2','BlockBox','',5),(191766,'74860','origin','block-191765','BlockBox','',1),(191767,'74861','origin','block-191766','Quotations\\QuotationData','',2),(191768,'74862','origin','block-191766','Html_box','',1),(191769,'74863','origin','block-191765','BlockBox','',4),(191770,'74864','origin','block-191769','Html_box','',1),(191771,'74865','origin','block-191769','Quotations\\QuotationData','',2),(191772,'74866','origin','block-191765-2','BlockBox','',2),(191773,'74867','origin','block-191772','Html_box','',1),(191774,'74868','origin','block-191772','Quotations\\QuotationData','',2),(191775,'74869','origin','block-191765-2','BlockBox','',1),(191776,'74870','origin','block-191775','Html_box','',1),(191777,'74871','origin','block-191775','Quotations\\QuotationData','',2),(191778,'74872','origin','block-191765-3','BlockBox','',1),(191779,'74873','origin','block-191778','Quotations\\QuotationData','',2),(191780,'74874','origin','block-191778','Html_box','',1),(191781,'74875','origin','block-191765-3','BlockBox','',2),(191782,'74876','origin','block-191781','Quotations\\QuotationData','',2),(191783,'74877','origin','block-191781','Html_box','',1),(191784,'74878','origin','block-191744-2','Html_box','',6),(191785,'74879','origin','block-191744-2','Quotations\\QuotationHistory','',10),(191786,'74880','origin','block-191744-2','Html_box','',9),(191787,'74881','origin','block-191744-2','Quotations\\QuotationProducts','',7),(191788,'74882','origin','block-191744-2','Quotations\\QuotationSubTotal','',8),(191789,'74883','origin','block-191744-2','BlockBox','',12),(191790,'74884','origin','block-191789','account\\AccountLink','',1),(191791,'74885','origin','block-191744-2','Html_box','',4),(191792,'74886','origin','quote','BlockBox','',1),(191793,'74887','origin','block-191792','cart\\CartTabs','',1),(191794,'74888','origin','block-191793','BlockBox','',1),(191795,'74889','origin','block-191794','quote\\Products','',1),(191796,'74890','origin','block-191794-2','BlockBox','',1),(191797,'74891','origin','block-191796','BlockBox','',1),(191798,'74892','origin','block-191797','quote\\CheckoutBtn','',2),(191799,'74893','origin','block-191793','Quotations\\QuotationSubTotal','',2),(191800,'74894','origin','review','BlockBox','',1),(191801,'74895','origin','block-191800','BlockBox','',1),(191802,'74896','origin','block-191801','WidgetsAria','',1),(191822,'74897','origin','block-191801-2','Html_box','',1),(191823,'74898','origin','block-191801-2','account\\Reviews','',2),(191824,'74899','origin','reviews','BlockBox','',1),(191825,'74900','origin','block-191824','reviews\\Heading','',1),(191826,'74901','origin','block-191824','reviews\\Content','',2),(191827,'74902','origin','rma_document','invoice\\Container','',1),(191828,'74903','origin','block-191827','BlockBox','',1),(191829,'74904','origin','block-191828','BlockBox','',1),(191830,'74905','origin','block-191829','BlockBox','',2),(191831,'74906','origin','block-191830','Html_box','',1),(191832,'74907','origin','block-191830-2','Html_box','',1),(191833,'74908','origin','block-191829','BlockBox','',5),(191834,'74909','origin','block-191833','Html_box','',1),(191835,'74910','origin','block-191833-2','Html_box','',1),(191836,'74911','origin','block-191829','BlockBox','',4),(191837,'74912','origin','block-191836','Html_box','',1),(191838,'74913','origin','block-191836-2','Html_box','',1),(191839,'74914','origin','block-191829','BlockBox','',3),(191840,'74915','origin','block-191839','Html_box','',1),(191841,'74916','origin','block-191839-2','Html_box','',1),(191842,'74917','origin','block-191829','BlockBox','',1),(191843,'74918','origin','block-191842','Html_box','',1),(191844,'74919','origin','block-191842','Html_box','',2),(191845,'74920','origin','block-191828-2','BlockBox','',1),(191846,'74921','origin','block-191845','Html_box','',2),(191847,'74922','origin','block-191845','Logo','',1),(191848,'74923','origin','block-191828-2','BlockBox','',2),(191849,'74924','origin','block-191848','BlockBox','',5),(191850,'74925','origin','block-191849','BlockBox','',1),(191851,'74926','origin','block-191850','Html_box','',1),(191852,'74927','origin','block-191850-2','Rma\\DocumentData','',1),(191853,'74928','origin','block-191849-2','BlockBox','',1),(191854,'74929','origin','block-191853','Html_box','',1),(191855,'74930','origin','block-191853-2','Rma\\DocumentData','',1),(191856,'74931','origin','block-191848','BlockBox','',4),(191857,'74932','origin','block-191856','BlockBox','',1),(191858,'74933','origin','block-191857','Html_box','',1),(191859,'74934','origin','block-191857-2','Rma\\DocumentData','',1),(191860,'74935','origin','block-191856-2','BlockBox','',1),(191861,'74936','origin','block-191860','Html_box','',1),(191862,'74937','origin','block-191860-2','Rma\\DocumentData','',1),(191863,'74938','origin','block-191848','BlockBox','',3),(191864,'74939','origin','block-191863','BlockBox','',1),(191865,'74940','origin','block-191864','Html_box','',1),(191866,'74941','origin','block-191864-2','Rma\\DocumentData','',1),(191867,'74942','origin','block-191863-2','BlockBox','',1),(191868,'74943','origin','block-191867','Html_box','',1),(191869,'74944','origin','block-191867-2','Rma\\DocumentData','',1),(191870,'74945','origin','block-191848','BlockBox','',2),(191871,'74946','origin','block-191870','Html_box','',1),(191872,'74947','origin','block-191870-2','Rma\\DocumentData','',1),(191873,'74948','origin','block-191848','BlockBox','',1),(191874,'74949','origin','block-191873','BlockBox','',1),(191875,'74950','origin','block-191874','Html_box','',1),(191876,'74951','origin','block-191874-2','Rma\\DocumentData','',1),(191877,'74952','origin','block-191873-2','BlockBox','',1),(191878,'74953','origin','block-191877','Html_box','',1),(191879,'74954','origin','block-191877-2','Rma\\DocumentData','',1),(191880,'74955','origin','block-191828-2','BlockBox','',3),(191881,'74956','origin','block-191880','BlockBox','',1),(191882,'74957','origin','block-191881','Html_box','',1),(191883,'74958','origin','block-191881-2','Rma\\DocumentData','',1),(191884,'74959','origin','block-191880-2','BlockBox','',1),(191885,'74960','origin','block-191884','Html_box','',1),(191886,'74961','origin','block-191884-2','Rma\\DocumentData','',1),(191887,'74962','origin','block-191827','BlockBox','',2),(191888,'74963','origin','block-191887','Html_box','',1),(191889,'74964','origin','block-191887','Rma\\Products','',2),(191890,'74965','origin','block-191827','BlockBox','',3),(191891,'74966','origin','block-191890','BlockBox','',1),(191892,'74967','origin','block-191891','BlockBox','',1),(191893,'74968','origin','block-191892','BlockBox','',5),(191894,'74969','origin','block-191893','Html_box','',1),(191895,'74970','origin','block-191893-2','invoice\\StoreAddress','',2),(191896,'74971','origin','block-191893-2','Html_box','',1),(191897,'74972','origin','block-191892','BlockBox','',4),(191898,'74973','origin','block-191897','Html_box','',1),(191899,'74974','origin','block-191897-2','Html_box','',1),(191900,'74975','origin','block-191892','BlockBox','',2),(191901,'74976','origin','block-191900','Html_box','',1),(191902,'74977','origin','block-191900-2','Html_box','',1),(191903,'74978','origin','block-191892','BlockBox','',1),(191904,'74979','origin','block-191903','Html_box','',1),(191905,'74980','origin','block-191892','BlockBox','',3),(191906,'74981','origin','block-191905','Html_box','',1),(191907,'74982','origin','block-191905-2','Html_box','',1),(191908,'74983','origin','block-191892','BlockBox','',6),(191909,'74984','origin','block-191908','Html_box','',1),(191910,'74985','origin','block-191891-2','BlockBox','',1),(191911,'74986','origin','block-191910','BlockBox','',1),(191912,'74987','origin','block-191911','BlockBox','',1),(191913,'74988','origin','block-191912','Rma\\DocumentData','',2),(191914,'74989','origin','block-191912-3','BlockBox','',1),(191915,'74990','origin','block-191914','Html_box','',1),(191916,'74991','origin','block-191914-2','Rma\\DocumentData','',1),(191917,'74992','origin','block-191911','BlockBox','',2),(191918,'74993','origin','block-191917-2','invoice\\StoreAddress','',1),(191919,'74994','origin','block-191891-2','BlockBox','',2),(191920,'74995','origin','block-191919','Html_box','',1),(191921,'74996','origin','block-191919','Html_box','',2),(191922,'74997','origin','block-191919','Html_box','',3),(191923,'74998','origin','block-191919','Html_box','',4),(191924,'74999','origin','block-191919','Html_box','',5),(191925,'75000','origin','block-191891-2','BlockBox','',4),(191926,'75001','origin','block-191925','Html_box','',1),(191927,'75002','origin','block-191925-2','Html_box','',1),(191928,'75003','origin','block-191925-3','BlockBox','',1),(191929,'75004','origin','block-191928','Html_box','',1),(191930,'75005','origin','block-191928-2','Html_box','',1),(191931,'75006','origin','block-191891-2','BlockBox','',3),(191932,'75007','origin','block-191931','Html_box','',1),(191933,'75008','origin','block-191931-2','Html_box','',1),(191934,'75009','origin','block-191931-3','BlockBox','',1),(191935,'75010','origin','block-191934','Html_box','',1),(191936,'75011','origin','block-191934-2','Html_box','',1),(191937,'75012','origin','rows','BlockBox','',1),(191938,'75013','origin','block-191937','BlockBox','',2),(191939,'75014','origin','block-191938','BlockBox','',2),(191940,'75015','origin','block-191939','BonusActions\\widgets\\BonusPointsProductListing','',1),(191941,'75016','origin','block-191939','productListing\\image','',2),(191942,'75017','origin','block-191939','BlockBox','',3),(191943,'75018','origin','block-191942','productListing\\rating','',1),(191944,'75019','origin','block-191942','productListing\\ratingCounts','',2),(191945,'75020','origin','block-191939-2','productListing\\name','',1),(191946,'75021','origin','block-191939-2','productListing\\description','',2),(191947,'75022','origin','block-191939-2','productListing\\model','',3),(191948,'75023','origin','block-191939-2','productListing\\attributes','',4),(191949,'75024','origin','block-191938-2','BlockBox','listing-item',1),(191950,'75025','origin','block-191949','productListing\\qtyInput','',3),(191951,'75026','origin','block-191949','productListing\\price','',2),(191952,'75027','origin','block-191949','productListing\\compare','',5),(191953,'75028','origin','block-191949','productListing\\buyButton','',4),(191954,'75030','origin','block-191949','productListing\\stock','',1),(191955,'75031','origin','sample','BlockBox','',1),(191956,'75032','origin','block-191955','cart\\CartTabs','',1),(191957,'75033','origin','block-191956','BlockBox','',1),(191958,'75034','origin','block-191957','sample\\Products','',1),(191959,'75035','origin','block-191957-2','BlockBox','',1),(191960,'75036','origin','block-191959','BlockBox','',1),(191961,'75037','origin','block-191960','sample\\CheckoutBtn','',1),(191962,'75038','origin','samples','BlockBox','',1),(191963,'75039','origin','block-191962','BlockBox','',1),(191964,'75040','origin','block-191963','WidgetsAria','',1),(191984,'75041','origin','block-191963-2','Html_box','',1),(191985,'75042','origin','block-191963-2','Samples\\SamplesHistory','',2),(191986,'75043','origin','sample_info','BlockBox','',1),(191987,'75044','origin','block-191986','BlockBox','',1),(191988,'75045','origin','block-191987','WidgetsAria','',1),(192008,'75046','origin','block-191987-2','Html_box','',1),(192009,'75047','origin','block-191987-2','BlockBox','',8),(192010,'75048','origin','block-192009','account\\AccountLink','',1),(192011,'75049','origin','block-191987-2','Samples\\SampleHistory','',7),(192012,'75050','origin','block-191987-2','Html_box','',3),(192013,'75051','origin','block-191987-2','Samples\\SampleSubTotal','',5),(192014,'75052','origin','block-191987-2','Samples\\SampleProducts','',4),(192015,'75053','origin','block-191987-2','Html_box','',6),(192016,'75054','origin','block-191987-2','BlockBox','',2),(192017,'75055','origin','block-192016','BlockBox','',4),(192018,'75056','origin','block-192017','Html_box','',1),(192019,'75057','origin','block-192017','Samples\\SampleData','',2),(192020,'75058','origin','block-192016','BlockBox','',1),(192021,'75059','origin','block-192020','Samples\\SampleData','',2),(192022,'75060','origin','block-192020','Html_box','',1),(192023,'75061','origin','block-192016-2','BlockBox','',2),(192024,'75062','origin','block-192023','Samples\\SampleData','',2),(192025,'75063','origin','block-192023','Html_box','',1),(192026,'75064','origin','block-192016-2','BlockBox','',1),(192027,'75065','origin','block-192026','Samples\\SampleData','',2),(192028,'75066','origin','block-192026','Html_box','',1),(192029,'75067','origin','block-192016-3','BlockBox','',2),(192030,'75068','origin','block-192029','Samples\\SampleData','',2),(192031,'75069','origin','block-192029','Html_box','',1),(192032,'75070','origin','block-192016-3','BlockBox','',1),(192033,'75071','origin','block-192032','Samples\\SampleData','',2),(192034,'75072','origin','block-192032','Html_box','',1),(192035,'75073','origin','sitemap','BlockBox','',1),(192036,'75074','origin','block-192035','Html_box','',1),(192037,'75075','origin','block-192035','BlockBox','',2),(192038,'75076','origin','block-192037','Html_box','',1),(192039,'75077','origin','block-192037','Html_box','',5),(192040,'75078','origin','block-192037','Html_box','',3),(192041,'75079','origin','block-192037','sitemap\\InfoPages','',2),(192042,'75080','origin','block-192037','sitemap\\Categories','',4),(192043,'75081','origin','block-192037','Menu','Account box',6),(192044,'75082','origin','block-192037-2','sitemap\\DeliveryLocation','',2),(192045,'75083','origin','block-192037-2','Html_box','',1),(192046,'75084','origin','subscribe','BlockBox','',1),(192047,'75085','origin','block-192046','Html_box','',3),(192048,'75086','origin','block-192046','subscribers\\UnsubscribeForm','',4),(192049,'75087','origin','block-192046','Html_box','',1),(192050,'75088','origin','block-192046','subscribers\\SubscribeForm','',2),(192051,'75089','origin','subscribed','BlockBox','',1),(192052,'75090','origin','block-192051','Html_box','',1),(192053,'94795','origin','subscription','BlockBox','',2),(192054,'94796','origin','block-192053','BlockBox','',1),(192055,'94797','origin','block-192054','WidgetsAria','',1),(192075,'94798','origin','block-192054-2','Html_box','',2),(192076,'94799','origin','block-192054-2','Html_box','',3),(192077,'94800','origin','block-192054-2','account\\Subscription','',4),(192078,'1694099590.22143','origin','success','BlockBox','',1),(192079,'1694099590.340695','origin','block-192078','BlockBox','',2),(192080,'1694099590.343733','origin','block-192079','BlockBox','',3),(192081,'1694099590.345212','origin','block-192080','BlockBox','',2),(192082,'1694099590.34749','origin','block-192081','BlockBox','',1),(192083,'1694099590.3531','origin','block-192082','order\\ShippingMethod','',6),(192084,'1694099590.351567','origin','block-192082','order\\DeliveryAddress','',3),(192085,'1694099590.35337','origin','block-192082','Html_box','',7),(192086,'1694099590.360420','origin','block-192082','Html_box','',5),(192087,'1694099590.362714','origin','block-192082','Html_box','',1),(192088,'1694099590.36422','origin','block-192082','checkout\\ContactConfirm','',9),(192089,'1694099590.365625','origin','block-192082','Html_box','',2),(192090,'1694099590.367789','origin','block-192081-2','BlockBox','',1),(192091,'1694099590.369488','origin','block-192090','order\\PaymentMethod','',6),(192092,'1694099590.370690','origin','block-192090','order\\BillingAddress','',3),(192093,'1694099590.371953','origin','block-192090','Html_box','',5),(192094,'1694099590.373633','origin','block-192090','Html_box','',1),(192095,'1694099590.37590','origin','block-192090','Html_box','',2),(192096,'1694099590.376747','origin','block-192080','Html_box','',1),(192097,'1694099590.38020','origin','block-192079-2','BlockBox','',1),(192098,'1694099590.381373','origin','block-192097','success\\PrintBtn','',3),(192099,'1694099590.382864','origin','block-192097','success\\ContinueBtn','',4),(192100,'1694099590.384241','origin','block-192097','order\\Products','',1),(192101,'1694099590.385486','origin','block-192097','order\\Totals','',2),(192102,'1694099590.386683','origin','block-192078','BlockBox','',1),(192103,'1694099590.387673','origin','block-192102','Html_box','',2),(192104,'1694099590.389337','origin','block-192102','order\\OrderNumber','',1),(192105,'75097','origin','success_q','BlockBox','',1),(192106,'75098','origin','block-192105','BlockBox','',1),(192107,'75099','origin','block-192106','BlockBox','',2),(192108,'75100','origin','block-192107','success\\ContinueBtn','',2),(192109,'75101','origin','block-192107','success\\PrintBtn','',1),(192110,'75102','origin','block-192106','Html_box','',1),(192111,'75107','origin','ticket','invoice\\Container','',1),(192112,'75108','origin','block-192111','BlockBox','',4),(192113,'75109','origin','block-192112','BlockBox','',1),(192114,'75110','origin','block-192113','invoice\\ShippingAddress','',2),(192115,'75111','origin','block-192113','Text','',1),(192116,'75112','origin','block-192112-2','BlockBox','',1),(192117,'75113','origin','block-192116','invoice\\Totals','',1),(192118,'75114','origin','block-192111','BlockBox','',5),(192119,'75115','origin','block-192118','Text','',1),(192120,'75116','origin','block-192118','invoice\\StoreAddress','',8),(192121,'75117','origin','block-192118-2','Logo','',1),(192122,'75118','origin','block-192118-2','Text','',2),(192123,'75119','origin','block-192118-3','Text','',1),(192124,'75120','origin','block-192118-3','BlockBox','',3),(192125,'75121','origin','block-192124','Text','',1),(192126,'75122','origin','block-192124-2','invoice\\StoreEmail','',1),(192127,'75123','origin','block-192118-3','BlockBox','',2),(192128,'75124','origin','block-192127','Text','',1),(192129,'75125','origin','block-192127-2','invoice\\StorePhone','',1),(192130,'75126','origin','block-192111','invoice\\Products','',3),(192131,'75127','origin','block-192111','BlockBox','',1),(192132,'75128','origin','block-192131-2','BlockBox','',3),(192133,'75129','origin','block-192132','Text','',1),(192134,'75130','origin','block-192132-2','invoice\\StoreEmail','',1),(192135,'75131','origin','block-192131-2','BlockBox','',4),(192136,'75132','origin','block-192135','Text','',1),(192137,'75133','origin','block-192135-2','invoice\\StoreSite','',1),(192138,'75134','origin','block-192131-2','BlockBox','',1),(192139,'75135','origin','block-192138','invoice\\StoreAddress','',1),(192140,'75136','origin','block-192131-2','BlockBox','',2),(192141,'75137','origin','block-192140','Text','',1),(192142,'75138','origin','block-192140-2','invoice\\StorePhone','',1),(192143,'75139','origin','block-192111','BlockBox','',2),(192144,'75140','origin','block-192143','BlockBox','',8),(192145,'75141','origin','block-192144','BlockBox','',1),(192146,'75142','origin','block-192145','Text','',1),(192147,'75143','origin','block-192145','invoice\\ShippingMethod','',2),(192148,'75144','origin','block-192144-2','BlockBox','',1),(192149,'75145','origin','block-192148','Text','',1),(192150,'75146','origin','block-192148','invoice\\ShippingMethod','',2),(192151,'75147','origin','block-192143','BlockBox','',7),(192152,'75148','origin','block-192151','BlockBox','',1),(192153,'75149','origin','block-192152','invoice\\BillingAddress','',2),(192154,'75150','origin','block-192152','Text','',1),(192155,'75151','origin','block-192151-2','BlockBox','',1),(192156,'75152','origin','block-192155','invoice\\CustomerName','',2),(192157,'75153','origin','block-192155','Text','',3),(192158,'75154','origin','block-192155','invoice\\CustomerEmail','',6),(192159,'75155','origin','block-192155','invoice\\CustomerPhone','',4),(192160,'75156','origin','block-192155','Text','',5),(192161,'75157','origin','block-192155','Text','',1),(192162,'75158','origin','block-192143-2','invoice\\PaymentDate','',3),(192163,'75159','origin','block-192143-2','Text','',2),(192164,'75160','origin','block-192143-2','Text','',4),(192165,'75161','origin','block-192143-2','invoice\\OrderId','',1),(192166,'75162','origin','block-192143-2','invoice\\PaymentMethod','',5),(192167,'75163','origin','block-192143-2','invoice\\OrderBarcode','',6),(192168,'75194','origin','tracking_numbers','BlockBox','',1),(192169,'75195','origin','block-192168','Html_box','',1),(192170,'75196','origin','block-192168','account\\OrderTracking','',2),(192171,'75418','origin','unsubscribed','BlockBox','',1),(192172,'75419','origin','block-192171','Html_box','',1),(192173,'75420','origin','update-and-pay-order_confirmation','BlockBox','',1),(192174,'75421','origin','block-192173','BlockBox','',3),(192175,'75422','origin','block-192174','BlockBox','',1),(192176,'75423','origin','block-192175','BlockBox','',1),(192177,'75424','origin','block-192176','BlockBox','',1),(192178,'75425','origin','block-192177','order\\ShippingMethod','',5),(192179,'75426','origin','block-192177','Html_box','',2),(192180,'75427','origin','block-192177','Html_box','',4),(192181,'75428','origin','block-192177','Html_box','',1),(192182,'75429','origin','block-192177','order\\Telephone','',8),(192183,'75430','origin','block-192177','Html_box','',6),(192184,'75431','origin','block-192177','order\\Name','',7),(192185,'75432','origin','block-192177','order\\Email','',9),(192186,'75433','origin','block-192177','order\\DeliveryAddress','',3),(192187,'75434','origin','block-192176-2','BlockBox','',1),(192188,'75435','origin','block-192187','order\\BillingAddress','',3),(192189,'75436','origin','block-192187','UpdateAndPay\\PayConfirm','',5),(192190,'75437','origin','block-192187','Html_box','',1),(192191,'75438','origin','block-192187','Html_box','',2),(192192,'75439','origin','block-192187','Html_box','',4),(192193,'75440','origin','block-192175','BlockBox','',3),(192194,'75441','origin','block-192193','order\\Products','',2),(192195,'75442','origin','block-192193','Html_box','',1),(192196,'75443','origin','block-192174-2','BlockBox','',1),(192197,'75444','origin','block-192196','Html_box','',1),(192198,'75445','origin','block-192196','checkout\\ContinueBtn','',3),(192199,'75446','origin','block-192196','order\\Totals','',2),(192200,'75447','origin','block-192173','account\\OrderHeading','',1),(192201,'75448','origin','update-and-pay-order_pay','BlockBox','',1),(192202,'75449','origin','block-192201','BlockBox','',3),(192203,'75450','origin','block-192202','BlockBox','',1),(192204,'75451','origin','block-192203','BlockBox','',1),(192205,'75452','origin','block-192204','BlockBox','',1),(192206,'75453','origin','block-192205','order\\DeliveryAddress','',3),(192207,'75454','origin','block-192205','order\\Email','',9),(192208,'75455','origin','block-192205','order\\Name','',7),(192209,'75456','origin','block-192205','Html_box','',6),(192210,'75457','origin','block-192205','order\\Telephone','',8),(192211,'75458','origin','block-192205','Html_box','',4),(192212,'75459','origin','block-192205','order\\ShippingMethod','',5),(192213,'75460','origin','block-192205','Html_box','',1),(192214,'75461','origin','block-192205','Html_box','',2),(192215,'75462','origin','block-192204-2','BlockBox','',1),(192216,'75463','origin','block-192215','Html_box','',1),(192217,'75464','origin','block-192215','Html_box','',2),(192218,'75465','origin','block-192215','Html_box','',4),(192219,'75466','origin','block-192215','order\\BillingAddress','',3),(192220,'75467','origin','block-192215','UpdateAndPay\\PayForm','',5),(192221,'75468','origin','block-192203','BlockBox','',3),(192222,'75469','origin','block-192221','Html_box','',1),(192223,'75470','origin','block-192221','order\\Products','',2),(192224,'75471','origin','block-192202-2','BlockBox','',1),(192225,'75472','origin','block-192224','order\\Totals','',2),(192226,'75473','origin','block-192224','checkout\\ContinueBtn','',3),(192227,'75474','origin','block-192224','Html_box','',1),(192228,'75475','origin','block-192201','account\\OrderHeading','',1),(192229,'75540','origin','wishlist','BlockBox','',1),(192230,'75541','origin','block-192229','BlockBox','',1),(192231,'75542','origin','block-192230','WidgetsAria','',1),(192232,'73374','origin','account-menu','BlockBox','',1),(192233,'73375','origin','block-192232','BlockBox','account-side',1),(192234,'73376','origin','block-192233','Html_box','',16),(192235,'73377','origin','block-192233','account\\AccountLink','',17),(192236,'73378','origin','block-192233','account\\AccountLink','',18),(192237,'73379','origin','block-192233','account\\AccountLink','',1),(192238,'73380','origin','block-192233','Html_box','',2),(192239,'73381','origin','block-192233','account\\AccountLink','',4),(192240,'73382','origin','block-192233','account\\AccountLink','',7),(192241,'73383','origin','block-192233','account\\AccountLink','',11),(192242,'73384','origin','block-192233','Html_box','',6),(192243,'73385','origin','block-192233','account\\AccountLink','',3),(192244,'73386','origin','block-192233','account\\AccountLink','',14),(192245,'73387','origin','block-192233','account\\AccountLink','',8),(192246,'73388','origin','block-192233','account\\AccountLink','',5),(192247,'73389','origin','block-192233','account\\AccountLink','',9),(192248,'73390','origin','block-192233','account\\AccountLink','',12),(192249,'73391','origin','block-192233','Html_box','',10),(192250,'73392','origin','block-192233','account\\AccountLink','',15),(192251,'75543','origin','block-192230-2','account\\Wishlist','',2),(192252,'75544','origin','block-192230-2','Html_box','',1),(192253,'75545','origin','wishlist-cart','BlockBox','',1),(192254,'75546','origin','block-192253','cart\\CartTabs','',1),(192255,'75547','origin','block-192254','account\\Wishlist','',1),(192256,'73349','new_theme','404','Html_box','',1),(192257,'73350','new_theme','account','BlockBox','',1),(192258,'73351','new_theme','block-192257','BlockBox','',1),(192259,'73352','new_theme','block-192258','WidgetsAria','',1),(192279,'1704978704.8413','new_theme','block-192258-2','BlockBox','account-content',1),(192280,'73353','new_theme','block-192279','account\\OrdersHistory','',5),(192281,'73354','new_theme','block-192279','Html_box','',4),(192282,'73357','new_theme','block-192279','Html_box','',1),(192283,'1705060269.3517','new_theme','block-192279','BlockBox','account-content-top',2),(192284,'1705060551.6998','new_theme','block-192283','BlockBox','',1),(192285,'73361','new_theme','block-192284','Html_box','',1),(192286,'73362','new_theme','block-192284','account\\LastOrder','',2),(192287,'1705060566.121','new_theme','block-192283','BlockBox','',2),(192288,'73363','new_theme','block-192287','Html_box','',1),(192289,'73364','new_theme','block-192287','account\\OrderCount','',2),(192290,'73365','new_theme','block-192287','account\\AccountLink','',3),(192291,'1705060582.9285','new_theme','block-192283','BlockBox','',3),(192292,'73366','new_theme','block-192291','Html_box','',1),(192293,'73367','new_theme','block-192291','account\\TotalOrdered','',2),(192294,'1705060591.4402','new_theme','block-192283','BlockBox','',4),(192295,'73368','new_theme','block-192294','Html_box','',1),(192296,'73369','new_theme','block-192294','account\\CreditAmount','',2),(192297,'73370','new_theme','block-192294','account\\AccountLink','',3),(192298,'1705060602.1936','new_theme','block-192283','BlockBox','',5),(192299,'73371','new_theme','block-192298','account\\AccountLink','',3),(192300,'73372','new_theme','block-192298','BonusActions\\widgets\\PointsEarnt','',2),(192301,'73373','new_theme','block-192298','Html_box','',1),(192321,'73393','new_theme','account_edit','BlockBox','',1),(192322,'73394','new_theme','block-192321','BlockBox','',1),(192323,'73395','new_theme','block-192322','WidgetsAria','',1),(192343,'73396','new_theme','block-192322-2','account\\AccountEdit','',2),(192344,'73397','new_theme','block-192322-2','Html_box','',1),(192345,'73398','new_theme','address_book','BlockBox','',1),(192346,'73399','new_theme','block-192345','BlockBox','',1),(192347,'73400','new_theme','block-192346','WidgetsAria','',1),(192367,'73401','new_theme','block-192346-2','account\\AddressBook','',3),(192368,'73402','new_theme','block-192346-2','Html_box','',1),(192369,'73403','new_theme','block-192346-2','Html_box','',2),(192370,'73404','new_theme','address_book_process','BlockBox','',1),(192371,'73405','new_theme','block-192370','BlockBox','',1),(192372,'73406','new_theme','block-192371','WidgetsAria','',1),(192392,'73407','new_theme','block-192371-2','Html_box','',1),(192393,'73408','new_theme','block-192371-2','account\\EditAddress','',2),(192394,'73409','new_theme','b2b','BlockBox','listing-item',1),(192395,'73410','new_theme','block-192394','BlockBox','',1),(192396,'73411','new_theme','block-192395','productListing\\image','',1),(192397,'73412','new_theme','block-192395-2','productListing\\description','',6),(192398,'73413','new_theme','block-192395-2','productListing\\model','',5),(192399,'73414','new_theme','block-192395-2','productListing\\attributes','',3),(192400,'73415','new_theme','block-192395-2','BlockBox','',4),(192401,'73416','new_theme','block-192400','BlockBox','',1),(192402,'73417','new_theme','block-192401','productListing\\price','',1),(192403,'73418','new_theme','block-192401-2','BonusActions\\widgets\\BonusPointsProductListing','',1),(192404,'73419','new_theme','block-192400-2','productListing\\qtyInput','',1),(192405,'73420','new_theme','block-192395-2','productListing\\name','',1),(192406,'73421','new_theme','block-192395-2','BlockBox','',2),(192407,'73422','new_theme','block-192406','productListing\\stock','',1),(192408,'73423','new_theme','block-192406-2','productListing\\rating','',1),(192409,'76000','new_theme','batch','BlockBox','',1),(192410,'76001','new_theme','block-192409','productListing\\attributes','',5),(192411,'76002','new_theme','block-192409','productListing\\price','',6),(192412,'76003','new_theme','block-192409','productListing\\name','',4),(192413,'76004','new_theme','block-192409','productListing\\image','',2),(192414,'76005','new_theme','block-192409','batchSelect','',1),(192415,'76006','new_theme','batch_selected','BlockBox','',1),(192416,'76007','new_theme','block-192415','BlockBox','',13),(192417,'76008','new_theme','block-192416','productListing\\image','',1),(192418,'76009','new_theme','block-192416-2','batchRemove','',1),(192419,'76010','new_theme','block-192416-2','productListing\\price','',3),(192420,'76011','new_theme','block-192416-2','productListing\\name','',2),(192421,'76012','new_theme','bbbbb','BlockBox','',1),(192422,'76013','new_theme','block-192421','BlockBox','',2),(192423,'76014','new_theme','block-192422','Filters','',1),(192424,'76015','new_theme','block-192422-2','BlockBox','',6),(192425,'76016','new_theme','block-192424','catalog\\CountsItems','',1),(192426,'76017','new_theme','block-192424-2','catalog\\Paging','',1),(192427,'76018','new_theme','block-192422-2','catalog\\Image','',1),(192428,'76019','new_theme','block-192422-2','Listing','',5),(192429,'76020','new_theme','block-192422-2','catalog\\ImageMapCategory','',3),(192430,'76021','new_theme','block-192422-2','BlockBox','',4),(192431,'76022','new_theme','block-192430','catalog\\ListingLook','',1),(192432,'76023','new_theme','block-192430','catalog\\CompareButton','',2),(192433,'76024','new_theme','block-192430','catalog\\ItemsOnPage','',4),(192434,'76025','new_theme','block-192430','catalog\\Sorting','',3),(192435,'76026','new_theme','block-192422-2','Categories','',2),(192436,'76027','new_theme','block-192421','catalog\\Title','',1),(192437,'1683124632.767746','new_theme','cart','BlockBox','',1),(192438,'1683124632.80670','new_theme','block-192437','BlockBox','',2),(192439,'1683124632.809680','new_theme','block-192438','BlockBox','cart-content',4),(192440,'1683124632.816335','new_theme','block-192438','BlockBox','',1),(192441,'1683124632.817623','new_theme','block-192440','cart\\Products','',2),(192442,'1683124632.818551','new_theme','block-192440','BlockBox','',1),(192443,'1683124632.820317','new_theme','block-192442','MultiCart\\CartSwitcher','',1),(192444,'1683124632.820914','new_theme','block-192442','MultiCart\\SaveCart','',2),(192445,'1683124632.822588','new_theme','block-192442-2','MultiCart\\Actions','',1),(192446,'1683124632.823175','new_theme','block-192440','BlockBox','',3),(192447,'1683124632.825245','new_theme','block-192446','cart\\CreditAmount','',1),(192448,'1683124632.825649','new_theme','block-192446-2','BonusActions\\widgets\\BonusPointsCart','',1),(192449,'1683124632.82683','new_theme','block-192438','BlockBox','',3),(192450,'1683124632.827413','new_theme','block-192449','cart\\GiveAway','',2),(192451,'1683124632.828374','new_theme','block-192449','Html_box','',1),(192452,'1683124632.829840','new_theme','block-192438','BlockBox','',5),(192453,'1683124632.831459','new_theme','block-192452','Html_box','',1),(192454,'1683124632.832592','new_theme','block-192452','cart\\ShippingEstimator','',2),(192455,'1683124632.833353','new_theme','block-192438-2','BlockBox','',1),(192456,'1683124632.834715','new_theme','block-192455','BlockBox','',2),(192457,'1683124632.835884','new_theme','block-192456','cart\\DiscountCoupon','',1),(192458,'1683124632.836532','new_theme','block-192456','Image','',4),(192459,'1683124632.844829','new_theme','block-192456','cart\\CheckoutBtn','',3),(192460,'1683124632.84681','new_theme','block-192456','cart\\OrderTotal','',2),(192461,'1683124632.846538','new_theme','block-192456','cart\\OrderTotal','',0),(192462,'1683124632.84726','new_theme','block-192455','Html_box','',1),(192463,'94658','new_theme','cart2','BlockBox','',2),(192464,'94659','new_theme','block-192463','cart\\CartTabs','',2),(192465,'94660','new_theme','block-192464','BlockBox','',1),(192466,'94661','new_theme','block-192465','BlockBox','',4),(192467,'94662','new_theme','block-192466','cart\\UpSell','6',2),(192468,'94663','new_theme','block-192466','Html_box','',1),(192469,'94664','new_theme','block-192465','BlockBox','',1),(192470,'94665','new_theme','block-192469','cart\\Products','',3),(192471,'94666','new_theme','block-192469','BlockBox','',2),(192472,'94667','new_theme','block-192471','MultiCart\\CartSwitcher','',1),(192473,'94668','new_theme','block-192471','MultiCart\\SaveCart','',2),(192474,'94669','new_theme','block-192471-2','MultiCart\\Actions','',1),(192475,'94670','new_theme','block-192465','BlockBox','',3),(192476,'94671','new_theme','block-192475','cart\\GiveAway','',2),(192477,'94672','new_theme','block-192475','Html_box','',1),(192478,'94673','new_theme','block-192465','BlockBox','',2),(192479,'94674','new_theme','block-192478','Html_box','',1),(192480,'94675','new_theme','block-192478','BlockBox','',2),(192481,'94676','new_theme','block-192480','cart\\DiscountCoupon','',1),(192482,'94677','new_theme','block-192480-2','cart\\CreditAmount','',1),(192483,'94678','new_theme','block-192480-3','BonusActions\\widgets\\BonusPointsCart','',1),(192484,'94679','new_theme','block-192465','BlockBox','',5),(192485,'94680','new_theme','block-192484','Html_box','',1),(192486,'94681','new_theme','block-192484','cart\\ShippingEstimator','',2),(192487,'94682','new_theme','block-192465-2','BlockBox','',1),(192488,'94683','new_theme','block-192487','Html_box','',1),(192489,'94684','new_theme','block-192487','BlockBox','',2),(192490,'94685','new_theme','block-192489','Image','',4),(192491,'94686','new_theme','block-192489','cart\\CheckoutBtn','',2),(192492,'94687','new_theme','block-192489','cart\\OrderTotal','',1),(192493,'73462','new_theme','categories','BlockBox','catalog-content',1),(192494,'73463','new_theme','block-192493','BlockBox','catalog-side',2),(192495,'73464','new_theme','block-192494','Filters','',1),(192496,'73465','new_theme','block-192494-2','Listing','',5),(192497,'73466','new_theme','block-192494-2','catalog\\Image','',1),(192498,'73467','new_theme','block-192494-2','BlockBox','',6),(192499,'73468','new_theme','block-192498','catalog\\CountsItems','',1),(192500,'73469','new_theme','block-192498-2','catalog\\Paging','',1),(192501,'73470','new_theme','block-192494-2','catalog\\ImageMapCategory','',3),(192502,'73471','new_theme','block-192494-2','Categories','',2),(192503,'73472','new_theme','block-192494-2','BlockBox','catalog-features',4),(192504,'73473','new_theme','block-192503','catalog\\ListingLook','',1),(192505,'73474','new_theme','block-192503','catalog\\CompareButton','',2),(192506,'73475','new_theme','block-192503','catalog\\ItemsOnPage','',4),(192507,'73476','new_theme','block-192503','catalog\\Sorting','',3),(192508,'73477','new_theme','block-192493','catalog\\Title','',1),(192509,'73478','new_theme','category','Categories','',1),(192510,'73479','new_theme','category','Listing','',4),(192511,'73480','new_theme','category','ListingFunctionality','',2),(192512,'73481','new_theme','category','PagingBar','',3),(192513,'73482','new_theme','category','PagingBar','',5),(192514,'94688','new_theme','category_2','BlockBox','',1),(192515,'94689','new_theme','block-192514','catalog\\Title','',1),(192516,'94690','new_theme','block-192514','BlockBox','',2),(192517,'94691','new_theme','block-192516','Filters','',1),(192518,'94692','new_theme','block-192516-2','catalog\\Image','',1),(192519,'94693','new_theme','block-192516-2','Listing','',5),(192520,'94694','new_theme','block-192516-2','BlockBox','',4),(192521,'94695','new_theme','block-192520','catalog\\Sorting','',3),(192522,'94696','new_theme','block-192520','catalog\\ItemsOnPage','',4),(192523,'94697','new_theme','block-192520','catalog\\CompareButton','',2),(192524,'94698','new_theme','block-192520','catalog\\ListingLook','',1),(192525,'94699','new_theme','block-192516-2','catalog\\ImageMapCategory','',3),(192526,'94700','new_theme','block-192516-2','Categories','',2),(192527,'94701','new_theme','block-192516-2','BlockBox','',6),(192528,'94702','new_theme','block-192527','catalog\\CountsItems','',1),(192529,'94703','new_theme','block-192527-2','catalog\\Paging','',1),(192530,'73483','new_theme','category_no_filters','BlockBox','',1),(192531,'73484','new_theme','block-192530','catalog\\Title','',1),(192532,'73485','new_theme','block-192530','Categories','',3),(192533,'73486','new_theme','block-192530','BlockBox','catalog-features',4),(192534,'73487','new_theme','block-192533','catalog\\ItemsOnPage','',4),(192535,'73488','new_theme','block-192533','catalog\\Sorting','',3),(192536,'73489','new_theme','block-192533','catalog\\CompareButton','',2),(192537,'73490','new_theme','block-192533','catalog\\ListingLook','',1),(192538,'73491','new_theme','block-192533','HeaderStock','',5),(192539,'73492','new_theme','block-192530','BlockBox','',6),(192540,'73493','new_theme','block-192539','catalog\\CountsItems','',1),(192541,'73494','new_theme','block-192539-2','catalog\\Paging','',1),(192542,'73495','new_theme','block-192530','Listing','',5),(192543,'73496','new_theme','block-192530','catalog\\Image','',2),(192544,'73497','new_theme','block-192530','catalog\\B2bAddButton','',7),(192545,'1683125852.345798','new_theme','checkout','BlockBox','',1),(192546,'1683125852.356555','new_theme','block-192545','BlockBox','',2),(192547,'1683125852.358412','new_theme','block-192546','BlockBox','',2),(192548,'1683125852.35982','new_theme','block-192547','BlockBox','checkout-comments',5),(192549,'1683125852.361569','new_theme','block-192548','checkout\\Comments','',2),(192550,'1683125852.362847','new_theme','block-192548','Html_box','',1),(192551,'1683125852.36485','new_theme','block-192547','BlockBox','checkout-discount',4),(192552,'1683125852.366422','new_theme','block-192551','Html_box','',1),(192553,'1683125852.367732','new_theme','block-192551','BlockBox','',2),(192554,'1683125852.36968','new_theme','block-192553','CouponsAndVauchers\\Checkout','',1),(192555,'1683125852.369745','new_theme','block-192553-2','checkout\\CreditAmount','',1),(192556,'1683125852.37045','new_theme','block-192553-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(192557,'1683125852.371233','new_theme','block-192547','BlockBox','checkout-shipping',2),(192558,'1683125852.37350','new_theme','block-192557','BlockBox','',3),(192559,'1683125852.374899','new_theme','block-192558','checkout\\ShippingChoice','',1),(192560,'1683125852.375685','new_theme','block-192557','Neighbour\\Checkout','',5),(192561,'1683125852.376557','new_theme','block-192557','BlockBox','',4),(192562,'1683125852.377637','new_theme','block-192561','BlockBox','',1),(192563,'1683125852.378829','new_theme','block-192562','checkout\\ShippingAddress','',2),(192564,'1683125852.379375','new_theme','block-192562','Html_box','',3),(192565,'1683125852.380323','new_theme','block-192562','checkout\\ContactInformation','',4),(192566,'1683125852.380722','new_theme','block-192562','UploadCustomerId\\UploadCustomerIdForm','',4),(192567,'1683125852.381183','new_theme','block-192561-2','BlockBox','',1),(192568,'1683125852.382226','new_theme','block-192567','checkout\\Shipping','',2),(192569,'1683125852.382635','new_theme','block-192567','DelayedDespatch\\Checkout','',3),(192570,'1683125852.383516','new_theme','block-192567','Html_box','',1),(192571,'1683125852.385278','new_theme','block-192557','Html_box','',2),(192572,'1683125852.386397','new_theme','block-192547','cart\\Products','',6),(192573,'1683125852.386970','new_theme','block-192547','checkout\\CreateAccount','',7),(192574,'1683125852.38820','new_theme','block-192547','BlockBox','checkout-payment',3),(192575,'1683125852.390244','new_theme','block-192574','Html_box','',1),(192576,'1683125852.391810','new_theme','block-192574','BlockBox','',2),(192577,'1683125852.393320','new_theme','block-192576','Html_box','',1),(192578,'1683125852.394747','new_theme','block-192576','checkout\\BillingAddress','',2),(192579,'1683125852.395767','new_theme','block-192576-2','BlockBox','',1),(192580,'1683125852.397129','new_theme','block-192579','checkout\\PaymentMethod','',2),(192581,'1683125852.398588','new_theme','block-192579','Html_box','',1),(192582,'1683125852.400291','new_theme','block-192547','BlockBox','',1),(192583,'1683125852.402237','new_theme','block-192582','checkout\\LoginOnForm','',0),(192584,'1683128325.0836','new_theme','block-192582','BlockBox','',1),(192585,'1683125852.403563','new_theme','block-192546-2','BlockBox','checkout-side',1),(192586,'1683125852.405625','new_theme','block-192585','Html_box','',6),(192587,'1683125852.407666','new_theme','block-192585','Html_box','',1),(192588,'1683125852.40885','new_theme','block-192585','checkout\\Terms','',5),(192589,'1683125852.409688','new_theme','block-192585','checkout\\Totals','',3),(192590,'1683125852.410151','new_theme','block-192585','checkout\\ContinueBtn','',4),(192591,'1683125852.412647','new_theme','block-192585','cart\\Products','',2),(192592,'73542','new_theme','checkout_confirmation','BlockBox','',1),(192593,'73543','new_theme','block-192592','checkout\\Totals','',8),(192594,'73544','new_theme','block-192592','Html_box','',5),(192595,'73545','new_theme','block-192592','checkout\\EditBtn','',6),(192596,'73546','new_theme','block-192592','BlockBox','',3),(192597,'73547','new_theme','block-192596','BlockBox','',1),(192598,'73548','new_theme','block-192597','Html_box','',1),(192599,'73549','new_theme','block-192597','checkout\\ShippingConfirm','',3),(192600,'73550','new_theme','block-192596-2','BlockBox','',1),(192601,'73551','new_theme','block-192600','checkout\\PaymentMethodConfirm','',3),(192602,'73552','new_theme','block-192600','Html_box','',1),(192603,'73553','new_theme','block-192592','checkout\\ConfirmBtn','',9),(192604,'73554','new_theme','block-192592','BlockBox','',2),(192605,'73555','new_theme','block-192604','BlockBox','',1),(192606,'73556','new_theme','block-192605','checkout\\ShippingAddressConfirm','',3),(192607,'73557','new_theme','block-192605','Html_box','',1),(192608,'73558','new_theme','block-192604-2','BlockBox','',1),(192609,'73559','new_theme','block-192608','Html_box','',1),(192610,'73560','new_theme','block-192608','checkout\\BillingAddressConfirm','',3),(192611,'73561','new_theme','block-192592','checkout\\ConfirmBtn','',4),(192612,'73562','new_theme','block-192592','cart\\Products','',7),(192613,'73576','new_theme','checkout_confirmation_no_shipping','BlockBox','',1),(192614,'73577','new_theme','block-192613','checkout\\ConfirmBtn','',9),(192615,'73578','new_theme','block-192613','BlockBox','',2),(192616,'73579','new_theme','block-192615','BlockBox','',1),(192617,'73580','new_theme','block-192616','Html_box','',1),(192618,'73581','new_theme','block-192616','checkout\\BillingAddressConfirm','',3),(192619,'73582','new_theme','block-192615-2','BlockBox','',1),(192620,'73583','new_theme','block-192619','Html_box','',1),(192621,'73584','new_theme','block-192619','checkout\\PaymentMethodConfirm','',3),(192622,'73585','new_theme','block-192613','checkout\\ConfirmBtn','',4),(192623,'73586','new_theme','block-192613','checkout\\Totals','',8),(192624,'73587','new_theme','block-192613','cart\\Products','',7),(192625,'73588','new_theme','block-192613','Html_box','',5),(192626,'73563','new_theme','checkout_confirmation_no_shipping_q','BlockBox','',1),(192627,'73564','new_theme','block-192626','quote\\Products','',4),(192628,'73565','new_theme','block-192626','checkout\\ConfirmBtn','',2),(192629,'73566','new_theme','block-192626','checkout\\ConfirmBtn','',6),(192630,'73567','new_theme','block-192626','BlockBox','',1),(192631,'73568','new_theme','block-192630','BlockBox','',1),(192632,'73569','new_theme','block-192631','checkout\\BillingAddressConfirm','',3),(192633,'73570','new_theme','block-192631','Html_box','',1),(192634,'73571','new_theme','block-192630-2','BlockBox','',1),(192635,'73572','new_theme','block-192634','checkout\\PaymentMethodConfirm','',3),(192636,'73573','new_theme','block-192634','Html_box','',1),(192637,'73574','new_theme','block-192626','Html_box','',3),(192638,'73575','new_theme','block-192626','checkout\\Totals','',5),(192639,'73589','new_theme','checkout_confirmation_q','BlockBox','',1),(192640,'73590','new_theme','block-192639','BlockBox','',1),(192641,'73591','new_theme','block-192640','BlockBox','',1),(192642,'73592','new_theme','block-192641','checkout\\ShippingAddressConfirm','',3),(192643,'73593','new_theme','block-192641','Html_box','',1),(192644,'73594','new_theme','block-192640-2','BlockBox','',1),(192645,'73595','new_theme','block-192644','checkout\\BillingAddressConfirm','',3),(192646,'73596','new_theme','block-192644','Html_box','',1),(192647,'73597','new_theme','block-192639','checkout\\Totals','',7),(192648,'73598','new_theme','block-192639','quote\\Products','',6),(192649,'73599','new_theme','block-192639','Html_box','',4),(192650,'73600','new_theme','block-192639','checkout\\EditBtn','',5),(192651,'73601','new_theme','block-192639','checkout\\ConfirmBtn','',8),(192652,'73602','new_theme','block-192639','checkout\\ConfirmBtn','',3),(192653,'73603','new_theme','block-192639','BlockBox','',2),(192654,'73604','new_theme','block-192653','BlockBox','',1),(192655,'73605','new_theme','block-192654','Html_box','',1),(192656,'73606','new_theme','block-192654','checkout\\ShippingConfirm','',3),(192657,'73607','new_theme','block-192653-2','BlockBox','',1),(192658,'73608','new_theme','block-192657','Html_box','',1),(192659,'73609','new_theme','block-192657','checkout\\PaymentMethodConfirm','',3),(192660,'73610','new_theme','checkout_confirmation_title','Html_box','',1),(192661,'73611','new_theme','checkout_confirmation_title_g','Html_box','',1),(192662,'73613','new_theme','checkout_confirmation_title_no_shipping','Html_box','',1),(192663,'73612','new_theme','checkout_confirmation_title_no_shipping_g','Html_box','',1),(192664,'73614','new_theme','checkout_confirmation_title_q','Html_box','',1),(192665,'73615','new_theme','checkout_confirmation_title_s','Html_box','',1),(192666,'73616','new_theme','checkout_delivery','BlockBox','',2),(192667,'73617','new_theme','block-192666','BlockBox','',1),(192668,'73618','new_theme','block-192667','Html_box','',1),(192669,'73619','new_theme','block-192667','checkout\\ContactInformation','',2),(192670,'73620','new_theme','block-192666-2','BlockBox','',1),(192671,'73621','new_theme','block-192670','Html_box','',1),(192672,'73622','new_theme','block-192670','checkout\\Comments','',2),(192673,'73623','new_theme','checkout_delivery','BlockBox','',3),(192674,'73624','new_theme','block-192673','Html_box','',1),(192675,'73625','new_theme','block-192673-2','checkout\\ContinueBtn','',1),(192676,'73626','new_theme','checkout_delivery','BlockBox','',1),(192677,'73627','new_theme','block-192676','BlockBox','',1),(192678,'73628','new_theme','block-192677','Html_box','',1),(192679,'73629','new_theme','block-192677','checkout\\ShippingAddress','',2),(192680,'73630','new_theme','block-192676-2','BlockBox','',1),(192681,'73631','new_theme','block-192680','DelayedDespatch\\Checkout','',3),(192682,'73632','new_theme','block-192680','checkout\\Shipping','',2),(192683,'73633','new_theme','block-192680','Html_box','',1),(192684,'73634','new_theme','block-192680','Neighbour\\Checkout','',4),(192685,'73635','new_theme','checkout_delivery_g','BlockBox','',2),(192686,'73636','new_theme','block-192685','BlockBox','',1),(192687,'73637','new_theme','block-192686','checkout\\ContactInformation','',2),(192688,'73638','new_theme','block-192686','Html_box','',1),(192689,'73639','new_theme','block-192685-2','BlockBox','',1),(192690,'73640','new_theme','block-192689','Html_box','',1),(192691,'73641','new_theme','block-192689','checkout\\Comments','',2),(192692,'73642','new_theme','checkout_delivery_g','BlockBox','',3),(192693,'73643','new_theme','block-192692','Html_box','',1),(192694,'73644','new_theme','block-192692-2','checkout\\ContinueBtn','',1),(192695,'73645','new_theme','checkout_delivery_g','BlockBox','',1),(192696,'73646','new_theme','block-192695','BlockBox','',1),(192697,'73647','new_theme','block-192696','checkout\\ShippingAddress','',2),(192698,'73648','new_theme','block-192696','Html_box','',1),(192699,'73649','new_theme','block-192695-2','BlockBox','',1),(192700,'73650','new_theme','block-192699','checkout\\Shipping','',2),(192701,'73651','new_theme','block-192699','Html_box','',1),(192702,'73652','new_theme','block-192699','DelayedDespatch\\Checkout','',3),(192703,'73653','new_theme','block-192699','Neighbour\\Checkout','',4),(192704,'73654','new_theme','checkout_delivery_no_shipping','BlockBox','',2),(192705,'73655','new_theme','block-192704','Html_box','',1),(192706,'73656','new_theme','block-192704-2','checkout\\ContinueBtn','',1),(192707,'73657','new_theme','checkout_delivery_no_shipping','BlockBox','',1),(192708,'73658','new_theme','block-192707','BlockBox','',1),(192709,'73659','new_theme','block-192708','checkout\\ContactInformation','',2),(192710,'73660','new_theme','block-192707-2','BlockBox','',1),(192711,'73661','new_theme','block-192710','Html_box','',1),(192712,'73662','new_theme','block-192710','checkout\\Comments','',2),(192713,'73663','new_theme','checkout_delivery_no_shipping_g','BlockBox','',2),(192714,'73664','new_theme','block-192713','Html_box','',1),(192715,'73665','new_theme','block-192713-2','checkout\\ContinueBtn','',1),(192716,'73666','new_theme','checkout_delivery_no_shipping_g','BlockBox','',1),(192717,'73667','new_theme','block-192716','BlockBox','',1),(192718,'73668','new_theme','block-192717','checkout\\ContactInformation','',2),(192719,'73669','new_theme','block-192716-2','BlockBox','',1),(192720,'73670','new_theme','block-192719','checkout\\Comments','',2),(192721,'73671','new_theme','block-192719','Html_box','',1),(192722,'73672','new_theme','checkout_delivery_title','Html_box','',1),(192723,'73673','new_theme','checkout_delivery_title_g','Html_box','',1),(192724,'73675','new_theme','checkout_delivery_title_no_shipping','Html_box','',1),(192725,'73674','new_theme','checkout_delivery_title_no_shipping_g','Html_box','',1),(192726,'73676','new_theme','checkout_delivery_title_q','Html_box','',1),(192727,'73677','new_theme','checkout_delivery_title_s','Html_box','',1),(192728,'73678','new_theme','checkout_free_s','BlockBox','',1),(192729,'73679','new_theme','block-192728','BlockBox','',2),(192730,'73680','new_theme','block-192729','BlockBox','',2),(192731,'73682','new_theme','block-192730','BlockBox','',6),(192732,'73683','new_theme','block-192731','sample\\Products','',1),(192733,'73684','new_theme','block-192731','checkout\\CreateAccount','',3),(192734,'73685','new_theme','block-192730','BlockBox','',5),(192735,'73686','new_theme','block-192734','Html_box','',1),(192736,'73687','new_theme','block-192734','checkout\\Comments','',2),(192737,'73688','new_theme','block-192730','BlockBox','',2),(192738,'73689','new_theme','block-192737','BlockBox','',2),(192739,'73690','new_theme','block-192738','checkout\\ShippingChoice','',1),(192740,'73691','new_theme','block-192737','Html_box','',1),(192741,'73692','new_theme','block-192737','BlockBox','',3),(192742,'73693','new_theme','block-192741','BlockBox','',1),(192743,'73694','new_theme','block-192742','checkout\\ContactInformation','',4),(192744,'73695','new_theme','block-192742','checkout\\ShippingAddress','',2),(192745,'73696','new_theme','block-192742','Html_box','',3),(192746,'73697','new_theme','block-192741-2','BlockBox','',1),(192747,'73698','new_theme','block-192746','DelayedDespatch\\Checkout','',3),(192748,'73699','new_theme','block-192737','Neighbour\\Checkout','',4),(192749,'73700','new_theme','block-192729-2','BlockBox','',1),(192750,'73701','new_theme','block-192749','Html_box','',3),(192751,'73702','new_theme','block-192749','checkout\\ContinueBtn','',1),(192752,'115999','new_theme','block-192749','checkout\\Terms','',2),(192753,'73703','new_theme','checkout_no_shipping','BlockBox','',1),(192754,'73704','new_theme','block-192753','BlockBox','',2),(192755,'73705','new_theme','block-192754','BlockBox','',1),(192756,'73706','new_theme','block-192755','BlockBox','',6),(192757,'73707','new_theme','block-192756','checkout\\CreateAccount','',2),(192758,'73708','new_theme','block-192756','cart\\Products','',1),(192759,'73709','new_theme','block-192755','BlockBox','',3),(192760,'73710','new_theme','block-192759','Html_box','',1),(192761,'73711','new_theme','block-192759','BlockBox','',2),(192762,'73712','new_theme','block-192761','checkout\\BillingAddress','',2),(192763,'73713','new_theme','block-192761','Html_box','',1),(192764,'73714','new_theme','block-192761-2','BlockBox','',1),(192765,'73715','new_theme','block-192764','Html_box','',1),(192766,'73716','new_theme','block-192764','checkout\\PaymentMethod','',2),(192767,'73717','new_theme','block-192755','BlockBox','',4),(192768,'73718','new_theme','block-192767','BlockBox','',2),(192769,'73719','new_theme','block-192768','CouponsAndVauchers\\Checkout','',1),(192770,'73720','new_theme','block-192768-2','checkout\\CreditAmount','',1),(192771,'73721','new_theme','block-192768-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(192772,'73722','new_theme','block-192767','Html_box','',1),(192773,'73723','new_theme','block-192755','BlockBox','',5),(192774,'73724','new_theme','block-192773','checkout\\Comments','',2),(192775,'73725','new_theme','block-192773','Html_box','',1),(192776,'73726','new_theme','block-192754-2','BlockBox','',1),(192777,'73727','new_theme','block-192776','Html_box','',1),(192778,'73728','new_theme','block-192776','Html_box','',5),(192779,'73729','new_theme','block-192776','checkout\\Totals','',2),(192780,'73730','new_theme','block-192776','checkout\\ContinueBtn','',3),(192781,'73731','new_theme','block-192776','checkout\\Terms','',4),(192782,'73732','new_theme','checkout_no_shipping_g','BlockBox','',1),(192783,'73733','new_theme','block-192782','checkout\\Totals','',5),(192784,'73734','new_theme','block-192782','BlockBox','',6),(192785,'73735','new_theme','block-192784','Html_box','',1),(192786,'73736','new_theme','block-192784-2','checkout\\ContinueBtn','',1),(192787,'73737','new_theme','block-192782','BlockBox','',2),(192788,'73738','new_theme','block-192787','BlockBox','',1),(192789,'73739','new_theme','block-192788','checkout\\ContactInformation','',2),(192790,'73740','new_theme','block-192788','Html_box','',1),(192791,'73741','new_theme','block-192787-2','BlockBox','',1),(192792,'73742','new_theme','block-192791','checkout\\Comments','',2),(192793,'73743','new_theme','block-192791','Html_box','',1),(192794,'73744','new_theme','block-192782','BlockBox','',1),(192795,'73745','new_theme','block-192794','BlockBox','',1),(192796,'73746','new_theme','block-192795','Html_box','',1),(192797,'73747','new_theme','block-192795','checkout\\BillingAddress','',2),(192798,'73748','new_theme','block-192794-2','BlockBox','',1),(192799,'73749','new_theme','block-192798','BonusActions\\widgets\\BonusPointsCheckout','',4),(192800,'73750','new_theme','block-192798','CouponsAndVauchers\\Checkout','',5),(192801,'73751','new_theme','block-192798','checkout\\PaymentMethod','',2),(192802,'73752','new_theme','block-192798','checkout\\CreditAmount','',3),(192803,'73753','new_theme','block-192798','Html_box','',1),(192804,'73754','new_theme','block-192782','quote\\Products','',3),(192805,'73755','new_theme','checkout_no_shipping_q','BlockBox','',1),(192806,'73756','new_theme','block-192805','BlockBox','',2),(192807,'73757','new_theme','block-192806','BlockBox','',2),(192808,'73758','new_theme','block-192807','checkout\\Gdpr','',1),(192809,'73759','new_theme','block-192807','BlockBox','',5),(192810,'73760','new_theme','block-192809','checkout\\Comments','',2),(192811,'73761','new_theme','block-192809','Html_box','',1),(192812,'73762','new_theme','block-192807','BlockBox','',6),(192813,'73763','new_theme','block-192812','checkout\\CreateAccount','',3),(192814,'73764','new_theme','block-192812','quote\\Products','',2),(192815,'73765','new_theme','block-192807','BlockBox','',3),(192816,'73766','new_theme','block-192815','Html_box','',1),(192817,'73767','new_theme','block-192815','BlockBox','',2),(192818,'73768','new_theme','block-192817','Html_box','',1),(192819,'73769','new_theme','block-192817','checkout\\BillingAddress','',2),(192820,'73770','new_theme','block-192817-2','BlockBox','',1),(192821,'73771','new_theme','block-192820','checkout\\PaymentMethod','',2),(192822,'73772','new_theme','block-192820','Html_box','',1),(192823,'73773','new_theme','block-192806-2','BlockBox','',1),(192824,'73774','new_theme','block-192823','checkout\\ContinueBtn','',3),(192825,'73775','new_theme','block-192823','Html_box','',4),(192826,'73776','new_theme','block-192823','Html_box','',1),(192827,'73777','new_theme','block-192823','checkout\\Totals','',2),(192828,'73778','new_theme','checkout_payment','BlockBox','',1),(192829,'73779','new_theme','block-192828','BlockBox','',1),(192830,'73780','new_theme','block-192829','checkout\\BillingAddress','',2),(192831,'73781','new_theme','block-192829','Html_box','',1),(192832,'73782','new_theme','block-192828-2','BlockBox','',1),(192833,'73783','new_theme','block-192832','checkout\\CreditAmount','',3),(192834,'73784','new_theme','block-192832','BonusActions\\widgets\\BonusPointsCheckout','',4),(192835,'73785','new_theme','block-192832','CouponsAndVauchers\\Checkout','',5),(192836,'73786','new_theme','block-192832','checkout\\PaymentMethod','',2),(192837,'73787','new_theme','block-192832','Html_box','',1),(192838,'73788','new_theme','checkout_payment','BlockBox','',2),(192839,'73789','new_theme','block-192838','Html_box','',1),(192840,'73790','new_theme','block-192838-2','checkout\\ContinueBtn','',1),(192841,'73791','new_theme','checkout_payment_g','BlockBox','',1),(192842,'73792','new_theme','block-192841','BlockBox','',1),(192843,'73793','new_theme','block-192842','checkout\\BillingAddress','',2),(192844,'73794','new_theme','block-192842','Html_box','',1),(192845,'73795','new_theme','block-192841-2','BlockBox','',1),(192846,'73796','new_theme','block-192845','checkout\\CreditAmount','',3),(192847,'73797','new_theme','block-192845','Html_box','',1),(192848,'73798','new_theme','block-192845','checkout\\PaymentMethod','',2),(192849,'73799','new_theme','block-192845','CouponsAndVauchers\\Checkout','',5),(192850,'73800','new_theme','block-192845','BonusActions\\widgets\\BonusPointsCheckout','',4),(192851,'73801','new_theme','checkout_payment_g','BlockBox','',2),(192852,'73802','new_theme','block-192851','Html_box','',1),(192853,'73803','new_theme','block-192851-2','checkout\\ContinueBtn','',1),(192854,'73804','new_theme','checkout_payment_no_shipping','BlockBox','',2),(192855,'73805','new_theme','block-192854','Html_box','',1),(192856,'73806','new_theme','block-192854-2','checkout\\ContinueBtn','',1),(192857,'73807','new_theme','checkout_payment_no_shipping','BlockBox','',1),(192858,'73808','new_theme','block-192857','BlockBox','',1),(192859,'73809','new_theme','block-192858','Html_box','',1),(192860,'73810','new_theme','block-192858','checkout\\BillingAddress','',2),(192861,'73811','new_theme','block-192857-2','BlockBox','',1),(192862,'73812','new_theme','block-192861','BonusActions\\widgets\\BonusPointsCheckout','',4),(192863,'73813','new_theme','block-192861','CouponsAndVauchers\\Checkout','',5),(192864,'73814','new_theme','block-192861','checkout\\PaymentMethod','',2),(192865,'73815','new_theme','block-192861','checkout\\CreditAmount','',3),(192866,'73816','new_theme','block-192861','Html_box','',1),(192867,'73817','new_theme','checkout_payment_no_shipping_g','BlockBox','',2),(192868,'73818','new_theme','block-192867','Html_box','',1),(192869,'73819','new_theme','block-192867-2','checkout\\ContinueBtn','',1),(192870,'73820','new_theme','checkout_payment_no_shipping_g','BlockBox','',1),(192871,'73821','new_theme','block-192870','BlockBox','',1),(192872,'73822','new_theme','block-192871','checkout\\BillingAddress','',2),(192873,'73823','new_theme','block-192871','Html_box','',1),(192874,'73824','new_theme','block-192870-2','BlockBox','',1),(192875,'73825','new_theme','block-192874','BonusActions\\widgets\\BonusPointsCheckout','',4),(192876,'73826','new_theme','block-192874','checkout\\CreditAmount','',3),(192877,'73827','new_theme','block-192874','checkout\\PaymentMethod','',2),(192878,'73828','new_theme','block-192874','Html_box','',1),(192879,'73829','new_theme','block-192874','CouponsAndVauchers\\Checkout','',5),(192880,'73830','new_theme','checkout_payment_title','Html_box','',1),(192881,'73831','new_theme','checkout_payment_title_g','Html_box','',1),(192882,'73832','new_theme','checkout_payment_title_no_shipping','Html_box','',1),(192883,'73833','new_theme','checkout_payment_title_no_shipping_g','Html_box','',1),(192884,'73834','new_theme','checkout_payment_title_q','Html_box','',1),(192885,'73835','new_theme','checkout_payment_title_s','Html_box','',1),(192886,'73836','new_theme','checkout_q','BlockBox','',1),(192887,'73837','new_theme','block-192886','BlockBox','',2),(192888,'73838','new_theme','block-192887','BlockBox','',2),(192889,'73839','new_theme','block-192888','BlockBox','',6),(192890,'73840','new_theme','block-192889','checkout\\CreateAccount','',3),(192891,'73841','new_theme','block-192889','quote\\Products','',2),(192892,'73842','new_theme','block-192888','BlockBox','',2),(192893,'73843','new_theme','block-192892','BlockBox','',2),(192894,'73844','new_theme','block-192893','checkout\\ShippingChoice','',1),(192895,'73845','new_theme','block-192892','Neighbour\\Checkout','',4),(192896,'73846','new_theme','block-192892','Html_box','',1),(192897,'73847','new_theme','block-192892','BlockBox','',3),(192898,'73848','new_theme','block-192897','BlockBox','',1),(192899,'73849','new_theme','block-192898','checkout\\ContactInformation','',4),(192900,'73850','new_theme','block-192898','checkout\\ShippingAddress','',2),(192901,'73851','new_theme','block-192898','Html_box','',3),(192902,'73852','new_theme','block-192897-2','BlockBox','',1),(192903,'73853','new_theme','block-192902','checkout\\Shipping','',2),(192904,'73854','new_theme','block-192902','Html_box','',1),(192905,'73855','new_theme','block-192902','DelayedDespatch\\Checkout','',3),(192906,'73856','new_theme','block-192888','BlockBox','',5),(192907,'73857','new_theme','block-192906','Html_box','',1),(192908,'73858','new_theme','block-192906','checkout\\Comments','',2),(192909,'73860','new_theme','block-192888','BlockBox','',3),(192910,'73861','new_theme','block-192909','Html_box','',1),(192911,'73862','new_theme','block-192909','BlockBox','',2),(192912,'73863','new_theme','block-192911','checkout\\BillingAddress','',2),(192913,'73864','new_theme','block-192911','Html_box','',1),(192914,'73865','new_theme','block-192911-2','BlockBox','',1),(192915,'73866','new_theme','block-192914','checkout\\PaymentMethod','',2),(192916,'73867','new_theme','block-192914','Html_box','',1),(192917,'73868','new_theme','block-192887-2','BlockBox','',1),(192918,'73869','new_theme','block-192917','Html_box','',1),(192919,'73870','new_theme','block-192917','Html_box','',5),(192920,'73871','new_theme','block-192917','checkout\\Totals','',2),(192921,'73872','new_theme','block-192917','checkout\\ContinueBtn','',3),(192922,'115996','new_theme','block-192917','checkout\\Terms','',4),(192923,'73873','new_theme','checkout_s','BlockBox','',1),(192924,'73874','new_theme','block-192923','BlockBox','',2),(192925,'73875','new_theme','block-192924','BlockBox','',2),(192926,'73876','new_theme','block-192925','checkout\\Gdpr','',1),(192927,'73877','new_theme','block-192925','BlockBox','',6),(192928,'73878','new_theme','block-192927','sample\\Products','',1),(192929,'73879','new_theme','block-192927','checkout\\CreateAccount','',3),(192930,'73880','new_theme','block-192925','BlockBox','',2),(192931,'73881','new_theme','block-192930','Html_box','',1),(192932,'73882','new_theme','block-192930','Neighbour\\Checkout','',4),(192933,'73883','new_theme','block-192930','BlockBox','',2),(192934,'73884','new_theme','block-192933','checkout\\ShippingChoice','',1),(192935,'73885','new_theme','block-192930','BlockBox','',3),(192936,'73886','new_theme','block-192935','BlockBox','',1),(192937,'73887','new_theme','block-192936','checkout\\ShippingAddress','',2),(192938,'73888','new_theme','block-192936','checkout\\ContactInformation','',4),(192939,'73889','new_theme','block-192936','Html_box','',3),(192940,'73890','new_theme','block-192935-2','BlockBox','',1),(192941,'73891','new_theme','block-192940','checkout\\Shipping','',2),(192942,'73892','new_theme','block-192940','DelayedDespatch\\Checkout','',3),(192943,'73893','new_theme','block-192940','Html_box','',1),(192944,'73894','new_theme','block-192925','BlockBox','',3),(192945,'73895','new_theme','block-192944','BlockBox','',2),(192946,'73896','new_theme','block-192945','Html_box','',1),(192947,'73897','new_theme','block-192945','checkout\\BillingAddress','',2),(192948,'73898','new_theme','block-192945-2','BlockBox','',1),(192949,'73899','new_theme','block-192948','Html_box','',1),(192950,'73900','new_theme','block-192948','checkout\\PaymentMethod','',2),(192951,'73901','new_theme','block-192944','Html_box','',1),(192952,'73902','new_theme','block-192925','BlockBox','',5),(192953,'73903','new_theme','block-192952','Html_box','',1),(192954,'73904','new_theme','block-192952','checkout\\Comments','',2),(192955,'73905','new_theme','block-192925','BlockBox','',4),(192956,'73906','new_theme','block-192955','BlockBox','',2),(192957,'73907','new_theme','block-192956','CouponsAndVauchers\\Checkout','',1),(192958,'73908','new_theme','block-192956-2','BonusActions\\widgets\\BonusPointsCheckout','',2),(192959,'73909','new_theme','block-192956-2','checkout\\CreditAmount','',1),(192960,'73910','new_theme','block-192955','Html_box','',1),(192961,'73911','new_theme','block-192924-2','BlockBox','',1),(192962,'73912','new_theme','block-192961','checkout\\Totals','',2),(192963,'73913','new_theme','block-192961','Html_box','',5),(192964,'73914','new_theme','block-192961','Html_box','',1),(192965,'73915','new_theme','block-192961','checkout\\ContinueBtn','',3),(192966,'115998','new_theme','block-192961','checkout\\Terms','',4),(192967,'73916','new_theme','checkout_step_bottom','Html_box','',1),(192968,'73917','new_theme','checkout_step_bottom','cart\\Products','',2),(192969,'73918','new_theme','checkout_step_bottom','checkout\\Totals','',3),(192970,'73919','new_theme','checkout_step_bottom_g','checkout\\Totals','',3),(192971,'73920','new_theme','checkout_step_bottom_g','quote\\Products','',2),(192972,'73921','new_theme','checkout_step_bottom_g','Html_box','',1),(192973,'73923','new_theme','checkout_step_bottom_no_shipping','Html_box','',1),(192974,'73924','new_theme','checkout_step_bottom_no_shipping','checkout\\Totals','',3),(192975,'73927','new_theme','checkout_step_bottom_no_shipping','cart\\Products','',2),(192976,'73922','new_theme','checkout_step_bottom_no_shipping_g','Html_box','',1),(192977,'73925','new_theme','checkout_step_bottom_no_shipping_g','checkout\\Totals','',3),(192978,'73926','new_theme','checkout_step_bottom_no_shipping_g','quote\\Products','',2),(192979,'73928','new_theme','communication','BlockBox','',1),(192980,'73929','new_theme','block-192979','Html_box','',2),(192981,'73930','new_theme','block-192979','Communication\\NewTopicButton','',1),(192982,'73931','new_theme','block-192979','Communication\\Topic','',3),(192983,'94704','new_theme','compare','BlockBox','',1),(192984,'94705','new_theme','block-192983','catalog\\Compare','',1),(192985,'94706','new_theme','compare_products','BlockBox','',2),(192986,'94707','new_theme','block-192985','productListing\\rating','',4),(192987,'94708','new_theme','block-192985','productListing\\model','',5),(192988,'94709','new_theme','block-192985','productListing\\compare','',1),(192989,'94710','new_theme','block-192985','BlockBox','',2),(192990,'94711','new_theme','block-192989','productListing\\image','',1),(192991,'94712','new_theme','block-192989-2','productListing\\name','',2),(192992,'94713','new_theme','block-192985','BlockBox','',3),(192993,'94714','new_theme','block-192992','productListing\\price','',1),(192994,'94715','new_theme','block-192992-2','productListing\\buyButton','',1),(192995,'73932','new_theme','confirmation','BlockBox','',1),(192996,'73933','new_theme','block-192995','BlockBox','',2),(192997,'73934','new_theme','block-192996','BlockBox','',2),(192998,'73935','new_theme','block-192997','BlockBox','',3),(192999,'73936','new_theme','block-192998','checkout\\EditBtn','',2),(193000,'73937','new_theme','block-192998','cart\\Products','',3),(193001,'73938','new_theme','block-192998','Html_box','',1),(193002,'73939','new_theme','block-192997','BlockBox','',2),(193003,'73940','new_theme','block-193002','checkout\\EditBtn','',2),(193004,'73941','new_theme','block-193002','Html_box','',1),(193005,'73942','new_theme','block-193002','checkout\\CommentsConfirm','',3),(193006,'73943','new_theme','block-192997','BlockBox','',1),(193007,'73944','new_theme','block-193006','BlockBox','',1),(193008,'73945','new_theme','block-193007','checkout\\EditBtn','',6),(193009,'73946','new_theme','block-193007','DelayedDespatch\\CheckoutConfirm','',8),(193010,'73947','new_theme','block-193007','Html_box','',9),(193011,'73948','new_theme','block-193007','checkout\\EditBtn','',10),(193012,'73949','new_theme','block-193007','Html_box','',5),(193013,'73950','new_theme','block-193007','checkout\\ShippingConfirm','',7),(193014,'73951','new_theme','block-193007','Html_box','',1),(193015,'73952','new_theme','block-193007','checkout\\EditBtn','',3),(193016,'73953','new_theme','block-193007','checkout\\ContactConfirm','',11),(193017,'73954','new_theme','block-193007','Html_box','',2),(193018,'73955','new_theme','block-193007','checkout\\ShippingAddressConfirm','',4),(193019,'73956','new_theme','block-193006-2','BlockBox','',1),(193020,'73957','new_theme','block-193019','checkout\\EditBtn','',6),(193021,'73958','new_theme','block-193019','checkout\\EditBtn','',3),(193022,'73959','new_theme','block-193019','checkout\\PaymentMethodConfirm','',7),(193023,'73960','new_theme','block-193019','Html_box','',5),(193024,'73961','new_theme','block-193019','Html_box','',1),(193025,'73962','new_theme','block-193019','checkout\\BillingAddressConfirm','',4),(193026,'73963','new_theme','block-193019','Html_box','',2),(193027,'73964','new_theme','block-192996','UploadCustomerId\\UploadCustomerIdForm','',1),(193028,'73965','new_theme','block-192996-2','BlockBox','',1),(193029,'73966','new_theme','block-193028','Html_box','',1),(193030,'73967','new_theme','block-193028','checkout\\ConfirmBtn','',3),(193031,'73968','new_theme','block-193028','checkout\\Totals','',2),(193032,'73969','new_theme','block-192995','Html_box','',1),(193033,'73970','new_theme','confirmation_free_s','BlockBox','',1),(193034,'73971','new_theme','block-193033','BlockBox','',2),(193035,'73972','new_theme','block-193034','BlockBox','',1),(193036,'73973','new_theme','block-193035','BlockBox','',2),(193037,'73974','new_theme','block-193036','checkout\\CommentsConfirm','',3),(193038,'73975','new_theme','block-193036','checkout\\EditBtn','',2),(193039,'73976','new_theme','block-193036','Html_box','',1),(193040,'73977','new_theme','block-193035','BlockBox','',3),(193041,'73978','new_theme','block-193040','checkout\\EditBtn','',3),(193042,'73979','new_theme','block-193040','Html_box','',1),(193043,'73980','new_theme','block-193040','sample\\Products','',2),(193044,'73981','new_theme','block-193035','BlockBox','',1),(193045,'73982','new_theme','block-193044','BlockBox','',1),(193046,'73983','new_theme','block-193045','checkout\\EditBtn','',3),(193047,'73984','new_theme','block-193045','checkout\\ShippingConfirm','',7),(193048,'73985','new_theme','block-193045','Html_box','',5),(193049,'73986','new_theme','block-193045','checkout\\EditBtn','',6),(193050,'73987','new_theme','block-193045','Html_box','',2),(193051,'73988','new_theme','block-193045','checkout\\ShippingAddressConfirm','',4),(193052,'73989','new_theme','block-193044-2','BlockBox','',1),(193053,'73990','new_theme','block-193052','checkout\\ContactConfirm','',3),(193054,'73991','new_theme','block-193052','DelayedDespatch\\CheckoutConfirm','',4),(193055,'73992','new_theme','block-193052','checkout\\EditBtn','',2),(193056,'73993','new_theme','block-193052','Html_box','',1),(193057,'73994','new_theme','block-193034-2','BlockBox','',1),(193058,'73995','new_theme','block-193057','checkout\\ConfirmBtn','',3),(193059,'73996','new_theme','block-193033','Html_box','',1),(193060,'73997','new_theme','confirmation_no_shipping','BlockBox','',1),(193061,'73998','new_theme','block-193060','Html_box','',1),(193062,'73999','new_theme','block-193060','BlockBox','',2),(193063,'74000','new_theme','block-193062','BlockBox','',1),(193064,'74001','new_theme','block-193063','BlockBox','',1),(193065,'74002','new_theme','block-193064','BlockBox','',1),(193066,'74003','new_theme','block-193065','checkout\\EditBtn','',10),(193067,'74004','new_theme','block-193065','Html_box','',9),(193068,'74005','new_theme','block-193065','checkout\\ContactConfirm','',11),(193069,'74006','new_theme','block-193064-2','BlockBox','',1),(193070,'74007','new_theme','block-193069','checkout\\PaymentMethodConfirm','',7),(193071,'74008','new_theme','block-193069','checkout\\EditBtn','',6),(193072,'74009','new_theme','block-193069','Html_box','',5),(193073,'74010','new_theme','block-193069','Html_box','',1),(193074,'74011','new_theme','block-193069','checkout\\EditBtn','',3),(193075,'74012','new_theme','block-193069','checkout\\BillingAddressConfirm','',4),(193076,'74013','new_theme','block-193069','Html_box','',2),(193077,'74014','new_theme','block-193063','BlockBox','',2),(193078,'74015','new_theme','block-193077','Html_box','',1),(193079,'74016','new_theme','block-193077','checkout\\CommentsConfirm','',3),(193080,'74017','new_theme','block-193077','checkout\\EditBtn','',2),(193081,'74018','new_theme','block-193063','BlockBox','',3),(193082,'74019','new_theme','block-193081','Html_box','',1),(193083,'74020','new_theme','block-193081','checkout\\EditBtn','',2),(193084,'74021','new_theme','block-193081','cart\\Products','',3),(193085,'74022','new_theme','block-193062-2','BlockBox','',1),(193086,'74023','new_theme','block-193085','checkout\\ConfirmBtn','',3),(193087,'74024','new_theme','block-193085','Html_box','',1),(193088,'74025','new_theme','block-193085','checkout\\Totals','',2),(193089,'74026','new_theme','confirmation_no_shipping_q','BlockBox','',2),(193090,'74027','new_theme','block-193089','Html_box','',1),(193091,'74028','new_theme','block-193089','BlockBox','',2),(193092,'74029','new_theme','block-193091','BlockBox','',1),(193093,'74030','new_theme','block-193092','BlockBox','',2),(193094,'74031','new_theme','block-193093','Html_box','',1),(193095,'74032','new_theme','block-193093','checkout\\CommentsConfirm','',3),(193096,'74033','new_theme','block-193093','checkout\\EditBtn','',2),(193097,'74034','new_theme','block-193092','BlockBox','',1),(193098,'74035','new_theme','block-193097','BlockBox','',1),(193099,'74036','new_theme','block-193098','checkout\\EditBtn','',5),(193100,'74037','new_theme','block-193098','checkout\\ContactConfirm','',6),(193101,'74038','new_theme','block-193098','checkout\\PaymentMethodConfirm','',3),(193102,'74039','new_theme','block-193098','checkout\\EditBtn','',2),(193103,'74040','new_theme','block-193098','Html_box','',4),(193104,'74041','new_theme','block-193098','Html_box','',1),(193105,'74042','new_theme','block-193097-2','BlockBox','',1),(193106,'74043','new_theme','block-193105','checkout\\BillingAddressConfirm','',4),(193107,'74044','new_theme','block-193105','checkout\\EditBtn','',3),(193108,'74045','new_theme','block-193105','Html_box','',2),(193109,'74046','new_theme','block-193092','BlockBox','',3),(193110,'74047','new_theme','block-193109','checkout\\EditBtn','',2),(193111,'74048','new_theme','block-193109','Html_box','',1),(193112,'74049','new_theme','block-193109','quote\\Products','',3),(193113,'74050','new_theme','block-193091-2','BlockBox','',1),(193114,'74051','new_theme','block-193113','checkout\\ConfirmBtn','',3),(193115,'74052','new_theme','block-193113','checkout\\Totals','',2),(193116,'74053','new_theme','block-193113','Html_box','',1),(193117,'74054','new_theme','confirmation_q','BlockBox','',1),(193118,'74055','new_theme','block-193117','Html_box','',1),(193119,'74056','new_theme','block-193117','BlockBox','',2),(193120,'74057','new_theme','block-193119','BlockBox','',1),(193121,'74058','new_theme','block-193120','BlockBox','',3),(193122,'74059','new_theme','block-193121','quote\\Products','',3),(193123,'74060','new_theme','block-193121','Html_box','',1),(193124,'74061','new_theme','block-193121','checkout\\EditBtn','',2),(193125,'74062','new_theme','block-193120','BlockBox','',1),(193126,'74063','new_theme','block-193125','BlockBox','',1),(193127,'74064','new_theme','block-193126','Html_box','',1),(193128,'74065','new_theme','block-193126','checkout\\EditBtn','',10),(193129,'74066','new_theme','block-193126','Html_box','',2),(193130,'74067','new_theme','block-193126','checkout\\ContactConfirm','',11),(193131,'74068','new_theme','block-193126','checkout\\ShippingAddressConfirm','',4),(193132,'74069','new_theme','block-193126','checkout\\ShippingConfirm','',7),(193133,'74070','new_theme','block-193126','checkout\\EditBtn','',3),(193134,'74071','new_theme','block-193126','DelayedDespatch\\CheckoutConfirm','',8),(193135,'74072','new_theme','block-193126','Html_box','',9),(193136,'74073','new_theme','block-193126','Html_box','',5),(193137,'74074','new_theme','block-193126','checkout\\EditBtn','',6),(193138,'74075','new_theme','block-193125-2','BlockBox','',1),(193139,'74076','new_theme','block-193138','checkout\\EditBtn','',3),(193140,'74077','new_theme','block-193138','checkout\\BillingAddressConfirm','',4),(193141,'74078','new_theme','block-193138','checkout\\PaymentMethodConfirm','',7),(193142,'74079','new_theme','block-193138','Html_box','',1),(193143,'74080','new_theme','block-193138','Html_box','',2),(193144,'74081','new_theme','block-193138','checkout\\EditBtn','',6),(193145,'74082','new_theme','block-193138','Html_box','',5),(193146,'74083','new_theme','block-193120','BlockBox','',2),(193147,'74084','new_theme','block-193146','checkout\\CommentsConfirm','',3),(193148,'74085','new_theme','block-193146','Html_box','',1),(193149,'74086','new_theme','block-193146','checkout\\EditBtn','',2),(193150,'74087','new_theme','block-193119-2','BlockBox','',1),(193151,'74088','new_theme','block-193150','Html_box','',1),(193152,'74089','new_theme','block-193150','checkout\\Totals','',2),(193153,'74090','new_theme','block-193150','checkout\\ConfirmBtn','',3),(193154,'74091','new_theme','confirmation_s','BlockBox','',1),(193155,'74092','new_theme','block-193154','BlockBox','',2),(193156,'74093','new_theme','block-193155','BlockBox','',1),(193157,'74094','new_theme','block-193156','BlockBox','',1),(193158,'74095','new_theme','block-193157','BlockBox','',1),(193159,'74096','new_theme','block-193158','checkout\\ShippingAddressConfirm','',4),(193160,'74097','new_theme','block-193158','checkout\\EditBtn','',3),(193161,'74098','new_theme','block-193158','Html_box','',2),(193162,'74099','new_theme','block-193158','DelayedDespatch\\CheckoutConfirm','',8),(193163,'74100','new_theme','block-193158','checkout\\ShippingConfirm','',7),(193164,'74101','new_theme','block-193158','Html_box','',1),(193165,'74102','new_theme','block-193158','Html_box','',5),(193166,'74103','new_theme','block-193158','Html_box','',9),(193167,'74104','new_theme','block-193158','checkout\\ContactConfirm','',11),(193168,'74105','new_theme','block-193158','checkout\\EditBtn','',6),(193169,'74106','new_theme','block-193158','checkout\\EditBtn','',10),(193170,'74107','new_theme','block-193157-2','BlockBox','',1),(193171,'74108','new_theme','block-193170','Html_box','',2),(193172,'74109','new_theme','block-193170','checkout\\BillingAddressConfirm','',4),(193173,'74110','new_theme','block-193170','checkout\\EditBtn','',3),(193174,'74111','new_theme','block-193170','checkout\\PaymentMethodConfirm','',7),(193175,'74112','new_theme','block-193170','checkout\\EditBtn','',6),(193176,'74113','new_theme','block-193170','Html_box','',1),(193177,'74114','new_theme','block-193170','Html_box','',5),(193178,'74115','new_theme','block-193156','BlockBox','',3),(193179,'74116','new_theme','block-193178','checkout\\EditBtn','',3),(193180,'74117','new_theme','block-193178','Html_box','',1),(193181,'74118','new_theme','block-193178','sample\\Products','',2),(193182,'74119','new_theme','block-193156','BlockBox','',2),(193183,'74120','new_theme','block-193182','Html_box','',1),(193184,'74121','new_theme','block-193182','checkout\\EditBtn','',2),(193185,'74122','new_theme','block-193182','checkout\\CommentsConfirm','',3),(193186,'74123','new_theme','block-193155-2','BlockBox','',1),(193187,'74124','new_theme','block-193186','checkout\\Totals','',2),(193188,'74125','new_theme','block-193186','checkout\\ConfirmBtn','',3),(193189,'74126','new_theme','block-193186','Html_box','',1),(193190,'74127','new_theme','block-193154','Html_box','',1),(193191,'74128','new_theme','contact','BlockBox','',1),(193192,'74132','new_theme','block-193191','info\\Title','',1),(193193,'74133','new_theme','block-193191','BlockBox','',3),(193194,'74134','new_theme','block-193193','contact\\ContactForm','',1),(193195,'74135','new_theme','block-193193-2','contact\\Contacts','',1),(193196,'74136','new_theme','created_success','BlockBox','',1),(193197,'74137','new_theme','block-193196','Html_box','',1),(193198,'74138','new_theme','block-193196','Html_box','',2),(193199,'74139','new_theme','credit_note','invoice\\Container','',1),(193200,'74140','new_theme','block-193199','BlockBox','',5),(193201,'74141','new_theme','block-193200','invoice\\StoreAddress','',8),(193202,'74142','new_theme','block-193200','Text','',1),(193203,'74143','new_theme','block-193200-2','Text','',2),(193204,'74144','new_theme','block-193200-2','Logo','',1),(193205,'74145','new_theme','block-193200-3','Text','',1),(193206,'74146','new_theme','block-193200-3','BlockBox','',3),(193207,'74147','new_theme','block-193206','Text','',1),(193208,'74148','new_theme','block-193206-2','invoice\\StoreEmail','',1),(193209,'74149','new_theme','block-193200-3','BlockBox','',2),(193210,'74150','new_theme','block-193209','Text','',1),(193211,'74151','new_theme','block-193209-2','invoice\\StorePhone','',1),(193212,'74152','new_theme','block-193199','invoice\\Products','',3),(193213,'74153','new_theme','block-193199','BlockBox','',1),(193214,'74154','new_theme','block-193213','Logo','',1),(193215,'74155','new_theme','block-193213-2','BlockBox','',4),(193216,'74156','new_theme','block-193215','Text','',1),(193217,'74157','new_theme','block-193215-2','invoice\\StoreSite','',1),(193218,'74158','new_theme','block-193213-2','BlockBox','',2),(193219,'74159','new_theme','block-193218','Text','',1),(193220,'74160','new_theme','block-193218-2','invoice\\StorePhone','',1),(193221,'74161','new_theme','block-193213-2','BlockBox','',3),(193222,'74162','new_theme','block-193221','Text','',1),(193223,'74163','new_theme','block-193221-2','invoice\\StoreEmail','',1),(193224,'74164','new_theme','block-193213-2','BlockBox','',1),(193225,'74165','new_theme','block-193224','invoice\\StoreAddress','',1),(193226,'74166','new_theme','block-193199','BlockBox','',4),(193227,'74167','new_theme','block-193226','BlockBox','',1),(193228,'74168','new_theme','block-193227','invoice\\ShippingAddress','',2),(193229,'74169','new_theme','block-193227','Text','',1),(193230,'74170','new_theme','block-193226-2','BlockBox','',1),(193231,'74171','new_theme','block-193199','BlockBox','',2),(193232,'74172','new_theme','block-193231','BlockBox','',7),(193233,'74173','new_theme','block-193232','BlockBox','',1),(193234,'74174','new_theme','block-193233','Text','',1),(193235,'74175','new_theme','block-193233','invoice\\BillingAddress','',2),(193236,'74176','new_theme','block-193232-2','BlockBox','',1),(193237,'74177','new_theme','block-193236','invoice\\CustomerPhone','',4),(193238,'74178','new_theme','block-193236','Text','',1),(193239,'74179','new_theme','block-193236','Text','',3),(193240,'74180','new_theme','block-193236','invoice\\CustomerName','',2),(193241,'74181','new_theme','block-193236','invoice\\CustomerEmail','',6),(193242,'74182','new_theme','block-193236','Text','',5),(193243,'74183','new_theme','block-193231','BlockBox','',8),(193244,'74184','new_theme','block-193243','BlockBox','',1),(193245,'74185','new_theme','block-193244','invoice\\ShippingMethod','',2),(193246,'74186','new_theme','block-193244','Text','',1),(193247,'74187','new_theme','block-193243-2','BlockBox','',1),(193248,'74188','new_theme','block-193247','Text','',1),(193249,'74189','new_theme','block-193247','invoice\\ShippingMethod','',2),(193250,'74190','new_theme','block-193231-2','invoice\\OrderId','',1),(193251,'74191','new_theme','block-193231-2','Text','',2),(193252,'74192','new_theme','block-193231-2','invoice\\PaymentDate','',3),(193253,'74193','new_theme','delivery-location','DeliveryLocation\\FeaturedList','',6),(193254,'74194','new_theme','delivery-location','DeliveryLocation\\LocationLongDescription','',5),(193255,'74195','new_theme','delivery-location','DeliveryLocation\\LocationList','',7),(193256,'74196','new_theme','delivery-location','DeliveryLocation\\LocationTitle','',2),(193257,'74197','new_theme','delivery-location','DeliveryLocation\\LocationProducts','',8),(193258,'74198','new_theme','delivery-location','DeliveryLocation\\LocationDescription','',3),(193259,'74199','new_theme','delivery-location','DeliveryLocation\\LocationHeadlineImage','',1),(193260,'74200','new_theme','delivery-location-default','DeliveryLocation\\TopLocationList','',2),(193261,'74201','new_theme','delivery-location-default','Heading','',1),(193262,'94716','new_theme','delivery_loc_2','DeliveryLocation\\FeaturedList','',6),(193263,'94717','new_theme','delivery_loc_2','DeliveryLocation\\LocationDescription','',3),(193264,'94718','new_theme','delivery_loc_2','DeliveryLocation\\LocationHeadlineImage','',1),(193265,'94719','new_theme','delivery_loc_2','DeliveryLocation\\LocationTitle','',2),(193266,'94720','new_theme','delivery_loc_2','DeliveryLocation\\LocationProducts','',8),(193267,'94721','new_theme','delivery_loc_2','DeliveryLocation\\LocationList','',7),(193268,'94722','new_theme','delivery_loc_2','DeliveryLocation\\LocationLongDescription','',5),(193269,'74202','new_theme','email','email\\BlockBox','',1),(193270,'74203','new_theme','block-193269','email\\BlockBox','',1),(193271,'74204','new_theme','block-193270','Copyright','',4),(193272,'74205','new_theme','block-193270','email\\Content','',3),(193273,'74206','new_theme','block-193270','email\\BlockBox','',2),(193274,'74207','new_theme','block-193273','email\\Title','',1),(193275,'74208','new_theme','block-193273-2','email\\Date','',1),(193276,'74209','new_theme','block-193270','Logo','',1),(193277,'74210','new_theme','email_2','email\\BlockBox','',1),(193278,'74211','new_theme','block-193277','email\\BlockBox','',1),(193279,'74212','new_theme','block-193278','Copyright','',4),(193280,'74213','new_theme','block-193278','Logo','',1),(193281,'74214','new_theme','block-193278','email\\Content','',3),(193282,'74215','new_theme','block-193278','email\\BlockBox','',2),(193283,'74216','new_theme','block-193282','email\\Title','',1),(193284,'74217','new_theme','block-193282-2','email\\Date','',1),(193285,'74218','new_theme','email_3','email\\BlockBox','',1),(193286,'74219','new_theme','block-193285','email\\BlockBox','',1),(193287,'74220','new_theme','block-193286','email\\BlockBox','',2),(193288,'74221','new_theme','block-193287','email\\Content','',2),(193289,'74222','new_theme','block-193287','email\\BlockBox','',1),(193290,'74223','new_theme','block-193289','email\\Title','',1),(193291,'74224','new_theme','block-193289-2','email\\Date','',1),(193292,'74225','new_theme','block-193286','Copyright','',3),(193293,'74226','new_theme','block-193286','Logo','',1),(193294,'74227','new_theme','email_4','email\\BlockBox','',1),(193295,'74228','new_theme','block-193294','email\\BlockBox','',1),(193296,'74229','new_theme','block-193295','Copyright','',2),(193297,'74230','new_theme','block-193295','email\\BlockBox','',1),(193298,'74231','new_theme','block-193297','email\\BlockBox','',1),(193299,'74232','new_theme','block-193298','Logo','',1),(193300,'74233','new_theme','block-193298-2','email\\Date','',2),(193301,'74234','new_theme','block-193298-2','email\\Title','',1),(193302,'74235','new_theme','block-193297','email\\Content','',2),(193303,'74236','new_theme','footer','BlockBox','',1),(193304,'74237','new_theme','block-193303','BlockBox','',1),(193305,'74238','new_theme','block-193304','BlockBox','',1),(193306,'74239','new_theme','block-193305','Menu','footer3',3),(193307,'1695906739.5696','new_theme','block-193305','Html_box','',2),(193308,'74241','new_theme','block-193304-2','BlockBox','',1),(193309,'74243','new_theme','block-193308','Menu','footer1',3),(193310,'1695906751.0591','new_theme','block-193308','Html_box','',2),(193311,'74244','new_theme','block-193304-3','BlockBox','',1),(193312,'74246','new_theme','block-193311','Menu','footer2',3),(193313,'1695906756.0887','new_theme','block-193311','Html_box','',2),(193314,'74247','new_theme','block-193304-4','BlockBox','',1),(193315,'74248','new_theme','block-193314','Contacts','',4),(193316,'74249','new_theme','block-193314','Contacts','',3),(193317,'1695906761.6568','new_theme','block-193314','Html_box','',2),(193318,'74256','new_theme','block-193303','BlockBox','footer-content',4),(193319,'74257','new_theme','block-193318','Copyright','',1),(193320,'74258','new_theme','block-193318-2','invoice\\StoreAddress','',1),(193321,'94723','new_theme','for_menu','BlockBox','',1),(193322,'94724','new_theme','block-193321','Html_box','',1),(193323,'94725','new_theme','block-193321-2','Languages','',1),(193324,'94726','new_theme','for_menu','BlockBox','',3),(193325,'94727','new_theme','block-193324','Html_box','',1),(193326,'94728','new_theme','block-193324-2','Currencies','',1),(193327,'74263','new_theme','gift','BlockBox','',1),(193328,'74264','new_theme','block-193327','BlockBox','',3),(193329,'74265','new_theme','block-193328','BlockBox','',1),(193330,'74266','new_theme','block-193329','gift\\Card','',1),(193331,'74267','new_theme','block-193328-2','gift\\Form','',2),(193332,'74268','new_theme','block-193328-2','Text','',1),(193333,'74269','new_theme','block-193327','info\\Title','',1),(193334,'74270','new_theme','gift_card','BlockBox','',1),(193335,'74271','new_theme','block-193334','BlockBox','',11),(193336,'74272','new_theme','block-193335','invoice\\StoreEmail','',3),(193337,'74273','new_theme','block-193335','Text','',1),(193338,'74274','new_theme','block-193335','invoice\\StorePhone','',2),(193339,'74275','new_theme','block-193334','Text','',8),(193340,'74276','new_theme','block-193334','Text','',3),(193341,'74277','new_theme','block-193334','BlockBox','',10),(193342,'74278','new_theme','block-193341','Text','',1),(193343,'74279','new_theme','block-193341-2','gift\\CodeView','',1),(193344,'74280','new_theme','block-193334','gift\\MessageView','',7),(193345,'74281','new_theme','block-193334','gift\\AmountView','',5),(193346,'74282','new_theme','block-193334','Text','',6),(193347,'74284','new_theme','block-193334','Logo','',1),(193348,'74285','new_theme','block-193334','Text','',4),(193349,'74286','new_theme','block-193334','Text','',9),(193350,'74287','new_theme','gift_card_2','BlockBox','',1),(193351,'74288','new_theme','block-193350','gift\\AmountView','',3),(193352,'74289','new_theme','block-193350','BlockBox','',8),(193353,'74290','new_theme','block-193352','Text','',1),(193354,'74291','new_theme','block-193352-2','gift\\CodeView','',1),(193355,'74292','new_theme','block-193350','BlockBox','',9),(193356,'74293','new_theme','block-193355','invoice\\StoreEmail','',3),(193357,'74294','new_theme','block-193355','Text','',1),(193358,'74295','new_theme','block-193355','invoice\\StorePhone','',2),(193359,'74296','new_theme','block-193350','gift\\MessageView','',5),(193360,'74297','new_theme','block-193350','Text','',4),(193361,'74298','new_theme','block-193350','Text','',7),(193362,'74299','new_theme','block-193350','Text','',2),(193363,'74300','new_theme','block-193350','Text','',6),(193364,'74301','new_theme','block-193350','Text','',1),(193365,'94729','new_theme','gift_card_2_pdf','BlockBox','',1),(193366,'94730','new_theme','block-193365','BlockBox','',12),(193367,'94731','new_theme','block-193366','invoice\\StoreEmail','',4),(193368,'94732','new_theme','block-193366','invoice\\StorePhone','',3),(193369,'94733','new_theme','block-193366','Html_box','',1),(193370,'94734','new_theme','block-193365','BlockBox','',11),(193371,'94735','new_theme','block-193370','Html_box','',1),(193372,'94736','new_theme','block-193370-2','gift\\CodeViewPdf','',1),(193373,'94737','new_theme','block-193365','BlockBox','',1),(193374,'94738','new_theme','block-193373','Text','',4),(193375,'94739','new_theme','block-193373','Html_box','',1),(193376,'94740','new_theme','block-193373','Html_box','',2),(193377,'94741','new_theme','block-193373','gift\\AmountViewPdf','',3),(193378,'94742','new_theme','block-193373','gift\\MessageViewPdf','',5),(193379,'94743','new_theme','block-193373','Html_box','',7),(193380,'94744','new_theme','block-193373','Html_box','',6),(193381,'94746','new_theme','gift_card_pdf','BlockBox','',1),(193382,'94747','new_theme','block-193381','BlockBox','',12),(193383,'94748','new_theme','block-193382','invoice\\StoreEmail','',4),(193384,'94749','new_theme','block-193382','invoice\\StorePhone','',3),(193385,'94750','new_theme','block-193382','Html_box','',1),(193386,'94751','new_theme','block-193381','BlockBox','',11),(193387,'94752','new_theme','block-193386','Html_box','',1),(193388,'94753','new_theme','block-193386-2','gift\\CodeViewPdf','',1),(193389,'94754','new_theme','block-193381','BlockBox','',1),(193390,'94755','new_theme','block-193389','Text','',5),(193391,'94757','new_theme','block-193389','Html_box','',3),(193392,'94758','new_theme','block-193389','gift\\AmountViewPdf','',4),(193393,'94759','new_theme','block-193389','gift\\MessageViewPdf','',6),(193394,'94760','new_theme','block-193389','Html_box','',8),(193395,'94761','new_theme','block-193389','Html_box','',7),(193396,'1707902674.2595','new_theme','block-193389','Logo','',2),(193397,'94762','new_theme','gift_card_pdf','Import','',1),(193398,'74302','new_theme','gift_certificate','BlockBox','',1),(193399,'74303','new_theme','block-193398','account\\ApplyCertificate','',2),(193400,'74304','new_theme','block-193398','Html_box','',1),(193401,'74305','new_theme','gigt_card_3','BlockBox','',1),(193402,'74306','new_theme','block-193401','BlockBox','',8),(193403,'74307','new_theme','block-193402','Text','',1),(193404,'74308','new_theme','block-193402-2','gift\\CodeView','',1),(193405,'74309','new_theme','block-193401','Text','',6),(193406,'74310','new_theme','block-193401','Text','',1),(193407,'74311','new_theme','block-193401','BlockBox','',9),(193408,'74312','new_theme','block-193407','Text','',1),(193409,'74313','new_theme','block-193407','invoice\\StoreEmail','',3),(193410,'74314','new_theme','block-193407','invoice\\StorePhone','',2),(193411,'74315','new_theme','block-193401','gift\\MessageView','',5),(193412,'74316','new_theme','block-193401','Text','',2),(193413,'74317','new_theme','block-193401','Text','',4),(193414,'74318','new_theme','block-193401','gift\\AmountView','',3),(193415,'74319','new_theme','block-193401','Text','',7),(193416,'94763','new_theme','gigt_card_3_pdf','BlockBox','',1),(193417,'94764','new_theme','block-193416','BlockBox','',12),(193418,'94765','new_theme','block-193417','invoice\\StoreEmail','',4),(193419,'94766','new_theme','block-193417','invoice\\StorePhone','',3),(193420,'94767','new_theme','block-193417','Html_box','',1),(193421,'94768','new_theme','block-193416','BlockBox','',11),(193422,'94769','new_theme','block-193421','Html_box','',1),(193423,'94770','new_theme','block-193421-2','gift\\CodeViewPdf','',1),(193424,'94771','new_theme','block-193416','BlockBox','',1),(193425,'94772','new_theme','block-193424','Text','',4),(193426,'94773','new_theme','block-193424','Html_box','',1),(193427,'94774','new_theme','block-193424','Html_box','',2),(193428,'94775','new_theme','block-193424','gift\\AmountViewPdf','',3),(193429,'94776','new_theme','block-193424','gift\\MessageViewPdf','',5),(193430,'94777','new_theme','block-193424','Html_box','',7),(193431,'94778','new_theme','block-193424','Html_box','',6),(193432,'1713770938.449798','new_theme','header','CookieNotice','',1),(193433,'1713770938.464587','new_theme','header','BlockBox','header-content-small',2),(193434,'1713770938.467593','new_theme','block-193433','BlockBox','header-content-small-left',1),(193435,'1713770938.470248','new_theme','block-193434','Menu','Header menu',1),(193436,'1713770938.51635','new_theme','block-193434-2','BlockBox','header-content-small-right',5),(193437,'1713770938.51828','new_theme','block-193436','Cart','',1),(193438,'1713770938.573998','new_theme','block-193436','Account','',2),(193439,'1713770938.61982','new_theme','block-193436','Currencies','',4),(193440,'1713770938.663457','new_theme','block-193436','Languages','',3),(193441,'1713770938.697915','new_theme','header','BlockBox','header-content',3),(193442,'1713770938.706821','new_theme','block-193441','Logo','',1),(193443,'1713770938.709156','new_theme','block-193441','Search','',2),(193444,'1713770938.773998','new_theme','block-193441','Text','',3),(193445,'1713770938.811953','new_theme','header','BlockBox','header-menu',4),(193446,'1713770938.81834','new_theme','block-193445','Menu','Categories',1),(193447,'74346','new_theme','info','BlockBox','info-content',1),(193448,'74347','new_theme','block-193447','info\\DescriptionShort','',2),(193449,'74348','new_theme','block-193447','info\\Content','',4),(193450,'74349','new_theme','block-193447','info\\Title','',1),(193451,'74350','new_theme','block-193447','info\\Image','',3),(193452,'74351','new_theme','invoice','invoice\\Container','',1),(193453,'74352','new_theme','block-193452','BlockBox','',3),(193454,'74353','new_theme','block-193453','BlockBox','',8),(193455,'74354','new_theme','block-193454','BlockBox','',1),(193456,'74355','new_theme','block-193455','invoice\\ShippingMethod','',2),(193457,'74356','new_theme','block-193455','Text','',1),(193458,'74357','new_theme','block-193454-2','BlockBox','',1),(193459,'74358','new_theme','block-193458','Text','',1),(193460,'74359','new_theme','block-193458','invoice\\ShippingMethod','',2),(193461,'74360','new_theme','block-193453','BlockBox','',7),(193462,'74361','new_theme','block-193461','BlockBox','',1),(193463,'74362','new_theme','block-193462','Text','',1),(193464,'74363','new_theme','block-193462','invoice\\BillingAddress','',2),(193465,'74364','new_theme','block-193461-2','BlockBox','',1),(193466,'74365','new_theme','block-193465','Text','',5),(193467,'74366','new_theme','block-193465','invoice\\CustomerName','',2),(193468,'74367','new_theme','block-193465','invoice\\CustomerPhone','',4),(193469,'74368','new_theme','block-193465','Text','',1),(193470,'74369','new_theme','block-193465','Text','',3),(193471,'74370','new_theme','block-193465','invoice\\CustomerEmail','',6),(193472,'74371','new_theme','block-193453-2','invoice\\PaymentMethod','',5),(193473,'74372','new_theme','block-193453-2','Text','',4),(193474,'74373','new_theme','block-193453-2','Text','',2),(193475,'74374','new_theme','block-193453-2','invoice\\OrderId','',1),(193476,'74375','new_theme','block-193453-2','invoice\\PaymentDate','',3),(193477,'74376','new_theme','block-193453-2','invoice\\OrderBarcode','',6),(193478,'74377','new_theme','block-193452','BlockBox','',6),(193479,'74378','new_theme','block-193478','invoice\\StoreAddress','',8),(193480,'74379','new_theme','block-193478','Text','',1),(193481,'74380','new_theme','block-193478-2','Text','',2),(193482,'74381','new_theme','block-193478-2','Logo','',1),(193483,'74382','new_theme','block-193478-3','BlockBox','',3),(193484,'74383','new_theme','block-193483','Text','',1),(193485,'74384','new_theme','block-193483-2','invoice\\StoreEmail','',1),(193486,'74385','new_theme','block-193478-3','BlockBox','',2),(193487,'74386','new_theme','block-193486','Text','',1),(193488,'74387','new_theme','block-193486-2','invoice\\StorePhone','',1),(193489,'74388','new_theme','block-193478-3','Text','',1),(193490,'74389','new_theme','block-193452','invoice\\Products','',4),(193491,'74390','new_theme','block-193452','BlockBox','',5),(193492,'74391','new_theme','block-193491','BlockBox','',1),(193493,'74392','new_theme','block-193492','invoice\\ShippingAddress','',2),(193494,'74393','new_theme','block-193492','Text','',1),(193495,'74394','new_theme','block-193491-2','BlockBox','',1),(193496,'74395','new_theme','block-193495','invoice\\Totals','',1),(193497,'74396','new_theme','block-193452','BlockBox','',2),(193498,'74397','new_theme','block-193497','Logo','',1),(193499,'74398','new_theme','block-193497-2','BlockBox','',4),(193500,'74399','new_theme','block-193499','Text','',1),(193501,'74400','new_theme','block-193499-2','invoice\\StoreSite','',1),(193502,'74401','new_theme','block-193497-2','BlockBox','',3),(193503,'74402','new_theme','block-193502','Text','',1),(193504,'74403','new_theme','block-193502-2','invoice\\StoreEmail','',1),(193505,'74404','new_theme','block-193497-2','BlockBox','',1),(193506,'74405','new_theme','block-193505','invoice\\StoreAddress','',3),(193507,'74406','new_theme','block-193497-2','BlockBox','',2),(193508,'74407','new_theme','block-193507','Text','',1),(193509,'74408','new_theme','block-193507-2','invoice\\StorePhone','',1),(193510,'74409','new_theme','login_account','BlockBox','',1),(193511,'74410','new_theme','block-193510','Tabs','',2),(193512,'74411','new_theme','block-193511-1','login\\Returning','',1),(193513,'74412','new_theme','block-193511-2','BlockBox','',1),(193514,'74413','new_theme','block-193513','Html_box','',1),(193515,'74414','new_theme','block-193513-2','BlockBox','',1),(193516,'74415','new_theme','block-193515','Html_box','',2),(193517,'74416','new_theme','block-193515','login\\Register','',1),(193518,'74417','new_theme','block-193510','BlockBox','',1),(193519,'74418','new_theme','block-193518','Html_box','',3),(193520,'74419','new_theme','block-193518','Html_box','',1),(193521,'74420','new_theme','block-193518','login\\Socials','',2),(193522,'74421','new_theme','login_checkout','BlockBox','',1),(193523,'74422','new_theme','block-193522','BlockBox','',1),(193524,'74423','new_theme','block-193523','checkout\\CreateBtn','',4),(193525,'74424','new_theme','block-193523','checkout\\GuestBtn','',2),(193526,'74425','new_theme','block-193523','Html_box','',3),(193527,'74426','new_theme','block-193523','BlockBox','',5),(193528,'74427','new_theme','block-193527','Html_box','',1),(193529,'74428','new_theme','block-193527','login\\Socials','',2),(193530,'74429','new_theme','block-193523','Html_box','',1),(193531,'74430','new_theme','block-193523-2','login\\Returning','',2),(193532,'74431','new_theme','block-193523-2','Html_box','',1),(193533,'74432','new_theme','login_checkout2','BlockBox','',1),(193534,'74433','new_theme','block-193533','Tabs','',4),(193535,'74434','new_theme','block-193534-1','BlockBox','',1),(193536,'74435','new_theme','block-193535','Html_box','',1),(193537,'74436','new_theme','block-193535-2','BlockBox','',1),(193538,'74437','new_theme','block-193537','login\\Guest','',1),(193539,'74438','new_theme','block-193537','Html_box','',2),(193540,'74439','new_theme','block-193534-2','login\\Returning','',1),(193541,'74440','new_theme','block-193534-3','BlockBox','',1),(193542,'74441','new_theme','block-193541','Html_box','',1),(193543,'74442','new_theme','block-193541-2','BlockBox','',1),(193544,'74443','new_theme','block-193543','Html_box','',2),(193545,'74444','new_theme','block-193543','login\\Register','',1),(193546,'74445','new_theme','block-193533','login\\Socials','',2),(193547,'74446','new_theme','block-193533','Html_box','',3),(193548,'74447','new_theme','block-193533','Html_box','',1),(193549,'74448','new_theme','login_checkout2_q','BlockBox','',1),(193550,'74449','new_theme','block-193549','Tabs','',4),(193551,'74450','new_theme','block-193550-1','BlockBox','',1),(193552,'74451','new_theme','block-193551','Html_box','',1),(193553,'74452','new_theme','block-193551-2','quote\\FastOrder','',1),(193554,'74453','new_theme','block-193550-2','login\\Returning','',1),(193555,'74454','new_theme','block-193550-3','BlockBox','',1),(193556,'74455','new_theme','block-193555','Html_box','',1),(193557,'74456','new_theme','block-193555','Import','',2),(193558,'74457','new_theme','block-193555-2','BlockBox','',1),(193559,'74458','new_theme','block-193558','login\\Register','',1),(193560,'74459','new_theme','block-193558','Html_box','',2),(193561,'74460','new_theme','block-193549','Html_box','',3),(193562,'74461','new_theme','block-193549','Html_box','',1),(193563,'74462','new_theme','block-193549','login\\Socials','',2),(193564,'74463','new_theme','login_checkout2_s','BlockBox','',1),(193565,'74464','new_theme','block-193564','login\\Socials','',2),(193566,'74465','new_theme','block-193564','Html_box','',3),(193567,'74466','new_theme','block-193564','Tabs','',4),(193568,'74467','new_theme','block-193567-1','BlockBox','',1),(193569,'74468','new_theme','block-193568','Html_box','',1),(193570,'74469','new_theme','block-193568-2','quote\\FastOrder','',1),(193571,'74470','new_theme','block-193567-2','login\\Returning','',1),(193572,'74471','new_theme','block-193567-3','BlockBox','',1),(193573,'74472','new_theme','block-193572','Html_box','',1),(193574,'74473','new_theme','block-193572-2','BlockBox','',1),(193575,'74474','new_theme','block-193574','login\\Register','',1),(193576,'74475','new_theme','block-193574','Html_box','',2),(193577,'74476','new_theme','block-193564','Html_box','',1),(193578,'74477','new_theme','login_checkout_q','BlockBox','',1),(193579,'74478','new_theme','block-193578','BlockBox','',1),(193580,'74479','new_theme','block-193579','BlockBox','',6),(193581,'74480','new_theme','block-193580','Html_box','',1),(193582,'74481','new_theme','block-193580','login\\Socials','',2),(193583,'74482','new_theme','block-193579','checkout\\GuestBtn','',2),(193584,'74483','new_theme','block-193579','checkout\\CreateBtn','',5),(193585,'74484','new_theme','block-193579','Html_box','',4),(193586,'74485','new_theme','block-193579','Html_box','',1),(193587,'74486','new_theme','block-193579-2','Html_box','',1),(193588,'74487','new_theme','block-193579-2','login\\Returning','',2),(193589,'74488','new_theme','login_checkout_s','BlockBox','',1),(193590,'74489','new_theme','block-193589','BlockBox','',1),(193591,'74490','new_theme','block-193590','Html_box','',1),(193592,'74491','new_theme','block-193590','checkout\\GuestBtn','',2),(193593,'74492','new_theme','block-193590','checkout\\CreateBtn','',4),(193594,'74493','new_theme','block-193590','Html_box','',3),(193595,'74494','new_theme','block-193590','BlockBox','',5),(193596,'74495','new_theme','block-193595','Html_box','',1),(193597,'74496','new_theme','block-193595','login\\Socials','',2),(193598,'74497','new_theme','block-193590-2','Html_box','',1),(193599,'74498','new_theme','block-193590-2','login\\Returning','',2),(193600,'74499','new_theme','logoff','BlockBox','',1),(193601,'74500','new_theme','block-193600','Html_box','',1),(193602,'74501','new_theme','logoff_forever','BlockBox','',1),(193603,'74502','new_theme','block-193602','Html_box','',1),(193604,'74503','new_theme','main','BlockBox','',5),(193605,'74504','new_theme','block-193604','BlockBox','',1),(193606,'74505','new_theme','block-193605','Bestsellers','10',1),(193607,'74506','new_theme','block-193605-2','Reviews','3',1),(193608,'74507','new_theme','main','Banner','',2),(193609,'74508','new_theme','main','BlockBox','main-content',4),(193610,'74510','new_theme','block-193609','Tabs','',4),(193611,'74511','new_theme','block-193610-1','NewProducts','8',1),(193612,'74512','new_theme','block-193610-2','SpecialsProducts','',2),(193613,'74513','new_theme','block-193610-3','FeaturedProducts','4',2),(193614,'74514','new_theme','block-193609','TopCategories','',3),(193615,'74515','new_theme','main','Heading','',3),(193616,'1708693901.7617','new_theme','main','FormBuilder\\widgets\\Form','',6),(193617,'74516','new_theme','manufacturers','BlockBox','',1),(193618,'74517','new_theme','block-193617','Html_box','',1),(193619,'74518','new_theme','block-193617','Brands','',2),(193620,'74519','new_theme','messages-index','BlockBox','',1),(193621,'74520','new_theme','block-193620','BlockBox','',1),(193622,'74521','new_theme','block-193621','BlockBox','',1),(193623,'74522','new_theme','block-193622','Messages\\Sidebar','',1),(193624,'74523','new_theme','block-193621-2','Messages\\Listing','',1),(193625,'74524','new_theme','messages-new','BlockBox','',1),(193626,'74525','new_theme','block-193625','BlockBox','',1),(193627,'74526','new_theme','block-193626','Messages\\Sidebar','',1),(193628,'74527','new_theme','block-193626-2','Messages\\NewMessage','',1),(193629,'74528','new_theme','messages-view','BlockBox','',1),(193630,'74529','new_theme','block-193629','BlockBox','',1),(193631,'74530','new_theme','block-193630','Messages\\Sidebar','',1),(193632,'74531','new_theme','block-193630-2','Messages\\Message','',1),(193633,'74532','new_theme','my_password','BlockBox','',1),(193634,'74533','new_theme','block-193633','BlockBox','',1),(193635,'74534','new_theme','block-193634','WidgetsAria','',1),(193655,'74535','new_theme','block-193634-2','account\\ChangePassword','',2),(193656,'74536','new_theme','block-193634-2','Html_box','',1),(193657,'74537','new_theme','need_login','BlockBox','',1),(193658,'74538','new_theme','block-193657','Tabs','',2),(193659,'74539','new_theme','block-193658-1','login\\Returning','',1),(193660,'74540','new_theme','block-193658-2','BlockBox','',1),(193661,'74541','new_theme','block-193660','Html_box','',1),(193662,'74542','new_theme','block-193660-2','BlockBox','',1),(193663,'74543','new_theme','block-193662','login\\Register','',1),(193664,'74544','new_theme','block-193662','Html_box','',2),(193665,'74545','new_theme','block-193657','BlockBox','',1),(193666,'74546','new_theme','new-topic','BlockBox','',1),(193667,'74547','new_theme','block-193666','Breadcrumb','',2),(193668,'74548','new_theme','block-193666','Communication\\NewTopic','',3),(193669,'74549','new_theme','block-193666','Html_box','',1),(193670,'94779','new_theme','nnnn','BlockBox','',1),(193671,'94780','new_theme','block-193670','catalog\\Title','',1),(193672,'94781','new_theme','block-193670','BlockBox','',2),(193673,'94782','new_theme','block-193672','Filters','',1),(193674,'94783','new_theme','block-193672-2','Listing','',5),(193675,'94784','new_theme','block-193672-2','catalog\\Image','',1),(193676,'94785','new_theme','block-193672-2','BlockBox','',6),(193677,'94786','new_theme','block-193676','catalog\\CountsItems','',1),(193678,'94787','new_theme','block-193676-2','catalog\\Paging','',1),(193679,'94788','new_theme','block-193672-2','catalog\\ImageMapCategory','',3),(193680,'94789','new_theme','block-193672-2','Categories','',2),(193681,'94790','new_theme','block-193672-2','BlockBox','',4),(193682,'94791','new_theme','block-193681','catalog\\ListingLook','',1),(193683,'94792','new_theme','block-193681','catalog\\ItemsOnPage','',4),(193684,'94793','new_theme','block-193681','catalog\\CompareButton','',2),(193685,'94794','new_theme','block-193681','catalog\\Sorting','',3),(193686,'74550','new_theme','no-logged','BlockBox','',1),(193687,'74551','new_theme','block-193686','Communication\\NewTopic','',2),(193688,'74552','new_theme','block-193686','Html_box','',1),(193689,'74553','new_theme','no_filters','BlockBox','catalog-content',1),(193690,'74554','new_theme','block-193689','BlockBox','',4),(193691,'74555','new_theme','block-193690','catalog\\CountsItems','',1),(193692,'74556','new_theme','block-193690-2','catalog\\Paging','',1),(193693,'74557','new_theme','block-193689','Listing','',3),(193694,'74558','new_theme','block-193689','catalog\\Title','',1),(193695,'74559','new_theme','block-193689','catalog\\B2bAddButton','',5),(193696,'74560','new_theme','block-193689','BlockBox','',2),(193697,'74561','new_theme','block-193696','BlockBox','catalog-features',3),(193698,'74562','new_theme','block-193697','HeaderStock','',5),(193699,'74563','new_theme','block-193697','catalog\\ListingLook','',1),(193700,'74564','new_theme','block-193697','catalog\\CompareButton','',2),(193701,'74565','new_theme','block-193697','catalog\\ItemsOnPage','',4),(193702,'74566','new_theme','block-193697','catalog\\Sorting','',3),(193703,'74567','new_theme','block-193696','catalog\\Image','',1),(193704,'74568','new_theme','order_history','BlockBox','',1),(193705,'74569','new_theme','block-193704','BlockBox','',1),(193706,'74570','new_theme','block-193705','WidgetsAria','',1),(193726,'74571','new_theme','block-193705-2','Html_box','',1),(193727,'74572','new_theme','block-193705-2','account\\OrdersHistory','',2),(193728,'74573','new_theme','order_history_info','BlockBox','',1),(193729,'74574','new_theme','block-193728','BlockBox','',1),(193730,'74575','new_theme','block-193729','WidgetsAria','',1),(193750,'74576','new_theme','block-193729-2','account\\OrderInvoiceButton','',3),(193751,'74577','new_theme','block-193729-2','account\\OrderSubTotals','',10),(193752,'74578','new_theme','block-193729-2','account\\OrderPayButton','',5),(193753,'74579','new_theme','block-193729-2','BlockBox','',13),(193754,'74580','new_theme','block-193753','account\\AccountLink','',1),(193755,'74581','new_theme','block-193753-2','account\\OrderInvoiceButton','',1),(193756,'74582','new_theme','block-193729-2','Html_box','',8),(193757,'74583','new_theme','block-193729-2','account\\OrderHistory','',12),(193758,'74584','new_theme','block-193729-2','account\\OrderCancelAndReorder','',4),(193759,'74585','new_theme','block-193729-2','account\\OrderHeading','',1),(193760,'74586','new_theme','block-193729-2','account\\OrderDownload','',6),(193761,'74587','new_theme','block-193729-2','Html_box','',11),(193762,'74588','new_theme','block-193729-2','account\\OrderProducts','',9),(193763,'74589','new_theme','block-193729-2','account\\OrderReorderButton','',2),(193764,'74590','new_theme','block-193729-2','BlockBox','',7),(193765,'74591','new_theme','block-193764','BlockBox','',2),(193766,'74592','new_theme','block-193765','Html_box','',1),(193767,'74593','new_theme','block-193765','account\\OrderData','',2),(193768,'74594','new_theme','block-193764','BlockBox','',1),(193769,'74595','new_theme','block-193768','Html_box','',1),(193770,'74596','new_theme','block-193768','account\\OrderData','',2),(193771,'74597','new_theme','block-193764','BlockBox','',3),(193772,'74598','new_theme','block-193771','account\\OrderTracking','',2),(193773,'74599','new_theme','block-193771','Html_box','',1),(193774,'74600','new_theme','block-193771','account\\AccountLink','',3),(193775,'74601','new_theme','block-193764-2','BlockBox','',2),(193776,'74602','new_theme','block-193775','account\\OrderData','',2),(193777,'74603','new_theme','block-193775','Html_box','',1),(193778,'74604','new_theme','block-193764-2','BlockBox','',1),(193779,'74605','new_theme','block-193778','account\\OrderData','',2),(193780,'74606','new_theme','block-193778','Html_box','',1),(193781,'74607','new_theme','block-193764-3','BlockBox','',2),(193782,'74608','new_theme','block-193781','account\\OrderData','',2),(193783,'74609','new_theme','block-193781','Html_box','',1),(193784,'74610','new_theme','block-193764-3','BlockBox','',1),(193785,'74611','new_theme','block-193784','Html_box','',1),(193786,'74612','new_theme','block-193784','account\\OrderData','',2),(193787,'74613','new_theme','order_pay','BlockBox','',1),(193788,'74614','new_theme','block-193787','BlockBox','',1),(193789,'74615','new_theme','block-193788','WidgetsAria','',1),(193809,'74616','new_theme','block-193788-2','account\\OrderProducts','',4),(193810,'74617','new_theme','block-193788-2','BlockBox','',2),(193811,'74618','new_theme','block-193810','BlockBox','',1),(193812,'74619','new_theme','block-193811','Html_box','',1),(193813,'74620','new_theme','block-193811','account\\OrderData','',2),(193814,'74621','new_theme','block-193810','BlockBox','',4),(193815,'74622','new_theme','block-193814','account\\OrderData','',2),(193816,'74623','new_theme','block-193814','Html_box','',1),(193817,'74624','new_theme','block-193810-2','BlockBox','',1),(193818,'74625','new_theme','block-193817','Html_box','',1),(193819,'74626','new_theme','block-193817','account\\OrderData','',2),(193820,'74627','new_theme','block-193810-2','BlockBox','',2),(193821,'74628','new_theme','block-193820','account\\OrderData','',2),(193822,'74629','new_theme','block-193820','Html_box','',1),(193823,'74630','new_theme','block-193810-3','BlockBox','',2),(193824,'74631','new_theme','block-193823','Html_box','',1),(193825,'74632','new_theme','block-193823','account\\OrderData','',2),(193826,'74633','new_theme','block-193810-3','BlockBox','',1),(193827,'74634','new_theme','block-193826','account\\OrderData','',2),(193828,'74635','new_theme','block-193826','Html_box','',1),(193829,'74636','new_theme','block-193788-2','UpdateAndPay\\PayForm','',6),(193830,'74637','new_theme','block-193788-2','Html_box','',3),(193831,'74638','new_theme','block-193788-2','account\\OrderHeading','',1),(193832,'74639','new_theme','block-193788-2','account\\OrderSubTotals','',5),(193833,'74640','new_theme','packingslip','invoice\\Container','',2),(193834,'74641','new_theme','block-193833','BlockBox','',1),(193835,'74642','new_theme','block-193834','Logo','',1),(193836,'74643','new_theme','block-193834-2','BlockBox','',3),(193837,'74644','new_theme','block-193836','Text','',2),(193838,'74645','new_theme','block-193836-2','invoice\\StoreEmail','',1),(193839,'74646','new_theme','block-193834-2','BlockBox','',2),(193840,'74647','new_theme','block-193839','Text','',2),(193841,'74648','new_theme','block-193839-2','invoice\\StorePhone','',1),(193842,'74649','new_theme','block-193834-2','BlockBox','',1),(193843,'74650','new_theme','block-193842','invoice\\StoreAddress','',1),(193844,'74651','new_theme','block-193834-2','BlockBox','',4),(193845,'74652','new_theme','block-193844','Text','',2),(193846,'74653','new_theme','block-193844-2','invoice\\StoreSite','',1),(193847,'74654','new_theme','block-193833','packingslip\\Products','',3),(193848,'74655','new_theme','block-193833','BlockBox','',4),(193849,'74656','new_theme','block-193848','invoice\\StoreAddress','',2),(193850,'74657','new_theme','block-193848','Text','',1),(193851,'74658','new_theme','block-193833','BlockBox','',2),(193852,'74659','new_theme','block-193851','BlockBox','',2),(193853,'74660','new_theme','block-193852','BlockBox','',1),(193854,'74661','new_theme','block-193853','invoice\\ShippingAddress','',2),(193855,'74662','new_theme','block-193853','Text','',1),(193856,'74663','new_theme','block-193852-2','BlockBox','',1),(193857,'74664','new_theme','block-193856','Text','',1),(193858,'74665','new_theme','block-193856','invoice\\CustomerName','',2),(193859,'74666','new_theme','block-193856','invoice\\CustomerEmail','',6),(193860,'74667','new_theme','block-193856','Text','',3),(193861,'74668','new_theme','block-193856','invoice\\CustomerPhone','',4),(193862,'74669','new_theme','block-193856','Text','',5),(193863,'74670','new_theme','block-193851','BlockBox','',3),(193864,'74671','new_theme','block-193863','BlockBox','',1),(193865,'74672','new_theme','block-193864','invoice\\ShippingMethod','',2),(193866,'74673','new_theme','block-193864','Text','',1),(193867,'74674','new_theme','block-193863-2','BlockBox','',1),(193868,'74675','new_theme','block-193867','invoice\\ShippingMethod','',2),(193869,'74676','new_theme','block-193867','Text','',1),(193870,'74677','new_theme','block-193851-2','invoice\\AddressQrcode','',1),(193871,'74678','new_theme','password_forgotten','BlockBox','',1),(193872,'74679','new_theme','block-193871','BlockBox','',2),(193873,'74680','new_theme','block-193872-2','Html_box','',1),(193874,'74681','new_theme','block-193872-2','login\\PasswordForgotten','',2),(193875,'74682','new_theme','block-193871','Html_box','',1),(193876,'74683','new_theme','pdf','invoice\\Container','',1),(193877,'74684','new_theme','block-193876','BlockBox','',1),(193878,'74685','new_theme','block-193877','BlockBox','',1),(193879,'74686','new_theme','block-193878','BlockBox','',1),(193880,'74687','new_theme','block-193879','pdf\\ProductElement','',1),(193881,'74688','new_theme','block-193878','BlockBox','',2),(193882,'74689','new_theme','block-193881','pdf\\ProductElement','',1),(193883,'74690','new_theme','block-193881-2','pdf\\ProductElement','',2),(193884,'74691','new_theme','block-193881-2','pdf\\ProductElement','',1),(193885,'74692','new_theme','block-193877-2','BlockBox','',1),(193886,'74693','new_theme','block-193885','BlockBox','',2),(193887,'74694','new_theme','block-193886','pdf\\ProductElement','',1),(193888,'74695','new_theme','block-193886-2','pdf\\ProductElement','',2),(193889,'74696','new_theme','block-193886-2','pdf\\ProductElement','',1),(193890,'74697','new_theme','block-193885','BlockBox','',1),(193891,'74698','new_theme','block-193890','pdf\\ProductElement','',1),(193892,'74699','new_theme','pdf_category','pdf\\CategoryName','',2),(193893,'74700','new_theme','pdf_category','pdf\\CategoryImage','',1),(193894,'74701','new_theme','pdf_cover','invoice\\Container','',1),(193895,'74702','new_theme','block-193894','Logo','',1),(193896,'74703','new_theme','block-193894','Text','',3),(193897,'74704','new_theme','pdf_footer','BlockBox','',1),(193898,'74705','new_theme','block-193897-2','pdf\\PageNumber','',1),(193899,'74706','new_theme','pdf_header','pdf\\CategoryName','',1),(193900,'74707','new_theme','personal_catalog','BlockBox','',1),(193901,'74708','new_theme','block-193900','BlockBox','',1),(193902,'74709','new_theme','block-193901','WidgetsAria','',1),(193922,'74710','new_theme','block-193901-2','Html_box','',1),(193923,'74711','new_theme','block-193901-2','account\\AccountLink','',3),(193924,'74712','new_theme','block-193901-2','account\\PersonalCatalog','',2),(193925,'74713','new_theme','points_earnt_history','BlockBox','',1),(193926,'74714','new_theme','block-193925','Html_box','',1),(193927,'74715','new_theme','block-193925','BonusActions\\widgets\\PointsEarntHistory','',2),(193928,'74716','new_theme','posts','BlockBox','',1),(193929,'74717','new_theme','block-193928','Breadcrumb','',2),(193930,'74718','new_theme','block-193928','Html_box','',1),(193931,'74719','new_theme','block-193928','Communication\\Post','',3),(193932,'74720','new_theme','product','BlockBox','product-content',2),(193933,'74721','new_theme','block-193932','product\\CustomersActivity','',11),(193934,'74722','new_theme','block-193932','BlockBox','product-image',2),(193935,'74724','new_theme','block-193934','product\\Images','',2),(193936,'74725','new_theme','block-193934','product\\ImageMapProduct','',4),(193937,'74726','new_theme','block-193934','product\\PromotionIcons','',1),(193938,'74727','new_theme','block-193934-2','BlockBox','product-side',10),(193939,'74728','new_theme','block-193938','product\\ButtonsQuote','',3),(193940,'74729','new_theme','block-193938','BlockBox','',1),(193941,'74730','new_theme','block-193940','product\\Price','',1),(193942,'74731','new_theme','block-193940-2','product\\Quantity','',1),(193943,'74732','new_theme','block-193938','BonusActions\\widgets\\BonusPointsProduct','',4),(193944,'1694165842.4776','new_theme','block-193938','product\\QuantityDiscounts','',2),(193945,'74733','new_theme','block-193938-2','product\\Buttons','',1),(193946,'74734','new_theme','block-193938-2','product\\ButtonsSample','',2),(193947,'74735','new_theme','block-193934-2','product\\DescriptionShort','',6),(193948,'74737','new_theme','block-193934-2','product\\Documents','',5),(193949,'74738','new_theme','block-193934-2','product\\AvailableInWarehouses','',9),(193950,'74739','new_theme','block-193934-2','BlockBox','',11),(193951,'74741','new_theme','block-193950','product\\PersonalCatalogButton','',1),(193952,'74743','new_theme','block-193934-2','product\\Brand','',4),(193953,'74744','new_theme','block-193934-2','product\\Model','',3),(193954,'74745','new_theme','block-193934-2','product\\Name','',2),(193955,'74746','new_theme','block-193934-2','product\\Stock','',1),(193956,'1642500646.3623','new_theme','block-193934-2','product\\Attributes','',7),(193957,'74749','new_theme','block-193932','product\\Configurator','',5),(193958,'74750','new_theme','block-193932','Breadcrumb','',1),(193959,'74752','new_theme','block-193932','Tabs','',6),(193960,'74753','new_theme','block-193959-1','product\\Description','',2),(193961,'74754','new_theme','block-193959-1','product\\Properties','',1),(193962,'74755','new_theme','block-193959-2','product\\Reviews','',1),(193963,'74757','new_theme','block-193932','product\\InBundles','',4),(193964,'74758','new_theme','block-193932','product\\Bundle','',3),(193965,'1694166186.2638','new_theme','block-193932','BlockBox','',7),(193966,'74751','new_theme','block-193965','product\\AlsoPurchased','10',2),(193967,'1694166209.3278','new_theme','block-193965','Html_box','',1),(193968,'1694166191.5684','new_theme','block-193932','BlockBox','',9),(193969,'74747','new_theme','block-193968','ViewedProducts','4',2),(193970,'1694166222.3382','new_theme','block-193968','Html_box','',1),(193971,'74761','new_theme','product-bottom','product\\Properties','',1),(193972,'74762','new_theme','product-tabs','product\\Reviews','',2),(193973,'74763','new_theme','product-tabs','product\\Description','',1),(193974,'74764','new_theme','product-top-left','product\\Images','',1),(193975,'74765','new_theme','product-top-right','product\\Price','',2),(193976,'74766','new_theme','product-top-right','product\\Quantity','',5),(193977,'74767','new_theme','product-top-right','product\\Quantity','',6),(193978,'74768','new_theme','product-top-right','product\\Attributes','',3),(193979,'74769','new_theme','product-top-right','product\\Name','',1),(193980,'74770','new_theme','product-top-right','product\\Buttons','',6),(193981,'74771','new_theme','productListing','BlockBox','listing-item',1),(193982,'74773','new_theme','block-193981','productListing\\model','',7),(193983,'74774','new_theme','block-193981','BonusActions\\widgets\\BonusPointsProductListing','',6),(193984,'74775','new_theme','block-193981','productListing\\description','',5),(193985,'74776','new_theme','block-193981','productListing\\buyButton','',9),(193986,'74777','new_theme','block-193981','productListing\\rating','',3),(193987,'74778','new_theme','block-193981','productListing\\image','',1),(193988,'74779','new_theme','block-193981','BlockBox','',8),(193989,'74780','new_theme','block-193988','productListing\\price','',1),(193990,'74781','new_theme','block-193988-2','productListing\\qtyInput','',1),(193991,'74782','new_theme','block-193981','productListing\\name','',4),(193992,'74783','new_theme','block-193981','productListing\\stock','',2),(193993,'75903','new_theme','block-193981','productListing\\compare','',10),(193994,'74785','new_theme','products','BlockBox','catalog-content',1),(193995,'74786','new_theme','block-193994','BlockBox','catalog-side',4),(193996,'74787','new_theme','block-193995','Filters','',1),(193997,'74788','new_theme','block-193995','HeaderStock','',2),(193998,'74789','new_theme','block-193995-2','catalog\\B2bAddButton','',4),(193999,'74790','new_theme','block-193995-2','BlockBox','catalog-features',2),(194000,'74791','new_theme','block-193999','catalog\\Sorting','',3),(194001,'74792','new_theme','block-193999','catalog\\ListingLook','',1),(194002,'74793','new_theme','block-193999','catalog\\ItemsOnPage','',4),(194003,'74794','new_theme','block-193999','catalog\\CompareButton','',2),(194004,'74795','new_theme','block-193995-2','BlockBox','',5),(194005,'74796','new_theme','block-194004','catalog\\CountsItems','',1),(194006,'74797','new_theme','block-194004-2','catalog\\Paging','',1),(194007,'74798','new_theme','block-193995-2','Listing','',3),(194008,'74799','new_theme','block-193994','catalog\\Title','',1),(194009,'74800','new_theme','block-193994','BlockBox','',3),(194010,'74801','new_theme','block-194009','catalog\\Image','',1),(194011,'75886','new_theme','products-list','packingslip\\AllProductsList','',2),(194012,'74802','new_theme','promotions','BlockBox','',1),(194013,'74803','new_theme','block-194012','promotions\\PromoList','',2),(194014,'74804','new_theme','block-194012','Html_box','',1),(194015,'74805','new_theme','purchase','invoice\\Container','',1),(194016,'74806','new_theme','block-194015','invoice\\Products','',3),(194017,'74807','new_theme','block-194015','BlockBox','',5),(194018,'74808','new_theme','block-194017','Text','',1),(194019,'74809','new_theme','block-194017','invoice\\StoreAddress','',8),(194020,'74810','new_theme','block-194017-2','Text','',2),(194021,'74811','new_theme','block-194017-2','Logo','',1),(194022,'74812','new_theme','block-194017-3','BlockBox','',3),(194023,'74813','new_theme','block-194022','Text','',1),(194024,'74814','new_theme','block-194022-2','invoice\\StoreEmail','',1),(194025,'74815','new_theme','block-194017-3','Text','',1),(194026,'74816','new_theme','block-194017-3','BlockBox','',2),(194027,'74817','new_theme','block-194026','Text','',1),(194028,'74818','new_theme','block-194026-2','invoice\\StorePhone','',1),(194029,'74819','new_theme','block-194015','BlockBox','',1),(194030,'74820','new_theme','block-194029','Logo','',1),(194031,'74821','new_theme','block-194029-2','BlockBox','',2),(194032,'74822','new_theme','block-194031','Text','',1),(194033,'74823','new_theme','block-194031-2','invoice\\StorePhone','',1),(194034,'74824','new_theme','block-194029-2','BlockBox','',4),(194035,'74825','new_theme','block-194034','Text','',1),(194036,'74826','new_theme','block-194034-2','invoice\\StoreSite','',1),(194037,'74827','new_theme','block-194029-2','BlockBox','',1),(194038,'74828','new_theme','block-194037','invoice\\StoreAddress','',1),(194039,'74829','new_theme','block-194029-2','BlockBox','',3),(194040,'74830','new_theme','block-194039','Text','',1),(194041,'74831','new_theme','block-194039-2','invoice\\StoreEmail','',1),(194042,'74832','new_theme','block-194015','BlockBox','',2),(194043,'74833','new_theme','block-194042','BlockBox','',7),(194044,'74834','new_theme','block-194043','BlockBox','',1),(194045,'74835','new_theme','block-194044','invoice\\BillingAddress','',2),(194046,'74836','new_theme','block-194044','Text','',1),(194047,'74837','new_theme','block-194043-2','BlockBox','',1),(194048,'74838','new_theme','block-194047','invoice\\CustomerEmail','',6),(194049,'74839','new_theme','block-194047','Text','',5),(194050,'74840','new_theme','block-194047','invoice\\CustomerPhone','',4),(194051,'74841','new_theme','block-194047','invoice\\CustomerName','',2),(194052,'74842','new_theme','block-194047','Text','',3),(194053,'74843','new_theme','block-194047','Text','',1),(194054,'74844','new_theme','block-194042-2','invoice\\OrderId','',1),(194055,'74845','new_theme','block-194042-2','Text','',2),(194056,'74846','new_theme','block-194042-2','invoice\\PaymentDate','',3),(194057,'74847','new_theme','block-194015','BlockBox','',4),(194058,'74848','new_theme','block-194057','BlockBox','',1),(194059,'74849','new_theme','block-194058','invoice\\ShippingAddress','',2),(194060,'74850','new_theme','block-194058','Text','',1),(194061,'74851','new_theme','quotations','BlockBox','',1),(194062,'74852','new_theme','block-194061','BlockBox','',1),(194063,'74853','new_theme','block-194062','WidgetsAria','',1),(194083,'74854','new_theme','block-194062-2','Html_box','',1),(194084,'74855','new_theme','block-194062-2','Quotations\\QuotationsHistory','',2),(194085,'74856','new_theme','quotation_info','BlockBox','',1),(194086,'74857','new_theme','block-194085','BlockBox','',1),(194087,'74858','new_theme','block-194086','WidgetsAria','',1),(194107,'74859','new_theme','block-194086-2','BlockBox','',5),(194108,'74860','new_theme','block-194107','BlockBox','',1),(194109,'74861','new_theme','block-194108','Quotations\\QuotationData','',2),(194110,'74862','new_theme','block-194108','Html_box','',1),(194111,'74863','new_theme','block-194107','BlockBox','',4),(194112,'74864','new_theme','block-194111','Html_box','',1),(194113,'74865','new_theme','block-194111','Quotations\\QuotationData','',2),(194114,'74866','new_theme','block-194107-2','BlockBox','',2),(194115,'74867','new_theme','block-194114','Html_box','',1),(194116,'74868','new_theme','block-194114','Quotations\\QuotationData','',2),(194117,'74869','new_theme','block-194107-2','BlockBox','',1),(194118,'74870','new_theme','block-194117','Html_box','',1),(194119,'74871','new_theme','block-194117','Quotations\\QuotationData','',2),(194120,'74872','new_theme','block-194107-3','BlockBox','',1),(194121,'74873','new_theme','block-194120','Quotations\\QuotationData','',2),(194122,'74874','new_theme','block-194120','Html_box','',1),(194123,'74875','new_theme','block-194107-3','BlockBox','',2),(194124,'74876','new_theme','block-194123','Quotations\\QuotationData','',2),(194125,'74877','new_theme','block-194123','Html_box','',1),(194126,'74878','new_theme','block-194086-2','Html_box','',6),(194127,'74879','new_theme','block-194086-2','Quotations\\QuotationHistory','',10),(194128,'74880','new_theme','block-194086-2','Html_box','',9),(194129,'74881','new_theme','block-194086-2','Quotations\\QuotationProducts','',7),(194130,'74882','new_theme','block-194086-2','Quotations\\QuotationSubTotal','',8),(194131,'74883','new_theme','block-194086-2','BlockBox','',12),(194132,'74884','new_theme','block-194131','account\\AccountLink','',1),(194133,'74885','new_theme','block-194086-2','Html_box','',4),(194134,'74886','new_theme','quote','BlockBox','',1),(194135,'74887','new_theme','block-194134','cart\\CartTabs','',1),(194136,'74888','new_theme','block-194135','BlockBox','',1),(194137,'74889','new_theme','block-194136','quote\\Products','',1),(194138,'74890','new_theme','block-194136-2','BlockBox','',1),(194139,'74891','new_theme','block-194138','BlockBox','',1),(194140,'74892','new_theme','block-194139','quote\\CheckoutBtn','',2),(194141,'74893','new_theme','block-194135','Quotations\\QuotationSubTotal','',2),(194142,'74894','new_theme','review','BlockBox','',1),(194143,'74895','new_theme','block-194142','BlockBox','',1),(194144,'74896','new_theme','block-194143','WidgetsAria','',1),(194164,'74897','new_theme','block-194143-2','Html_box','',1),(194165,'74898','new_theme','block-194143-2','account\\Reviews','',2),(194166,'74899','new_theme','reviews','BlockBox','',1),(194167,'74900','new_theme','block-194166','reviews\\Heading','',1),(194168,'74901','new_theme','block-194166','reviews\\Content','',2),(194169,'74902','new_theme','rma_document','invoice\\Container','',1),(194170,'74903','new_theme','block-194169','BlockBox','',1),(194171,'74904','new_theme','block-194170','BlockBox','',1),(194172,'74905','new_theme','block-194171','BlockBox','',2),(194173,'74906','new_theme','block-194172','Html_box','',1),(194174,'74907','new_theme','block-194172-2','Html_box','',1),(194175,'74908','new_theme','block-194171','BlockBox','',5),(194176,'74909','new_theme','block-194175','Html_box','',1),(194177,'74910','new_theme','block-194175-2','Html_box','',1),(194178,'74911','new_theme','block-194171','BlockBox','',4),(194179,'74912','new_theme','block-194178','Html_box','',1),(194180,'74913','new_theme','block-194178-2','Html_box','',1),(194181,'74914','new_theme','block-194171','BlockBox','',3),(194182,'74915','new_theme','block-194181','Html_box','',1),(194183,'74916','new_theme','block-194181-2','Html_box','',1),(194184,'74917','new_theme','block-194171','BlockBox','',1),(194185,'74918','new_theme','block-194184','Html_box','',1),(194186,'74919','new_theme','block-194184','Html_box','',2),(194187,'74920','new_theme','block-194170-2','BlockBox','',1),(194188,'74921','new_theme','block-194187','Html_box','',2),(194189,'74922','new_theme','block-194187','Logo','',1),(194190,'74923','new_theme','block-194170-2','BlockBox','',2),(194191,'74924','new_theme','block-194190','BlockBox','',5),(194192,'74925','new_theme','block-194191','BlockBox','',1),(194193,'74926','new_theme','block-194192','Html_box','',1),(194194,'74927','new_theme','block-194192-2','Rma\\DocumentData','',1),(194195,'74928','new_theme','block-194191-2','BlockBox','',1),(194196,'74929','new_theme','block-194195','Html_box','',1),(194197,'74930','new_theme','block-194195-2','Rma\\DocumentData','',1),(194198,'74931','new_theme','block-194190','BlockBox','',4),(194199,'74932','new_theme','block-194198','BlockBox','',1),(194200,'74933','new_theme','block-194199','Html_box','',1),(194201,'74934','new_theme','block-194199-2','Rma\\DocumentData','',1),(194202,'74935','new_theme','block-194198-2','BlockBox','',1),(194203,'74936','new_theme','block-194202','Html_box','',1),(194204,'74937','new_theme','block-194202-2','Rma\\DocumentData','',1),(194205,'74938','new_theme','block-194190','BlockBox','',3),(194206,'74939','new_theme','block-194205','BlockBox','',1),(194207,'74940','new_theme','block-194206','Html_box','',1),(194208,'74941','new_theme','block-194206-2','Rma\\DocumentData','',1),(194209,'74942','new_theme','block-194205-2','BlockBox','',1),(194210,'74943','new_theme','block-194209','Html_box','',1),(194211,'74944','new_theme','block-194209-2','Rma\\DocumentData','',1),(194212,'74945','new_theme','block-194190','BlockBox','',2),(194213,'74946','new_theme','block-194212','Html_box','',1),(194214,'74947','new_theme','block-194212-2','Rma\\DocumentData','',1),(194215,'74948','new_theme','block-194190','BlockBox','',1),(194216,'74949','new_theme','block-194215','BlockBox','',1),(194217,'74950','new_theme','block-194216','Html_box','',1),(194218,'74951','new_theme','block-194216-2','Rma\\DocumentData','',1),(194219,'74952','new_theme','block-194215-2','BlockBox','',1),(194220,'74953','new_theme','block-194219','Html_box','',1),(194221,'74954','new_theme','block-194219-2','Rma\\DocumentData','',1),(194222,'74955','new_theme','block-194170-2','BlockBox','',3),(194223,'74956','new_theme','block-194222','BlockBox','',1),(194224,'74957','new_theme','block-194223','Html_box','',1),(194225,'74958','new_theme','block-194223-2','Rma\\DocumentData','',1),(194226,'74959','new_theme','block-194222-2','BlockBox','',1),(194227,'74960','new_theme','block-194226','Html_box','',1),(194228,'74961','new_theme','block-194226-2','Rma\\DocumentData','',1),(194229,'74962','new_theme','block-194169','BlockBox','',2),(194230,'74963','new_theme','block-194229','Html_box','',1),(194231,'74964','new_theme','block-194229','Rma\\Products','',2),(194232,'74965','new_theme','block-194169','BlockBox','',3),(194233,'74966','new_theme','block-194232','BlockBox','',1),(194234,'74967','new_theme','block-194233','BlockBox','',1),(194235,'74968','new_theme','block-194234','BlockBox','',5),(194236,'74969','new_theme','block-194235','Html_box','',1),(194237,'74970','new_theme','block-194235-2','invoice\\StoreAddress','',2),(194238,'74971','new_theme','block-194235-2','Html_box','',1),(194239,'74972','new_theme','block-194234','BlockBox','',4),(194240,'74973','new_theme','block-194239','Html_box','',1),(194241,'74974','new_theme','block-194239-2','Html_box','',1),(194242,'74975','new_theme','block-194234','BlockBox','',2),(194243,'74976','new_theme','block-194242','Html_box','',1),(194244,'74977','new_theme','block-194242-2','Html_box','',1),(194245,'74978','new_theme','block-194234','BlockBox','',1),(194246,'74979','new_theme','block-194245','Html_box','',1),(194247,'74980','new_theme','block-194234','BlockBox','',3),(194248,'74981','new_theme','block-194247','Html_box','',1),(194249,'74982','new_theme','block-194247-2','Html_box','',1),(194250,'74983','new_theme','block-194234','BlockBox','',6),(194251,'74984','new_theme','block-194250','Html_box','',1),(194252,'74985','new_theme','block-194233-2','BlockBox','',1),(194253,'74986','new_theme','block-194252','BlockBox','',1),(194254,'74987','new_theme','block-194253','BlockBox','',1),(194255,'74988','new_theme','block-194254','Rma\\DocumentData','',2),(194256,'74989','new_theme','block-194254-3','BlockBox','',1),(194257,'74990','new_theme','block-194256','Html_box','',1),(194258,'74991','new_theme','block-194256-2','Rma\\DocumentData','',1),(194259,'74992','new_theme','block-194253','BlockBox','',2),(194260,'74993','new_theme','block-194259-2','invoice\\StoreAddress','',1),(194261,'74994','new_theme','block-194233-2','BlockBox','',2),(194262,'74995','new_theme','block-194261','Html_box','',1),(194263,'74996','new_theme','block-194261','Html_box','',2),(194264,'74997','new_theme','block-194261','Html_box','',3),(194265,'74998','new_theme','block-194261','Html_box','',4),(194266,'74999','new_theme','block-194261','Html_box','',5),(194267,'75000','new_theme','block-194233-2','BlockBox','',4),(194268,'75001','new_theme','block-194267','Html_box','',1),(194269,'75002','new_theme','block-194267-2','Html_box','',1),(194270,'75003','new_theme','block-194267-3','BlockBox','',1),(194271,'75004','new_theme','block-194270','Html_box','',1),(194272,'75005','new_theme','block-194270-2','Html_box','',1),(194273,'75006','new_theme','block-194233-2','BlockBox','',3),(194274,'75007','new_theme','block-194273','Html_box','',1),(194275,'75008','new_theme','block-194273-2','Html_box','',1),(194276,'75009','new_theme','block-194273-3','BlockBox','',1),(194277,'75010','new_theme','block-194276','Html_box','',1),(194278,'75011','new_theme','block-194276-2','Html_box','',1),(194279,'75012','new_theme','rows','BlockBox','',1),(194280,'75013','new_theme','block-194279','BlockBox','',2),(194281,'75014','new_theme','block-194280','BlockBox','',2),(194282,'75015','new_theme','block-194281','BonusActions\\widgets\\BonusPointsProductListing','',1),(194283,'75016','new_theme','block-194281','productListing\\image','',2),(194284,'75017','new_theme','block-194281','BlockBox','',3),(194285,'75018','new_theme','block-194284','productListing\\rating','',1),(194286,'75019','new_theme','block-194284','productListing\\ratingCounts','',2),(194287,'75020','new_theme','block-194281-2','productListing\\name','',1),(194288,'75021','new_theme','block-194281-2','productListing\\description','',2),(194289,'75022','new_theme','block-194281-2','productListing\\model','',3),(194290,'75023','new_theme','block-194281-2','productListing\\attributes','',4),(194291,'75024','new_theme','block-194280-2','BlockBox','listing-item',1),(194292,'75025','new_theme','block-194291','productListing\\qtyInput','',3),(194293,'75026','new_theme','block-194291','productListing\\price','',2),(194294,'75027','new_theme','block-194291','productListing\\compare','',5),(194295,'75028','new_theme','block-194291','productListing\\buyButton','',4),(194296,'75030','new_theme','block-194291','productListing\\stock','',1),(194297,'75031','new_theme','sample','BlockBox','',1),(194298,'75032','new_theme','block-194297','cart\\CartTabs','',1),(194299,'75033','new_theme','block-194298','BlockBox','',1),(194300,'75034','new_theme','block-194299','sample\\Products','',1),(194301,'75035','new_theme','block-194299-2','BlockBox','',1),(194302,'75036','new_theme','block-194301','BlockBox','',1),(194303,'75037','new_theme','block-194302','sample\\CheckoutBtn','',1),(194304,'75038','new_theme','samples','BlockBox','',1),(194305,'75039','new_theme','block-194304','BlockBox','',1),(194306,'75040','new_theme','block-194305','WidgetsAria','',1),(194326,'75041','new_theme','block-194305-2','Html_box','',1),(194327,'75042','new_theme','block-194305-2','Samples\\SamplesHistory','',2),(194328,'75043','new_theme','sample_info','BlockBox','',1),(194329,'75044','new_theme','block-194328','BlockBox','',1),(194330,'75045','new_theme','block-194329','WidgetsAria','',1),(194350,'75046','new_theme','block-194329-2','Html_box','',1),(194351,'75047','new_theme','block-194329-2','BlockBox','',8),(194352,'75048','new_theme','block-194351','account\\AccountLink','',1),(194353,'75049','new_theme','block-194329-2','Samples\\SampleHistory','',7),(194354,'75050','new_theme','block-194329-2','Html_box','',3),(194355,'75051','new_theme','block-194329-2','Samples\\SampleSubTotal','',5),(194356,'75052','new_theme','block-194329-2','Samples\\SampleProducts','',4),(194357,'75053','new_theme','block-194329-2','Html_box','',6),(194358,'75054','new_theme','block-194329-2','BlockBox','',2),(194359,'75055','new_theme','block-194358','BlockBox','',4),(194360,'75056','new_theme','block-194359','Html_box','',1),(194361,'75057','new_theme','block-194359','Samples\\SampleData','',2),(194362,'75058','new_theme','block-194358','BlockBox','',1),(194363,'75059','new_theme','block-194362','Samples\\SampleData','',2),(194364,'75060','new_theme','block-194362','Html_box','',1),(194365,'75061','new_theme','block-194358-2','BlockBox','',2),(194366,'75062','new_theme','block-194365','Samples\\SampleData','',2),(194367,'75063','new_theme','block-194365','Html_box','',1),(194368,'75064','new_theme','block-194358-2','BlockBox','',1),(194369,'75065','new_theme','block-194368','Samples\\SampleData','',2),(194370,'75066','new_theme','block-194368','Html_box','',1),(194371,'75067','new_theme','block-194358-3','BlockBox','',2),(194372,'75068','new_theme','block-194371','Samples\\SampleData','',2),(194373,'75069','new_theme','block-194371','Html_box','',1),(194374,'75070','new_theme','block-194358-3','BlockBox','',1),(194375,'75071','new_theme','block-194374','Samples\\SampleData','',2),(194376,'75072','new_theme','block-194374','Html_box','',1),(194377,'75073','new_theme','sitemap','BlockBox','',1),(194378,'75074','new_theme','block-194377','Html_box','',1),(194379,'75075','new_theme','block-194377','BlockBox','',2),(194380,'75076','new_theme','block-194379','Html_box','',1),(194381,'75077','new_theme','block-194379','Html_box','',5),(194382,'75078','new_theme','block-194379','Html_box','',3),(194383,'75079','new_theme','block-194379','sitemap\\InfoPages','',2),(194384,'75080','new_theme','block-194379','sitemap\\Categories','',4),(194385,'75081','new_theme','block-194379','Menu','Account box',6),(194386,'75082','new_theme','block-194379-2','sitemap\\DeliveryLocation','',2),(194387,'75083','new_theme','block-194379-2','Html_box','',1),(194388,'75084','new_theme','subscribe','BlockBox','',1),(194389,'75085','new_theme','block-194388','Html_box','',3),(194390,'75086','new_theme','block-194388','subscribers\\UnsubscribeForm','',4),(194391,'75087','new_theme','block-194388','Html_box','',1),(194392,'75088','new_theme','block-194388','subscribers\\SubscribeForm','',2),(194393,'75089','new_theme','subscribed','BlockBox','',1),(194394,'75090','new_theme','block-194393','Html_box','',1),(194395,'94795','new_theme','subscription','BlockBox','',2),(194396,'94796','new_theme','block-194395','BlockBox','',1),(194397,'94797','new_theme','block-194396','WidgetsAria','',1),(194417,'94798','new_theme','block-194396-2','Html_box','',2),(194418,'94799','new_theme','block-194396-2','Html_box','',3),(194419,'94800','new_theme','block-194396-2','account\\Subscription','',4),(194420,'1694099590.22143','new_theme','success','BlockBox','',1),(194421,'1694099590.340695','new_theme','block-194420','BlockBox','',2),(194422,'1694099590.343733','new_theme','block-194421','BlockBox','',3),(194423,'1694099590.345212','new_theme','block-194422','BlockBox','',2),(194424,'1694099590.34749','new_theme','block-194423','BlockBox','',1),(194425,'1694099590.3531','new_theme','block-194424','order\\ShippingMethod','',6),(194426,'1694099590.351567','new_theme','block-194424','order\\DeliveryAddress','',3),(194427,'1694099590.35337','new_theme','block-194424','Html_box','',7),(194428,'1694099590.360420','new_theme','block-194424','Html_box','',5),(194429,'1694099590.362714','new_theme','block-194424','Html_box','',1),(194430,'1694099590.36422','new_theme','block-194424','checkout\\ContactConfirm','',9),(194431,'1694099590.365625','new_theme','block-194424','Html_box','',2),(194432,'1694099590.367789','new_theme','block-194423-2','BlockBox','',1),(194433,'1694099590.369488','new_theme','block-194432','order\\PaymentMethod','',6),(194434,'1694099590.370690','new_theme','block-194432','order\\BillingAddress','',3),(194435,'1694099590.371953','new_theme','block-194432','Html_box','',5),(194436,'1694099590.373633','new_theme','block-194432','Html_box','',1),(194437,'1694099590.37590','new_theme','block-194432','Html_box','',2),(194438,'1694099590.376747','new_theme','block-194422','Html_box','',1),(194439,'1694099590.38020','new_theme','block-194421-2','BlockBox','',1),(194440,'1694099590.381373','new_theme','block-194439','success\\PrintBtn','',3),(194441,'1694099590.382864','new_theme','block-194439','success\\ContinueBtn','',4),(194442,'1694099590.384241','new_theme','block-194439','order\\Products','',1),(194443,'1694099590.385486','new_theme','block-194439','order\\Totals','',2),(194444,'1694099590.386683','new_theme','block-194420','BlockBox','',1),(194445,'1694099590.387673','new_theme','block-194444','Html_box','',2),(194446,'1694099590.389337','new_theme','block-194444','order\\OrderNumber','',1),(194447,'75097','new_theme','success_q','BlockBox','',1),(194448,'75098','new_theme','block-194447','BlockBox','',1),(194449,'75099','new_theme','block-194448','BlockBox','',2),(194450,'75100','new_theme','block-194449','success\\ContinueBtn','',2),(194451,'75101','new_theme','block-194449','success\\PrintBtn','',1),(194452,'75102','new_theme','block-194448','Html_box','',1),(194453,'75107','new_theme','ticket','invoice\\Container','',1),(194454,'75108','new_theme','block-194453','BlockBox','',4),(194455,'75109','new_theme','block-194454','BlockBox','',1),(194456,'75110','new_theme','block-194455','invoice\\ShippingAddress','',2),(194457,'75111','new_theme','block-194455','Text','',1),(194458,'75112','new_theme','block-194454-2','BlockBox','',1),(194459,'75113','new_theme','block-194458','invoice\\Totals','',1),(194460,'75114','new_theme','block-194453','BlockBox','',5),(194461,'75115','new_theme','block-194460','Text','',1),(194462,'75116','new_theme','block-194460','invoice\\StoreAddress','',8),(194463,'75117','new_theme','block-194460-2','Logo','',1),(194464,'75118','new_theme','block-194460-2','Text','',2),(194465,'75119','new_theme','block-194460-3','Text','',1),(194466,'75120','new_theme','block-194460-3','BlockBox','',3),(194467,'75121','new_theme','block-194466','Text','',1),(194468,'75122','new_theme','block-194466-2','invoice\\StoreEmail','',1),(194469,'75123','new_theme','block-194460-3','BlockBox','',2),(194470,'75124','new_theme','block-194469','Text','',1),(194471,'75125','new_theme','block-194469-2','invoice\\StorePhone','',1),(194472,'75126','new_theme','block-194453','invoice\\Products','',3),(194473,'75127','new_theme','block-194453','BlockBox','',1),(194474,'75128','new_theme','block-194473-2','BlockBox','',3),(194475,'75129','new_theme','block-194474','Text','',1),(194476,'75130','new_theme','block-194474-2','invoice\\StoreEmail','',1),(194477,'75131','new_theme','block-194473-2','BlockBox','',4),(194478,'75132','new_theme','block-194477','Text','',1),(194479,'75133','new_theme','block-194477-2','invoice\\StoreSite','',1),(194480,'75134','new_theme','block-194473-2','BlockBox','',1),(194481,'75135','new_theme','block-194480','invoice\\StoreAddress','',1),(194482,'75136','new_theme','block-194473-2','BlockBox','',2),(194483,'75137','new_theme','block-194482','Text','',1),(194484,'75138','new_theme','block-194482-2','invoice\\StorePhone','',1),(194485,'75139','new_theme','block-194453','BlockBox','',2),(194486,'75140','new_theme','block-194485','BlockBox','',8),(194487,'75141','new_theme','block-194486','BlockBox','',1),(194488,'75142','new_theme','block-194487','Text','',1),(194489,'75143','new_theme','block-194487','invoice\\ShippingMethod','',2),(194490,'75144','new_theme','block-194486-2','BlockBox','',1),(194491,'75145','new_theme','block-194490','Text','',1),(194492,'75146','new_theme','block-194490','invoice\\ShippingMethod','',2),(194493,'75147','new_theme','block-194485','BlockBox','',7),(194494,'75148','new_theme','block-194493','BlockBox','',1),(194495,'75149','new_theme','block-194494','invoice\\BillingAddress','',2),(194496,'75150','new_theme','block-194494','Text','',1),(194497,'75151','new_theme','block-194493-2','BlockBox','',1),(194498,'75152','new_theme','block-194497','invoice\\CustomerName','',2),(194499,'75153','new_theme','block-194497','Text','',3),(194500,'75154','new_theme','block-194497','invoice\\CustomerEmail','',6),(194501,'75155','new_theme','block-194497','invoice\\CustomerPhone','',4),(194502,'75156','new_theme','block-194497','Text','',5),(194503,'75157','new_theme','block-194497','Text','',1),(194504,'75158','new_theme','block-194485-2','invoice\\PaymentDate','',3),(194505,'75159','new_theme','block-194485-2','Text','',2),(194506,'75160','new_theme','block-194485-2','Text','',4),(194507,'75161','new_theme','block-194485-2','invoice\\OrderId','',1),(194508,'75162','new_theme','block-194485-2','invoice\\PaymentMethod','',5),(194509,'75163','new_theme','block-194485-2','invoice\\OrderBarcode','',6),(194510,'75194','new_theme','tracking_numbers','BlockBox','',1),(194511,'75195','new_theme','block-194510','Html_box','',1),(194512,'75196','new_theme','block-194510','account\\OrderTracking','',2),(194513,'75418','new_theme','unsubscribed','BlockBox','',1),(194514,'75419','new_theme','block-194513','Html_box','',1),(194515,'75420','new_theme','update-and-pay-order_confirmation','BlockBox','',1),(194516,'75421','new_theme','block-194515','BlockBox','',3),(194517,'75422','new_theme','block-194516','BlockBox','',1),(194518,'75423','new_theme','block-194517','BlockBox','',1),(194519,'75424','new_theme','block-194518','BlockBox','',1),(194520,'75425','new_theme','block-194519','order\\ShippingMethod','',5),(194521,'75426','new_theme','block-194519','Html_box','',2),(194522,'75427','new_theme','block-194519','Html_box','',4),(194523,'75428','new_theme','block-194519','Html_box','',1),(194524,'75429','new_theme','block-194519','order\\Telephone','',8),(194525,'75430','new_theme','block-194519','Html_box','',6),(194526,'75431','new_theme','block-194519','order\\Name','',7),(194527,'75432','new_theme','block-194519','order\\Email','',9),(194528,'75433','new_theme','block-194519','order\\DeliveryAddress','',3),(194529,'75434','new_theme','block-194518-2','BlockBox','',1),(194530,'75435','new_theme','block-194529','order\\BillingAddress','',3),(194531,'75436','new_theme','block-194529','UpdateAndPay\\PayConfirm','',5),(194532,'75437','new_theme','block-194529','Html_box','',1),(194533,'75438','new_theme','block-194529','Html_box','',2),(194534,'75439','new_theme','block-194529','Html_box','',4),(194535,'75440','new_theme','block-194517','BlockBox','',3),(194536,'75441','new_theme','block-194535','order\\Products','',2),(194537,'75442','new_theme','block-194535','Html_box','',1),(194538,'75443','new_theme','block-194516-2','BlockBox','',1),(194539,'75444','new_theme','block-194538','Html_box','',1),(194540,'75445','new_theme','block-194538','checkout\\ContinueBtn','',3),(194541,'75446','new_theme','block-194538','order\\Totals','',2),(194542,'75447','new_theme','block-194515','account\\OrderHeading','',1),(194543,'75448','new_theme','update-and-pay-order_pay','BlockBox','',1),(194544,'75449','new_theme','block-194543','BlockBox','',3),(194545,'75450','new_theme','block-194544','BlockBox','',1),(194546,'75451','new_theme','block-194545','BlockBox','',1),(194547,'75452','new_theme','block-194546','BlockBox','',1),(194548,'75453','new_theme','block-194547','order\\DeliveryAddress','',3),(194549,'75454','new_theme','block-194547','order\\Email','',9),(194550,'75455','new_theme','block-194547','order\\Name','',7),(194551,'75456','new_theme','block-194547','Html_box','',6),(194552,'75457','new_theme','block-194547','order\\Telephone','',8),(194553,'75458','new_theme','block-194547','Html_box','',4),(194554,'75459','new_theme','block-194547','order\\ShippingMethod','',5),(194555,'75460','new_theme','block-194547','Html_box','',1),(194556,'75461','new_theme','block-194547','Html_box','',2),(194557,'75462','new_theme','block-194546-2','BlockBox','',1),(194558,'75463','new_theme','block-194557','Html_box','',1),(194559,'75464','new_theme','block-194557','Html_box','',2),(194560,'75465','new_theme','block-194557','Html_box','',4),(194561,'75466','new_theme','block-194557','order\\BillingAddress','',3),(194562,'75467','new_theme','block-194557','UpdateAndPay\\PayForm','',5),(194563,'75468','new_theme','block-194545','BlockBox','',3),(194564,'75469','new_theme','block-194563','Html_box','',1),(194565,'75470','new_theme','block-194563','order\\Products','',2),(194566,'75471','new_theme','block-194544-2','BlockBox','',1),(194567,'75472','new_theme','block-194566','order\\Totals','',2),(194568,'75473','new_theme','block-194566','checkout\\ContinueBtn','',3),(194569,'75474','new_theme','block-194566','Html_box','',1),(194570,'75475','new_theme','block-194543','account\\OrderHeading','',1),(194571,'75540','new_theme','wishlist','BlockBox','',1),(194572,'75541','new_theme','block-194571','BlockBox','',1),(194573,'75542','new_theme','block-194572','WidgetsAria','',1),(194574,'73374','new_theme','account-menu','BlockBox','',1),(194575,'73375','new_theme','block-194574','BlockBox','account-side',1),(194576,'73376','new_theme','block-194575','Html_box','',16),(194577,'73377','new_theme','block-194575','account\\AccountLink','',17),(194578,'73378','new_theme','block-194575','account\\AccountLink','',18),(194579,'73379','new_theme','block-194575','account\\AccountLink','',1),(194580,'73380','new_theme','block-194575','Html_box','',2),(194581,'73381','new_theme','block-194575','account\\AccountLink','',4),(194582,'73382','new_theme','block-194575','account\\AccountLink','',7),(194583,'73383','new_theme','block-194575','account\\AccountLink','',11),(194584,'73384','new_theme','block-194575','Html_box','',6),(194585,'73385','new_theme','block-194575','account\\AccountLink','',3),(194586,'73386','new_theme','block-194575','account\\AccountLink','',14),(194587,'73387','new_theme','block-194575','account\\AccountLink','',8),(194588,'73388','new_theme','block-194575','account\\AccountLink','',5),(194589,'73389','new_theme','block-194575','account\\AccountLink','',9),(194590,'73390','new_theme','block-194575','account\\AccountLink','',12),(194591,'73391','new_theme','block-194575','Html_box','',10),(194592,'73392','new_theme','block-194575','account\\AccountLink','',15),(194593,'75543','new_theme','block-194572-2','account\\Wishlist','',2),(194594,'75544','new_theme','block-194572-2','Html_box','',1),(194595,'75545','new_theme','wishlist-cart','BlockBox','',1),(194596,'75546','new_theme','block-194595','cart\\CartTabs','',1),(194597,'75547','new_theme','block-194596','account\\Wishlist','',1);
/*!40000 ALTER TABLE `design_boxes_tmp` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `document_types`
--

DROP TABLE IF EXISTS `document_types`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `document_types` (
  `document_types_id` int(11) NOT NULL,
  `language_id` int(11) NOT NULL,
  `document_types_name` varchar(255) DEFAULT NULL,
  `document_types_icon` varchar(32) DEFAULT NULL,
  PRIMARY KEY (`document_types_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `document_types`
--

LOCK TABLES `document_types` WRITE;
/*!40000 ALTER TABLE `document_types` DISABLE KEYS */;
/*!40000 ALTER TABLE `document_types` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `dropshipping_ships`
--

DROP TABLE IF EXISTS `dropshipping_ships`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `dropshipping_ships` (
  `dropshipping_ships_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `dropshipping_module` varchar(64) DEFAULT NULL,
  `shipping_code` varchar(64) DEFAULT NULL,
  `dropshipping_code` varchar(64) DEFAULT NULL,
  `dropshipping_desc` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`dropshipping_ships_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `dropshipping_ships`
--

LOCK TABLES `dropshipping_ships` WRITE;
/*!40000 ALTER TABLE `dropshipping_ships` DISABLE KEYS */;
/*!40000 ALTER TABLE `dropshipping_ships` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `easy_passwords`
--

DROP TABLE IF EXISTS `easy_passwords`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `easy_passwords` (
  `password` varchar(32) NOT NULL,
  PRIMARY KEY (`password`),
  KEY `idx_password` (`password`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `easy_passwords`
--

LOCK TABLES `easy_passwords` WRITE;
/*!40000 ALTER TABLE `easy_passwords` DISABLE KEYS */;
INSERT INTO `easy_passwords` VALUES (''),('!'),('!!!!!!'),('!@#$%^'),('!@#$%^&*'),('!@#$%^&*('),('!@#$%^&*()'),('!ab#cd$'),('!q'),('!QAZ1qaz'),('!qaz2wsx'),('!qazxsw2'),('!qazzaq1'),('!~!1'),('#1angel'),('#1baby'),('#1babygirl'),('#1baller'),('#1bitch'),('#1chick'),('#1cutie'),('#1daddy'),('#1diva'),('#1girl'),('#1hottie'),('#1love'),('#1lover'),('#1mommy'),('#1nigga'),('#1pimp'),('#1player'),('#1princess'),('#1sexy'),('#1stunna'),('#1stunner'),('$HEX'),('$HEX[687474703a2f2f616473]'),('$HEX[687474703a2f2f777777]'),('$money'),('$money$'),('&'),('&#2335:'),('&#2335;'),('&#2336:'),('&#2336;'),('&#2354189:'),('&#2354189;'),('&3'),('&hearts'),('&hearts:'),('&lt'),(')ryan'),('*123456'),('*love*'),('*star*'),('++++++'),('-'),('--'),('------'),('-9'),('-deleted-'),('.'),('..'),('...'),('....'),('.....'),('......'),('.......'),('........'),('..........'),('.:'),('.adgj'),('.adgjm'),('.adgjmpt'),('.adgjmptw'),('.kbxrf'),('.kbz123'),('.kmxbr'),('.ktxrf'),('.ktymrf'),('.kzirf'),('/.,mnb'),('/.,mnbvcxz'),('/.:'),('//////'),('0.0'),('0.0.0.'),('0.00000000'),('0.123456'),('00'),('000'),('0000'),('00000'),('000000'),('0000000'),('00000000'),('000000000'),('0000000000'),('00000000000'),('000000000000'),('000000000000000'),('00000000000000000000'),('00000000001'),('0000000000o'),('0000000001'),('00000000a'),('00000001'),('00000007'),('00000008'),('0000000a'),('0000001'),('0000007'),('000000a'),('000000aa'),('000000b'),('000000d'),('000000j'),('000000k'),('000000l'),('000000m'),('000000o'),('000000p'),('000000q'),('000000s'),('000000z'),('000001'),('0000011111'),('000002'),('000003'),('000005'),('000006'),('000007'),('000008'),('000009'),('00000a'),('00000m'),('00000o'),('00000p'),('00000q'),('00001'),('000010'),('000011'),('00001111'),('000012'),('0000123'),('00001234'),('000013'),('000021'),('000022'),('000023'),('000069'),('00007'),('000099'),('00009999'),('0000aa'),('0000aaaa'),('0000oooo'),('0001'),('000111'),('000111222'),('000123'),('000222'),('000321'),('000333'),('000420'),('000555'),('000666'),('0007'),('00070007'),('000777'),('000786'),('000789'),('000888'),('000911'),('000999'),('000999888'),('000aaa'),('000ooo'),('000webhost'),('000webhost.com'),('001'),('001001'),('001002'),('001002003'),('001007'),('0011'),('001100'),('00110011'),('001122'),('00112233'),('0011223344'),('00114477'),('001200'),('001212'),('00123'),('001234'),('00123456'),('00123456789'),('001453'),('001579238'),('001905'),('001907'),('001964'),('001965'),('001966'),('001967'),('001968'),('001969'),('001970'),('001971'),('001972'),('001973'),('001974'),('001975'),('001976'),('001977'),('001978'),('001979'),('001980'),('001981'),('001982'),('001983'),('001984'),('001985'),('001986'),('001987'),('001988'),('001989'),('001990'),('001991'),('001992'),('001995'),('001996'),('002002'),('002200'),('002211'),('002233'),('00233'),('0024657'),('003003'),('005005'),('005500'),('0069'),('006900'),('007'),('0070'),('007007'),('007007007'),('007008'),('007008009'),('007123'),('0077'),('007700'),('007911'),('007bond'),('007james'),('008008'),('008800'),('008hotboy'),('009009'),('009900'),('00990099'),('009988'),('00998877'),('0099887766'),('009d9cc2'),('01'),('010'),('010010'),('0101'),('010100'),('010101'),('01010101'),('0101010101'),('010101a'),('010102'),('010103'),('010104'),('010105'),('010106'),('010107'),('010108'),('010109'),('01011'),('010110'),('01011900'),('01011910'),('01011959'),('01011960'),('01011961'),('01011962'),('01011963'),('01011964'),('01011965'),('01011966'),('01011967'),('01011968'),('01011969'),('01011970'),('01011971'),('01011972'),('01011973'),('01011974'),('01011975'),('01011976'),('01011977'),('01011978'),('01011979'),('01011980'),('01011981'),('01011982'),('01011983'),('01011984'),('01011985'),('01011986'),('01011987'),('01011988'),('01011989'),('01011990'),('01011991'),('01011992'),('01011993'),('01011994'),('01011995'),('01011996'),('01011997'),('01011998'),('01011999'),('01012000'),('01012001'),('01012005'),('01012006'),('01012007'),('01012008'),('01012009'),('01012010'),('01012011'),('010161'),('010165'),('010166'),('010168'),('010169'),('010170'),('010171'),('010172'),('010173'),('010174'),('010175'),('010176'),('010177'),('010178'),('010179'),('010180'),('010181'),('010182'),('010183'),('010184'),('010185'),('010186'),('010187'),('010188'),('010189'),('010190'),('010191'),('010192'),('010193'),('010194'),('010195'),('010196'),('010199'),('0102'),('010200'),('010201'),('01020102'),('010203'),('0102030'),('010203010203'),('01020304'),('0102030405'),('010203040506'),('010203040506070809'),('010203a'),('010203q'),('010204'),('010205'),('010207'),('010208'),('010209'),('01021973'),('01021974'),('01021975'),('01021976'),('01021977'),('01021978'),('01021979'),('01021980'),('01021981'),('01021982'),('01021983'),('01021984'),('01021985'),('01021986'),('01021987'),('01021988'),('01021989'),('01021990'),('01021991'),('01021992'),('01021993'),('01021994'),('01021995'),('01021996'),('01021997'),('010277'),('010278'),('010279'),('010280'),('010281'),('010282'),('010283'),('010284'),('010285'),('010286'),('010287'),('010288'),('010289'),('010290'),('010291'),('010292'),('010293'),('010294'),('010295'),('010296'),('0103'),('010305'),('010306'),('010307'),('010308'),('010309'),('01031972'),('01031975'),('01031976'),('01031977'),('01031978'),('01031979'),('01031980'),('01031981'),('01031982'),('01031983'),('01031984'),('01031985'),('01031986'),('01031987'),('01031988'),('01031989'),('01031990'),('01031991'),('01031992'),('01031993'),('01031994'),('01031995'),('01031996'),('010377'),('010378'),('010379'),('010380'),('010381'),('010382'),('010383'),('010384'),('010385'),('010386'),('010387'),('010388'),('010389'),('010390'),('010391'),('010392'),('010393'),('010394'),('010395'),('010396'),('0104'),('010405'),('010406'),('010407'),('010408'),('010409'),('01041975'),('01041976'),('01041977'),('01041978'),('01041979'),('01041980'),('01041981'),('01041982'),('01041983'),('01041984'),('01041985'),('01041986'),('01041987'),('01041988'),('01041989'),('01041990'),('01041991'),('01041992'),('01041993'),('01041994'),('01041995'),('01041996'),('010475'),('010477'),('010478'),('010479'),('010480'),('010481'),('010482'),('010483'),('010484'),('010485'),('010486'),('010487'),('010488'),('010489'),('010490'),('010491'),('010492'),('010493'),('010494'),('010495'),('010496'),('0105'),('010506'),('010507'),('010508'),('010509'),('01051976'),('01051977'),('01051978'),('01051979'),('01051980'),('01051981'),('01051982'),('01051983'),('01051984'),('01051985'),('01051986'),('01051987'),('01051988'),('01051989'),('01051990'),('01051991'),('01051992'),('01051993'),('01051994'),('01051995'),('01051996'),('010577'),('010578'),('010579'),('010580'),('010581'),('010582'),('010583'),('010584'),('010585'),('010586'),('010587'),('010588'),('010589'),('010590'),('010591'),('010592'),('010593'),('010594'),('010595'),('010596'),('010597'),('0106'),('010601'),('010607'),('010608'),('010609'),('01061975'),('01061976'),('01061977'),('01061978'),('01061979'),('01061980'),('01061981'),('01061982'),('01061983'),('01061984'),('01061985'),('01061986'),('01061987'),('01061988'),('01061989'),('01061990'),('01061991'),('01061992'),('01061993'),('01061994'),('01061995'),('01061996'),('010677'),('010678'),('010679'),('010680'),('010681'),('010682'),('010683'),('010684'),('010685'),('010686'),('010687'),('010688'),('010689'),('010690'),('010691'),('010692'),('010693'),('010694'),('010695'),('010696'),('0107'),('010708'),('010709'),('01071975'),('01071976'),('01071977'),('01071978'),('01071979'),('01071980'),('01071981'),('01071982'),('01071983'),('01071984'),('01071985'),('01071986'),('01071987'),('01071988'),('01071989'),('01071990'),('01071991'),('01071992'),('01071993'),('01071994'),('01071995'),('010777'),('010778'),('010779'),('010780'),('010781'),('010782'),('010783'),('010784'),('010785'),('010786'),('010787'),('010788'),('010789'),('010790'),('010791'),('010792'),('010793'),('010794'),('010795'),('0108'),('010807'),('010808'),('010809'),('01081977'),('01081978'),('01081979'),('01081980'),('01081981'),('01081982'),('01081983'),('01081984'),('01081985'),('01081986'),('01081987'),('01081988'),('01081989'),('01081990'),('01081991'),('01081992'),('01081993'),('01081994'),('01081995'),('01081996'),('010877'),('010878'),('010879'),('010880'),('010881'),('010882'),('010883'),('010884'),('010885'),('010886'),('010887'),('010888'),('010889'),('010890'),('010891'),('010892'),('010893'),('010894'),('010895'),('010896'),('0109'),('010901'),('010906'),('010907'),('010908'),('010909'),('01091976'),('01091977'),('01091978'),('01091979'),('01091980'),('01091981'),('01091982'),('01091983'),('01091984'),('01091985'),('01091986'),('01091987'),('01091988'),('01091989'),('01091990'),('01091991'),('01091992'),('01091993'),('01091994'),('01091995'),('01091996'),('01092000'),('01092006'),('01092007'),('01092008'),('01092009'),('010978'),('010979'),('010980'),('010981'),('010982'),('010983'),('010984'),('010985'),('010986'),('010987'),('010988'),('010989'),('010990'),('010991'),('010992'),('010993'),('010994'),('010995'),('011'),('0110'),('011001'),('01100110'),('011011'),('01101977'),('01101978'),('01101979'),('01101980'),('01101981'),('01101982'),('01101983'),('01101984'),('01101985'),('01101986'),('01101987'),('01101988'),('01101989'),('01101990'),('01101991'),('01101992'),('01101993'),('01101994'),('01101995'),('011077'),('011078'),('011079'),('011080'),('011081'),('011082'),('011083'),('011084'),('011085'),('011086'),('011087'),('011088'),('011089'),('011090'),('011091'),('011092'),('011093'),('011094'),('011095'),('0111'),('011111'),('01111980'),('01111981'),('01111982'),('01111983'),('01111984'),('01111985'),('01111986'),('01111987'),('01111988'),('01111989'),('01111990'),('01111991'),('01111992'),('011151zangetsu'),('011181'),('011182'),('011183'),('011184'),('011185'),('011186'),('011187'),('011188'),('011189'),('011190'),('011191'),('011192'),('011193'),('011194'),('0112'),('01121978'),('01121979'),('01121980'),('01121981'),('01121982'),('01121983'),('01121984'),('01121985'),('01121986'),('01121987'),('01121988'),('01121989'),('01121990'),('01121991'),('01121992'),('01121993'),('01121994'),('01121995'),('0112358'),('011235813'),('011278'),('011279'),('011280'),('011281'),('011282'),('011283'),('011284'),('011285'),('011286'),('011287'),('011288'),('011289'),('011290'),('011291'),('011292'),('011293'),('011294'),('011295'),('011980'),('011982'),('011983'),('011984'),('011985'),('011986'),('011987'),('011989'),('012'),('0120'),('01200120'),('012012'),('012012012'),('0121'),('0122'),('0123'),('01230123'),('0123123'),('01233210'),('01234'),('012345'),('0123456'),('01234560'),('01234561'),('01234567'),('012345678'),('0123456789'),('01234567890'),('01234567891'),('012345678910'),('0123456789a'),('0123456a'),('012345a'),('0123654'),('0123654789'),('012369'),('0123698745'),('0124'),('0125'),('012511n'),('012589'),('013013'),('013579'),('014014'),('0147'),('01470147'),('01470258'),('014702580369'),('0147258'),('0147258369'),('01477410'),('0147852'),('01478520'),('0147852369'),('014789'),('01478963'),('0147896325'),('0159753'),('0174426'),('019283'),('0192837465'),('01love'),('02'),('020'),('0201'),('020103'),('02011975'),('02011977'),('02011978'),('02011979'),('02011980'),('02011981'),('02011982'),('02011983'),('02011984'),('02011985'),('02011986'),('02011987'),('02011988'),('02011989'),('02011990'),('02011991'),('02011992'),('02011993'),('02011995'),('020178'),('020180'),('020181'),('020183'),('020184'),('020185'),('020186'),('020187'),('020188'),('020189'),('020190'),('020191'),('020192'),('020193'),('0202'),('020201'),('020202'),('02020202'),('020203'),('020206'),('020207'),('020208'),('020209'),('02021970'),('02021972'),('02021973'),('02021974'),('02021975'),('02021976'),('02021977'),('02021978'),('02021979'),('02021980'),('02021981'),('02021982'),('02021983'),('02021984'),('02021985'),('02021986'),('02021987'),('02021988'),('02021989'),('02021990'),('02021991'),('02021992'),('02021993'),('02021994'),('02021995'),('02021996'),('02022002'),('020272'),('020274'),('020276'),('020277'),('020278'),('020279'),('020280'),('020281'),('020282'),('020283'),('020284'),('020285'),('020286'),('020287'),('020288'),('020289'),('020290'),('020291'),('020292'),('020293'),('020294'),('020295'),('020296'),('0203'),('020301'),('020302'),('02030203'),('020304'),('020305'),('020306'),('020307'),('020308'),('020309'),('02031974'),('02031975'),('02031976'),('02031977'),('02031978'),('02031979'),('02031980'),('02031981'),('02031982'),('02031983'),('02031984'),('02031985'),('02031986'),('02031987'),('02031988'),('02031989'),('02031990'),('02031991'),('02031992'),('02031993'),('02031994'),('02031995'),('02031996'),('020377'),('020378'),('020379'),('020380'),('020381'),('020382'),('020383'),('020384'),('020385'),('020386'),('020387'),('020388'),('020389'),('020390'),('020391'),('020392'),('020393'),('020394'),('020395'),('020396'),('0204'),('02040204'),('020405'),('020406'),('020408'),('020409'),('02041971'),('02041973'),('02041974'),('02041975'),('02041976'),('02041977'),('02041978'),('02041979'),('02041980'),('02041981'),('02041982'),('02041983'),('02041984'),('02041985'),('02041986'),('02041987'),('02041988'),('02041989'),('02041990'),('02041991'),('02041992'),('02041993'),('02041994'),('02041995'),('02041996'),('020476'),('020477'),('020478'),('020479'),('020480'),('020481'),('020482'),('020483'),('020484'),('020485'),('020486'),('020487'),('020488'),('020489'),('020490'),('020491'),('020492'),('020493'),('020494'),('020495'),('020496'),('0205'),('020507'),('020508'),('020509'),('02051972'),('02051974'),('02051975'),('02051976'),('02051977'),('02051978'),('02051979'),('02051980'),('02051981'),('02051982'),('02051983'),('02051984'),('02051985'),('02051986'),('02051987'),('02051988'),('02051989'),('02051990'),('02051991'),('02051992'),('02051993'),('02051994'),('02051995'),('02051996'),('020575'),('020577'),('020578'),('020579'),('020580'),('020581'),('020582'),('020583'),('020584'),('020585'),('020586'),('020587'),('020588'),('020589'),('020590'),('020591'),('020592'),('020593'),('020594'),('020595'),('020596'),('0206'),('020607'),('020608'),('020609'),('02061972'),('02061974'),('02061975'),('02061976'),('02061977'),('02061978'),('02061979'),('02061980'),('02061981'),('02061982'),('02061983'),('02061984'),('02061985'),('02061986'),('02061987'),('02061988'),('02061989'),('02061990'),('02061991'),('02061992'),('02061993'),('02061994'),('02061995'),('02061996'),('020672'),('020676'),('020677'),('020678'),('020679'),('020680'),('020681'),('020682'),('020683'),('020684'),('020685'),('020686'),('020687'),('020688'),('020689'),('020690'),('020691'),('020692'),('020693'),('020694'),('020695'),('020696'),('0207'),('020708'),('020709'),('02071975'),('02071976'),('02071977'),('02071978'),('02071979'),('02071980'),('02071981'),('02071982'),('02071983'),('02071984'),('02071985'),('02071986'),('02071987'),('02071988'),('02071989'),('02071990'),('02071991'),('02071992'),('02071993'),('02071994'),('02071995'),('02071996'),('020777'),('020779'),('020780'),('020781'),('020782'),('020783'),('020784'),('020785'),('020786'),('020787'),('020788'),('020789'),('020790'),('020791'),('020792'),('020793'),('020794'),('020795'),('020796'),('0208'),('020802'),('020808'),('020809'),('02081973'),('02081974'),('02081975'),('02081976'),('02081977'),('02081978'),('02081979'),('02081980'),('02081981'),('02081982'),('02081983'),('02081984'),('02081985'),('02081986'),('02081987'),('02081988'),('02081989'),('02081990'),('02081991'),('02081992'),('02081993'),('02081994'),('02081995'),('02081996'),('020876'),('020877'),('020878'),('020879'),('020880'),('020881'),('020882'),('020883'),('020884'),('020885'),('020886'),('020887'),('020888'),('020889'),('020890'),('020891'),('020892'),('020893'),('020894'),('020895'),('020896'),('0209'),('020906'),('02091974'),('02091975'),('02091976'),('02091977'),('02091978'),('02091979'),('02091980'),('02091981'),('02091982'),('02091983'),('02091984'),('02091985'),('02091986'),('02091987'),('02091988'),('02091989'),('02091990'),('02091991'),('02091992'),('02091993'),('02091994'),('02091995'),('020968'),('020977'),('020978'),('020979'),('020980'),('020981'),('020982'),('020983'),('020984'),('020985'),('020986'),('020987'),('020988'),('020989'),('020990'),('020991'),('020992'),('020993'),('020994'),('020995'),('021'),('0210'),('0210-605'),('02101976'),('02101977'),('02101978'),('02101979'),('02101980'),('02101981'),('02101982'),('02101983'),('02101984'),('02101985'),('02101986'),('02101987'),('02101988'),('02101989'),('02101990'),('02101991'),('02101992'),('02101993'),('02101994'),('02101995'),('02101996'),('021021'),('021065'),('021076'),('021077'),('021078'),('021079'),('021080'),('021081'),('021082'),('021083'),('021084'),('021085'),('021086'),('021087'),('021088'),('021089'),('021090'),('021091'),('021092'),('021093'),('021095'),('021096'),('0211'),('021102'),('02111980'),('02111981'),('02111982'),('02111983'),('02111984'),('02111985'),('02111986'),('02111987'),('02111988'),('02111989'),('02111990'),('02111991'),('02111992'),('02111993'),('021177'),('021178'),('021179'),('021180'),('021181'),('021182'),('021183'),('021184'),('021185'),('021186'),('021187'),('021188'),('021189'),('021190'),('021191'),('021192'),('021193'),('021194'),('021195'),('021196'),('0212'),('021202'),('02120212'),('02121977'),('02121978'),('02121979'),('02121980'),('02121981'),('02121982'),('02121983'),('02121984'),('02121985'),('02121986'),('02121987'),('02121988'),('02121989'),('02121990'),('02121991'),('02121992'),('02121993'),('02121994'),('021277'),('021278'),('021279'),('021280'),('021281'),('021282'),('021283'),('021284'),('021285'),('021286'),('021287'),('021288'),('021289'),('021290'),('021291'),('021292'),('021293'),('021294'),('021295'),('021296'),('0213'),('0214'),('021409'),('021977'),('021978'),('021979'),('021980'),('021981'),('021982'),('021983'),('021984'),('021985'),('021986'),('021987'),('021988'),('021989'),('021990'),('021992'),('0220'),('023023'),('02468'),('024680'),('0246810'),('0246813579'),('0258'),('02580258'),('02588520'),('0277127298'),('03'),('030'),('0301'),('03011980'),('03011981'),('03011982'),('03011983'),('03011984'),('03011985'),('03011986'),('03011987'),('03011988'),('03011989'),('03011990'),('03011991'),('03011992'),('03011993'),('03011994'),('03011995'),('030180'),('030181'),('030182'),('030183'),('030184'),('030185'),('030186'),('030187'),('030188'),('030189'),('030190'),('030191'),('030192'),('030194'),('030197'),('0302'),('030201'),('03021977'),('03021980'),('03021981'),('03021982'),('03021983'),('03021984'),('03021985'),('03021986'),('03021987'),('03021988'),('03021989'),('03021990'),('03021991'),('03021992'),('03021993'),('03021994'),('03021995'),('030281'),('030282'),('030283'),('030284'),('030285'),('030286'),('030287'),('030288'),('030289'),('030290'),('030291'),('030292'),('030293'),('030294'),('030295'),('0303'),('030303'),('03030303'),('030306'),('030307'),('030308'),('030309'),('03031976'),('03031977'),('03031978'),('03031979'),('03031980'),('03031981'),('03031982'),('03031983'),('03031984'),('03031985'),('03031986'),('03031987'),('03031988'),('03031989'),('03031990'),('03031991'),('03031992'),('03031993'),('03031994'),('03031995'),('03031996'),('03031997'),('03031998'),('0303456'),('030366'),('030373'),('030375'),('030377'),('030378'),('030379'),('030380'),('030381'),('030382'),('030383'),('030384'),('030385'),('030386'),('030387'),('030388'),('030389'),('030390'),('030391'),('030392'),('030393'),('030394'),('030395'),('030396'),('0304'),('030405'),('030407'),('030409'),('03041975'),('03041976'),('03041977'),('03041978'),('03041979'),('03041980'),('03041981'),('03041982'),('03041983'),('03041984'),('03041985'),('03041986'),('03041987'),('03041988'),('03041989'),('03041990'),('03041991'),('03041992'),('03041993'),('03041994'),('03041995'),('03041996'),('030477'),('030478'),('030479'),('030480'),('030481'),('030482'),('030483'),('030484'),('030485'),('030486'),('030487'),('030488'),('030489'),('030490'),('030491'),('030492'),('030493'),('030494'),('030495'),('030496'),('0305'),('030503'),('030507'),('030508'),('030509'),('03051979'),('03051980'),('03051981'),('03051982'),('03051983'),('03051984'),('03051985'),('03051986'),('03051987'),('03051988'),('03051989'),('03051990'),('03051991'),('03051992'),('03051993'),('03051994'),('03051995'),('03051996'),('030577'),('030578'),('030579'),('030580'),('030581'),('030582'),('030583'),('030584'),('030585'),('030586'),('030587'),('030588'),('030589'),('030590'),('030591'),('030592'),('030593'),('030594'),('030595'),('030596'),('0306'),('030608'),('030609'),('03061978'),('03061979'),('03061980'),('03061981'),('03061982'),('03061983'),('03061984'),('03061985'),('03061986'),('03061987'),('03061988'),('03061989'),('03061990'),('03061991'),('03061992'),('03061993'),('03061994'),('03061995'),('03061996'),('030676'),('030677'),('030678'),('030679'),('030680'),('030681'),('030682'),('030683'),('030684'),('030685'),('030686'),('030687'),('030688'),('030689'),('030690'),('030691'),('030692'),('030693'),('030694'),('030695'),('030696'),('0307'),('030709'),('03071977'),('03071978'),('03071979'),('03071980'),('03071981'),('03071982'),('03071983'),('03071984'),('03071985'),('03071986'),('03071987'),('03071988'),('03071989'),('03071990'),('03071991'),('03071992'),('03071993'),('03071994'),('03071995'),('03071996'),('030777'),('030778'),('030779'),('030780'),('030781'),('030782'),('030783'),('030784'),('030785'),('030786'),('030787'),('030788'),('030789'),('030790'),('030791'),('030792'),('030793'),('030794'),('030795'),('0308'),('030803'),('030809'),('03081977'),('03081978'),('03081979'),('03081980'),('03081981'),('03081982'),('03081983'),('03081984'),('03081985'),('03081986'),('03081987'),('03081988'),('03081989'),('03081990'),('03081991'),('03081992'),('03081993'),('03081994'),('03081995'),('03082006'),('030877'),('030878'),('030879'),('030880'),('030881'),('030882'),('030883'),('030884'),('030885'),('030886'),('030887'),('030888'),('030889'),('030890'),('030891'),('030892'),('030893'),('030894'),('030895'),('0309'),('03091977'),('03091979'),('03091980'),('03091981'),('03091982'),('03091983'),('03091984'),('03091985'),('03091986'),('03091987'),('03091988'),('03091989'),('03091990'),('03091991'),('03091992'),('03091993'),('03091994'),('030978'),('030979'),('030980'),('030981'),('030982'),('030983'),('030984'),('030985'),('030986'),('030987'),('030988'),('030989'),('030990'),('030991'),('030992'),('030993'),('030994'),('030995'),('031'),('0310'),('03101978'),('03101979'),('03101980'),('03101981'),('03101982'),('03101983'),('03101984'),('03101985'),('03101986'),('03101987'),('03101988'),('03101989'),('03101990'),('03101991'),('03101992'),('03101993'),('03101994'),('03101995'),('03101996'),('031076'),('031077'),('031078'),('031079'),('031080'),('031081'),('031082'),('031083'),('031084'),('031085'),('031086'),('031087'),('031088'),('031089'),('031090'),('031091'),('031092'),('031093'),('031094'),('031095'),('0311'),('03110311'),('03111976'),('03111980'),('03111981'),('03111982'),('03111983'),('03111984'),('03111985'),('03111986'),('03111987'),('03111988'),('03111989'),('03111990'),('03111991'),('03111992'),('03111993'),('031177'),('031178'),('031179'),('031180'),('031181'),('031182'),('031183'),('031184'),('031185'),('031186'),('031187'),('031188'),('031189'),('031190'),('031191'),('031192'),('031193'),('031194'),('031195'),('0312'),('03120312'),('03121976'),('03121979'),('03121980'),('03121981'),('03121982'),('03121983'),('03121984'),('03121985'),('03121986'),('03121987'),('03121988'),('03121989'),('03121990'),('03121991'),('03121992'),('03121993'),('03121994'),('03121995'),('03121996'),('031275'),('031276'),('031277'),('031278'),('031279'),('031280'),('031281'),('031282'),('031283'),('031284'),('031285'),('031286'),('031287'),('031288'),('031289'),('031290'),('031291'),('031292'),('031293'),('031294'),('031296'),('0313'),('0314'),('0315'),('0316'),('031982'),('031983'),('031984'),('031985'),('031986'),('031987'),('031988'),('031989'),('031990'),('031995'),('0321'),('03210321'),('0321654987'),('0323'),('0325'),('0330'),('0331'),('035690'),('03cobra'),('03kids'),('04'),('040'),('0401'),('040109'),('04011980'),('04011981'),('04011982'),('04011983'),('04011984'),('04011985'),('04011986'),('04011987'),('04011988'),('04011989'),('04011990'),('04011991'),('04011992'),('04011993'),('04011994'),('040180'),('040181'),('040182'),('040183'),('040184'),('040185'),('040186'),('040187'),('040188'),('040189'),('040190'),('040191'),('040192'),('040193'),('0402'),('04021980'),('04021981'),('04021982'),('04021983'),('04021984'),('04021985'),('04021986'),('04021987'),('04021988'),('04021989'),('04021990'),('04021991'),('04021992'),('04021993'),('04021994'),('04022000'),('040280'),('040281'),('040282'),('040283'),('040284'),('040285'),('040286'),('040287'),('040288'),('040289'),('040290'),('040291'),('040292'),('040293'),('040294'),('0403'),('04031980'),('04031981'),('04031982'),('04031983'),('04031984'),('04031985'),('04031986'),('04031987'),('04031988'),('04031989'),('04031990'),('04031991'),('04031992'),('04031993'),('04031994'),('040380'),('040381'),('040382'),('040383'),('040384'),('040385'),('040386'),('040387'),('040388'),('040389'),('040390'),('040391'),('040392'),('040393'),('0404'),('040404'),('04040404'),('040408'),('040409'),('04041974'),('04041975'),('04041977'),('04041978'),('04041979'),('04041980'),('04041981'),('04041982'),('04041983'),('04041984'),('04041985'),('04041986'),('04041987'),('04041988'),('04041989'),('04041990'),('04041991'),('04041992'),('04041993'),('04041994'),('04041995'),('04041996'),('04041997'),('040471'),('040474'),('040475'),('040477'),('040478'),('040479'),('040480'),('040481'),('040482'),('040483'),('040484'),('040485'),('040486'),('040487'),('040488'),('040489'),('040490'),('040491'),('040492'),('040493'),('040494'),('040495'),('040496'),('040498'),('0405'),('040506'),('040509'),('04051977'),('04051978'),('04051979'),('04051980'),('04051981'),('04051982'),('04051983'),('04051984'),('04051985'),('04051986'),('04051987'),('04051988'),('04051989'),('04051990'),('04051991'),('04051992'),('04051993'),('04051994'),('04051995'),('04051996'),('040576'),('040577'),('040578'),('040579'),('040580'),('040581'),('040582'),('040583'),('040584'),('040585'),('040586'),('040587'),('040588'),('040589'),('040590'),('040591'),('040592'),('040593'),('040594'),('040595'),('040596'),('0406'),('040608'),('040609'),('04061977'),('04061978'),('04061980'),('04061981'),('04061982'),('04061983'),('04061984'),('04061985'),('04061986'),('04061987'),('04061988'),('04061989'),('04061990'),('04061991'),('04061992'),('04061993'),('04061994'),('04061995'),('04061996'),('040677'),('040678'),('040679'),('040680'),('040681'),('040682'),('040683'),('040684'),('040685'),('040686'),('040687'),('040688'),('040689'),('040690'),('040691'),('040692'),('040693'),('040694'),('040695'),('040696'),('0407'),('040709'),('04071979'),('04071980'),('04071981'),('04071982'),('04071983'),('04071984'),('04071985'),('04071986'),('04071987'),('04071988'),('04071989'),('04071990'),('04071991'),('04071992'),('04071993'),('04071994'),('04071995'),('04071996'),('040777'),('040778'),('040779'),('040780'),('040781'),('040782'),('040783'),('040784'),('040785'),('040786'),('040787'),('040788'),('040789'),('040790'),('040791'),('040792'),('040793'),('040794'),('040795'),('0408'),('040806'),('040807'),('040809'),('04081978'),('04081979'),('04081980'),('04081981'),('04081982'),('04081983'),('04081984'),('04081985'),('04081986'),('04081987'),('04081988'),('04081989'),('04081990'),('04081991'),('04081992'),('04081993'),('04081994'),('04081995'),('040877'),('040879'),('040880'),('040881'),('040882'),('040883'),('040884'),('040885'),('040886'),('040887'),('040888'),('040889'),('040890'),('040891'),('040892'),('040893'),('040894'),('040895'),('0409'),('04091979'),('04091980'),('04091981'),('04091982'),('04091983'),('04091984'),('04091985'),('04091986'),('04091987'),('04091988'),('04091989'),('04091990'),('04091991'),('04091992'),('04091993'),('04091994'),('040977'),('040979'),('040980'),('040981'),('040982'),('040983'),('040984'),('040985'),('040986'),('040987'),('040988'),('040989'),('040990'),('040991'),('040992'),('040993'),('041'),('0410'),('04101980'),('04101981'),('04101982'),('04101983'),('04101984'),('04101985'),('04101986'),('04101987'),('04101988'),('04101989'),('04101990'),('04101991'),('04101992'),('04101993'),('04101994'),('041078'),('041079'),('041080'),('041081'),('041082'),('041083'),('041084'),('041085'),('041086'),('041087'),('041088'),('041089'),('041090'),('041091'),('041092'),('041093'),('041094'),('041095'),('0411'),('04111980'),('04111982'),('04111983'),('04111984'),('04111985'),('04111986'),('04111987'),('04111988'),('04111989'),('04111990'),('04111991'),('04111992'),('04111993'),('041177'),('041178'),('041179'),('041180'),('041181'),('041182'),('041183'),('041184'),('041185'),('041186'),('041187'),('041188'),('041189'),('041190'),('041191'),('041192'),('041193'),('041194'),('041195'),('0412'),('04120412'),('04121977'),('04121980'),('04121981'),('04121982'),('04121983'),('04121984'),('04121985'),('04121986'),('04121987'),('04121988'),('04121989'),('04121990'),('04121991'),('04121992'),('04121993'),('04121994'),('041278'),('041279'),('041280'),('041281'),('041282'),('041283'),('041284'),('041285'),('041286'),('041287'),('041288'),('041289'),('041290'),('041291'),('041292'),('041293'),('041294'),('041295'),('041296'),('0415'),('041978'),('041980'),('041982'),('041983'),('041984'),('041985'),('041986'),('041987'),('041988'),('041989'),('041992'),('0420'),('04200420'),('0421'),('042108'),('0423'),('0424'),('0425'),('042945d'),('05'),('050'),('0501'),('050109'),('05011980'),('05011981'),('05011982'),('05011983'),('05011984'),('05011985'),('05011986'),('05011987'),('05011988'),('05011989'),('05011990'),('05011991'),('05011992'),('05011993'),('05011994'),('050180'),('050181'),('050182'),('050183'),('050184'),('050185'),('050186'),('050187'),('050188'),('050189'),('050190'),('050191'),('050192'),('050193'),('050194'),('0502'),('050209'),('05021978'),('05021979'),('05021980'),('05021981'),('05021982'),('05021983'),('05021984'),('05021985'),('05021986'),('05021987'),('05021988'),('05021989'),('05021990'),('05021991'),('05021992'),('05021993'),('05021994'),('05021995'),('05021996'),('050280'),('050281'),('050282'),('050283'),('050284'),('050285'),('050286'),('050287'),('050288'),('050289'),('050290'),('050291'),('050292'),('050293'),('0503'),('050305'),('050309'),('05031980'),('05031981'),('05031982'),('05031983'),('05031984'),('05031985'),('05031986'),('05031987'),('05031988'),('05031989'),('05031990'),('05031991'),('05031992'),('05031993'),('05031994'),('05031996'),('050380'),('050381'),('050382'),('050383'),('050384'),('050385'),('050386'),('050387'),('050388'),('050389'),('050390'),('050391'),('050392'),('050393'),('050396'),('0504'),('050403'),('050409'),('05041977'),('05041979'),('05041980'),('05041981'),('05041982'),('05041983'),('05041984'),('05041985'),('05041986'),('05041987'),('05041988'),('05041989'),('05041990'),('05041991'),('05041992'),('05041993'),('05041994'),('05041995'),('050478'),('050479'),('050480'),('050481'),('050482'),('050483'),('050484'),('050485'),('050486'),('050487'),('050488'),('050489'),('050490'),('050491'),('050492'),('050493'),('050494'),('0505'),('050501'),('050505'),('05050505'),('050506'),('050507'),('050508'),('050509'),('05051971'),('05051975'),('05051976'),('05051977'),('05051978'),('05051979'),('05051980'),('05051981'),('05051982'),('05051983'),('05051984'),('05051985'),('05051986'),('05051987'),('05051988'),('05051989'),('05051990'),('05051991'),('05051992'),('05051993'),('05051994'),('05051995'),('05051996'),('05051997'),('05052005'),('050572'),('050575'),('050576'),('050577'),('050578'),('050579'),('050580'),('050581'),('050582'),('050583'),('050584'),('050585'),('050586'),('050587'),('050588'),('050589'),('050590'),('050591'),('050592'),('050593'),('050594'),('050595'),('050596'),('0506'),('050607'),('050608'),('050609'),('05061978'),('05061979'),('05061980'),('05061981'),('05061982'),('05061983'),('05061984'),('05061985'),('05061986'),('05061987'),('05061988'),('05061989'),('05061990'),('05061991'),('05061992'),('05061993'),('05061994'),('05061995'),('05061996'),('050677'),('050678'),('050679'),('050680'),('050681'),('050682'),('050683'),('050684'),('050685'),('050686'),('050687'),('050688'),('050689'),('050690'),('050691'),('050692'),('050693'),('050694'),('050695'),('050696'),('0507'),('050708'),('050709'),('05071977'),('05071978'),('05071979'),('05071980'),('05071981'),('05071982'),('05071983'),('05071984'),('05071985'),('05071986'),('05071987'),('05071988'),('05071989'),('05071990'),('05071991'),('05071992'),('05071993'),('05071994'),('05071995'),('05071996'),('050777'),('050778'),('050779'),('050780'),('050781'),('050782'),('050783'),('050784'),('050785'),('050786'),('050787'),('050788'),('050789'),('050790'),('050791'),('050792'),('050793'),('050794'),('050795'),('0508'),('050805'),('050809'),('05081979'),('05081980'),('05081980bija'),('05081981'),('05081982'),('05081983'),('05081984'),('05081985'),('05081986'),('05081987'),('05081988'),('05081989'),('05081990'),('05081991'),('05081992'),('05081993'),('05081994'),('05081995'),('050877'),('050878'),('050879'),('050880'),('050881'),('050882'),('050883'),('050884'),('050885'),('050886'),('050887'),('050888'),('050889'),('050890'),('050891'),('050892'),('050893'),('050894'),('050895'),('050898'),('0509'),('050900'),('050909'),('05091978'),('05091979'),('05091980'),('05091981'),('05091982'),('05091983'),('05091984'),('05091985'),('05091986'),('05091987'),('05091988'),('05091989'),('05091990'),('05091991'),('05091992'),('05091993'),('05091994'),('05091995'),('050965'),('050977'),('050978'),('050979'),('050980'),('050981'),('050982'),('050983'),('050984'),('050985'),('050986'),('050987'),('050988'),('050989'),('050990'),('050991'),('050992'),('050993'),('050994'),('050995'),('051'),('0510'),('05101978'),('05101979'),('05101980'),('05101981'),('05101982'),('05101983'),('05101984'),('05101985'),('05101986'),('05101987'),('05101988'),('05101989'),('05101990'),('05101991'),('05101992'),('05101993'),('05101994'),('05101995'),('051077'),('051078'),('051079'),('051080'),('051081'),('051082'),('051083'),('051084'),('051085'),('051086'),('051087'),('051088'),('051089'),('051090'),('051091'),('051092'),('051093'),('051094'),('051095'),('0511'),('05111980'),('05111981'),('05111982'),('05111983'),('05111984'),('05111985'),('05111986'),('05111987'),('05111988'),('05111989'),('05111990'),('05111991'),('05111992'),('05111993'),('051176'),('051177'),('051178'),('051179'),('051180'),('051181'),('051182'),('051183'),('051184'),('051185'),('051186'),('051187'),('051188'),('051189'),('051190'),('051191'),('051192'),('051193'),('051194'),('0512'),('05121978'),('05121980'),('05121981'),('05121982'),('05121983'),('05121984'),('05121985'),('05121986'),('05121987'),('05121988'),('05121989'),('05121990'),('05121991'),('05121992'),('05121993'),('05121994'),('05121995'),('051277'),('051278'),('051279'),('051280'),('051281'),('051282'),('051283'),('051284'),('051285'),('051286'),('051287'),('051288'),('051289'),('051290'),('051291'),('051292'),('051293'),('051294'),('051295'),('051383'),('051978'),('051980'),('051981'),('051982'),('051983'),('051984'),('051985'),('051986'),('051987'),('051988'),('051989'),('051990'),('051991'),('05200520'),('0521'),('0522'),('0523213511'),('0525'),('0531'),('055001984'),('0564335'),('05mustang'),('06'),('060'),('0601'),('060109'),('06011980'),('06011981'),('06011982'),('06011983'),('06011984'),('06011985'),('06011986'),('06011987'),('06011988'),('06011989'),('06011990'),('06011991'),('06011992'),('06011993'),('06011994'),('06011995'),('060178'),('060179'),('060180'),('060181'),('060182'),('060183'),('060184'),('060185'),('060186'),('060187'),('060188'),('060189'),('060190'),('060191'),('060192'),('060193'),('060194'),('060195'),('060196'),('0602'),('06021979'),('06021980'),('06021981'),('06021982'),('06021983'),('06021984'),('06021985'),('06021986'),('06021987'),('06021988'),('06021989'),('06021990'),('06021991'),('06021992'),('06021993'),('06021994'),('06021996'),('060279'),('060280'),('060281'),('060282'),('060283'),('060284'),('060285'),('060286'),('060287'),('060288'),('060289'),('060290'),('060291'),('060292'),('060293'),('060295'),('0603'),('060309'),('06031978'),('06031981'),('06031982'),('06031983'),('06031984'),('06031985'),('06031986'),('06031987'),('06031988'),('06031989'),('06031990'),('06031991'),('06031992'),('06031993'),('06031994'),('06031996'),('060380'),('060381'),('060382'),('060383'),('060384'),('060385'),('060386'),('060387'),('060388'),('060389'),('060390'),('060391'),('060392'),('060393'),('060395'),('0604'),('060405'),('06041979'),('06041980'),('06041981'),('06041982'),('06041983'),('06041984'),('06041985'),('06041986'),('06041987'),('06041988'),('06041989'),('06041990'),('06041991'),('06041992'),('06041993'),('06041994'),('06041995'),('060479'),('060480'),('060481'),('060482'),('060483'),('060484'),('060485'),('060486'),('060487'),('060488'),('060489'),('060490'),('060491'),('060492'),('060493'),('060494'),('0605'),('060504'),('060506'),('06051980'),('06051981'),('06051982'),('06051983'),('06051984'),('06051985'),('06051986'),('06051987'),('06051988'),('06051989'),('06051990'),('06051991'),('06051992'),('06051993'),('06051994'),('06051995'),('060580'),('060581'),('060582'),('060583'),('060584'),('060585'),('060586'),('060587'),('060588'),('060589'),('060590'),('060591'),('060592'),('060593'),('060594'),('060595'),('0606'),('060606'),('06060606'),('060608'),('060609'),('06061975'),('06061976'),('06061977'),('06061978'),('06061979'),('06061980'),('06061981'),('06061982'),('06061983'),('06061984'),('06061985'),('06061986'),('06061987'),('06061988'),('06061989'),('06061990'),('06061991'),('06061992'),('06061993'),('06061994'),('06061995'),('06061996'),('06062006'),('060675'),('060676'),('060677'),('060678'),('060679'),('060680'),('060681'),('060682'),('060683'),('060684'),('060685'),('060686'),('060687'),('060688'),('060689'),('060690'),('060691'),('060692'),('060693'),('060694'),('060695'),('060696'),('060697'),('060698'),('0607'),('060708'),('060709'),('06071978'),('06071979'),('06071980'),('06071981'),('06071982'),('06071983'),('06071984'),('06071985'),('06071986'),('06071987'),('06071988'),('06071989'),('06071990'),('06071991'),('06071992'),('06071993'),('06071994'),('06071995'),('06071996'),('060777'),('060778'),('060780'),('060781'),('060782'),('060783'),('060784'),('060785'),('060786'),('060787'),('060788'),('060789'),('060790'),('060791'),('060792'),('060793'),('060794'),('060795'),('0608'),('060809'),('06081977'),('06081979'),('06081980'),('06081981'),('06081982'),('06081983'),('06081984'),('06081985'),('06081986'),('06081987'),('06081988'),('06081989'),('06081990'),('06081991'),('06081992'),('06081993'),('06081994'),('060878'),('060879'),('060880'),('060881'),('060882'),('060883'),('060884'),('060885'),('060886'),('060887'),('060888'),('060889'),('060890'),('060891'),('060892'),('060893'),('060894'),('060895'),('060896'),('060897'),('0609'),('060906'),('060908'),('06091979'),('06091980'),('06091981'),('06091982'),('06091983'),('06091984'),('06091985'),('06091986'),('06091987'),('06091988'),('06091989'),('06091990'),('06091991'),('06091992'),('06091993'),('06091994'),('06091995'),('060977'),('060978'),('060979'),('060980'),('060981'),('060982'),('060983'),('060984'),('060985'),('060986'),('060987'),('060988'),('060989'),('060990'),('060991'),('060992'),('060993'),('060994'),('060995'),('060996'),('061'),('0610'),('06101978'),('06101979'),('06101980'),('06101981'),('06101982'),('06101983'),('06101984'),('06101985'),('06101986'),('06101987'),('06101988'),('06101989'),('06101990'),('06101991'),('06101992'),('06101993'),('06101994'),('061077'),('061078'),('061079'),('061080'),('061081'),('061082'),('061083'),('061084'),('061085'),('061086'),('061087'),('061088'),('061089'),('061090'),('061091'),('061092'),('061093'),('061095'),('0611'),('06111980'),('06111981'),('06111982'),('06111983'),('06111984'),('06111985'),('06111986'),('06111987'),('06111988'),('06111989'),('06111990'),('06111991'),('06111992'),('061177'),('061178'),('061179'),('061180'),('061181'),('061182'),('061183'),('061184'),('061185'),('061186'),('061187'),('061188'),('061189'),('061190'),('061191'),('061192'),('061193'),('061194'),('061196'),('0612'),('061206'),('06121978'),('06121979'),('06121980'),('06121981'),('06121982'),('06121983'),('06121984'),('06121985'),('06121986'),('06121987'),('06121988'),('06121989'),('06121990'),('06121991'),('06121992'),('06121993'),('06121994'),('06121995'),('061277'),('061278'),('061279'),('061280'),('061281'),('061282'),('061283'),('061284'),('061285'),('061286'),('061287'),('061288'),('061289'),('061290'),('061291'),('061292'),('061293'),('061294'),('061295'),('061296'),('061606'),('061979'),('061980'),('061981'),('061982'),('061983'),('061984'),('061985'),('061986'),('061987'),('061988'),('061989'),('061990'),('062593'),('0666'),('0676135313'),('06LB18'),('07'),('070'),('0701'),('07011980'),('07011981'),('07011982'),('07011983'),('07011984'),('07011985'),('07011986'),('07011987'),('07011988'),('07011989'),('07011990'),('07011991'),('07011992'),('07011993'),('07011994'),('070180'),('070181'),('070182'),('070183'),('070184'),('070185'),('070186'),('070187'),('070188'),('070189'),('070190'),('070191'),('070192'),('070193'),('070194'),('070195'),('0702'),('07021980'),('07021981'),('07021982'),('07021983'),('07021984'),('07021985'),('07021986'),('07021987'),('07021988'),('07021989'),('07021990'),('07021991'),('07021992'),('07021993'),('07021994'),('07021995'),('070280'),('070282'),('070283'),('070284'),('070285'),('070286'),('070287'),('070288'),('070289'),('070290'),('070291'),('070292'),('070293'),('0703'),('070309'),('07031980'),('07031981'),('07031982'),('07031983'),('07031984'),('07031985'),('07031986'),('07031987'),('07031988'),('07031989'),('07031990'),('07031991'),('07031992'),('07031993'),('07031995'),('070380'),('070381'),('070382'),('070383'),('070384'),('070385'),('070386'),('070387'),('070388'),('070389'),('070390'),('070391'),('070392'),('070393'),('0704'),('07041978'),('07041979'),('07041980'),('07041981'),('07041982'),('07041983'),('07041984'),('07041985'),('07041986'),('07041987'),('07041988'),('07041989'),('07041990'),('07041991'),('07041992'),('07041993'),('07041994'),('07041995'),('070480'),('070481'),('070482'),('070483'),('070484'),('070485'),('070486'),('070487'),('070488'),('070489'),('070490'),('070491'),('070492'),('070493'),('070494'),('070495'),('0705'),('07051979'),('07051980'),('07051981'),('07051982'),('07051983'),('07051984'),('07051985'),('07051986'),('07051987'),('07051988'),('07051989'),('07051990'),('07051991'),('07051992'),('07051993'),('07051994'),('07051995'),('070580'),('070581'),('070582'),('070583'),('070584'),('070585'),('070586'),('070587'),('070588'),('070589'),('070590'),('070591'),('070592'),('070593'),('070594'),('070596'),('070605'),('070608'),('07061978'),('07061980'),('07061981'),('07061982'),('07061983'),('07061984'),('07061985'),('07061985nina'),('07061986'),('07061987'),('07061988'),('07061989'),('07061990'),('07061991'),('07061992'),('07061993'),('07061994'),('07061995'),('070680'),('070682'),('070683'),('070684'),('070685'),('070686'),('070687'),('070688'),('070689'),('070690'),('070691'),('070692'),('070693'),('070694'),('0707'),('070701'),('070707'),('07070707'),('070708'),('070709'),('07071976'),('07071977'),('07071978'),('07071979'),('07071980'),('07071981'),('07071982'),('07071983'),('07071984'),('07071985'),('07071986'),('07071987'),('07071988'),('07071989'),('07071990'),('07071991'),('07071992'),('07071993'),('07071994'),('07071995'),('07071997'),('07071998'),('07072007'),('070770'),('070775'),('070777'),('070778'),('070779'),('070780'),('070781'),('070782'),('070783'),('070784'),('070785'),('070786'),('070787'),('070788'),('070789'),('070790'),('070791'),('070792'),('070793'),('070794'),('070795'),('070797'),('0708'),('070807'),('070809'),('07081978'),('07081979'),('07081980'),('07081981'),('07081982'),('07081983'),('07081984'),('07081985'),('07081986'),('07081987'),('07081988'),('07081989'),('07081990'),('07081991'),('07081992'),('07081993'),('07081994'),('070878'),('070880'),('070881'),('070882'),('070883'),('070884'),('070885'),('070886'),('070887'),('070888'),('070889'),('070890'),('070891'),('070892'),('070893'),('070894'),('070895'),('0709'),('070907'),('07091980'),('07091981'),('07091982'),('07091983'),('07091984'),('07091985'),('07091986'),('07091987'),('07091988'),('07091989'),('07091990'),('07091991'),('07091992'),('07091993'),('07091994'),('07091995'),('070979'),('070980'),('070981'),('070982'),('070983'),('070984'),('070985'),('070986'),('070987'),('070988'),('070989'),('070990'),('070991'),('070992'),('070993'),('070994'),('071'),('0710'),('07101962'),('07101980'),('07101981'),('07101982'),('07101983'),('07101984'),('07101985'),('07101986'),('07101987'),('07101988'),('07101989'),('07101990'),('07101991'),('07101992'),('07101993'),('07101994'),('07101995'),('071077'),('071080'),('071081'),('071082'),('071083'),('071084'),('071085'),('071086'),('071087'),('071088'),('071089'),('071090'),('071091'),('071092'),('071093'),('071094'),('0711'),('07111980'),('07111981'),('07111982'),('07111983'),('07111984'),('07111985'),('07111986'),('07111987'),('07111988'),('07111989'),('07111990'),('07111991'),('07111992'),('07111993'),('071177'),('071178'),('071179'),('071180'),('071181'),('071182'),('071183'),('071184'),('071185'),('071186'),('071187'),('071188'),('071189'),('071190'),('071191'),('071192'),('071193'),('071194'),('071195'),('071198'),('0712'),('071207'),('07121979'),('07121980'),('07121981'),('07121982'),('07121983'),('07121984'),('07121985'),('07121986'),('07121987'),('07121988'),('07121989'),('07121990'),('07121991'),('07121992'),('07121993'),('07121994'),('071277'),('071278'),('071279'),('071280'),('071281'),('071282'),('071283'),('071284'),('071285'),('071286'),('071287'),('071288'),('071289'),('071290'),('071291'),('071292'),('071293'),('071294'),('071295'),('0714'),('071421'),('071982'),('071983'),('071984'),('071985'),('071986'),('071987'),('071988'),('071989'),('0721'),('0741020'),('07831505'),('07860786'),('08'),('080'),('0801'),('080108'),('08011981'),('08011982'),('08011983'),('08011984'),('08011985'),('08011986'),('08011987'),('08011988'),('08011989'),('08011990'),('08011991'),('08011992'),('08011993'),('08011994'),('080181'),('080182'),('080183'),('080184'),('080185'),('080186'),('080187'),('080188'),('080189'),('080190'),('080191'),('080192'),('080193'),('080194'),('0802'),('08021980'),('08021981'),('08021982'),('08021983'),('08021984'),('08021985'),('08021986'),('08021987'),('08021988'),('08021989'),('08021990'),('08021991'),('08021992'),('08021993'),('08021994'),('08021995'),('080280'),('080281'),('080282'),('080283'),('080284'),('080285'),('080286'),('080287'),('080288'),('080289'),('080290'),('080291'),('080292'),('080293'),('080294'),('0803'),('080308'),('080309'),('08031977'),('08031978'),('08031979'),('08031980'),('08031981'),('08031982'),('08031983'),('08031984'),('08031985'),('08031986'),('08031987'),('08031988'),('08031989'),('08031990'),('08031991'),('08031992'),('08031993'),('08031994'),('08031996'),('080365'),('080380'),('080382'),('080383'),('080384'),('080385'),('080386'),('080387'),('080388'),('080389'),('080390'),('080391'),('080392'),('080393'),('080394'),('080395'),('0804'),('080408'),('08041978'),('08041980'),('08041981'),('08041982'),('08041983'),('08041984'),('08041985'),('08041986'),('08041987'),('08041988'),('08041989'),('08041990'),('08041991'),('08041992'),('08041993'),('08041994'),('080480'),('080482'),('080483'),('080484'),('080485'),('080486'),('080487'),('080488'),('080489'),('080490'),('080491'),('080492'),('080493'),('080494'),('0805'),('080502'),('080508'),('08051980'),('08051981'),('08051982'),('08051983'),('08051984'),('08051985'),('08051986'),('08051987'),('08051988'),('08051989'),('08051990'),('08051991'),('08051992'),('08051993'),('08051994'),('080580'),('080581'),('080582'),('080583'),('080584'),('080585'),('080586'),('080587'),('080588'),('080589'),('080590'),('080591'),('080592'),('080593'),('080595'),('080596'),('0806'),('08061977'),('08061979'),('08061980'),('08061981'),('08061982'),('08061983'),('08061984'),('08061985'),('08061986'),('08061987'),('08061988'),('08061989'),('08061990'),('08061991'),('08061992'),('08061993'),('08061994'),('08061995'),('080680'),('080681'),('080682'),('080683'),('080684'),('080685'),('080686'),('080687'),('080688'),('080689'),('080690'),('080691'),('080692'),('080693'),('080694'),('080695'),('0807'),('080706'),('08071980'),('08071981'),('08071982'),('08071983'),('08071984'),('08071985'),('08071986'),('08071987'),('08071988'),('08071989'),('08071990'),('08071991'),('08071992'),('08071993'),('08071994'),('080780'),('080781'),('080782'),('080783'),('080784'),('080785'),('080786'),('080787'),('080788'),('080789'),('080790'),('080791'),('080792'),('080793'),('0808'),('080807'),('080808'),('08080808'),('080809'),('08081973'),('08081974'),('08081976'),('08081977'),('08081978'),('08081979'),('08081980'),('08081981'),('08081982'),('08081983'),('08081984'),('08081985'),('08081986'),('08081987'),('08081988'),('08081989'),('08081990'),('08081991'),('08081992'),('08081993'),('08081994'),('08081995'),('08081996'),('08081998'),('08082008'),('080874'),('080875'),('080876'),('080877'),('080878'),('080879'),('080880'),('080881'),('080882'),('080883'),('080884'),('080885'),('080886'),('080887'),('080888'),('080889'),('080890'),('080891'),('080892'),('080893'),('080894'),('080895'),('080896'),('080897'),('080898'),('0809'),('080907'),('080908'),('08090809'),('080910'),('08091977'),('08091979'),('08091980'),('08091981'),('08091982'),('08091983'),('08091984'),('08091985'),('08091986'),('08091987'),('08091988'),('08091989'),('08091990'),('08091991'),('08091992'),('08091993'),('08091994'),('08091995'),('080977'),('080979'),('080980'),('080981'),('080982'),('080983'),('080984'),('080985'),('080986'),('080987'),('080988'),('080989'),('080990'),('080991'),('080992'),('080993'),('080994'),('080995'),('081'),('0810'),('08101980'),('08101981'),('08101982'),('08101983'),('08101984'),('08101985'),('08101986'),('08101987'),('08101988'),('08101989'),('08101990'),('08101991'),('08101992'),('08101993'),('081080'),('081081'),('081082'),('081083'),('081084'),('081085'),('081086'),('081087'),('081088'),('081089'),('081090'),('081091'),('081092'),('081093'),('081094'),('081096'),('0811'),('081108'),('08111982'),('08111983'),('08111984'),('08111985'),('08111986'),('08111987'),('08111988'),('08111989'),('08111990'),('08111991'),('08111992'),('08111993'),('081178'),('081179'),('081180'),('081181'),('081182'),('081183'),('081184'),('081185'),('081186'),('081187'),('081188'),('081189'),('081190'),('081191'),('081192'),('081193'),('081194'),('0812'),('081200'),('081208'),('08121979'),('08121980'),('08121981'),('08121982'),('08121983'),('08121984'),('08121985'),('08121986'),('08121987'),('08121988'),('08121989'),('08121990'),('08121991'),('08121992'),('08121993'),('08121994'),('08121995'),('081275'),('081277'),('081278'),('081279'),('081280'),('081281'),('081282'),('081283'),('081284'),('081285'),('081286'),('081287'),('081288'),('081289'),('081290'),('081291'),('081292'),('081293'),('081294'),('081295'),('0813'),('0815'),('08150815'),('08154711'),('081980'),('081982'),('081983'),('081984'),('081985'),('081986'),('081987'),('081988'),('081989'),('081990'),('081991'),('0822'),('0825'),('0852'),('08520852'),('085213'),('08522580'),('086421'),('088011'),('09'),('090'),('090078601'),('0901'),('090109'),('09011982'),('09011983'),('09011984'),('09011985'),('09011986'),('09011987'),('09011988'),('09011989'),('09011990'),('09011991'),('09011992'),('09011993'),('090181'),('090182'),('090183'),('090184'),('090185'),('090186'),('090187'),('090188'),('090189'),('090190'),('090191'),('090192'),('090193'),('0902'),('09021977'),('09021978'),('09021980'),('09021981'),('09021982'),('09021983'),('09021984'),('09021985'),('09021986'),('09021987'),('09021988'),('09021989'),('09021990'),('09021991'),('09021992'),('09021993'),('09021994'),('09021995'),('090280'),('090281'),('090282'),('090283'),('090284'),('090285'),('090286'),('090287'),('090288'),('090289'),('090290'),('090291'),('090292'),('090293'),('090295'),('0903'),('090309'),('09031980'),('09031981'),('09031982'),('09031983'),('09031984'),('09031985'),('09031986'),('09031987'),('09031988'),('09031989'),('09031990'),('09031991'),('09031992'),('09031993'),('09031994'),('09031995'),('090381'),('090382'),('090383'),('090384'),('090385'),('090386'),('090387'),('090388'),('090389'),('090390'),('090391'),('090392'),('090393'),('0904'),('090409'),('09041977'),('09041979'),('09041980'),('09041981'),('09041982'),('09041983'),('09041984'),('09041985'),('09041986'),('09041987'),('09041988'),('09041989'),('09041990'),('09041991'),('09041992'),('09041993'),('09041994'),('090477'),('090480'),('090481'),('090482'),('090483'),('090484'),('090485'),('090486'),('090487'),('090488'),('090489'),('090490'),('090491'),('090492'),('090493'),('0905'),('090509'),('09051945'),('09051978'),('09051979'),('09051980'),('09051981'),('09051982'),('09051983'),('09051984'),('09051985'),('09051986'),('09051987'),('09051988'),('09051989'),('09051990'),('09051991'),('09051992'),('09051993'),('09051994'),('09051995'),('090545'),('090579'),('090580'),('090581'),('090582'),('090583'),('090584'),('090585'),('090586'),('090587'),('090588'),('090589'),('090590'),('090591'),('090592'),('090593'),('090594'),('090595'),('0906'),('090603'),('09061976'),('09061980'),('09061981'),('09061982'),('09061983'),('09061984'),('09061985'),('09061986'),('09061987'),('09061988'),('09061989'),('09061990'),('09061991'),('09061992'),('09061993'),('09061994'),('09061995'),('090678'),('090679'),('090680'),('090681'),('090682'),('090683'),('090684'),('090685'),('090686'),('090687'),('090688'),('090689'),('090690'),('090691'),('090692'),('090693'),('090694'),('090695'),('0907'),('09071980'),('09071981'),('09071982'),('09071983'),('09071984'),('09071985'),('09071986'),('09071987'),('09071988'),('09071989'),('09071990'),('09071991'),('09071992'),('09071993'),('09071994'),('090781'),('090782'),('090783'),('090784'),('090785'),('090786'),('090787'),('090788'),('090789'),('090790'),('090791'),('090792'),('090793'),('0908'),('090807'),('09080706'),('0908070605'),('090808'),('090809'),('09081980'),('09081981'),('09081982'),('09081983'),('09081984'),('09081985'),('09081986'),('09081987'),('09081988'),('09081989'),('09081990'),('09081991'),('09081992'),('09081993'),('09081994'),('090880'),('090881'),('090882'),('090883'),('090884'),('090885'),('090886'),('090887'),('090888'),('090889'),('090890'),('090891'),('090892'),('090893'),('0909'),('090900'),('090906'),('090907'),('090908'),('090909'),('09090909'),('0909090909'),('09091088'),('09091977'),('09091978'),('09091979'),('09091980'),('09091981'),('09091982'),('09091983'),('09091984'),('09091985'),('09091986'),('09091987'),('09091988'),('09091989'),('09091990'),('09091991'),('09091992'),('09091993'),('09091994'),('09091995'),('09091999'),('09092009'),('090976'),('090977'),('090978'),('090979'),('090980'),('090981'),('090982'),('090983'),('090984'),('090985'),('090986'),('090987'),('090988'),('090989'),('090990'),('090991'),('090992'),('090993'),('090994'),('090995'),('090999'),('091'),('0910'),('09101980'),('09101981'),('09101982'),('09101983'),('09101984'),('09101985'),('09101986'),('09101987'),('09101988'),('09101989'),('09101990'),('09101991'),('09101992'),('09101993'),('091080'),('091081'),('091082'),('091083'),('091084'),('091085'),('091086'),('091087'),('091088'),('091089'),('091090'),('091091'),('091092'),('091093'),('0911'),('091101'),('09110911'),('09111980'),('09111981'),('09111982'),('09111983'),('09111984'),('09111985'),('09111986'),('09111987'),('09111988'),('09111989'),('09111990'),('09111991'),('09111992'),('09111993'),('091177'),('091178'),('091179'),('091180'),('091181'),('091182'),('091183'),('091184'),('091185'),('091186'),('091187'),('091188'),('091189'),('091190'),('091191'),('091192'),('091193'),('091194'),('0912'),('091209'),('09120912'),('09121980'),('09121981'),('09121982'),('09121983'),('09121984'),('09121985'),('09121986'),('09121987'),('09121988'),('09121989'),('09121990'),('09121991'),('09121992'),('09121993'),('09121994'),('09123456'),('0912345678'),('09123456789'),('091276'),('091277'),('091278'),('091279'),('091280'),('091281'),('091282'),('091283'),('091284'),('091285'),('091286'),('091287'),('091288'),('091289'),('091290'),('091291'),('091292'),('091293'),('091294'),('091295'),('091296'),('091298'),('0919'),('091979'),('091981'),('091982'),('091983'),('091984'),('091985'),('091986'),('091987'),('091988'),('091989'),('092'),('0921'),('092124'),('0923'),('0931541082'),('097531'),('098'),('098098'),('098098098'),('098123'),('0987'),('09870987'),('09876'),('0987612345'),('098765'),('0987654'),('09876543'),('098765432'),('0987654321'),('09876543210'),('09876543211'),('0987654321a'),('0987654321q'),('0987654321z'),('098765a'),('09877890'),('0987poiu'),('098890'),('098poi'),('0blivion'),('0cDh0v99uE'),('0icOtpd785'),('0lHhNw3v'),('0liver'),('0o0o0o'),('0o0o0o0o'),('0o9i8u'),('0o9i8u7y'),('0o9i8u7y6t'),('0okm9ijn'),('0okmnji9'),('0p9o8i'),('0p9o8i7u'),('0p9o8i7u6y'),('0password'),('0r968ji9ufj6'),('0range'),('0xzryx'),('0zero0'),('1'),('1,00001E+14'),('1,00002E+14'),('1.2.3.'),('1.23457E'),('1.23457E+11'),('10'),('100'),('1000'),('10000'),('100000'),('1000000'),('10000000'),('1000000000'),('100001'),('10001000'),('10002000'),('1001'),('100100'),('1001001'),('100100100'),('100101'),('100102'),('100109'),('100110'),('10011001'),('10011975'),('10011976'),('10011977'),('10011978'),('10011979'),('10011980'),('10011981'),('10011982'),('10011983'),('10011984'),('10011985'),('10011986'),('10011987'),('10011988'),('10011989'),('10011990'),('10011991'),('10011992'),('10011993'),('10011994'),('10011995'),('10011996'),('10011997'),('100175'),('100176'),('100177'),('100178'),('100179'),('100180'),('100181'),('100182'),('100183'),('100184'),('100185'),('100186'),('100187'),('100188'),('100189'),('100190'),('100191'),('100192'),('100193'),('100194'),('100195'),('100196'),('100199'),('1001WDST'),('1002'),('100200'),('100200300'),('100202'),('100203'),('10021002'),('10021976'),('10021977'),('10021978'),('10021979'),('10021980'),('10021981'),('10021982'),('10021983'),('10021984'),('10021985'),('10021986'),('10021987'),('10021988'),('10021989'),('10021990'),('10021991'),('10021992'),('10021993'),('10021994'),('10021995'),('10021996'),('10021997'),('100261'),('100272'),('100273'),('100275'),('100276'),('100277'),('100278'),('100279'),('100280'),('100281'),('100282'),('100283'),('100284'),('100285'),('100286'),('100287'),('100288'),('100289'),('100290'),('100291'),('100292'),('100293'),('100294'),('100295'),('100296'),('100297'),('100299'),('1003'),('100300'),('10031003'),('10031977'),('10031978'),('10031979'),('10031980'),('10031981'),('10031982'),('10031983'),('10031984'),('10031985'),('10031986'),('10031987'),('10031988'),('10031989'),('10031990'),('10031991'),('10031992'),('10031993'),('10031994'),('10031995'),('100374'),('100375'),('100376'),('100377'),('100378'),('100379'),('100380'),('100381'),('100382'),('100383'),('100384'),('100385'),('100386'),('100387'),('100388'),('100389'),('100390'),('100391'),('100392'),('100393'),('100394'),('100395'),('100396'),('100397'),('100398'),('1004'),('100400'),('100402'),('10041004'),('10041974'),('10041977'),('10041978'),('10041979'),('10041980'),('10041981'),('10041982'),('10041983'),('10041984'),('10041985'),('10041986'),('10041987'),('10041988'),('10041989'),('10041990'),('10041991'),('10041992'),('10041993'),('10041994'),('10041995'),('10041996'),('10041997'),('100472'),('100475'),('100476'),('100477'),('100478'),('100479'),('100480'),('100481'),('100482'),('100483'),('100484'),('100485'),('100486'),('100487'),('100488'),('100489'),('100490'),('100491'),('100492'),('100493'),('100494'),('100495'),('100496'),('100497'),('100499'),('1005'),('100500'),('10051005'),('10051976'),('10051977'),('10051978'),('10051979'),('10051980'),('10051981'),('10051982'),('10051983'),('10051984'),('10051985'),('10051986'),('10051987'),('10051988'),('10051989'),('10051990'),('10051991'),('10051992'),('10051993'),('10051994'),('10051995'),('10051996'),('100574'),('100575'),('100576'),('100577'),('100578'),('100579'),('100580'),('100581'),('100582'),('100583'),('100584'),('100585'),('100586'),('100587'),('100588'),('100589'),('100590'),('100591'),('100592'),('100593'),('100594'),('100595'),('100596'),('100599'),('1006'),('100600'),('100606'),('10061006'),('10061976'),('10061977'),('10061978'),('10061979'),('10061980'),('10061981'),('10061982'),('10061983'),('10061984'),('10061985'),('10061986'),('10061987'),('10061988'),('10061989'),('10061990'),('10061991'),('10061992'),('10061993'),('10061994'),('10061995'),('10061996'),('100674'),('100675'),('100676'),('100677'),('100678'),('100679'),('100680'),('100681'),('100682'),('100683'),('100684'),('100685'),('100686'),('100687'),('100688'),('100689'),('100690'),('100691'),('100692'),('100693'),('100694'),('100695'),('100696'),('1007'),('100700'),('10071007'),('10071977'),('10071978'),('10071979'),('10071980'),('10071981'),('10071982'),('10071983'),('10071984'),('10071985'),('10071986'),('10071987'),('10071988'),('10071989'),('10071990'),('10071991'),('10071992'),('10071993'),('10071994'),('10071995'),('10071996'),('100772'),('100775'),('100776'),('100777'),('100778'),('100779'),('100780'),('100781'),('100782'),('100783'),('100784'),('100785'),('100786'),('100787'),('100788'),('100789'),('100790'),('100791'),('100792'),('100793'),('100794'),('100795'),('100796'),('1008'),('100800'),('100808'),('10081008'),('10081975'),('10081976'),('10081977'),('10081978'),('10081979'),('10081980'),('10081981'),('10081982'),('10081983'),('10081984'),('10081985'),('10081986'),('10081987'),('10081988'),('10081989'),('10081990'),('10081991'),('10081992'),('10081993'),('10081994'),('10081995'),('100827092'),('100866'),('100871'),('100874'),('100875'),('100876'),('100877'),('100878'),('100879'),('100880'),('100881'),('100882'),('100883'),('100884'),('100885'),('100886'),('100887'),('100888'),('100889'),('100890'),('100891'),('100892'),('100893'),('100894'),('100895'),('100896'),('1009'),('100900'),('100908'),('10091009'),('10091977'),('10091978'),('10091979'),('10091980'),('10091981'),('10091982'),('10091983'),('10091984'),('10091985'),('10091986'),('10091987'),('10091988'),('10091989'),('10091990'),('10091991'),('10091992'),('10091993'),('10091994'),('10091995'),('100975'),('100976'),('100977'),('100978'),('100979'),('100980'),('100981'),('100982'),('100983'),('100984'),('100985'),('100986'),('100987'),('100988'),('100989'),('100990'),('100991'),('100992'),('100993'),('100994'),('100995'),('100996'),('100999'),('100dollars'),('100grand'),('100million'),('100percent'),('100proof'),('100years'),('101'),('1010'),('101000'),('101001'),('101002'),('101003'),('101004'),('101005'),('101006'),('101007'),('101008'),('101009'),('10101'),('101010'),('1010101'),('10101010'),('1010101010'),('101010a'),('101011'),('1010110'),('101012'),('10101968'),('10101970'),('10101972'),('10101973'),('10101974'),('10101975'),('10101976'),('10101977'),('10101978'),('10101979'),('10101980'),('10101981'),('10101982'),('10101983'),('10101984'),('10101985'),('10101986'),('10101987'),('10101988'),('10101989'),('10101990'),('10101991'),('10101992'),('10101993'),('10101994'),('10101995'),('10101996'),('10101997'),('10101998'),('101020'),('10102000'),('10102008'),('10102010'),('10102020'),('1010220'),('101055'),('101060'),('101064'),('101066'),('101067'),('101068'),('101069'),('101070'),('101071'),('101072'),('101073'),('101074'),('101075'),('101076'),('101077'),('101078'),('101079'),('101080'),('101081'),('101082'),('101083'),('101084'),('101085'),('101086'),('101087'),('101088'),('101089'),('101090'),('101091'),('101092'),('101093'),('101094'),('101095'),('101096'),('101097'),('101098'),('101099'),('1011'),('101100'),('101101'),('101102'),('101103'),('101107'),('101108'),('101110'),('10111011'),('101111'),('1011111'),('101112'),('10111213'),('10111975'),('10111976'),('10111977'),('10111978'),('10111979'),('10111980'),('10111981'),('10111982'),('10111983'),('10111984'),('10111985'),('10111986'),('10111987'),('10111988'),('10111989'),('10111990'),('10111991'),('10111992'),('10111993'),('10111994'),('10111995'),('101169'),('101171'),('101172'),('101173'),('101174'),('101175'),('101176'),('101177'),('101178'),('101179'),('101180'),('101181'),('101182'),('101183'),('101184'),('101185'),('101186'),('101187'),('101188'),('101189'),('101190'),('101191'),('101192'),('101193'),('101194'),('101195'),('101196'),('101197'),('101198'),('101199'),('1012'),('101200'),('101201'),('101202'),('101203'),('101204'),('101205'),('101206'),('101207'),('101208'),('101210'),('10121012'),('101213'),('101214'),('10121972'),('10121974'),('10121975'),('10121976'),('10121977'),('10121978'),('10121979'),('10121980'),('10121981'),('10121982'),('10121983'),('10121984'),('10121985'),('10121986'),('10121987'),('10121988'),('10121989'),('10121990'),('10121991'),('10121992'),('10121993'),('10121994'),('10121995'),('10121996'),('10121997'),('101268'),('101269'),('101270'),('101271'),('101272'),('101273'),('101274'),('101275'),('101276'),('101277'),('101278'),('101279'),('101280'),('101281'),('101282'),('101283'),('101284'),('101285'),('101286'),('101287'),('101288'),('101289'),('101290'),('101291'),('101292'),('101293'),('101294'),('101295'),('101296'),('101297'),('101298'),('101299'),('1013'),('10131013'),('1014'),('101400'),('10141014'),('1015'),('101510'),('10151015'),('101520'),('1016'),('10161016'),('1017'),('10171017'),('1018'),('10181018'),('1019'),('10191019'),('101968'),('101970'),('101972'),('101973'),('101974'),('101975'),('101976'),('101977'),('101978'),('101979'),('101980'),('101981'),('101982'),('101983'),('101984'),('101985'),('101986'),('101987'),('101988'),('101989'),('101990'),('101991'),('101992'),('101993'),('101994'),('101995'),('101996'),('101998'),('102'),('1020'),('102000'),('102001'),('10200718'),('102008'),('102010'),('10201020'),('10203'),('102030'),('102030102030'),('1020304'),('10203040'),('1020304050'),('102030405060'),('102030405060708090'),('102030a'),('102030q'),('102080'),('102088'),('102090'),('1021'),('102100'),('102102'),('102102102'),('102103'),('10211021'),('1022'),('102201'),('10221022'),('102288'),('1023'),('102300'),('10231023'),('102345'),('1024'),('102400'),('10241024'),('102489'),('102498'),('1025'),('102500'),('10251025'),('102578'),('102589'),('1026'),('10261026'),('1027'),('10271027'),('1028'),('102800'),('10281028'),('1029'),('10291029'),('102938'),('10293847'),('1029384756'),('1029384756a'),('1029384756q'),('103'),('1030'),('10301030'),('1031'),('103103'),('10311031'),('103185'),('103196'),('104'),('1040'),('10401040'),('104104'),('105'),('105105'),('1052'),('10577'),('106106'),('1066'),('10661066'),('107107'),('10711071'),('108'),('1080'),('108108'),('109'),('109109'),('10971199'),('109876'),('1098765432'),('10987654321'),('10fingers'),('10inches'),('10million'),('10pace'),('10point'),('10qpalzm'),('10sne1'),('10toes'),('10years'),('10z10z'),('11'),('11-05-1992'),('110'),('1100'),('110000'),('110001'),('110002'),('110003'),('110005'),('110006'),('110007'),('110008'),('110009'),('110010'),('11001001'),('1100101'),('110011'),('11001100'),('110014'),('110015'),('110016'),('110017'),('110018'),('110019'),('110020'),('110021'),('110022'),('110023'),('110024'),('110025'),('110026'),('110027'),('110028'),('110029'),('110030'),('110031'),('110032'),('110033'),('110034'),('110035'),('110037'),('110043'),('110044'),('110045'),('110046'),('110048'),('110049'),('110051'),('110052'),('110053'),('110054'),('110055'),('110057'),('110058'),('110059'),('110060'),('110062'),('110063'),('110064'),('110065'),('110066'),('110067'),('110070'),('110075'),('110076'),('110077'),('110085'),('110087'),('110088'),('110091'),('110092'),('110095'),('110096'),('1101'),('110100'),('110101'),('110102'),('110105'),('110108'),('110110'),('110110110'),('110110jp'),('110111'),('11011101'),('110112'),('110119'),('110119120'),('11011977'),('11011978'),('11011979'),('11011980'),('11011981'),('11011982'),('11011983'),('11011984'),('11011985'),('11011986'),('11011987'),('11011988'),('11011989'),('11011990'),('11011991'),('11011992'),('11011993'),('11011994'),('11011995'),('11011996'),('110120'),('110120119'),('110120130'),('110176'),('110177'),('110178'),('110179'),('110180'),('110181'),('110182'),('110183'),('110184'),('110185'),('110186'),('110187'),('110188'),('110189'),('110190'),('110191'),('110192'),('110193'),('110194'),('110195'),('110196'),('110197'),('1102'),('110200'),('110202'),('110206'),('11021102'),('11021977'),('11021978'),('11021979'),('11021980'),('11021981'),('11021982'),('11021983'),('11021984'),('11021985'),('11021986'),('11021987'),('11021988'),('11021989'),('11021990'),('11021991'),('11021992'),('11021993'),('11021994'),('11021995'),('11021996'),('11021997'),('11021998'),('110220'),('110274'),('110275'),('110276'),('110277'),('110278'),('110279'),('110280'),('110281'),('110282'),('110283'),('110284'),('110285'),('110286'),('110287'),('110288'),('110289'),('110290'),('110291'),('110292'),('110293'),('110294'),('110295'),('110296'),('110297'),('110298'),('110299'),('1103'),('110300'),('110303'),('110309'),('11031103'),('11031975'),('11031977'),('11031978'),('11031979'),('11031980'),('11031981'),('11031982'),('11031983'),('11031984'),('11031985'),('11031986'),('11031987'),('11031988'),('11031989'),('11031990'),('11031991'),('11031992'),('11031993'),('11031994'),('11031995'),('11031996'),('11031997'),('110331rahili'),('110372'),('110374'),('110375'),('110376'),('110377'),('110378'),('110379'),('110380'),('110381'),('110382'),('110383'),('110384'),('110385'),('110386'),('110387'),('110388'),('110389'),('110390'),('110391'),('110392'),('110393'),('110394'),('110395'),('110396'),('110397'),('1104'),('110400'),('11041104'),('11041976'),('11041978'),('11041979'),('11041980'),('11041981'),('11041982'),('11041983'),('11041984'),('11041985'),('11041986'),('11041987'),('11041988'),('11041989'),('11041990'),('11041991'),('11041992'),('11041993'),('11041994'),('11041995'),('11041996'),('11041997'),('110472'),('110474'),('110475'),('110476'),('110477'),('110478'),('110479'),('110480'),('110481'),('110482'),('110483'),('110484'),('110485'),('110486'),('110487'),('110488'),('110489'),('110490'),('110491'),('110492'),('110493'),('110494'),('110495'),('110496'),('110497'),('110498'),('1105'),('110505'),('110506'),('11051105'),('11051976'),('11051977'),('11051978'),('11051979'),('11051980'),('11051981'),('11051982'),('11051983'),('11051984'),('11051985'),('11051986'),('11051987'),('11051988'),('11051989'),('11051990'),('11051991'),('11051992'),('11051993'),('11051994'),('11051995'),('11051996'),('110573'),('110574'),('110575'),('110576'),('110577'),('110578'),('110579'),('110580'),('110581'),('110582'),('110583'),('110584'),('110585'),('110586'),('110587'),('110588'),('110589'),('110590'),('110591'),('110592'),('110593'),('110594'),('110595'),('110596'),('110597'),('110598'),('110599'),('1106'),('11061106'),('11061976'),('11061978'),('11061979'),('11061980'),('11061981'),('11061982'),('11061983'),('11061984'),('11061985'),('11061986'),('11061987'),('11061988'),('11061989'),('11061990'),('11061991'),('11061992'),('11061993'),('11061994'),('11061995'),('11061996'),('110673'),('110674'),('110675'),('110676'),('110677'),('110678'),('1106782'),('110679'),('110680'),('110681'),('110682'),('110683'),('110684'),('110685'),('110686'),('110687'),('110688'),('110689'),('110690'),('110691'),('110692'),('110693'),('110694'),('110695'),('110696'),('110697'),('110698'),('110699'),('1107'),('110707'),('110708'),('11071107'),('11071977'),('11071978'),('11071979'),('11071980'),('11071981'),('11071982'),('11071983'),('11071984'),('11071985'),('11071986'),('11071987'),('11071988'),('11071989'),('11071990'),('11071991'),('11071992'),('11071993'),('11071994'),('11071995'),('11071996'),('110775'),('110776'),('110777'),('110778'),('110779'),('110780'),('110781'),('110782'),('110783'),('110784'),('110785'),('110786'),('110787'),('110788'),('110789'),('110790'),('110791'),('110792'),('110793'),('110794'),('110795'),('110796'),('110797'),('110798'),('1108'),('110806'),('110807'),('110808'),('11081108'),('11081976'),('11081977'),('11081978'),('11081979'),('11081980'),('11081981'),('11081982'),('11081983'),('11081984'),('11081985'),('11081986'),('11081987'),('11081988'),('11081989'),('11081990'),('11081991'),('11081992'),('11081993'),('11081994'),('11081995'),('110872'),('110875'),('110876'),('110877'),('110878'),('110879'),('110880'),('110881'),('110882'),('110883'),('110884'),('110885'),('110886'),('110887'),('110888'),('110889'),('110890'),('110891'),('110892'),('110893'),('110894'),('110895'),('110896'),('110897'),('110898'),('110899'),('1109'),('110901'),('110911'),('11091109'),('11091978'),('11091979'),('11091980'),('11091981'),('11091982'),('11091983'),('11091984'),('11091985'),('11091986'),('11091987'),('11091988'),('11091989'),('11091990'),('11091991'),('11091992'),('11091993'),('11091994'),('11091995'),('11091996'),('11092001'),('110973'),('110974'),('110975'),('110976'),('110977'),('110978'),('110979'),('110980'),('110981'),('110982'),('110983'),('110984'),('110985'),('110986'),('110987'),('110988'),('110989'),('110990'),('110991'),('110992'),('110993'),('110994'),('110995'),('110996'),('110999'),('111'),('1110'),('111000'),('111007'),('111008'),('11101976'),('11101978'),('11101979'),('11101980'),('11101981'),('11101982'),('11101983'),('11101984'),('11101985'),('11101986'),('11101987'),('11101988'),('11101989'),('11101990'),('11101991'),('11101992'),('11101993'),('11101994'),('11101995'),('111075'),('111076'),('111077'),('111078'),('111079'),('111080'),('111081'),('111082'),('111083'),('111084'),('111085'),('111086'),('111087'),('111088'),('111089'),('111090'),('111091'),('111092'),('111093'),('111094'),('111095'),('111096'),('1111'),('111100'),('11110000'),('111105'),('111106'),('111108'),('11111'),('111110'),('111111'),('1111111'),('11111111'),('111111111'),('1111111111'),('11111111111'),('111111111111'),('1111111111111'),('11111111111111'),('111111111111111'),('11111111111111111111'),('1111111111a'),('1111111111q'),('111111111a'),('111111111q'),('11111111a'),('11111111q'),('11111112'),('11111118'),('1111111a'),('1111111q'),('1111112'),('1111114'),('1111117'),('111111a'),('111111aa'),('111111aaa'),('111111b'),('111111c'),('111111d'),('111111e'),('111111f'),('111111g'),('111111j'),('111111k'),('111111l'),('111111m'),('111111n'),('111111p'),('111111prof_root2.sql.txt:,'),('111111prof_root3.sql.txt:,'),('111111q'),('111111qq'),('111111r'),('111111s'),('111111t'),('111111v'),('111111w'),('111111z'),('111112'),('1111122222'),('111113'),('111115'),('111116'),('111119'),('11111974'),('11111975'),('11111976'),('11111977'),('11111978'),('11111979'),('11111980'),('11111981'),('11111982'),('11111983'),('11111984'),('11111985'),('11111986'),('11111987'),('11111988'),('11111989'),('11111990'),('11111991'),('11111992'),('11111993'),('11111994'),('11111995'),('11111a'),('11111aaaaa'),('11111b'),('11111c'),('11111d'),('11111j'),('11111k'),('11111l'),('11111m'),('11111p'),('11111q'),('11111qqqqq'),('11111r'),('11111s'),('11111w'),('11111z'),('11112'),('11112011'),('111122'),('11112222'),('111122223333'),('111123'),('11113333'),('11114444'),('111156'),('111166'),('111169'),('111170'),('111171'),('111174'),('111175'),('111176'),('111177'),('111178'),('111179'),('111180'),('111181'),('111182'),('111183'),('111184'),('111185'),('111186'),('111187'),('111188'),('111189'),('111190'),('111191'),('111192'),('111193'),('111194'),('111195'),('111196'),('111197'),('111198'),('111199'),('11119999'),('1111aa'),('1111aaaa'),('1111qq'),('1111qqqq'),('1112'),('111211'),('11121112'),('111213'),('11121314'),('1112131415'),('11121974'),('11121975'),('11121976'),('11121977'),('11121978'),('11121979'),('11121980'),('11121981'),('11121982'),('11121983'),('11121984'),('11121985'),('11121986'),('11121987'),('11121988'),('11121989'),('11121990'),('11121991'),('11121992'),('11121993'),('11121994'),('11121995'),('11121996'),('11121997'),('11122'),('111222'),('1112223'),('11122233'),('111222333'),('111222333444'),('111222333444555'),('111222333a'),('111222333q'),('111222a'),('111222q'),('111222tianya'),('111223'),('111234'),('111274'),('111275'),('111276'),('111277'),('111278'),('111279'),('111280'),('111281'),('111282'),('111283'),('111284'),('111285'),('111286'),('111287'),('111288'),('111289'),('111290'),('111291'),('111292'),('111293'),('111294'),('111295'),('111296'),('111297'),('111298'),('111299'),('1113'),('11131113'),('111333'),('1114'),('111444'),('1115'),('111555'),('111555999'),('1116'),('111666'),('111680'),('1117'),('111777'),('1118'),('111888'),('1119'),('111963'),('111964'),('111965'),('111966'),('111967'),('111968'),('111969'),('111970'),('111971'),('111972'),('111973'),('111974'),('111975'),('111976'),('111977'),('111978'),('111979'),('111980'),('111981'),('111982'),('111983'),('111984'),('111985'),('111986'),('111987'),('111988'),('111989'),('111990'),('111991'),('111992'),('111993'),('111994'),('111995'),('111996'),('111997'),('111998'),('111999'),('111a111'),('111aaa'),('111qqq'),('111qqq111'),('111www'),('111zabavina'),('111zzz'),('112'),('1120'),('112000'),('112001'),('112002'),('112003'),('112004'),('112005'),('112006'),('112007'),('112008'),('112009'),('112011'),('11201120'),('112020'),('1121'),('112111'),('11211121'),('112112'),('112112112'),('112113'),('112123'),('112131'),('1122'),('112200'),('112211'),('11221122'),('112212'),('11223'),('112233'),('1122330'),('11223300'),('1122331'),('11223311'),('112233112233'),('112233123'),('1122333'),('1122334'),('11223343'),('11223344'),('112233445'),('1122334455'),('112233445566'),('11223344556677'),('1122334455667788'),('112233445566778899'),('11223344556677889900'),('11223344a'),('11223344q'),('11223345'),('11223355'),('11223366'),('112233a'),('112233aa'),('112233d'),('112233m'),('112233q'),('112233qq'),('112233s'),('112233z'),('112234'),('11223456'),('112244'),('112255'),('112266'),('112277'),('112288'),('112299'),('1122aa'),('1122qq'),('1122qqww'),('1123'),('112300'),('112311'),('11231123'),('11234'),('112345'),('1123456'),('1123456789'),('11235'),('112358'),('11235813'),('1123581321'),('112358132134'),('112369'),('1124'),('11241124'),('1125'),('112500'),('112511'),('11251125'),('112567'),('1126'),('11261126'),('1127'),('11271127'),('1128'),('112800'),('11281128'),('1129'),('112911'),('11291129'),('113'),('1130'),('11301130'),('1131'),('113113'),('113114'),('1133'),('113311'),('11331133'),('113322'),('113355'),('11335577'),('1133557799'),('1134'),('11341134'),('113456'),('1138'),('114'),('114114'),('1144'),('114411'),('11441144'),('114455'),('114477'),('1147'),('115'),('115115'),('1155'),('115511'),('11551155'),('115533'),('115569'),('115599'),('116'),('116116'),('116688'),('117'),('117117'),('1177'),('117711'),('11794591'),('118118'),('118218'),('1187'),('118720'),('1188'),('118811'),('119'),('119110'),('119119'),('1192'),('11921192'),('1192296'),('11922960'),('119872653'),('1199'),('119900'),('119911'),('11991199'),('119955'),('11aa11'),('11aa22bb'),('11bravo'),('11eleven'),('11love'),('11november'),('11qq11'),('11qq11qq'),('11qq22ww'),('11qqaazz'),('11vote'),('12'),('120'),('1200'),('120000'),('120012'),('12001200'),('1200nerds'),('1201'),('120100'),('120101'),('120102'),('120107'),('120108'),('12011201'),('12011976'),('12011977'),('12011978'),('12011979'),('12011980'),('12011981'),('12011982'),('12011983'),('12011984'),('12011985'),('12011986'),('12011987'),('12011988'),('12011989'),('12011990'),('12011991'),('12011992'),('12011993'),('12011994'),('12011995'),('12011996'),('120120'),('120120120'),('120173'),('120176'),('120177'),('120178'),('120179'),('120180'),('120181'),('120182'),('120183'),('120184'),('120185'),('120186'),('120187'),('120188'),('120189'),('120190'),('120191'),('120192'),('120193'),('120194'),('120195'),('120196'),('120197'),('120198'),('120199'),('1202'),('120200'),('120202'),('120203'),('120208'),('12021202'),('12021974'),('12021975'),('12021976'),('12021977'),('12021978'),('12021979'),('12021980'),('12021981'),('12021982'),('12021983'),('12021984'),('12021985'),('12021986'),('12021987'),('12021988'),('12021989'),('12021990'),('12021991'),('12021992'),('12021993'),('12021994'),('12021995'),('12021996'),('12021997'),('120272'),('120274'),('120275'),('120276'),('120277'),('120278'),('120279'),('120280'),('120281'),('120282'),('120283'),('120284'),('120285'),('120286'),('120287'),('120288'),('120289'),('120290'),('120291'),('120292'),('120293'),('120294'),('120295'),('120296'),('120297'),('120298'),('1203'),('120300'),('120303'),('120304'),('120305'),('12031203'),('12031976'),('12031977'),('12031978'),('12031979'),('12031980'),('12031981'),('12031982'),('12031983'),('12031984'),('12031985'),('12031986'),('12031987'),('12031988'),('12031989'),('12031990'),('12031991'),('12031992'),('12031993'),('12031994'),('12031995'),('12031996'),('12031997'),('120369'),('120372'),('120374'),('120375'),('120376'),('120377'),('120378'),('120379'),('120380'),('120381'),('120382'),('120383'),('120384'),('120385'),('120386'),('120387'),('120388'),('120389'),('120390'),('120391'),('120392'),('120393'),('120394'),('120395'),('120396'),('120397'),('120398'),('120399'),('1204'),('120400'),('120404'),('120408'),('12041204'),('12041961'),('12041976'),('12041977'),('12041978'),('12041979'),('12041980'),('12041981'),('12041982'),('12041983'),('12041984'),('12041985'),('12041986'),('12041987'),('12041988'),('12041989'),('12041990'),('12041991'),('12041992'),('12041993'),('12041994'),('12041995'),('12041996'),('120469'),('120470'),('120471'),('120472'),('120473'),('120474'),('120475'),('120476'),('120477'),('120478'),('120479'),('120480'),('120481'),('120482'),('120483'),('120484'),('120485'),('120486'),('120487'),('120488'),('120489'),('120490'),('120491'),('120492'),('120493'),('120494'),('120495'),('120496'),('120497'),('120498'),('120499'),('1205'),('120500'),('120505'),('120506'),('120507'),('120508'),('12051205'),('12051976'),('12051977'),('12051978'),('12051979'),('12051980'),('12051981'),('12051982'),('12051983'),('12051984'),('12051985'),('12051986'),('12051987'),('12051988'),('12051989'),('12051990'),('12051991'),('12051992'),('12051993'),('12051994'),('12051995'),('12051996'),('12051997'),('120569'),('120571'),('120572'),('120573'),('120574'),('120575'),('120576'),('120577'),('120578'),('120579'),('120580'),('120581'),('120582'),('120583'),('120584'),('120585'),('120586'),('120587'),('120588'),('120589'),('120590'),('120591'),('120592'),('120593'),('120594'),('120595'),('120596'),('120597'),('120598'),('120599'),('1206'),('120600'),('120603'),('120604'),('120606'),('120607'),('120608'),('120609'),('12061206'),('12061976'),('12061977'),('12061978'),('12061979'),('12061980'),('12061981'),('12061982'),('12061983'),('12061984'),('12061985'),('12061986'),('12061987'),('12061988'),('12061989'),('12061990'),('12061991'),('12061992'),('12061993'),('12061994'),('12061995'),('12061996'),('12061997'),('120670'),('120671'),('120672'),('120673'),('120674'),('120675'),('120676'),('120677'),('120678'),('120679'),('120680'),('120681'),('120682'),('120683'),('120684'),('120685'),('120686'),('120687'),('120688'),('120689'),('120690'),('120691'),('120692'),('120693'),('120694'),('120695'),('120696'),('120697'),('120698'),('120699'),('1207'),('120700'),('120702'),('120707'),('120708'),('12071207'),('12071976'),('12071977'),('12071978'),('12071979'),('12071980'),('12071981'),('12071982'),('12071983'),('12071984'),('12071985'),('12071986'),('12071987'),('12071988'),('12071989'),('12071990'),('12071991'),('12071992'),('12071993'),('12071994'),('12071995'),('12071996'),('120772'),('120774'),('120775'),('120776'),('120777'),('120778'),('120779'),('120780'),('120781'),('120782'),('120783'),('120784'),('120785'),('120786'),('120787'),('120788'),('120789'),('120790'),('120791'),('120792'),('120793'),('120794'),('120795'),('120796'),('120797'),('120798'),('1208'),('120800'),('120805'),('120806'),('120807'),('120808'),('120809'),('12081208'),('12081975'),('12081976'),('12081977'),('12081978'),('12081979'),('12081980'),('12081981'),('12081982'),('12081983'),('12081984'),('12081985'),('12081986'),('12081987'),('12081988'),('12081989'),('12081990'),('12081991'),('12081992'),('12081993'),('12081994'),('12081995'),('12081996'),('120869'),('120871'),('120872'),('120873'),('120874'),('120875'),('120876'),('120877'),('120878'),('120879'),('120880'),('120881'),('120882'),('120883'),('120884'),('120885'),('120886'),('120887'),('120888'),('120889'),('120890'),('120891'),('120892'),('120893'),('120894'),('120895'),('120896'),('120897'),('120898'),('120899'),('1209'),('120900'),('120906'),('120907'),('120908'),('120909'),('12091209'),('12091976'),('12091977'),('12091978'),('12091979'),('12091980'),('12091981'),('12091982'),('12091983'),('12091984'),('12091985'),('12091986'),('12091987'),('12091988'),('12091989'),('12091990'),('12091991'),('12091992'),('12091993'),('12091994'),('12091995'),('12091996'),('120974'),('120975'),('120976'),('120977'),('120978'),('120979'),('120980'),('120981'),('120982'),('120983'),('120984'),('120985'),('120986'),('120987'),('120988'),('120989'),('120990'),('120991'),('120992'),('120993'),('120994'),('120995'),('120996'),('120997'),('120998'),('120n2X'),('121'),('1210'),('121000'),('121001'),('121002'),('121003'),('121004'),('121005'),('121006'),('121007'),('121008'),('121009'),('121010'),('121012'),('12101210'),('12101961'),('12101974'),('12101975'),('12101976'),('12101977'),('12101978'),('12101979'),('12101980'),('12101981'),('12101982'),('12101983'),('12101984'),('12101985'),('12101986'),('12101987'),('12101988'),('12101989'),('12101990'),('12101991'),('12101992'),('12101993'),('12101994'),('12101995'),('12101996'),('121068'),('121069'),('121070'),('121071'),('121072'),('121073'),('121074'),('121075'),('121076'),('121077'),('121078'),('121079'),('121080'),('121081'),('121082'),('121083'),('121084'),('121085'),('121086'),('121087'),('121088'),('121089'),('121090'),('121091'),('121092'),('121093'),('121094'),('121095'),('121096'),('121097'),('121098'),('121099'),('1211'),('121100'),('121102'),('121106'),('121108'),('121110'),('1211109032'),('121111'),('12111211'),('1211123a'),('12111977'),('12111978'),('12111979'),('12111980'),('12111981'),('12111982'),('12111983'),('12111984'),('12111985'),('12111986'),('12111987'),('12111988'),('12111989'),('12111990'),('12111991'),('12111992'),('12111993'),('12111994'),('12111995'),('121121'),('121170'),('121171'),('121172'),('121174'),('121175'),('121176'),('121177'),('121178'),('121179'),('121180'),('121181'),('121182'),('121183'),('121184'),('121185'),('121186'),('121187'),('121188'),('121189'),('121190'),('121191'),('121192'),('121193'),('121194'),('121195'),('121196'),('121197'),('121198'),('121199'),('1212'),('121200'),('121201'),('121202'),('121203'),('121204'),('121205'),('121206'),('121207'),('121208'),('121209'),('12121'),('121210'),('121211'),('121212'),('1212121'),('12121212'),('1212121212'),('121212121212'),('12121212a'),('1212123'),('121212a'),('121212m'),('121212q'),('121212qw'),('121212s'),('121212w'),('121212z'),('121213'),('12121313'),('121214'),('12121970'),('12121972'),('12121973'),('12121974'),('12121975'),('12121976'),('12121977'),('12121978'),('12121979'),('12121980'),('12121981'),('12121982'),('12121983'),('12121984'),('12121985'),('12121986'),('12121987'),('12121988'),('12121989'),('12121990'),('12121991'),('12121992'),('12121993'),('12121994'),('12121995'),('12121996'),('12121997'),('12122000'),('12122008'),('12122012'),('121221'),('121223'),('121224'),('12123'),('1212312121'),('121232'),('121233'),('121234'),('12123434'),('1212345'),('12123456'),('121245'),('121255'),('121256'),('121261'),('121262'),('121263'),('121264'),('121265'),('121266'),('121267'),('121268'),('121269'),('121270'),('121271'),('121272'),('121273'),('121274'),('121275'),('121276'),('121277'),('121278'),('121279'),('121280'),('121281'),('121282'),('121283'),('121284'),('121285'),('121286'),('121287'),('121288'),('121289'),('121290'),('121291'),('121292'),('121293'),('121294'),('121295'),('121296'),('121297'),('121298'),('121299'),('1212aa'),('1212qq'),('1212qw'),('1212qwqw'),('1213'),('121300'),('121303'),('121312'),('12131213'),('121314'),('12131415'),('1213141516'),('1213141516171819'),('121314a'),('121314z'),('121315'),('121316'),('121345'),('1213456'),('121388'),('1214'),('121412'),('12141214'),('121415'),('121416'),('121484'),('1215'),('121500'),('121512'),('12151215'),('121518'),('1215225'),('12152325'),('121588'),('1216'),('121600'),('12161216'),('1217'),('12171217'),('1218'),('121800'),('12181218'),('1219'),('12191219'),('121964'),('121965'),('121966'),('121967'),('121968'),('121969'),('121970'),('121971'),('121972'),('121973'),('121974'),('121975'),('121976'),('121977'),('121978'),('121979'),('121980'),('121981'),('121982'),('121983'),('121984'),('121985'),('121986'),('121987'),('121988'),('121989'),('121990'),('121991'),('121992'),('121993'),('121994'),('121995'),('121996'),('121997'),('121998'),('121999'),('122'),('1220'),('122000'),('122001'),('122002'),('122003'),('122005'),('122007'),('122008'),('122009'),('12201220'),('122015'),('122016'),('122017'),('1221'),('122100'),('122112'),('12211221'),('122122'),('122123'),('122133'),('12213443'),('122188'),('1222'),('122221'),('122222'),('1223'),('12231223'),('122333'),('1223334444'),('122333444455555'),('122334'),('12233445'),('122345'),('1223456'),('1224'),('122412'),('12241224'),('122436'),('122448'),('1225'),('122500'),('12251225'),('1226'),('12261226'),('1227'),('12271227'),('1228'),('122800'),('12280202'),('122805'),('12281228'),('1229'),('12291229'),('122987'),('123'),('123!'),('123!@#'),('123-123'),('123-456'),('123...'),('123.123'),('123.456'),('123.abc'),('123.com'),('1230'),('12300'),('123000'),('123001'),('12300123'),('123007'),('123012'),('1230123'),('12301230'),('123012301230'),('1230321'),('123045'),('1230456'),('12304560'),('123056'),('123098'),('123098a'),('123098q'),('1231'),('123100'),('123103'),('123111'),('12311231'),('12312'),('123121'),('123123'),('1231230'),('12312300'),('1231231'),('12312312'),('123123123'),('1231231230'),('1231231231'),('123123123123'),('123123123123123'),('1231231234'),('123123123a'),('123123123q'),('123123123z'),('1231233'),('123123321'),('1231234'),('12312345'),('123123456'),('123123456456'),('1231235'),('123123a'),('123123aa'),('123123aaa'),('123123abc'),('123123as'),('123123asd'),('123123b'),('123123c'),('123123d'),('123123e'),('123123f'),('123123g'),('123123j'),('123123k'),('123123l'),('123123m'),('123123n'),('123123p'),('123123q'),('123123qq'),('123123qw'),('123123qwe'),('123123qweqwe'),('123123r'),('123123s'),('123123t'),('123123w'),('123123z'),('123123zz'),('123124'),('123125'),('123132'),('123147'),('123156'),('123159'),('123181'),('1232'),('12321'),('123210'),('123211'),('123212'),('1232123'),('12321232'),('123212321'),('123213'),('123231'),('1232323q'),('123234'),('123234345'),('123258'),('1232580'),('123258789'),('1233'),('123312'),('12331233'),('12332'),('123321'),('1233210'),('12332100'),('1233211'),('12332112'),('123321123'),('123321123321'),('1233211234567'),('1233214'),('12332145'),('123321456'),('123321456654'),('1233215'),('123321a'),('123321aa'),('123321abc'),('123321as'),('123321asd'),('123321b'),('123321d'),('123321e'),('123321fvfv'),('123321k'),('123321l'),('123321m'),('123321q'),('123321qaz'),('123321qq'),('123321qw'),('123321qwe'),('123321qweewq'),('123321r'),('123321s'),('123321v'),('123321w'),('123321z'),('123321zxc'),('1233321'),('123333'),('123344'),('123345'),('1233456'),('123369'),('1234'),('1234!'),('1234!@#$'),('12340'),('123400'),('12340000'),('123401'),('12340987'),('12341'),('123411'),('123412'),('1234123'),('12341234'),('123412341234'),('123412345'),('12341234a'),('12341234q'),('1234126'),('12342234'),('123423'),('123432'),('1234321'),('1234321a'),('1234321q'),('123434'),('12343412'),('12344'),('123443'),('1234432'),('12344321'),('123443211'),('12344321a'),('12344321q'),('123444'),('123445'),('1234456'),('12345'),('12345!'),('12345.'),('123450'),('1234500'),('1234509876'),('123451'),('1234512'),('12345123'),('123451234'),('1234512345'),('123451234512345'),('123452'),('123453'),('123454'),('123454321'),('123454321a'),('123454321q'),('1234545'),('1234546'),('123455'),('1234554321'),('1234554321a'),('1234554321q'),('1234555'),('1234556'),('123456'),('123456!'),('123456*'),('123456**'),('123456+'),('123456-'),('123456.'),('123456..'),('1234560'),('12345600'),('123456000'),('1234561'),('12345610'),('12345611'),('12345612'),('123456123'),('1234561234'),('123456123456'),('1234562'),('123456286'),('1234563'),('123456321'),('123456456'),('1234565'),('12345654'),('12345654321'),('12345656'),('1234566'),('12345665'),('123456654'),('1234566543'),('123456654321'),('12345666'),('1234567'),('12345670'),('12345671'),('1234567123'),('12345671234567'),('12345676'),('1234567654321'),('12345677'),('12345677654321'),('123456777'),('12345678'),('123456780'),('1234567809'),('123456781'),('1234567812345678'),('123456787'),('123456788'),('1234567887654321'),('1234567889'),('123456789'),('123456789!'),('123456789*'),('123456789+'),('123456789-'),('123456789.'),('1234567890'),('1234567890-'),('1234567890-='),('1234567890.'),('12345678900'),('123456789000'),('12345678900987654321'),('12345678901'),('123456789012'),('1234567890123'),('123456789012345'),('1234567890123456'),('12345678901234567890'),('12345678909'),('1234567890987654321'),('1234567890a'),('1234567890abc'),('1234567890d'),('1234567890f'),('1234567890k'),('1234567890l'),('1234567890m'),('1234567890o'),('1234567890p'),('1234567890q'),('1234567890qaz'),('1234567890qw'),('1234567890qwe'),('1234567890qwer'),('1234567890qwert'),('1234567890qwerty'),('1234567890qwertyuiop'),('1234567890r'),('1234567890s'),('1234567890v'),('1234567890w'),('1234567890z'),('1234567891'),('12345678910'),('123456789101'),('1234567891011'),('123456789101112'),('12345678910a'),('12345678911'),('12345678912'),('123456789123'),('1234567891234'),('12345678912345'),('123456789123456'),('1234567891234567'),('123456789123456789'),('1234567892'),('1234567895'),('1234567896'),('12345678963'),('1234567897'),('123456789789'),('1234567898'),('12345678987654321'),('1234567899'),('123456789987'),('123456789987654'),('1234567899876543'),('123456789987654321'),('12345678999'),('123456789@'),('123456789a'),('123456789aa'),('123456789aaa'),('123456789ab'),('123456789abc'),('123456789abcd'),('123456789ABCDe'),('123456789as'),('123456789asd'),('123456789asdf'),('123456789az'),('123456789b'),('123456789c'),('123456789d'),('123456789e'),('123456789f'),('123456789g'),('123456789h'),('123456789i'),('123456789j'),('123456789k'),('123456789l'),('123456789lol'),('123456789love'),('123456789m'),('123456789ma'),('123456789n'),('123456789o'),('123456789ok'),('123456789p'),('123456789q'),('123456789qaz'),('123456789qq'),('123456789qqq'),('123456789qw'),('123456789qwe'),('123456789qwer'),('123456789qwert'),('123456789qwerty'),('123456789qwertyuio'),('123456789qwertyuiop'),('123456789r'),('123456789s'),('123456789t'),('123456789u'),('123456789v'),('123456789w'),('123456789x'),('123456789y'),('123456789z'),('123456789zx'),('123456789zxc'),('123456789zxcvbnm'),('123456789zz'),('123456789zzz'),('123456789_'),('123456789�'),('12345678a'),('12345678aa'),('12345678ab'),('12345678abc'),('12345678as'),('12345678b'),('12345678bj'),('12345678c'),('12345678d'),('12345678e'),('12345678f'),('12345678g'),('12345678h'),('12345678i'),('12345678j'),('12345678k'),('12345678l'),('12345678m'),('12345678n'),('12345678o'),('12345678p'),('12345678q'),('12345678qw'),('12345678qwe'),('12345678qwertyui'),('12345678r'),('12345678s'),('12345678t'),('12345678u'),('12345678v'),('12345678w'),('12345678x'),('12345678y'),('12345678z'),('12345679'),('123456798'),('1234567a'),('1234567aa'),('1234567ab'),('1234567abc'),('1234567as'),('1234567asd'),('1234567b'),('1234567c'),('1234567d'),('1234567e'),('1234567f'),('1234567g'),('1234567h'),('1234567i'),('1234567j'),('1234567k'),('1234567l'),('1234567m'),('1234567n'),('1234567o'),('1234567p'),('1234567q'),('1234567Qq'),('1234567qw'),('1234567qwe'),('1234567qwerty'),('1234567qwertyu'),('1234567r'),('1234567s'),('1234567t'),('1234567u'),('1234567v'),('1234567w'),('1234567x'),('1234567y'),('1234567z'),('1234568'),('123456852'),('12345687'),('12345688'),('12345689'),('1234569'),('12345698'),('123456987'),('12345699'),('123456:'),('123456@'),('123456a'),('123456aa'),('123456aaa'),('123456ab'),('123456abc'),('123456abcd'),('123456abcdef'),('123456ad'),('123456al'),('123456am'),('123456as'),('123456asd'),('123456asdf'),('123456asdfgh'),('123456ass'),('123456az'),('123456b'),('123456bb'),('123456c'),('123456cc'),('123456d'),('123456da'),('123456dd'),('123456dj'),('123456dm'),('123456e'),('123456er'),('123456f'),('123456ff'),('123456g'),('123456gg'),('123456gh'),('123456go'),('123456h'),('123456hh'),('123456hi'),('123456i'),('123456j'),('123456jb'),('123456jc'),('123456jj'),('123456jk'),('123456jr'),('123456k'),('123456kk'),('123456kl'),('123456l'),('123456ll'),('123456lol'),('123456love'),('123456m'),('123456ma'),('123456mama'),('123456me'),('123456mm'),('123456mn'),('123456ms'),('123456n'),('123456o'),('123456ok'),('123456p'),('123456pa'),('123456po'),('123456pp'),('123456prof_root2.sql.txt:,'),('123456prof_root3.sql.txt:,'),('123456q'),('123456qa'),('123456qaz'),('123456qq'),('123456qqq'),('123456qw'),('123456qwe'),('123456qwer'),('123456qwert'),('123456qwerty'),('123456r'),('123456rr'),('123456ru'),('123456s'),('123456sa'),('123456sd'),('123456ss'),('123456t'),('123456tt'),('123456ty'),('123456u'),('123456v'),('123456w'),('123456ww'),('123456www'),('123456x'),('123456xx'),('123456xxx'),('123456y'),('123456yu'),('123456yy'),('123456z'),('123456zx'),('123456zxc'),('123456zxcv'),('123456zxcvbn'),('123456zz'),('123456zzz'),('123456_'),('123456й'),('123456�'),('123456��'),('123457'),('1234576'),('1234578'),('12345789'),('123458'),('1234589'),('123459'),('123459876'),('12345@'),('12345a'),('12345aa'),('12345aaa'),('12345ab'),('12345abc'),('12345abcd'),('12345abcde'),('12345as'),('12345asd'),('12345asdf'),('12345asdfg'),('12345az'),('12345b'),('12345c'),('12345d'),('12345e'),('12345f'),('12345g'),('12345h'),('12345hi'),('12345i'),('12345j'),('12345k'),('12345l'),('12345lol'),('12345love'),('12345m'),('12345me'),('12345n'),('12345o'),('12345p'),('12345q'),('12345qaz'),('12345qq'),('12345qqq'),('12345qw'),('12345qwe'),('12345qwer'),('12345qwert'),('12345qwertasdfg'),('12345qwerty'),('12345r'),('12345rewq'),('12345s'),('12345sex'),('12345six'),('12345ss'),('12345t'),('12345ta'),('12345tgb'),('12345trewq'),('12345tt'),('12345ty'),('12345u'),('12345v'),('12345w'),('12345x'),('12345y'),('12345z'),('12345zx'),('12345zxc'),('12345zxcvb'),('12345zz'),('12345zzz'),('12345�'),('12345��������'),('12346'),('123465'),('123466'),('123467'),('1234678'),('12346789'),('123468'),('12347'),('123478'),('1234789'),('12347890'),('12348765'),('12348878'),('123489'),('12349876'),('123498765'),('1234a'),('1234aa'),('1234aaa'),('1234aaaa'),('1234ab'),('1234abc'),('1234abcd'),('1234anna'),('1234as'),('1234asd'),('1234asdf'),('1234er'),('1234five'),('1234go'),('1234hi'),('1234jk'),('1234kids'),('1234love'),('1234me'),('1234mm'),('1234O8o'),('1234pass'),('1234q'),('1234qaz'),('1234qq'),('1234qw'),('1234qwe'),('1234qwer'),('1234qwerasdf'),('1234qwerasdfzxcv'),('1234qwert'),('1234qwerty'),('1234rewq'),('1234rfv'),('1234rr'),('1234rt'),('1234ss'),('1234tt'),('1234we'),('1234wert'),('1234zx'),('1234zxc'),('1234zxcv'),('1234������'),('1235'),('12351235'),('123520'),('12354'),('123546'),('123555'),('12356'),('123564'),('123567'),('1235678'),('12356789'),('12356790'),('123568'),('1235689'),('123569'),('1235789'),('123578951'),('123579'),('12358'),('123580'),('1235813'),('123581321'),('123589'),('1236'),('12361236'),('123645'),('12365'),('123654'),('1236540'),('1236541'),('123654123'),('1236547'),('12365478'),('123654789'),('1236547890'),('123654789a'),('123654789q'),('123654987'),('123654a'),('123654q'),('123654z'),('123666'),('123678'),('12369'),('123690'),('123695'),('1236951'),('123698'),('123698547'),('1236987'),('12369874'),('123698741'),('123698745'),('1236987450'),('1236987456'),('123698745a'),('1237'),('123700'),('123741'),('123777'),('123786'),('123789'),('1237890'),('123789456'),('1237895'),('123789654'),('123789852'),('123789a'),('123789abc'),('1238'),('12381238'),('123852'),('123888'),('123890'),('1239'),('123951'),('123963'),('123987'),('123987456'),('1239875'),('123987a'),('123999'),('123@123'),('123@abc'),('123a'),('123a123'),('123a123a'),('123a321'),('123a456'),('123a456b'),('123aaa'),('123aaa123'),('123abc'),('123abc!'),('123abc.'),('123abc1'),('123abc123'),('123abc123abc'),('123abc456'),('123abcd'),('123abcde'),('123admin'),('123admin32'),('123admin321'),('123admin321A'),('123alex'),('123angel'),('123apple'),('123as123'),('123asd'),('123asd123'),('123asd123asd'),('123asd456'),('123asd88'),('123asdf'),('123asdfg'),('123asdqwe'),('123asdzxc'),('123ass'),('123aye'),('123aze'),('123baby'),('123bbb'),('123bitch'),('123blue'),('123bnm'),('123bob'),('123boo'),('123boy'),('123car'),('123cat'),('123chris'),('123cool'),('123dan'),('123david'),('123ddd'),('123dima'),('123dog'),('123e123e'),('123e456'),('123edc'),('123eee'),('123ert'),('123ewq'),('123ewqasd'),('123ewqasdcxz'),('123fake'),('123four'),('123fuck'),('123fuckyou'),('123god'),('123green'),('123haha'),('123happy'),('123hello'),('123hfjdk147'),('123hot'),('123iloveme'),('123iloveu'),('123india'),('123itsme'),('123jesus'),('123jkl'),('123joe'),('123kat'),('123kdd'),('123kid'),('123kids'),('123killer'),('123king'),('123kkk'),('123lol'),('123lol123'),('123love'),('123m456'),('123mama'),('123man'),('123masha'),('123max'),('123mike'),('123mmm'),('123mnb'),('123mom'),('123money'),('123monkey'),('123mudar'),('123music'),('123myspace'),('123odidol'),('123one'),('123pass'),('123passwor'),('123password'),('123pimp'),('123pink'),('123poi'),('123poop'),('123pop'),('123pormi'),('123pro'),('123q123'),('123q123q'),('123q321'),('123q456'),('123qaz'),('123qaz123'),('123qazwsx'),('123qq123'),('123qqq'),('123qw123'),('123qwaszx'),('123qwe'),('123qwe!'),('123qwe,./'),('123qwe1'),('123qwe123'),('123qwe123qwe'),('123qwe321'),('123qwe4'),('123qwe456'),('123qwe456asd'),('123qwe456rty'),('123qwe4r'),('123qweas'),('123qweasd'),('123qweasdz'),('123qweasdzxc'),('123qweqwe'),('123qwer'),('123qwert'),('123qwerty'),('123qwerty123'),('123qwezxc'),('123red'),('123rf'),('123rock'),('123rrr'),('123rty'),('123sam'),('123sex'),('123sexy'),('123smile'),('123soleil'),('123spill'),('123sss'),('123star'),('123stella'),('123test'),('123usa'),('123w123'),('123wee'),('123wer'),('123wert'),('123wwe'),('123www'),('123xxx'),('123xyz'),('123you'),('123z123'),('123z321'),('123zaq'),('123zxc'),('123zxc123'),('123zxcv'),('123zxcvbnm'),('123zzz'),('123_123'),('123_abc'),('123йцу'),('123�����'),('124'),('124001'),('12401240'),('124124'),('12413'),('12421242'),('1243'),('12431243'),('124356'),('12435687'),('124365'),('1244'),('124421'),('1245'),('124512'),('12451245'),('124536'),('12456'),('124563'),('124567'),('12456789'),('124578'),('1245780'),('124578369'),('1245789'),('12457896'),('124578963'),('124578a'),('124589'),('124680'),('1248'),('12481248'),('124816'),('12481632'),('125'),('1250'),('125000'),('125001'),('12501250'),('125125'),('125125125'),('12521252'),('1254'),('125412'),('12541254'),('125478'),('125478963'),('1255'),('125521'),('1256'),('12561256'),('125634'),('125678'),('125689'),('125690'),('1257'),('1258'),('125800'),('12581258'),('125874'),('12589'),('125896'),('1258963'),('126'),('126126'),('1269'),('127'),('127127'),('1272446'),('1277'),('1278'),('12781278'),('128'),('1281'),('128128'),('128500'),('1288'),('1289'),('12891289'),('129'),('1290'),('12901290'),('129129'),('1299'),('12991299'),('12ab34'),('12ab34cd'),('12abcd'),('12asdf'),('12d8a377'),('12e3E456'),('12e456'),('12fuckyou'),('12gage'),('12gauge'),('12hat93'),('12inches'),('12love'),('12many'),('12monkey'),('12monkeys'),('12pack'),('12password'),('12play'),('12q12q'),('12q12q12q'),('12qazwsx'),('12qw!'),('12qw12'),('12qw12qw'),('12qw23we'),('12qw34'),('12qw34as'),('12qw34er'),('12qw34er56ty'),('12qwas'),('12qwasyx'),('12qwaszx'),('12qwer'),('12qwert'),('12qwerty'),('12roses'),('12s3t4p55'),('12sexy'),('12step'),('12steps'),('12stones'),('12string'),('12three'),('12wq12wq'),('12wqasxz'),('13'),('130'),('1300'),('130000'),('130013'),('1301'),('13011301'),('13011977'),('13011979'),('13011980'),('13011981'),('13011982'),('13011983'),('13011984'),('13011985'),('13011986'),('13011987'),('13011988'),('13011989'),('13011990'),('13011991'),('13011992'),('13011993'),('13011994'),('13011995'),('130130'),('130177'),('130178'),('130179'),('130180'),('130181'),('130182'),('130183'),('130184'),('130185'),('130186'),('130187'),('130188'),('130189'),('130190'),('130191'),('130192'),('130193'),('130194'),('130195'),('130196'),('1302'),('13021302'),('13021977'),('13021978'),('13021979'),('13021980'),('13021981'),('13021982'),('13021983'),('13021984'),('13021985'),('13021986'),('13021987'),('13021988'),('13021989'),('13021990'),('13021991'),('13021992'),('13021993'),('13021994'),('13021995'),('13021996'),('13021997'),('130276'),('130277'),('130278'),('130279'),('130280'),('130281'),('130282'),('130283'),('130284'),('130285'),('130286'),('130287'),('130288'),('130289'),('130290'),('130291'),('130292'),('130293'),('130294'),('130295'),('130296'),('1303'),('130303'),('13031303'),('13031977'),('13031978'),('13031979'),('13031980'),('13031981'),('13031982'),('13031983'),('13031984'),('13031985'),('13031986'),('13031987'),('13031988'),('13031989'),('13031990'),('13031991'),('13031992'),('13031993'),('13031994'),('13031995'),('13031996'),('130373'),('130375'),('130377'),('130378'),('130379'),('130380'),('130381'),('130382'),('130383'),('130384'),('130385'),('130386'),('130387'),('130388'),('130389'),('130390'),('130391'),('130392'),('130393'),('130394'),('130395'),('130396'),('1304'),('13041304'),('13041978'),('13041979'),('13041980'),('13041981'),('13041982'),('13041983'),('13041984'),('13041985'),('13041986'),('13041987'),('13041988'),('13041989'),('13041990'),('13041991'),('13041992'),('13041993'),('13041994'),('13041995'),('13041996'),('130476'),('130477'),('130478'),('130479'),('130480'),('130481'),('130482'),('130483'),('130484'),('130485'),('130486'),('130487'),('130488'),('130489'),('130490'),('130491'),('130492'),('130493'),('130494'),('130495'),('130496'),('1305'),('13051305'),('13051976'),('13051977'),('13051978'),('13051979'),('13051980'),('13051981'),('13051982'),('13051983'),('13051984'),('13051985'),('13051986'),('13051987'),('13051988'),('13051989'),('13051990'),('13051991'),('13051992'),('13051993'),('13051994'),('13051995'),('13051996'),('130574'),('130575'),('130576'),('130577'),('130578'),('130579'),('130580'),('130581'),('130582'),('130583'),('130584'),('130585'),('130586'),('130587'),('130588'),('130589'),('130590'),('130591'),('130592'),('130593'),('130594'),('130595'),('130596'),('1306'),('13061306'),('13061978'),('13061979'),('13061980'),('13061981'),('13061982'),('13061983'),('13061984'),('13061985'),('13061986'),('13061987'),('13061988'),('13061989'),('13061990'),('13061991'),('13061992'),('13061993'),('13061994'),('13061995'),('13061996'),('130675'),('130676'),('130677'),('130678'),('130679'),('130680'),('130681'),('130682'),('130683'),('130684'),('130685'),('130686'),('130687'),('130688'),('130689'),('130690'),('130691'),('130692'),('130693'),('130694'),('130695'),('130696'),('130697'),('1307'),('13071307'),('13071977'),('13071978'),('13071979'),('13071980'),('13071981'),('13071982'),('13071983'),('13071984'),('13071985'),('13071986'),('13071987'),('13071988'),('13071989'),('13071990'),('13071991'),('13071992'),('13071993'),('13071994'),('13071995'),('130775'),('130776'),('130777'),('130778'),('130779'),('130780'),('130781'),('130782'),('130783'),('130784'),('130785'),('130786'),('130787'),('130788'),('130789'),('130790'),('130791'),('130792'),('130793'),('130794'),('130795'),('130796'),('1308'),('130808'),('13081308'),('13081977'),('13081979'),('13081980'),('13081981'),('13081982'),('13081983'),('13081984'),('13081985'),('13081986'),('13081987'),('13081988'),('13081989'),('13081990'),('13081991'),('13081992'),('13081993'),('13081994'),('13081996'),('130874'),('130875'),('130876'),('130877'),('130878'),('130879'),('130880'),('130881'),('130882'),('130883'),('130884'),('130885'),('130886'),('130887'),('130888'),('130889'),('130890'),('130891'),('130892'),('130893'),('130894'),('130895'),('130896'),('130897'),('1309'),('13091309'),('13091979'),('13091980'),('13091981'),('13091982'),('13091983'),('13091984'),('13091985'),('13091986'),('13091987'),('13091988'),('13091989'),('13091990'),('13091991'),('13091992'),('13091993'),('13091994'),('13091995'),('13091996'),('130977'),('130978'),('130979'),('130980'),('130981'),('130982'),('130983'),('130984'),('130985'),('130986'),('130987'),('130988'),('130989'),('130990'),('130991'),('130992'),('130993'),('130994'),('130995'),('130996'),('131'),('1310'),('131001'),('13101310'),('13101976'),('13101977'),('13101978'),('13101979'),('13101980'),('13101981'),('13101982'),('13101983'),('13101984'),('13101985'),('13101986'),('13101987'),('13101988'),('13101989'),('13101990'),('13101991'),('13101992'),('13101993'),('13101994'),('13101995'),('131061'),('131072'),('131075'),('131076'),('131077'),('131078'),('131079'),('131080'),('131081'),('131082'),('131083'),('131084'),('131085'),('131086'),('131087'),('131088'),('131089'),('131090'),('131091'),('131092'),('131093'),('131094'),('131095'),('131096'),('1311'),('13111311'),('13111978'),('13111979'),('13111980'),('13111981'),('13111982'),('13111983'),('13111984'),('13111985'),('13111986'),('13111987'),('13111988'),('13111989'),('13111990'),('13111991'),('13111992'),('13111993'),('13111994'),('13111995'),('131131'),('131176'),('131177'),('131178'),('131179'),('131180'),('131181'),('131182'),('131183'),('131184'),('131185'),('131186'),('131187'),('131188'),('131189'),('131190'),('131191'),('131192'),('131193'),('131194'),('131195'),('131196'),('1312'),('131200'),('131211'),('131213'),('13121312'),('13121975'),('13121976'),('13121977'),('13121978'),('13121979'),('13121980'),('13121981'),('13121982'),('13121983'),('13121984'),('13121985'),('13121986'),('13121987'),('13121988'),('13121989'),('13121990'),('13121991'),('13121992'),('13121993'),('13121994'),('13121995'),('13121996'),('131275'),('131276'),('131277'),('131278'),('131279'),('131280'),('131281'),('131282'),('131283'),('131284'),('131285'),('131286'),('131287'),('131288'),('131289'),('131290'),('131291'),('131292'),('131293'),('131294'),('131295'),('131296'),('1313'),('131313'),('1313131'),('13131313'),('1313131313'),('131313a'),('131313q'),('1313666'),('1314'),('131400'),('131413'),('13141314'),('131415'),('13141516'),('1314159'),('131420'),('131421'),('131425'),('1314258'),('1314520'),('13145200'),('1314521'),('1315'),('13151315'),('131517'),('1316'),('131619'),('1317'),('13171317'),('1318'),('131977'),('131978'),('131979'),('131980'),('131981'),('131982'),('131983'),('131984'),('131985'),('131986'),('131987'),('131988'),('131989'),('131990'),('131991'),('131992'),('131993'),('131994'),('131995'),('131996'),('132'),('1320'),('132001'),('13201320'),('132040'),('1321'),('132103'),('13211321'),('132123'),('132132'),('132132132'),('1322'),('13221322'),('1323'),('132313'),('13231323'),('132333'),('1323456'),('1323456789'),('1324'),('13241324'),('132435'),('13243546'),('1324354657'),('1324354657687980'),('13245'),('132456'),('132456789'),('13245768'),('132465'),('132465798'),('1325'),('13251325'),('132546'),('1326'),('13261326'),('132639'),('132680'),('1327'),('13271327'),('13281328'),('133001'),('13301827475'),('1331'),('133113'),('13311331'),('133133'),('13324124'),('133333'),('1337'),('13371337'),('1337ness'),('134'),('1340'),('134109'),('134134'),('1342'),('13421342'),('1344'),('1345'),('13451345'),('13456'),('134567'),('13456789'),('1346'),('13461346'),('134625'),('134652'),('134679'),('1346790'),('134679258'),('1346795'),('13467982'),('134679852'),('1346798520'),('134679a'),('13489277'),('135'),('1350'),('13501350'),('13511351'),('135135'),('13521352'),('135246'),('13531353'),('13541354'),('13551355'),('135531'),('1356'),('13561356'),('135642'),('1357'),('135711'),('13571357'),('1357246'),('13572468'),('1357642'),('13577531'),('135789'),('13579'),('13579-'),('135790'),('1357900'),('13579000'),('1357902468'),('1357908642'),('135790a'),('135791'),('1357910'),('1357911'),('135791113'),('1357911q'),('1357913'),('13579135'),('1357913579'),('135792'),('1357924'),('13579246'),('135792468'),('1357924680'),('13579246810'),('135795'),('135797531'),('135798'),('135798642'),('135799'),('1357997531'),('13579a'),('13579q'),('1357reti99'),('1358'),('13581358'),('13587930210'),('1359'),('13591359'),('135qet'),('1360'),('13601360'),('13611361'),('136136'),('13621362'),('13631363'),('1364'),('13641364'),('136479'),('1365'),('13651365'),('1366'),('13661366'),('13666'),('1366613'),('136666'),('13671367'),('13681368'),('1369'),('136900'),('136913'),('13691369'),('13701370'),('137137'),('13751375'),('13771377'),('1379'),('137900'),('13791379'),('137946'),('13795'),('137955'),('13801380'),('138138'),('1388'),('139139'),('139381512'),('1397'),('13971397'),('13grom'),('13love'),('13Marino'),('13pass13'),('13qeadzc'),('13thirteen'),('14'),('140'),('1400'),('140000'),('14001400'),('1401'),('14011401'),('14011980'),('14011981'),('14011982'),('14011983'),('14011984'),('14011985'),('14011986'),('14011987'),('14011988'),('14011989'),('14011990'),('14011991'),('14011992'),('14011993'),('14011994'),('14011995'),('140140'),('140178'),('140179'),('140180'),('140181'),('140182'),('140183'),('140184'),('140185'),('140186'),('140187'),('140188'),('140189'),('140190'),('140191'),('140192'),('140193'),('140194'),('140195'),('1402'),('140200'),('140202'),('140203'),('140204'),('140206'),('140207'),('140208'),('140209'),('14021402'),('14021975'),('14021976'),('14021977'),('14021978'),('14021979'),('14021980'),('14021981'),('14021982'),('14021983'),('14021984'),('14021985'),('14021986'),('14021987'),('14021988'),('14021989'),('14021990'),('14021991'),('14021992'),('14021993'),('14021994'),('14021995'),('14021996'),('14021997'),('14022008'),('14022009'),('140274'),('140275'),('140276'),('140277'),('140278'),('140279'),('140280'),('140281'),('140282'),('140283'),('140284'),('140285'),('140286'),('140287'),('140288'),('140289'),('140290'),('140291'),('140292'),('140293'),('140294'),('140295'),('140296'),('140297'),('140298'),('140299'),('1403'),('14031403'),('14031972'),('14031977'),('14031978'),('14031979'),('14031980'),('14031981'),('14031982'),('14031983'),('14031984'),('14031985'),('14031986'),('14031987'),('14031988'),('14031989'),('14031990'),('14031991'),('14031992'),('14031993'),('14031994'),('14031995'),('14031996'),('140377'),('140378'),('140379'),('140380'),('140381'),('140382'),('140383'),('140384'),('140385'),('140386'),('140387'),('140388'),('140389'),('140390'),('140391'),('140392'),('140393'),('140394'),('140395'),('140396'),('1404'),('140404'),('14041404'),('14041976'),('14041977'),('14041978'),('14041979'),('14041980'),('14041981'),('14041982'),('14041983'),('14041984'),('14041985'),('14041986'),('14041987'),('14041988'),('14041989'),('14041990'),('14041991'),('14041992'),('14041993'),('14041994'),('14041995'),('14041997'),('140473'),('140474'),('140476'),('140477'),('140478'),('140479'),('140480'),('140481'),('140482'),('140483'),('140484'),('140485'),('140486'),('140487'),('140488'),('140489'),('140490'),('140491'),('140492'),('140493'),('140494'),('140495'),('1405'),('140505'),('14051405'),('14051977'),('14051979'),('14051980'),('14051981'),('14051982'),('14051983'),('14051984'),('14051985'),('14051986'),('14051987'),('14051988'),('14051989'),('14051990'),('14051991'),('14051992'),('14051993'),('14051994'),('14051995'),('14051996'),('14051997'),('140575'),('140576'),('140577'),('140578'),('140579'),('140580'),('140581'),('140582'),('140583'),('140584'),('140585'),('140586'),('140587'),('140588'),('140589'),('140590'),('140591'),('140592'),('140593'),('140594'),('140595'),('140596'),('1406'),('140603'),('14061406'),('14061976'),('14061977'),('14061979'),('14061980'),('14061981'),('14061982'),('14061983'),('14061984'),('14061985'),('14061986'),('14061987'),('14061988'),('14061989'),('14061990'),('14061991'),('14061992'),('14061993'),('14061994'),('14061995'),('14061996'),('140675'),('140676'),('140677'),('140678'),('140679'),('140680'),('140681'),('140682'),('140683'),('140684'),('140685'),('140686'),('140687'),('140688'),('140689'),('140690'),('140691'),('140692'),('140693'),('140694'),('140695'),('140696'),('1407'),('140707'),('14071407'),('14071977'),('14071979'),('14071980'),('14071981'),('14071982'),('14071983'),('14071984'),('14071985'),('14071986'),('14071987'),('14071988'),('14071989'),('14071990'),('14071991'),('14071992'),('14071993'),('14071994'),('14071995'),('14071997'),('140776'),('140777'),('140778'),('140779'),('140780'),('140781'),('140782'),('140783'),('140784'),('140785'),('140786'),('140787'),('140788'),('140789'),('140790'),('140791'),('140792'),('140793'),('140794'),('140795'),('1408'),('14081408'),('14081979'),('14081980'),('14081981'),('14081982'),('14081983'),('14081984'),('14081985'),('14081986'),('14081987'),('14081988'),('14081989'),('14081990'),('14081991'),('14081992'),('14081993'),('14081994'),('14081995'),('14081996'),('140876'),('140877'),('140878'),('140879'),('140880'),('140881'),('140882'),('140883'),('140884'),('140885'),('140886'),('140887'),('140888'),('140889'),('140890'),('140891'),('140892'),('140893'),('140894'),('140895'),('140896'),('1409'),('14091980'),('14091981'),('14091982'),('14091983'),('14091984'),('14091985'),('14091986'),('14091987'),('14091988'),('14091989'),('14091990'),('14091991'),('14091992'),('14091993'),('14091994'),('14091995'),('140976'),('140977'),('140978'),('140979'),('140980'),('140981'),('140982'),('140983'),('140984'),('140985'),('140986'),('140987'),('140988'),('140989'),('140990'),('140991'),('140992'),('140993'),('140994'),('140995'),('141'),('1410'),('141000'),('141001'),('141002'),('141003'),('141008'),('141010'),('14101410'),('14101976'),('14101978'),('14101979'),('14101980'),('14101981'),('14101982'),('14101983'),('14101984'),('14101985'),('14101986'),('14101987'),('14101988'),('14101989'),('14101990'),('14101991'),('14101992'),('14101993'),('14101994'),('14101995'),('14101996'),('141070'),('141075'),('141076'),('141077'),('141078'),('141079'),('141080'),('141081'),('141082'),('141083'),('141084'),('141085'),('141086'),('141087'),('141088'),('141089'),('141090'),('141091'),('141092'),('141093'),('141094'),('141095'),('141096'),('1411'),('14111411'),('14111978'),('14111979'),('14111980'),('14111981'),('14111982'),('14111983'),('14111984'),('14111985'),('14111986'),('14111987'),('14111988'),('14111989'),('14111990'),('14111991'),('14111992'),('14111993'),('14111994'),('14111995'),('141141'),('141175'),('141176'),('141177'),('141178'),('141179'),('141180'),('141181'),('141182'),('141183'),('141184'),('141185'),('141186'),('141187'),('141188'),('141189'),('141190'),('141191'),('141192'),('141193'),('141194'),('141195'),('141196'),('1412'),('141200'),('14121412'),('14121976'),('14121977'),('14121978'),('14121979'),('14121980'),('14121981'),('14121982'),('14121983'),('14121984'),('14121985'),('14121986'),('14121987'),('14121988'),('14121989'),('14121990'),('14121991'),('14121992'),('14121993'),('14121994'),('14121995'),('14121996'),('141276'),('141277'),('141278'),('141279'),('141280'),('141281'),('141282'),('141283'),('141284'),('141285'),('141286'),('141287'),('141288'),('141289'),('141290'),('141291'),('141292'),('141293'),('141294'),('141295'),('141296'),('141312'),('14131413'),('1414'),('141414'),('14141414'),('141421'),('1415'),('14151415'),('141516'),('14151617'),('1415926'),('141618'),('1417'),('1418'),('14181418'),('141888'),('141975'),('141977'),('141978'),('141979'),('141980'),('141981'),('141982'),('141983'),('141984'),('141985'),('141986'),('141987'),('141988'),('141989'),('141990'),('141991'),('141992'),('141993'),('141994'),('141995'),('141996'),('142'),('1420'),('14201420'),('1420839army'),('1421'),('14211421'),('142142'),('1422'),('14221422'),('1423'),('14231423'),('142356'),('1424'),('14241424'),('142434'),('1425'),('14251425'),('142536'),('142536789'),('142536a'),('142753869'),('1428'),('142857'),('143'),('1430'),('143000'),('143001'),('14301430'),('143143'),('143143143'),('1432'),('14321432'),('143256'),('1433'),('143341'),('1434'),('14344'),('143441'),('143444'),('143445'),('143445254'),('1435'),('1435254'),('1436'),('143637'),('1437'),('14371437'),('143baby'),('143iloveyo'),('143jesus'),('143love'),('144000'),('144001'),('1441'),('14411441'),('144144'),('145'),('145145'),('1452'),('14521452'),('145236'),('145236987'),('145263'),('1453'),('145300'),('14531453'),('145353'),('1456'),('14561456'),('145623'),('145632'),('146146'),('14629227'),('1469'),('147'),('1470'),('147001'),('14701470'),('147123'),('147147'),('147147147'),('147159'),('1472'),('14725'),('147258'),('1472580'),('1472580369'),('1472583'),('14725836'),('147258369'),('1472583690'),('1472583691'),('147258369a'),('147258369q'),('147258963'),('147258a'),('147369'),('147369258'),('147456'),('1475369'),('1475963'),('1477'),('147741'),('147789'),('1478'),('14781478'),('14785'),('147852'),('1478520'),('1478523'),('14785236'),('147852369'),('1478523690'),('147852369a'),('147852369q'),('147852963'),('147852a'),('147852zes'),('14789'),('147890'),('147895'),('147896'),('1478963'),('14789632'),('147896321'),('147896325'),('1478963250'),('1478963258'),('147896325a'),('1478963a'),('1478965'),('147963'),('147963258'),('148148'),('1488'),('148814'),('14881488'),('148888'),('1488ss'),('149149'),('1492'),('14921492'),('14jesus'),('14love'),('14themoney'),('14theroad'),('15'),('150'),('1500'),('150000'),('15001500'),('1501'),('15011977'),('15011978'),('15011979'),('15011980'),('15011981'),('15011982'),('15011983'),('15011984'),('15011985'),('15011986'),('15011987'),('15011988'),('15011989'),('15011990'),('15011991'),('15011992'),('15011993'),('15011994'),('15011995'),('15011996'),('150150'),('150150as'),('150177'),('150178'),('150179'),('150180'),('150181'),('150182'),('150183'),('150184'),('150185'),('150186'),('150187'),('150188'),('150189'),('150190'),('150191'),('150192'),('150193'),('150196'),('1502'),('15021502'),('15021976'),('15021977'),('15021978'),('15021979'),('15021980'),('15021981'),('15021982'),('15021983'),('15021984'),('15021985'),('15021986'),('15021987'),('15021988'),('15021989'),('15021990'),('15021991'),('15021992'),('15021993'),('15021994'),('15021995'),('15021996'),('150276'),('150277'),('150278'),('150279'),('150280'),('150281'),('150282'),('150283'),('150284'),('150285'),('150286'),('150287'),('150288'),('150289'),('150290'),('150291'),('150292'),('150293'),('150294'),('150295'),('150296'),('1503'),('15031503'),('15031975'),('15031977'),('15031978'),('15031979'),('15031980'),('15031981'),('15031982'),('15031983'),('15031984'),('15031985'),('15031986'),('15031987'),('15031988'),('15031989'),('15031990'),('15031991'),('15031992'),('15031993'),('15031994'),('15031995'),('15031996'),('150375'),('150376'),('150377'),('150378'),('150379'),('150380'),('150381'),('150382'),('150383'),('150384'),('150385'),('150386'),('150387'),('150388'),('150389'),('150390'),('150391'),('150392'),('150393'),('150394'),('150395'),('150396'),('1504'),('15041977'),('15041978'),('15041979'),('15041980'),('15041981'),('15041982'),('15041983'),('15041984'),('15041985'),('15041986'),('15041987'),('15041988'),('15041989'),('15041990'),('15041991'),('15041992'),('15041993'),('15041994'),('15041995'),('15041996'),('150475'),('150476'),('150477'),('150478'),('150479'),('150480'),('150481'),('150482'),('150483'),('150484'),('150485'),('150486'),('150487'),('150488'),('150489'),('150490'),('150491'),('150492'),('150493'),('150494'),('150495'),('150496'),('1505'),('150505'),('15051505'),('15051975'),('15051976'),('15051977'),('15051978'),('15051979'),('15051980'),('15051981'),('15051982'),('15051983'),('15051984'),('15051985'),('15051986'),('15051987'),('15051988'),('15051989'),('15051990'),('15051991'),('15051992'),('15051993'),('15051994'),('15051995'),('15051996'),('150556'),('150575'),('150576'),('150577'),('150578'),('150579'),('150580'),('150581'),('150582'),('150583'),('150584'),('150585'),('150586'),('150587'),('150588'),('150589'),('150590'),('150591'),('150592'),('150593'),('150594'),('150595'),('150596'),('1506'),('15061977'),('15061978'),('15061979'),('15061980'),('15061981'),('15061982'),('15061983'),('15061984'),('15061985'),('15061986'),('15061987'),('15061988'),('15061989'),('15061990'),('15061991'),('15061992'),('15061993'),('15061994'),('15061995'),('15061996'),('150676'),('150677'),('150678'),('150679'),('150680'),('150681'),('150682'),('150683'),('150684'),('150685'),('150686'),('150687'),('150688'),('150689'),('150690'),('150691'),('150692'),('150693'),('150694'),('150695'),('150696'),('1507'),('15071977'),('15071979'),('15071980'),('15071981'),('15071982'),('15071983'),('15071984'),('15071985'),('15071986'),('15071987'),('15071988'),('15071989'),('15071990'),('15071991'),('15071992'),('15071993'),('15071994'),('15071996'),('150777'),('150778'),('150779'),('150780'),('150781'),('150782'),('150783'),('150784'),('150785'),('150786'),('150787'),('150788'),('150789'),('150790'),('150791'),('150792'),('150793'),('150794'),('150795'),('150796'),('1508'),('150801'),('150808'),('15081508'),('15081976'),('15081977'),('15081978'),('15081979'),('15081980'),('15081981'),('15081982'),('15081983'),('15081984'),('15081985'),('15081986'),('15081987'),('15081988'),('15081989'),('15081990'),('15081991'),('15081992'),('15081993'),('15081994'),('15081995'),('15081996'),('150875'),('150876'),('150877'),('150878'),('150879'),('150880'),('150881'),('150882'),('150883'),('150884'),('150885'),('150886'),('150887'),('150888'),('150889'),('150890'),('150891'),('150892'),('150893'),('150894'),('150895'),('150896'),('1509'),('150907'),('15091977'),('15091978'),('15091979'),('15091980'),('15091981'),('15091982'),('15091983'),('15091984'),('15091985'),('15091986'),('15091987'),('15091988'),('15091989'),('15091990'),('15091991'),('15091992'),('15091993'),('15091994'),('15091995'),('15092007'),('150976'),('150977'),('150978'),('150979'),('150980'),('150981'),('150982'),('150983'),('150984'),('150985'),('150986'),('150987'),('150988'),('150989'),('150990'),('150991'),('150992'),('150993'),('150994'),('150995'),('151'),('1510'),('151001'),('15101510'),('15101975'),('15101976'),('15101977'),('15101978'),('15101979'),('15101980'),('15101981'),('15101982'),('15101983'),('15101984'),('15101985'),('15101986'),('15101987'),('15101988'),('15101989'),('15101990'),('15101991'),('15101992'),('15101993'),('15101994'),('15101995'),('15101996'),('151076'),('151077'),('151078'),('151079'),('151080'),('151081'),('151082'),('151083'),('151084'),('151085'),('151086'),('151087'),('151088'),('151089'),('151090'),('151091'),('151092'),('151093'),('151094'),('151095'),('151096'),('1511'),('15111978'),('15111979'),('15111980'),('15111981'),('15111982'),('15111983'),('15111984'),('15111985'),('15111986'),('15111987'),('15111988'),('15111989'),('15111990'),('15111991'),('15111992'),('15111993'),('15111994'),('15111995'),('151151'),('151174'),('151175'),('151176'),('151177'),('151178'),('151179'),('151180'),('151181'),('151182'),('151183'),('151184'),('151185'),('151186'),('151187'),('151188'),('151189'),('151190'),('151191'),('151192'),('151193'),('151194'),('151195'),('151196'),('1512'),('151200'),('151214'),('15121512'),('15121975'),('15121977'),('15121978'),('15121979'),('15121980'),('15121981'),('15121982'),('15121983'),('15121984'),('15121985'),('15121986'),('15121987'),('15121988'),('15121989'),('15121990'),('15121991'),('15121992'),('15121993'),('15121994'),('15121995'),('151275'),('151276'),('151277'),('151278'),('151279'),('151280'),('151281'),('151282'),('151283'),('151284'),('151285'),('151286'),('151287'),('151288'),('151289'),('151290'),('151291'),('151292'),('151293'),('151294'),('151295'),('1515'),('151515'),('15151515'),('1515151515'),('151515a'),('1516'),('15161516'),('151617'),('15161718'),('151976'),('151980'),('151981'),('151982'),('151983'),('151984'),('151985'),('151986'),('151987'),('151988'),('151989'),('151990'),('151991'),('151992'),('151993'),('151994'),('1520'),('15201520'),('1521'),('152152'),('152207'),('1523'),('15231523'),('1524'),('15241524'),('15243'),('152436'),('1525'),('15251525'),('152535'),('15253545'),('15261526'),('153'),('1530'),('15301530'),('153045'),('153153'),('15321532'),('153246'),('153351'),('153426'),('153486'),('153624'),('153759'),('154154'),('15421542'),('154263'),('15426378'),('154322358'),('1551'),('15511551'),('155155'),('15516210'),('155555'),('156156'),('156324'),('157157'),('15727666'),('15731573'),('157359'),('157953'),('1580'),('1580@welca'),('1580@welcamino'),('1580welcamino'),('158158'),('159'),('1590'),('159000'),('15901590'),('1590736tany'),('1590753'),('159123'),('159159'),('159159159'),('159159a'),('159159p'),('159258'),('159258357'),('159263'),('159263487'),('159357'),('1593570'),('15935700'),('159357000'),('159357123'),('159357159357'),('1593572468'),('1593572486'),('159357258'),('159357258456'),('15935728'),('159357456'),('15935746'),('1593575'),('159357852'),('15935789'),('159357a'),('159357q'),('159357r'),('159357z'),('159369'),('159456'),('159487'),('159487263'),('15951'),('15963'),('159630'),('159632'),('1596321'),('159632478'),('1596357'),('159635741'),('159654'),('159753'),('1597530'),('15975300'),('1597531'),('159753123'),('159753159'),('159753159753'),('1597532'),('15975321'),('1597532468'),('1597532486'),('159753258'),('159753258456'),('1597532684'),('159753456'),('159753456852'),('15975346'),('1597534682'),('1597535'),('159753654'),('159753852'),('159753852456'),('159753a'),('159753m'),('159753q'),('159753s'),('159753z'),('159789'),('159852'),('15987'),('159874'),('1598741'),('159874123'),('1598753'),('15987532'),('159875321'),('1598753a'),('159951'),('159951159'),('15995123'),('159951a'),('159963'),('159987'),('15love'),('16'),('160'),('160000'),('160022'),('160036'),('160047'),('1601'),('160101'),('16011978'),('16011980'),('16011981'),('16011982'),('16011983'),('16011984'),('16011985'),('16011986'),('16011987'),('16011988'),('16011989'),('16011990'),('16011991'),('16011992'),('16011993'),('16011994'),('16011995'),('16011996'),('160160'),('160178'),('160178z'),('160179'),('160180'),('160181'),('160182'),('160183'),('160184'),('160185'),('160186'),('160187'),('160188'),('160189'),('160190'),('160191'),('160192'),('160193'),('160194'),('160195'),('1602'),('16021977'),('16021978'),('16021979'),('16021980'),('16021981'),('16021982'),('16021983'),('16021984'),('16021985'),('16021986'),('16021987'),('16021988'),('16021989'),('16021990'),('16021991'),('16021992'),('16021993'),('16021994'),('16021995'),('16021996'),('160277'),('160278'),('160279'),('160280'),('160281'),('160282'),('160283'),('160284'),('160285'),('160286'),('160287'),('160288'),('160289'),('160290'),('160291'),('160292'),('160293'),('160294'),('160295'),('160296'),('1603'),('16031977'),('16031978'),('16031980'),('16031981'),('16031982'),('16031983'),('16031984'),('16031985'),('16031986'),('16031987'),('16031988'),('16031989'),('16031990'),('16031991'),('16031992'),('16031993'),('16031994'),('16031995'),('160376'),('160377'),('160378'),('160379'),('160380'),('160381'),('160382'),('160383'),('160384'),('160385'),('160386'),('160387'),('160388'),('160389'),('160390'),('160391'),('160392'),('160393'),('160394'),('160395'),('1604'),('160403'),('16041976'),('16041977'),('16041978'),('16041979'),('16041980'),('16041981'),('16041982'),('16041983'),('16041984'),('16041985'),('16041986'),('16041987'),('16041988'),('16041989'),('16041990'),('16041991'),('16041992'),('16041993'),('16041994'),('16041995'),('16041997'),('160476'),('160477'),('160478'),('160479'),('160480'),('160481'),('160482'),('160483'),('160484'),('160485'),('160486'),('160487'),('160488'),('160489'),('160490'),('160491'),('160492'),('160493'),('160494'),('160495'),('160496'),('1605'),('16051977'),('16051978'),('16051979'),('16051980'),('16051981'),('16051982'),('16051983'),('16051984'),('16051985'),('16051986'),('16051987'),('16051988'),('16051989'),('16051990'),('16051991'),('16051992'),('16051993'),('16051994'),('16051995'),('16051996'),('16051997'),('160577'),('160578'),('160579'),('160580'),('160581'),('160582'),('160583'),('160584'),('160585'),('160586'),('160587'),('160588'),('160589'),('160590'),('160591'),('160592'),('160593'),('160594'),('160595'),('160596'),('160597'),('1606'),('160606'),('16061977'),('16061978'),('16061980'),('16061981'),('16061982'),('16061983'),('16061984'),('16061985'),('16061986'),('16061987'),('16061988'),('16061989'),('16061990'),('16061991'),('16061992'),('16061993'),('16061994'),('16061995'),('160676'),('160677'),('160678'),('160679'),('160680'),('160681'),('160682'),('160683'),('160684'),('160685'),('160686'),('160687'),('160688'),('160689'),('160690'),('160691'),('160692'),('160693'),('160694'),('160695'),('160696'),('1607'),('16071978'),('16071979'),('16071980'),('16071981'),('16071982'),('16071983'),('16071984'),('16071985'),('16071986'),('16071987'),('16071988'),('16071989'),('16071990'),('16071991'),('16071992'),('16071993'),('16071994'),('160777'),('160779'),('160780'),('160781'),('160782'),('160783'),('160784'),('160785'),('160786'),('160787'),('160788'),('160789'),('160790'),('160791'),('160792'),('160793'),('160794'),('1608'),('160808'),('16081977'),('16081978'),('16081979'),('16081980'),('16081981'),('16081982'),('16081983'),('16081984'),('16081985'),('16081986'),('16081987'),('16081988'),('16081989'),('16081990'),('16081991'),('16081992'),('16081993'),('16081994'),('16081995'),('16081996'),('160877'),('160878'),('160879'),('160880'),('160881'),('160882'),('160883'),('160884'),('160885'),('160886'),('160887'),('160888'),('160889'),('160890'),('160891'),('160892'),('160893'),('160894'),('160895'),('1609'),('16091980'),('16091981'),('16091982'),('16091983'),('16091984'),('16091985'),('16091986'),('16091987'),('16091988'),('16091989'),('16091990'),('16091991'),('16091992'),('16091993'),('16091994'),('16091995'),('160977'),('160978'),('160979'),('160980'),('160981'),('160982'),('160983'),('160984'),('160985'),('160986'),('160987'),('160988'),('160989'),('160990'),('160991'),('160992'),('160993'),('160994'),('160995'),('161'),('1610'),('16101610'),('16101976'),('16101977'),('16101978'),('16101979'),('16101980'),('16101981'),('16101982'),('16101983'),('16101984'),('16101985'),('16101986'),('16101987'),('16101988'),('16101989'),('16101990'),('16101991'),('16101992'),('16101993'),('16101994'),('16101995'),('161077'),('161078'),('161079'),('161080'),('161081'),('161082'),('161083'),('161084'),('161085'),('161086'),('161087'),('161088'),('161089'),('161090'),('161091'),('161092'),('161093'),('161094'),('161095'),('161096'),('1611'),('16111978'),('16111979'),('16111980'),('16111981'),('16111982'),('16111983'),('16111984'),('16111985'),('16111986'),('16111987'),('16111988'),('16111989'),('16111990'),('16111991'),('16111992'),('16111993'),('16111994'),('16111995'),('161161'),('161177'),('161178'),('161179'),('161180'),('161181'),('161182'),('161183'),('161184'),('161185'),('161186'),('161187'),('161188'),('161189'),('161190'),('161191'),('161192'),('161193'),('161194'),('161195'),('1612'),('16121612'),('16121976'),('16121977'),('16121978'),('16121979'),('16121980'),('16121981'),('16121982'),('16121983'),('16121984'),('16121985'),('16121986'),('16121987'),('16121988'),('16121989'),('16121990'),('16121991'),('16121992'),('16121993'),('16121994'),('16121995'),('16121996'),('161275'),('161276'),('161277'),('161278'),('161279'),('161280'),('161281'),('161282'),('161283'),('161284'),('161285'),('161286'),('161287'),('161288'),('161289'),('161290'),('161291'),('161292'),('161293'),('161294'),('161295'),('1616'),('161616'),('16161616'),('1617'),('161718'),('1618'),('16181618'),('161980'),('161982'),('161983'),('161984'),('161985'),('161986'),('161987'),('161988'),('161989'),('161990'),('161991'),('161992'),('161993'),('161994'),('161995'),('1620'),('16246149'),('162534'),('162636'),('163163'),('165165'),('165432'),('166166'),('1664'),('16641664'),('167167'),('167349'),('167943'),('168168'),('168168168'),('1688'),('16881688'),('168888'),('16897168'),('16899168'),('168ASD168'),('169169'),('16candles'),('17'),('170'),('170000'),('1701'),('17011701'),('17011977'),('17011980'),('17011981'),('17011982'),('17011983'),('17011984'),('17011985'),('17011986'),('17011987'),('17011988'),('17011989'),('17011990'),('17011991'),('17011992'),('17011993'),('17011994'),('17011995'),('17011996'),('17012003'),('170170'),('170177'),('170180'),('170181'),('170182'),('170183'),('170184'),('170185'),('170186'),('170187'),('170188'),('170189'),('170190'),('170191'),('170192'),('170193'),('170194'),('170195'),('170196'),('1702'),('17021977'),('17021978'),('17021979'),('17021980'),('17021981'),('17021982'),('17021983'),('17021984'),('17021985'),('17021986'),('17021987'),('17021988'),('17021989'),('17021990'),('17021991'),('17021992'),('17021993'),('17021994'),('17021995'),('17021996'),('17021997'),('170277'),('170278'),('170280'),('170281'),('170282'),('170283'),('170284'),('170285'),('170286'),('170287'),('170288'),('170289'),('170290'),('170291'),('170292'),('170293'),('170294'),('170295'),('170296'),('1703'),('17031978'),('17031980'),('17031981'),('17031982'),('17031983'),('17031984'),('17031985'),('17031986'),('17031987'),('17031988'),('17031989'),('17031990'),('17031991'),('17031992'),('17031993'),('17031994'),('17031995'),('170376'),('170377'),('170378'),('170379'),('170380'),('170381'),('170382'),('170383'),('170384'),('170385'),('170386'),('170387'),('170388'),('170389'),('170390'),('170391'),('170392'),('170393'),('170394'),('170395'),('1704'),('17041977'),('17041978'),('17041979'),('17041980'),('17041981'),('17041982'),('17041983'),('17041984'),('17041985'),('17041986'),('17041987'),('17041988'),('17041989'),('17041990'),('17041991'),('17041992'),('17041993'),('17041994'),('17041995'),('170477'),('170478'),('170479'),('170480'),('170481'),('170482'),('170483'),('170484'),('170485'),('170486'),('170487'),('170488'),('170489'),('170490'),('170491'),('170492'),('170493'),('170494'),('170495'),('170496'),('1705'),('17051978'),('17051979'),('17051980'),('17051981'),('17051982'),('17051983'),('17051984'),('17051985'),('17051986'),('17051987'),('17051988'),('17051989'),('17051990'),('17051991'),('17051992'),('17051993'),('17051994'),('17051995'),('17051996'),('170576'),('170577'),('170578'),('170579'),('170580'),('170581'),('170582'),('170583'),('170584'),('170585'),('170586'),('170587'),('170588'),('170589'),('170590'),('170591'),('170592'),('170593'),('170594'),('170595'),('170596'),('1706'),('17061978'),('17061980'),('17061981'),('17061982'),('17061983'),('17061984'),('17061985'),('17061986'),('17061987'),('17061988'),('17061989'),('17061990'),('17061991'),('17061992'),('17061993'),('17061994'),('17061995'),('170678'),('170679'),('170680'),('170681'),('170682'),('170683'),('170684'),('170685'),('170686'),('170687'),('170688'),('170689'),('170690'),('170691'),('170692'),('170693'),('170694'),('170695'),('170696'),('1707'),('170707'),('17071977'),('17071978'),('17071979'),('17071980'),('17071981'),('17071982'),('17071983'),('17071984'),('17071985'),('17071986'),('17071987'),('17071988'),('17071989'),('17071990'),('17071991'),('17071992'),('17071993'),('17071994'),('17071995'),('17071996'),('17071997'),('170777'),('170778'),('170779'),('170780'),('170781'),('170782'),('170783'),('170784'),('170785'),('170786'),('170787'),('170788'),('170789'),('170790'),('170791'),('170792'),('170793'),('170794'),('170795'),('170797'),('1708'),('17081945'),('17081977'),('17081978'),('17081980'),('17081981'),('17081982'),('17081983'),('17081984'),('17081985'),('17081986'),('17081987'),('17081988'),('17081989'),('17081990'),('17081991'),('17081992'),('17081993'),('17081994'),('17081995'),('170845'),('170876'),('170877'),('170878'),('170879'),('170880'),('170881'),('170882'),('170883'),('170884'),('170885'),('170886'),('170887'),('170888'),('170889'),('170890'),('170891'),('170892'),('170893'),('170894'),('170895'),('1709'),('17091976'),('17091979'),('17091980'),('17091981'),('17091982'),('17091983'),('17091984'),('17091985'),('17091986'),('17091987'),('17091988'),('17091989'),('17091990'),('17091991'),('17091992'),('17091993'),('17091994'),('17091995'),('170976'),('170977'),('170979'),('170980'),('170981'),('170982'),('170983'),('170984'),('170985'),('170986'),('170987'),('170988'),('170989'),('170990'),('170991'),('170992'),('170993'),('170994'),('171'),('1710'),('17101710'),('17101975'),('17101978'),('17101979'),('17101980'),('17101981'),('17101982'),('17101983'),('17101984'),('17101985'),('17101986'),('17101987'),('17101988'),('17101989'),('17101990'),('17101991'),('17101992'),('17101993'),('17101994'),('17101995'),('17101996'),('171077'),('171078'),('171079'),('171080'),('171081'),('171082'),('171083'),('171084'),('171085'),('171086'),('171087'),('171088'),('171089'),('171090'),('171091'),('171092'),('171093'),('171094'),('171095'),('1711'),('17111979'),('17111980'),('17111981'),('17111982'),('17111983'),('17111984'),('17111985'),('17111986'),('17111987'),('17111988'),('17111989'),('17111990'),('17111991'),('17111992'),('17111993'),('17111994'),('17111995'),('171171'),('171177'),('171178'),('171179'),('171180'),('171181'),('171182'),('171183'),('171184'),('171185'),('171186'),('171187'),('171188'),('171189'),('171190'),('171191'),('171192'),('171193'),('171194'),('171195'),('1712'),('171204jg'),('17121977'),('17121978'),('17121979'),('17121980'),('17121981'),('17121982'),('17121983'),('17121984'),('17121985'),('17121986'),('17121987'),('17121988'),('17121989'),('17121990'),('17121991'),('17121992'),('17121993'),('17121994'),('17121995'),('17121996'),('171276'),('171277'),('171278'),('171279'),('171280'),('171281'),('171282'),('171283'),('171284'),('171285'),('171286'),('171287'),('171288'),('171289'),('171290'),('171291'),('171292'),('171293'),('171294'),('171295'),('171296'),('17151715'),('1717'),('171717'),('17171717'),('1718'),('171819'),('171977'),('171980'),('171981'),('171982'),('171983'),('171984'),('171985'),('171986'),('171987'),('171988'),('171989'),('171990'),('171991'),('171992'),('171993'),('171994'),('171995'),('1721'),('1721k1721'),('1725'),('1725782'),('1726354'),('172737'),('172839'),('172839456'),('173173'),('1738'),('173928'),('174174'),('175175'),('1771'),('17711771'),('177177'),('17746052'),('1776'),('177777'),('178178'),('178500'),('1789'),('17891789'),('1793'),('17931793'),('179324865'),('17ciao72'),('18'),('180'),('1800'),('180000'),('180001'),('18001800'),('1801'),('18011979'),('18011980'),('18011981'),('18011982'),('18011983'),('18011984'),('18011985'),('18011986'),('18011987'),('18011988'),('18011989'),('18011990'),('18011991'),('18011992'),('18011993'),('18011994'),('18011995'),('180179'),('180180'),('180181'),('180182'),('180183'),('180184'),('180185'),('180186'),('180187'),('180188'),('180189'),('180190'),('180191'),('180192'),('180193'),('180194'),('180195'),('180196'),('1802'),('18021977'),('18021978'),('18021979'),('18021980'),('18021981'),('18021982'),('18021983'),('18021984'),('18021985'),('18021986'),('18021987'),('18021988'),('18021989'),('18021990'),('18021991'),('18021992'),('18021993'),('18021994'),('18021995'),('18021996'),('180277'),('180278'),('180279'),('180280'),('180281'),('180282'),('180283'),('180284'),('180285'),('180286'),('180287'),('180288'),('180289'),('180290'),('180291'),('180292'),('180293'),('180294'),('180295'),('1803'),('18031977'),('18031978'),('18031979'),('18031980'),('18031981'),('18031982'),('18031983'),('18031984'),('18031985'),('18031986'),('18031987'),('18031988'),('18031989'),('18031990'),('18031991'),('18031992'),('18031993'),('18031994'),('18031995'),('18031996'),('18031997'),('180377'),('180378'),('180379'),('180380'),('180381'),('180382'),('180383'),('180384'),('180385'),('180386'),('180387'),('180388'),('180389'),('180390'),('180391'),('180392'),('180393'),('180394'),('180395'),('180396'),('1804'),('18041977'),('18041978'),('18041979'),('18041980'),('18041981'),('18041982'),('18041983'),('18041984'),('18041985'),('18041986'),('18041987'),('18041988'),('18041989'),('18041990'),('18041991'),('18041992'),('18041993'),('18041994'),('18041995'),('18041996'),('180476'),('180477'),('180478'),('180479'),('180480'),('180481'),('180482'),('180483'),('180484'),('180485'),('180486'),('180487'),('180488'),('180489'),('180490'),('180491'),('180492'),('180493'),('180494'),('180495'),('1805'),('18051959'),('18051978'),('18051979'),('18051980'),('18051981'),('18051982'),('18051983'),('18051984'),('18051985'),('18051986'),('18051987'),('18051988'),('18051989'),('18051990'),('18051991'),('18051992'),('18051993'),('18051994'),('18051995'),('180575'),('180576'),('180577'),('180578'),('180579'),('180580'),('180581'),('180582'),('180583'),('180584'),('180585'),('180586'),('180587'),('180588'),('180589'),('180590'),('180591'),('180592'),('180593'),('180594'),('180595'),('180596'),('1806'),('18061978'),('18061979'),('18061980'),('18061981'),('18061982'),('18061983'),('18061984'),('18061985'),('18061986'),('18061987'),('18061988'),('18061989'),('18061990'),('18061991'),('18061992'),('18061993'),('18061994'),('18061996'),('180676'),('180679'),('180680'),('180681'),('180682'),('180683'),('180684'),('180685'),('180686'),('180687'),('180688'),('180689'),('180690'),('180691'),('180692'),('180693'),('180694'),('180695'),('1807'),('18071979'),('18071980'),('18071981'),('18071982'),('18071983'),('18071984'),('18071985'),('18071986'),('18071987'),('18071988'),('18071989'),('18071990'),('18071991'),('18071992'),('18071993'),('18071994'),('18071995'),('180777'),('180778'),('180779'),('180780'),('180781'),('180782'),('180783'),('180784'),('180785'),('180786'),('180787'),('180788'),('180789'),('180790'),('180791'),('180792'),('180793'),('180794'),('180795'),('1808'),('180808'),('18081977'),('18081978'),('18081979'),('18081980'),('18081981'),('18081982'),('18081983'),('18081984'),('18081985'),('18081986'),('18081987'),('18081988'),('18081989'),('18081990'),('18081991'),('18081992'),('18081993'),('18081994'),('18081995'),('180878'),('180879'),('180880'),('180881'),('180882'),('180883'),('180884'),('180885'),('180886'),('180887'),('180888'),('180889'),('180890'),('180891'),('180892'),('180893'),('180894'),('180895'),('180898'),('1809'),('18091978'),('18091979'),('18091980'),('18091981'),('18091982'),('18091983'),('18091984'),('18091985'),('18091986'),('18091987'),('18091988'),('18091989'),('18091990'),('18091991'),('18091992'),('18091993'),('18091994'),('180977'),('180978'),('180979'),('180980'),('180981'),('180982'),('180983'),('180984'),('180985'),('180986'),('180987'),('180988'),('180989'),('180990'),('180991'),('180992'),('180993'),('180994'),('180995'),('181'),('1810'),('18101810'),('18101977'),('18101978'),('18101979'),('18101980'),('18101981'),('18101982'),('18101983'),('18101984'),('18101985'),('18101986'),('18101987'),('18101988'),('18101989'),('18101990'),('18101991'),('18101992'),('18101993'),('18101994'),('18101995'),('18101996'),('181077'),('181078'),('181079'),('181080'),('181081'),('181082'),('181083'),('181084'),('181085'),('181086'),('181087'),('181088'),('181089'),('181090'),('181091'),('181092'),('181093'),('181094'),('181095'),('181096'),('1811'),('18111976'),('18111978'),('18111980'),('18111981'),('18111982'),('18111983'),('18111984'),('18111985'),('18111986'),('18111987'),('18111988'),('18111989'),('18111990'),('18111991'),('18111992'),('18111993'),('18111994'),('18111995'),('181175'),('181176'),('181177'),('181178'),('181179'),('181180'),('181181'),('181182'),('181183'),('181184'),('181185'),('181186'),('181187'),('181188'),('181189'),('181190'),('181191'),('181192'),('181193'),('181194'),('181195'),('1812'),('181208q'),('18121812'),('18121977'),('18121978'),('18121979'),('18121980'),('18121981'),('18121982'),('18121983'),('18121984'),('18121985'),('18121986'),('18121987'),('18121988'),('18121989'),('18121990'),('18121991'),('18121992'),('18121993'),('18121994'),('18121995'),('18121996'),('181275'),('181276'),('181277'),('181278'),('181279'),('181280'),('181281'),('181282'),('181283'),('181284'),('181285'),('181286'),('181287'),('181288'),('181289'),('181290'),('181291'),('181292'),('181293'),('181294'),('181295'),('181296'),('1818'),('181818'),('18181818'),('1819'),('18191819'),('181920'),('181981'),('181982'),('181983'),('181984'),('181985'),('181986'),('181987'),('181988'),('181989'),('181990'),('181991'),('181992'),('181993'),('181994'),('181995'),('1821'),('18211821'),('182182'),('1824'),('18273645'),('182838'),('18297649'),('182blink'),('183183'),('183461'),('183729'),('18436572'),('185185'),('185800'),('1860'),('1867sb'),('187'),('187187'),('187211'),('1881'),('18811881'),('18811938'),('188188'),('1888'),('188888'),('189189'),('18atcskD2W'),('18dummy'),('18n28n24a5'),('18street'),('18wheeler'),('19'),('190'),('1900'),('190000'),('190001'),('19001560'),('19001570'),('19001900'),('1901'),('19011977'),('19011980'),('19011981'),('19011982'),('19011983'),('19011984'),('19011985'),('19011986'),('19011987'),('19011988'),('19011989'),('19011990'),('19011991'),('19011992'),('19011993'),('19011994'),('19011995'),('19011996'),('190178'),('190179'),('190180'),('190181'),('190182'),('190183'),('190184'),('190185'),('190186'),('190187'),('190188'),('190189'),('190190'),('190191'),('190192'),('190193'),('190194'),('190195'),('1902'),('19021902'),('19021975'),('19021977'),('19021978'),('19021979'),('19021980'),('19021981'),('19021982'),('19021983'),('19021984'),('19021985'),('19021986'),('19021987'),('19021988'),('19021989'),('19021990'),('19021991'),('19021992'),('19021993'),('19021994'),('19021995'),('19021996'),('190277'),('190278'),('190279'),('190280'),('190281'),('190282'),('190283'),('190284'),('190285'),('190286'),('190287'),('190288'),('190289'),('190290'),('190291'),('190292'),('190293'),('190294'),('190295'),('1903'),('190300'),('19031903'),('19031979'),('19031980'),('19031981'),('19031982'),('19031983'),('19031984'),('19031985'),('19031986'),('19031987'),('19031988'),('19031989'),('19031990'),('19031991'),('19031992'),('19031993'),('19031994'),('19031995'),('19031996'),('19031997'),('19032003'),('190377'),('190378'),('190379'),('190380'),('190381'),('190382'),('190383'),('190384'),('190385'),('190386'),('190387'),('190388'),('190389'),('190390'),('190391'),('190392'),('190393'),('190394'),('1903bjk'),('1904'),('19041977'),('19041978'),('19041979'),('19041980'),('19041981'),('19041982'),('19041983'),('19041984'),('19041985'),('19041986'),('19041987'),('19041988'),('19041989'),('19041990'),('19041991'),('19041992'),('19041993'),('19041994'),('19041995'),('190477'),('190478'),('190479'),('190480'),('190481'),('190482'),('190483'),('190484'),('190485'),('190486'),('190487'),('190488'),('190489'),('190490'),('190491'),('190492'),('190493'),('190494'),('190495'),('1905'),('190500'),('190505'),('19051905'),('19051977'),('19051978'),('19051979'),('19051980'),('19051981'),('19051982'),('19051983'),('19051984'),('19051985'),('19051986'),('19051987'),('19051988'),('19051989'),('19051990'),('19051991'),('19051992'),('19051993'),('19051994'),('19051995'),('19051996'),('19051997'),('19052005'),('190577'),('190578'),('190579'),('190580'),('190581'),('190582'),('190583'),('190584'),('190585'),('190586'),('190587'),('190588'),('190589'),('190590'),('190591'),('190592'),('190593'),('190594'),('190595'),('1905gs'),('1906'),('19061978'),('19061979'),('19061980'),('19061981'),('19061982'),('19061983'),('19061984'),('19061985'),('19061986'),('19061987'),('19061988'),('19061989'),('19061990'),('19061991'),('19061992'),('19061993'),('19061994'),('19061995'),('19061996'),('190678'),('190679'),('190680'),('190681'),('190682'),('190683'),('190684'),('190685'),('190686'),('190687'),('190688'),('190689'),('190690'),('190691'),('190692'),('190693'),('190694'),('190695'),('1907'),('190700'),('190707'),('19071907'),('19071978'),('19071979'),('19071980'),('19071981'),('19071982'),('19071983'),('19071984'),('19071985'),('19071986'),('19071987'),('19071988'),('19071989'),('19071990'),('19071991'),('19071992'),('19071993'),('19071994'),('19071995'),('19071996'),('19072007'),('190777'),('190778'),('190779'),('190780'),('190781'),('190782'),('190783'),('190784'),('190785'),('190786'),('190787'),('190788'),('190789'),('190790'),('190791'),('190792'),('190793'),('190794'),('1907fb'),('1907fener'),('1908'),('19081908'),('19081977'),('19081978'),('19081980'),('19081981'),('19081982'),('19081983'),('19081984'),('19081985'),('19081986'),('19081987'),('19081988'),('19081989'),('19081990'),('19081991'),('19081992'),('19081993'),('19081994'),('19081995'),('190876'),('190879'),('190880'),('190881'),('190882'),('190883'),('190884'),('190885'),('190886'),('190887'),('190888'),('190889'),('190890'),('190891'),('190892'),('190893'),('190894'),('190895'),('1909'),('190909'),('19091977'),('19091978'),('19091979'),('19091980'),('19091981'),('19091982'),('19091983'),('19091984'),('19091985'),('19091986'),('19091987'),('19091988'),('19091989'),('19091990'),('19091991'),('19091992'),('19091993'),('19091994'),('19091995'),('190979'),('190980'),('190981'),('190982'),('190983'),('190984'),('190985'),('190986'),('190987'),('190988'),('190989'),('190990'),('190991'),('190992'),('190993'),('190994'),('191'),('1910'),('19101910'),('19101977'),('19101978'),('19101979'),('19101980'),('19101981'),('19101982'),('19101983'),('19101984'),('19101985'),('19101986'),('19101987'),('19101988'),('19101989'),('19101990'),('19101991'),('19101992'),('19101993'),('19101994'),('19101995'),('191078'),('191079'),('191080'),('191081'),('191082'),('191083'),('191084'),('191085'),('191086'),('191087'),('191088'),('191089'),('191090'),('191091'),('191092'),('191093'),('191094'),('191095'),('1911'),('19111911'),('19111979'),('19111980'),('19111981'),('19111982'),('19111983'),('19111984'),('19111985'),('19111986'),('19111987'),('19111988'),('19111989'),('19111990'),('19111991'),('19111992'),('19111993'),('19111994'),('19111996'),('191177'),('191178'),('191179'),('191180'),('191181'),('191182'),('191183'),('191184'),('191185'),('191186'),('191187'),('191188'),('191189'),('191190'),('191191'),('191192'),('191193'),('191194'),('1911a1'),('1912'),('19121912'),('19121977'),('19121978'),('19121979'),('19121980'),('19121981'),('19121982'),('19121983'),('19121984'),('19121985'),('19121986'),('19121987'),('19121988'),('19121989'),('19121990'),('19121991'),('19121992'),('19121993'),('19121994'),('19121995'),('19121996'),('191277'),('191278'),('191279'),('191280'),('191281'),('191282'),('191283'),('191284'),('191285'),('191286'),('191287'),('191288'),('191289'),('191290'),('191291'),('191292'),('191293'),('191294'),('191295'),('1913'),('1914'),('19141914'),('1915'),('1916'),('1917'),('19171917'),('1918'),('191817'),('1919'),('191919'),('19191919'),('191979'),('191980'),('191981'),('191982'),('191983'),('191984'),('191985'),('191986'),('191987'),('191988'),('191989'),('191990'),('191991'),('191992'),('191993'),('192'),('1920'),('192000'),('19201920'),('192021'),('1921'),('192168'),('19216801'),('1922'),('19221922'),('1923'),('19231923'),('1924'),('1925'),('19251925'),('1926'),('1927'),('19271927'),('1928'),('19281928'),('192837'),('19283746'),('192837465'),('1928374655'),('192837465a'),('1929'),('192939'),('1930'),('1931'),('193193'),('1932'),('1933'),('1934'),('1935'),('1936'),('1937'),('19371937'),('193728'),('19372846'),('193746'),('193755'),('1938'),('19381938'),('1939'),('19391939'),('19391945'),('194'),('1940'),('19401940'),('1941'),('1941-1945'),('19411941'),('19411945'),('1942'),('19421942'),('1943'),('19431943'),('1944'),('19441944'),('1945'),('19451945'),('1946'),('19461946'),('1947'),('19471947'),('1948'),('19481948'),('1949'),('19491001'),('1949101'),('19491949'),('195'),('1950'),('195000'),('19501950'),('1951'),('19511951'),('1952'),('19521952'),('1953'),('19531953'),('1954'),('19541954'),('1955'),('19551955'),('195555'),('1955chevy'),('1956'),('19561956'),('1957'),('195700'),('19571957'),('1957chevy'),('1958'),('195800'),('19581958'),('1959'),('195900'),('19591959'),('196'),('1960'),('196000'),('19601960'),('1961'),('19611961'),('1962'),('196200'),('19621962'),('1963'),('196300'),('19631963'),('196363'),('1964'),('196400'),('19641964'),('196464'),('1965'),('196500'),('19651965'),('196565'),('1966'),('196600'),('19661966'),('196666'),('1967'),('196700'),('19671967'),('196767'),('1967gto'),('1968'),('196800'),('19681968'),('196868'),('1969'),('196900'),('19691969'),('196969'),('1969camaro'),('197'),('1970'),('197000'),('197011'),('19701970'),('197070'),('1971'),('197100'),('197111'),('19711971'),('197171'),('1972'),('197200'),('197210'),('197211'),('197212'),('197219'),('19721972'),('197222'),('197272'),('1973'),('197300'),('197310'),('197311'),('197312'),('197319'),('19731973'),('197328'),('197333'),('19733791'),('197346'),('19734682'),('197346825'),('197355'),('197373'),('1974'),('197400'),('197410'),('197411'),('197412'),('197419'),('19741974'),('197474'),('1975'),('197500'),('197505'),('197510'),('197511'),('197512'),('197519'),('19751975'),('197555'),('197575'),('1976'),('197600'),('197610'),('197611'),('197612'),('197619'),('19761968Serg'),('19761976'),('197666'),('197676'),('1977'),('197700'),('197710'),('197711'),('197712'),('197719'),('19771977'),('197722'),('197777'),('1978'),('197800'),('197801'),('197802'),('197803'),('197805'),('197806'),('197810'),('197811'),('197812'),('197819'),('19781978'),('197822'),('197825'),('197826'),('197828'),('197830'),('197878'),('197888'),('1979'),('197900'),('197901'),('197904'),('197906'),('197909'),('197910'),('197911'),('197912'),('197919'),('19791979'),('19791980'),('197922'),('197925'),('197926'),('197928'),('197929'),('197930'),('197979'),('197999'),('1979pool'),('198'),('1980'),('198000'),('198001'),('198002'),('198003'),('198005'),('198006'),('198007'),('198008'),('198010'),('198011'),('198012'),('198013'),('198018'),('198019'),('19801980'),('19801981'),('19801982'),('198020'),('198021'),('198022'),('198023'),('198024'),('198025'),('198026'),('198027'),('198028'),('198029'),('198030'),('198080'),('1981'),('198100'),('198101'),('198102'),('198103'),('19810301'),('198104'),('198105'),('198106'),('198107'),('198109'),('198110'),('198111'),('198112'),('198113'),('198118'),('198119'),('19811981'),('19811982'),('198121'),('198122'),('198123'),('198124'),('198125'),('198126'),('198127'),('198128'),('198129'),('198181'),('198198'),('1982'),('198200'),('198201'),('198202'),('198203'),('198204'),('198205'),('198206'),('198207'),('198208'),('198209'),('198210'),('19821010'),('19821012'),('19821020'),('19821023'),('19821028'),('198211'),('19821108'),('1982111'),('198212'),('19821209'),('19821212'),('198213'),('198214'),('198215'),('198216'),('198217'),('198218'),('198219'),('19821982'),('19821983'),('19821984'),('198220'),('198221'),('198222'),('198223'),('198224'),('198225'),('198226'),('198227'),('198228'),('19822891'),('198229'),('198282'),('198283'),('1982gonzo'),('1983'),('198300'),('198301'),('198302'),('198303'),('198304'),('198305'),('198306'),('198307'),('198308'),('198309'),('198310'),('19831010'),('19831015'),('19831020'),('19831022'),('198311'),('19831120'),('198312'),('19831212'),('198313'),('198314'),('198315'),('198316'),('198317'),('198318'),('198319'),('19831983'),('19831984'),('19831985'),('198320'),('198321'),('198322'),('198323'),('198324'),('198325'),('198326'),('198327'),('198328'),('198329'),('198333'),('19833891'),('198383'),('1984'),('198400'),('198401'),('198402'),('198403'),('198404'),('198405'),('198406'),('198407'),('198408'),('198409'),('198410'),('19841001'),('19841002'),('19841007'),('19841010'),('19841011'),('19841012'),('19841013'),('19841014'),('19841015'),('19841016'),('19841017'),('19841018'),('19841019'),('19841020'),('19841021'),('19841022'),('19841023'),('19841024'),('19841025'),('19841026'),('19841027'),('19841028'),('19841029'),('198411'),('19841120'),('19841121'),('19841123'),('19841124'),('19841125'),('198412'),('19841212'),('19841224'),('19841225'),('198413'),('198414'),('198415'),('198416'),('198417'),('198418'),('198419'),('19841984'),('19841985'),('19841986'),('198420'),('198421'),('198422'),('198423'),('198424'),('198425'),('198426'),('198427'),('198428'),('198429'),('198444'),('19844891'),('198456'),('198484'),('198488'),('1985'),('198500'),('198501'),('19850101'),('198502'),('198503'),('198504'),('198505'),('198506'),('198507'),('198508'),('198509'),('198510'),('19851001'),('19851010'),('19851011'),('19851012'),('19851015'),('19851016'),('19851018'),('19851020'),('19851022'),('19851023'),('19851024'),('19851025'),('19851028'),('19851030'),('198511'),('19851111'),('19851120'),('19851121'),('19851122'),('19851123'),('19851125'),('19851126'),('19851127'),('198512'),('19851203'),('19851210'),('19851211'),('19851212'),('19851213'),('19851215'),('19851216'),('19851217'),('19851218'),('19851220'),('19851223'),('19851224'),('19851225'),('19851228'),('1985123'),('19851230'),('198513'),('198514'),('198515'),('198516'),('198517'),('198518'),('198519'),('19851985'),('19851986'),('19851987'),('198520'),('198521'),('198522'),('198523'),('198524'),('198525'),('198526'),('198527'),('198528'),('198529'),('198531'),('198555'),('19855891'),('198566'),('198585'),('198586'),('198588'),('1986'),('198600'),('198601'),('19860101'),('198602'),('19860214'),('198603'),('198604'),('198605'),('198606'),('198607'),('198608'),('198609'),('198610'),('19861001'),('19861002'),('19861010'),('19861011'),('19861012'),('19861013'),('19861015'),('19861016'),('19861017'),('19861018'),('19861020'),('19861021'),('19861022'),('19861023'),('19861024'),('19861025'),('19861026'),('19861028'),('19861030'),('198611'),('19861103'),('19861106'),('19861110'),('19861111'),('19861115'),('19861119'),('19861120'),('19861121'),('19861122'),('19861123'),('19861124'),('19861125'),('19861126'),('198612'),('19861210'),('19861211'),('19861212'),('19861213'),('19861214'),('19861215'),('19861216'),('19861218'),('19861220'),('19861223'),('19861224'),('19861225'),('19861226'),('1986123'),('198613'),('198614'),('198615'),('198616'),('198617'),('198618'),('198619'),('19861986'),('19861987'),('19861988'),('198620'),('198621'),('198622'),('198623'),('198624'),('198625'),('198626'),('198627'),('198628'),('198629'),('198630'),('198631'),('198655'),('198666'),('19866891'),('198677'),('198686'),('198688'),('198699'),('1987'),('198700'),('198701'),('19870101'),('19870111'),('198702'),('19870212'),('198703'),('198704'),('198705'),('198706'),('198707'),('198708'),('198709'),('198710'),('19871010'),('19871012'),('19871015'),('19871016'),('19871020'),('19871021'),('19871023'),('19871024'),('19871025'),('19871026'),('19871028'),('19871029'),('198711'),('19871111'),('19871120'),('198712'),('19871212'),('19871225'),('1987123'),('198713'),('198714'),('198715'),('198716'),('198717'),('198718'),('198719'),('19871987'),('198719871987'),('19871988'),('19871989'),('198720'),('198721'),('198722'),('198723'),('198724'),('198725'),('198726'),('198727'),('198728'),('198729'),('198731'),('198765'),('198777'),('19877891'),('198787'),('198788'),('1988'),('198800'),('198801'),('198802'),('198803'),('198804'),('198805'),('198806'),('198807'),('198808'),('198809'),('198810'),('19881010'),('198811'),('198812'),('19881212'),('198813'),('198814'),('198815'),('198816'),('198817'),('198818'),('198819'),('19881988'),('19881989'),('198820'),('198821'),('198822'),('198823'),('198824'),('198825'),('198826'),('198827'),('198828'),('198829'),('198877'),('198888'),('19888891'),('1988comeer'),('1989'),('198900'),('198901'),('198902'),('198903'),('198904'),('198905'),('198906'),('198907'),('198908'),('198909'),('198910'),('198911'),('198912'),('19891229'),('198913'),('198914'),('198915'),('198916'),('198917'),('198918'),('198919'),('19891989'),('198920'),('198921'),('198922'),('198923'),('198924'),('198925'),('198926'),('198927'),('198928'),('198929'),('198989'),('19899891'),('198999'),('199'),('1990'),('199000'),('199001'),('199005'),('199006'),('199007'),('199009'),('19900991'),('199010'),('199011'),('199012'),('199013'),('199014'),('199015'),('199016'),('199017'),('199018'),('199019'),('19901990'),('19901991'),('199020'),('19902000ttt'),('199021'),('199022'),('199023'),('199025'),('199090'),('1991'),('199100'),('199101'),('199102'),('199103'),('199105'),('199106'),('199107'),('199108'),('199109'),('199110'),('199111'),('199112'),('199113'),('199114'),('199115'),('199116'),('199117'),('199118'),('199119'),('19911991'),('19911992'),('199120'),('19912009'),('199121'),('199122'),('199123'),('199124'),('199125'),('199126'),('199128'),('199129'),('199191'),('199199'),('1992'),('199200'),('199202'),('199203'),('199205'),('199207'),('199210'),('199211'),('199212'),('199213'),('199214'),('199215'),('199216'),('199217'),('199218'),('199219'),('19921992'),('19921993'),('199221'),('199222'),('199223'),('199224'),('199225'),('199226'),('199227'),('199228'),('199229'),('19922991'),('199292'),('1993'),('199300'),('199302'),('199303'),('199305'),('199308'),('199310'),('199311'),('199312'),('199313'),('199314'),('199315'),('199316'),('199317'),('199319'),('19931993'),('19931994'),('19932008'),('19932009'),('199321'),('199322'),('199323'),('199325'),('199327'),('19933991'),('199393'),('1993ga4mi'),('1994'),('199400'),('199404'),('199405'),('199406'),('199407'),('199410'),('19941028'),('199411'),('199412'),('199413'),('199414'),('199415'),('199416'),('199417'),('199418'),('199419'),('19941994'),('19941995'),('199420'),('19942009'),('199421'),('199422'),('199423'),('199424'),('199425'),('199427'),('199428'),('19944991'),('199494'),('1995'),('199500'),('199505'),('199510'),('199511'),('199512'),('199513'),('199514'),('199515'),('199516'),('199519'),('19951995'),('19951996'),('19952009'),('199522'),('199523'),('199525'),('199527'),('199555'),('19955991'),('199595'),('1996'),('199600'),('19960122'),('19960309'),('199610'),('199611'),('199612'),('199613'),('199614'),('199615'),('199619'),('19961996'),('19961997'),('199621'),('199622'),('199624'),('199626'),('19966991'),('199696'),('1997'),('199700'),('199710'),('199711'),('199712'),('199713'),('19971997'),('19971998'),('199771'),('19977991'),('199797'),('1998'),('199800'),('19980621'),('199810'),('199811'),('199812'),('19981998'),('199898'),('1999'),('199911'),('19991999'),('19992000'),('199991'),('199999'),('19weed'),('1a1a1a'),('1a1a1a1a'),('1a1a1a1a1a'),('1a2345'),('1a23456'),('1a2a3a'),('1a2a3a4a'),('1a2a3a4a5a'),('1a2a3a4a5a6a'),('1a2b3c'),('1a2b3c4d'),('1a2b3c4d5e'),('1a2b3c4d5e6f'),('1a2s3d'),('1a2s3d4f'),('1a2s3d4f5g'),('1a2s3d4f5g6h'),('1aaaaa'),('1aaaaaa'),('1aaliyah'),('1aaron'),('1abcde'),('1abcdef'),('1abcdefg'),('1abcdefgh'),('1adam12'),('1adgjm'),('1adgjmptw'),('1adrian'),('1alabama'),('1albert'),('1alejandro'),('1alexander'),('1alexis'),('1alicia'),('1allah'),('1alyssa'),('1amanda'),('1amber'),('1america'),('1american'),('1andonly'),('1andrea'),('1andrew'),('1angel'),('1angela'),('1angels'),('1animal'),('1anthony'),('1antonio'),('1apple'),('1apples'),('1april'),('1arsenal'),('1artist'),('1asdfg'),('1asdfgh'),('1asdfghj'),('1asdfghjkl'),('1ashley'),('1asshole'),('1atlanta'),('1austin'),('1azerty'),('1babyboy'),('1babydoll'),('1babygirl'),('1babygurl'),('1babylove'),('1badass'),('1badbitch'),('1badboy'),('1badgirl'),('1bailey'),('1balla'),('1baller'),('1ballin'),('1bambam'),('1banana'),('1bandit'),('1barbara'),('1barbie'),('1baseball'),('1basketbal'),('1bastard'),('1batman'),('1beast'),('1beautiful'),('1beauty'),('1bella'),('1benjamin'),('1bigboy'),('1bigcock'),('1bigdaddy'),('1bigdick'),('1bigdog'),('1bigfish'),('1bighead'),('1bigman'),('1bigpimp'),('1bigred'),('1billion'),('1bitch'),('1bitches'),('1black'),('1blessed'),('1blessing'),('1blondie'),('1blood'),('1blunt'),('1bobby'),('1booboo'),('1booger'),('1boomer'),('1boricua'),('1boston'),('1bowwow'),('1bradley'),('1brandon'),('1brandy'),('1brenda'),('1brian'),('1brianna'),('1brittany'),('1brooke'),('1brooklyn'),('1brother'),('1brown'),('1bubba'),('1bubble'),('1bubbles'),('1buddy'),('1budlight'),('1bulldog'),('1bullet'),('1bullshit'),('1bunny'),('1business'),('1buster'),('1butter'),('1buttercup'),('1butterfly'),('1butthead'),('1californi'),('1camaro'),('1cameron'),('1candy'),('1carlos'),('1carmen'),('1carolina'),('1carter'),('1casper'),('1cassie'),('1catdog'),('1cecream'),('1champ'),('1champion'),('1chance'),('1change'),('1charles'),('1charlie'),('1cheater'),('1cheer'),('1cheese'),('1chelsea'),('1cherry'),('1chester'),('1chevy'),('1cheyenne'),('1chicago'),('1chick'),('1chicken'),('1child'),('1chivas'),('1chocolate'),('1chopper'),('1chris'),('1chrisbrow'),('1christ'),('1christian'),('1christina'),('1christine'),('1christmas'),('1christoph'),('1church'),('1Ck75iflgA'),('1clen1'),('1cocacola'),('1coffee'),('1compaq'),('1computer'),('1cookie'),('1cookies'),('1cooldude'),('1coolguy'),('1cooper'),('1cor13'),('1corazon'),('1corona'),('1corvette'),('1country'),('1courtney'),('1cowboy'),('1cowboys'),('1cowgirl'),('1cracker'),('1crazy'),('1cricket'),('1crystal'),('1cupcake'),('1cutie'),('1cutiepie'),('1daddy'),('1daisy'),('1dakota'),('1dallas'),('1dance'),('1dancer'),('1daniel'),('1danielle'),('1danny'),('1daughter'),('1david'),('1death'),('1december'),('1denise'),('1dennis'),('1derful'),('1derrick'),('1destiny'),('1diamond'),('1dickhead'),('1dipset'),('1doggie'),('1doggy'),('1dollar'),('1dolphin'),('1donkey'),('1dontknow'),('1dragon'),('1dream'),('1dreamer'),('1drowssap'),('1drpepper'),('1drummer'),('1dumbass'),('1E'),('1E+14'),('1eagles'),('1eastside'),('1edward'),('1element'),('1elephant'),('1elijah'),('1elizabeth'),('1emily'),('1eminem'),('1estrella'),('1f3Q8AunKE'),('1faith'),('1family'),('1fatass'),('1fatboy'),('1fatcat'),('1father'),('1fender'),('1fineday'),('1fireman'),('1fish2fish'),('1fishing'),('1florida'),('1flower'),('1flowers'),('1fluffy'),('1football'),('1forall'),('1forever'),('1forgot'),('1forme'),('1foryou'),('1FpTJTl919'),('1Fr2rfq7xL'),('1frankie'),('1freak'),('1freedom'),('1freeman'),('1friend'),('1friends'),('1froggy'),('1fucker'),('1fuckme'),('1fuckoff'),('1fucku'),('1fuckyou'),('1g2w3e4r'),('1gabriel'),('1gangsta'),('1gangster'),('1gateway'),('1gemini'),('1george'),('1georgia'),('1getmoney'),('1ginger'),('1goddess'),('1godisgood'),('1golfer'),('1goodgirl'),('1google'),('1gracie'),('1grandma'),('1grandpa'),('1granny'),('1green'),('1greenday'),('1guitar'),('1hahaha'),('1hannah'),('1happy'),('1harley'),('1hater'),('1hateu'),('1hateyou'),('1heart'),('1heather'),('1heaven'),('1hello'),('1hiphop'),('1hockey'),('1hollywood'),('1honda'),('1honey'),('1horse'),('1horses'),('1hotbitch'),('1hotboy'),('1hotchick'),('1hotdog'),('1hotgirl'),('1hotmail'),('1hotmama'),('1hotmom'),('1hotmomma'),('1hotrod'),('1hotstuff'),('1hottie'),('1house'),('1houston'),('1hundred'),('1hunter'),('1husband'),('1hustler'),('1hxboqg2s'),('1icecream'),('1iffQb66tW'),('1ilove'),('1iloveme'),('1iloveu'),('1iloveyou'),('1indian'),('1inlove'),('1internet'),('1inuyasha'),('1isabella'),('1jackass'),('1jackie'),('1jackson'),('1jacob'),('1jamaica'),('1james'),('1jasmine'),('1jason'),('1jasper'),('1jayden'),('1jehovah'),('1jellybean'),('1jennifer'),('1jenny'),('1jeremy'),('1jessica'),('1jessie'),('1jesus'),('1jesus1'),('1jimmy'),('1johncena'),('1johnny'),('1johnson'),('1joker'),('1jonathan'),('1jordan'),('1joseph'),('1joshua'),('1juggalo'),('1junior'),('1justice'),('1justin'),('1katie'),('1kayla'),('1kelly'),('1kenneth'),('1kevin'),('1killa'),('1killer'),('1kimberly'),('1kingdom'),('1kisses'),('1kitten'),('1kitty'),('1kittycat'),('1knight'),('1l0v3y0u'),('1ladybug'),('1lakers'),('1larry'),('1lauren'),('1legend'),('1lesbian'),('1letmein'),('1life1love'),('1life2live'),('1light'),('1lilmama'),('1lilman'),('1lilwayne'),('1linda'),('1linkedin'),('1little'),('1liverpool'),('1lollipop'),('1london'),('1loser'),('1louise'),('1love'),('1love!'),('1love1'),('1love1life'),('1love2'),('1love4ever'),('1love4life'),('1love4me'),('1love4u'),('1lovebaby'),('1lovebug'),('1lovechris'),('1loved'),('1lovee'),('1lovegod'),('1loveher'),('1lovehim'),('1lovejesus'),('1lovelife'),('1lovelove'),('1lovely'),('1loveme'),('1lovemom'),('1lovemusic'),('1lover'),('1loverboy'),('1lovers'),('1loves'),('1loveu'),('1loveyou'),('1lucky'),('1luckydog'),('1madison'),('1maggie'),('1malaysia'),('1manarmy'),('1manuel'),('1marcus'),('1maria'),('1mariah'),('1marie'),('1marine'),('1marley'),('1martin'),('1maryjane'),('1master'),('1matthew'),('1maxwell'),('1melissa'),('1mercedes'),('1metallica'),('1mexican'),('1mexico'),('1michael'),('1michelle'),('1mickey'),('1midnight'),('1miguel'),('1miller'),('1million'),('1minnie'),('1missy'),('1mnbvcxz'),('1molly'),('1momma'),('1mommy'),('1monday'),('1money'),('1monica'),('1monique'),('1monkey'),('1monster'),('1montana'),('1moretime'),('1morgan'),('1mother'),('1mountain'),('1mouse'),('1muffin'),('1music'),('1mustang'),('1mylove'),('1myspace'),('1myspace1'),('1naruto'),('1natalie'),('1natasha'),('1nathan'),('1nation'),('1newlife'),('1newport'),('1newyork'),('1nicholas'),('1nicole'),('1nigga'),('1nigger'),('1night'),('1nikki'),('1ninja'),('1nirvana'),('1nonly'),('1norte4'),('1nothing'),('1november'),('1nternet'),('1number'),('1nurse'),('1ofakind'),('1oliver'),('1olivia'),('1Olmetec1'),('1onelove'),('1orange'),('1orlando'),('1oscar'),('1outlaw'),('1panther'),('1passion'),('1password'),('1password1'),('1password2'),('1patches'),('1patricia'),('1patrick'),('1peace'),('1peaches'),('1peanut'),('1pebbles'),('1peewee'),('1penguin'),('1penis'),('1penny'),('1people'),('1pepper'),('1person'),('1peter'),('1phoenix'),('1pickle'),('1piece'),('1pimpin'),('1pioneer'),('1pitbull'),('1pizza'),('1playa'),('1playboy'),('1player'),('1please'),('1pokemon'),('1police'),('1poohbear'),('1pookie'),('1poopoo'),('1popcorn'),('1potato'),('1pothead'),('1power'),('1precious'),('1pretty'),('1prince'),('1princess'),('1promise'),('1pumpkin'),('1puppy'),('1purple'),('1pussy'),('1q1a1z'),('1q1q1q'),('1q1q1q1'),('1q1q1q1q'),('1q1q1q1q1q'),('1q2'),('1q21q2'),('1q2345'),('1q23456'),('1q2a3z'),('1q2q3q'),('1q2q3q4q'),('1q2q3q4q5q'),('1q2w'),('1q2w1q2w'),('1q2w3'),('1q2w3e'),('1q2w3e1q2w3e'),('1q2w3e4'),('1q2w3e4r'),('1q2w3e4r5'),('1q2w3e4r5t'),('1q2w3e4r5t6'),('1q2w3e4r5t6y'),('1q2w3e4r5t6y7'),('1q2w3e4r5t6y7u'),('1q2w3e4r5t6y7u8'),('1q2w3e4r5t6y7u8i'),('1q2w3e4r5t6y7u8i9o'),('1q2w3e4r5t6y7u8i9o0p'),('1q2w3e4r5t6z'),('1q2w3easd'),('1q3e2w4r'),('1q3e5t'),('1q3e5t7u'),('1q3e5t7u9o'),('1qa'),('1qa1qa'),('1qa2ws'),('1qa2ws3ed'),('1qa2ws3ed4rf'),('1qa2ws3ed4rf5tg'),('1qasw2'),('1qasw23ed'),('1qaw321'),('1qay2wsx'),('1qayxsw2'),('1qaz'),('1qaz!QAZ'),('1qaz0okm'),('1qaz1qaz'),('1qaz2w'),('1qaz2ws'),('1qaz2wsx'),('1qaz2wsx3'),('1qaz2wsx3e'),('1qaz2wsx3edc'),('1qaz2wsx3edc4rfv'),('1qaz2wsx3edc4rfv5tgb'),('1qaz3edc'),('1qaz@WSX'),('1qazaq1'),('1qazqaz'),('1qazse4'),('1qazwsx'),('1qazwsxedc'),('1qazxc'),('1qazxcv'),('1qazxcvb'),('1qazxcvbnm'),('1qazxdr5'),('1qazxs'),('1qazxsw'),('1qazxsw2'),('1qazxsw23'),('1qazxsw23e'),('1qazxsw23edc'),('1qazxsw23edcvfr4'),('1qazxsw@'),('1qazzaq!'),('1qazzaq1'),('1qqqqq'),('1qqqqqq'),('1queen'),('1qw21qw2'),('1qw23e'),('1qw23er4'),('1qw23er45t'),('1qwaszx'),('1qweasd'),('1qweasdzxc'),('1qweqwe'),('1qwert'),('1qwerty'),('1qwerty1'),('1qwerty2'),('1qwerty7'),('1qwertyu'),('1qwertyui'),('1qwertyuio'),('1qwertyuiop'),('1rabbit'),('1rachel'),('1raider'),('1raiders'),('1rainbow'),('1ranger'),('1raymond'),('1realnigga'),('1rebecca'),('1redhead'),('1redneck'),('1redrose'),('1remember'),('1retard'),('1richard'),('1robert'),('1rocker'),('1rockstar'),('1rocky'),('1rooster'),('1rosebud'),('1runner'),('1s2s3s'),('1sabella'),('1sabrina'),('1samantha'),('1sammy'),('1samsung'),('1samuel'),('1sandra'),('1sarah'),('1sassy'),('1savage'),('1savannah'),('1savior'),('1sayang'),('1scarface'),('1school'),('1scooby'),('1scooter'),('1scorpio'),('1sebastian'),('1secret'),('1september'),('1sexy1'),('1sexybitch'),('1sexyboy'),('1sexygirl'),('1sexygurl'),('1sexylady'),('1sexymama'),('1sexyman'),('1shadow'),('1shannon'),('1shelby'),('1shithead'),('1shorty'),('1shot1kill'),('1silver'),('1singer'),('1single'),('1sister'),('1skate'),('1skater'),('1slipknot'),('1smile'),('1smokey'),('1snickers'),('1snoopy'),('1snowball'),('1snowman'),('1soccer'),('1softball'),('1soldier'),('1sophie'),('1southside'),('1space'),('1sparky'),('1spencer'),('1spider'),('1spiderman'),('1spirit'),('1spongebob'),('1starwars'),('1stborn'),('1stclass'),('1steelers'),('1stephanie'),('1stephen'),('1steven'),('1stlady'),('1stlove'),('1stoner'),('1stplace'),('1strawberr'),('1stunna'),('1stunner'),('1stupid'),('1success'),('1sucker'),('1sugar'),('1summer'),('1sunday'),('1sunflower'),('1sunshine'),('1superman'),('1superstar'),('1surfer'),('1sweet'),('1sweetie'),('1sweetpea'),('1sweety'),('1tattoo'),('1taylor'),('1teacher'),('1teddy'),('1teddybear'),('1tennis'),('1texas'),('1theman'),('1thing'),('1thomas'),('1thuglife'),('1thunder'),('1Thursday'),('1tiffany'),('1tiger'),('1tigers'),('1tigger'),('1timothy'),('1tinker'),('1tinkerbel'),('1toomany'),('1toyota'),('1travis'),('1treehill'),('1trinity'),('1trouble'),('1truck'),('1truelove'),('1truluv'),('1truth'),('1tucker'),('1tunde'),('1turkey'),('1turtle'),('1tweety'),('1two3four'),('1twothree'),('1ty2an3JA'),('1tyler'),('1um83z'),('1unicorn'),('1united'),('1urkilbth674'),('1v7Upjw3nT'),('1vagina'),('1vampire'),('1vanessa'),('1veronica'),('1victor'),('1victoria'),('1vincent'),('1vision'),('1w1w1w'),('1w2e3r4t'),('1w2q3r4e'),('1w2w3w'),('1w2w3w4w'),('1warrior'),('1water'),('1wayne'),('1welcome'),('1westside'),('1wetpussy'),('1whatever'),('1whore'),('1wifey'),('1wildcat'),('1william'),('1williams'),('1willie'),('1wilson'),('1winner'),('1winston'),('1winter'),('1woman'),('1wordpass'),('1world'),('1x2x3x'),('1xavier'),('1xxxxxx'),('1yahoo'),('1yamaha'),('1yankees'),('1yellow'),('1z1z1z'),('1z2x3c'),('1z2x3c4v'),('1z2x3c4v5b'),('1z2x3c4v5b6n'),('1z2z3z'),('1zachary'),('1zg1H9suza'),('1zn6FpN01n'),('1zn6FpN01x'),('1zxcvb'),('1zxcvbn'),('1zxcvbnm'),('1zyYbyt82A'),('1zzzzz'),('1й2ц3у'),('1й2ц3у4к'),('1й2ц3у4к5е'),('1�2��3��'),('1�2��3��4�'),('1�2��3��4�5��'),('1�����2������'),('2'),('20'),('200'),('2000'),('20000'),('200000'),('2000000'),('20000000'),('200001'),('200002'),('200008'),('200009'),('200010'),('200011'),('20002000'),('2000comeer'),('2001'),('200100'),('200101'),('200111'),('20011975'),('20011977'),('20011978'),('20011979'),('20011980'),('20011981'),('20011982'),('20011983'),('20011984'),('20011985'),('20011986'),('20011987'),('20011988'),('20011989'),('20011990'),('20011991'),('20011992'),('20011993'),('20011994'),('20011995'),('20011996'),('20012001'),('20012002'),('20012003'),('20012005'),('20012007'),('200177'),('200178'),('200179'),('200180'),('200181'),('200182'),('200183'),('200184'),('200185'),('200186'),('200187'),('200188'),('200189'),('200190'),('200191'),('200192'),('200193'),('200194'),('200195'),('2002'),('200200'),('200202'),('200206'),('200211'),('20021967'),('20021975'),('20021976'),('20021977'),('20021978'),('20021979'),('20021980'),('20021981'),('20021982'),('20021983'),('20021984'),('20021985'),('20021986'),('20021987'),('20021988'),('20021989'),('20021990'),('20021991'),('20021992'),('20021993'),('20021994'),('20021995'),('20021996'),('20021997'),('200220'),('20022002'),('20022003'),('20022004'),('20022006'),('20022007'),('200275'),('200276'),('200277'),('200278'),('200279'),('200280'),('200281'),('200282'),('200283'),('200284'),('200285'),('200286'),('200287'),('200288'),('200289'),('200290'),('200291'),('200292'),('200293'),('200295'),('200296'),('2003'),('200300'),('20031975'),('20031976'),('20031977'),('20031978'),('20031979'),('20031980'),('20031981'),('20031982'),('20031983'),('20031984'),('20031985'),('20031986'),('20031987'),('20031988'),('20031989'),('20031990'),('20031991'),('20031992'),('20031993'),('20031994'),('20031995'),('20031996'),('20031997'),('20032003'),('20032004'),('20032005'),('20032006'),('20032007'),('20032008'),('200375'),('200376'),('200377'),('200378'),('200379'),('200380'),('200381'),('200382'),('200383'),('200384'),('200385'),('200386'),('200387'),('200388'),('200389'),('200390'),('200391'),('200392'),('200393'),('200394'),('200395'),('200396'),('2004'),('200400'),('200404'),('200406'),('20041889'),('20041976'),('20041977'),('20041978'),('20041979'),('20041980'),('20041981'),('20041982'),('20041983'),('20041984'),('20041985'),('20041986'),('20041987'),('20041988'),('20041989'),('20041990'),('20041991'),('20041992'),('20041993'),('20041994'),('20041995'),('20041996'),('20042004'),('20042005'),('20042006'),('20042007'),('20042008'),('200476'),('200477'),('200478'),('200479'),('200480'),('200481'),('200482'),('200483'),('200484'),('200485'),('200486'),('200487'),('200488'),('200489'),('200490'),('200491'),('200492'),('200493'),('200494'),('200495'),('200496'),('2005'),('200500'),('200505'),('200506'),('20051975'),('20051976'),('20051977'),('20051978'),('20051979'),('20051980'),('20051981'),('20051982'),('20051983'),('20051984'),('20051985'),('20051986'),('20051987'),('20051988'),('20051989'),('20051990'),('20051991'),('20051992'),('20051993'),('20051994'),('20051995'),('20051996'),('20051997'),('20052005'),('20052006'),('20052007'),('20052008'),('20052009'),('200575'),('200576'),('200577'),('200578'),('200579'),('200580'),('200581'),('200582'),('200583'),('200584'),('200585'),('200586'),('200587'),('200588'),('200589'),('200590'),('200591'),('200592'),('200593'),('200594'),('200595'),('200596'),('2006'),('200600'),('200606'),('200608'),('200609'),('20061977'),('20061978'),('20061979'),('20061980'),('20061981'),('20061982'),('20061983'),('20061984'),('20061985'),('20061986'),('20061987'),('20061988'),('20061989'),('20061990'),('20061991'),('20061992'),('20061993'),('20061994'),('20061995'),('20061996'),('20061997'),('20062006'),('20062007'),('20062008'),('20062009'),('200666'),('200669'),('200675'),('200676'),('200677'),('200678'),('200679'),('200680'),('200681'),('200682'),('200683'),('200684'),('200685'),('200686'),('200687'),('200688'),('200689'),('200690'),('200691'),('200692'),('200693'),('200694'),('200695'),('200696'),('2007'),('200700'),('20070509031'),('200707'),('20071977'),('20071979'),('20071980'),('20071981'),('20071982'),('20071983'),('20071984'),('20071985'),('20071986'),('20071987'),('20071988'),('20071989'),('20071990'),('20071991'),('20071992'),('20071993'),('20071994'),('20071995'),('20071996'),('20072007'),('20072008'),('200776'),('200777'),('200778'),('200779'),('200780'),('200781'),('200782'),('200783'),('200784'),('200785'),('200786'),('200787'),('200788'),('200789'),('200790'),('200791'),('200792'),('200793'),('200794'),('200795'),('200796'),('2008'),('200800'),('200805'),('200808'),('20080808'),('200809'),('200810'),('20081975'),('20081977'),('20081978'),('20081979'),('20081980'),('20081981'),('20081982'),('20081983'),('20081984'),('20081985'),('20081986'),('20081987'),('20081988'),('20081989'),('20081990'),('20081991'),('20081992'),('20081993'),('20081994'),('20081995'),('20081996'),('20082008'),('200820082'),('20082009'),('200876'),('200877'),('200878'),('200879'),('200880'),('200881'),('200882'),('200883'),('200884'),('200885'),('200886'),('200887'),('200888'),('200889'),('200890'),('200891'),('200892'),('200893'),('200894'),('200895'),('200896'),('2009'),('200900'),('200908'),('200909'),('200910'),('20091975'),('20091977'),('20091978'),('20091979'),('20091980'),('20091981'),('20091982'),('20091983'),('20091984'),('20091985'),('20091986'),('20091987'),('20091988'),('20091989'),('20091990'),('20091991'),('20091992'),('20091993'),('20091994'),('20091995'),('20091996'),('20092008'),('20092009'),('20092010'),('200976'),('200977'),('200978'),('200979'),('200980'),('200981'),('200982'),('200983'),('200984'),('200985'),('200986'),('200987'),('200988'),('200989'),('200990'),('200991'),('200992'),('200993'),('200994'),('200995'),('200999'),('201'),('2010'),('201000'),('201001'),('201002'),('201003'),('201005'),('201007'),('20100728'),('201009'),('201010'),('201011'),('201012'),('201014'),('20101975'),('20101976'),('20101977'),('20101978'),('20101979'),('20101980'),('20101981'),('20101982'),('20101983'),('20101984'),('20101985'),('20101986'),('20101987'),('20101988'),('20101989'),('20101990'),('20101991'),('20101992'),('20101993'),('20101994'),('20101995'),('20101996'),('20101997'),('201020'),('20102000'),('20102007'),('20102010'),('20102011'),('201030'),('201061'),('201070'),('201075'),('201076'),('201077'),('201078'),('201079'),('201080'),('201081'),('201082'),('201083'),('201084'),('201085'),('201086'),('201087'),('201088'),('201089'),('201090'),('201091'),('201092'),('201093'),('201094'),('201095'),('2010comer'),('2011'),('201100'),('201102'),('201111'),('20111976'),('20111977'),('20111978'),('20111979'),('20111980'),('20111981'),('20111982'),('20111983'),('20111984'),('20111985'),('20111986'),('20111987'),('20111988'),('20111989'),('20111990'),('20111991'),('20111992'),('20111993'),('20111994'),('20111995'),('20111996'),('20112011'),('20112012'),('201175'),('201176'),('201177'),('201178'),('201179'),('201180'),('201181'),('201182'),('201183'),('201184'),('201185'),('201186'),('201187'),('201188'),('201189'),('201190'),('201191'),('201192'),('201193'),('201194'),('201195'),('201196'),('2012'),('201200'),('201201'),('201202'),('201203'),('201204'),('201206'),('201208'),('201212'),('20121204'),('20121207'),('20121975'),('20121976'),('20121977'),('20121978'),('20121979'),('20121980'),('20121981'),('20121982'),('20121983'),('20121984'),('20121985'),('20121986'),('20121987'),('20121988'),('20121989'),('20121990'),('20121991'),('20121992'),('20121993'),('20121994'),('20121995'),('20121996'),('20122012'),('201274'),('201275'),('201276'),('201277'),('201278'),('201279'),('201280'),('201281'),('201282'),('201283'),('201284'),('201285'),('201286'),('201287'),('201288'),('201289'),('201290'),('201291'),('201292'),('201293'),('201294'),('201295'),('201296'),('2012comeer'),('2013'),('201301'),('201303'),('201307'),('201308'),('201314'),('20132013'),('2014'),('20142014'),('2015'),('20152015'),('2016'),('201983'),('201984'),('201985'),('201986'),('201987'),('201988'),('201989'),('202'),('2020'),('202001'),('202002'),('202010'),('20202'),('202020'),('20202020'),('2020202020'),('202020a'),('202030'),('2020327'),('2020fb'),('2021'),('20212021'),('202122'),('2022'),('202202'),('20252025'),('2030'),('20302030'),('203040'),('20304050'),('203203'),('2040'),('204060'),('204204'),('20462046'),('205205'),('205gti'),('206206'),('208001'),('208208'),('209209'),('21'),('210'),('2100'),('210000'),('21002100'),('2101'),('210101'),('21011974'),('21011977'),('21011978'),('21011979'),('21011980'),('21011981'),('21011982'),('21011983'),('21011984'),('21011985'),('21011986'),('21011987'),('21011988'),('21011989'),('21011990'),('21011991'),('21011992'),('21011993'),('21011994'),('21011995'),('21011996'),('21011997'),('21012101'),('210175'),('210176'),('210177'),('210178'),('210179'),('210180'),('210181'),('210182'),('210183'),('210184'),('210185'),('210186'),('210187'),('210188'),('210189'),('210190'),('210191'),('210192'),('210193'),('210194'),('210195'),('210196'),('210197'),('2102'),('210210'),('21021978'),('21021979'),('21021980'),('21021981'),('21021982'),('21021983'),('21021984'),('21021985'),('21021986'),('21021987'),('21021988'),('21021989'),('21021990'),('21021991'),('21021992'),('21021993'),('21021994'),('21021995'),('21021996'),('210275'),('210277'),('210278'),('210279'),('210280'),('210281'),('210282'),('210283'),('210284'),('210285'),('210286'),('210287'),('210288'),('210289'),('210290'),('210291'),('210292'),('210293'),('210294'),('210295'),('210296'),('2103'),('21031977'),('21031978'),('21031979'),('21031980'),('21031981'),('21031982'),('21031983'),('21031984'),('21031985'),('21031986'),('21031987'),('21031988'),('21031989'),('21031990'),('21031991'),('21031992'),('21031993'),('21031994'),('21031995'),('21031996'),('21031997'),('21032103'),('210375'),('210376'),('210377'),('210378'),('210379'),('210380'),('210381'),('210382'),('210383'),('210384'),('210385'),('210386'),('210387'),('210388'),('210389'),('210390'),('210391'),('210392'),('210393'),('210394'),('210395'),('210396'),('2104'),('21041977'),('21041978'),('21041979'),('21041980'),('21041981'),('21041982'),('21041983'),('21041984'),('21041985'),('21041986'),('21041987'),('21041988'),('21041989'),('21041990'),('21041991'),('21041992'),('21041993'),('21041994'),('21041995'),('21041996'),('21042104'),('210476'),('210477'),('210478'),('210479'),('210480'),('210481'),('210482'),('210483'),('210484'),('210485'),('210486'),('210487'),('210488'),('210489'),('210490'),('210491'),('210492'),('210493'),('210494'),('210495'),('210496'),('2105'),('210505'),('21051976'),('21051977'),('21051978'),('21051979'),('21051980'),('21051981'),('21051982'),('21051983'),('21051984'),('21051985'),('21051986'),('21051987'),('21051988'),('21051989'),('21051990'),('21051991'),('21051992'),('21051993'),('21051994'),('21051995'),('21051996'),('21051997'),('21052003'),('21052105'),('210574'),('210575'),('210576'),('210577'),('210578'),('210579'),('210580'),('210581'),('210582'),('210583'),('210584'),('210585'),('210586'),('210587'),('210588'),('210589'),('210590'),('210591'),('210592'),('210593'),('210594'),('210595'),('210596'),('2106'),('21061978'),('21061979'),('21061980'),('21061981'),('21061982'),('21061983'),('21061984'),('21061985'),('21061986'),('21061987'),('21061988'),('21061989'),('21061990'),('21061991'),('21061992'),('21061993'),('21061994'),('21061995'),('21061996'),('21062106'),('210674'),('210675'),('210676'),('210677'),('210678'),('210679'),('210680'),('210681'),('210682'),('210683'),('210684'),('210685'),('210686'),('210687'),('210688'),('210689'),('210690'),('210691'),('210692'),('210693'),('210694'),('210695'),('210696'),('2107'),('210707'),('21071977'),('21071978'),('21071979'),('21071980'),('21071981'),('21071982'),('21071983'),('21071984'),('21071985'),('21071986'),('21071987'),('21071988'),('21071989'),('21071990'),('21071991'),('21071992'),('21071993'),('21071994'),('21071995'),('21072107'),('210774'),('210775'),('210777'),('210778'),('210779'),('210780'),('210781'),('210782'),('210783'),('210784'),('210785'),('210786'),('210787'),('210788'),('210789'),('210790'),('210791'),('210792'),('210793'),('210794'),('210795'),('2108'),('21081978'),('21081979'),('21081980'),('21081981'),('21081982'),('21081983'),('21081984'),('21081985'),('21081986'),('21081987'),('21081988'),('21081989'),('21081990'),('21081991'),('21081992'),('21081993'),('21081994'),('21081995'),('21081996'),('21082108'),('210874'),('210875'),('210876'),('210877'),('210878'),('210879'),('210880'),('210881'),('210882'),('210883'),('210884'),('210885'),('210886'),('210887'),('210888'),('210889'),('210890'),('210891'),('210892'),('210893'),('210894'),('210895'),('210896'),('2109'),('21091977'),('21091979'),('21091980'),('21091981'),('21091982'),('21091983'),('21091984'),('21091985'),('21091986'),('21091987'),('21091988'),('21091989'),('21091990'),('21091991'),('21091992'),('21091993'),('21091994'),('21091995'),('21092109'),('210975'),('210976'),('210977'),('210978'),('210979'),('210980'),('210981'),('210982'),('210983'),('210984'),('210985'),('210986'),('210987'),('210988'),('210989'),('210990'),('210991'),('210992'),('210993'),('210994'),('210995'),('210996'),('210999'),('211'),('2110'),('211001'),('211002'),('211003'),('211006'),('21101976'),('21101977'),('21101978'),('21101979'),('21101980'),('21101981'),('21101982'),('21101983'),('21101984'),('21101985'),('21101986'),('21101987'),('21101988'),('21101989'),('21101990'),('21101991'),('21101992'),('21101993'),('21101994'),('21101995'),('21102110'),('211075'),('211076'),('211077'),('211078'),('211079'),('211080'),('211081'),('211082'),('211083'),('211084'),('211085'),('211086'),('211087'),('211088'),('211089'),('211090'),('211091'),('211092'),('211093'),('211094'),('211095'),('211096'),('2111'),('211111'),('211112'),('21111977'),('21111978'),('21111979'),('21111980'),('21111981'),('21111982'),('21111983'),('21111984'),('21111985'),('21111986'),('21111987'),('21111988'),('21111989'),('21111990'),('21111991'),('21111992'),('21111993'),('21111994'),('21111995'),('211174'),('211176'),('211177'),('211178'),('211179'),('211180'),('211181'),('211182'),('211183'),('211184'),('211185'),('211186'),('211187'),('211188'),('211189'),('211190'),('211191'),('211192'),('211193'),('211194'),('211195'),('2112'),('211200'),('211211'),('211212'),('21121976'),('21121977'),('21121978'),('21121979'),('21121980'),('21121981'),('21121982'),('21121983'),('21121984'),('21121985'),('21121986'),('21121987'),('21121988'),('21121989'),('21121990'),('21121991'),('21121992'),('21121993'),('21121994'),('21121995'),('21121996'),('21122012'),('211221'),('21122112'),('211275'),('211276'),('211277'),('211278'),('211279'),('211280'),('211281'),('211282'),('211283'),('211284'),('211285'),('211286'),('211287'),('211288'),('211289'),('211290'),('211291'),('211292'),('211293'),('211294'),('211295'),('211296'),('2112rush'),('2113'),('211314'),('21152117'),('211981'),('211983'),('211984'),('211985'),('211986'),('211987'),('211988'),('211989'),('211990'),('211991'),('211994'),('211995'),('212'),('2120'),('2121'),('21212'),('212121'),('21212121'),('2121212121'),('212121a'),('212121q'),('2121321e'),('2121321q'),('2122'),('212212'),('21222122'),('212223'),('21222324'),('212224'),('212224236'),('2123'),('212321'),('21232123'),('212325'),('2124'),('2125'),('21252125'),('2128506'),('213'),('2131'),('21312131'),('213141'),('21314151'),('213213'),('213243'),('2134'),('21342134'),('213456'),('213546'),('213546879'),('214'),('214214'),('2143'),('214365'),('21436587'),('2143658709'),('214dallas'),('215215'),('215487'),('216216'),('217217'),('218218'),('218540'),('21864812'),('219219'),('2199127551'),('21AINIYAN'),('21guns'),('21love'),('22'),('220'),('2200'),('220011'),('220022'),('22002200'),('2201'),('22011979'),('22011980'),('22011981'),('22011982'),('22011983'),('22011984'),('22011985'),('22011986'),('22011987'),('22011988'),('22011989'),('22011990'),('22011991'),('22011992'),('22011993'),('22011994'),('22011995'),('22011996'),('22011997'),('22012201'),('220177'),('220178'),('220179'),('220180'),('220181'),('220182'),('220183'),('220184'),('220185'),('220186'),('220187'),('220188'),('220189'),('220190'),('220191'),('220192'),('220193'),('220194'),('220195'),('220196'),('2202'),('220202'),('22021977'),('22021978'),('22021979'),('22021980'),('22021981'),('22021982'),('22021983'),('22021984'),('22021985'),('22021986'),('22021987'),('22021988'),('22021989'),('22021990'),('22021991'),('22021992'),('22021993'),('22021994'),('22021995'),('22021996'),('22021997'),('220220'),('22022002'),('22022202'),('220272'),('220277'),('220278'),('220279'),('220280'),('220281'),('220282'),('220283'),('220284'),('220285'),('220286'),('220287'),('220288'),('220289'),('220290'),('220291'),('220292'),('220293'),('220294'),('220295'),('220296'),('2203'),('22031975'),('22031976'),('22031977'),('22031978'),('22031979'),('22031980'),('22031981'),('22031982'),('22031983'),('22031984'),('22031985'),('22031986'),('22031987'),('22031988'),('22031989'),('22031990'),('22031991'),('22031992'),('22031993'),('22031994'),('22031995'),('22031996'),('22032203'),('220376'),('220377'),('220378'),('220379'),('220380'),('220381'),('220382'),('220383'),('220384'),('220385'),('220386'),('220387'),('220388'),('220389'),('220390'),('220391'),('220392'),('220393'),('220394'),('220395'),('220396'),('2204'),('22041976'),('22041977'),('22041978'),('22041979'),('22041980'),('22041981'),('22041982'),('22041983'),('22041984'),('22041985'),('22041986'),('22041987'),('22041988'),('22041989'),('22041990'),('22041991'),('22041992'),('22041993'),('22041994'),('22041995'),('22041996'),('22041997'),('220470'),('220474'),('220475'),('220476'),('220477'),('220478'),('220479'),('220480'),('220481'),('220482'),('220483'),('220484'),('220485'),('220486'),('220487'),('220488'),('220489'),('220490'),('220491'),('220492'),('220493'),('220494'),('220495'),('220496'),('220497'),('2205'),('22051977'),('22051978'),('22051979'),('22051980'),('22051981'),('22051982'),('22051983'),('22051984'),('22051985'),('22051986'),('22051987'),('22051988'),('22051989'),('22051990'),('22051991'),('22051992'),('22051993'),('22051994'),('22051995'),('22051996'),('22051997'),('22052205'),('220574'),('220575'),('220576'),('220577'),('220578'),('220579'),('220580'),('220581'),('220582'),('220583'),('220584'),('220585'),('220586'),('220587'),('220588'),('220589'),('220590'),('220591'),('220592'),('220593'),('220594'),('220595'),('220596'),('220597'),('2206'),('22061941'),('22061976'),('22061977'),('22061978'),('22061979'),('22061980'),('22061981'),('22061982'),('22061983'),('22061984'),('22061985'),('22061986'),('22061987'),('22061988'),('22061989'),('22061990'),('22061991'),('22061992'),('22061993'),('22061994'),('22061995'),('22061996'),('220641'),('220673'),('220674'),('220675'),('220676'),('220677'),('220678'),('220679'),('220680'),('220681'),('220682'),('220683'),('220684'),('220685'),('220686'),('220687'),('220688'),('220689'),('220690'),('220691'),('220692'),('220693'),('220694'),('220695'),('220696'),('2207'),('22071972'),('22071977'),('22071979'),('22071980'),('22071981'),('22071982'),('22071983'),('22071984'),('22071985'),('22071986'),('22071987'),('22071988'),('22071989'),('22071990'),('22071991'),('22071992'),('22071993'),('22071994'),('22071995'),('220775'),('220776'),('220777'),('220778'),('220779'),('220780'),('220781'),('220782'),('220783'),('220784'),('220785'),('220786'),('220787'),('220788'),('220789'),('220790'),('220791'),('220792'),('220793'),('220794'),('220795'),('220796'),('2208'),('220808'),('22081977'),('22081978'),('22081979'),('22081980'),('22081981'),('22081982'),('22081983'),('22081984'),('22081985'),('22081986'),('22081987'),('22081988'),('22081989'),('22081990'),('22081991'),('22081992'),('22081993'),('22081994'),('22081995'),('22081996'),('220874'),('220875'),('220876'),('220877'),('220878'),('220879'),('220880'),('220881'),('220882'),('220883'),('220884'),('220885'),('220886'),('220887'),('220888'),('220889'),('220890'),('220891'),('220892'),('220893'),('220894'),('220895'),('220896'),('2209'),('220907'),('22091978'),('22091979'),('22091980'),('22091981'),('22091982'),('22091983'),('22091984'),('22091985'),('22091986'),('22091987'),('22091988'),('22091989'),('22091990'),('22091991'),('22091992'),('22091993'),('22091994'),('22091995'),('22091996'),('220975'),('220976'),('220977'),('220978'),('220979'),('220980'),('220981'),('220982'),('220983'),('220984'),('220985'),('220986'),('220987'),('220988'),('220989'),('220990'),('220991'),('220992'),('220993'),('220994'),('220995'),('220a220a'),('221'),('2210'),('221001'),('221002'),('221005'),('221010'),('22101976'),('22101977'),('22101978'),('22101979'),('22101980'),('22101981'),('22101982'),('22101983'),('22101984'),('22101985'),('22101986'),('22101987'),('22101988'),('22101989'),('22101990'),('22101991'),('22101992'),('22101993'),('22101994'),('22101995'),('22101996'),('22101997'),('221022'),('22102210'),('221074'),('221075'),('221076'),('221077'),('221078'),('221079'),('221080'),('221081'),('221082'),('221083'),('221084'),('221085'),('221086'),('221087'),('221088'),('221089'),('221090'),('221091'),('221092'),('221093'),('221094'),('221095'),('221096'),('2211'),('221100'),('221108'),('22111976'),('22111978'),('22111979'),('22111980'),('22111981'),('22111982'),('22111983'),('22111984'),('22111985'),('22111986'),('22111987'),('22111988'),('22111989'),('22111990'),('22111991'),('22111992'),('22111993'),('22111994'),('22111995'),('221122'),('22112211'),('221133'),('221166'),('221171'),('221172'),('221173'),('221174'),('221175'),('221176'),('221177'),('221178'),('221179'),('221180'),('221181'),('221182'),('221183'),('221184'),('221185'),('221186'),('221187'),('221188'),('221189'),('221190'),('221191'),('221192'),('221193'),('221194'),('221195'),('221196'),('221199'),('2212'),('221200'),('22121977'),('22121978'),('22121979'),('22121980'),('22121981'),('22121982'),('22121983'),('22121984'),('22121985'),('22121986'),('22121987'),('22121988'),('22121989'),('22121990'),('22121991'),('22121992'),('22121993'),('22121994'),('22121995'),('22121996'),('221221'),('221222'),('22122212'),('221226'),('221272'),('221275'),('221276'),('221277'),('221278'),('221279'),('221280'),('221281'),('221282'),('221283'),('221284'),('221285'),('221286'),('221287'),('221288'),('221289'),('221290'),('221291'),('221292'),('221293'),('221294'),('221295'),('221296'),('2213'),('22132213'),('2214'),('2215'),('22152182'),('221969'),('221978'),('221980'),('221981'),('221982'),('221983'),('221984'),('221985'),('221986'),('221987'),('221988'),('221989'),('221990'),('221991'),('221992'),('221993'),('221994'),('222'),('222000'),('2221'),('222111'),('2222'),('22221111'),('22222'),('222221'),('222222'),('2222221'),('2222222'),('22222222'),('222222222'),('2222222222'),('222222222222'),('222222a'),('222222q'),('222223'),('22222a'),('222233'),('22223333'),('22224444'),('2222ww'),('2223'),('222324'),('222333'),('222333444'),('2224'),('222444'),('2225'),('222555'),('222666'),('222777'),('222888'),('2229'),('222999'),('222www'),('223'),('22312231'),('2232'),('223223'),('2233'),('223300'),('223311'),('223322'),('22332233'),('223344'),('22334455'),('2233445566'),('223355'),('223366'),('2234'),('223456'),('2234562'),('223456789'),('2236'),('22362236'),('223856'),('2238qwer'),('223qwe'),('224'),('224224'),('2244'),('224422'),('22442244'),('224455'),('224466'),('22446688'),('2244668800'),('224488'),('2246926'),('225'),('225225'),('2255'),('225500'),('225522'),('22552255'),('225566'),('225577'),('225588'),('22558800'),('226001'),('226010'),('226012'),('226016'),('226226'),('2266'),('226622'),('226688'),('227227'),('2277'),('227722'),('22772277'),('228'),('228228'),('228228228'),('2288'),('228822'),('22882288'),('229229'),('22janv67'),('22love'),('22tt22'),('23'),('230'),('2300'),('230000'),('2301'),('230101'),('23011978'),('23011980'),('23011981'),('23011982'),('23011983'),('23011984'),('23011985'),('23011986'),('23011987'),('23011988'),('23011989'),('23011990'),('23011991'),('23011992'),('23011993'),('23011994'),('23011995'),('23011996'),('23011997'),('23012301'),('230176'),('230177'),('230178'),('230179'),('230180'),('230181'),('230182'),('230183'),('230184'),('230185'),('230186'),('230187'),('230188'),('230189'),('230190'),('230191'),('230192'),('230193'),('230194'),('230195'),('230196'),('2302'),('23021977'),('23021978'),('23021979'),('23021980'),('23021981'),('23021982'),('23021983'),('23021984'),('23021985'),('23021986'),('23021987'),('23021988'),('23021989'),('23021990'),('23021991'),('23021992'),('23021993'),('23021994'),('23021995'),('23021996'),('23022302'),('230230'),('230276'),('230277'),('230278'),('230279'),('230280'),('230281'),('230282'),('230283'),('230284'),('230285'),('230286'),('230287'),('230288'),('230289'),('230290'),('230291'),('230292'),('230293'),('230294'),('230295'),('230296'),('2303'),('230303'),('23031977'),('23031978'),('23031979'),('23031980'),('23031981'),('23031982'),('23031983'),('23031984'),('23031985'),('23031986'),('23031987'),('23031988'),('23031989'),('23031990'),('23031991'),('23031992'),('23031993'),('23031994'),('23031995'),('23031996'),('23032303'),('230373'),('230376'),('230377'),('230378'),('230379'),('230380'),('230381'),('230382'),('230383'),('230384'),('230385'),('230386'),('230387'),('230388'),('230389'),('230390'),('230391'),('230392'),('230393'),('230394'),('230395'),('230396'),('2304'),('23041977'),('23041978'),('23041979'),('23041980'),('23041981'),('23041982'),('23041983'),('23041984'),('23041985'),('23041986'),('23041987'),('23041988'),('23041989'),('23041990'),('23041991'),('23041992'),('23041993'),('23041994'),('23041995'),('23041996'),('23041997'),('23042304'),('230475'),('230476'),('230477'),('230478'),('230479'),('230480'),('230481'),('230482'),('230483'),('230484'),('230485'),('230486'),('230487'),('230488'),('230489'),('230490'),('230491'),('230492'),('230493'),('230494'),('230495'),('230496'),('2305'),('23051978'),('23051979'),('23051980'),('23051981'),('23051982'),('23051983'),('23051984'),('23051985'),('23051986'),('23051987'),('23051988'),('23051989'),('23051990'),('23051991'),('23051992'),('23051993'),('23051994'),('23051995'),('23051996'),('23051997'),('23052305'),('230575'),('230576'),('230577'),('230578'),('230579'),('230580'),('230581'),('230582'),('230583'),('230584'),('230585'),('230586'),('230587'),('230588'),('230589'),('230590'),('230591'),('230592'),('230593'),('230594'),('230595'),('230596'),('230597'),('2306'),('23061976'),('23061978'),('23061979'),('23061980'),('23061981'),('23061982'),('23061983'),('23061984'),('23061985'),('23061986'),('23061987'),('23061988'),('23061989'),('23061990'),('23061991'),('23061992'),('23061993'),('23061994'),('23061995'),('23061996'),('230675'),('230676'),('230677'),('230678'),('230679'),('230680'),('230681'),('230682'),('230683'),('230684'),('230685'),('230686'),('230687'),('230688'),('230689'),('230690'),('230691'),('230692'),('230693'),('230694'),('230695'),('2307'),('230708'),('23071977'),('23071978'),('23071979'),('23071980'),('23071981'),('23071982'),('23071983'),('23071984'),('23071985'),('23071986'),('23071987'),('23071988'),('23071989'),('23071990'),('23071991'),('23071992'),('23071993'),('23071994'),('23071995'),('23071996'),('230776'),('230777'),('230778'),('230779'),('230780'),('230781'),('230782'),('230783'),('230784'),('230785'),('230786'),('230787'),('230788'),('230789'),('230790'),('230791'),('230792'),('230793'),('230794'),('230795'),('230796'),('2308'),('230808'),('23081977'),('23081978'),('23081979'),('23081980'),('23081981'),('23081982'),('23081983'),('23081984'),('23081985'),('23081986'),('23081987'),('23081988'),('23081989'),('23081990'),('23081991'),('23081992'),('23081993'),('23081994'),('23081995'),('23081996'),('23082308'),('230874'),('230876'),('230877'),('230878'),('230879'),('230880'),('230881'),('230882'),('230883'),('230884'),('230885'),('230886'),('230887'),('230888'),('230889'),('230890'),('230891'),('230892'),('230893'),('230894'),('230895'),('230896'),('230897'),('2309'),('23091977'),('23091978'),('23091979'),('23091980'),('23091981'),('23091982'),('23091983'),('23091984'),('23091985'),('23091986'),('23091987'),('23091988'),('23091989'),('23091990'),('23091991'),('23091992'),('23091993'),('23091994'),('23091995'),('230974'),('230975'),('230976'),('230977'),('230978'),('230979'),('230980'),('230981'),('230982'),('230983'),('230984'),('230985'),('230986'),('230987'),('230988'),('230989'),('230990'),('230991'),('230992'),('230993'),('230994'),('230995'),('230996'),('231'),('2310'),('231000'),('23101977'),('23101978'),('23101979'),('23101980'),('23101981'),('23101982'),('23101983'),('23101984'),('23101985'),('23101986'),('23101987'),('23101988'),('23101989'),('23101990'),('23101991'),('23101992'),('23101993'),('23101994'),('23101995'),('23101996'),('23102310'),('231072'),('231074'),('231075'),('231076'),('231077'),('231078'),('231079'),('231080'),('231081'),('231082'),('231083'),('231084'),('231085'),('231086'),('231087'),('231088'),('231089'),('231090'),('231091'),('231092'),('231093'),('231094'),('231095'),('231096'),('231097'),('2311'),('23111977'),('23111978'),('23111979'),('23111980'),('23111981'),('23111982'),('23111983'),('23111984'),('23111985'),('23111986'),('23111987'),('23111988'),('23111989'),('23111990'),('23111991'),('23111992'),('23111993'),('23111994'),('23111995'),('231123'),('23112311'),('231175'),('231176'),('231177'),('231178'),('231179'),('231180'),('231181'),('231182'),('231183'),('231184'),('231185'),('231186'),('231187'),('231188'),('231189'),('231190'),('231191'),('231192'),('231193'),('231194'),('231195'),('231196'),('2312'),('231200'),('23121977'),('23121978'),('23121979'),('23121980'),('23121981'),('23121982'),('23121983'),('23121984'),('23121985'),('23121986'),('23121987'),('23121988'),('23121989'),('23121990'),('23121991'),('23121992'),('23121993'),('23121994'),('23121995'),('23121996'),('23121997'),('23122312'),('231231'),('231274'),('231275'),('231276'),('231277'),('231278'),('231279'),('231280'),('231281'),('231282'),('231283'),('231284'),('231285'),('231286'),('231287'),('231288'),('231289'),('231290'),('231291'),('231292'),('231293'),('231294'),('231295'),('231296'),('231297'),('23132313'),('2314'),('23142314'),('231456'),('2315'),('231977'),('231978'),('231979'),('231980'),('231981'),('231982'),('231983'),('231984'),('231985'),('231986'),('231987'),('231988'),('231989'),('231990'),('231991'),('231992'),('231993'),('231994'),('231995'),('232'),('2321'),('23212321'),('232232'),('2323'),('232323'),('23232323'),('2323232323'),('232323a'),('2324'),('23242324'),('232425'),('23242526'),('2325'),('23252325'),('2326'),('23262326'),('232629'),('2327'),('2332'),('233223'),('23322332'),('233233'),('2333'),('233391'),('234'),('2341'),('234234'),('234234234'),('234432'),('2345'),('23452345'),('23456'),('234561'),('234567'),('2345678'),('23456789'),('234567890'),('2345678z'),('234589'),('234649'),('234wer'),('235'),('235235'),('2356'),('23562356'),('235689'),('2357'),('235711'),('236236'),('23628221'),('236589'),('2369'),('23692369'),('237237'),('238238'),('239239'),('23isback'),('23jordan'),('23love'),('23skidoo'),('23wesdxc'),('24'),('240'),('240000'),('2401'),('24011980'),('24011981'),('24011982'),('24011983'),('24011984'),('24011985'),('24011986'),('24011987'),('24011988'),('24011989'),('24011990'),('24011991'),('24011992'),('24011993'),('24011994'),('24011995'),('24011996'),('240177'),('240178'),('240179'),('240180'),('240181'),('240182'),('240183'),('240184'),('240185'),('240186'),('240187'),('240188'),('240189'),('240190'),('240191'),('240192'),('240193'),('240194'),('240195'),('240196'),('2402'),('24021976'),('24021978'),('24021980'),('24021981'),('24021982'),('24021983'),('24021984'),('24021985'),('24021986'),('24021987'),('24021988'),('24021989'),('24021990'),('24021991'),('24021992'),('24021993'),('24021994'),('24021995'),('24021996'),('240277'),('240278'),('240279'),('240280'),('240281'),('240282'),('240283'),('240284'),('240285'),('240286'),('240287'),('240288'),('240289'),('240290'),('240291'),('240292'),('240293'),('240294'),('240295'),('2403'),('24031977'),('24031979'),('24031980'),('24031981'),('24031982'),('24031983'),('24031984'),('24031985'),('24031986'),('24031987'),('24031988'),('24031989'),('24031990'),('24031991'),('24031992'),('24031993'),('24031994'),('24031995'),('240377'),('240378'),('240379'),('240380'),('240381'),('240382'),('240383'),('240384'),('240385'),('240386'),('240387'),('240388'),('240389'),('240390'),('240391'),('240392'),('240393'),('240394'),('240395'),('2404'),('240404'),('24041978'),('24041979'),('24041980'),('24041981'),('24041982'),('24041983'),('24041984'),('24041985'),('24041986'),('24041987'),('24041988'),('24041989'),('24041990'),('24041991'),('24041992'),('24041993'),('24041994'),('24041995'),('24041996'),('240474'),('240477'),('240478'),('240479'),('240480'),('240481'),('240482'),('240483'),('240484'),('240485'),('240486'),('240487'),('240488'),('240489'),('240490'),('240491'),('240492'),('240493'),('240494'),('240495'),('240496'),('2405'),('24051978'),('24051980'),('24051981'),('24051982'),('24051983'),('24051984'),('24051985'),('24051986'),('24051987'),('24051988'),('24051989'),('24051990'),('24051991'),('24051992'),('24051993'),('24051994'),('24051995'),('24051996'),('240575'),('240576'),('240577'),('240578'),('240579'),('240580'),('240581'),('240582'),('240583'),('240584'),('240585'),('240586'),('240587'),('240588'),('240589'),('240590'),('240591'),('240592'),('240593'),('240594'),('240595'),('240596'),('2406'),('24061978'),('24061979'),('24061980'),('24061981'),('24061982'),('24061983'),('24061984'),('24061985'),('24061986'),('24061987'),('24061988'),('24061989'),('24061990'),('24061991'),('24061992'),('24061993'),('24061994'),('24061995'),('240675'),('240677'),('240678'),('240679'),('240680'),('240681'),('240682'),('240683'),('240684'),('240685'),('240686'),('240687'),('240688'),('240689'),('240690'),('240691'),('240692'),('240693'),('240694'),('240695'),('2407'),('24071980'),('24071981'),('24071982'),('24071983'),('24071984'),('24071985'),('24071986'),('24071987'),('24071988'),('24071989'),('24071990'),('24071991'),('24071992'),('24071993'),('24071994'),('24071995'),('240777'),('240778'),('240779'),('240780'),('240781'),('240782'),('240783'),('240784'),('240785'),('240786'),('240787'),('240788'),('240789'),('240790'),('240791'),('240792'),('240793'),('240795'),('2408'),('24081977'),('24081978'),('24081979'),('24081980'),('24081981'),('24081982'),('24081983'),('24081984'),('24081985'),('24081986'),('24081987'),('24081988'),('24081989'),('24081990'),('24081991'),('24081992'),('24081993'),('24081994'),('24081995'),('24081996'),('240876'),('240877'),('240878'),('240879'),('240880'),('240881'),('240882'),('240883'),('240884'),('240885'),('240886'),('240887'),('240888'),('240889'),('240890'),('240891'),('240892'),('240893'),('240894'),('240895'),('240896'),('2409'),('24091979'),('24091980'),('24091981'),('24091982'),('24091983'),('24091984'),('24091985'),('24091986'),('24091987'),('24091988'),('24091989'),('24091990'),('24091991'),('24091992'),('24091993'),('24091994'),('240976'),('240977'),('240978'),('240979'),('240980'),('240981'),('240982'),('240983'),('240984'),('240985'),('240986'),('240987'),('240988'),('240989'),('240990'),('240991'),('240992'),('240993'),('240994'),('240995'),('240996'),('241'),('2410'),('24101977'),('24101978'),('24101979'),('24101980'),('24101981'),('24101982'),('24101983'),('24101984'),('24101985'),('24101986'),('24101987'),('24101988'),('24101989'),('24101990'),('24101991'),('24101992'),('24101993'),('24101994'),('24101995'),('24101996'),('24102410'),('241074'),('241075'),('241076'),('241077'),('241078'),('241079'),('241080'),('241081'),('241082'),('241083'),('241084'),('241085'),('241086'),('241087'),('241088'),('241089'),('241090'),('241091'),('241092'),('241093'),('241094'),('241095'),('241096'),('241097'),('241098'),('2411'),('24111978'),('24111979'),('24111980'),('24111981'),('24111982'),('24111983'),('24111984'),('24111985'),('24111986'),('24111987'),('24111988'),('24111989'),('24111990'),('24111991'),('24111992'),('24111993'),('24111994'),('24111995'),('24112411'),('241175'),('241176'),('241177'),('241178'),('241179'),('241180'),('241181'),('241182'),('241183'),('241184'),('241185'),('241186'),('241187'),('241188'),('241189'),('241190'),('241191'),('241192'),('241193'),('241194'),('241195'),('241196'),('2412'),('24121976'),('24121977'),('24121978'),('24121979'),('24121980'),('24121981'),('24121982'),('24121983'),('24121984'),('24121985'),('24121986'),('24121987'),('24121988'),('24121989'),('24121990'),('24121991'),('24121992'),('24121993'),('24121994'),('24121995'),('24121996'),('24122412'),('241241'),('241275'),('241276'),('241277'),('241278'),('241279'),('241280'),('241281'),('241282'),('241283'),('241284'),('241285'),('241286'),('241287'),('241288'),('241289'),('241290'),('241291'),('241292'),('241293'),('241294'),('241295'),('241296'),('2416101113'),('241980'),('241981'),('241982'),('241983'),('241984'),('241985'),('241986'),('241987'),('241988'),('241989'),('241990'),('241991'),('241992'),('241993'),('241994'),('242'),('242242'),('2424'),('242424'),('24242424'),('2425'),('24252425'),('242526'),('2426'),('24262426'),('242628'),('243243'),('244'),('244001'),('2442'),('24422442'),('245245'),('2455'),('245678'),('246'),('246135'),('246246'),('246789'),('2468'),('24680'),('246800'),('246801'),('2468013579'),('246802'),('246810'),('24681012'),('2468101214'),('246810a'),('246812'),('246813'),('24681357'),('246813579'),('246824'),('24682468'),('24685'),('246855'),('24688642'),('24689'),('246890'),('246891'),('2469'),('24692469'),('247001'),('247247'),('247365'),('248001'),('2481632'),('248248'),('2486'),('248624'),('24862486'),('248655'),('24crow'),('24gordon'),('24hours'),('24kobe'),('24seven'),('25'),('250'),('2500'),('250000'),('250001'),('25002500'),('2500hd'),('2501'),('25011978'),('25011979'),('25011980'),('25011981'),('25011982'),('25011983'),('25011984'),('25011985'),('25011986'),('25011987'),('25011988'),('25011989'),('25011990'),('25011991'),('25011992'),('25011993'),('25011994'),('25011995'),('25011996'),('25012501'),('250177'),('250178'),('250179'),('250180'),('250181'),('250182'),('250183'),('250184'),('250185'),('250186'),('250187'),('250188'),('250189'),('250190'),('250191'),('250192'),('250193'),('250194'),('250195'),('250196'),('2502'),('25021977'),('25021978'),('25021979'),('25021980'),('25021981'),('25021982'),('25021983'),('25021984'),('25021985'),('25021986'),('25021987'),('25021988'),('25021989'),('25021990'),('25021991'),('25021992'),('25021993'),('25021994'),('25021995'),('250250'),('250277'),('250278'),('250279'),('250280'),('250281'),('250282'),('250283'),('250284'),('250285'),('250286'),('250287'),('250288'),('250289'),('250290'),('250291'),('250292'),('250293'),('250294'),('250295'),('2503'),('25031978'),('25031980'),('25031981'),('25031982'),('25031983'),('25031984'),('25031985'),('25031986'),('25031987'),('25031988'),('25031989'),('25031990'),('25031991'),('25031992'),('25031993'),('25031994'),('25031995'),('25031996'),('25032503'),('250375'),('250376'),('250377'),('250378'),('250379'),('250380'),('250381'),('250382'),('250383'),('250384'),('250385'),('250386'),('250387'),('250388'),('250389'),('250390'),('250391'),('250392'),('250393'),('250394'),('250395'),('250396'),('250397'),('2504'),('25041977'),('25041978'),('25041979'),('25041980'),('25041981'),('25041982'),('25041983'),('25041984'),('25041985'),('25041986'),('25041987'),('25041988'),('25041989'),('25041990'),('25041991'),('25041992'),('25041993'),('25041994'),('25041995'),('25041996'),('25041997'),('250476'),('250477'),('250478'),('250479'),('250480'),('250481'),('250482'),('250483'),('250484'),('250485'),('250486'),('250487'),('250488'),('250489'),('250490'),('250491'),('250492'),('250493'),('250494'),('250495'),('250496'),('2505'),('250505'),('25051975'),('25051976'),('25051977'),('25051978'),('25051979'),('25051980'),('25051981'),('25051982'),('25051983'),('25051984'),('25051985'),('25051986'),('25051987'),('25051988'),('25051989'),('25051990'),('25051991'),('25051992'),('25051993'),('25051994'),('25051995'),('25051996'),('25052005'),('25052505'),('250574'),('250575'),('250576'),('250577'),('250578'),('250579'),('250580'),('250581'),('250582'),('250583'),('250584'),('250585'),('250586'),('250587'),('250588'),('250589'),('250590'),('250591'),('250592'),('250593'),('250594'),('250595'),('250596'),('2506'),('25061977'),('25061978'),('25061979'),('25061980'),('25061981'),('25061982'),('25061983'),('25061984'),('25061985'),('25061986'),('25061987'),('25061988'),('25061989'),('25061990'),('25061991'),('25061992'),('25061993'),('25061994'),('25061996'),('250676'),('250677'),('250678'),('250679'),('250680'),('250681'),('250682'),('250683'),('250684'),('250685'),('250686'),('250687'),('250688'),('250689'),('250690'),('250691'),('250692'),('250693'),('250694'),('250695'),('250696'),('2507'),('25071977'),('25071978'),('25071979'),('25071980'),('25071981'),('25071982'),('25071983'),('25071984'),('25071985'),('25071986'),('25071987'),('25071988'),('25071989'),('25071990'),('25071991'),('25071992'),('25071993'),('25071994'),('25071995'),('250776'),('250777'),('250778'),('250779'),('250780'),('250781'),('250782'),('250783'),('250784'),('250785'),('250786'),('250787'),('250788'),('250789'),('250790'),('250791'),('250792'),('250793'),('250794'),('250795'),('2508'),('250807'),('25081978'),('25081979'),('25081980'),('25081981'),('25081982'),('25081983'),('25081984'),('25081985'),('25081986'),('25081987'),('25081988'),('25081989'),('25081990'),('25081991'),('25081992'),('25081993'),('25081994'),('25081995'),('25082508'),('250876'),('250877'),('250878'),('250879'),('250880'),('250881'),('250882'),('250883'),('250884'),('250885'),('250886'),('250887'),('250888'),('250889'),('250890'),('250891'),('250892'),('250893'),('250894'),('250895'),('2509'),('25091978'),('25091979'),('25091980'),('25091981'),('25091982'),('25091983'),('25091984'),('25091985'),('25091986'),('25091987'),('25091988'),('25091989'),('25091990'),('25091991'),('25091992'),('25091993'),('25091994'),('25091995'),('25091996'),('250976'),('250977'),('250978'),('250979'),('250980'),('250981'),('250982'),('250983'),('250984'),('250985'),('250986'),('250987'),('250988'),('250989'),('250990'),('250991'),('250992'),('250993'),('250994'),('250995'),('250996'),('251'),('2510'),('251001'),('25101977'),('25101978'),('25101979'),('25101980'),('25101981'),('25101982'),('25101983'),('25101984'),('25101985'),('25101986'),('25101987'),('25101988'),('25101989'),('25101990'),('25101991'),('25101992'),('25101993'),('25101994'),('25101995'),('25102510'),('251075'),('251076'),('251077'),('251078'),('251079'),('251080'),('251081'),('251082'),('251083'),('251084'),('251085'),('251086'),('251087'),('251088'),('251089'),('251090'),('251091'),('251092'),('251093'),('251094'),('251095'),('251096'),('2511'),('251106'),('25111978'),('25111979'),('25111980'),('25111981'),('25111982'),('25111983'),('25111984'),('25111985'),('25111986'),('25111987'),('25111988'),('25111989'),('25111990'),('25111991'),('25111992'),('25111993'),('25111994'),('25111995'),('25112511'),('251174'),('251175'),('251176'),('251177'),('251178'),('251179'),('251180'),('251181'),('251182'),('251183'),('251184'),('251185'),('251186'),('251187'),('251188'),('251189'),('251190'),('251191'),('251192'),('251193'),('251194'),('251195'),('251196'),('2512'),('251200'),('251206'),('251208'),('25121975'),('25121976'),('25121977'),('25121978'),('25121979'),('25121980'),('25121981'),('25121982'),('25121983'),('25121984'),('25121985'),('25121986'),('25121987'),('25121988'),('25121989'),('25121990'),('25121991'),('25121992'),('25121993'),('25121994'),('25121995'),('25121996'),('25122512'),('251251'),('251259a'),('251273'),('251274'),('251275'),('251276'),('251277'),('251278'),('251279'),('251280'),('251281'),('251282'),('251283'),('251284'),('251285'),('251286'),('251287'),('251288'),('251289'),('251290'),('251291'),('251292'),('251293'),('251294'),('251295'),('251296'),('2513'),('251314'),('25132513'),('2514'),('25142514'),('2515'),('2516'),('2517'),('25172517'),('2518'),('2519'),('251975'),('251978'),('251979'),('251980'),('251981'),('251982'),('251983'),('251984'),('251985'),('251986'),('251987'),('251988'),('251989'),('251990'),('251991'),('251992'),('251993'),('251994'),('251995'),('252'),('2520'),('25202520'),('2521'),('25212521'),('2522'),('25222522'),('252252'),('2523'),('25232523'),('2524'),('25242524'),('2525'),('25251325'),('252525'),('25252525'),('2525252525'),('252525a'),('252526'),('2525775'),('25257758'),('2526'),('25262526'),('252627'),('2527'),('25272527'),('2528'),('25282528'),('25292529'),('2530'),('25302530'),('25312531'),('253253'),('253314'),('25352535'),('253545'),('2536'),('25362536'),('253634'),('2539'),('25393275'),('25412541'),('2541435'),('254254'),('25452545'),('2552'),('255225'),('25522552'),('255255'),('256256'),('25632563'),('256buoWriZ'),('257257'),('257ers'),('258'),('2580'),('25800'),('258000'),('25800852'),('258012'),('2580123'),('258013'),('258025'),('25802580'),('258036'),('2580369'),('2580456'),('258046'),('2580852'),('258123'),('258147'),('258147369'),('258258'),('258258258'),('258369'),('258369147'),('258456'),('258456a'),('258654'),('258741'),('2587758'),('258789'),('258852'),('2589'),('25892589'),('258963'),('258963147'),('259421'),('25962596'),('259758'),('2597758'),('25cent'),('25nuvaha'),('25tolife'),('26'),('26.09.67'),('260'),('2601'),('26011979'),('26011980'),('26011981'),('26011982'),('26011983'),('26011984'),('26011985'),('26011986'),('26011987'),('26011988'),('26011989'),('26011990'),('26011991'),('26011992'),('26011993'),('26011994'),('26011995'),('26011996'),('260177'),('260178'),('260179'),('260180'),('260181'),('260182'),('260183'),('260184'),('260185'),('260186'),('260187'),('260188'),('260189'),('260190'),('260191'),('260192'),('260193'),('260194'),('260195'),('260196'),('2602'),('26021979'),('26021980'),('26021981'),('26021982'),('26021983'),('26021984'),('26021985'),('26021986'),('26021987'),('26021988'),('26021989'),('26021990'),('26021991'),('26021992'),('26021993'),('26021994'),('26021995'),('26021996'),('260260'),('260278'),('260279'),('260280'),('260281'),('260282'),('260283'),('260284'),('260285'),('260286'),('260287'),('260288'),('260289'),('260290'),('260291'),('260292'),('260293'),('260294'),('260296'),('2603'),('26031979'),('26031980'),('26031981'),('26031982'),('26031983'),('26031984'),('26031985'),('26031986'),('26031987'),('26031988'),('26031989'),('26031990'),('26031991'),('26031992'),('26031993'),('26031994'),('26031995'),('26031996'),('26031998m'),('260377'),('260378'),('260379'),('260380'),('260381'),('260382'),('260383'),('260384'),('260385'),('260386'),('260387'),('260388'),('260389'),('260390'),('260391'),('260392'),('260393'),('260394'),('260395'),('260396'),('2604'),('26041978'),('26041979'),('26041980'),('26041981'),('26041982'),('26041983'),('26041984'),('26041985'),('26041986'),('26041987'),('26041988'),('26041989'),('26041990'),('26041991'),('26041992'),('26041993'),('26041994'),('26041995'),('260477'),('260478'),('260479'),('260480'),('260481'),('260482'),('260483'),('260484'),('260485'),('260486'),('260487'),('260488'),('260489'),('260490'),('260491'),('260492'),('260493'),('260494'),('260495'),('260496'),('2605'),('26051980'),('26051981'),('26051982'),('26051983'),('26051984'),('26051985'),('26051986'),('26051987'),('26051988'),('26051989'),('26051990'),('26051991'),('26051992'),('26051993'),('26051994'),('26051995'),('260577'),('260578'),('260579'),('260580'),('260581'),('260582'),('260583'),('260584'),('260585'),('260586'),('260587'),('260588'),('260589'),('260590'),('260591'),('260592'),('260593'),('260594'),('260595'),('2606'),('260606'),('26061977'),('26061978'),('26061979'),('26061980'),('26061981'),('26061982'),('26061983'),('26061984'),('26061985'),('26061986'),('26061987'),('26061988'),('26061989'),('26061990'),('26061991'),('26061992'),('26061993'),('26061994'),('26061995'),('26061996'),('26061997'),('260675'),('260676'),('260677'),('260678'),('260679'),('260680'),('260681'),('260682'),('260683'),('260684'),('260685'),('260686'),('260687'),('260688'),('260689'),('260690'),('260691'),('260692'),('260693'),('260694'),('260695'),('260696'),('2607'),('26071979'),('26071980'),('26071981'),('26071982'),('26071983'),('26071984'),('26071985'),('26071986'),('26071987'),('26071988'),('26071989'),('26071990'),('26071991'),('26071992'),('26071993'),('26071994'),('26071995'),('260777'),('260778'),('260779'),('260780'),('260781'),('260782'),('260783'),('260784'),('260785'),('260786'),('260787'),('260788'),('260789'),('260790'),('260791'),('260792'),('260793'),('260794'),('260795'),('2608'),('26081980'),('26081981'),('26081982'),('26081983'),('26081984'),('26081985'),('26081986'),('26081987'),('26081988'),('26081989'),('26081990'),('26081991'),('26081992'),('26081993'),('26081994'),('26081995'),('260876'),('260877'),('260878'),('260879'),('260880'),('260881'),('260882'),('260883'),('260884'),('260885'),('260886'),('260887'),('260888'),('260889'),('260890'),('260891'),('260892'),('260893'),('260894'),('260895'),('260896'),('2609'),('26091979'),('26091980'),('26091981'),('26091982'),('26091983'),('26091984'),('26091985'),('26091986'),('26091987'),('26091988'),('26091989'),('26091990'),('26091991'),('26091992'),('26091993'),('26091994'),('26091995'),('260977'),('260978'),('260979'),('260980'),('260981'),('260982'),('260983'),('260984'),('260985'),('260986'),('260987'),('260988'),('260989'),('260990'),('260991'),('260992'),('260993'),('260994'),('260995'),('261'),('2610'),('26101978'),('26101979'),('26101980'),('26101981'),('26101982'),('26101983'),('26101984'),('26101985'),('26101986'),('26101987'),('26101988'),('26101989'),('26101990'),('26101991'),('26101992'),('26101993'),('26101994'),('26101995'),('26101996'),('26102610'),('261076'),('261077'),('261078'),('261079'),('261080'),('261081'),('261082'),('261083'),('261084'),('261085'),('261086'),('261087'),('261088'),('261089'),('261090'),('261091'),('261092'),('261093'),('261094'),('261095'),('261096'),('2611'),('26111978'),('26111979'),('26111980'),('26111981'),('26111982'),('26111983'),('26111984'),('26111985'),('26111986'),('26111987'),('26111988'),('26111989'),('26111990'),('26111991'),('26111992'),('26111993'),('26111994'),('261173'),('261174'),('261177'),('261178'),('261179'),('261180'),('261181'),('261182'),('261183'),('261184'),('261185'),('261186'),('261187'),('261188'),('261189'),('261190'),('261191'),('261192'),('261193'),('261194'),('261195'),('261196'),('2612'),('26121977'),('26121978'),('26121979'),('26121980'),('26121981'),('26121982'),('26121983'),('26121984'),('26121985'),('26121986'),('26121987'),('26121988'),('26121989'),('26121990'),('26121991'),('26121992'),('26121993'),('26121994'),('26121995'),('26121996'),('261261'),('261275'),('261276'),('261277'),('261278'),('261279'),('261280'),('261281'),('261282'),('261283'),('261284'),('261285'),('261286'),('261287'),('261288'),('261289'),('261290'),('261291'),('261292'),('261293'),('261294'),('261295'),('261296'),('261978'),('261980'),('261982'),('261983'),('261984'),('261985'),('261986'),('261987'),('261988'),('261989'),('261990'),('261991'),('261992'),('261993'),('2626'),('262626'),('26262626'),('262728'),('263263'),('265349'),('2662'),('266266'),('266469'),('26665806'),('268268'),('26842684'),('269269'),('26r10d'),('27'),('270'),('2701'),('27011978'),('27011979'),('27011980'),('27011981'),('27011982'),('27011983'),('27011984'),('27011985'),('27011986'),('27011987'),('27011988'),('27011989'),('27011990'),('27011991'),('27011992'),('27011993'),('27011994'),('27011995'),('270177'),('270178'),('270179'),('270180'),('270181'),('270182'),('270183'),('270184'),('270185'),('270186'),('270187'),('270188'),('270189'),('270190'),('270191'),('270192'),('270193'),('270194'),('270195'),('2702'),('27021978'),('27021979'),('27021980'),('27021981'),('27021982'),('27021983'),('27021984'),('27021985'),('27021986'),('27021987'),('27021988'),('27021989'),('27021990'),('27021991'),('27021992'),('27021993'),('27021994'),('27021995'),('27021996'),('270270'),('270278'),('270279'),('270280'),('270281'),('270282'),('270283'),('270284'),('270285'),('270286'),('270287'),('270288'),('270289'),('270290'),('270291'),('270292'),('270293'),('270294'),('270295'),('2703'),('27031978'),('27031980'),('27031981'),('27031982'),('27031983'),('27031984'),('27031985'),('27031986'),('27031987'),('27031988'),('27031989'),('27031990'),('27031991'),('27031992'),('27031993'),('27031994'),('27031995'),('270377'),('270378'),('270379'),('270380'),('270381'),('270382'),('270383'),('270384'),('270385'),('270386'),('270387'),('270388'),('270389'),('270390'),('270391'),('270392'),('270393'),('270395'),('270396'),('2704'),('27041977'),('27041978'),('27041979'),('27041980'),('27041981'),('27041982'),('27041983'),('27041984'),('27041985'),('27041986'),('27041987'),('27041988'),('27041989'),('27041990'),('27041991'),('27041992'),('27041993'),('27041994'),('27041995'),('270478'),('270479'),('270480'),('270481'),('270482'),('270483'),('270484'),('270485'),('270486'),('270487'),('270488'),('270489'),('270490'),('270491'),('270492'),('270493'),('270494'),('270495'),('270496'),('2705'),('27051977'),('27051978'),('27051980'),('27051981'),('27051982'),('27051983'),('27051984'),('27051985'),('27051986'),('27051987'),('27051988'),('27051989'),('27051990'),('27051991'),('27051992'),('27051993'),('27051994'),('27051995'),('270578'),('270579'),('270580'),('270581'),('270582'),('270583'),('270584'),('270585'),('270586'),('270587'),('270588'),('270589'),('270590'),('270591'),('270592'),('270593'),('270594'),('270595'),('2706'),('27061979'),('27061980'),('27061981'),('27061982'),('27061983'),('27061984'),('27061985'),('27061986'),('27061987'),('27061988'),('27061989'),('27061990'),('27061991'),('27061992'),('27061993'),('27061994'),('27061995'),('270677'),('270678'),('270679'),('270680'),('270681'),('270682'),('270683'),('270684'),('270685'),('270686'),('270687'),('270688'),('270689'),('270690'),('270691'),('270692'),('270693'),('270694'),('270695'),('2707'),('270707'),('27071977'),('27071978'),('27071980'),('27071981'),('27071982'),('27071983'),('27071984'),('27071985'),('27071986'),('27071987'),('27071988'),('27071989'),('27071990'),('27071991'),('27071992'),('27071993'),('27071994'),('27071995'),('27072007'),('270776'),('270777'),('270778'),('270779'),('270780'),('270781'),('270782'),('270783'),('270784'),('270785'),('270786'),('270787'),('270788'),('270789'),('270790'),('270791'),('270792'),('270793'),('270794'),('270795'),('270797'),('2708'),('27081980'),('27081981'),('27081982'),('27081983'),('27081984'),('27081985'),('27081986'),('27081987'),('27081988'),('27081989'),('27081990'),('27081991'),('27081992'),('27081993'),('27081994'),('270873_'),('270878'),('270879'),('270880'),('270881'),('270882'),('270883'),('270884'),('270885'),('270886'),('270887'),('270888'),('270889'),('270890'),('270891'),('270892'),('270893'),('270894'),('270895'),('2709'),('27091979'),('27091980'),('27091981'),('27091982'),('27091983'),('27091984'),('27091985'),('27091986'),('27091987'),('27091988'),('27091989'),('27091990'),('27091991'),('27091992'),('27091993'),('27091994'),('27091995'),('270976'),('270978'),('270979'),('270980'),('270981'),('270982'),('270983'),('270984'),('270985'),('270986'),('270987'),('270988'),('270989'),('270990'),('270991'),('270992'),('270993'),('270994'),('270995'),('270996'),('271'),('2710'),('27101977'),('27101979'),('27101980'),('27101981'),('27101982'),('27101983'),('27101984'),('27101985'),('27101986'),('27101987'),('27101988'),('27101989'),('27101990'),('27101991'),('27101992'),('27101993'),('27101994'),('27101995'),('271077'),('271078'),('271079'),('271080'),('271081'),('271082'),('271083'),('271084'),('271085'),('271086'),('271087'),('271088'),('271089'),('271090'),('271091'),('271092'),('271093'),('271094'),('271095'),('2711'),('27111978'),('27111979'),('27111980'),('27111981'),('27111982'),('27111983'),('27111984'),('27111985'),('27111986'),('27111987'),('27111988'),('27111989'),('27111990'),('27111991'),('27111992'),('27111993'),('27111994'),('271172'),('271177'),('271178'),('271179'),('271180'),('271181'),('271182'),('271183'),('271184'),('271185'),('271186'),('271187'),('271188'),('271189'),('271190'),('271191'),('271192'),('271193'),('271194'),('271195'),('271196'),('2712'),('27121977'),('27121978'),('27121979'),('27121980'),('27121981'),('27121982'),('27121983'),('27121984'),('27121985'),('27121986'),('27121987'),('27121988'),('27121989'),('27121990'),('27121991'),('27121992'),('27121993'),('27121994'),('27121995'),('271271'),('271277'),('271278'),('271279'),('271280'),('271281'),('271282'),('271283'),('271284'),('271285'),('271286'),('271287'),('271288'),('271289'),('271290'),('271291'),('271292'),('271293'),('271294'),('271295'),('271296'),('27140621'),('271828'),('271980'),('271982'),('271983'),('271984'),('271985'),('271986'),('271987'),('271988'),('271989'),('271990'),('271991'),('271992'),('27254931'),('2727'),('272727'),('27272727'),('272829'),('27352735'),('2741001'),('27412678'),('275-22-74'),('27653'),('28'),('280'),('2801'),('28011980'),('28011981'),('28011982'),('28011983'),('28011984'),('28011985'),('28011986'),('28011987'),('28011988'),('28011989'),('28011990'),('28011991'),('28011992'),('28011993'),('28011994'),('280177'),('280178'),('280179'),('280180'),('280181'),('280182'),('280183'),('280184'),('280185'),('280186'),('280187'),('280188'),('280189'),('280190'),('280191'),('280192'),('280193'),('280194'),('280195'),('280196'),('2802'),('28021978'),('28021980'),('28021981'),('28021982'),('28021983'),('28021984'),('28021985'),('28021986'),('28021987'),('28021988'),('28021989'),('28021990'),('28021991'),('28021992'),('28021993'),('28021994'),('28021995'),('28021996'),('280277'),('280279'),('280280'),('280281'),('280282'),('280283'),('280284'),('280285'),('280286'),('280287'),('280288'),('280289'),('280290'),('280291'),('280292'),('280293'),('280294'),('280295'),('2803'),('28031979'),('28031980'),('28031981'),('28031982'),('28031983'),('28031984'),('28031985'),('28031986'),('28031987'),('28031988'),('28031989'),('28031990'),('28031991'),('28031992'),('28031993'),('28031994'),('28031995'),('28031996'),('280377'),('280378'),('280379'),('280380'),('280381'),('280382'),('280383'),('280384'),('280385'),('280386'),('280387'),('280388'),('280389'),('280390'),('280391'),('280392'),('280393'),('280394'),('280395'),('2804'),('28041977'),('28041979'),('28041980'),('28041981'),('28041982'),('28041983'),('28041984'),('28041985'),('28041986'),('28041987'),('28041988'),('28041989'),('28041990'),('28041991'),('28041992'),('28041993'),('28041994'),('28041995'),('280475'),('280477'),('280478'),('280479'),('280480'),('280481'),('280482'),('280483'),('280484'),('280485'),('280486'),('280487'),('280488'),('280489'),('280490'),('280491'),('280492'),('280493'),('280494'),('280495'),('2805'),('28051978'),('28051979'),('28051980'),('28051981'),('28051982'),('28051983'),('28051984'),('28051985'),('28051986'),('28051987'),('28051988'),('28051989'),('28051990'),('28051991'),('28051992'),('28051993'),('28051994'),('28051995'),('28051996'),('280576'),('280577'),('280578'),('280579'),('280580'),('280581'),('280582'),('280583'),('280584'),('280585'),('280586'),('280587'),('280588'),('280589'),('280590'),('280591'),('280592'),('280593'),('280594'),('280595'),('280596'),('2806'),('28061977'),('28061979'),('28061980'),('28061981'),('28061982'),('28061983'),('28061984'),('28061985'),('28061986'),('28061987'),('28061988'),('28061989'),('28061990'),('28061991'),('28061992'),('28061993'),('28061994'),('280677'),('280678'),('280679'),('280680'),('280681'),('280682'),('280683'),('280684'),('280685'),('280686'),('280687'),('280688'),('280689'),('280690'),('280691'),('280692'),('280693'),('280694'),('280695'),('280696'),('2807'),('280707'),('28071976'),('28071977'),('28071979'),('28071980'),('28071981'),('28071982'),('28071983'),('28071984'),('28071985'),('28071986'),('28071987'),('28071988'),('28071989'),('28071990'),('28071991'),('28071992'),('28071993'),('28071994'),('28071995'),('280777'),('280778'),('280779'),('280780'),('280781'),('280782'),('280783'),('280784'),('280785'),('280786'),('280787'),('280788'),('280789'),('280790'),('280791'),('280792'),('280793'),('280794'),('280795'),('2808'),('280800'),('280808'),('28081976'),('28081978'),('28081980'),('28081981'),('28081982'),('28081983'),('28081984'),('28081985'),('28081986'),('28081987'),('28081988'),('28081989'),('28081990'),('28081991'),('28081992'),('28081993'),('28081994'),('28081995'),('28081996'),('28082008'),('280875'),('280877'),('280878'),('280879'),('280880'),('280881'),('280882'),('280883'),('280884'),('280885'),('280886'),('280887'),('280888'),('280889'),('280890'),('280891'),('280892'),('280893'),('280894'),('280895'),('280896'),('280898'),('2809'),('28091979'),('28091980'),('28091981'),('28091982'),('28091983'),('28091984'),('28091985'),('28091986'),('28091987'),('28091988'),('28091989'),('28091990'),('28091991'),('28091992'),('28091993'),('28091994'),('28091995'),('280977'),('280978'),('280979'),('280980'),('280981'),('280982'),('280983'),('280984'),('280985'),('280986'),('280987'),('280988'),('280989'),('280990'),('280991'),('280992'),('280993'),('280994'),('280995'),('281'),('2810'),('28101977'),('28101978'),('28101979'),('28101980'),('28101981'),('28101982'),('28101983'),('28101984'),('28101985'),('28101986'),('28101987'),('28101988'),('28101989'),('28101990'),('28101991'),('28101992'),('28101993'),('28101994'),('28101995'),('281076'),('281077'),('281078'),('281079'),('281080'),('281081'),('281082'),('281083'),('281084'),('281085'),('281086'),('281087'),('281088'),('281089'),('281090'),('281091'),('281092'),('281093'),('281094'),('281095'),('2811'),('28111980'),('28111981'),('28111982'),('28111983'),('28111984'),('28111985'),('28111986'),('28111987'),('28111988'),('28111989'),('28111990'),('28111991'),('28111992'),('28111993'),('28111994'),('281175'),('281176'),('281177'),('281178'),('281179'),('281180'),('281181'),('281182'),('281183'),('281184'),('281185'),('281186'),('281187'),('281188'),('281189'),('281190'),('281191'),('281192'),('281193'),('281194'),('281195'),('281196'),('2812'),('28121976'),('28121977'),('28121978'),('28121979'),('28121980'),('28121981'),('28121982'),('28121983'),('28121984'),('28121985'),('28121986'),('28121987'),('28121988'),('28121989'),('28121990'),('28121991'),('28121992'),('28121993'),('28121994'),('28121995'),('281274'),('281276'),('281277'),('281278'),('281279'),('281280'),('281281'),('281282'),('281283'),('281284'),('281285'),('281286'),('281287'),('281288'),('281289'),('281290'),('281291'),('281292'),('281293'),('281294'),('281295'),('281296'),('2813308004'),('281978'),('281980'),('281982'),('281983'),('281984'),('281985'),('281986'),('281987'),('281988'),('281989'),('281990'),('281991'),('281992'),('282001'),('282002'),('2828'),('282828'),('28282828'),('282930'),('28462846'),('284655'),('2882'),('28972323'),('28zxrpuNFA'),('28zxrpvNFA'),('29'),('290'),('2901'),('29011980'),('29011981'),('29011982'),('29011983'),('29011984'),('29011985'),('29011986'),('29011987'),('29011988'),('29011989'),('29011990'),('29011991'),('29011992'),('29011993'),('29011994'),('29011996'),('290178'),('290179'),('290180'),('290181'),('290182'),('290183'),('290184'),('290185'),('290186'),('290187'),('290188'),('290189'),('290190'),('290191'),('290192'),('290193'),('290194'),('29021980'),('29021984'),('29021988'),('29021992'),('290280'),('290284'),('290288'),('290292'),('2903'),('29031979'),('29031980'),('29031981'),('29031982'),('29031983'),('29031984'),('29031985'),('29031986'),('29031987'),('29031988'),('29031989'),('29031990'),('29031991'),('29031992'),('29031993'),('29031994'),('29031995'),('290377'),('290378'),('290379'),('290380'),('290381'),('290382'),('290383'),('290384'),('290385'),('290386'),('290387'),('290388'),('290389'),('290390'),('290391'),('290392'),('290393'),('290394'),('290395'),('290396'),('2904'),('29041979'),('29041980'),('29041981'),('29041982'),('29041983'),('29041984'),('29041985'),('29041986'),('29041987'),('29041988'),('29041989'),('29041990'),('29041991'),('29041992'),('29041993'),('29041994'),('29041995'),('29041996'),('290477'),('290478'),('290479'),('290480'),('290481'),('290482'),('290483'),('290484'),('290485'),('290486'),('290487'),('290488'),('290489'),('290490'),('290491'),('290492'),('290493'),('290494'),('290495'),('290496'),('2905'),('29051978'),('29051979'),('29051980'),('29051981'),('29051982'),('29051983'),('29051984'),('29051985'),('29051986'),('29051987'),('29051988'),('29051989'),('29051990'),('29051991'),('29051992'),('29051993'),('29051994'),('29051995'),('290576'),('290578'),('290579'),('290580'),('290581'),('290582'),('290583'),('290584'),('290585'),('290586'),('290587'),('290588'),('290589'),('290590'),('290591'),('290592'),('290593'),('290595'),('2906'),('29061979'),('29061980'),('29061981'),('29061982'),('29061983'),('29061984'),('29061985'),('29061986'),('29061987'),('29061988'),('29061989'),('29061990'),('29061991'),('29061992'),('29061993'),('29061994'),('29061995'),('29061996'),('290676'),('290677'),('290678'),('290679'),('290680'),('290681'),('290682'),('290683'),('290684'),('290685'),('290686'),('290687'),('290688'),('290689'),('290690'),('290691'),('290692'),('290693'),('290694'),('290695'),('2907'),('29071980'),('29071981'),('29071982'),('29071983'),('29071984'),('29071985'),('29071986'),('29071987'),('29071988'),('29071989'),('29071990'),('29071991'),('29071992'),('29071993'),('29071994'),('29071995'),('290777'),('290779'),('290780'),('290781'),('290782'),('290783'),('290784'),('290785'),('290786'),('290787'),('290788'),('290789'),('290790'),('290791'),('290792'),('290793'),('290794'),('2908'),('29081979'),('29081980'),('29081981'),('29081982'),('29081983'),('29081984'),('29081985'),('29081986'),('29081987'),('29081988'),('29081989'),('29081990'),('29081991'),('29081992'),('29081993'),('29081994'),('29081995'),('290877'),('290878'),('290879'),('290880'),('290881'),('290882'),('290883'),('290884'),('290885'),('290886'),('290887'),('290888'),('290889'),('290890'),('290891'),('290892'),('290893'),('290894'),('290895'),('2909'),('29091976'),('29091977'),('29091978'),('29091979'),('29091980'),('29091981'),('29091982'),('29091983'),('29091984'),('29091985'),('29091986'),('29091987'),('29091988'),('29091989'),('29091990'),('29091991'),('29091992'),('29091993'),('29091994'),('29091995'),('290966'),('290976'),('290978'),('290979'),('290980'),('290981'),('290982'),('290983'),('290984'),('290985'),('290986'),('290987'),('290988'),('290989'),('290990'),('290991'),('290992'),('290993'),('290994'),('290995'),('291'),('2910'),('29101978'),('29101979'),('29101980'),('29101981'),('29101982'),('29101983'),('29101984'),('29101985'),('29101986'),('29101987'),('29101988'),('29101989'),('29101990'),('29101991'),('29101992'),('29101993'),('29101994'),('29101995'),('29101996'),('291077'),('291078'),('291079'),('291080'),('291081'),('291082'),('291083'),('291084'),('291085'),('291086'),('291087'),('291088'),('291089'),('291090'),('291091'),('291092'),('291093'),('291094'),('2911'),('29111978'),('29111979'),('29111980'),('29111981'),('29111982'),('29111983'),('29111984'),('29111985'),('29111986'),('29111987'),('29111988'),('29111989'),('29111990'),('29111991'),('29111992'),('29111993'),('29111994'),('291175'),('291177'),('291178'),('291179'),('291180'),('291181'),('291182'),('291183'),('291184'),('291185'),('291186'),('291187'),('291188'),('291189'),('291190'),('291191'),('291192'),('291193'),('291194'),('291195'),('2912'),('29121978'),('29121979'),('29121980'),('29121981'),('29121982'),('29121983'),('29121984'),('29121985'),('29121986'),('29121987'),('29121988'),('29121989'),('29121990'),('29121991'),('29121992'),('29121993'),('29121994'),('29121995'),('291277'),('291278'),('291279'),('291280'),('291281'),('291282'),('291283'),('291284'),('291285'),('291286'),('291287'),('291288'),('291289'),('291290'),('291291'),('291292'),('291293'),('291294'),('291295'),('291979'),('291983'),('291984'),('291985'),('291986'),('291987'),('291988'),('291989'),('291990'),('291991'),('291992'),('292513'),('29271188'),('292814lolo'),('2929'),('292929'),('29292929'),('292tom'),('2933455'),('29422277'),('29662012'),('29694419'),('29710455d'),('299792458'),('299kgj8hgf'),('29rsavoy'),('2a2a2a'),('2angels'),('2apples'),('2babies'),('2babyboys'),('2babygirls'),('2bad4u'),('2balls'),('2bananas'),('2beautiful'),('2bFiy28byL'),('2bfree'),('2bhappy'),('2bigballs'),('2bigtits'),('2bitch'),('2bitches'),('2black'),('2blessed'),('2blueeyes'),('2bon2b'),('2boobies'),('2boobs'),('2bornot2b'),('2boys1girl'),('2brothers'),('2children'),('2cookies'),('2cool4u'),('2cool4you'),('2crazy'),('2cute4u'),('2cute4you'),('2CxdN8S271'),('2daughters'),('2doggies'),('2dollars'),('2dragons'),('2dumb2live'),('2ealtD3y4Y'),('2fast4u'),('2fast4you'),('2fine4u'),('2flowers'),('2fly4u'),('2fresh'),('2friends'),('2fuckyou'),('2funny'),('2gangsta'),('2gelaF3h4A'),('2gether'),('2gether4ev'),('2gether4ever'),('2girls'),('2good4u'),('2good4you'),('2grandkids'),('2h7Vkzo266'),('2happy'),('2hdq6c9aZV'),('2hearts'),('2heaven'),('2horses'),('2hot2handl'),('2hot4tv'),('2hot4u'),('2hot4you'),('2hott4u'),('2inlove'),('2jab4x2c'),('2joints'),('2kids4me'),('2kisses'),('2kittens'),('2kitties'),('2kool4u'),('2kroliczek'),('2legit'),('2letmein'),('2lovely'),('2loveme'),('2lovers'),('2loves'),('2loveu'),('2loveyou'),('2m66xF2AJT'),('2manykids'),('2million'),('2mndonaaa'),('2money'),('2monkey'),('2monkeys'),('2morrow'),('2much4u'),('2muchfun'),('2muchlove'),('2muchmoney'),('2mylove'),('2myspace'),('2n66xG2zIU'),('2n6ezl7XhP'),('2n76xG2yIU'),('2ndchance'),('2night'),('2nipples'),('2nqW7A1517'),('2ofakind'),('2p76xG2yHV'),('2p76xH2xHV'),('2pac'),('2pac2pac'),('2pac4ever'),('2pac4life'),('2pacshakur'),('2password'),('2people'),('2pretty'),('2princess'),('2ps5wLc4xQ'),('2pSXVVd7'),('2puppies'),('2q2q2q'),('2q2w3e'),('2q2w3e8r5t'),('2q3w4e5r'),('2q87xI3vFX'),('2q87xI3wGW'),('2qaz2wsx'),('2qefx7T3sY'),('2qwerty'),('2r97xJ3xEX'),('2r97xJ3xEY'),('2rOH8tl433'),('2sexy4u'),('2sexy4you'),('2short'),('2simple'),('2sisters'),('2smart4u'),('2smooth'),('2stupid'),('2sweet'),('2sweet4u'),('2thick'),('2times'),('2titties'),('2turtles'),('2twins'),('2w2w2w'),('2w3e4r'),('2w3e4r5t'),('2wsx'),('2wsx1qaz'),('2wsx2wsx'),('2wsx3edc'),('2wsxcde3'),('2wsxzaq1'),('2wWerty1'),('2xtreme'),('3'),('3.14159'),('3.1415926'),('3.141592654'),('30'),('300'),('3000'),('300000'),('30003000'),('3000gt'),('3001'),('30011978'),('30011979'),('30011980'),('30011981'),('30011982'),('30011983'),('30011984'),('30011985'),('30011986'),('30011987'),('30011988'),('30011989'),('30011990'),('30011991'),('30011992'),('30011993'),('30011994'),('30011995'),('300179'),('300180'),('300181'),('300182'),('300183'),('300184'),('300185'),('300186'),('300187'),('300188'),('300189'),('300190'),('300191'),('300192'),('300193'),('3003'),('300300'),('30031977'),('30031978'),('30031979'),('30031980'),('30031981'),('30031982'),('30031983'),('30031984'),('30031985'),('30031986'),('30031987'),('30031988'),('30031989'),('30031990'),('30031991'),('30031992'),('30031993'),('30031994'),('30031995'),('30033003'),('300377'),('300378'),('300379'),('300380'),('300381'),('300382'),('300383'),('300384'),('300385'),('300386'),('300387'),('300388'),('300389'),('300390'),('300391'),('300392'),('300393'),('300394'),('300395'),('3004'),('300400'),('30041978'),('30041979'),('30041980'),('30041981'),('30041982'),('30041983'),('30041984'),('30041985'),('30041986'),('30041987'),('30041988'),('30041989'),('30041990'),('30041991'),('30041992'),('30041993'),('30041994'),('30041996'),('30041997'),('300476'),('300477'),('300478'),('300479'),('300480'),('300481'),('300482'),('300483'),('300484'),('300485'),('300486'),('300487'),('300488'),('300489'),('300490'),('300491'),('300492'),('300493'),('300494'),('300496'),('3005'),('300500'),('30051978'),('30051979'),('30051980'),('30051981'),('30051982'),('30051983'),('30051984'),('30051985'),('30051986'),('30051987'),('30051988'),('30051989'),('30051990'),('30051991'),('30051992'),('30051993'),('30051994'),('30051995'),('30051996'),('300575'),('300577'),('300578'),('300579'),('300580'),('300581'),('300582'),('300583'),('300584'),('300585'),('300586'),('300587'),('300588'),('300589'),('300590'),('300591'),('300592'),('300593'),('300594'),('300595'),('300596'),('3006'),('300600'),('30061978'),('30061979'),('30061980'),('30061981'),('30061982'),('30061983'),('30061984'),('30061985'),('30061986'),('30061987'),('30061988'),('30061989'),('30061990'),('30061991'),('30061992'),('30061993'),('30061994'),('30061995'),('30063006'),('300676'),('300677'),('300678'),('300679'),('300680'),('300681'),('300682'),('300683'),('300684'),('300685'),('300686'),('300687'),('300688'),('300689'),('300690'),('300691'),('300692'),('300693'),('300694'),('300695'),('3007'),('30071979'),('30071980'),('30071981'),('30071982'),('30071983'),('30071984'),('30071985'),('30071986'),('30071987'),('30071988'),('30071989'),('30071990'),('30071991'),('30071992'),('30071993'),('30071994'),('300777'),('300778'),('300779'),('300780'),('300781'),('300782'),('300783'),('300784'),('300785'),('300786'),('300787'),('300788'),('300789'),('300790'),('300791'),('300792'),('300793'),('3008'),('300808'),('30081980'),('30081981'),('30081982'),('30081983'),('30081984'),('30081985'),('30081986'),('30081987'),('30081988'),('30081989'),('30081990'),('30081991'),('30081992'),('30081993'),('30081994'),('30081995'),('300877'),('300878'),('300879'),('300880'),('300881'),('300882'),('300883'),('300884'),('300885'),('300886'),('300887'),('300888'),('300889'),('300890'),('300891'),('300892'),('300893'),('300894'),('3009'),('30091978'),('30091980'),('30091981'),('30091982'),('30091983'),('30091984'),('30091985'),('30091986'),('30091987'),('30091988'),('30091989'),('30091990'),('30091991'),('30091992'),('30091993'),('30091994'),('30091995'),('300976'),('300977'),('300979'),('300980'),('300981'),('300982'),('300983'),('300984'),('300985'),('300986'),('300987'),('300988'),('300989'),('300990'),('300991'),('300992'),('300993'),('300994'),('300995'),('301'),('3010'),('301001'),('30101978'),('30101979'),('30101980'),('30101981'),('30101982'),('30101983'),('30101984'),('30101985'),('30101986'),('30101987'),('30101988'),('30101989'),('30101990'),('30101991'),('30101992'),('30101993'),('30101994'),('30101995'),('30101996'),('30103010'),('301070'),('301077'),('301078'),('301079'),('301080'),('301081'),('301082'),('301083'),('301084'),('301085'),('301086'),('301087'),('301088'),('301089'),('301090'),('301091'),('301092'),('301093'),('301094'),('301095'),('3011'),('30111978'),('30111979'),('30111980'),('30111981'),('30111982'),('30111983'),('30111984'),('30111985'),('30111986'),('30111987'),('30111988'),('30111989'),('30111990'),('30111991'),('30111992'),('30111993'),('30111994'),('30111995'),('301176'),('301177'),('301178'),('301179'),('301180'),('301181'),('301182'),('301183'),('301184'),('301185'),('301186'),('301187'),('301188'),('301189'),('301190'),('301191'),('301192'),('301193'),('301194'),('301195'),('301197'),('3012'),('30121978'),('30121979'),('30121980'),('30121981'),('30121982'),('30121983'),('30121984'),('30121985'),('30121986'),('30121987'),('30121988'),('30121989'),('30121990'),('30121991'),('30121992'),('30121993'),('30121994'),('30121996'),('30123012'),('301275'),('301276'),('301277'),('301278'),('301279'),('301280'),('301281'),('301282'),('301283'),('301284'),('301285'),('301285mn'),('301286'),('301287'),('301288'),('301289'),('301290'),('301291'),('301292'),('301293'),('301294'),('301301'),('301987'),('302001'),('302004'),('302010'),('302012'),('302015'),('302016'),('302017'),('302019'),('302020'),('302021'),('302302'),('303'),('3030'),('30303'),('303030'),('30303030'),('303132'),('303303'),('303677'),('304050'),('304304'),('305001'),('305305'),('305mia'),('305miami'),('306090'),('30624700'),('306306'),('307307'),('308308'),('309309'),('30media'),('30seconds'),('30secondstomars'),('31'),('310'),('3100'),('310000'),('3101'),('31011979'),('31011980'),('31011981'),('31011982'),('31011983'),('31011984'),('31011985'),('31011986'),('31011987'),('31011988'),('31011989'),('31011990'),('31011991'),('31011992'),('31011993'),('31011994'),('31011995'),('31011996'),('31011997'),('310176'),('310178'),('310179'),('310180'),('310181'),('310182'),('310183'),('310184'),('310185'),('310186'),('310187'),('310188'),('310189'),('310190'),('310191'),('310192'),('310193'),('310194'),('310195'),('310196'),('310197'),('3103'),('310310'),('31031977'),('31031978'),('31031979'),('31031980'),('31031981'),('31031982'),('31031983'),('31031984'),('31031985'),('31031986'),('31031987'),('31031988'),('31031989'),('31031990'),('31031991'),('31031992'),('31031993'),('31031994'),('31031995'),('310377'),('310378'),('310379'),('310380'),('310381'),('310382'),('310383'),('310384'),('310385'),('310386'),('310387'),('310388'),('310389'),('310390'),('310391'),('310392'),('310393'),('310394'),('310395'),('3105'),('31051977'),('31051979'),('31051980'),('31051981'),('31051982'),('31051983'),('31051984'),('31051985'),('31051986'),('31051987'),('31051988'),('31051989'),('31051990'),('31051991'),('31051992'),('31051993'),('31051994'),('31051995'),('31051996'),('310575'),('310576'),('310577'),('310578'),('310579'),('310580'),('310581'),('310582'),('310583'),('310584'),('310585'),('310586'),('310587'),('310588'),('310588m'),('310589'),('310590'),('310591'),('310592'),('310593'),('310594'),('310595'),('310596'),('3106934abc'),('3107'),('31071979'),('31071980'),('31071981'),('31071982'),('31071983'),('31071984'),('31071985'),('31071986'),('31071987'),('31071988'),('31071989'),('31071990'),('31071991'),('31071992'),('31071993'),('31071994'),('31071995'),('310775'),('310777'),('310778'),('310779'),('310780'),('310781'),('310782'),('310783'),('310784'),('310785'),('310786'),('310787'),('310788'),('310789'),('310790'),('310791'),('310792'),('310793'),('310794'),('310795'),('3108'),('31081977'),('31081978'),('31081979'),('31081980'),('31081981'),('31081981rs'),('31081982'),('31081983'),('31081984'),('31081985'),('31081986'),('31081987'),('31081988'),('31081989'),('31081990'),('31081991'),('31081992'),('31081993'),('31081994'),('31081995'),('310876'),('310877'),('310878'),('310879'),('310880'),('310881'),('310882'),('310883'),('310884'),('310885'),('310886'),('310887'),('310888'),('310889'),('310890'),('310891'),('310892'),('310893'),('310894'),('310895'),('311'),('3110'),('311001'),('31101977'),('31101978'),('31101979'),('31101980'),('31101981'),('31101982'),('31101983'),('31101984'),('31101985'),('31101986'),('31101987'),('31101988'),('31101989'),('31101990'),('31101991'),('31101992'),('31101993'),('31101994'),('31101995'),('31101996'),('31103110'),('311070'),('311077'),('311078'),('311079'),('311080'),('311081'),('311082'),('311083'),('311084'),('311085'),('311086'),('311087'),('311088'),('311089'),('311090'),('311091'),('311092'),('311093'),('311094'),('311095'),('3112'),('311200'),('311208'),('31121977'),('31121978'),('31121979'),('31121980'),('31121981'),('31121982'),('31121983'),('31121984'),('31121985'),('31121986'),('31121987'),('31121988'),('31121989'),('31121990'),('31121991'),('31121992'),('31121993'),('31121994'),('31121995'),('31122008'),('31122009'),('31123112'),('311275'),('311276'),('311277'),('311278'),('311279'),('311280'),('311281'),('311282'),('311283'),('311284'),('311285'),('311286'),('311287'),('311288'),('311289'),('311290'),('311291'),('311292'),('311293'),('311294'),('311296'),('3113'),('311311'),('31133113'),('312'),('312312'),('3128'),('312881040'),('313'),('313001'),('3131'),('313131'),('31313131'),('313233'),('313313'),('31337'),('31337a'),('314'),('3141'),('31415'),('314159'),('3141592'),('31415926'),('314159265'),('3141592653'),('31415926535'),('3141592654'),('31415927'),('314314'),('315023'),('3151020'),('315315'),('3155530'),('315920'),('316'),('316316'),('316497'),('317317'),('317537'),('3182'),('318318'),('319319'),('31P5WTDYG'),('31P5WTDYG/WGQ'),('31x7T5XBke'),('32'),('320000'),('320320'),('321'),('3210'),('321000'),('32103210'),('3211'),('321123'),('32113211'),('32123212'),('321321'),('321321321'),('321321a'),('321321q'),('3214'),('32143214'),('321456'),('321456987'),('3214789'),('321478965'),('3215987'),('321654'),('321654987'),('321654987a'),('321654a'),('32167'),('3216732167'),('321678'),('321789'),('321987'),('3219993xx'),('321abc'),('321cba'),('321ewq'),('321meins'),('321qaz'),('321qwe'),('322223'),('3223'),('322322'),('323'),('323046'),('3232'),('323232'),('32323232'),('3232547'),('323323'),('32342711'),('324324'),('325'),('32503250'),('325325'),('326159487'),('32615948worms'),('326326'),('326598'),('327327'),('328328'),('329210b'),('329329'),('32flame'),('33'),('330033'),('330330'),('3310'),('33103310'),('3311'),('331133'),('331331'),('332'),('3321'),('3322'),('332211'),('33221100'),('332233'),('33223322'),('3323'),('332332'),('332335'),('333'),('333000'),('333111'),('333123'),('333221'),('333222'),('333222111'),('3333'),('33333'),('333333'),('3333331'),('3333333'),('33333333'),('333333333'),('3333333333'),('333333a'),('33333a'),('33334444'),('333444'),('3334444'),('333444555'),('333555'),('333555777'),('333666'),('333666999'),('333777'),('333777333'),('333888'),('333999'),('333aaa'),('333eee'),('3344'),('334433'),('33443344'),('3344520'),('3344521'),('334455'),('33445566'),('3345678'),('3353212li'),('335335'),('3355'),('335533'),('335577'),('336336'),('3366'),('336633'),('33663366'),('336688'),('336699'),('3369'),('337337'),('3377'),('337733'),('337799'),('3388'),('33rjhjds'),('34'),('342001'),('3429795'),('3434'),('343434'),('34343434'),('343536'),('34416912'),('345'),('3452'),('34523452'),('345345'),('345543'),('3456'),('34563456'),('34567'),('345678'),('3456789'),('34567890'),('346100'),('347347'),('34erdfcv'),('3500sucks'),('350350'),('350chevy'),('351351'),('352352'),('3526535265'),('3535'),('353535'),('35353535'),('35365123'),('354354'),('355355'),('356356'),('357'),('357159'),('357357'),('357753'),('3578951'),('3579'),('35793579'),('357951'),('357mag'),('357magnum'),('358358'),('360001'),('360360'),('360flip'),('360modena'),('362436'),('362514'),('3630000'),('3636'),('363636'),('36363636'),('3647226'),('3651118xun'),('365214'),('365365'),('3663'),('366366'),('369'),('3690'),('36903690'),('36912'),('3691215'),('369123'),('369147'),('369258'),('369258147'),('369369'),('369369369'),('369741'),('3698'),('369852'),('369852147'),('36987'),('369874'),('3698741'),('36987412'),('369874125'),('369963'),('36chambers'),('36mafia'),('3700'),('370000'),('37213721'),('37217086'),('3737'),('373737'),('37373737'),('3762352'),('379379'),('37gudoplfs45'),('380006'),('380007'),('380008'),('380009'),('380013'),('380015'),('380054'),('3825'),('38253825'),('3830182'),('3838'),('383838'),('38383838'),('3838438'),('38gjgeuftd'),('38special'),('390007'),('39073588'),('393041123'),('3939'),('393939'),('39393939'),('395007'),('395009'),('3@p@g#'),('3amigos'),('3angels'),('3aNs97t397'),('3babies'),('3bears'),('3bitches'),('3blindmice'),('3boys1girl'),('3brothers'),('3children'),('3d8Cubaj2E'),('3daughters'),('3daysgrace'),('3dognight'),('3doorsdown'),('3e2w1q'),('3e3e3e'),('3e4r5t'),('3e4r5t6y'),('3edc4rfv'),('3edcvfr4'),('3eHd1ixi1Y'),('3foZaqb33Q'),('3friends'),('3girls'),('3grandkids'),('3horses'),('3iverson'),('3kids'),('3kids4me'),('3kings'),('3kitties'),('3l3m3nt'),('3l3phant'),('3monkeys'),('3Odi14ngxB'),('3Odi15ngxB'),('3Odi55ngxB'),('3password'),('3pointer'),('3puppies'),('3q2w3e4r3t'),('3Qdlqb49jS'),('3qvn5K4qgV'),('3rdeye'),('3rdward'),('3rJs1la2qE'),('3rJs1la7qE'),('3rJs5la8qE'),('3s43pth5aea'),('3sa8xK4xDZ'),('3sisters'),('3stars'),('3stooges'),('3sYqo15hiL'),('3tb8xL42BJ'),('3tb9xM42xI'),('3three'),('3tktkthth'),('3Tutso24qF'),('3u7wrkaA8J'),('3ub9xM53xI'),('3uc9xN53xH'),('3yIxda15hR'),('3ZibUVmRx6'),('4'),('4000'),('400000'),('400001'),('400002'),('400003'),('400004'),('400005'),('400006'),('400007'),('400008'),('400009'),('400012'),('400013'),('400016'),('400018'),('400019'),('400020'),('400021'),('400022'),('400025'),('400026'),('400028'),('400037'),('400049'),('400050'),('400051'),('400052'),('400053'),('400054'),('400055'),('400056'),('400057'),('400058'),('400059'),('400060'),('400061'),('400062'),('400063'),('400064'),('400066'),('400067'),('400068'),('400069'),('400070'),('400071'),('400072'),('400074'),('400076'),('400077'),('400078'),('400079'),('400080'),('400081'),('400086'),('400088'),('400089'),('400091'),('400092'),('400093'),('400094'),('400095'),('400097'),('400098'),('400099'),('400101'),('400102'),('400103'),('40028922'),('400400'),('400601'),('400602'),('400604'),('400606'),('400607'),('400610'),('400614'),('400701'),('400703'),('400705'),('400706'),('400708'),('400709'),('401101'),('401105'),('401107'),('401202'),('4040'),('404040'),('40404040'),('4040782as'),('4043vd'),('405060'),('4071505'),('4077mash'),('4079'),('4097870'),('410000'),('410206'),('410210'),('41034103'),('410410'),('411'),('411001'),('411004'),('411006'),('411007'),('411013'),('411014'),('411015'),('411016'),('411018'),('411019'),('411021'),('411027'),('411028'),('411030'),('411033'),('411037'),('411038'),('411040'),('411044'),('411045'),('411048'),('411052'),('411057'),('411411'),('412'),('4123'),('41234123'),('412412'),('4128'),('413413'),('4141'),('414141'),('41414141'),('414200'),('414243'),('414414'),('415'),('415263'),('415415'),('41563445'),('416416'),('417417'),('419'),('419419'),('420'),('4200'),('420000'),('420024'),('4201'),('420247'),('420420'),('420420420'),('420420a'),('4204life'),('420666'),('42069'),('4209211'),('420allday'),('420bitch'),('420blaze'),('420bud'),('420high'),('420love'),('420man'),('420pot'),('420smoke'),('420stoner'),('420time'),('420weed'),('421201'),('421202'),('421301'),('421421'),('421uiopy258'),('4224035'),('422422'),('423423'),('423456'),('4242'),('424242'),('42424242'),('4242564'),('425425'),('426426'),('42684268'),('426hemi'),('427468'),('427cobra'),('4294967296'),('43046721'),('431001'),('432'),('4321'),('432100'),('43211234'),('43214321'),('432156'),('4321rewq'),('432432'),('4343'),('434343'),('43434343'),('435453'),('4391634m'),('43922572'),('44'),('440010'),('440022'),('440226'),('4422'),('442244'),('443322'),('44332211'),('444'),('444111'),('444222'),('444333'),('4444'),('44442013vkkv'),('444422'),('44444'),('444444'),('4444444'),('44444444'),('444444444'),('4444444444'),('444444a'),('444455'),('44445555'),('44448888'),('444555'),('444555666'),('444666'),('444777'),('444888'),('4454708'),('4455'),('445544'),('44554455'),('445566'),('44556677'),('445566a'),('446688'),('4488'),('44f16f17f'),('44gatti'),('44magnum'),('45'),('450000'),('450450'),('45124512'),('451451'),('452001'),('452010'),('45214521'),('452452'),('453'),('454'),('454454'),('4545'),('454545'),('45454545'),('4545454545'),('454545a'),('454647'),('45533990'),('4554'),('455445'),('45544554'),('455455'),('456'),('4561'),('456123'),('4561230'),('456123789'),('456123a'),('456258'),('456321'),('456456'),('456456456'),('456456a'),('45654565'),('456654'),('4567'),('45674567'),('45678'),('456789'),('4567890'),('4567891'),('45678910'),('456789123'),('456789a'),('456838'),('45683968'),('456852'),('4568520'),('456852a'),('4569'),('456963'),('456987'),('456abc'),('456asd'),('456rty'),('458458'),('45874587'),('45M2DO5BS'),('462001'),('462016'),('46265216'),('463395727'),('4646'),('464646'),('46464646'),('46466452'),('4649'),('46494649'),('465465'),('46709394'),('46and2'),('4711'),('47114711'),('4747'),('474747'),('47474747'),('474849'),('475869'),('47593893'),('476730751'),('481516'),('48151623'),('4815162342'),('4815162342a'),('4815162342lost'),('4815162342q'),('482001'),('4826159'),('483483'),('484066'),('4848'),('484848'),('48484848'),('48624862'),('486255'),('486486'),('491001'),('492001'),('492529'),('4949'),('494949'),('49494949'),('49ers'),('49ers1'),('49ersrule'),('49erss'),('4always'),('4angels'),('4babies'),('4beatles'),('4brothers'),('4children'),('4christ'),('4eternity'),('4ever'),('4ever1'),('4ever21'),('4everlove'),('4everluv'),('4everme'),('4evermine'),('4evermore'),('4everurs'),('4everyoung'),('4everyours'),('4f51eijViF'),('4family'),('4forever'),('4freedom'),('4friends'),('4g3uvrXn7W'),('4getit'),('4getmenot'),('4girls'),('4given'),('4gotten'),('4grandkids'),('4horsemen'),('4horses'),('4j9r4rnTtP'),('4jesus'),('4linkedin'),('4me2know'),('4me2no'),('4meonly'),('4money'),('4monkeys'),('4music'),('4mutdfgvtp'),('4myfamily'),('4mygirls'),('4mykids'),('4mylove'),('4myself'),('4myspace'),('4password'),('4peace'),('4pussy'),('4r3e2w1q'),('4r5t6y'),('4r5t6y7u'),('4rfv5tgb'),('4rfvbgt5'),('4runner'),('4seasons'),('4shizzle'),('4sisters'),('4success'),('4sunshine'),('4thekids'),('4thofjuly'),('4twenty'),('4u2nvme'),('4vdaxP542G'),('4vgYvq46aJ'),('4wdaxP642F'),('4wdaxQ642F'),('4weaxQ642E'),('4wheeler'),('4xeaxR653E'),('4xebxR653D'),('4xxlqU94yO'),('4yfb2S753C'),('4yfb2S753D'),('5'),('5.254.105.20:test'),('5.254.105.20:test1'),('50'),('500'),('5000'),('50000'),('500000'),('500001'),('500003'),('500004'),('500005'),('500007'),('500008'),('500009'),('500011'),('500013'),('500015'),('500016'),('500017'),('500018'),('500020'),('500026'),('500028'),('500029'),('500032'),('500033'),('500034'),('500035'),('500036'),('500038'),('500044'),('500045'),('500047'),('500049'),('500050'),('500060'),('500062'),('500072'),('500073'),('500076'),('500081'),('500082'),('5005'),('500500'),('500600'),('501501'),('502502'),('504boy'),('504boyz'),('505'),('5050'),('50505'),('505050'),('50505050'),('505505'),('506070'),('50cent'),('50cent1'),('50cent123'),('50cent50'),('50cents'),('5101520'),('510510'),('511511'),('512'),('51200000'),('5121314'),('5121472'),('512345'),('512512'),('51286700'),('513513'),('514514'),('5150'),('515000'),('515051'),('51505150'),('5151'),('515151'),('51515151'),('515253'),('51525354'),('5152535455'),('51535759'),('515515'),('51615801'),('516516'),('516888'),('517501'),('517517'),('518518'),('518888'),('519519'),('520'),('5200'),('520000'),('520025'),('520123'),('5201314'),('52013140'),('5201314520'),('5201314a'),('5203344'),('520520'),('520520520'),('520521'),('520530'),('520999'),('520LOVE101182'),('521'),('521000'),('52105210'),('521125'),('5211314'),('521314'),('5213344'),('521521'),('521521521'),('5225'),('522522'),('52253823'),('52255225'),('523'),('523252'),('5234055'),('523456'),('523456789'),('523523'),('5236'),('523698741'),('524524'),('524645'),('5251410'),('5252'),('525252'),('52525252'),('5254'),('5254143'),('52545658'),('525525'),('5262499'),('526282'),('526452'),('526526'),('527527'),('527728'),('528528'),('52hoova'),('52hoover'),('52xmax'),('530016'),('530017'),('530530'),('531531'),('5324'),('532532'),('533533'),('533656'),('53472235'),('5353'),('535353'),('53535353'),('535535'),('540000'),('541788'),('54226269'),('5432'),('54321'),('543210'),('543211'),('5432112345'),('5432154321'),('543216'),('54321a'),('54321q'),('543543'),('5454'),('545454'),('54545454'),('5455'),('545545'),('54565456'),('546546'),('547896321'),('5482'),('5482++'),('55'),('550055'),('550550'),('551155'),('551976MS'),('5522'),('552200'),('552211'),('552233'),('552255'),('55225522'),('5525'),('55255525'),('5532361cnjqrf'),('5544'),('554433'),('5544332211'),('554455'),('554466'),('555'),('555000'),('5550123'),('5550666'),('555111'),('5551212'),('555123'),('555151asd'),('555222'),('555333'),('555444'),('5555'),('55554444'),('55555'),('555550'),('555551'),('555555'),('5555551'),('5555555'),('55555555'),('555555555'),('5555555555'),('55555555555'),('555555555555'),('555555555555555'),('5555555tl'),('555555a'),('555555q'),('555555s'),('555556'),('5555566666'),('55555a'),('55555b'),('55555d'),('55555f'),('55555j'),('55555k'),('55555l'),('55555lvl'),('55555m'),('55555q'),('55555r'),('55555s'),('55555t'),('55555z'),('555566'),('55556666'),('55558888'),('555666'),('555666777'),('555666a'),('555777'),('555888'),('555999'),('555aaa'),('556556'),('5566'),('556644'),('556655'),('55665566'),('556677'),('55667788'),('5566778899'),('556688'),('556699'),('5577'),('557733'),('557755'),('557799'),('5588'),('558855'),('558899'),('55chevy'),('56'),('560001'),('560002'),('560003'),('560004'),('560005'),('560008'),('560010'),('560011'),('560016'),('560017'),('560025'),('560027'),('560029'),('560032'),('560034'),('560037'),('560038'),('560040'),('560043'),('560047'),('560048'),('560050'),('560052'),('560054'),('560058'),('560064'),('560066'),('560068'),('560070'),('560071'),('560072'),('560075'),('560076'),('560078'),('560079'),('560084'),('560085'),('560093'),('560094'),('560095'),('560097'),('560100'),('560102'),('560103'),('5609867'),('5610405'),('563214789'),('5633634'),('564321'),('564335'),('564564'),('564738'),('5647382910'),('5656'),('565656'),('56565656'),('565758'),('566556'),('566566'),('567'),('567567'),('567567567'),('567765'),('5678'),('56785678'),('56789'),('567890'),('567891'),('5678910'),('5678dance'),('567tyu'),('5683'),('56835683'),('5683love'),('568568'),('5695595'),('569874123'),('56chevy'),('56tyghbn'),('571632'),('5757'),('575757'),('57575757'),('575859'),('577191'),('578322'),('579395571'),('57chevy'),('584131420'),('584131421'),('5841314520'),('5841314521'),('584201314'),('584520'),('5845201314'),('584521'),('5845211314'),('58565254'),('5858'),('585858'),('58585858'),('586016'),('586586'),('58666z'),('588588'),('589589'),('59230120'),('594love168'),('595490067ua1'),('5959'),('595959'),('59595959'),('5963'),('59635963'),('59blood'),('59fifty'),('59mile'),('59piru'),('59trick'),('5a8b9c2d'),('5Ahc2V875z'),('5alive'),('5angels'),('5Bhc2V875z'),('5blood'),('5bt2jtzTKE'),('5children'),('5demayo'),('5element'),('5fingers'),('5girls'),('5grandkids'),('5hsU75kpoT'),('5jN16uxpiD'),('5million'),('5monkeys'),('5plK4L5Uc7'),('5point'),('5poppin'),('5q2w3e4r5t'),('5qwerty67890'),('5starbitch'),('5starchick'),('5starg'),('5stars'),('5string'),('5t4r3e2w1q'),('5t6y7u'),('5t6y7u8i'),('5tgb6yhn'),('5tgbnhy6'),('5thward'),('5times'),('5X1CJdsb9p'),('5xfgs3Ii9D'),('5xq57cGseB'),('5zgb2T764B'),('5zgc2T764B'),('6'),('600000'),('600001'),('600002'),('600004'),('600005'),('600006'),('600010'),('600014'),('600015'),('600017'),('600018'),('600020'),('600024'),('600028'),('600032'),('600033'),('600034'),('600037'),('600040'),('600041'),('600042'),('600044'),('600053'),('600061'),('600073'),('600078'),('600083'),('600087'),('600088'),('600089'),('600091'),('600092'),('600094'),('600096'),('600100'),('600116'),('600600'),('601601'),('6031769'),('603575'),('6041074'),('604604'),('6060'),('606060'),('60606060'),('606606'),('60crip'),('610610'),('611611'),('612345'),('6125060'),('612612'),('613613'),('615243'),('615615'),('6161'),('616161'),('61616161'),('616263'),('616616'),('6173580'),('618618'),('619'),('619619'),('619619619'),('619rey'),('61atnakaeva'),('620620'),('620850'),('6215348'),('621621'),('622906268'),('623623'),('624624'),('62543234'),('625625'),('6262'),('626262'),('62626262'),('626626'),('628628'),('630630'),('63145151'),('6323463'),('63245009'),('63256632'),('634142554'),('635241'),('6358986'),('636234'),('6363'),('636322'),('636332'),('636363'),('63636363'),('637846'),('639374'),('63impala'),('63val63'),('6430130'),('6435'),('6450716'),('6453'),('6464'),('646464'),('64646464'),('64chevy'),('64impala'),('65'),('650829yjm'),('654'),('654123'),('654312'),('65432'),('654321'),('6543210'),('65432100'),('6543211'),('654321123456'),('654321987'),('654321a'),('654321abc'),('654321b'),('654321c'),('654321d'),('654321j'),('654321k'),('654321l'),('654321m'),('654321p'),('654321q'),('654321r'),('654321s'),('654321t'),('654321w'),('654321z'),('65432a'),('654456'),('654654'),('654654654'),('654789'),('654852'),('654987'),('654987321'),('6552090'),('655321'),('6565'),('656565'),('65656565'),('6572757'),('65impala'),('65mustang'),('65stang'),('66'),('6610_2006'),('663366'),('6651953'),('6655321'),('665544'),('665566'),('665665'),('666'),('666000'),('666111'),('666123'),('6661313'),('66613666'),('666222'),('666333'),('666420'),('666425'),('666444'),('666555'),('6666'),('66666'),('666665'),('666666'),('6666661'),('6666666'),('66666666'),('666666666'),('6666666666'),('666666666666'),('6666666666EMPULGARA'),('6666667'),('666666a'),('666666d'),('666666g'),('666666j'),('666666k'),('666666m'),('666666q'),('666666s'),('666666t'),('666666z'),('666667'),('66666a'),('66667777'),('66668888'),('66669999'),('666777'),('666777888'),('666888'),('6669'),('666999'),('666999666'),('666aaa'),('666beast'),('666devil'),('666fafnir'),('666hell'),('666satan'),('666xxx'),('667788'),('66778899'),('668668'),('668899'),('6699'),('669966'),('66996699'),('66bob'),('66chevelle'),('66chevy'),('66mustang'),('673kobby'),('67529353'),('6767'),('676767'),('67676767'),('676869'),('678678'),('678876'),('6789'),('67890'),('678900'),('678901'),('678910'),('67896789'),('679956'),('67camaro'),('67chevelle'),('67chevy'),('67mustang'),('67shelby'),('681774'),('6817zd57'),('6820055'),('68582988'),('686611'),('686686'),('6868'),('686868'),('68686868'),('68camaro'),('68charger'),('68chevelle'),('68chevy'),('68mustang'),('69'),('6917123'),('695847'),('696'),('69664848'),('6969'),('696969'),('69696969'),('6969696969'),('696969a'),('696969j'),('6996'),('699669'),('69966996'),('69bitch'),('69camaro'),('69camero'),('69charger'),('69chevelle'),('69chevy'),('69cougar'),('69dude'),('69eyes'),('69love'),('69lover'),('69mustang'),('69pussy'),('69qd5CgxhU'),('6Acaxa54bE'),('6cctbbk516'),('6children'),('6cs2huAULF'),('6Cxd2X986x'),('6D2-24E5r'),('6dnwch275049'),('6Exe3Za97v'),('6feetunder'),('6flags'),('6grandkids'),('6hBf28W791'),('6letters'),('6lfXlo629uI'),('6point'),('6poppin'),('6shooter'),('6string'),('6strings'),('6thgrade'),('6uldv8'),('6V21wbgad'),('6y4rV0a992'),('6yhn7ujm'),('7'),('7000'),('70000'),('700000'),('700001'),('700006'),('700007'),('700016'),('700017'),('700019'),('700020'),('700027'),('700029'),('700040'),('700059'),('700064'),('700075'),('700084'),('700091'),('7001850'),('7007'),('700700'),('7008'),('70142021103'),('7070'),('707070'),('70707070'),('707707'),('708090'),('709394'),('70chevelle'),('71'),('710710'),('711'),('711101'),('7117'),('711711'),('71191926'),('7123456'),('712712'),('71310615'),('713713'),('713houston'),('7142128'),('714714'),('7153'),('7171'),('717171'),('71717171'),('717273'),('717717'),('718293'),('71chevelle'),('720720'),('721521'),('721721'),('723723'),('723723723'),('725725'),('7272'),('727272'),('72727272'),('727727'),('72chevelle'),('72chevy'),('72nova'),('731731'),('734001'),('73439984'),('7344555'),('734992'),('73501505'),('7355608'),('7373'),('737373'),('73737373'),('737kkbLskV'),('7399'),('73jaGtk4q'),('741'),('7410'),('741000'),('741023'),('7410258'),('74107410'),('7410852'),('74108520'),('741085209630'),('7410852963'),('741123'),('741147'),('7412'),('74123'),('741230'),('741236'),('7412369'),('74123698'),('741236985'),('741258'),('741258963'),('741369'),('7414'),('741456'),('741456963'),('7415963'),('741741'),('741741741'),('741852'),('74185296'),('741852963'),('7418529630'),('741852963a'),('741852963q'),('741852963z'),('741852a'),('741953'),('741963'),('7419635'),('741963852'),('742617000027'),('74699723'),('7474'),('747400'),('747474'),('74747474'),('747546'),('747747'),('748159263'),('748596'),('748748'),('74a82s78'),('74gangsta'),('750750'),('751001'),('751002'),('751010'),('751953'),('753'),('753159'),('753214'),('7532159'),('753357'),('753421'),('753753'),('753951'),('7539510'),('753951456'),('753951852'),('753951852456'),('753951a'),('753dfx'),('754321'),('7546'),('7550055'),('7555545'),('7575'),('757575'),('75757575'),('757757'),('759123asd'),('759153'),('75fs'),('765432'),('7654321'),('76543210'),('7654321a'),('7654321q'),('765765'),('7676'),('767676'),('76767676'),('77'),('7700'),('770077'),('770770'),('770880'),('771122'),('771177'),('772324'),('7732844'),('7734'),('774411'),('774517397'),('7753191'),('7753191a'),('775533'),('775577'),('7758258'),('7758520'),('7758521'),('77585210'),('7758991'),('776158ab'),('776655'),('777'),('777000'),('7770777'),('777111'),('777123'),('777222'),('777333'),('777444'),('777555'),('777555333'),('777555666'),('777666'),('7777'),('77777'),('777771'),('777777'),('7777771'),('7777777'),('77777771'),('77777777'),('777777777'),('7777777777'),('777777777777'),('77777778'),('7777777a'),('7777777c'),('7777777d'),('7777777j'),('7777777k'),('7777777m'),('7777777n'),('7777777q'),('7777777s'),('7777777v'),('7777777z'),('777777a'),('777777q'),('777777s'),('777778'),('77777a'),('77778888'),('77779999'),('7777_74'),('777888'),('777888999'),('7779311'),('777999'),('777aaa'),('777dashuta157'),('777jesus'),('777kroxa'),('777vlad'),('7783757s'),('7788'),('7788250'),('7788414'),('7788520'),('7788521'),('778866'),('778877'),('77887788'),('778899'),('77889900'),('7794422'),('779977'),('78'),('780405'),('780504'),('780813'),('781001'),('781003'),('781005'),('781006'),('781007'),('781012'),('781020'),('781021'),('781022'),('781024'),('781025'),('781028'),('781227'),('784512'),('7845120'),('784512963'),('784533'),('784951623'),('785412'),('785612'),('786'),('786000'),('786110'),('786123'),('786786'),('786786786'),('786allah'),('7878'),('787878'),('78787878'),('787898'),('789'),('7890'),('789000'),('789012'),('78907890'),('7890uiop'),('78910'),('7891011'),('789123'),('789123456'),('7891235'),('78917891'),('789321'),('7894'),('78945'),('789456'),('7894561'),('78945612'),('789456123'),('7894561230'),('7894561231'),('789456123a'),('789456123b'),('789456123m'),('789456123q'),('789456123z'),('789456321'),('789456a'),('789456m'),('789456q'),('789456qwe'),('7895123'),('78951230'),('789512357'),('7895123z'),('789520'),('789521'),('789523'),('789551'),('7896'),('78963'),('789632'),('7896321'),('78963214'),('789632145'),('789632147'),('789654'),('789654123'),('7896541230'),('789654321'),('789741'),('789789'),('789789789'),('789789a'),('789852'),('789852123'),('789963'),('789987'),('789987789'),('789qwe'),('78kdow9sPF'),('791010'),('791028'),('791111'),('791127'),('791159392'),('79137913'),('794613'),('794613258'),('794613852'),('795001'),('79621601378.kirill'),('79641777070'),('7979'),('797979'),('79797979'),('79camaro'),('79ford'),('79transam'),('7angels'),('7children'),('7cr2guBVMG'),('7e9lNk3fc01'),('7e9lNk3fcO'),('7elephants'),('7eleven'),('7f4df451'),('7fperlangel'),('7Fxf3Jaa7u'),('7Fxf3Jba8t'),('7grandkids'),('7heaven'),('7inches'),('7jokx7b9DU'),('7nc4lqW7tO'),('7samurai'),('7seven'),('7seven7'),('7sfqc8zI5D'),('7sO2ekbc6R'),('7stars'),('7thgrade'),('7thheaven'),('7things'),('7thward'),('7u8i9o0p'),('7uGd5HIp2J'),('7uqbwx8N4Z'),('7US20'),('7v8bv5TeoW'),('8'),('8-9899578642'),('80'),('80000'),('800000'),('800001'),('800008'),('800020'),('800620'),('8008'),('800800'),('8008070'),('8008beb'),('801010'),('801018'),('801020'),('801122'),('801123'),('801124'),('801212'),('801225'),('80173Rroom5'),('8080'),('80808'),('808080'),('80808080'),('808808'),('808state'),('809'),('80959002443'),('80baby'),('80fefune'),('80sbaby'),('810810'),('811009'),('811010'),('811018'),('811020'),('811023'),('811024'),('811025'),('811026'),('811028'),('811029'),('811118'),('811224bai'),('811225'),('811228'),('811811'),('8123'),('812812'),('813813'),('814336633'),('815815'),('81726354'),('8181'),('818181'),('81818181'),('818283'),('818818'),('820820'),('820919'),('821010'),('821011'),('821012'),('821013'),('821014'),('821015'),('821016'),('821017'),('821018'),('821020'),('821021'),('821022'),('821023'),('821024'),('821025'),('821026'),('821028'),('821121'),('821125'),('821126'),('821128'),('821210'),('821212'),('821218'),('821224'),('821225'),('821226'),('821228'),('82214989'),('824553435ss'),('824655'),('82468246'),('825825'),('82597971'),('827ccb0eea8a706c4c'),('8282'),('828282'),('82828282'),('828828'),('82airborne'),('830830'),('830928urodziny'),('831001'),('831004'),('831005'),('831010'),('831011'),('831012'),('831013'),('831018'),('831022'),('831024'),('831220'),('834001'),('834002'),('83742222'),('83773049'),('8383'),('838383'),('841010'),('841012'),('841015'),('841018'),('841020'),('841022'),('841023'),('841024'),('841025'),('841026'),('841027'),('841028'),('841029'),('841226'),('84131421'),('842001'),('842655'),('84268426'),('84569280'),('84728472'),('8484'),('848484'),('84848484'),('849vak17'),('851010'),('851023'),('851120'),('851123'),('851125'),('851210'),('851212'),('851216'),('852'),('8520'),('852000'),('85200258'),('8520456'),('85207410'),('85208520'),('852123'),('852147'),('85218812'),('8522003'),('852258'),('852369'),('852456'),('852456852456'),('852456a'),('852456i'),('852654'),('852741'),('852741963'),('852852'),('852852852'),('852963'),('852963741'),('8562835'),('85726648'),('8585'),('858585'),('85858585'),('858877108aop'),('85bears'),('85chevy'),('86'),('8602229096klo'),('86026403'),('861229'),('8616695'),('86248624'),('863560'),('86402241'),('8657'),('8675309'),('8675309a'),('8675309j'),('8686'),('868686'),('86868686'),('870621345'),('871982'),('875421'),('87651234'),('876543'),('8765432'),('87654321'),('876543210'),('87654321a'),('87654321q'),('87654321q.'),('876876'),('8787'),('878787'),('87878787'),('87calis'),('87chevy'),('88'),('88002000600'),('880088'),('880505'),('881122'),('881988'),('88488848'),('885522'),('88552200'),('886688'),('886886'),('887766'),('888'),('888000'),('888111'),('888168'),('888222'),('888333'),('888444'),('888555'),('888666'),('888777'),('888777-'),('8888'),('88888'),('888888'),('8888881'),('8888888'),('88888888'),('888888881'),('888888888'),('8888888888'),('88888888a'),('888888a'),('888889'),('88888a'),('88889999'),('888999'),('889889'),('8899'),('889900'),('889977'),('889988'),('88998899'),('88chevy'),('88keys'),('88mustang'),('89'),('890'),('890098'),('890123'),('89058895869cth'),('890890'),('890iop'),('891'),('891011'),('89140041205'),('89173371487v'),('892'),('89216279708a'),('89217657066'),('89272585'),('892892'),('893208'),('8933959'),('895'),('895623'),('89631139'),('8989'),('898989'),('89898989'),('89chevy'),('89moocows'),('89mustang'),('8ba9Klw1cE'),('8balls'),('8eight'),('8en3dwDXPI'),('8i9o0p'),('8iIw4Ct9Rq'),('8inches'),('8ix6S1fceH'),('8letters'),('8marta'),('8PHroWZ622'),('8PHroWZ624'),('8point'),('8rlB9l1sqU'),('8seconds'),('8thgrade'),('8uxzd1b3BD'),('8vfhnf'),('8wwH19duyJ'),('8x2h4Eddan'),('8x2h4Fccap'),('8x2h4Fddap'),('8xxg4Gcc9q'),('9'),('9-11-1961'),('90'),('9000'),('900000'),('9009'),('900900'),('900900m'),('90107142a'),('90210'),('902100'),('9021090210'),('902860'),('9052950013'),('906090'),('90801'),('908070'),('9086916264'),('909'),('9090'),('90909'),('909090'),('90909090'),('9090909090'),('909909'),('910910'),('911'),('911007'),('9111'),('911111'),('911119'),('9111961'),('9119'),('911911'),('911911911'),('911turbo'),('9121318barssuki'),('912401'),('912912'),('913913'),('916916'),('918273'),('91827364'),('918273645'),('91866709'),('918918'),('9191'),('919191'),('91919191'),('919293'),('9198425200'),('919919'),('91camaro'),('91mustang'),('920920'),('921921'),('92246247'),('92298899'),('922i4Ceebk'),('922i4Ddebm'),('922i4Deebm'),('922j5Cefcj'),('92631043'),('9268356683'),('92702689'),('929292'),('9293709b13'),('92camaro'),('92Dk2cidP'),('92k2cizCdP'),('9379992'),('9379992a'),('9379992q'),('938271'),('939393'),('93mustang'),('94246843'),('94327579'),('946hvt'),('94793763'),('949494'),('94mustang'),('9508402243id'),('951'),('951159'),('95123'),('9512357'),('951236'),('951357'),('95135876'),('951623'),('951753'),('951753123'),('951753456'),('951753654'),('951753852'),('951753852456'),('951753a'),('951753aa'),('951951'),('951951951'),('95279527'),('95368452'),('956208q'),('9562876'),('958506'),('9595'),('959595'),('95959595'),('95camaro'),('95chevy'),('95civic'),('95mustang'),('9602929770'),('96101z'),('96132925'),('962464'),('963'),('963123'),('963147'),('96321'),('963210'),('963214'),('9632147'),('96321478'),('963214785'),('963258'),('963258741'),('9632587410'),('963321'),('963369'),('963741'),('963741852'),('963852'),('96385274'),('963852741'),('9638527410'),('963852741a'),('963963'),('963963963'),('964123'),('968574'),('9696'),('969696'),('96969696'),('96impala'),('96mustang'),('9749676621ok'),('97531'),('975310'),('976431'),('9788960'),('979575'),('9797183185'),('979797'),('97979797'),('979899'),('980099'),('9852a9'),('985632'),('985985'),('986532'),('987'),('987123'),('987321'),('987321654'),('987410'),('9874123'),('98741236'),('987412365'),('987456'),('987456123'),('987456321'),('9874563210'),('9875321'),('9876'),('98765'),('987654'),('9876541'),('987654123'),('9876543'),('98765432'),('987654321'),('9876543210'),('98765432100'),('9876543211'),('987654321123456789'),('987654321a'),('987654321b'),('987654321c'),('987654321d'),('987654321g'),('987654321j'),('987654321k'),('987654321l'),('987654321m'),('987654321n'),('987654321p'),('987654321q'),('987654321r'),('987654321s'),('987654321t'),('987654321w'),('987654321z'),('987654a'),('987654q'),('98765a'),('98766789'),('98769876'),('987789'),('987987'),('987987987'),('9898'),('989898'),('98989898'),('98chevy'),('98mustang'),('99'),('9900'),('990099'),('99009900'),('990990'),('991199'),('995511'),('9958123'),('996633'),('996699'),('9988'),('998877'),('99887766'),('9988776655'),('998899'),('99889988'),('998998'),('999'),('999000'),('999111'),('999123'),('999333'),('999555'),('999666'),('999666333'),('999777'),('999888'),('999888777'),('9999'),('99990000'),('99998888'),('99999'),('999990'),('999991'),('999998'),('999999'),('9999991'),('9999999'),('99999999'),('999999999'),('9999999999'),('999999999999'),('999999999a'),('999999a'),('99999a'),('99bottles'),('99mustang'),('99problems'),('99XfXlo19uI'),('9ac9hb7vVX'),('9inches'),('9inchnails'),('9itz78vUfW'),('9lives'),('9thward'),('9uzp9jEk3F'),('9xx7c8GseB'),('9yQss2h9uB'),('9YUE27RI'),(':'),(':lol'),(':tytxrf'),(';tytxrf'),('<blank>'),('<password>'),('?'),('??'),('???'),('????'),('?????'),('??????'),('???????'),('????????'),('?????????'),('??????????'),('???????????'),('????????????'),('???????????????'),('??????@mail.ru'),('@!@'),('@123456'),('@@@@@@'),('@@@@@@@@@@'),('@bigmir.net'),('@elit-centr.com.ua'),('@gmail.com.mx'),('@mail.ru'),('@yahoo'),('@yahoo.com'),('a'),('a!515253'),('a00000'),('a000000'),('a0000000'),('a00000000'),('a010203'),('a012345'),('a0123456'),('a101010'),('a102030'),('a11111'),('a111111'),('a1111111'),('a11111111'),('a111111111'),('a111222'),('a112233'),('a11223344'),('a1169619'),('a121212'),('a12121212'),('a123'),('a123098'),('a123123'),('a123123123'),('a123123a'),('a12321'),('a123321'),('a123321a'),('a1234'),('a12341234'),('a12344321'),('a12345'),('a123456'),('a1234567'),('a12345678'),('a123456789'),('a1234567890'),('a123456789a'),('a123456a'),('a123456b'),('a123456z'),('a12345a'),('a12345b'),('a1234a'),('a1234b'),('a123654'),('a123654789'),('a123789'),('a123a123'),('a123b456'),('a123sd'),('a12b13c14'),('a131313'),('a1314520'),('a134679'),('a13579'),('a147258'),('a147258369'),('a147852'),('a159357'),('a159753'),('a1a1a1'),('a1a1a1a1'),('a1a1a1a1a1'),('a1a2a3'),('a1a2a3a4'),('a1a2a3a4a5'),('a1a2a3a4a5a6'),('a1b1c1'),('a1b1c1d1'),('a1b2c3'),('a1b2c3d'),('a1b2c3d4'),('a1b2c3d4e5'),('a1b2c3d4e5f6'),('a1l2e3x4'),('a1s2d3'),('a1s2d3f4'),('a1s2d3f4g5'),('a1s2d3f4g5h6'),('a1sauce'),('a1z2e3'),('a1z2e3r4'),('a212121'),('a22222'),('a222222'),('a22j5Bffci'),('a232323'),('a23456'),('a234567'),('a2345678'),('a23456789'),('a246810'),('a252525'),('a2a2a2'),('a2a2a2a2'),('a321321'),('a33333'),('a333333'),('a333444'),('a33k5Afgdh'),('a3eilm2s2y'),('a420420'),('a42904290'),('a444444'),('a456123'),('a456456'),('a456789'),('a4s5d6'),('a4tech'),('a5201314'),('a520520'),('a54321'),('a55555'),('a555555'),('a654321'),('a6543210'),('a66666'),('a666666'),('a696969'),('a741852'),('a741852963'),('a753951'),('a7654321'),('a7758521'),('a77777'),('a777777'),('a7777777'),('a789456'),('a789456123'),('a7CkuntLDy'),('a7x4life'),('a7xa7x'),('a7xrocks'),('a801016'),('a838hfiD'),('a8675309'),('a87654321'),('a88888'),('a888888'),('a88888888'),('a951753'),('a987654'),('a987654321'),('a99999'),('a999999'),('a9999999'),('a999999999'),('a:sldkfj'),('aa'),('aa000000'),('aa1111'),('aa111111'),('aa1122'),('aa112233'),('aa11aa'),('aa11bb22'),('aa123123'),('aa123321'),('aa1234'),('aa12345'),('aa123456'),('aa1234561'),('aa1234567'),('aa12345678'),('Aa123456789'),('aa224466'),('aa261599'),('aa3030316'),('aa456852'),('aa5201314'),('aaa'),('aaa000'),('aaa111'),('aaa111aaa'),('aaa123'),('aaa123123'),('aaa1234'),('aaa12345'),('aaa123456'),('aaa147'),('aaa222'),('aaa333'),('aaa444'),('aaa555'),('aaa666'),('aaa777'),('aaa888'),('aaa999'),('aaaa'),('aaaa0000'),('aaaa11'),('aaaa1111'),('aaaa12'),('aaaa123'),('aaaa1234'),('aaaaa'),('aaaaa1'),('aaaaa11111'),('aaaaa2'),('aaaaa5'),('aaaaa6'),('aaaaaa'),('aaaaaa.'),('aaaaaa1'),('aaaaaa11'),('aaaaaa12'),('aaaaaa123'),('aaaaaa2'),('aaaaaa6'),('aaaaaa7'),('aaaaaaa'),('aaaaaaa1'),('aaaaaaa7'),('aaaaaaaa'),('aaaaaaaa1'),('aaaaaaaaa'),('aaaaaaaaa1'),('aaaaaaaaaa'),('aaaaaaaaaaa'),('aaaaaaaaaaaa'),('aaaaaaaaaaaaaaa'),('aaaaaaaaaaaaaaaa'),('aaaabbbb'),('aaaassss'),('aaabbb'),('aaabbb1'),('aaabbb2'),('aaabbbccc'),('aaaddd'),('aaasss'),('aaasss1'),('aaasssddd'),('aaazzz'),('aabb1122'),('aabbcc'),('aabbcc1'),('aabbcc123'),('aabbccdd'),('aachen'),('aaff'),('aakash'),('aaliyah'),('aaliyah01'),('aaliyah08'),('aaliyah1'),('aaliyah12'),('aaliyah123'),('aaliyah2'),('aaliyah22'),('aaliyah3'),('aaliyah4'),('aaliyah5'),('aaliyah7'),('aaprintbb'),('aardvark'),('aardvark1'),('aaron'),('aaron!'),('aaron01'),('aaron07'),('aaron08'),('aaron09'),('aaron1'),('aaron10'),('aaron11'),('aaron12'),('aaron123'),('aaron1234'),('aaron13'),('aaron14'),('aaron15'),('aaron16'),('aaron17'),('aaron18'),('aaron2'),('aaron21'),('aaron22'),('aaron23'),('aaron24'),('aaron3'),('aaron4'),('aaron431'),('aaron5'),('aaron6'),('aaron69'),('aaron7'),('aaron8'),('aaronc'),('aarons'),('aaryan'),('aassdd'),('aassddff'),('aastha'),('AaVlG728'),('aayush'),('ab'),('ab1234'),('ab12345'),('ab123456'),('ab12345678'),('ab12cd34'),('ab69432'),('Ab7f23rSV'),('abab1122'),('ababab'),('abababab'),('abacab'),('abacabb'),('abacaxi'),('abacus'),('abarth'),('abaybay1'),('abayomi'),('abba'),('abbaabba'),('abbas'),('abbey'),('abbey1'),('abbey123'),('abbey2010'),('abbeyroad'),('abbie'),('abbie1'),('abbie123'),('abbigail'),('abbott'),('abby'),('abby01'),('abby07'),('abby08'),('abby10'),('abby11'),('abby12'),('abby123'),('abby1234'),('abby13'),('abby22'),('abbydog'),('abbydog1'),('abbygail'),('abbygirl'),('abbygirl1'),('abc'),('abc-123'),('abc.123'),('abc111'),('abc123'),('abc123!'),('abc123!@#'),('abc123#'),('abc123.'),('abc1231'),('abc123123'),('abc123321'),('abc1234'),('abc12345'),('abc123456'),('Abc123456!'),('abc1234567'),('abc12345678'),('abc123456789'),('abc123@'),('abc123abc'),('abc123abc123'),('abc123def'),('abc123def456'),('abc123xyz'),('abc124'),('abc234'),('abc321'),('abc456'),('abc666'),('abc777'),('abc789'),('abc987'),('abc@123'),('abcabc'),('abcabc1'),('abcabc123'),('abcabcabc'),('abccba'),('abcd'),('abcd11'),('abcd12'),('abcd123'),('abcd1234'),('abcd12345'),('abcd123456'),('abcd2244'),('abcd4321'),('abcd@1234'),('abcdabcd'),('abcde'),('abcde1'),('abcde12'),('abcde123'),('abcde1234'),('abcde12345'),('abcde2'),('abcde3'),('abcde5'),('abcde6'),('abcdef'),('abcdef.'),('abcdef1'),('abcdef12'),('abcdef123'),('abcdef1234'),('abcdef123456'),('abcdef2'),('abcdef3'),('abcdef4'),('abcdef5'),('abcdef6'),('abcdef7'),('abcdefg'),('abcdefg!'),('abcdefg.'),('abcdefg1'),('abcdefg12'),('abcdefg123'),('abcdefg2'),('abcdefg3'),('abcdefg5'),('abcdefg7'),('abcdefgh'),('abcdefgh1'),('abcdefgh12'),('abcdefghi'),('abcdefghi1'),('abcdefghij'),('abcdefghijk'),('abcdefghijkl'),('abcxyz'),('abcxyz123'),('abc_123'),('abd123'),('abdallah'),('abdelkader'),('abdellah'),('abdoul'),('abdoulaye'),('abdul'),('abdul1'),('abdul123'),('abdula'),('abdulaziz'),('abdulla'),('abdullah'),('abdullah1'),('abdullahi'),('abe123'),('abe1973'),('abegail'),('abeille'),('abel'),('abelardo'),('abella'),('Abenteuer'),('abercrombi'),('abercrombie'),('aberdeen'),('aberdeen1'),('abfkrf'),('abgos999'),('abgrtyu'),('abhi'),('abhi123'),('abhi1234'),('abhijeet'),('abhijit'),('abhilash'),('abhilasha'),('abhimanyu'),('abhinav'),('abhishek'),('abi'),('abi123'),('abidemi'),('abidjan'),('abigael'),('abigail'),('abigail01'),('abigail1'),('abigail11'),('abigail12'),('abigail123'),('abigail2'),('abigail3'),('abigail4'),('abigail5'),('abigail7'),('ability'),('abimbola'),('abiodun'),('abiodun1'),('abiola'),('abkbgg'),('abkbvjy'),('ablegod'),('abnormal'),('abogado'),('abosede'),('abpbrf'),('abracadabr'),('abracadabra'),('abraham'),('abraham1'),('abrakadabra'),('abramov'),('abramova'),('abraxas'),('abrejkina'),('abricot'),('abrikos'),('abril'),('abs123'),('absinthe'),('absolut'),('absolut1'),('absolute'),('absolute1'),('abstract'),('abstract1'),('abu123'),('abubakar'),('abucanda'),('abudfv'),('abudhabi'),('abuela'),('abuela1'),('abuelita'),('abuelo'),('abulafia'),('abundance'),('abundance1'),('ABUSE_123456_ABUSE'),('ac'),('ac1234'),('ac123456'),('Ac3SG728'),('acacia'),('academia'),('academic'),('academy'),('academy1'),('acapulco'),('acapulco1'),('acb123'),('acc123'),('acc123.'),('accent'),('accenture'),('accept'),('access'),('access01'),('access1'),('access12'),('access123'),('accident'),('accord'),('accord1'),('account'),('account1'),('account123'),('account2'),('accountant'),('accounting'),('accounts'),('acdc'),('acdc12'),('acdc123'),('acdc1234'),('acdcacdc'),('acdcrocks1'),('ace'),('ace101'),('ace123'),('ace1234'),('ace12345'),('ace154ever'),('aceace'),('aceace1'),('aceeva.irina'),('aceman'),('acer'),('acer12'),('acer123'),('acer1234'),('aceracer'),('aceraspire'),('aceshigh'),('acevedo'),('achiever'),('achille'),('achilles'),('achilles1'),('achraf'),('achtung'),('acid'),('acidburn'),('acinom'),('acissej'),('acm1pt'),('acmilan'),('acmilan1'),('acmilan1899'),('acosta'),('acosta1'),('acoustic'),('acoustic1'),('acquario'),('acqwah'),('acrobat'),('actarus'),('acting'),('acting1'),('action'),('action1'),('action123'),('actionman'),('activa'),('activate'),('active'),('active1'),('AcTlG728'),('actor1'),('actress'),('actress1'),('actros'),('acts238'),('acuario'),('acuario1'),('acura'),('acura1'),('aczx7812'),('ad'),('ad1234'),('ad123456'),('ad1das'),('ad2021'),('ada'),('ada123'),('adaada'),('adaaja'),('adadad'),('adadadad'),('adadeh'),('adaeze'),('adagio'),('adalberto'),('adam'),('adam01'),('adam06'),('adam07'),('adam08'),('adam1'),('adam10'),('adam11'),('adam12'),('adam123'),('adam1234'),('adam12345'),('adam13'),('adam14'),('adam15'),('adam16'),('adam18'),('adam21'),('adam22'),('adam23'),('adam2326'),('adam69'),('adam88'),('adamadam'),('adamant'),('adamek'),('adamko'),('adams'),('adams1'),('adams33486'),('adamson'),('adana01'),('adarsh'),('adc123'),('add123'),('addict'),('addicted'),('addicted1'),('addiction'),('addidas'),('addie'),('addie1'),('addison'),('addison1'),('addison2'),('addl0223'),('address'),('address1'),('ade'),('ade123'),('adeade'),('adebayo'),('adebayo1'),('adebayor'),('adebisi'),('adebola'),('adebowale'),('adedayo'),('adedeji'),('adedoyin'),('adegoke'),('adejimi1'),('adekunle'),('adekunle1'),('adela'),('adelaida'),('adelaide'),('adelaide1'),('adelante'),('adele'),('adele1'),('adeleke'),('adelia'),('adelina'),('adelina1'),('adeline'),('adeline1'),('adelka'),('adelle'),('ademola'),('adenike'),('adeniran'),('adeniyi'),('adeola'),('adeola1'),('adeoye'),('aderonke'),('adeshina'),('adesola'),('adetunji'),('adewale'),('adewale1'),('adewunmi'),('adeyemi'),('adeyinka'),('adg123'),('adgjm'),('adgjmp'),('adgjmpt'),('adgjmptw'),('adgjmptw0'),('adgjmptw1'),('adi'),('adi123'),('adidas'),('adidas01'),('adidas1'),('adidas10'),('adidas11'),('adidas12'),('adidas123'),('adidas13'),('adidas14'),('adidas2'),('adidas21'),('adidas22'),('adidas23'),('adidas3'),('adidas5'),('adidas69'),('adidas7'),('adidas777'),('adidas88'),('adidass'),('adinda'),('adios'),('adithya'),('aditya'),('aditya123'),('adivina'),('adm'),('admin'),('admin01'),('admin1'),('admin12'),('admin1213'),('admin123'),('admin1234'),('admin12345'),('admin123456'),('admin2'),('admin2010'),('admin@123'),('adminadmin'),('administra'),('administrator'),('admins'),('admiral'),('admiral1'),('adnan'),('adnan123'),('adolf'),('adolfhitler'),('adolfo'),('adolfo1'),('adonai'),('adonis'),('adonis1'),('adoption'),('adorable'),('adorable1'),('adr'),('adrenalin'),('adrenalina'),('adrenaline'),('adrian'),('adrian01'),('adrian05'),('adrian06'),('adrian07'),('adrian08'),('adrian09'),('adrian1'),('adrian10'),('adrian11'),('adrian12'),('adrian123'),('adrian1234'),('adrian13'),('adrian14'),('adrian15'),('adrian16'),('adrian17'),('adrian18'),('adrian2'),('adrian21'),('adrian22'),('adrian23'),('adrian24'),('adrian28'),('adrian3'),('adrian4'),('adrian5'),('adrian7'),('adriana'),('adriana1'),('adriana12'),('adriana123'),('adriana13'),('adriana2'),('adriane'),('adrianita'),('adrianna'),('adrianna1'),('adrianne'),('adriano'),('adriano1'),('adriano10'),('adriel'),('adrien'),('adrienne'),('adrienne1'),('ads123'),('adsl120'),('adv23'),('adv24'),('advance'),('advance1'),('advanced'),('advanced1'),('advantage'),('advent'),('advent1'),('adventure'),('adventure1'),('advertising'),('advocate'),('advokat'),('aeiou'),('aeiou1'),('aeiou123'),('aeiou12345'),('aeiouy'),('aekara'),('aekara21'),('aelita'),('aen:'),('aenima'),('aerdna'),('aerial'),('aero123'),('aero87'),('aerobics'),('aeroplane'),('aeropostal'),('aerosmith'),('aerosmith1'),('aerospace'),('aeynbr'),('aezakmi'),('aezakmi1'),('aezakmi123'),('af123456'),('afbic'),('afdjhbn'),('affection'),('affinity'),('afganistan'),('afghan'),('afghan1'),('afghan123'),('afghanistan'),('afi123'),('afireinside'),('afolabi'),('afonso'),('afreen'),('africa'),('africa1'),('africa12'),('africa123'),('african'),('african1'),('afridi'),('afrika'),('afrique'),('afrodita'),('afrodite'),('afroman'),('afroman1'),('afshan'),('afterlife'),('aftermath'),('aftermath1'),('ag1234'),('aga'),('aga123'),('agadir'),('again'),('again1'),('agamemnon'),('agape'),('agape1'),('agapito'),('agarwal'),('agassi'),('agata'),('agata1'),('agatha'),('agatha1'),('agathe'),('agatka'),('agbdlcid'),('agency'),('agenda'),('agent'),('agent0'),('agent007'),('agent1'),('agent47'),('agent99'),('agente007'),('aggarwal'),('aggie'),('aggie1'),('aggies'),('aggies1'),('aggies12'),('aggro1'),('aggroberlin'),('agnes'),('agnes1'),('agnese'),('agness'),('agnieszka'),('agnieszka1'),('agostina'),('agostino'),('agosto'),('agrawal'),('agriculture'),('aguacate'),('aguila'),('aguila1'),('aguilar'),('aguilar1'),('aguilas'),('aguilas1'),('aguilas10'),('aguilera'),('aguirre'),('agung'),('agusia'),('agustin'),('agustin1'),('agustina'),('agustus'),('agyeman'),('ahahah'),('ahbird1984'),('ahfywbz'),('ahjkjdf'),('ahmad'),('ahmad1'),('ahmad123'),('ahmed'),('ahmed1'),('ahmed12'),('ahmed123'),('ahmed12345'),('ahmedabad'),('ahmedahmed'),('ahmed_orudzhov'),('ahmet'),('ahmet123'),('ahojky'),('ahov'),('ahovbipw'),('ahovwpib'),('aiaiai'),('aicha'),('aida'),('aidan'),('aidan1'),('aidan123'),('aidana'),('aiden'),('aiden06'),('aiden07'),('aiden08'),('aiden1'),('aiden123'),('aiden2'),('aigerim'),('aikido'),('aikido1'),('aikman'),('aikman08'),('aikman8'),('aileen'),('aileen1'),('aim123'),('aiman123'),('aimee'),('aimee1'),('aimee123'),('ain123'),('ainara'),('ainhoa'),('aini1314'),('ainsley'),('air'),('air123'),('airbag'),('airborne'),('airborne1'),('airborne82'),('airbus'),('airbus320'),('airbus380'),('airbusa380'),('aircraft'),('airedale'),('airforce'),('airforce1'),('airforce2'),('airhead'),('airhead1'),('airjordan'),('airjordan1'),('airjordan2'),('airjordan23'),('airline'),('airman'),('airmax'),('airmax1'),('airmax95'),('airplane'),('airplane1'),('airplanes'),('airport'),('airport1'),('airsoft'),('airsoft1'),('airtel'),('airwalk'),('airwalk1'),('airwolf'),('aisha'),('aisha1'),('aisha123'),('aishah'),('aishat'),('aishiteru'),('aishiteru1'),('aishwarya'),('aisling'),('aissatou'),('aisyah'),('aitana'),('aj'),('aj1234'),('aj12345'),('aj123456'),('aja152'),('ajajaj'),('ajalaa'),('ajax'),('ajay'),('ajay123'),('AjcuiVd289'),('ajedrez'),('ajhneyf'),('ajibola'),('ajnjuhfabz'),('ajtajt'),('ajtdmw'),('ajtgjm'),('ak'),('ak1234'),('ak123456'),('ak47'),('ak47ak47'),('aka'),('aka123'),('aka1908'),('akademia'),('akademiks11'),('akamaru'),('akanksha'),('akash'),('akash123'),('akasha'),('akasha1'),('akatsuki'),('akatsuki1'),('AKAX89Wn'),('akbar'),('akeem1'),('akhilesh'),('akhtar'),('akindele'),('akinola'),('akinom'),('akinsanmi'),('akinsola'),('akinto'),('akinwale'),('akinyemi'),('akira'),('akira1'),('akira123'),('akkolesnikov'),('akmaral'),('akoako'),('akoito'),('akolang'),('akomismo'),('akon12'),('akon123'),('akopa123'),('akril2442'),('aksaray'),('aksaray68'),('aksenov.dms'),('akshat'),('akshay'),('akshaya'),('aksrms8010'),('aku'),('aku123'),('akucantik'),('akucinta'),('akucintaka'),('akucintakamu'),('akuganteng'),('akunamatata'),('akusayangk'),('akusayangkamu'),('al'),('al1234'),('al123456'),('al1716'),('al1916w'),('al3xand3r'),('ala'),('ala123'),('alabala'),('alabama'),('alabama1'),('alabama12'),('alabama123'),('alabama2'),('alabama3'),('alabaster'),('aladdin'),('aladdin1'),('aladin'),('aladino'),('alain'),('alain1'),('alaina'),('alaina1'),('alakazam'),('alalal'),('alamakota'),('alameda'),('alamierda'),('alamo1'),('alan'),('alan11'),('alan12'),('alan123'),('alan1234'),('alan13'),('alana'),('alana1'),('alana123'),('alanalan'),('alania'),('alanis'),('alanis1'),('alanna'),('alanna1'),('alannah'),('alannah1'),('alanya'),('alarcon'),('alaska'),('alaska1'),('alaska11'),('alaska12'),('alaska123'),('alaska2'),('alastair'),('alayna'),('alayna1'),('alb'),('alba'),('albacete'),('albachiara'),('albania'),('albania1'),('albano'),('albany'),('albany1'),('albastru'),('albator'),('albatros'),('albatross'),('albero'),('albert'),('albert01'),('albert1'),('albert11'),('albert12'),('albert123'),('albert13'),('albert2'),('albert3'),('albert5'),('alberta'),('alberta1'),('albertina'),('alberto'),('alberto1'),('alberto10'),('alberto12'),('alberto123'),('alberto13'),('alberto2'),('albina'),('albina-1945'),('albino'),('albino1'),('albion'),('albion1'),('albita'),('alcala'),('alcantara'),('alcapone'),('alcatel'),('alcatraz'),('alcatraz1'),('alchemist'),('alchemist1'),('alchemy'),('alchemy1'),('alcohol'),('alcohol1'),('alcool'),('aldana'),('aldebaran'),('aldo'),('aldrich'),('aldrin'),('aldwin'),('ale'),('ale123'),('aleale'),('alec'),('alecia'),('aleena'),('alegna'),('alegre'),('alegria'),('alegria1'),('alejandra'),('alejandra.'),('alejandra1'),('alejandra2'),('alejandra3'),('alejandra7'),('alejandra9'),('alejandro'),('alejandro.'),('alejandro0'),('alejandro1'),('alejandro123'),('alejandro2'),('alejandro3'),('alejandro5'),('alejandro7'),('alejandro8'),('alejandro9'),('alejo'),('aleks'),('aleks-270379'),('aleks1'),('aleksa'),('aleksandar'),('aleksander'),('aleksandr'),('aleksandr.ustinov.2012'),('aleksandra'),('aleksandra1'),('alekseev'),('alekseeva'),('aleksei'),('aleksej'),('aleksej.shorin.86'),('aleksey'),('aleksik'),('aleksis1611'),('aleluia'),('aleluya'),('aleman'),('alemanha'),('alemania'),('alena'),('alena1'),('alena123'),('alena_plotnikova_1995'),('alenka'),('alenushka'),('alesana'),('alesana1'),('alesha'),('alesia'),('alessa'),('alessandra'),('alessandro'),('alessandro1'),('alessia'),('alessia1'),('alessio'),('alessio1'),('alesya'),('alevtina'),('alex'),('alex00'),('alex007'),('alex01'),('alex02'),('alex03'),('alex04'),('alex05'),('alex06'),('alex07'),('alex08'),('alex09'),('alex1'),('alex10'),('alex100'),('alex101'),('alex11'),('alex111'),('alex12'),('alex123'),('alex1234'),('alex12345'),('alex123456'),('alex13'),('alex14'),('alex15'),('alex16'),('alex17'),('alex18'),('alex19'),('alex1972'),('alex1973'),('alex1974'),('alex1975'),('alex1976'),('alex1977'),('alex1978'),('alex1979'),('alex1980'),('alex1981'),('alex1982'),('alex1983'),('alex1984'),('alex1985'),('alex1986'),('alex1987'),('alex1988'),('alex1989'),('alex1990'),('alex1991'),('alex1992'),('alex1993'),('alex1994'),('alex1995'),('alex1996'),('alex1997'),('alex1998'),('alex1999'),('alex20'),('alex2000'),('alex2001'),('alex2002'),('alex2003'),('alex2004'),('alex2005'),('alex2006'),('alex2007'),('alex2008'),('alex2009'),('alex2010'),('alex2011'),('alex21'),('alex22'),('alex23'),('alex24'),('alex25'),('alex2539'),('alex26'),('alex27'),('alex28'),('alex29'),('alex30'),('alex31'),('alex32'),('alex33'),('alex34'),('alex44'),('alex45'),('alex4ever'),('alex55'),('alex66'),('alex666'),('alex69'),('alex76'),('alex77'),('alex777'),('alex78'),('alex82'),('alex83'),('alex84'),('alex85'),('alex86'),('alex87'),('alex88'),('alex89'),('alex90'),('alex91'),('alex92'),('alex93'),('alex94'),('alex95'),('alex96'),('alex97'),('alex98'),('alex99'),('alexa'),('alexa1'),('alexa12'),('alexa123'),('alexa2'),('alexalex'),('alexalex1'),('alexan'),('alexande'),('alexander'),('alexander!'),('alexander.'),('alexander0'),('alexander1'),('alexander11'),('alexander12'),('alexander123'),('alexander2'),('alexander3'),('alexander4'),('alexander5'),('alexander6'),('alexander7'),('alexander8'),('alexander9'),('alexandr'),('alexandra'),('alexandra0'),('alexandra1'),('alexandra2'),('alexandra3'),('alexandra7'),('alexandra9'),('alexandre'),('alexandre1'),('alexandrea'),('alexandria'),('alexandro'),('alexandros'),('alexandru'),('alexandru1'),('alexdelpiero'),('alexdok76'),('alexei'),('alexey'),('alexia'),('alexia1'),('alexie'),('alexis'),('alexis!'),('alexis.'),('alexis00'),('alexis01'),('alexis02'),('alexis03'),('alexis04'),('alexis05'),('alexis06'),('alexis07'),('alexis08'),('alexis09'),('alexis1'),('alexis10'),('alexis11'),('alexis12'),('alexis123'),('alexis1234'),('alexis13'),('alexis14'),('alexis15'),('alexis16'),('alexis17'),('alexis18'),('alexis2'),('alexis20'),('alexis21'),('alexis22'),('alexis23'),('alexis24'),('alexis25'),('alexis3'),('alexis4'),('alexis5'),('alexis6'),('alexis7'),('alexis8'),('alexis9'),('alexis96'),('alexis97'),('alexis98'),('alexis99'),('alexito'),('alexrv_06'),('alexsander'),('alexsandr'),('alexsandra'),('alexus'),('alexus1'),('alexx'),('alexxx'),('alexzander'),('aleyna'),('alf'),('alf123'),('alfa'),('alfa123'),('alfa147'),('alfa156'),('alfa33'),('alfaalfa'),('alfabeta'),('alfakran'),('alfalfa'),('alfaomega'),('alfaro'),('alfaromeo'),('alfaromeo1'),('alfie'),('alfie1'),('alfie123'),('alfons'),('alfonso'),('alfonso1'),('alfred'),('alfred1'),('alfred123'),('alfred19'),('alfredo'),('alfredo1'),('alfredo123'),('algarve'),('algebra'),('algebra1'),('algebra2'),('algeria'),('algerie'),('algernon'),('alhambra'),('alhamdulillah'),('ali'),('ali110'),('ali123'),('ali1234'),('ali12345'),('ali123456'),('ali786'),('aliali'),('aliali1'),('alialiali'),('alianza'),('alianza1'),('alianzalima'),('alias'),('alias1'),('alibaba'),('alibaba1'),('alibek'),('alican'),('alicante'),('alicat'),('alice'),('alice1'),('alice12'),('alice123'),('alice2'),('aliceadsl'),('alices'),('alicia'),('alicia01'),('alicia1'),('alicia10'),('alicia11'),('alicia12'),('alicia123'),('alicia13'),('alicia2'),('alicia21'),('alicia22'),('alicia23'),('alicia3'),('alicia7'),('alicja'),('alien'),('alien1'),('alien123'),('aliens'),('aliens1'),('alienware'),('aliev0583'),('aligator'),('alihan'),('alija-gatina0'),('alikhan'),('alina'),('alina1'),('alina12'),('alina123'),('alina1995'),('alina1997'),('alina1998'),('alina2010'),('alinaalina'),('aline'),('aline1'),('aline123'),('alinka'),('alino4ka'),('alinochka'),('alinuta'),('alinutza'),('aliona'),('alireza'),('alisa'),('alisa1'),('alisa123'),('alisha'),('alisha1'),('alisha123'),('alisher'),('alisia'),('aliska'),('alison'),('alison1'),('alison12'),('alison123'),('alissa'),('alissa1'),('alisson'),('alistair'),('alitalia'),('alive'),('alive1'),('alivia'),('alivia1'),('alivioo'),('aliya'),('aliya.mutallapova'),('aliyah'),('aliyah1'),('alize1'),('alizee'),('alkaline'),('alkaline3'),('alkohol'),('all'),('all123'),('all4god'),('all4him'),('all4jesus'),('all4love'),('all4me'),('all4one'),('all4you'),('alla'),('allaboutme'),('alladin'),('alladin79'),('allah'),('allah1'),('allah123'),('allah786'),('allah99'),('allaha'),('allahabad'),('allahakbar'),('allahallah'),('allahhoo'),('allahis1'),('allahisgreat'),('allahisone'),('allahoakbar'),('allahswt'),('allahu'),('allahu1'),('allahuakba'),('allahuakbar'),('allalone'),('allalone1'),('allan'),('allan1'),('allan123'),('allana'),('allblack'),('allblacks'),('allblacks1'),('allday'),('allday1'),('allegra'),('allegra1'),('allegria'),('allegro'),('allegro1'),('alleluia'),('allen'),('allen1'),('allen11'),('allen12'),('allen123'),('allen13'),('allen2'),('allen20'),('allen21'),('allen23'),('allen3'),('alleniverson'),('allens'),('alley'),('alley1'),('alleycat'),('alleycat1'),('allezlom'),('allfor1'),('allgood'),('allgood1'),('allh11'),('alliance'),('alliance1'),('allie'),('allie1'),('allie12'),('allie123'),('allie2'),('alliecat'),('allied'),('alligator'),('alligator1'),('alligator3'),('allin1'),('allinone'),('allison'),('allison!'),('allison1'),('allison11'),('allison12'),('allison123'),('allison13'),('allison2'),('allison3'),('allison4'),('allison5'),('allison7'),('allister'),('alliswell'),('alliyah'),('allme1'),('allmeu112'),('allmine'),('allmine1'),('allmine2'),('allmylife'),('allo'),('alloallo'),('allochka'),('allrecipes'),('allright'),('allsaints'),('allsop'),('allsop1'),('allstar'),('allstar1'),('allstar11'),('allstar12'),('allstar123'),('allstar13'),('allstar2'),('allstar23'),('allstar3'),('allstar5'),('allstar7'),('allstars'),('allstars1'),('allstate'),('allstate1'),('alltel1'),('allthat'),('allthebest'),('alltheway'),('alltimelow'),('allure'),('alluser'),('ally'),('ally12'),('ally123'),('allycat'),('allycat1'),('allysa'),('allyson'),('allyson1'),('allyssa'),('allyssa1'),('alma'),('alma12'),('alma123'),('almario927'),('almaty'),('almaz'),('almaz_kiramov'),('almeida'),('almendra'),('almera'),('almeria'),('almighty'),('almighty1'),('almighty5'),('almira'),('almita'),('almond'),('almost'),('almost1'),('almudena'),('alo123'),('aloalo'),('aloevera'),('aloha'),('aloha1'),('aloha123'),('alohamora'),('alohomora'),('alondra'),('alondra1'),('alone'),('alone1'),('alone4ever'),('along'),('along1'),('alonso'),('alonso1'),('alonso14'),('alonzo'),('alonzo1'),('alouette'),('aloysius'),('alpaca'),('alpacino'),('alperen'),('alpha'),('alpha01'),('alpha06'),('alpha1'),('alpha12'),('alpha123'),('alpha1906'),('alpha2'),('alpha3'),('alpha5'),('alpha7'),('alphabet'),('alphabet1'),('alphabeta'),('alphaomega'),('alphonse'),('alpina'),('alpine'),('alpine1'),('alquimia'),('already'),('already1'),('alright'),('alright1'),('alsace'),('alskdj'),('alskdjfhg'),('alskdjfhg1'),('alskeo'),('altagracia'),('altair'),('altamira'),('altavista'),('altec'),('altec1'),('alteclansing'),('alterego'),('alterego1'),('alternate'),('alternativ'),('alternativa'),('alternative'),('althea'),('althea1'),('altima'),('altima1'),('altoids'),('altoids1'),('alucard'),('alucard1'),('alucard666'),('alukard'),('aluminum'),('alumni'),('alvarado'),('alvarado1'),('alvarez'),('alvarez1'),('alvarito'),('alvaro'),('alvaro1'),('alvin'),('alvin1'),('alvin123'),('alvina'),('always'),('always1'),('always12'),('always123'),('always2'),('alwaysandf'),('aly123'),('alyanna'),('alycia'),('alyona'),('alysha'),('alysha1'),('alysia'),('alyson'),('alyson1'),('alyssa'),('alyssa!'),('alyssa01'),('alyssa02'),('alyssa03'),('alyssa04'),('alyssa05'),('alyssa06'),('alyssa07'),('alyssa08'),('alyssa09'),('alyssa1'),('alyssa10'),('alyssa11'),('alyssa12'),('alyssa123'),('alyssa13'),('alyssa14'),('alyssa15'),('alyssa16'),('alyssa2'),('alyssa21'),('alyssa22'),('alyssa23'),('alyssa3'),('alyssa4'),('alyssa5'),('alyssa6'),('alyssa7'),('alyssa8'),('alyssa9'),('alyssa99'),('alyssia'),('am'),('am1234'),('am123456'),('ama'),('ama123'),('amadeo'),('amadeus'),('amadeus1'),('amadeus55'),('amador'),('amadou'),('amalia'),('amalia1'),('amalie'),('amamam'),('aman'),('aman123'),('amanaman'),('amanda'),('amanda!'),('amanda.'),('amanda0'),('amanda00'),('amanda01'),('amanda02'),('amanda03'),('amanda05'),('amanda06'),('amanda07'),('amanda08'),('amanda09'),('amanda1'),('amanda10'),('amanda101'),('amanda11'),('amanda12'),('amanda123'),('amanda1234'),('amanda13'),('amanda14'),('amanda15'),('amanda16'),('amanda17'),('amanda18'),('amanda19'),('amanda2'),('amanda20'),('amanda21'),('amanda22'),('amanda23'),('amanda24'),('amanda25'),('amanda26'),('amanda27'),('amanda3'),('amanda33'),('amanda4'),('amanda5'),('amanda6'),('amanda69'),('amanda7'),('amanda77'),('amanda8'),('amanda86'),('amanda87'),('amanda88'),('amanda89'),('amanda9'),('amanda92'),('amanda93'),('amanda95'),('amanda99'),('amande'),('amandeep'),('amandine'),('amanecer'),('amani1'),('amante'),('amapola'),('amar'),('amarachi'),('amaral'),('amarelo'),('amaretto'),('amari1'),('amarillo'),('amarillo1'),('amarnath'),('amaterasu'),('amateur'),('amatory'),('amauri'),('amaury'),('amaya'),('amaya1'),('amazing'),('amazing!'),('amazing1'),('amazing123'),('amazing2'),('amazinggrace'),('amazon'),('amazon1'),('amazonas'),('amazone'),('amazonia'),('amazonka'),('amb123'),('ambassador'),('amber'),('amber!'),('amber01'),('amber06'),('amber07'),('amber08'),('amber09'),('amber1'),('amber10'),('amber101'),('amber11'),('amber12'),('amber123'),('amber1234'),('amber13'),('amber14'),('amber15'),('amber16'),('amber17'),('amber18'),('amber2'),('amber21'),('amber22'),('amber23'),('amber3'),('amber4'),('amber5'),('amber6'),('amber69'),('amber7'),('amber8'),('amber9'),('amberlynn'),('ambers'),('ambers1'),('ambiente'),('ambika'),('ambition'),('ambition1'),('ambot'),('ambre'),('ambrose'),('ambrose1'),('ambrosia'),('ambrosio'),('ambulance'),('ambulance1'),('amc123'),('amdturion64'),('ame'),('amedeo'),('ameena'),('ameera'),('amelia'),('amelia1'),('amelia12'),('amelia123'),('amelie'),('amelie1'),('amen'),('amenamen'),('america'),('america!'),('america#1'),('america.'),('america01'),('america07'),('america08'),('america09'),('america1'),('america10'),('america100'),('america11'),('america12'),('america123'),('america13'),('america14'),('america15'),('america16'),('america17'),('america18'),('america2'),('america21'),('america22'),('america23'),('america3'),('america4'),('america5'),('america6'),('america7'),('america8'),('america9'),('american'),('american1'),('american12'),('american2'),('americana'),('americano'),('americanpie'),('americas'),('americo'),('amerika'),('amerika1'),('AmerikanBlend'),('amethyst'),('amethyst1'),('ametistfatal'),('amherst'),('ami'),('ami123'),('amicizia'),('amidala'),('amidamaru'),('amiga'),('amiga1'),('amigas'),('amigas1'),('amigo'),('amigo1'),('amigo123'),('amigos'),('amigos1'),('amilcar'),('amin'),('amin123'),('amina'),('amina1'),('amina123'),('aminah'),('aminat'),('aminata'),('amine'),('aminin94'),('aminlove'),('amir'),('amir123'),('amira'),('amira1'),('amirah'),('amiramir'),('amiret2015'),('amirkhan'),('amirul'),('amisha'),('amistad'),('amistad1'),('amit'),('amit123'),('amit1234'),('amitabh'),('amitie'),('amitkumar'),('amizade'),('amma'),('ammaamma'),('ammaappa'),('ammananna'),('ammukutty'),('ammulu'),('amnesia'),('amo'),('amo-te'),('amoah2010'),('amoeba'),('amojesus'),('amonra'),('amooti'),('amor'),('amor01'),('amor10'),('amor11'),('amor12'),('amor123'),('amor1234'),('amor13'),('amor14'),('amor15'),('amor16'),('amor17'),('amor18'),('amor20'),('amor2009'),('amor21'),('amor22'),('amor23'),('amor25'),('amor69'),('amoramor'),('amorcito'),('amorcito1'),('amore'),('amore1'),('amoreco'),('amoree'),('amoremio'),('amoremio1'),('amoremiotiamo'),('amores'),('amores1'),('amoreterno'),('amoretiamo'),('amorino'),('amormio'),('amormio1'),('amorosa'),('amoroso'),('amorsito'),('amorypaz'),('amorzinho'),('amos'),('amouna'),('amour'),('amour1'),('amour100'),('amoure'),('amoureuse'),('amoureux'),('amours'),('amp123'),('amparo'),('amrita'),('amritsar'),('amruta'),('amrutha'),('ams123'),('amstel'),('amsterdam'),('amsterdam1'),('amy'),('amy123'),('amy1234'),('amyamy'),('amylee'),('amylee1'),('amylou'),('amylynn'),('an'),('an1234'),('an123456'),('an4oys12120'),('ana'),('ana123'),('ana1234'),('ana12345'),('ana123456'),('anaana'),('anabel'),('anabel1'),('anabela'),('anabelen'),('anabella'),('anabelle'),('anacarolina'),('anaclara'),('anacleto'),('anaconda'),('anaconda1'),('anadolu'),('anaelle'),('anagha'),('anaheim'),('anaheim1'),('anaheim714'),('anahi1'),('anais'),('anais1'),('anaisabel'),('anajulia'),('anakaren'),('anakin'),('anakin1'),('anakku'),('anakonda'),('anal'),('anal69'),('analaura'),('analia'),('analiza'),('analla'),('analog'),('analsex'),('analsex1'),('analsex69'),('analucia'),('analuisa'),('analuiza'),('analyn'),('anamaria'),('anamaria1'),('anamarie'),('anamika'),('ananas'),('anand'),('anand123'),('ananda'),('ananth'),('ananya'),('anapaula'),('anarchia'),('anarchie'),('anarchist'),('anarchy'),('anarchy1'),('anarchy666'),('anarchy99'),('anarkia'),('anarquia'),('anasofia'),('anastacia'),('anastacia1'),('anastas'),('anastasia'),('anastasia1'),('anastasija'),('anastasija3010'),('anastasiy'),('anastasiya'),('anastasya'),('anathema'),('anatol'),('anatole'),('anatoli'),('anatolii'),('anatoliy'),('anatomia'),('anatomy'),('anatomy1'),('anchor'),('anchor1'),('anchorage'),('ancient'),('ancient1'),('ancona'),('ancora'),('ancuta'),('and'),('and123'),('and125'),('andalucia'),('anderlecht'),('anders'),('anders1'),('andersen'),('anderson'),('anderson1'),('anderson12'),('anderson2'),('andersson'),('andg1705'),('andi'),('andi121382'),('andi123'),('andiamo1'),('andika'),('andohz'),('andone'),('andone1'),('andorra'),('andover'),('andr3w'),('andra'),('andrada'),('andrade'),('andrade1'),('andras'),('andre'),('andre01'),('andre1'),('andre10'),('andre11'),('andre12'),('andre123'),('andre13'),('andre1986'),('andre2'),('andre22'),('andre23'),('andre3'),('andre3000'),('andre5'),('andrea'),('andrea!'),('andrea.'),('andrea01'),('andrea05'),('andrea06'),('andrea07'),('andrea08'),('andrea09'),('andrea1'),('andrea10'),('andrea11'),('andrea12'),('andrea123'),('andrea1234'),('andrea13'),('andrea14'),('andrea15'),('andrea16'),('andrea17'),('andrea18'),('andrea19'),('andrea2'),('andrea20'),('andrea21'),('andrea22'),('andrea23'),('andrea24'),('andrea25'),('andrea3'),('andrea4'),('andrea5'),('andrea6'),('andrea69'),('andrea7'),('andrea77'),('andrea8'),('andrea88'),('andrea89'),('andrea9'),('andrea99'),('andreas'),('andreas1'),('andreas123'),('andree'),('andreea'),('andreea1'),('andreev'),('andreeva'),('andrei'),('andrei1'),('andrei123'),('andreia'),('andreika'),('andreina'),('andreita'),('andrei_rew'),('andrej'),('andrejka'),('andres'),('andres01'),('andres1'),('andres10'),('andres12'),('andres123'),('andres13'),('andres2'),('andresito'),('andressa'),('andreu'),('andrew'),('andrew!'),('andrew.'),('andrew00'),('andrew01'),('andrew02'),('andrew03'),('andrew04'),('andrew05'),('andrew06'),('andrew07'),('andrew08'),('andrew09'),('andrew1'),('andrew10'),('andrew101'),('andrew11'),('andrew12'),('andrew123'),('andrew1234'),('andrew13'),('andrew14'),('andrew15'),('andrew16'),('andrew17'),('andrew18'),('andrew19'),('andrew2'),('andrew20'),('andrew21'),('andrew22'),('andrew23'),('andrew24'),('andrew25'),('andrew26'),('andrew27'),('andrew28'),('andrew29'),('andrew3'),('andrew33'),('andrew4'),('andrew5'),('andrew55'),('andrew6'),('andrew69'),('andrew7'),('andrew77'),('andrew8'),('andrew86'),('andrew87'),('andrew88'),('andrew89'),('andrew9'),('andrew91'),('andrew92'),('andrew93'),('andrew94'),('andrew95'),('andrew96'),('andrew97'),('andrew98'),('andrew99'),('andrews'),('andrews1'),('andrey'),('andrey-1983_08'),('andrey.shalanov'),('andrey1'),('andrey123'),('andrey1412ua'),('andrey1983'),('andrey1995'),('andrey1996'),('andrey1997'),('andreyka'),('andreyka.gorshkov.98'),('andreyka.zhilin.1981'),('andria'),('andrian'),('andriana'),('andrik'),('andris'),('andriy'),('android'),('android1'),('andromeda'),('andromeda1'),('andron'),('andros'),('andruha'),('andruhova.1982'),('andrusha'),('andrusic1'),('andrzej'),('andrzej1'),('anduril'),('andy'),('andy01'),('andy10'),('andy11'),('andy12'),('andy123'),('andy1234'),('andy13'),('andy14'),('andy15'),('andy16'),('andy1999'),('andy21'),('andy22'),('andy23'),('andy69'),('andyandy'),('andyouone'),('andypandy'),('andysixx'),('andzia'),('ane4ka'),('anechka'),('aneczka'),('anelka'),('anemone'),('aneta'),('anetka'),('anetka11'),('anette'),('anewlife'),('anfield'),('anfield1'),('anfisa'),('ang'),('ang123'),('angarova81'),('angcuteko'),('ange'),('angedemon'),('angel'),('angel!'),('angel#1'),('angel.'),('angel0'),('angel00'),('angel001'),('angel007'),('angel01'),('angel02'),('angel03'),('angel04'),('angel05'),('angel06'),('angel07'),('angel08'),('angel09'),('angel1'),('angel10'),('angel100'),('angel101'),('angel11'),('angel111'),('angel12'),('angel123'),('angel1234'),('angel12345'),('angel13'),('angel14'),('angel143'),('angel15'),('angel16'),('angel17'),('angel18'),('angel19'),('angel1985'),('angel1987'),('angel1988'),('angel1989'),('angel1990'),('angel1991'),('angel1992'),('angel1993'),('angel1994'),('angel1995'),('angel1996'),('angel1997'),('angel1998'),('angel2'),('angel20'),('angel2000'),('angel2001'),('angel2003'),('angel2004'),('angel2005'),('angel2006'),('angel2007'),('angel2008'),('angel2009'),('angel2010'),('angel2011'),('angel21'),('angel22'),('angel23'),('angel24'),('angel25'),('angel26'),('angel27'),('angel28'),('angel29'),('angel3'),('angel30'),('angel31'),('angel32'),('angel321'),('angel33'),('angel333'),('angel34'),('angel4'),('angel420'),('angel44'),('angel45'),('angel4ever'),('angel4life'),('angel4u'),('angel5'),('angel55'),('angel555'),('angel56'),('angel6'),('angel637'),('angel66'),('angel666'),('angel67'),('angel675'),('angel69'),('angel7'),('angel72'),('angel76'),('angel77'),('angel777'),('angel78'),('angel79'),('angel8'),('angel81'),('angel82'),('angel83'),('angel84'),('angel85'),('angel86'),('angel87'),('angel88'),('angel89'),('angel9'),('angel90'),('angel91'),('angel911'),('angel92'),('angel93'),('angel94'),('angel95'),('angel96'),('angel97'),('angel98'),('angel99'),('angel999'),('angela'),('angela!'),('angela.'),('angela01'),('angela08'),('angela1'),('angela10'),('angela11'),('angela12'),('angela123'),('angela13'),('angela14'),('angela15'),('angela18'),('angela2'),('angela21'),('angela22'),('angela23'),('angela3'),('angela4'),('angela5'),('angela69'),('angela7'),('angelangel'),('angelbaby'),('angelbaby1'),('angelbaby2'),('angelboy'),('angeldevil'),('angeldog'),('angeldust'),('angele'),('angeles'),('angeles1'),('angeleyes'),('angeleyes1'),('angeleyes2'),('angelface'),('angelface1'),('angelfire'),('angelfire1'),('angelfish'),('angelgirl'),('angelgirl1'),('angelheart'),('angeli'),('angelia'),('angelic'),('angelic1'),('angelica'),('angelica1'),('angelica12'),('angelica13'),('angelica2'),('angelidis'),('angelie'),('angelika'),('angelika1'),('angelina'),('angelina1'),('angelina12'),('angelina2'),('angelina3'),('angeline'),('angeline1'),('angelino'),('angelique'),('angelique1'),('angelita'),('angelita1'),('angelito'),('angelito1'),('angelitos'),('angell'),('angell1'),('angella'),('angelle'),('angellove'),('angellove1'),('angelo'),('angelo01'),('angelo1'),('angelo12'),('angelo123'),('angelo2'),('angelo4ek'),('angelochek'),('angelok'),('angels'),('angels!'),('angels.'),('angels01'),('angels02'),('angels07'),('angels1'),('angels10'),('angels11'),('angels12'),('angels123'),('angels13'),('angels2'),('angels21'),('angels22'),('angels23'),('angels27'),('angels3'),('angels4'),('angels5'),('angels6'),('angels69'),('angels7'),('angels77'),('angels8'),('angels9'),('angelseye22'),('angelus'),('angelus1'),('angelwings'),('angely'),('angelyn'),('angelz'),('angelz1'),('angers'),('angga'),('anggandako'),('anggun'),('anghel'),('angie'),('angie01'),('angie1'),('angie11'),('angie12'),('angie123'),('angie13'),('angie2'),('angie21'),('angie23'),('angie3'),('angioletto'),('anglais'),('angle'),('angle1'),('angle12'),('angle123'),('angler'),('angles'),('angles1'),('anglia'),('angola'),('angpogiko'),('angry1'),('angrybirds'),('angus'),('angus1'),('angus123'),('angusyoung'),('angwar77'),('anh123'),('anhhung'),('anhmaiyeuem'),('anhnhoem'),('anhthu'),('anhtuan'),('anhyeu'),('anhyeuem'),('anhyeuem1'),('anhyeuem123'),('ani'),('ani123'),('ania'),('ania1986'),('aniani'),('anibal'),('anicka'),('anika'),('anika1'),('aniket'),('anil'),('anil123'),('anilkumar'),('anillo'),('anima'),('animal'),('animal1'),('animal11'),('animal12'),('animal123'),('animal13'),('animal2'),('animal3'),('animal6'),('animal69'),('animale'),('animales'),('animals'),('animals1'),('animals12'),('animals123'),('animals2'),('animals3'),('animation'),('animation1'),('animator'),('animax'),('anime'),('anime1'),('anime101'),('anime12'),('anime123'),('anime13'),('anime2'),('anime4ever'),('animefreak'),('animelover'),('animes'),('anindita'),('aninha'),('aniolek'),('aniram'),('anirudh'),('anisha'),('anisoara'),('anissa'),('anissa1'),('anita'),('anita1'),('anita12'),('anita123'),('anita2'),('anitas'),('anitha'),('aniya1'),('aniyah'),('aniyah1'),('anja'),('anjali'),('anjana'),('anjaneya'),('anjani'),('anjela'),('anjelik'),('anjelika'),('anjing'),('anjing1'),('anjing123'),('anjinho'),('anjink'),('ankara'),('ankara06'),('ankit'),('ankit123'),('ankita'),('ankush'),('ann'),('ann123'),('anna'),('anna.savickaya.1986'),('anna01'),('anna06'),('anna07'),('anna08'),('anna09'),('anna1'),('anna10'),('anna11'),('anna12'),('anna123'),('anna1234'),('anna12345'),('anna13'),('anna14'),('anna15'),('anna16'),('anna17'),('anna18'),('anna19'),('anna1982'),('anna1983'),('anna1984'),('anna1985'),('anna1986'),('anna1987'),('anna1988'),('anna1989'),('anna1990'),('anna1991'),('anna1992'),('anna1993'),('anna1994'),('anna1995'),('anna1996'),('anna1997'),('anna1998'),('anna1999'),('anna2000'),('anna2001'),('anna2002'),('anna2003'),('anna2004'),('anna2005'),('anna2006'),('anna2007'),('anna2008'),('anna2009'),('anna2010'),('anna2011'),('anna21'),('anna22'),('anna23'),('anna24'),('anna25'),('anna2976'),('anna69'),('anna777'),('anna88'),('anna89'),('anna99'),('annaanna'),('annaba'),('annaba23'),('annabel'),('annabel1'),('annabell'),('annabell1'),('annabella'),('annabella1'),('annabelle'),('annabelle1'),('annagor20'),('annalee'),('annalena'),('annalisa'),('annalise'),('annaliza'),('annalyn'),('annamaria'),('annamaria1'),('annamarie'),('annamarie1'),('annann'),('annapurna'),('annarella'),('annarita'),('annarose'),('anne'),('anne12'),('anne123'),('AnneA'),('anneanne'),('annecy'),('anneke'),('annelies'),('anneliese'),('annelise'),('annemarie'),('annemarie1'),('anneso'),('annette'),('annette1'),('annhen1'),('annick'),('annie'),('annie01'),('annie1'),('annie11'),('annie12'),('annie123'),('annie13'),('annie2'),('annie3'),('annieb'),('anniedog'),('annies'),('annika'),('annika1'),('annina'),('annisa'),('annita'),('anniversary'),('annmarie'),('annmarie1'),('anno1602'),('annoying'),('annoying1'),('annushka'),('annywka_86'),('anointed'),('anointed1'),('anonelbe'),('anonim'),('anonimo'),('anonymous'),('anonymous1'),('anorexia'),('another'),('another1'),('anoushka'),('ansari'),('anselmo'),('anshul'),('anshuman'),('answer'),('answer1'),('answer3'),('ant'),('ant123'),('antalya'),('antalya07'),('antani'),('antara'),('antares'),('antares1'),('anteater'),('antelope'),('anth0ny'),('anthea'),('anthem'),('anthon'),('anthony'),('anthony!'),('anthony.'),('anthony0'),('anthony00'),('anthony01'),('anthony02'),('anthony03'),('anthony04'),('anthony05'),('anthony06'),('anthony07'),('anthony08'),('anthony09'),('anthony1'),('anthony10'),('anthony101'),('anthony11'),('anthony12'),('anthony123'),('anthony13'),('anthony14'),('anthony15'),('anthony16'),('anthony17'),('anthony18'),('anthony19'),('anthony2'),('anthony20'),('anthony200'),('anthony21'),('anthony22'),('anthony23'),('anthony24'),('anthony25'),('anthony26'),('anthony27'),('anthony28'),('anthony29'),('anthony3'),('anthony33'),('anthony4'),('anthony5'),('anthony6'),('anthony69'),('anthony7'),('anthony77'),('anthony8'),('anthony88'),('anthony89'),('anthony9'),('anthony99'),('anthrax'),('anthrax1'),('antibes'),('antichrist'),('antifa'),('antiflag'),('antiflag1'),('antigone'),('antigua'),('antigua1'),('antihero'),('antilles'),('antioch'),('antique'),('antiques'),('antivirus'),('antman'),('antman1'),('anto'),('antoha'),('antoha50a'),('antoine'),('antoine1'),('antoinette'),('anton'),('anton1'),('anton123'),('anton1995'),('anton1996'),('antonanton'),('antone'),('antonela'),('antonella'),('antonella1'),('antonello'),('antonette'),('antoni'),('antonia'),('antonia1'),('antonichmeli'),('antonietta'),('antonin'),('antonina'),('Antonine1'),('antonino'),('antonio'),('antonio.'),('antonio01'),('antonio1'),('antonio10'),('antonio11'),('antonio12'),('antonio123'),('antonio13'),('antonio14'),('antonio15'),('antonio16'),('antonio17'),('antonio18'),('antonio2'),('antonio21'),('antonio22'),('antonio23'),('antonio3'),('antonio4'),('antonio5'),('antonio6'),('antonio69'),('antonio7'),('antonio8'),('antonio9'),('antonius'),('antonls'),('antonov'),('antonova'),('antony'),('antony1'),('antosha'),('antoshka'),('antoxa'),('antrax'),('antsiferova1973'),('antusenok_zhekonya'),('antwan'),('antwan1'),('antwerp'),('antwerpen'),('antwon1'),('anu'),('anu123'),('anubhav'),('anubis'),('anubis1'),('anulka'),('anuoluwapo'),('anupam'),('anupama'),('anupriya'),('anuradha'),('anurag'),('anusha'),('anushka'),('anushree'),('anusia'),('anuska'),('anutka'),('anvils'),('anwar'),('anya'),('anycall123'),('anyone'),('anything'),('anything1'),('anything12'),('anything2'),('anytime'),('anytime1'),('anyuta'),('anyway'),('anywhere'),('aobo2010'),('aol'),('aol.com'),('aol123'),('aol1234'),('aolsucks'),('aosamples'),('aotearoa'),('ap1234'),('apa123'),('apaaja'),('apache'),('apache1'),('apalkova.tatiana'),('aparecida'),('aparna'),('apartment'),('apelsin'),('apfelbaum'),('aphrodite'),('aphrodite1'),('apinoy'),('ApjSqpM844'),('apocalipse'),('apocalipsis'),('apocalypse'),('apokalipsa'),('apokalipsis'),('apollo'),('apollo1'),('apollo11'),('apollo12'),('apollo123'),('apollo13'),('apollon'),('apolo13'),('apologize'),('apolon'),('apolonia'),('apoorva'),('apostle'),('apostol'),('app'),('appaamma'),('appaloosa'),('appels'),('appelsap'),('apple'),('apple!'),('apple.'),('apple01'),('apple08'),('apple09'),('apple1'),('apple10'),('apple101'),('apple11'),('apple111'),('apple12'),('apple123'),('apple1234'),('apple12345'),('apple13'),('apple14'),('apple15'),('apple16'),('apple17'),('apple18'),('apple2'),('apple21'),('apple22'),('apple23'),('apple24'),('apple25'),('apple3'),('apple33'),('apple4'),('apple44'),('apple45'),('apple5'),('apple55'),('apple6'),('apple69'),('apple7'),('apple8'),('apple88'),('apple9'),('apple99'),('appleapple'),('applebees1'),('applejack'),('applejack1'),('applejacks'),('applejuice'),('applemac'),('applepie'),('applepie1'),('applepie12'),('applepie2'),('apples'),('apples!'),('apples.'),('apples01'),('apples1'),('apples10'),('apples11'),('apples12'),('apples123'),('apples13'),('apples2'),('apples22'),('apples23'),('apples3'),('apples4'),('apples5'),('apples6'),('apples7'),('applesauce'),('appleseed'),('appleseed1'),('appleton'),('appletree'),('appletree1'),('application'),('approtec'),('approved'),('apricot'),('april'),('april01'),('april02'),('april03'),('april04'),('april05'),('april06'),('april07'),('april08'),('april09'),('april1'),('april10'),('april11'),('april12'),('april123'),('april13'),('april14'),('april15'),('april16'),('april17'),('april18'),('april19'),('april1987'),('april1988'),('april1990'),('april1991'),('april1992'),('april1994'),('april2'),('april20'),('april2006'),('april2007'),('april2008'),('april2009'),('april2010'),('april21'),('april22'),('april23'),('april24'),('april25'),('april26'),('april27'),('april28'),('april29'),('april3'),('april30'),('april4'),('april420'),('april5'),('april6'),('april69'),('april7'),('april8'),('april88'),('april89'),('april9'),('april92'),('aprile'),('aprilfool'),('aprilia'),('aprilia1'),('aprils'),('apsk0518'),('apsk54321'),('apteka'),('aptiva'),('aptx4869'),('apurva'),('aq1234'),('aq123456'),('aq12ws'),('aq1sw2'),('aq1sw2de3'),('aqaqaq'),('aqq997'),('aqswde'),('aqswdefr'),('aqua'),('aquafina'),('aquafina1'),('aqualung'),('aquaman'),('aquamarine'),('aquario'),('aquarium'),('aquarius'),('aquarius1'),('aquila'),('aquiles'),('aquinas'),('aquino'),('aqw123'),('aqwaqw'),('aqwleeb_6e0pk59'),('aqwxsz'),('aqwzsx'),('aqwzsx123'),('aqwzsxedc'),('ar'),('ar1234'),('ar123456'),('ara'),('ara123'),('arabella'),('arabella1'),('arabella24630'),('arabia'),('arabian'),('arabian1'),('araceli'),('araceli1'),('aracely'),('aracely1'),('aradhana'),('arafat'),('aragon'),('aragorn'),('aragorn1'),('aram198309'),('aramis'),('aramis1'),('arancione'),('aranha'),('ararat'),('arashi'),('araujo'),('aravind'),('arbeit'),('arbiter'),('arbonne'),('arc'),('arcade'),('arcadia'),('arcadia1'),('arcane'),('arcangel'),('arcangel1'),('arcenciel'),('archana'),('archangel'),('archangel1'),('archer'),('archer1'),('archery'),('archery1'),('archibald'),('archie'),('archie01'),('archie1'),('archie12'),('archie123'),('archimede'),('archimedes'),('architect'),('architect1'),('architecture'),('architetto'),('archived'),('archuleta'),('arcobaleno'),('arcoiris'),('arctic'),('arcticcat'),('ardian'),('ardilla'),('area51'),('arellano'),('aremania'),('arena'),('arenas'),('arequipa'),('ares'),('aretha'),('arevalo'),('arfarf'),('argent'),('argentina'),('argentina1'),('argentina2'),('argentine'),('argento'),('argentum'),('argyle'),('arhangel'),('ari'),('ari-kyarova'),('ari123'),('aria'),('ariadna'),('ariadne'),('ariana'),('ariana1'),('ariana12'),('ariana123'),('ariane'),('arianna'),('arianna1'),('arianna2'),('arianne'),('ariel'),('ariel1'),('ariel12'),('ariel123'),('ariel2'),('ariella'),('arielle'),('arielle1'),('aries'),('aries1'),('aries123'),('ariete'),('arigato'),('arihant'),('arina'),('arina-sharapova-80'),('arinayu0'),('arinka'),('arisha'),('arista'),('aristide'),('aristo'),('aristotle'),('arividerchi_shatalov'),('arizona'),('arizona1'),('arizona123'),('arizona2'),('arjay'),('arjona'),('arjun'),('arjun123'),('arjuna'),('arkangel'),('arkansas'),('arkansas1'),('arkoximsp'),('arlene'),('arlene1'),('arlette'),('arlington'),('arlington1'),('ArlingtonP'),('arm'),('armaan'),('armada'),('armada-n'),('armada1'),('armadillo'),('armageddon'),('armagedon'),('armagedon1'),('arman'),('armand'),('armand1'),('armando'),('armando1'),('armando123'),('armando2'),('armani'),('armani1'),('armelle'),('armenia'),('armenia1'),('armin'),('armine'),('armitage'),('armonia'),('armorgames'),('armstrong'),('armstrong1'),('army'),('army11'),('army12'),('army123'),('army1234'),('armyach-aleksandra'),('armyman'),('armyman1'),('armyof1'),('armyof2'),('armystrong'),('arnaldo'),('arnaud'),('arnel'),('arnie'),('arnie1'),('arnold'),('arnold1'),('arnold123'),('arod13'),('aron'),('arowana'),('arpita'),('arquitecto'),('arquitectura'),('arrahman'),('arrakis'),('arriba'),('arrow'),('arrow1'),('arrowhead'),('arrowhead1'),('arrows'),('arroyo'),('ars'),('arsalan'),('arsch'),('arsch1'),('arsch123'),('arschloch'),('arschloch1'),('arsehole'),('arselect'),('arsen'),('arsenal'),('arsenal01'),('arsenal07'),('arsenal08'),('arsenal09'),('arsenal1'),('arsenal10'),('arsenal11'),('arsenal12'),('arsenal123'),('arsenal13'),('arsenal14'),('arsenal2'),('arsenal22'),('arsenal23'),('arsenal3'),('arsenal4'),('arsenal5'),('arsenal7'),('arsenal8'),('arsenal9'),('arsenalfc'),('arsenalfc1'),('arsene'),('arsenio'),('arseniy'),('arshad'),('arshavin'),('arshavin23'),('arsik-di-noxcho95'),('arslan'),('art'),('art123'),('art131313'),('artart'),('artem'),('artem1'),('artem123'),('artem1994'),('artem1995'),('artem1996'),('artem1997'),('artem1998'),('artem1999'),('artem2010'),('artemblya'),('artemida'),('artemis'),('artemis1'),('artemisa'),('artemisia'),('artemka'),('artemon'),('arthas'),('arthur'),('arthur01'),('arthur1'),('arthur12'),('arthur123'),('arthur2'),('artichoke'),('article456'),('articolo31'),('articuno'),('artist'),('artist1'),('artista'),('artiste'),('artistic'),('artov.95'),('artur'),('artur1'),('artur123'),('arturamirov89'),('arturik'),('arturito'),('arturo'),('arturo1'),('artwork'),('artyom'),('aruba1'),('arun'),('arun123'),('arunkumar'),('arusha'),('arvin'),('arvind'),('arwd89'),('arwen'),('aryan'),('as'),('as0000'),('as0620'),('as123123'),('as1234'),('as12345'),('as123456'),('as123456789'),('as12as12'),('as12df34'),('as790433'),('asa'),('asa123'),('asa62'),('asaasa'),('asabsmelik5g'),('asad'),('asad123'),('asadasad'),('asakapa'),('asakapa123'),('asakura'),('asaness'),('asante'),('asas'),('asas1122'),('asas12'),('asas1212'),('asas123'),('asasas'),('asasas1'),('asasas12'),('asasasas'),('asasasasas'),('asasin'),('asassin1997'),('asawako'),('asawakoh'),('asawaq'),('asbestos'),('ascension'),('ascona'),('asd'),('asd098'),('asd111'),('asd123'),('asd123123'),('asd123321'),('asd1234'),('asd12345'),('asd123456'),('asd1234567'),('asd123456789'),('asd123asd'),('asd123asd123'),('asd123qwe'),('asd123zxc'),('asd147'),('asd159'),('asd222'),('asd321'),('asd456'),('asd654'),('asd666fds'),('asd777'),('asd789'),('asda'),('asda123'),('asdasd'),('asdasd1'),('asdasd11'),('asdasd12'),('asdasd123'),('asdasd123123'),('asdasd12313d'),('asdasd2'),('asdasd456'),('asdasd5'),('asdasd666'),('asdasda'),('asdasdas'),('asdasdasd'),('asdasdasd1'),('asdasdasd123'),('asdasdasdasd'),('asdcxz'),('asddsa'),('asddsa1'),('asddsa123'),('asdert'),('asdewq'),('asdewq123'),('asdf'),('asdf00'),('asdf0987'),('asdf1'),('asdf11'),('asdf12'),('asdf123'),('asdf1234'),('asdf12345'),('asdf123456'),('asdf13'),('asdf22'),('asdf23'),('asdf321'),('asdf3423'),('asdf4321'),('asdf45'),('asdf456'),('asdf:lkj'),('asdf;lkj'),('asdfas'),('asdfasdf'),('asdfasdf1'),('asdfasdf12'),('asdfasdf123'),('asdfasdf2'),('asdfasdfasdf'),('asdfdsa'),('asdffdsa'),('asdffdsa1'),('asdfg'),('asdfg1'),('asdfg11'),('asdfg12'),('asdfg123'),('asdfg1234'),('asdfg12345'),('asdfg2'),('asdfg456'),('asdfg5'),('asdfg6'),('asdfgasdfg'),('asdfgf'),('asdfgh'),('asdfgh!'),('asdfgh.'),('asdfgh01'),('asdfgh1'),('asdfgh11'),('asdfgh12'),('asdfgh123'),('asdfgh1234'),('asdfgh123456'),('asdfgh2'),('asdfgh3'),('asdfgh5'),('asdfgh6'),('asdfgh7'),('asdfghj'),('asdfghj1'),('asdfghj12'),('asdfghj123'),('asdfghjk'),('asdfghjk1'),('asdfghjk12'),('asdfghjkl'),('asdfghjkl!'),('asdfghjkl.'),('asdfghjkl0'),('asdfghjkl1'),('asdfghjkl12'),('asdfghjkl123'),('asdfghjkl12345'),('asdfghjkl2'),('asdfghjkl3'),('asdfghjkl4'),('asdfghjkl456'),('asdfghjkl5'),('asdfghjkl7'),('asdfghjkl9'),('asdfghjkl:'),('asdfghjkl:&#39:'),('asdfghjkl:\''),('asdfghjkl;'),('asdfghjkl;&#39;'),('asdfghjkl;\''),('asdfghjklz'),('asdfghjklzxcvbnm'),('asdfgzxcvb'),('asdfjk'),('asdfjkl'),('asdfjkl1'),('asdfjkl123'),('asdfjkl:'),('asdfjkl:1'),('asdfjkl;'),('asdflkj'),('asdflkjh'),('asdfqwer'),('asdfqwer1'),('asdfqwer123'),('asdfqwer1234'),('asdfrewq'),('asdfvcxz'),('asdfzxc'),('asdfzxcv'),('asdfzxcv1'),('asdjkl'),('asdlkj'),('asdqwe'),('asdqwe1'),('asdqwe12'),('asdqwe123'),('asdqwezxc'),('asdzxc'),('asdzxc1'),('asdzxc12'),('asdzxc123'),('asdzxcqwe'),('asecret'),('asecret1'),('asemmanis'),('aseret'),('aserzx1'),('asesino'),('asgard'),('ash'),('ash101'),('ash123'),('ash1234'),('ash12345'),('asha'),('ashanti'),('ashanti1'),('ashash'),('ashash1'),('ashely'),('ashely1'),('asher'),('asher1'),('ashes'),('ashes1'),('ashford'),('ashish'),('ashish123'),('ashishbiyani'),('ashl3y'),('ashland'),('ashland1'),('ashlee'),('ashlee1'),('ashlee12'),('ashlee123'),('ashleigh'),('ashleigh1'),('ashley'),('ashley!'),('ashley.'),('ashley0'),('ashley00'),('ashley01'),('ashley02'),('ashley03'),('ashley04'),('ashley05'),('ashley06'),('ashley07'),('ashley08'),('ashley09'),('ashley1'),('ashley10'),('ashley101'),('ashley11'),('ashley12'),('ashley123'),('ashley1234'),('ashley13'),('ashley14'),('ashley15'),('ashley16'),('ashley17'),('ashley18'),('ashley19'),('ashley2'),('ashley20'),('ashley21'),('ashley22'),('ashley23'),('ashley24'),('ashley25'),('ashley26'),('ashley27'),('ashley28'),('ashley3'),('ashley33'),('ashley4'),('ashley5'),('ashley6'),('ashley69'),('ashley7'),('ashley77'),('ashley8'),('ashley85'),('ashley86'),('ashley87'),('ashley88'),('ashley89'),('ashley9'),('ashley90'),('ashley91'),('ashley92'),('ashley93'),('ashley94'),('ashley95'),('ashley96'),('ashley97'),('ashley98'),('ashley99'),('ashlie'),('ashlie1'),('ashly'),('ashly1'),('ashlyn'),('ashlyn1'),('ashlynn'),('ashlynn1'),('ashok'),('ashok123'),('ashoka'),('ashokkumar'),('ashraf'),('ashton'),('ashton01'),('ashton1'),('ashton11'),('ashton12'),('ashton123'),('ashton2'),('ashton3'),('ashton9'),('ashtray'),('ashtray1'),('ashu'),('Ashu1992'),('ashutosh'),('ashwani'),('ashwin'),('ashwini'),('asia'),('asia12'),('asia123'),('asiamarketing'),('asian'),('asian1'),('asian123'),('asians'),('asil.dovlatov.1982'),('asilas'),('asimov'),('ask'),('ask123'),('askim'),('askim1'),('askim123'),('askimaskim'),('askimbenim'),('askimsin'),('asking'),('aslan'),('aslan1'),('aslan123'),('asm'),('asmara'),('asmita'),('asmodeus'),('asnaeb'),('asotjan'),('asparagus'),('aspen'),('aspen1'),('aspen123'),('asphalt'),('aspire'),('aspire1'),('aspirin'),('aspirina'),('aspirine'),('aspirine1'),('asqw12'),('asroma'),('asroma1927'),('ass'),('ass101'),('ass111'),('ass123'),('ass1234'),('ass12345'),('ass123456'),('ass1ass1'),('ass666'),('assa'),('assaassa'),('assasin'),('assasin1'),('assass'),('assass1'),('assass123'),('assass2'),('assassass'),('assassin'),('assassin1'),('assassins'),('assassinscreed'),('assault'),('assclown'),('assclown1'),('asscrack1'),('assface'),('assface1'),('assfuck'),('assfuck1'),('assfucker'),('assh0le'),('asshat'),('asshat1'),('asshol3'),('asshole'),('asshole!'),('asshole.'),('asshole0'),('asshole01'),('asshole1'),('asshole10'),('asshole101'),('asshole11'),('asshole12'),('asshole123'),('asshole13'),('asshole14'),('asshole2'),('asshole21'),('asshole22'),('asshole23'),('asshole24'),('asshole3'),('asshole4'),('asshole420'),('asshole5'),('asshole6'),('asshole666'),('asshole69'),('asshole7'),('asshole8'),('asshole9'),('asshole99'),('assholes'),('assholes1'),('assilem'),('assinantes'),('assistant'),('asskicker'),('asskicker1'),('assman'),('assman1'),('assman69'),('assmaster'),('assmonkey'),('assmonkey1'),('assmunch'),('assmunch1'),('asss'),('asssss'),('asstastic'),('assumption'),('assunta'),('asswhole'),('asswhole1'),('asswipe'),('asswipe1'),('assword'),('assword1'),('ast'),('astalavista'),('astana'),('astaroth'),('asterisk'),('asterix'),('asterix1'),('asterlam'),('asteroid'),('astig'),('astigako'),('astigor'),('aston'),('aston1'),('astonmartin'),('astonvilla'),('astonvilla1'),('astoria'),('astoria1'),('astra'),('astra1'),('astra123'),('astral'),('astray'),('astrid'),('astrid1'),('astrid29'),('astro'),('astro1'),('astro123'),('astroboy'),('astrology'),('astronaut'),('astronomy'),('astros'),('astros1'),('asturias'),('asuncion'),('asus'),('asusasus'),('aswang'),('asylum'),('at1234'),('atakan'),('atalanta'),('ataman'),('atanda'),('ataris'),('atchoum'),('atdhfkm'),('atelier'),('atenas'),('atenea'),('ateneo'),('Ateneo123'),('atharva'),('athena'),('athena1'),('athena12'),('athens'),('athens1'),('athina'),('athlete'),('athletic'),('athletics'),('athletics1'),('athlon'),('athlon64'),('athome'),('atienza'),('atilla'),('atkbrc'),('atkins'),('atkinson'),('atl123'),('atlant'),('atlanta'),('atlanta1'),('atlanta123'),('atlanta2'),('atlanta3'),('atlanta7'),('atlantic'),('atlantic1'),('atlantida'),('atlantis'),('atlantis1'),('atlars10'),('atlas'),('atlas1'),('atlas123'),('atleti'),('atletico'),('atljhjdf'),('atmosphere'),('atomic'),('atomic1'),('atown1'),('atreides'),('atreyu'),('atreyu1'),('att123'),('attack'),('attack1'),('attention'),('atticus'),('atticus1'),('attila'),('attila1'),('attilio'),('attitude'),('attitude1'),('attorney'),('attorney1'),('atx512'),('atybrc'),('au'),('aubergine'),('aubree'),('aubree1'),('aubrey'),('aubrey1'),('auburn'),('auburn1'),('auburn12'),('auckland'),('auction'),('auction1'),('aud'),('audi'),('audi100'),('audi1991'),('audi80'),('audia3'),('audia4'),('audia6'),('audia8'),('audio'),('audio1'),('audiopel'),('audioslave'),('audiq7'),('audir8'),('audirs4'),('audirs6'),('audis3'),('audis4'),('audition'),('auditor'),('auditt'),('audrey'),('audrey01'),('audrey1'),('audrey12'),('audrey123'),('audrey2'),('aug'),('Aug!272010'),('auggie'),('auggie1'),('augie1'),('augsburg'),('august'),('august01'),('august02'),('august03'),('august04'),('august05'),('august06'),('august07'),('august08'),('august09'),('august1'),('august10'),('august11'),('august12'),('august123'),('august13'),('august14'),('august15'),('august16'),('august17'),('august18'),('august19'),('august2'),('august20'),('august21'),('august22'),('august23'),('august24'),('august25'),('august26'),('august27'),('august28'),('august29'),('august3'),('august30'),('august31'),('august4'),('august5'),('august6'),('august7'),('august8'),('august88'),('august89'),('august9'),('augusta'),('augusta1'),('auguste'),('augustin'),('augustine'),('augustine1'),('augusto'),('augusto1'),('augustus'),('augustus1'),('aukewpyrt'),('auntie'),('auntie1'),('aur'),('auralog'),('aurelia'),('aurelia1'),('aurelie'),('aurelie1'),('aurelien'),('aurelio'),('aurevoir'),('auriane'),('aurinko'),('aurora'),('aurora1'),('aurora32'),('aurore'),('aus'),('aussie'),('aussie1'),('aust1n'),('austen'),('austen1'),('austin'),('austin!'),('austin.'),('austin00'),('austin01'),('austin02'),('austin03'),('austin04'),('austin05'),('austin06'),('austin07'),('austin08'),('austin09'),('austin1'),('austin10'),('austin101'),('austin11'),('austin12'),('austin123'),('austin1234'),('austin13'),('austin14'),('austin15'),('austin16'),('austin17'),('austin18'),('austin19'),('austin2'),('austin20'),('austin21'),('austin22'),('austin23'),('austin24'),('austin25'),('austin3'),('austin316'),('austin4'),('austin5'),('austin512'),('austin6'),('austin69'),('austin7'),('austin8'),('austin88'),('austin9'),('austin94'),('austin95'),('austin96'),('austin97'),('austin98'),('austin99'),('austine'),('australia'),('australia0'),('australia1'),('australia2'),('australie'),('australien'),('austria'),('austria1'),('authentic'),('author'),('autism'),('auto'),('auto123'),('autobahn'),('autobot'),('autobots'),('autobus'),('autocad'),('automatic'),('automobil'),('automobile'),('automotive'),('autumn'),('autumn01'),('autumn08'),('autumn1'),('autumn11'),('autumn12'),('autumn123'),('autumn13'),('autumn2'),('autumn3'),('auxerre'),('av8Ygj1f2U'),('ava'),('ava123'),('avadakedavra'),('available'),('avalanche'),('avalanche1'),('avalon'),('avalon08'),('avalon1'),('avanesov'),('avangard'),('avanti'),('avantika'),('avatar'),('avatar1'),('avatar12'),('avatar123'),('avefenix'),('avelino'),('avellino'),('avemaria'),('avenged'),('avenged1'),('avenged7'),('avenged7x'),('avengedsev'),('avengedsevenfold'),('avenger'),('avenger1'),('avengers'),('avenir'),('avensis'),('aventura'),('aventura1'),('aventure'),('avenue'),('avery'),('avery1'),('avery123'),('avetisyanartur'),('avgust'),('aviation'),('aviation1'),('aviator'),('aviator1'),('avignon'),('avikuzen'),('avinash'),('avisis7'),('avkhachev78'),('AVM6Ubdunj'),('AVMPWD'),('avocado'),('avocat'),('avokado'),('avondale'),('avondale1'),('avril'),('avril1'),('avril123'),('avrill'),('avrillavig'),('avrillavigne'),('avrora'),('avto55.rus'),('avvocato'),('aw96b6'),('awawaw'),('awdawd'),('awdrgy'),('awdrgyjilp'),('awei1616'),('awerty'),('awesome'),('awesome!'),('awesome.'),('awesome1'),('awesome101'),('awesome11'),('awesome12'),('awesome123'),('awesome13'),('awesome2'),('awesome22'),('awesome3'),('awesome4'),('awesome5'),('awesome7'),('awesome8'),('awesomeness'),('awful'),('awsedr'),('awsome'),('awsome1'),('awsome12'),('awsome123'),('axe123'),('axel'),('axel123'),('axelle'),('axeman'),('axio'),('axlrose'),('axlrose1'),('axssyha'),('ayamgoreng'),('ayanami'),('ayanda'),('ayanna'),('ayanna1'),('aybaybay1'),('aydani_'),('ayden1'),('aydink'),('ayesha'),('ayesha1'),('ayinde'),('aylyan2001'),('ayman2008'),('aymeric'),('ayobami'),('ayodeji'),('ayodeji1'),('ayodele'),('ayomide'),('ayomide1'),('ayomikun'),('ayoola'),('ayrton'),('Aysa2423'),('ayurveda'),('ayushi'),('ayyappa'),('az1234'),('az12345'),('az123456'),('az123456789'),('az147258'),('azacos'),('azalea'),('azalia'),('azamat'),('azazaz'),('azazazaz'),('azazel'),('azazello'),('aza_93-93'),('azbest777'),('azbuka'),('aze'),('aze123'),('azeaze'),('azefirov.inno1987.r'),('azeqsd'),('azeqsdwxc'),('azer'),('azer123'),('azer1234'),('azerazer'),('azerbaijan'),('azerbaycan'),('azert'),('azert1'),('azert123'),('azerty'),('azerty0'),('azerty00'),('azerty01'),('azerty1'),('azerty10'),('azerty11'),('azerty12'),('azerty123'),('azerty1234'),('azerty123456'),('azerty13'),('azerty31'),('azerty59'),('azerty69'),('azerty77'),('azerty78'),('azerty789'),('azertyu'),('azertyui'),('azertyuio'),('azertyuiop'),('azertyuiop1'),('azertyuiop123'),('azik_06'),('azimut'),('aziz'),('aziza'),('azizah'),('azizbek'),('azkaban'),('azn123'),('azn4life'),('aznpride'),('aznpride1'),('azqswx'),('azrael'),('azsxdc'),('azsxdc1'),('azsxdc12'),('azsxdc123'),('azsxdcf'),('azsxdcfv'),('azsxdcfv1'),('azsxdcfvgb'),('aztec1'),('azteca'),('azteca1'),('azteca13'),('aztecs'),('aztnm'),('aztyvl_ka44ze'),('azucar'),('azucena'),('azul'),('azul12'),('azul123'),('azul13'),('azulazul'),('azules'),('azure'),('azxcvbnm'),('azzurra'),('azzurro'),('b'),('b-ball'),('b-ball1'),('b00b00'),('b00bies'),('b00ger'),('b00mb00m'),('b00mer'),('b0ll0cks'),('b11111'),('b111111'),('b123098'),('b123123'),('b12345'),('b123456'),('b1234567'),('b12345678'),('b123456789'),('b1b1b1'),('b1b2b3'),('b1b2b3b4'),('B1LKeB6711'),('b1tches'),('b1teme'),('b1x7qN2tuG'),('b2spirit'),('b33m6yghef'),('b4272327'),('b43m6xhiee'),('b43m6xhife'),('b43n6whifd'),('b55555'),('b654321'),('b696969'),('b8cA6yz1nJ'),('ba'),('bab'),('bab123'),('baba'),('baba12'),('baba123'),('baba1234'),('bababa'),('babababa'),('babacar'),('babajaga'),('babaji'),('babajide'),('babala123'),('babalola'),('babaloo'),('babalu'),('babamama'),('babar'),('babatunde'),('babatunde1'),('babby'),('babby1'),('babbygirl1'),('babcia'),('babe'),('babe01'),('babe10'),('babe101'),('babe11'),('babe12'),('babe123'),('babe1234'),('babe13'),('babe14'),('babe15'),('babe16'),('babe21'),('babe22'),('babe23'),('babe69'),('babebabe'),('baberuth'),('babes'),('babes1'),('babeth'),('babette'),('babi'),('babi12'),('babi123'),('babi1234'),('babich.e'),('babicka'),('babie'),('babie1'),('babies'),('babies1'),('babies123'),('babies2'),('babies3'),('babies4'),('babigurl'),('babigurl1'),('babii1'),('babiigurl1'),('babilon'),('babilonia'),('babita'),('babloo'),('babmicmar'),('babochka'),('babolat'),('baboon'),('baboon1'),('baboshka'),('baboso'),('babou'),('babouche'),('baboune'),('baboy'),('babs'),('babu'),('babu123'),('babubabu'),('babushka'),('baby'),('baby#1'),('baby-girl'),('baby00'),('baby002'),('baby01'),('baby02'),('baby03'),('baby04'),('baby05'),('baby06'),('baby07'),('baby08'),('baby09'),('baby1'),('baby10'),('baby100'),('baby101'),('baby11'),('baby111'),('baby12'),('baby123'),('baby1234'),('baby12345'),('baby123456'),('baby13'),('baby14'),('baby143'),('baby15'),('baby16'),('baby17'),('baby18'),('baby19'),('baby20'),('baby2000'),('baby2004'),('baby2005'),('baby2006'),('baby2007'),('baby2008'),('baby2009'),('baby2010'),('baby2011'),('baby21'),('baby22'),('baby23'),('baby24'),('baby25'),('baby26'),('baby27'),('baby28'),('baby29'),('baby30'),('baby31'),('baby32'),('baby321'),('baby33'),('baby34'),('baby420'),('baby44'),('baby45'),('baby55'),('baby56'),('baby66'),('baby67'),('baby69'),('baby77'),('baby777'),('baby78'),('baby79'),('baby86'),('baby87'),('baby88'),('baby89'),('baby90'),('baby91'),('baby92'),('baby93'),('baby94'),('baby95'),('baby96'),('baby98'),('baby99'),('babyangel'),('babyangel1'),('babyb1'),('babybaby'),('babybaby1'),('babybash'),('babybash1'),('babybear'),('babybear1'),('babybird'),('babyblu3'),('babyblue'),('babyblue1'),('babyblue12'),('babyblue13'),('babyblue2'),('babyblue3'),('babyblue7'),('babyboi'),('babyboi1'),('babyboo'),('babyboo!'),('babyboo1'),('babyboo12'),('babyboo123'),('babyboo13'),('babyboo2'),('babyboo3'),('babyboo7'),('babyboom'),('babyboss'),('babyboy'),('babyboy!'),('babyboy01'),('babyboy06'),('babyboy07'),('babyboy08'),('babyboy09'),('babyboy1'),('babyboy10'),('babyboy11'),('babyboy12'),('babyboy123'),('babyboy13'),('babyboy14'),('babyboy15'),('babyboy16'),('babyboy17'),('babyboy18'),('babyboy2'),('babyboy21'),('babyboy22'),('babyboy23'),('babyboy24'),('babyboy3'),('babyboy4'),('babyboy5'),('babyboy6'),('babyboy69'),('babyboy7'),('babyboy8'),('babyboy9'),('babyboys'),('babycake'),('babycake1'),('babycakes'),('babycakes!'),('babycakes1'),('babycakes2'),('babycakes3'),('babycakes7'),('babycat'),('babycat1'),('babycoh'),('babycute'),('babyd1'),('babydaddy'),('babydaddy1'),('babydog'),('babydog1'),('babydoll'),('babydoll1'),('babydoll12'),('babydoll13'),('babydoll2'),('babydoll3'),('babydoll69'),('babydoll7'),('babyface'),('babyface1'),('babyface12'),('babyface2'),('babyfat1'),('babyg'),('babyg1'),('babyg123'),('babyg1rl'),('babygal'),('babygirl'),('babygirl!'),('babygirl#1'),('babygirl.'),('babygirl0'),('babygirl00'),('babygirl01'),('babygirl02'),('babygirl03'),('babygirl04'),('babygirl05'),('babygirl06'),('babygirl07'),('babygirl08'),('babygirl09'),('babygirl1'),('babygirl10'),('babygirl11'),('babygirl12'),('babygirl123'),('babygirl13'),('babygirl14'),('babygirl15'),('babygirl16'),('babygirl17'),('babygirl18'),('babygirl19'),('babygirl2'),('babygirl20'),('babygirl21'),('babygirl22'),('babygirl23'),('babygirl24'),('babygirl25'),('babygirl26'),('babygirl27'),('babygirl28'),('babygirl29'),('babygirl3'),('babygirl30'),('babygirl31'),('babygirl32'),('babygirl33'),('babygirl34'),('babygirl4'),('babygirl44'),('babygirl45'),('babygirl5'),('babygirl55'),('babygirl56'),('babygirl6'),('babygirl69'),('babygirl7'),('babygirl77'),('babygirl78'),('babygirl8'),('babygirl87'),('babygirl88'),('babygirl89'),('babygirl9'),('babygirl90'),('babygirl91'),('babygirl92'),('babygirl93'),('babygirl94'),('babygirl95'),('babygirl96'),('babygirl97'),('babygirl98'),('babygirl99'),('babygirls'),('babygirls2'),('babygril'),('babygril1'),('babygrl'),('babygrl1'),('babygurl'),('babygurl!'),('babygurl01'),('babygurl06'),('babygurl07'),('babygurl08'),('babygurl09'),('babygurl1'),('babygurl10'),('babygurl11'),('babygurl12'),('babygurl13'),('babygurl14'),('babygurl15'),('babygurl16'),('babygurl17'),('babygurl18'),('babygurl19'),('babygurl2'),('babygurl20'),('babygurl21'),('babygurl22'),('babygurl23'),('babygurl24'),('babygurl3'),('babygurl4'),('babygurl5'),('babygurl6'),('babygurl69'),('babygurl7'),('babygurl8'),('babygurl9'),('babyj1'),('babyjack'),('babyjames'),('babyjane'),('babyjay'),('babyjay1'),('babyjoker1'),('babykitty'),('babykitty1'),('babyko'),('babyko1'),('babykoh'),('babylon'),('babylon1'),('babylon5'),('babylone'),('babylove'),('babylove1'),('babylove12'),('babylove2'),('babylove3'),('babyluv'),('babyluv1'),('babymama'),('babymama1'),('babymomma1'),('babynames'),('babyoneone'),('babypapa'),('babyphat'),('babyphat1'),('babyphat12'),('babyphat2'),('babypink'),('babypink1'),('babyruth'),('babys'),('babys1'),('babyt1'),('baby_girl'),('baby_gurl'),('bac'),('bacardi'),('bacardi1'),('bacardi151'),('bacchus'),('bacchus1'),('bach'),('bachata'),('bachelor'),('bachir'),('back'),('back2back'),('backbone'),('backdoor'),('backdraft'),('backend'),('backflip'),('backflip1'),('backhoe'),('backlash'),('backoff'),('backoff1'),('backpack'),('backpack1'),('backsdau'),('backspace'),('backspace1'),('backspace2'),('backstab'),('backstreet'),('backstreetboys'),('backup'),('backup1'),('backyard'),('backyard1'),('bacolod'),('bacon'),('bacon1'),('bacon123'),('bacteria'),('bad'),('bad123'),('badabing'),('badakhshan'),('badalona'),('badass'),('badass!'),('badass1'),('badass11'),('badass12'),('badass123'),('badass13'),('badass2'),('badass21'),('badass22'),('badass23'),('badass3'),('badass69'),('badazz'),('badazz1'),('badazz2'),('badbad'),('badbitch'),('badbitch1'),('badboi1'),('badboy'),('badboy01'),('badboy08'),('badboy09'),('badboy1'),('badboy10'),('badboy11'),('badboy12'),('badboy123'),('badboy13'),('badboy14'),('badboy15'),('badboy2'),('badboy21'),('badboy22'),('badboy23'),('badboy3'),('badboy4'),('badboy5'),('badboy6'),('badboy69'),('badboy7'),('badboy9'),('badboys'),('badboys1'),('badboys2'),('badboyz'),('badboyz1'),('badcat'),('badcompany'),('baddest1'),('baddog'),('baddog1'),('badfish'),('badger'),('badger1'),('badger123'),('badgers'),('badgers1'),('badgirl'),('badgirl1'),('badgirl12'),('badgirl123'),('badgirl2'),('badgirls'),('badgurl'),('badgurl1'),('badguy'),('bading'),('badkitty'),('badlands'),('badman'),('badman1'),('badman123'),('badminton'),('badminton1'),('badmus'),('badong'),('badoo'),('badoo.com'),('badoo1'),('badoo123'),('badoo2012'),('badoobadoo'),('badooo'),('badromance'),('badshah'),('badtrip'),('bad_boys_adience'),('baerchen'),('bagdad'),('bagel1'),('bagels'),('bagger'),('baggies'),('baggies1'),('baggins'),('baggins1'),('baggio'),('baggio10'),('baghdad'),('bagheera'),('baghera'),('bagira'),('bagong'),('bagpipes'),('bagpuss'),('bagpuss1'),('baguio'),('baguvix'),('bahadur'),('bahagia'),('bahalana'),('bahamas'),('bahamas1'),('bahamut'),('bahamut0'),('bahamut1'),('bahia1979'),('bahrain'),('bai'),('baikal'),('bailarina'),('bailee'),('bailee1'),('bailey'),('bailey!'),('bailey00'),('bailey01'),('bailey02'),('bailey03'),('bailey04'),('bailey05'),('bailey06'),('bailey07'),('bailey08'),('bailey09'),('bailey1'),('bailey10'),('bailey11'),('bailey12'),('bailey123'),('bailey13'),('bailey14'),('bailey15'),('bailey16'),('bailey17'),('bailey2'),('bailey21'),('bailey22'),('bailey23'),('bailey24'),('bailey3'),('bailey33'),('bailey4'),('bailey5'),('bailey6'),('bailey69'),('bailey7'),('bailey77'),('bailey8'),('bailey9'),('bailey98'),('bailey99'),('baileys'),('baili123com'),('Bajaonel12'),('bajingan'),('bajs123'),('bajsbajs'),('bajskorv'),('bajskorv1'),('bakabaka'),('bakekang'),('baker'),('baker1'),('baker12'),('baker123'),('baker2'),('baker3'),('baker4'),('bakers'),('bakery'),('bakker'),('bakla'),('baklan'),('baksik'),('bakugan'),('bakugan1'),('bakuman.manga.drawing'),('bakura'),('bal'),('bala'),('balaji'),('balanar'),('balance'),('balance1'),('balaton'),('balazs'),('balbes'),('balbina'),('balboa'),('balboa1'),('baldeagle'),('balder'),('balderdash'),('baldrick'),('baldur'),('baldwin'),('baldwin1'),('balentinra'),('baleri22'),('balerina'),('balikpapan'),('ball'),('ball11'),('ball12'),('ball123'),('ball1n'),('ball22'),('ball23'),('ball4life'),('balla'),('balla1'),('balla12'),('balla123'),('balla2'),('balla22'),('balla23'),('balla3'),('balla4life'),('ballack'),('ballack13'),('ballard'),('ballard1'),('ballas'),('ballbag'),('ballball'),('ballen'),('ballen1'),('baller'),('baller!'),('baller01'),('baller03'),('baller07'),('baller08'),('baller09'),('baller1'),('baller10'),('baller101'),('baller11'),('baller12'),('baller123'),('baller13'),('baller14'),('baller15'),('baller16'),('baller17'),('baller2'),('baller20'),('baller21'),('baller22'),('baller23'),('baller24'),('baller25'),('baller3'),('baller32'),('baller33'),('baller34'),('baller4'),('baller44'),('baller45'),('baller4lif'),('baller5'),('baller6'),('baller69'),('baller7'),('baller8'),('baller9'),('ballerina'),('ballerina1'),('ballers'),('ballers1'),('ballet'),('ballet1'),('ballin'),('ballin!'),('ballin01'),('ballin07'),('ballin08'),('ballin09'),('ballin1'),('ballin10'),('ballin101'),('ballin11'),('ballin12'),('ballin123'),('ballin13'),('ballin14'),('ballin15'),('ballin2'),('ballin21'),('ballin22'),('ballin23'),('ballin24'),('ballin3'),('ballin4'),('ballin5'),('ballin6'),('ballin69'),('ballin7'),('ballin8'),('balling'),('balling1'),('ballon'),('balloon'),('balloon1'),('balloons'),('balloons1'),('ballroom'),('balls'),('balls1'),('balls12'),('balls123'),('balls2'),('balls69'),('ballsack'),('ballsack1'),('ballsdeep'),('balmoral'),('baloch'),('balogun'),('baloncesto'),('balong'),('baloo'),('balou'),('balrog'),('baltazar'),('balthazar'),('baltika'),('baltimore'),('baltimore1'),('balto1'),('baluga'),('balzac'),('bam'),('bam123'),('bama'),('bama12'),('bamaboy1'),('bamako'),('bambam'),('bambam!'),('bambam01'),('bambam1'),('bambam11'),('bambam12'),('bambam123'),('bambam13'),('bambam2'),('bambam23'),('bambam3'),('bambam69'),('bambam7'),('bambang'),('bambi'),('bambi1'),('bambi123'),('bambie'),('bambina'),('bambino'),('bambino1'),('bambola'),('bambolina'),('bamboo'),('bamboo1'),('bambou'),('bambucha'),('bambus'),('bambush'),('bamidele'),('bammargera'),('ban'),('banaan'),('banan'),('banan1'),('banan123'),('banana'),('banana!'),('banana.'),('banana01'),('banana1'),('banana10'),('banana11'),('banana12'),('banana123'),('banana13'),('banana14'),('banana2'),('banana21'),('banana22'),('banana23'),('banana3'),('banana33'),('banana4'),('banana5'),('banana6'),('banana69'),('banana7'),('banana77'),('banana8'),('banana88'),('banana9'),('banana99'),('bananaman'),('bananarama'),('bananas'),('bananas!'),('bananas1'),('bananas11'),('bananas12'),('bananas123'),('bananas2'),('bananas3'),('bananas7'),('banane'),('banane1'),('bananna'),('banban'),('band'),('band101'),('band12'),('band123'),('banda1'),('bandaid'),('bandana'),('bandera'),('banderas'),('bandgeek'),('bandgeek1'),('bandicoot'),('bandidas747'),('bandido'),('bandit'),('bandit!'),('bandit01'),('bandit07'),('bandit08'),('bandit1'),('bandit10'),('bandit11'),('bandit12'),('bandit1200'),('bandit123'),('bandit13'),('bandit14'),('bandit2'),('bandit21'),('bandit22'),('bandit23'),('bandit3'),('bandit4'),('bandit5'),('bandit6'),('bandit600'),('bandit69'),('bandit7'),('bandit77'),('bandit99'),('bandito'),('bandito1'),('bandits'),('bandits1'),('bandung'),('bandung1'),('bang'),('bang123'),('bangalore'),('bangaram'),('bangbang'),('bangbang1'),('banger'),('banger1'),('bangkok'),('bangkok1'),('bangla'),('bangladesh'),('bangor'),('bangsat'),('banjaluka'),('banjo'),('banjo1'),('banjo123'),('bank'),('bank24'),('bankai'),('bankai1'),('banker'),('banker1'),('bankhead1'),('banking'),('banking1'),('bankole'),('banks'),('banks1'),('bannana'),('bannana1'),('banned'),('banner'),('banner1'),('bannono8'),('bansal'),('banshee'),('banshee1'),('banshee350'),('bantam'),('banzai'),('baobab'),('baobao'),('baobei'),('baphomet'),('baptist'),('baptist1'),('baptiste'),('bar'),('bar123'),('baraban'),('barabas'),('barabashka'),('baracuda'),('baraka'),('barakuda'),('baran'),('baranov'),('baranova'),('barata'),('barb'),('barbados'),('barbados1'),('barbapapa'),('barbar'),('barbara'),('barbara1'),('barbara12'),('barbara123'),('barbara2'),('barbarella'),('barbarian'),('barbarita'),('barbarossa'),('barber'),('barber1'),('barber24'),('barbi'),('barbie'),('barbie!'),('barbie.'),('barbie01'),('barbie07'),('barbie08'),('barbie09'),('barbie1'),('barbie10'),('barbie101'),('barbie11'),('barbie12'),('barbie123'),('barbie1234'),('barbie13'),('barbie14'),('barbie15'),('barbie16'),('barbie17'),('barbie18'),('barbie2'),('barbie21'),('barbie22'),('barbie23'),('barbie3'),('barbie4'),('barbie5'),('barbie6'),('barbie69'),('barbie7'),('barbie8'),('barbie9'),('barbiedoll'),('barbiegirl'),('barbora'),('barborka'),('barbos'),('barbosa'),('barbra'),('barby'),('barca'),('barca1'),('barca10'),('barca123'),('barcellona'),('barcelon'),('barcelona'),('barcelona0'),('barcelona1'),('barcelona10'),('barcelona123'),('barcelona2'),('barcelona3'),('barcelona5'),('barcelona7'),('barcelona8'),('barcelona9'),('barcelone'),('barchetta'),('barclay'),('barclays'),('barcode'),('barefoot'),('barefoot1'),('barfield13'),('bariloche'),('baritone'),('baritone1'),('barkada'),('barker'),('barker1'),('barkley'),('barkley1'),('barkov_65'),('barley'),('barley1'),('barlow'),('barmaley'),('barman'),('barnabas'),('barnaby'),('barnaby1'),('barnaul'),('barnes'),('barnes1'),('barnett'),('barney'),('barney!'),('barney01'),('barney1'),('barney10'),('barney11'),('barney12'),('barney123'),('barney13'),('barney2'),('barney5'),('barnie'),('barnsley'),('barnyard'),('baron'),('baron1'),('barone'),('baronessa87'),('baronn'),('barosan'),('barracuda'),('barracuda1'),('barrel'),('barrera'),('barret'),('barreto'),('barrett'),('barrett1'),('barrie'),('barrington'),('barrio13'),('barrios'),('barrister'),('barron'),('barron1'),('barros'),('barrow'),('barry'),('barry1'),('barry123'),('barry20'),('barselona'),('barsik'),('barsuk'),('bart'),('bart12'),('bart123'),('bartbart'),('bartek'),('bartek1'),('bartek123'),('bartender'),('bartender1'),('bartlett'),('bartman'),('bartman1'),('bartok'),('bartolo'),('bartolome'),('bartolomeo'),('barton'),('barton1'),('bartosz'),('bartsimpson'),('baruch'),('barunka'),('bas'),('bas123'),('bas3ball'),('basbas'),('base'),('baseba11'),('basebal1'),('baseball'),('baseball!'),('baseball.'),('baseball0'),('baseball00'),('baseball01'),('baseball02'),('baseball03'),('baseball04'),('baseball05'),('baseball06'),('baseball07'),('baseball08'),('baseball09'),('baseball1'),('baseball10'),('baseball11'),('baseball12'),('baseball123'),('baseball13'),('baseball14'),('baseball15'),('baseball16'),('baseball17'),('baseball18'),('baseball19'),('baseball2'),('baseball20'),('baseball21'),('baseball22'),('baseball23'),('baseball24'),('baseball25'),('baseball26'),('baseball27'),('baseball28'),('baseball29'),('baseball3'),('baseball30'),('baseball31'),('baseball32'),('baseball33'),('baseball34'),('baseball35'),('baseball4'),('baseball42'),('baseball44'),('baseball45'),('baseball5'),('baseball55'),('baseball6'),('baseball69'),('baseball7'),('baseball77'),('baseball8'),('baseball88'),('baseball9'),('baseball99'),('baseline'),('basement'),('basement1'),('basher'),('bashful'),('bashful1'),('bashir'),('bashiru'),('basia'),('basia1'),('basic'),('basic1'),('basil'),('basil1'),('basil123'),('basile'),('basilio'),('bask3tball'),('basket'),('basket1'),('basket10'),('basket101'),('basket11'),('basket12'),('basket123'),('basket13'),('basket2'),('basket23'),('basket5'),('basketba'),('basketba11'),('basketbal'),('basketbal1'),('basketbal2'),('basketbal9'),('basketball'),('basketball1'),('basketball10'),('basketball11'),('basketball12'),('basketball123'),('basketball13'),('basketball22'),('basketball23'),('basketball3'),('basketbol'),('basketcase'),('baskets'),('bass'),('bass11'),('bass12'),('bass123'),('bass1234'),('bassam'),('bassbass'),('bassboat'),('basset'),('bassett'),('bassey'),('bassfish'),('bassguitar'),('basshunter'),('bassie'),('bassin'),('bassist'),('bassist1'),('bassline'),('bassman'),('bassman1'),('bassmaster'),('bassoon'),('bassoon1'),('bassplayer'),('basspro'),('basspro1'),('basta'),('bastard'),('bastard1'),('bastardo'),('bastards'),('baster'),('bastet'),('basti'),('bastian'),('bastian1'),('bastien'),('bastille'),('bastion'),('basti_1014'),('bastos'),('basura'),('bat'),('bat123'),('batangas'),('batata'),('batch'),('bateau'),('bateman'),('bateria'),('batgirl'),('batgirl1'),('bathroom'),('bathroom1'),('batigol'),('batista'),('batista1'),('batista12'),('batista123'),('batista2'),('batista619'),('batistuta'),('batman'),('batman!'),('batman.'),('batman0'),('batman00'),('batman007'),('batman01'),('batman07'),('batman08'),('batman09'),('batman1'),('batman10'),('batman101'),('batman11'),('batman12'),('batman123'),('batman1234'),('batman13'),('batman14'),('batman15'),('batman16'),('batman17'),('batman18'),('batman19'),('batman2'),('batman20'),('batman21'),('batman22'),('batman23'),('batman24'),('batman25'),('batman27'),('batman3'),('batman33'),('batman4'),('batman44'),('batman45'),('batman5'),('batman55'),('batman6'),('batman66'),('batman666'),('batman69'),('batman7'),('batman77'),('batman8'),('batman88'),('batman89'),('batman9'),('batman99'),('batmonh'),('batteria'),('batterie'),('batteries'),('battery'),('battery1'),('battle'),('battle1'),('battlefield'),('battlefield2'),('battleon'),('battleship'),('battousai'),('batuhan'),('baubau'),('baudelaire'),('bauer'),('bauhaus'),('baumhaus'),('bautista'),('bautista1'),('bavaria'),('bavixepym'),('baxter'),('baxter01'),('baxter1'),('baxter11'),('baxter12'),('baxter123'),('baxter2'),('bay'),('bay123'),('bayarea'),('bayarea1'),('bayarea510'),('baybay'),('baybay1'),('baybee'),('baybee1'),('bayer04'),('bayern'),('bayern1'),('bayern94'),('baylee'),('baylee1'),('bayley'),('bayliner'),('baylor'),('baylor1'),('bayonne'),('bayrafis'),('bayram'),('bayside'),('bayside1'),('bayview'),('baywatch'),('bazas52'),('bazooka'),('bazooka1'),('bazueva.1990'),('bazuka'),('bb'),('bb1234'),('bb12345'),('bb123456'),('bball'),('bball!'),('bball07'),('bball08'),('bball09'),('bball1'),('bball10'),('bball101'),('bball11'),('bball12'),('bball123'),('bball13'),('bball14'),('bball15'),('bball2'),('bball20'),('bball21'),('bball22'),('bball23'),('bball24'),('bball25'),('bball3'),('bball30'),('bball31'),('bball32'),('bball33'),('bball34'),('bball4'),('bball42'),('bball44'),('bball4life'),('bball5'),('bball6'),('bball7'),('bball8'),('bball9'),('bballer'),('bballer1'),('bbb'),('bbb111'),('bbb123'),('bbbb'),('bbbbb'),('bbbbb1'),('bbbbbb'),('bbbbbb1'),('bbbbbbb'),('bbbbbbbb'),('bbbbbbbbbb'),('bbc123'),('bbking'),('BBLeo1zz'),('bby123'),('bc1234'),('bcgfybz'),('bcnjhbz'),('BCP201109a'),('bcrich'),('bdfyeirf'),('bdfyjd'),('bdfyjdbx'),('bdfyjdf'),('be'),('bea'),('bea123'),('beach'),('beach1'),('beach12'),('beach123'),('beach2'),('beachbabe'),('beachbabe1'),('beachboy'),('beachbum'),('beachbum1'),('beaches'),('beaches1'),('beacon'),('beagle'),('beagle1'),('beagles'),('beaker'),('beamer'),('beamer1'),('bean'),('bean123'),('beanbag'),('beanbean'),('beaner'),('beaner1'),('beaner12'),('beaner123'),('beaner13'),('beaner2'),('beanhead'),('beanie'),('beanie1'),('beans'),('beans1'),('beans123'),('bear'),('bear01'),('bear07'),('bear08'),('bear1'),('bear10'),('bear101'),('bear11'),('bear12'),('bear123'),('bear1234'),('bear13'),('bear14'),('bear15'),('bear16'),('bear21'),('bear22'),('bear23'),('bear2327'),('bear24'),('bear69'),('bear99'),('bearbear'),('bearbear1'),('bearcat'),('bearcat1'),('bearcats'),('bearcats1'),('beardog'),('beardog1'),('bears'),('bears1'),('bears12'),('bears123'),('bears2'),('bears23'),('bears34'),('bears54'),('bears85'),('bearshare'),('bearshare1'),('beasley'),('beasley1'),('beast'),('beast1'),('beast11'),('beast12'),('beast123'),('beast13'),('beast2'),('beast23'),('beast3'),('beast5'),('Beast556'),('beast666'),('beastie'),('Beastie0'),('beastie1'),('beastly1'),('beastmode'),('beastmode1'),('beasty'),('beasty1'),('beata'),('beata1'),('beatbox'),('beatbox1'),('beater'),('beatiful'),('beatit'),('beatka'),('beatle'),('beatle1'),('beatles'),('beatles1'),('beatles2'),('beatles4'),('beatrice'),('beatrice1'),('beatrix'),('beatriz'),('beatriz1'),('beats1'),('beau'),('beaubeau'),('beaufort'),('beaumont'),('beaumont1'),('beauregard'),('beaute'),('beautifu'),('beautiful'),('beautiful!'),('beautiful.'),('beautiful0'),('beautiful1'),('beautiful2'),('beautiful3'),('beautiful4'),('beautiful5'),('beautiful6'),('beautiful7'),('beautiful8'),('beautiful9'),('beautifulg'),('beautifull'),('beauty'),('beauty!'),('beauty01'),('beauty08'),('beauty1'),('beauty101'),('beauty11'),('beauty12'),('beauty123'),('beauty2'),('beauty21'),('beauty3'),('beauty7'),('beaver'),('beaver1'),('beaver69'),('beavers'),('beavers1'),('beavis'),('beavis1'),('beb'),('beba12'),('beba123'),('bebang'),('bebe'),('bebe01'),('bebe10'),('bebe11'),('bebe12'),('bebe123'),('bebe1234'),('bebe13'),('bebe14'),('bebe15'),('bebe16'),('bebe17'),('bebe18'),('bebe21'),('bebe22'),('bebe23'),('bebebe'),('bebebebe'),('bebegim'),('bebeko'),('bebep2x'),('bebert'),('bebeto'),('bebita'),('bebita1'),('bebito'),('bebo12'),('bebo123'),('bebop'),('bebop1'),('because'),('because1'),('becca'),('becca1'),('becca12'),('becca123'),('becca2'),('beccaboo'),('beck'),('becker'),('becker1'),('beckett'),('beckham'),('beckham07'),('beckham1'),('beckham23'),('beckham7'),('beckie'),('becky'),('becky1'),('becky12'),('becky123'),('becky2'),('becool'),('becool1'),('bedford'),('bedford1'),('bedrock'),('bedrock1'),('bedroom'),('bedroom1'),('bedtime'),('bee'),('bee123'),('beebee'),('beebee1'),('beebop'),('beechwood'),('beef'),('beefcake'),('beefcake1'),('beefy1'),('beegee'),('beegees'),('beehive'),('beejay'),('beeline'),('beemer'),('beemer1'),('beepbeep'),('beepbeep1'),('beeper'),('beer'),('beer12'),('beer123'),('beer30'),('beer4me'),('beer69'),('beerbeer'),('beerbeer1'),('beerman'),('beerman1'),('beerme'),('beerpong1'),('beertje'),('beethoven'),('beethoven1'),('Beethoven9'),('beetle'),('beetle1'),('beetlejuice'),('beezer'),('beezy1'),('before'),('befree'),('begemot'),('begonia'),('begood'),('behappy'),('behappy1'),('behappy2'),('behemoth'),('behemoth1'),('beibei'),('beijing'),('beijing2008'),('beirut'),('bekasi'),('bel'),('bela2404'),('belair'),('belarus'),('belen'),('belen1'),('belette'),('beleza'),('belfast'),('belfast1'),('belgarion'),('belgique'),('belgium'),('belgrano'),('belial'),('belier'),('believe'),('believe1'),('believer'),('belinda'),('belinda1'),('belinea'),('belinea1'),('belinea85'),('belinha'),('belinova14'),('belize'),('belize1'),('belka'),('belkin'),('belkin1'),('bell'),('bell12'),('bell123'),('bella'),('bella!'),('bella01'),('bella02'),('bella03'),('bella04'),('bella05'),('bella06'),('bella07'),('bella08'),('bella09'),('bella1'),('bella10'),('bella101'),('bella11'),('bella12'),('bella123'),('bella1234'),('bella13'),('bella14'),('bella15'),('bella16'),('bella17'),('bella18'),('bella19'),('bella2'),('bella2007'),('bella2008'),('bella2009'),('bella2010'),('bella21'),('bella22'),('bella23'),('bella24'),('bella25'),('bella3'),('bella4'),('bella5'),('bella6'),('bella69'),('bella7'),('bella77'),('bella8'),('bella88'),('bella9'),('bella99'),('bellabella'),('bellaboo'),('bellaboo1'),('belladog'),('belladonna'),('bellagio'),('bellamia'),('bellamy'),('bellas'),('bellatrix'),('bellavista'),('bellavita'),('bellbell'),('belldandy'),('belle'),('belle1'),('belle12'),('belle123'),('belle2'),('belles'),('bellevue'),('belleza'),('bellezza'),('bellisima'),('bellissima'),('bellissimo'),('bello'),('bellota'),('bellsouth'),('bellsouth1'),('belly'),('belly1'),('bellydance'),('belmar'),('belmont'),('belmont1'),('belmonte'),('belochka'),('belova'),('beloved'),('beloved1'),('beloved_a_devil'),('beltran'),('beluga'),('belvedere'),('bembem'),('bemine'),('bemine1'),('ben'),('ben10'),('ben100'),('ben101'),('ben123'),('ben1234'),('ben12345'),('ben123456'),('benben'),('benben1'),('benbenben'),('bench'),('bender'),('bender1'),('bendover'),('benedetta'),('benedetto'),('benedict'),('benedict1'),('benedicte'),('benedikt'),('benelli'),('benetton'),('benfica'),('benfica1'),('bengal'),('bengal1'),('bengals'),('bengals1'),('bengals85'),('bengbeng'),('benhur'),('benidorm'),('benita'),('benitez'),('benito'),('benito1'),('benjam1n'),('benjamin'),('benjamin!'),('benjamin01'),('benjamin1'),('benjamin10'),('benjamin11'),('benjamin12'),('benjamin123'),('benjamin13'),('benjamin15'),('benjamin2'),('benjamin22'),('benjamin3'),('benjamin4'),('benjamin5'),('benjamin7'),('benji'),('benji1'),('benji12'),('benji123'),('benji2'),('benjie'),('benjie1'),('benladen'),('bennet'),('bennett'),('bennett1'),('benni'),('bennie'),('Bennie!!'),('bennie1'),('bennington'),('benny'),('benny1'),('benny12'),('benny123'),('benny2'),('bennyboy'),('bennyboy1'),('benoit'),('benoit1'),('benson'),('benson1'),('benson12'),('benson123'),('bente6'),('benten'),('benten10'),('bentley'),('bentley1'),('bentley2'),('bently'),('bently1'),('benton'),('benton1'),('bentong'),('benz'),('benzema'),('benzin'),('ben_a95'),('beograd'),('beograd1'),('beowulf'),('beowulf1'),('bepositive'),('ber'),('ber217an'),('berbatov'),('berber'),('berenice'),('berenice1'),('beretta'),('beretta1'),('bereza'),('bergamo'),('bergen'),('berger'),('bergkamp'),('bergkamp10'),('berkay'),('berkeley'),('berkeley1'),('berkley'),('berkley1'),('berkshire'),('berkut'),('berlin'),('berlin1'),('berlin12'),('berlin123'),('berliner'),('berlingo'),('berlioz'),('Berlitz'),('berlusconi'),('bermuda'),('bermuda1'),('bermudez'),('bernabe'),('bernadette'),('bernal'),('bernard'),('bernard1'),('bernard2'),('bernardino'),('bernardo'),('bernardo1'),('bernhard'),('bernice'),('bernice1'),('bernie'),('bernie01'),('bernie1'),('berries'),('berries1'),('berry'),('berry1'),('berry12'),('berry123'),('berry2'),('berserk'),('berserk1'),('berserker'),('bert'),('bert123'),('berta'),('berta1'),('bertha'),('bertha1'),('bertie'),('bertie1'),('berto'),('bertone'),('bertram'),('bertrand'),('beruska'),('beryl'),('besiktas'),('besiktas1'),('besiktas1903'),('besitos'),('bessie'),('bessie1'),('best'),('best12'),('best123'),('best1234'),('bestbest'),('bestbuds'),('bestbuy'),('bestbuy1'),('bestfriend'),('bestfriend1'),('bestfriends'),('bestia'),('bestie'),('bestie1'),('besties'),('besties1'),('bestman'),('bestmom1'),('bestrong'),('bet'),('beta'),('beth'),('beth11'),('beth12'),('beth123'),('bethan'),('bethann'),('bethany'),('bethany1'),('bethany12'),('bethany123'),('bethany2'),('bethel'),('bethel1'),('bethesda'),('bethoven'),('betina'),('betito'),('betmen'),('beto'),('beto12'),('beto123'),('beto13'),('betrayed'),('betrayed1'),('betsie'),('betsy'),('betsy1'),('betsynx0kof'),('better'),('better1'),('betterdays'),('bettie'),('bettina'),('bettina1'),('bettina23'),('bettis'),('bettis36'),('betty'),('betty1'),('betty12'),('betty123'),('betty2'),('betty21'),('bettyboo'),('bettyboo1'),('bettyboop'),('bettyboop1'),('bettyboop2'),('bettyboop3'),('bettyboop7'),('bettylou'),('between121'),('beulah'),('beverley'),('beverley1'),('beverly'),('beverly1'),('beware'),('beyblade'),('beyblade1'),('beyonce'),('beyonce1'),('beyonce12'),('beyonce123'),('beyonce2'),('beyond'),('beyond1'),('beyourself'),('bf1942'),('bf4ever'),('bff123'),('bff4eva'),('bff4ever'),('bff4life'),('bffl123'),('bgt56yhn'),('bh90210'),('bhabes'),('bhabie'),('bhaby'),('bhabycoh'),('bhabyko'),('bhabykoh'),('bhabyq'),('bhabyqoh'),('bhagwan'),('bhagya'),('bhakti'),('bharat'),('bharat123'),('bharath'),('bharathi'),('bharati'),('bhardwaj'),('bhargavi'),('bharti'),('bhaskar'),('bhatti'),('bhavana'),('bhavani'),('bhavesh'),('bhavna'),('bhavya'),('bhbcrf'),('bhbirf'),('bhbyf'),('bhbyjxrf'),('bhbyrf'),('bhebhe'),('bhebheko'),('bhf'),('bhjxrf'),('bholenath'),('bhopal'),('bhumika'),('bhushan'),('bhutan'),('bhuvana'),('bia123'),('biabia'),('biagio'),('bianca'),('bianca01'),('bianca1'),('bianca10'),('bianca11'),('bianca12'),('bianca123'),('bianca13'),('bianca2'),('biancaneve'),('bianchi'),('bianco'),('bianka'),('biarritz'),('biatch'),('biatch1'),('bib'),('bibby10'),('bibi'),('bibi123'),('bibiana'),('bibibi'),('bibibibi'),('bibiche'),('bibigon'),('bible'),('bible1'),('bible123'),('bibles'),('biblia'),('biblioteca'),('biblioteka'),('bibou'),('biboune'),('bichette'),('bichito'),('bichon'),('bicicleta'),('bicicletta'),('bicth1'),('bicycle'),('bicycle1'),('bidadari'),('bidemi'),('bidule'),('bieber'),('bieberfeve'),('biedronka'),('bienchen'),('bienvenido'),('bienvenu'),('bienvenue'),('big'),('big123'),('bigal'),('bigal1'),('bigapple'),('bigass'),('bigass1'),('bigbaby'),('bigbaby1'),('bigbad'),('bigbad#13'),('bigballer'),('bigballer1'),('bigballs'),('bigballs1'),('bigballs2'),('bigbang'),('bigbang1'),('bigbang123'),('bigbass'),('bigbass1'),('bigbear'),('bigbear1'),('bigben'),('bigben07'),('bigben1'),('bigben7'),('bigbig'),('bigbig1'),('bigbird'),('bigbird1'),('bigbitch1'),('bigblack'),('bigblack1'),('bigblock'),('bigblue'),('bigblue1'),('bigbob'),('bigbob1'),('bigboi'),('bigboi1'),('bigboi2'),('bigboobs'),('bigboobs1'),('bigbooty'),('bigbooty1'),('bigboss'),('bigboss1'),('bigboy'),('bigboy!'),('bigboy01'),('bigboy08'),('bigboy09'),('bigboy1'),('bigboy10'),('bigboy11'),('bigboy12'),('bigboy123'),('bigboy13'),('bigboy14'),('bigboy15'),('bigboy2'),('bigboy21'),('bigboy22'),('bigboy23'),('bigboy3'),('bigboy4'),('bigboy5'),('bigboy6'),('bigboy69'),('bigboy7'),('bigboy8'),('bigboy9'),('bigbro'),('bigbro1'),('bigbrother'),('bigbuck'),('bigbuck1'),('bigbucks'),('bigbucks1'),('bigbutt'),('bigbutt1'),('bigbutts'),('bigcat'),('bigcat1'),('bigcock'),('bigcock1'),('bigcountry'),('bigd'),('bigd123'),('bigdad'),('bigdad1'),('bigdaddy'),('bigdaddy01'),('bigdaddy1'),('bigdaddy10'),('bigdaddy11'),('bigdaddy12'),('bigdaddy13'),('bigdaddy2'),('bigdaddy23'),('bigdaddy3'),('bigdaddy5'),('bigdaddy69'),('bigdaddy7'),('bigdave'),('bigdave1'),('bigdawg'),('bigdawg1'),('bigdick'),('bigdick1'),('bigdick12'),('bigdick123'),('bigdick2'),('bigdick69'),('bigdick7'),('bigdick9'),('bigdicks'),('bigdog'),('bigdog01'),('bigdog1'),('bigdog10'),('bigdog11'),('bigdog12'),('bigdog123'),('bigdog13'),('bigdog2'),('bigdog22'),('bigdog23'),('bigdog3'),('bigdog5'),('bigdog69'),('bigdog7'),('bigdogg'),('bigdogg1'),('bigdogs'),('bigears'),('bigfish'),('bigfish1'),('bigfoot'),('bigfoot1'),('bigfoot2'),('biggay1'),('biggdogg'),('bigger'),('bigger1'),('biggie'),('biggie1'),('biggie2'),('biggirl'),('biggirl1'),('biggles'),('biggles1'),('biggun'),('bigguns'),('bigguy'),('bigguy1'),('biggy'),('biggy1'),('bighead'),('bighead1'),('bighead2'),('bighouse'),('bigjake'),('bigjim'),('bigjoe'),('bigjohn'),('bigjohn1'),('biglove'),('bigmac'),('bigmac1'),('bigmama'),('bigmama1'),('bigmama2'),('bigman'),('bigman1'),('bigman12'),('bigman123'),('bigman2'),('bigmike'),('bigmike1'),('bigmomma'),('bigmomma1'),('bigmoney'),('bigmoney1'),('bigmoney2'),('bigmouth'),('bignasty'),('bignose'),('bignose1'),('bigone'),('bigone1'),('bigpapa'),('bigpapa1'),('bigpapi34'),('bigpenis'),('bigpimp'),('bigpimp1'),('bigpimpin'),('bigpimpin1'),('bigpimpin2'),('bigpoppa'),('bigpoppa1'),('bigpun'),('bigpun1'),('bigred'),('bigred1'),('bigred12'),('bigred123'),('bigred2'),('bigsexy'),('bigsexy1'),('bigshot'),('bigshow'),('bigshow1'),('bigsis'),('bigsis1'),('bigsister'),('bigsister1'),('bigsky'),('bigtime'),('bigtime1'),('bigtimerus'),('bigtits'),('bigtits1'),('bigtits2'),('bigtits69'),('bigtoe'),('bigtruck'),('bigtruck1'),('bigwill'),('bigwill1'),('bigworm'),('bigworm1'),('bijou'),('bijou1'),('bijoux'),('bike'),('bike123'),('bike4life'),('biker'),('biker1'),('biker123'),('bikerboy'),('bikerboy1'),('bikers'),('bikers1'),('bikes1'),('biking'),('biking1'),('bikini'),('bikini1'),('bil'),('bilabong'),('bilal'),('bilal1'),('bilal123'),('bilancia'),('bilbao'),('bilbo'),('bilbo1'),('bilgisayar'),('bill'),('bill12'),('bill123'),('bill1234'),('bill1989'),('bill89'),('billabong'),('billabong1'),('billabong2'),('billabong7'),('billard'),('billbill'),('billgates'),('billgeitslox'),('billiards'),('billie'),('billie1'),('billiejean'),('billiejoe'),('billiejoe1'),('billings'),('billion'),('billionaire'),('billions'),('billkaulit'),('billkaulitz'),('billou'),('bills'),('bills1'),('billups1'),('billy'),('billy!'),('billy01'),('billy07'),('billy1'),('billy10'),('billy11'),('billy12'),('billy123'),('billy1234'),('billy13'),('billy2'),('billy21'),('billy22'),('billy23'),('billy27'),('billy3'),('billy4'),('billy5'),('billy6'),('billy69'),('billy7'),('billyb'),('billybob'),('billybob1'),('billybob12'),('billybob2'),('billyboy'),('billyboy1'),('billygoat'),('billygoat1'),('billyjoe'),('billyjoe1'),('billyray'),('billys'),('biloute'),('bimba'),('bimbim'),('bimbo'),('bimbo1'),('bimmer'),('bimsta'),('bin'),('binbin'),('binder'),('bing'),('bingbing'),('bingbong'),('bingo'),('bingo1'),('bingo12'),('bingo123'),('bingo2'),('bingoo'),('bingos'),('binkie'),('binky'),('binky1'),('binladen'),('bintang'),('bintang1'),('bintou'),('binweevils'),('biochem'),('biochemistry'),('biodun'),('biohazard'),('biohazard1'),('biologia'),('biologie'),('biology'),('biology1'),('bionda'),('biondo'),('bionic'),('bionicle'),('bionicle1'),('bioshock'),('biotch'),('biotch1'),('biotech'),('biotechnology'),('bipbip'),('bipolar'),('bipolar1'),('biquette'),('birba'),('bird'),('bird12'),('bird123'),('bird33'),('birdbird'),('birdcage'),('birddog'),('birddog1'),('birdhouse'),('birdhouse1'),('birdie'),('birdie1'),('birdie123'),('birdies'),('birdman'),('birdman1'),('birds'),('birds1'),('birdy'),('birdy1'),('birgit'),('birillo'),('birmingham'),('birtanem'),('birthday'),('birthday1'),('birthday12'),('birthvillage'),('biscoito'),('biscotte'),('biscotto'),('biscuit'),('biscuit1'),('biscuit2'),('Biscuit22'),('biscuits'),('biscuits1'),('bisexual'),('bisexual1'),('bishop'),('bishop1'),('biskit'),('bismarck'),('bismark'),('bismilah'),('bismilla'),('bismillah'),('bismillah1'),('bismillah123'),('bismillah786'),('bisola'),('bisounours'),('bisous'),('bit'),('bitanem'),('bitch'),('bitch!'),('bitch!!'),('bitch#1'),('bitch.'),('bitch0'),('bitch00'),('bitch01'),('bitch02'),('bitch05'),('bitch06'),('bitch07'),('bitch08'),('bitch09'),('bitch1'),('bitch10'),('bitch100'),('bitch101'),('bitch11'),('bitch111'),('bitch12'),('bitch123'),('bitch1234'),('bitch12345'),('bitch13'),('bitch14'),('bitch15'),('bitch16'),('bitch17'),('bitch18'),('bitch19'),('bitch2'),('bitch20'),('bitch2008'),('bitch2009'),('bitch2010'),('bitch21'),('bitch22'),('bitch23'),('bitch24'),('bitch25'),('bitch26'),('bitch27'),('bitch3'),('bitch32'),('bitch321'),('bitch33'),('bitch34'),('bitch4'),('bitch420'),('bitch44'),('bitch45'),('bitch4life'),('bitch5'),('bitch55'),('bitch56'),('bitch6'),('bitch66'),('bitch666'),('bitch69'),('bitch7'),('bitch77'),('bitch8'),('bitch87'),('bitch88'),('bitch89'),('bitch9'),('bitch90'),('bitch92'),('bitch93'),('bitch99'),('bitchass'),('bitchass1'),('bitchass12'),('bitchass2'),('bitchbitch'),('bitches'),('bitches!'),('bitches.'),('bitches01'),('bitches1'),('bitches12'),('bitches123'),('bitches13'),('bitches2'),('bitches3'),('bitches4'),('bitches5'),('bitches69'),('bitches7'),('bitchez1'),('bitchface'),('bitchface1'),('bitchin'),('bitchin1'),('bitchnigga'),('bitchpleas'),('bitchplease'),('bitchplz1'),('bitchs'),('bitchs1'),('bitchy'),('bitchy1'),('bite'),('biteme'),('biteme!'),('biteme01'),('biteme1'),('biteme11'),('biteme12'),('biteme123'),('biteme13'),('biteme2'),('biteme22'),('biteme3'),('biteme69'),('bitter'),('bitter1'),('bittersweet'),('bizarre'),('bizkit'),('bizkit1'),('bizzle'),('bizzle1'),('bizzy1'),('bj1234'),('bjk1903'),('bk.irf'),('bk4life'),('bkl29m2bk'),('bkmlfh'),('bl'),('bl8LYGB0'),('bla'),('bla123'),('blabla'),('blabla1'),('blabla12'),('blabla123'),('blabla2'),('blablabla'),('blablabla1'),('black'),('black!'),('black.'),('black0'),('black00'),('black01'),('black07'),('black08'),('black09'),('black1'),('black10'),('black101'),('black11'),('black12'),('black123'),('black1234'),('black12345'),('black13'),('black14'),('black15'),('black16'),('black17'),('black18'),('black19'),('black2'),('black20'),('black21'),('black22'),('black23'),('black24'),('black25'),('black26'),('black27'),('black3'),('black33'),('black4'),('black45'),('black5'),('black55'),('black6'),('black666'),('black69'),('black7'),('black77'),('black8'),('black88'),('black89'),('black9'),('black92'),('black99'),('blackadder'),('blackandwhite'),('blackangel'),('blackangel09021'),('blackass'),('blackass1'),('blackbear'),('blackbear1'),('blackbeauty'),('blackbelt'),('blackbelt1'),('blackberry'),('blackberry1'),('blackbird'),('blackbird1'),('blackblack'),('blackbox'),('blackboy'),('blackboy1'),('blackburn'),('blackburn1'),('blackcat'),('blackcat1'),('Blackcat123'),('blackcat13'),('blackdeath'),('blackdevil'),('blackdog'),('blackdog1'),('blackdragon'),('blackeye'),('blackfire'),('blackfoot'),('blackgirl'),('blackgirl1'),('blackhawk'),('blackhawk1'),('blackhawks'),('blackheart'),('blackhole'),('blackhole1'),('blackhorse'),('blackice'),('blackice1'),('blackie'),('blackie1'),('blackie123'),('blackie2'),('blackjack'),('blackjack1'),('blackjack2'),('blackjack21'),('blackknight'),('blacklab'),('blacklab1'),('blacklabel'),('blacklight'),('blacklist'),('blackmagic'),('blackmamba'),('blackman'),('blackman1'),('blackmetal'),('blackmoon'),('blackmore'),('blackness'),('blacknight'),('blackops'),('blackops1'),('blackops2'),('blackout'),('blackout1'),('blackpanther'),('blackpearl'),('blackpool'),('blackpool1'),('blackpower'),('blackrock'),('blackrose'),('blackrose1'),('blacks'),('blacks1'),('blacksabbath'),('blacksheep'),('blacksmith'),('blackstar'),('blackstar1'),('blackstone'),('blacksun'),('blacktiger'),('blackveilb'),('blackwater'),('blackwell'),('blackwhite'),('blackwidow'),('blackwolf'),('blackwood'),('blacky'),('blacky1'),('blacky12'),('blacky123'),('blacky2'),('blade'),('blade1'),('blade12'),('blade123'),('blade2'),('blade3'),('blade55'),('blader'),('bladerunner'),('blades'),('blades1'),('blah'),('blah11'),('blah12'),('blah123'),('blah1234'),('blah13'),('blah22'),('blahblah'),('blahblah!'),('blahblah1'),('blahblah12'),('blahblah123'),('blahblah2'),('blahblahbl'),('blahblahblah'),('blahh1'),('blahkg321'),('blaine'),('blaine1'),('blair'),('blair1'),('blaise'),('blake'),('blake01'),('blake1'),('blake10'),('blake11'),('blake12'),('blake123'),('blake13'),('blake2'),('blake3'),('blake7'),('blakey'),('blanah'),('blanca'),('blanca1'),('blanchard'),('blanche'),('blanche1'),('blanco'),('blanco1'),('blanco10'),('blandine'),('blank'),('blank1'),('blanka'),('blanket'),('blanket1'),('blanquita'),('blarney'),('blasco'),('blast'),('blast1'),('blasted1'),('blaster'),('blaster1'),('blastoff'),('blaze'),('blaze1'),('blaze12'),('blaze123'),('blaze13'),('blaze2'),('blaze3'),('blaze420'),('blazed'),('blazed1'),('blazedup42'),('blazeit'),('blazeit420'),('blazer'),('blazer01'),('blazer1'),('blazer12'),('blazers'),('blazers1'),('blaziken'),('blazin'),('blazin1'),('blazing'),('blb'),('blbjn007'),('blbjnrf'),('blbntyf'),('blbyf'),('blbyf[eq'),('BLCKD_SA_UNPAIDFEE_OCT06'),('ble'),('bleach'),('bleach1'),('bleach12'),('bleach123'),('bleble'),('bledsoe'),('bleeding'),('bleeding1'),('blender'),('bless'),('bless1'),('blessed'),('blessed!'),('blessed01'),('blessed07'),('blessed08'),('blessed09'),('blessed1'),('blessed11'),('blessed12'),('blessed123'),('blessed2'),('blessed3'),('blessed4'),('blessed5'),('blessed7'),('blessedbe'),('blessing'),('blessing1'),('blessing12'),('blessing123'),('blessing2'),('blessings'),('blessings1'),('blessings7'),('blessme'),('blessme1'),('blessyou'),('blind'),('blind1'),('blind123'),('bling'),('bling1'),('bling123'),('blingbling'),('blink'),('blink-182'),('blink1'),('Blink123'),('Blink1234'),('blink182'),('blink183'),('blinkblink'),('blinker'),('blinkme'),('blinks'),('blinky'),('blinky1'),('bliss'),('bliss1'),('blissful'),('blister'),('blitz'),('blitz1'),('blitzen'),('blitzkrieg'),('blix729'),('blizzard'),('blizzard1'),('bljS2v85pT'),('blkdrag0ns'),('blo'),('blobby'),('block'),('block1'),('blockbuster'),('blocked'),('blockhead'),('bloemen'),('bloger01'),('blogs123'),('blomma'),('blond'),('blond1'),('blond72'),('blonda'),('blonde'),('blonde!'),('blonde1'),('blonde12'),('blonde123'),('blonde2'),('blondes'),('blondi'),('blondie'),('blondie!'),('blondie01'),('blondie1'),('blondie101'),('blondie11'),('blondie12'),('blondie123'),('blondie13'),('blondie2'),('blondie3'),('blondie69'),('blondie7'),('blondin'),('blondinka'),('blondy'),('blondy1'),('blood'),('blood1'),('blood101'),('blood11'),('blood12'),('blood123'),('blood13'),('blood14'),('blood15'),('blood2'),('blood21'),('blood22'),('blood23'),('blood3'),('blood4'),('blood4life'),('blood5'),('blood55'),('blood59'),('blood6'),('blood666'),('blood69'),('blood7'),('blood9'),('bloodbath'),('bloodbath1'),('bloodgang'),('bloodgang5'),('bloodhound'),('bloodline'),('bloodline1'),('bloodlust'),('bloodlust1'),('bloodmoney'),('bloodrayne'),('bloodred'),('bloods'),('bloods1'),('bloods5'),('bloody'),('bloody1'),('bloody5'),('bloodyhell'),('bloodymary'),('bloodz'),('bloodz1'),('bloodz5'),('bloom'),('bloom1'),('bloomfield'),('blooming'),('blossom'),('blossom1'),('blossoms'),('blow'),('blowfish'),('blowfish1'),('blowjob'),('blowjob1'),('blowjob69'),('blowjobs'),('blowme'),('blowme!'),('blowme1'),('blowme123'),('blowme2'),('blowme69'),('blu'),('blubb'),('blubber'),('blubber1'),('blue'),('blue00'),('blue01'),('blue02'),('blue03'),('blue04'),('blue05'),('blue06'),('blue07'),('blue08'),('blue09'),('blue1'),('blue10'),('blue100'),('blue101'),('blue11'),('blue12'),('blue123'),('blue1234'),('blue12345'),('blue13'),('blue14'),('blue15'),('blue16'),('blue17'),('blue18'),('blue19'),('blue20'),('blue2000'),('blue21'),('blue22'),('blue222'),('blue2222'),('blue23'),('blue24'),('blue25'),('blue26'),('blue27'),('blue28'),('blue29'),('blue30'),('blue31'),('blue32'),('blue321'),('blue33'),('blue34'),('blue42'),('blue420'),('blue43'),('blue44'),('blue45'),('blue456'),('blue47'),('blue4ever'),('blue4u'),('blue52'),('blue54'),('blue55'),('blue56'),('blue62'),('blue66'),('blue69'),('blue72'),('blue74'),('blue75'),('blue77'),('blue777'),('blue78'),('blue789'),('blue82'),('blue87'),('blue88'),('blue89'),('blue90'),('blue91'),('blue92'),('blue93'),('blue94'),('blue95'),('blue96'),('blue97'),('blue98'),('blue99'),('blueangel'),('blueangel1'),('bluearmy'),('bluebaby'),('blueballs'),('blueballs1'),('bluebear'),('bluebear1'),('bluebell'),('bluebell1'),('blueberry'),('blueberry1'),('blueberry2'),('bluebird'),('bluebird1'),('bluebird2'),('bluebirds'),('blueblue'),('blueblue1'),('blueboy'),('blueboy1'),('bluecar'),('bluecat'),('bluecat1'),('bluedevil'),('bluedevil1'),('bluedevils'),('bluedog'),('bluedog1'),('bluedragon'),('blueeyes'),('blueeyes1'),('blueeyes2'),('bluefire'),('bluefish'),('bluefish1'),('bluegill'),('bluegirl'),('bluegirl1'),('bluegrass'),('bluegrass1'),('bluegreen'),('bluegreen1'),('blueice'),('bluejay'),('bluejay1'),('bluejays'),('bluejays1'),('bluejeans'),('bluelight'),('blueline'),('bluem00n'),('blueman'),('blueman1'),('bluemonkey'),('bluemoon'),('bluemoon1'),('bluenose'),('bluenose1'),('bluenote'),('blueprint'),('blueprint1'),('bluered'),('bluerose'),('bluerose1'),('blues'),('blues1'),('blues123'),('bluesclues'),('bluesea'),('blueskies'),('bluesky'),('bluesky1'),('bluesky2'),('bluesman'),('bluesman1'),('bluestar'),('bluestar1'),('bluetooth'),('bluetooth1'),('bluewater'),('bluewater1'),('blueyes'),('blume'),('blume1'),('blumen'),('blumentopf'),('blunt'),('blunt1'),('blunt420'),('blunts'),('blunts1'),('blunts420'),('blyad_be_90'),('blythe'),('bmw'),('bmw123'),('bmw2002'),('bmw316'),('bmw318'),('bmw318i'),('bmw318is'),('bmw320'),('bmw320d'),('bmw320i'),('bmw323'),('bmw325'),('bmw325i'),('bmw325is'),('bmw328'),('bmw328i'),('bmw330'),('bmw330ci'),('bmw520'),('bmw525'),('bmw530'),('bmw540'),('bmw745'),('bmw750'),('bmwbmw'),('bmwe30'),('bmwe36'),('bmwm3gtr'),('bmx123'),('bmx4life'),('bmxbmx'),('bnbnbn'),('bnfkbz'),('bnm'),('bnm123'),('bnmbnm'),('bo1997'),('board'),('board1'),('boarder'),('boarder1'),('boarding'),('boat'),('boateng'),('boater'),('boating'),('boating1'),('boavista'),('bob'),('bob1'),('bob101'),('bob111'),('bob123'),('bob1234'),('bob12345'),('bob123456'),('bob420'),('bob666'),('bobafett'),('bobafett1'),('bobb'),('bobber'),('bobbi'),('bobbi1'),('bobbie'),('bobbie1'),('bobbin'),('bobble'),('bobbob'),('bobbob1'),('bobbob12'),('bobbob123'),('bobbobbob'),('bobby'),('bobby!'),('bobby01'),('bobby1'),('bobby10'),('bobby101'),('bobby11'),('bobby12'),('bobby123'),('bobby1234'),('bobby13'),('bobby14'),('bobby18'),('bobby2'),('bobby21'),('bobby22'),('bobby23'),('bobby3'),('bobby4'),('bobby5'),('bobby6'),('bobby69'),('bobby7'),('bobby9'),('bobbyb'),('bobbyboy'),('bobbyd'),('bobbyjack1'),('bobbyjoe'),('bobbys'),('bobbys1'),('bobcat'),('bobcat1'),('bobcat12'),('bobcats'),('bobcats1'),('bobdog'),('bobdole'),('bobdole1'),('bobdylan'),('bobdylan1'),('bobert'),('bobert1'),('bobesponja'),('bobik'),('bobina'),('bobita'),('bobmarley'),('bobmarley1'),('bobmarley2'),('bobo'),('bobo11'),('bobo12'),('bobo123'),('bobo1234'),('bobo13'),('bobo22'),('bobobo'),('bobobo1'),('bobobobo'),('bobrik'),('bobs'),('bobsaget'),('bobsaget1'),('bobsmith'),('bobster'),('bobthebuilder'),('boby'),('bocajuniors'),('bocephus'),('bocephus1'),('bochum'),('bocman'),('bodega'),('bodensee'),('bodie1'),('bodrum'),('bodyboard'),('bodyguard'),('bodyshop'),('boeing'),('boeing737'),('boeing747'),('boeing777'),('bofo100'),('bogart'),('bogart1'),('bogdan'),('bogdan1'),('bogdana'),('bogdanova'),('bogey'),('bogey1'),('boggie'),('boggie1'),('boggle'),('bogie'),('bogie1'),('bogoss'),('bogosse'),('bogota'),('bogota1'),('bogus'),('bogus1'),('Boguska123'),('bohemia'),('bohemian'),('bohica'),('boiler'),('boilers'),('boing747'),('bojana'),('bojangles'),('bojangles1'),('bokbok'),('bokkie'),('boknoy'),('bol'),('bolabola'),('bolaji'),('bolanle'),('bolatov.almaz'),('bolbol'),('bolero'),('bolinha'),('bolinhas'),('bolita'),('bolivar'),('bolivia'),('bolivia1'),('bolleke'),('bollocks'),('bollocks1'),('bollox'),('bollox1'),('bollywood'),('bolno_18035'),('bologna'),('bologna1'),('boloto'),('bolshoj_zmej'),('bolton'),('bolton1'),('boludo'),('boluwatife'),('bomb'),('bomba'),('bomba1'),('bombay'),('bombay1'),('bomber'),('bomber1'),('bomberman'),('bombero'),('bomberos'),('bombers'),('bombers1'),('bombom'),('bombom1'),('bombon'),('bombon1'),('bombshell'),('bombshell1'),('bommel'),('bon'),('bonanza'),('bonanza1'),('bonaparte'),('bonbon'),('bonbon1'),('boncuk'),('bond'),('bond0007'),('bond007'),('bondage'),('bondage1'),('bondar'),('bondarenko'),('bonds25'),('bone'),('boneca'),('bonefish'),('bonehead'),('bonehead1'),('boner'),('boner1'),('boner69'),('bones'),('bones1'),('bones123'),('bones2'),('bonethug'),('bonethug1'),('bonethugs'),('bonethugs1'),('bonfire'),('bong'),('bong420'),('bongbong'),('bonghit'),('bonghits'),('bongo'),('bongo1'),('bongos'),('bonheur'),('boniface'),('bonifacio'),('bonilla'),('bonita'),('bonita1'),('bonita12'),('bonita123'),('bonita13'),('bonita2'),('bonito'),('bonjour'),('bonjour1'),('bonjour123'),('bonjours'),('bonjovi'),('bonjovi1'),('bonkers'),('bonkers1'),('bonnechance'),('bonner'),('bonner1'),('bonneville'),('bonnie'),('bonnie01'),('bonnie1'),('bonnie10'),('bonnie11'),('bonnie12'),('bonnie123'),('bonnie13'),('bonnie2'),('bonnie3'),('bonny'),('bonny1'),('bono'),('bonobo'),('bonou2'),('bonovox'),('bonsai'),('bonsai1'),('bonsoir'),('bonus'),('bonzai'),('bonzo'),('bonzo1'),('boo'),('boo-boo'),('boo123'),('boo1234'),('boo1boo'),('boob'),('boob123'),('booba'),('boobear'),('boobear1'),('boober'),('boobie'),('boobie1'),('boobie2'),('boobies'),('boobies!'),('boobies1'),('boobies12'),('boobies123'),('boobies2'),('boobies69'),('booboo'),('booboo!'),('booboo01'),('booboo07'),('booboo08'),('booboo09'),('booboo1'),('booboo10'),('booboo11'),('booboo12'),('booboo123'),('booboo1234'),('booboo13'),('booboo14'),('booboo15'),('booboo16'),('booboo18'),('booboo2'),('booboo21'),('booboo22'),('booboo23'),('booboo3'),('booboo4'),('booboo5'),('booboo6'),('booboo69'),('booboo7'),('booboo8'),('booboo9'),('booboo99'),('booboobear'),('boobooboo'),('boobs'),('boobs!'),('boobs1'),('boobs12'),('boobs123'),('boobs2'),('boobs69'),('booby'),('booby1'),('booda1'),('booga1'),('boogaloo'),('booger'),('booger!'),('booger01'),('booger1'),('booger11'),('booger12'),('booger123'),('booger13'),('booger2'),('booger3'),('booger5'),('booger69'),('booger7'),('boogers'),('boogers1'),('boogie'),('boogie01'),('boogie1'),('boogie12'),('boogie123'),('boogie2'),('boogieman'),('boogieman1'),('boohoo'),('boohoo1'),('book'),('book12'),('book123'),('bookbook'),('booker'),('booker1'),('bookert'),('bookie'),('bookie1'),('booking'),('bookitty'),('bookmark'),('bookmark1'),('books'),('books1'),('books123'),('bookworm'),('bookworm1'),('boom'),('boom12'),('boom123'),('booman'),('booman1'),('boomboom'),('boomboom1'),('boomboom2'),('boombox'),('boomer'),('boomer01'),('boomer1'),('boomer10'),('boomer11'),('boomer12'),('boomer123'),('boomer13'),('boomer2'),('boomer22'),('boomer3'),('boomer4'),('boomer5'),('boomer7'),('boomerang'),('boomerang1'),('boondock'),('boondocks'),('boondocks1'),('boone'),('boone1'),('boonie'),('booo'),('booooo'),('booper'),('boopie'),('boosie'),('boosie1'),('boost1'),('booster'),('booster1'),('bootcamp'),('booter'),('bootie'),('bootie1'),('bootleg'),('bootleg1'),('boots'),('boots1'),('boots12'),('boots123'),('boots2'),('bootsie'),('bootsie1'),('bootsy'),('bootsy1'),('booty'),('booty1'),('booty12'),('booty123'),('booty2'),('booty3'),('booty5'),('booty69'),('bootycall'),('bootycall1'),('bootylicious'),('bootymeat1'),('booya'),('booyah'),('booyah1'),('booyaka619'),('boozer'),('boozer1'),('bopper'),('boquita'),('bor'),('borabora'),('borabora1'),('boracay'),('boragud02'),('borat1'),('borboleta'),('bordeaux'),('bordeaux33'),('border'),('borderline'),('borec123654'),('bored'),('bored1'),('bored123'),('boredom'),('borges'),('boricua'),('boricua1'),('boricua12'),('boricua123'),('boricua2'),('boricua21'),('boricua7'),('boring'),('boring1'),('boriqua'),('boriqua1'),('boris'),('boris1'),('boris123'),('boriska'),('borismf5tsh'),('borisov'),('borisova'),('boriss'),('borland'),('borman'),('born2die'),('born2kill'),('born2run'),('born2win'),('bornagain'),('borneo'),('bornfree'),('borntorun'),('borntowin'),('boroda'),('boromir'),('boromirus'),('borracho'),('borrego'),('borris'),('borussia'),('borussia09'),('bos'),('bosco'),('bosco1'),('bosco123'),('boscoe'),('bosley'),('bosna1'),('bosnia'),('bosox1'),('boss'),('boss01'),('boss11'),('boss12'),('boss123'),('boss1234'),('boss13'),('boss167'),('boss22'),('boss23'),('boss302'),('boss429'),('boss74'),('bossbitch1'),('bossboss'),('bosshog'),('bosshog1'),('bosshogg'),('bosslady'),('bosslady1'),('bossman'),('bossman1'),('bossss'),('bossy1'),('boston'),('boston01'),('boston04'),('boston07'),('boston08'),('boston1'),('boston10'),('boston11'),('boston12'),('boston123'),('boston13'),('boston2'),('boston21'),('boston22'),('boston23'),('boston24'),('boston3'),('boston33'),('boston34'),('boston4'),('boston5'),('boston617'),('boston69'),('boston7'),('boswell'),('botafogo'),('botany'),('botas76'),('botbot'),('botswana'),('bottle'),('bottle1'),('bottom'),('bottom1'),('bou'),('bouba'),('boubou'),('boubou1'),('bouboule'),('boucher'),('bouchon'),('bouchra'),('bouddha'),('boudin'),('boulanger'),('boulder'),('boulder1'),('boulet'),('boulette'),('boulevard'),('boulogne'),('boulot'),('boulou'),('bounce'),('bounce1'),('bouncer'),('bouncer1'),('bounty'),('bounty1'),('bourbon'),('bourbon1'),('bourne'),('boutique'),('bouvier'),('bovine'),('bowbow'),('bowers'),('bowhunter'),('bowhunter1'),('bowie'),('bowie1'),('bowl300'),('bowler'),('bowler1'),('bowling'),('bowling1'),('bowling300'),('bowman'),('bowman1'),('bowser'),('bowser1'),('bowtie'),('bowwow'),('bowwow1'),('bowwow11'),('bowwow12'),('bowwow123'),('bowwow13'),('bowwow2'),('bowwow3'),('bowwow4'),('bowwow5'),('bowwow7'),('box123'),('boxcar'),('boxer'),('boxer1'),('boxer123'),('boxerdog'),('boxers'),('boxers1'),('boxing'),('boxing1'),('boxing123'),('boxster'),('boxter'),('boy'),('boy123'),('boy1234'),('boy12345'),('boy123456'),('boyboy'),('boyboy1'),('boycrazy'),('boycrazy1'),('boyfriend'),('boyfriend1'),('boyfriend2'),('boylover'),('boylover1'),('boys'),('boys101'),('boys12'),('boys123'),('boys2men'),('boyscout'),('boysoverfl'),('boyssuck'),('boyssuck1'),('boytoy'),('boytoy1'),('boyz'),('boyz123'),('boyz2men'),('boyzone'),('bozena'),('bozkurt'),('bozo'),('bpvtyf'),('BqkTqqN844'),('BqkTrqN844'),('bqLk8kx79U'),('br'),('br00ke'),('br00klyn'),('br00tal'),('br0ken'),('br123456'),('br1ttany'),('br549'),('br5490'),('br5499'),('bra'),('brabus'),('braceface1'),('bracelet'),('braces'),('bracken'),('bracken1'),('brad'),('brad12'),('brad123'),('brad1234'),('braden'),('braden1'),('bradford'),('bradford1'),('bradipo'),('bradley'),('bradley01'),('bradley1'),('bradley11'),('bradley12'),('bradley123'),('bradley2'),('bradley3'),('bradley4'),('bradley5'),('bradley7'),('bradly'),('bradly1'),('bradpitt'),('bradpitt1'),('bradshaw'),('brady'),('brady1'),('brady12'),('brady123'),('braeden'),('braeden1'),('brahim'),('brahma'),('brain'),('brain1'),('braindead'),('brainiac'),('brains'),('brains1'),('brainstorm'),('bramble'),('bramble1'),('Brammi1'),('branca'),('branch'),('branco'),('brand'),('brand0n'),('brand1'),('brandee'),('branden'),('branden1'),('brandi'),('brandi1'),('brandi12'),('brandi123'),('brandi2'),('brandie'),('brandie1'),('brandnew'),('brandnew1'),('brando'),('brando1'),('brandon'),('brandon!'),('brandon.'),('brandon0'),('brandon00'),('brandon01'),('brandon02'),('brandon03'),('brandon04'),('brandon05'),('brandon06'),('brandon07'),('brandon08'),('brandon09'),('brandon1'),('brandon10'),('brandon101'),('brandon11'),('brandon12'),('brandon123'),('brandon13'),('brandon14'),('brandon15'),('brandon16'),('brandon17'),('brandon18'),('brandon19'),('brandon2'),('brandon20'),('brandon21'),('brandon22'),('brandon23'),('brandon24'),('brandon25'),('brandon27'),('brandon3'),('brandon4'),('brandon5'),('brandon6'),('brandon69'),('brandon7'),('brandon8'),('brandon88'),('brandon9'),('brandon98'),('brandon99'),('brandonlee'),('brandt'),('brandy'),('brandy01'),('brandy1'),('brandy10'),('brandy11'),('brandy12'),('brandy123'),('brandy13'),('brandy2'),('brandy21'),('brandy22'),('brandy23'),('brandy3'),('brandy5'),('brandy69'),('brandy7'),('branko'),('branson'),('branson1'),('brasil'),('brasil1'),('brasil10'),('brasil12'),('brasil123'),('brasile'),('brasileiro'),('brasilia'),('brasilien'),('brasov'),('brat'),('brat12'),('brat123'),('bratan'),('bratislava'),('bratty'),('bratty1'),('bratva'),('bratwurst'),('bratz'),('bratz1'),('bratz10'),('bratz11'),('bratz12'),('bratz123'),('bratz2'),('bratz9'),('braulio'),('brave'),('brave1'),('braveheart'),('braves'),('braves1'),('braves10'),('braves11'),('braves12'),('braves25'),('braves95'),('bravo'),('bravo1'),('bravo123'),('braxton'),('braxton1'),('brayan'),('brayan1'),('brayden'),('brayden08'),('brayden1'),('brayden2'),('brayden3'),('braydon'),('braydon1'),('brazil'),('brazil1'),('brazil10'),('brazil123'),('brazilia'),('brazzers'),('bre'),('bre123'),('bread'),('bread1'),('bread123'),('break'),('break1'),('breakdance'),('breakdown'),('breakdown1'),('breaker'),('breaker1'),('breakers'),('breakfast'),('breakfast1'),('breaking'),('breana'),('breana1'),('breanna'),('breanna1'),('breanna12'),('breanna123'),('breanna2'),('breanna3'),('breanne'),('breanne1'),('breast'),('breasts'),('breath'),('breathe'),('breathe1'),('brebre'),('brebre1'),('brebre12'),('brebre123'),('bree'),('bree06'),('bree123'),('breebree'),('breebree1'),('breeze'),('breeze1'),('breezer'),('breezy'),('breezy1'),('breitling'),('breizh'),('bremen'),('brenda'),('brenda01'),('brenda1'),('brenda10'),('brenda11'),('brenda12'),('brenda123'),('brenda13'),('brenda14'),('brenda15'),('brenda2'),('brenda3'),('brenda69'),('brenda7'),('brendan'),('brendan1'),('brenden'),('brenden1'),('brendon'),('brendon1'),('brenna'),('brenna1'),('brennan'),('brennan1'),('brennen'),('brennen1'),('brenner'),('brent'),('brent1'),('brent123'),('brentford'),('brenton'),('brenton1'),('brentwood'),('brentwood1'),('breonna1'),('brescia'),('bresil'),('bretagne'),('brethart'),('breton'),('brett'),('brett1'),('brett123'),('brett4'),('brewer'),('brewer1'),('brewers'),('brewers1'),('brewster'),('brewster1'),('bri'),('bri123'),('brian'),('brian!'),('brian01'),('brian07'),('brian08'),('brian1'),('brian10'),('brian11'),('brian12'),('brian123'),('brian1234'),('brian13'),('brian14'),('brian15'),('brian18'),('brian2'),('brian21'),('brian22'),('brian23'),('brian3'),('brian4'),('brian5'),('brian6'),('brian69'),('brian7'),('briana'),('briana1'),('briana12'),('briana123'),('briana2'),('brianna'),('brianna!'),('brianna01'),('brianna06'),('brianna07'),('brianna08'),('brianna09'),('brianna1'),('brianna10'),('brianna11'),('brianna12'),('brianna123'),('brianna13'),('brianna14'),('brianna2'),('brianna23'),('brianna3'),('brianna4'),('brianna5'),('brianna6'),('brianna7'),('brianna8'),('brianna9'),('brianne'),('brianne1'),('brians'),('bribri'),('bribri1'),('bribri12'),('bribri123'),('brice'),('brice1'),('briciola'),('brick'),('brick1'),('bricks'),('bricks1'),('bricksquad'),('bridge'),('bridge1'),('bridges'),('bridget'),('bridget1'),('bridgett'),('bridgette'),('bridgette1'),('bridie'),('brielle'),('brielle1'),('brigada'),('brigade'),('brigadeiro'),('briggs'),('bright'),('bright1'),('brighteyes'),('brighton'),('brighton1'),('brigida'),('brigitta'),('brigitte'),('brigitte1'),('brijesh'),('brille'),('brilliant'),('brilliant1'),('brillo'),('brina1'),('brinchen23'),('brindisi'),('brindle'),('bringit'),('bringiton'),('bringiton1'),('brinkley'),('briones'),('brisbane'),('brisbane1'),('brisingr'),('bristol'),('bristol1'),('brit'),('brit123'),('britain'),('britany'),('britbrat1'),('british'),('british1'),('britney'),('britney1'),('britney123'),('britney2'),('britneys'),('britneyspears'),('britni'),('britt'),('britt07'),('britt08'),('britt09'),('britt1'),('britt11'),('britt12'),('britt123'),('britt13'),('britt14'),('britt15'),('britt16'),('britt2'),('britt5'),('britta'),('brittani'),('brittani1'),('brittany'),('brittany!'),('brittany.'),('brittany01'),('brittany07'),('brittany08'),('brittany09'),('brittany1'),('brittany10'),('brittany11'),('brittany12'),('brittany13'),('brittany14'),('brittany15'),('brittany16'),('brittany17'),('brittany18'),('brittany19'),('brittany2'),('brittany20'),('brittany21'),('brittany22'),('brittany23'),('brittany3'),('brittany4'),('brittany5'),('brittany6'),('brittany69'),('brittany7'),('brittany8'),('brittany9'),('brittney'),('brittney1'),('brittney12'),('brittney2'),('brittni'),('britton'),('britton1'),('britty'),('britty1'),('brizet07'),('brm600'),('brn521'),('bro'),('bro123'),('bro3886'),('broadband'),('broadband1'),('broadway'),('broadway1'),('broccoli'),('brock'),('brock1'),('brodie'),('brodie1'),('Brodie10'),('brody'),('brody1'),('brody123'),('brogan'),('broke1'),('broken'),('broken!'),('broken1'),('broken12'),('broken123'),('broken13'),('broken2'),('broken3'),('brokencyde'),('brokenhear'),('brokenheart'),('broker'),('broker1'),('bronco'),('bronco1'),('bronco2'),('broncos'),('broncos07'),('broncos1'),('broncos12'),('broncos2'),('broncos24'),('broncos7'),('bronson'),('bronson1'),('bronte'),('bronte1'),('brontolo'),('bronwyn'),('bronx'),('bronx1'),('bronx718'),('bronze'),('bronze1'),('bronzewing'),('broodwar'),('brook'),('brook1'),('brook123'),('brooke'),('brooke!'),('brooke01'),('brooke06'),('brooke07'),('brooke08'),('brooke09'),('brooke1'),('brooke10'),('brooke11'),('brooke12'),('brooke123'),('brooke13'),('brooke14'),('brooke15'),('brooke2'),('brooke21'),('brooke22'),('brooke23'),('brooke3'),('brooke4'),('brooke5'),('brooke7'),('brookie'),('brookie1'),('brooklin'),('brooklyn'),('brooklyn!'),('brooklyn01'),('brooklyn07'),('brooklyn08'),('brooklyn09'),('brooklyn1'),('brooklyn10'),('brooklyn11'),('brooklyn12'),('brooklyn13'),('brooklyn2'),('brooklyn21'),('brooklyn22'),('brooklyn23'),('brooklyn3'),('brooklyn4'),('brooklyn5'),('brooklyn6'),('brooklyn7'),('brooklyn71'),('brooklynn'),('brooklynn1'),('brooks'),('brooks1'),('brookside'),('broomfield'),('bros4life'),('brosb4hoes'),('brother'),('brother1'),('brother12'),('brother123'),('brother2'),('brother3'),('brother4'),('brotherhood'),('brothers'),('brothers1'),('brothers2'),('brothers3'),('broucek'),('brown'),('brown1'),('brown11'),('brown12'),('brown123'),('brown13'),('brown2'),('brown22'),('brown23'),('brown3'),('brown5'),('brown7'),('brownbear'),('browncow'),('browndog'),('browndog1'),('browne'),('browneyes'),('browneyes1'),('browneyes2'),('brownie'),('brownie1'),('brownie12'),('brownie123'),('brownie2'),('brownie3'),('brownies'),('brownies1'),('browning'),('browning1'),('brownpride'),('browns'),('browns1'),('brownsuga1'),('brownsugar'),('browny'),('browny1'),('browser'),('bru'),('bruce'),('bruce1'),('bruce123'),('bruce2'),('brucelee'),('brucelee1'),('brucewayne'),('bruder'),('bruins'),('bruins1'),('bruins77'),('bruiser'),('bruiser1'),('brujita'),('bruna'),('brunette'),('brunette1'),('bruninha'),('bruninho'),('brunito'),('bruno'),('bruno01'),('bruno1'),('bruno10'),('bruno12'),('bruno123'),('bruno2'),('brunomars'),('brunos'),('brunswick'),('brunswick1'),('brussels'),('brutal'),('brutal1'),('brutis'),('brutis1'),('brutus'),('brutus01'),('brutus1'),('brutus11'),('brutus12'),('brutus123'),('brutus2'),('bruxelles'),('bruxinha'),('bryan'),('bryan01'),('bryan1'),('bryan11'),('bryan12'),('bryan123'),('bryan13'),('bryan2'),('bryan22'),('bryan23'),('bryan3'),('bryan5'),('bryanna'),('bryanna1'),('bryant'),('bryant08'),('bryant1'),('bryant24'),('bryant8'),('bryce'),('bryce1'),('bryce123'),('bryony'),('bryson'),('bryson1'),('bs1234'),('bscirc'),('bsd'),('BsXXbGs322'),('bub'),('buba'),('bubamara'),('bubba'),('bubba!'),('bubba01'),('bubba07'),('bubba08'),('bubba09'),('bubba1'),('bubba10'),('bubba101'),('bubba11'),('bubba12'),('bubba123'),('bubba1234'),('bubba13'),('bubba14'),('bubba15'),('bubba16'),('bubba2'),('bubba21'),('bubba22'),('bubba23'),('bubba24'),('bubba3'),('bubba4'),('bubba5'),('bubba6'),('bubba69'),('bubba7'),('bubba8'),('bubba9'),('bubba99'),('bubbadog'),('bubbagump'),('bubbagump1'),('bubbas'),('bubbas1'),('bubbie'),('bubbie1'),('bubbl3s'),('bubble'),('bubble!'),('bubble01'),('bubble1'),('bubble11'),('bubble12'),('bubble123'),('bubble2'),('bubble3'),('bubble5'),('bubble7'),('bubblebutt'),('bubblegum'),('bubblegum!'),('bubblegum1'),('bubblegum2'),('bubblegum3'),('bubblegum5'),('bubblegum7'),('bubblegum9'),('bubbles'),('bubbles!'),('bubbles.'),('bubbles0'),('bubbles01'),('bubbles07'),('bubbles08'),('bubbles09'),('bubbles1'),('bubbles10'),('bubbles101'),('bubbles11'),('bubbles12'),('bubbles123'),('bubbles13'),('bubbles14'),('bubbles15'),('bubbles16'),('bubbles17'),('bubbles18'),('bubbles2'),('bubbles21'),('bubbles22'),('bubbles23'),('bubbles24'),('bubbles3'),('bubbles4'),('bubbles5'),('bubbles6'),('bubbles69'),('bubbles7'),('bubbles8'),('bubbles88'),('bubbles9'),('bubbles99'),('bubblez'),('bubblez1'),('bubbly'),('bubbly1'),('bubby'),('bubby1'),('bubby123'),('bublik'),('bubluk'),('bubu'),('bubu123'),('bububu'),('bubububu'),('bubuka'),('bubulina'),('bubulle'),('buburuza'),('buccaneers'),('buceta'),('buchanan'),('buck'),('buck12'),('buck123'),('buckaroo'),('bucket'),('bucket1'),('buckethead'),('buckeye'),('buckeye1'),('buckeyes'),('buckeyes1'),('buckfast'),('buckie'),('buckingham'),('buckley'),('buckley1'),('buckmaster'),('bucks'),('bucks1'),('buckshot'),('buckshot1'),('buckwheat'),('buckwheat1'),('bucky'),('bucky1'),('bucuresti'),('bud'),('bud123'),('bud420'),('budala'),('budapest'),('budapest1'),('budbud'),('budda'),('budda1'),('buddah'),('buddah1'),('buddha'),('buddha1'),('buddie'),('buddie1'),('buddies'),('buddies1'),('buddy'),('buddy!'),('buddy01'),('buddy02'),('buddy05'),('buddy06'),('buddy07'),('buddy08'),('buddy09'),('buddy1'),('buddy10'),('buddy101'),('buddy11'),('buddy111'),('buddy12'),('buddy123'),('buddy1234'),('buddy12345'),('buddy13'),('buddy14'),('buddy15'),('buddy16'),('buddy17'),('buddy18'),('buddy2'),('buddy21'),('buddy22'),('buddy23'),('buddy24'),('buddy3'),('buddy4'),('buddy5'),('buddy6'),('buddy69'),('buddy7'),('buddy77'),('buddy8'),('buddy88'),('buddy9'),('buddy99'),('buddyboy'),('buddyboy1'),('buddycat'),('buddydog'),('buddydog1'),('buddyholly'),('buddylee'),('buddylove'),('buddylove1'),('buddys'),('buddys1'),('budget'),('budgie'),('budlight'),('budlight1'),('budlight12'),('budlight2'),('budlight3'),('budlight69'),('budlite'),('budlite1'),('budman'),('budman1'),('budweiser'),('budweiser1'),('budweiser2'),('budweiser8'),('budwiser'),('buenavista'),('buenos'),('buenosaires'),('bufalo'),('buffalo'),('buffalo1'),('buffalo2'),('buffalo66'),('buffer'),('buffet'),('buffett'),('buffett1'),('buffie'),('buffon'),('buffy'),('buffy1'),('buffy12'),('buffy123'),('buffy2'),('buffys'),('buford'),('buford1'),('bug'),('bug123'),('bugaboo'),('bugaboo1'),('bugaga'),('bugatti'),('bugatti1'),('bugbug'),('bugbug1'),('bugger'),('bugger1'),('buggie'),('buggie1'),('buggy'),('buggy1'),('bugman'),('bugmenot'),('bugs'),('bugsbunny'),('bugsbunny1'),('bugsbunny2'),('bugsy'),('bugsy1'),('buheirf'),('buick'),('buick1'),('builder'),('builder1'),('building'),('bujhm'),('bujhtr'),('bukkake'),('buknoy'),('bukola'),('bukowski'),('bul'),('BUL5Tacumi'),('bulacan'),('bulaklak'),('bulbul'),('buldog'),('bulgakov'),('bulgaria'),('bulgaria1'),('bulilit'),('bulka-a-shah'),('bull'),('bull123'),('bulldawg'),('bulldog'),('bulldog1'),('bulldog10'),('bulldog11'),('bulldog12'),('bulldog123'),('bulldog13'),('bulldog2'),('bulldog21'),('bulldog22'),('bulldog23'),('bulldog3'),('bulldog4'),('bulldog5'),('bulldog6'),('bulldog69'),('bulldog7'),('bulldog8'),('bulldog9'),('bulldogs'),('bulldogs!'),('bulldogs08'),('bulldogs09'),('bulldogs1'),('bulldogs10'),('bulldogs11'),('bulldogs12'),('bulldogs13'),('bulldogs2'),('bulldogs3'),('bulldogs5'),('bulldogs7'),('bulldozer'),('bulldozer1'),('buller'),('bullet'),('bullet1'),('bullet12'),('bullet123'),('bullet13'),('bullet2'),('bullet695'),('bullet83'),('bulletproof'),('bullets'),('bullets1'),('bullfrog'),('bullfrog1'),('bullhead'),('bullit'),('bullock'),('bullrider'),('bullrider1'),('bulls'),('bulls1'),('bulls23'),('bullseye'),('bullseye1'),('bullsh1t'),('bullshit'),('bullshit!'),('bullshit1'),('bullshit12'),('bullshit2'),('bullshit3'),('bullshit69'),('bullshit7'),('bullwinkle'),('bully'),('bully1'),('bum'),('bumble'),('bumble1'),('bumblebee'),('bumblebee1'),('bumblebee2'),('bumbum'),('bumbum1'),('bumerang'),('bumfluff'),('bumhole'),('bumhole1'),('bummer'),('bummer1'),('bumper'),('bumper1'),('bun'),('bunbun'),('bunbun1'),('bunbury'),('bunda'),('bundeswehr'),('bundy'),('bundy1'),('bunga'),('bungalow'),('bungee'),('bunghole'),('bunghole1'),('bungie'),('bungle'),('bunker'),('bunker1'),('bunky1'),('bunnie'),('bunnie1'),('bunnies'),('bunnies1'),('bunnies2'),('bunny'),('bunny!'),('bunny01'),('bunny1'),('bunny10'),('bunny101'),('bunny11'),('bunny12'),('bunny123'),('bunny13'),('bunny14'),('bunny2'),('bunny21'),('bunny22'),('bunny23'),('bunny3'),('bunny4'),('bunny5'),('bunny6'),('bunny69'),('bunny7'),('bunny8'),('bunny9'),('bunnyboo'),('bunnyboo1'),('bunnyhop'),('bunnyrabbit'),('bunnys'),('bunnys1'),('bunso'),('bunty'),('buongiorno'),('bur'),('burak'),('burak123'),('buratino'),('burbank'),('burberry'),('burberry1'),('burbuja'),('burchenkovi'),('bureau'),('burger'),('burger1'),('burgerking'),('burgers'),('burgess'),('burgess1'),('burgos'),('burgundy'),('burhan'),('burlington'),('burn'),('burner'),('burning'),('burning1'),('burnley'),('burnley1'),('burnout'),('burnout1'),('burnout3'),('burns'),('burnside'),('burrito'),('burrito1'),('bursaspor'),('burton'),('burton1'),('burton12'),('burton123'),('burton13'),('burunduk'),('burzum'),('bus'),('busayo'),('busdriver'),('busdriver1'),('bush'),('bush25'),('bushido'),('bushido1'),('bushido123'),('bushido7'),('bushman'),('bushra'),('business'),('business1'),('business12'),('business123'),('businka'),('busola'),('busta1'),('bustamante'),('busted'),('busted!'),('busted1'),('busted123'),('busted2'),('busted4'),('buster'),('buster!'),('buster.'),('buster00'),('buster01'),('buster02'),('buster05'),('buster06'),('buster07'),('buster08'),('buster09'),('buster1'),('buster10'),('buster101'),('buster11'),('buster12'),('buster123'),('buster1234'),('buster13'),('buster14'),('buster15'),('buster16'),('buster17'),('buster18'),('buster2'),('buster21'),('buster22'),('buster23'),('buster24'),('buster25'),('buster3'),('buster33'),('buster4'),('buster44'),('buster5'),('buster55'),('buster6'),('buster69'),('buster7'),('buster77'),('buster8'),('buster88'),('buster9'),('buster99'),('busterboy'),('busterbrown'),('busterdog'),('busybee'),('but'),('butch'),('butch1'),('butch123'),('butcher'),('butcher1'),('butchie'),('butchie1'),('butchy'),('buterfly'),('buterfly1'),('buthead'),('buthead1'),('buthole1'),('butkus'),('butler'),('butler1'),('butt'),('butt12'),('butt123'),('butt3rfly'),('butta1'),('buttbutt'),('buttbutt1'),('buttcrack1'),('butter'),('butter!'),('butter01'),('butter1'),('butter11'),('butter12'),('butter123'),('butter13'),('butter2'),('butter22'),('butter3'),('butter4'),('butter44'),('butter5'),('butter7'),('butter8'),('butterball'),('butterbean'),('buttercup'),('buttercup!'),('buttercup0'),('buttercup1'),('buttercup2'),('buttercup3'),('buttercup5'),('buttercup7'),('buttercup9'),('butterfing'),('butterfinger'),('butterfl'),('butterflie'),('butterflies'),('butterfly'),('butterfly!'),('butterfly.'),('butterfly0'),('butterfly1'),('butterfly12'),('butterfly123'),('butterfly2'),('butterfly3'),('butterfly4'),('butterfly5'),('butterfly6'),('butterfly7'),('butterfly8'),('butterfly9'),('butterflys'),('buttermilk'),('butternut'),('butters'),('butters1'),('butterscotch'),('buttface'),('buttface1'),('buttfuck'),('buttfuck1'),('butthead'),('butthead1'),('butthead12'),('butthead2'),('butthole'),('butthole1'),('butthole2'),('buttman'),('buttmunch'),('buttmunch1'),('button'),('button1'),('buttonquail'),('buttons'),('buttons1'),('buttons123'),('buttons2'),('buttplug'),('butts'),('buttsex'),('buttsex1'),('buttsex69'),('buxton'),('buzhidao'),('buzz'),('buzz123'),('buzzard'),('buzzard1'),('buzzbuzz'),('buzzer'),('buzzy1'),('bv123'),('bvb1909'),('bvgthbz'),('bvgthfnjh'),('bvp33W7epU'),('bwFq23jp7F'),('bwFqjpF'),('byabybnb'),('byajhvfnbrf'),('byakugan'),('bycnbnen'),('bye123'),('byebye'),('byebye1'),('bynthytn'),('bypass'),('byron'),('byron1'),('byteme'),('bytheway'),('bytopmcd'),('Byusdg23'),('byyjxrf'),('c'),('c.ronaldo'),('c.ronaldo7'),('c00kie'),('c00kies'),('c00per'),('c0c0nut'),('c0cac0la'),('c0ffee'),('c0l0rad0'),('c0mput3r'),('c0mputer'),('c0nn0r'),('c0raplok'),('c0urtney'),('c11111'),('c111111'),('c123123'),('c12345'),('c123456'),('c1234567'),('c12345678'),('c123456789'),('c1c2c3'),('c2h5oh'),('c3por2d2'),('c43qpul5RZ'),('c44n6vijfc'),('c44n6vijgc'),('c54p7uikgb'),('c654321'),('c6DjvmsKCx'),('c6h12o6'),('c7777777'),('c9p5au8naa'),('ca'),('ca1234'),('ca123456'),('cab'),('caballero'),('caballero1'),('caballo'),('caballo1'),('caballos'),('cabana'),('cabaret'),('cabbage'),('cabbage1'),('cabbage95'),('cabbages'),('cabelo'),('cabernet'),('cabeza'),('cabezon'),('cabinet'),('cable'),('cable1'),('cableguy'),('caboose'),('caboose1'),('caboverde'),('cabowabo'),('cabral'),('cabrera'),('cabrera1'),('cabrio'),('cabriolet'),('cabron'),('cabron1'),('cabrones'),('cac'),('caca'),('caca11'),('caca12'),('caca123'),('caca1234'),('caca13'),('caca22'),('cacaboudin'),('cacaca'),('cacaca1'),('cacacaca'),('cacahuate'),('cacahuete'),('cacamaca'),('cacapipi'),('cacat123'),('cacatua'),('cacca'),('caccola'),('caceres'),('cachito'),('cachondo'),('cachorra'),('cachorro'),('cachorro1'),('cachou'),('cacique'),('cactus'),('cactus1'),('cad'),('cadbury'),('cadbury1'),('caddie'),('caddy'),('caddy1'),('cadeau'),('caden'),('caden1'),('cadence'),('cadence1'),('cadets'),('cadillac'),('cadillac1'),('caesar'),('caesar1'),('cafemom'),('caffeine'),('cagada'),('cagayan'),('cagiva'),('cagliari'),('cagney'),('cagnolino'),('cahaya'),('caiden'),('caiden1'),('caillou'),('caitlin'),('caitlin1'),('caitlin12'),('caitlin123'),('caitlin2'),('caitlyn'),('caitlyn1'),('cajun1'),('cake'),('cake12'),('cake123'),('cakes'),('cakes1'),('cal'),('cal123'),('calabaza'),('calabria'),('calais'),('calamar'),('calamaro'),('calamity'),('calavera'),('calcio'),('calculator'),('calculus'),('calcutta'),('calderon'),('calderon1'),('caldwell'),('caldwell1'),('caleb'),('caleb01'),('caleb1'),('caleb12'),('caleb123'),('caleb2'),('caleb3'),('caledonia'),('calendar'),('calendar1'),('calendario'),('calender'),('calgary'),('calgary1'),('calhoun'),('calhoun1'),('cali'),('cali11'),('cali12'),('cali123'),('cali1234'),('cali13'),('cali14'),('cali22'),('cali4nia'),('caliban'),('caliber'),('calibra'),('calibra1'),('calico'),('calico1'),('caliente'),('caliente1'),('califas1'),('califas13'),('california'),('california1'),('californication'),('caligirl'),('caligirl1'),('caligula'),('calilove1'),('calimero'),('calimero1'),('caline'),('calinou'),('calipso'),('calista'),('call'),('call911'),('callahan'),('callan'),('callas'),('callaway'),('callaway1'),('calle13'),('callie'),('callie01'),('callie1'),('callie11'),('callie12'),('callie123'),('callie2'),('calling'),('calliope'),('callista'),('callisto'),('callme'),('callme1'),('callofduty'),('callofduty1'),('callofduty2'),('callofduty4'),('callum'),('callum01'),('callum1'),('callum12'),('callum123'),('calogero'),('calore'),('calvary'),('calvary1'),('calvert'),('calvin'),('calvin01'),('calvin1'),('calvin11'),('calvin12'),('calvin123'),('calvin2'),('calvin23'),('calypso'),('calypso1'),('cam'),('cam123'),('camacho'),('camacho1'),('camaleon'),('camaleonte'),('camara'),('camara1'),('camaro'),('camaro01'),('camaro1'),('camaro123'),('camaro2'),('camaro67'),('camaro68'),('camaro69'),('camaro95'),('camaro99'),('camaron'),('camaross'),('camaroz28'),('cambiami'),('cambodia'),('cambodia1'),('cambria'),('cambria1'),('cambridge'),('cambridge1'),('camcam'),('camcam1'),('camden'),('camden1'),('camel'),('camel1'),('camel123'),('camel232'),('cameleon'),('camelia'),('camello'),('camelo'),('camelot'),('camelot1'),('camels'),('camels1'),('cameltoe'),('cameltoe1'),('camer0n'),('camera'),('camera1'),('camera12'),('camera123'),('camero'),('camero1'),('cameron'),('cameron!'),('cameron01'),('cameron02'),('cameron03'),('cameron04'),('cameron05'),('cameron06'),('cameron07'),('cameron08'),('cameron09'),('cameron1'),('cameron10'),('cameron11'),('cameron12'),('cameron123'),('cameron13'),('cameron14'),('cameron15'),('cameron2'),('cameron21'),('cameron22'),('cameron23'),('cameron3'),('cameron4'),('cameron5'),('cameron6'),('cameron7'),('cameron8'),('cameron9'),('cameron99'),('cameroon'),('cameroun'),('camila'),('camila01'),('camila1'),('camila10'),('camila12'),('camila123'),('camile'),('camilita'),('camilla'),('camilla1'),('camille'),('camille1'),('camille2'),('camille22'),('camillo'),('camilo'),('camilo1'),('camilo123'),('camino'),('camion'),('camisa'),('cammello'),('cammie'),('cammie1'),('cammy1'),('camomilla'),('camp'),('campana'),('campanile'),('campanilla'),('campanita'),('campanita1'),('campari'),('campbell'),('campbell1'),('campeon'),('campeon1'),('campeones'),('camper'),('camper1'),('campinas'),('camping'),('camping1'),('campion'),('campione'),('campioni'),('campos'),('campos1'),('camprock'),('camprock1'),('campus'),('camron'),('camron1'),('camry1'),('camryn'),('camryn1'),('can'),('can123'),('canaan'),('canabis'),('canabis1'),('canada'),('canada01'),('canada1'),('canada10'),('canada11'),('canada12'),('canada123'),('canada13'),('canada2'),('canada99'),('canadian'),('canadian1'),('canadien'),('canadiens'),('canaille'),('canard'),('canarias'),('canarino'),('canario'),('canary'),('canberra'),('cancan'),('cancan1'),('cancel'),('cancel1'),('cancer'),('cancer1'),('cancer12'),('cancer123'),('cancer13'),('cancer2'),('cancer22'),('cancer69'),('cancer7'),('cancerian'),('cancro'),('cancun'),('cancun1'),('candace'),('candace1'),('canddcard1'),('candela'),('candela1'),('candelaria'),('candi'),('candi1'),('candice'),('candice1'),('candice123'),('candida'),('candide'),('candido'),('candie'),('candie1'),('candies'),('candies1'),('candle'),('candle1'),('candles'),('candles1'),('candra'),('candy'),('candy!'),('candy01'),('candy07'),('candy08'),('candy09'),('candy1'),('candy10'),('candy101'),('candy11'),('candy12'),('candy123'),('candy1234'),('candy13'),('candy14'),('candy15'),('candy16'),('candy17'),('candy18'),('candy2'),('candy21'),('candy22'),('candy23'),('candy24'),('candy25'),('candy3'),('candy4'),('candy5'),('candy55'),('candy6'),('candy69'),('candy7'),('candy77'),('candy8'),('candy9'),('candyapple'),('candyass'),('candybar'),('candybar1'),('candycandy'),('candycane'),('candycane1'),('candycane2'),('candyfloss'),('candygirl'),('candygirl1'),('candygirl2'),('candygurl1'),('candyland'),('candyland1'),('candyman'),('candyman1'),('candys'),('candys1'),('candyshop'),('candyshop1'),('cane'),('canela'),('canela1'),('canelita'),('canelle'),('canelo'),('canes'),('canes1'),('caneta'),('cangrejo'),('cangri1'),('canguro'),('canibal'),('canine'),('canito'),('cannabis'),('cannabis1'),('cannavaro'),('cannelle'),('cannes'),('cannibal'),('cannibal1'),('cannon'),('cannon1'),('cannonball'),('cannondale'),('canon'),('canon1'),('canon123'),('cantante'),('canterbury'),('cantik'),('cantik1'),('canton'),('canton1'),('cantona'),('cantona07'),('cantona1'),('cantona7'),('cantor'),('canuck'),('canucks'),('canucks1'),('canuto'),('canvas'),('canyon'),('canyon1'),('caocao'),('caonima'),('caonima123'),('cap'),('cap123'),('CAPA'),('CAPA2008'),('capcom'),('capcom1'),('capecod'),('capecod1'),('capella'),('capello'),('capetown'),('capetown1'),('capitaine'),('capital'),('capital1'),('capitals'),('capitals11'),('capitan'),('capitan1'),('capitano'),('capitol'),('capoeira'),('capoeira1'),('capone'),('capone1'),('cappuccino'),('cappy1'),('capri'),('capri1'),('caprice'),('caprice1'),('capricho'),('capricon'),('capricorn'),('capricorn1'),('capricorn2'),('capricorn7'),('capricorne'),('capricorni'),('capricornio'),('capricorno'),('caprisun1'),('capslock'),('capslock1'),('capsule'),('captain'),('captain1'),('captain2'),('captiva'),('capucine'),('capullo'),('car'),('car0line'),('car123'),('car1234'),('cara'),('cara4coM'),('carabinieri'),('caracas'),('caracas1'),('caracol'),('caracola'),('caracoles'),('caraculo'),('carajo'),('carajo1'),('caralho'),('caralho1'),('caramail'),('caramba'),('carambar'),('carambola'),('caramel'),('caramel1'),('caramelito'),('caramella'),('caramelle'),('caramelo'),('caramelo1'),('caravaggio'),('caravan'),('caravan1'),('carbon'),('carbon1'),('carbon12'),('carbone'),('carcar'),('carcar1'),('carcass'),('cardenas'),('cardenas1'),('cardiac'),('cardiff'),('cardiff1'),('cardigan'),('cardinal'),('cardinal1'),('cardinals'),('cardinals1'),('cardinals2'),('cardinals5'),('cardio'),('cardona'),('cardoso'),('cards'),('cards1'),('care'),('carebear'),('carebear1'),('carebear12'),('carebear2'),('carebear3'),('carebears'),('carebears1'),('carebears2'),('careca'),('career'),('career1'),('career121'),('careers'),('carefree'),('careful'),('caregiver'),('careless'),('caren'),('carey1'),('carhartt'),('caribbean'),('caribe'),('caribou'),('caridad'),('carina'),('carina1'),('carine'),('caring'),('carinho'),('carino'),('carioca'),('carisma'),('carissa'),('carissa1'),('carita'),('caritas'),('carito'),('carl'),('carl0s'),('carl12'),('carl123'),('carla'),('carla1'),('carla123'),('carlee'),('carlee1'),('carlene'),('carletto'),('carley'),('carley1'),('carlie'),('carlie1'),('carlin'),('carling'),('carling1'),('carlinha'),('carlinhos'),('carlino'),('carlisle'),('carlisle1'),('carlita'),('carlito'),('carlito1'),('carlitos'),('carlitos1'),('carlo'),('carlo1'),('carlo123'),('carlos'),('carlos!'),('carlos.'),('carlos01'),('carlos05'),('carlos06'),('carlos07'),('carlos08'),('carlos09'),('carlos1'),('carlos10'),('carlos11'),('carlos12'),('carlos123'),('carlos1234'),('carlos13'),('carlos14'),('carlos15'),('carlos16'),('carlos17'),('carlos18'),('carlos19'),('carlos2'),('carlos20'),('carlos21'),('carlos22'),('carlos23'),('carlos24'),('carlos25'),('carlos26'),('carlos27'),('carlos28'),('carlos3'),('carlos4'),('carlos5'),('carlos6'),('carlos69'),('carlos7'),('carlos8'),('carlos88'),('carlos9'),('carlos99'),('carlota'),('carlotta'),('carlotta1'),('carlsberg'),('carlson'),('carlson1'),('carlton'),('carlton1'),('carly'),('carly1'),('carly123'),('carman'),('carman1'),('carmel'),('carmel1'),('carmela'),('carmela1'),('carmelina'),('carmelita'),('carmella'),('carmella1'),('carmelo'),('carmelo1'),('carmelo15'),('carmen'),('carmen01'),('carmen1'),('carmen10'),('carmen11'),('carmen12'),('carmen123'),('carmen13'),('carmen2'),('carmen22'),('carmen23'),('carmen3'),('carmen5'),('carmen69'),('carmen7'),('carmencita'),('carmina'),('carmine'),('carmine1'),('carmona'),('carnage'),('carnage1'),('carnation'),('carnaval'),('carnegie'),('carneiro'),('carnell'),('carnell1'),('carnival'),('carnival1'),('caro'),('caro123'),('carol'),('carol1'),('carol12'),('carol123'),('carol2'),('carola'),('carolann'),('carole'),('carole1'),('caroli'),('carolin'),('carolin1'),('carolina'),('carolina.'),('carolina01'),('carolina1'),('carolina10'),('carolina11'),('carolina12'),('carolina13'),('carolina15'),('carolina2'),('carolina22'),('carolina23'),('carolina3'),('carolina5'),('carolina7'),('caroline'),('Caroline.'),('caroline1'),('caroline12'),('caroline2'),('carollo12'),('carolyn'),('carolyn1'),('caronte'),('carota'),('carotte'),('carousel'),('carpediem'),('carpediem1'),('carpenter'),('carpenter1'),('carpet'),('carpet1'),('carranza'),('carrasco'),('carrefour'),('carrera'),('carrera1'),('carrera4'),('carrick'),('carrie'),('carrie1'),('carrie12'),('carrie123'),('carrie2'),('carrier'),('carrillo'),('carrillo1'),('carrington'),('carroll'),('carroll1'),('carros'),('carrot'),('carrot1'),('carrots'),('carrots1'),('cars'),('cars11'),('cars12'),('cars123'),('cars1234'),('cars98'),('carson'),('carson1'),('carson12'),('carson123'),('carson2'),('carsten'),('cartagena'),('cartel'),('cartel1'),('carter'),('carter01'),('carter08'),('carter09'),('carter1'),('carter10'),('carter11'),('carter12'),('carter123'),('carter13'),('carter15'),('carter2'),('carter22'),('carter23'),('carter3'),('carter4'),('carter5'),('carthage'),('cartier'),('cartman'),('cartman1'),('cartman2'),('carton'),('cartoon'),('cartoon1'),('cartoon10'),('cartoon123'),('cartoons'),('cartoons1'),('cartouche'),('caruso'),('carvalho'),('carver'),('carver1'),('carwash'),('carwash1'),('cas'),('cas123'),('casa'),('casa12'),('casa123'),('casa1234'),('casablanca'),('casacasa'),('casada'),('casado'),('casale'),('casamento'),('casamia'),('casandra'),('casandra1'),('casanova'),('casanova1'),('cascada'),('cascada1'),('cascade'),('cascade1'),('cascades'),('case'),('caserta'),('casetta'),('casey'),('casey01'),('casey1'),('casey10'),('casey11'),('casey12'),('casey123'),('casey13'),('casey2'),('casey21'),('casey22'),('casey3'),('casey5'),('casey7'),('caseydog'),('cash'),('cash11'),('cash12'),('cash123'),('cash1234'),('cash23'),('cashcash'),('cashcrate'),('cashew'),('cashflow'),('cashflow1'),('cashman'),('cashmere'),('cashmere1'),('cashmoney'),('cashmoney1'),('cashmoney2'),('cashmoney3'),('cashmoney5'),('casillas'),('casillas1'),('casimir'),('casimiro'),('casino'),('casino1'),('casino123'),('casio'),('casio1'),('casio123'),('casiopea'),('casita'),('caspar'),('casper'),('casper!'),('casper01'),('casper1'),('casper10'),('casper11'),('casper12'),('casper123'),('casper13'),('casper14'),('casper2'),('casper21'),('casper22'),('casper23'),('casper3'),('casper4'),('casper5'),('casper69'),('casper7'),('casper99'),('caspian'),('cass'),('cass123'),('cassandra'),('cassandra1'),('cassandra2'),('cassandre'),('cassano'),('cassanova'),('cassey'),('cassey1'),('cassia'),('cassidy'),('cassidy1'),('cassidy12'),('cassidy123'),('cassidy2'),('cassidy3'),('cassie'),('cassie!'),('cassie01'),('cassie08'),('cassie09'),('cassie1'),('cassie10'),('cassie11'),('cassie12'),('cassie123'),('cassie13'),('cassie14'),('cassie15'),('cassie16'),('cassie2'),('cassie21'),('cassie22'),('cassie23'),('cassie3'),('cassie4'),('cassie5'),('cassie69'),('cassie7'),('cassiopea'),('cassiopeia'),('cassis'),('cassius'),('cassius1'),('cassy'),('cassy1'),('castaneda'),('castanha1'),('castaway'),('castel'),('castellano'),('castello'),('castelo'),('caster'),('castillo'),('castillo1'),('casting'),('castle'),('castle1'),('castor'),('castor1'),('castro'),('castro1'),('castrol'),('casual'),('cat'),('cat101'),('cat111'),('cat123'),('cat1234'),('cat12345'),('cat123456'),('cat15175'),('cat666'),('catalan'),('catalin'),('catalina'),('catalina1'),('catalog'),('catalunya'),('catalyst'),('catanddog'),('catania'),('catania46'),('catarina'),('catarina1'),('catcat'),('catcat1'),('catcat12'),('catcat123'),('catcatcat'),('catch22'),('catcher'),('catcher1'),('catchme'),('catdaddy'),('catdaddy1'),('catdog'),('catdog1'),('catdog11'),('catdog12'),('catdog123'),('catdog13'),('catdog2'),('catdog22'),('catdog3'),('catdog5'),('catdog7'),('Caterham7'),('caterina'),('catering'),('caterpillar'),('cateyes'),('catfish'),('catfish1'),('catfish2'),('catfood'),('catfood1'),('catgirl'),('catgirl1'),('cathedral'),('catherin'),('catherine'),('catherine1'),('catherine2'),('catherine3'),('cathie'),('cathleen'),('catholic'),('catholic1'),('cathrine'),('cathy'),('cathy1'),('cathy123'),('catia'),('catita'),('catlover'),('catlover1'),('catman'),('catman1'),('catnip'),('catnip1'),('catolica'),('catracho'),('catracho1'),('catrina'),('catrina1'),('catriona'),('cats'),('cats101'),('cats11'),('cats12'),('cats123'),('cats1234'),('cats22'),('catsanddogs'),('catscats'),('catsdogs'),('catseye'),('catsmeow'),('catsrule'),('catsrule1'),('cattle'),('cattle1'),('catty'),('catwalk'),('catwoman'),('catwoman1'),('caught1'),('caution'),('caution1'),('cavalier'),('cavalier1'),('cavaliere'),('cavaliers'),('cavaliers1'),('cavalli'),('cavallo'),('cavalo'),('caveman'),('caveman1'),('cavite'),('cavolo'),('cavs23'),('cayang'),('cayank'),('cayden'),('cayden1'),('cayenne'),('cayman'),('cayman1'),('cayuga'),('cazador'),('cazzarola'),('cazzimiei'),('cazzo'),('cazzo1001'),('cazzoduro'),('cazzone'),('cb'),('cb1234'),('cb123456'),('cba321'),('cbcmrb'),('cbcmrf'),('cbcntvf'),('cbhbec'),('cbhtym'),('cbr1000'),('cbr1000rr'),('cbr1100xx'),('cbr600'),('cbr600rr'),('cbr900'),('cbr900rr'),('cbr929'),('cbrown1'),('cbvcbv'),('cbvjyf'),('cby'),('cc'),('cc1234'),('cc12345'),('cc123456'),('ccc'),('ccc111'),('ccc123'),('ccc333'),('cccc'),('ccccc'),('ccccc1'),('cccccc'),('cccccc1'),('ccccccc'),('cccccccc'),('cccccccccc'),('ccopacell1'),('cd1234'),('cd123456'),('cdbymz'),('cde34rfv'),('cdexswzaq'),('cdflm:'),('cdj:'),('cdjkjxb'),('cdjkjxm'),('cds04121989'),('cdtnbr'),('cdtnf'),('cdtnjxrf'),('cdtnkfyf'),('cdtnkfyrf'),('cdtnkzxjr'),('cdtnrf'),('cdznjckfd'),('ce'),('ceasar'),('ceasar1'),('ceaser'),('ceaser1'),('cebucity'),('cece'),('cece12'),('cece123'),('cecelia'),('cecelia1'),('cecil'),('cecil1'),('cecile'),('cecilia'),('cecilia1'),('cecille'),('cecily'),('ceckbr'),('ceckbrcerfkbxyjcnm2'),('cedar1'),('cedric'),('cedric1'),('cedrick'),('ceecee'),('ceecee1'),('ceejay'),('cegthgfhjkm'),('cegthvty'),('ceilidh'),('cel'),('celebrate'),('celebration'),('celebrity'),('celebrity1'),('celeron'),('celeron1'),('celery'),('celeste'),('celeste1'),('celeste2'),('celestial'),('celestial1'),('celestin'),('celestina'),('celestine'),('celestino'),('celia'),('celia1'),('celibataire'),('celica'),('celica1'),('celina'),('celina1'),('celine'),('celine1'),('celinedion'),('celinesimon'),('cellardoor'),('cello'),('cello1'),('cellphone'),('cellphone1'),('cellphone2'),('cellphone3'),('cellular'),('cellulare'),('celtic'),('celtic01'),('celtic1'),('celtic12'),('celtic123'),('celtic1888'),('celtic1967'),('celtic67'),('celtic7'),('celtic88'),('celticfc'),('celticfc1'),('celtics'),('celtics1'),('celtics33'),('celtics34'),('celtics5'),('celular'),('celular1'),('cement'),('cemetery'),('cena'),('cena11'),('cena12'),('cena123'),('cena54'),('cena619'),('cenation'),('cendrillon'),('cenerentola'),('cenicienta'),('centaur'),('centauro'),('center'),('center1'),('central'),('central1'),('centre'),('centrino'),('centrino1'),('centro'),('centrum'),('centurion'),('century'),('century1'),('century21'),('cepetsugih'),('ceramics'),('cerber'),('cerberus'),('cerberus1'),('cereal'),('cereal1'),('cerebro'),('ceres'),('cereza'),('cerf'),('cerfcerf'),('cerise'),('certified'),('certified1'),('cerulean'),('cervantes'),('cervantes1'),('cerveja'),('cerveza'),('cerveza1'),('cesar'),('cesar1'),('cesar12'),('cesar123'),('cesar13'),('cesare'),('cesarin'),('cessna'),('cessna1'),('cessna152'),('cessna172'),('cestlavie'),('cestmoi'),('cet333333'),('cevthrb'),('cexfhf'),('ceylan'),('cezar'),('cf'),('cf:'),('cfdtkbq'),('cfdxtyrj'),('cfhfnjd'),('cfiekmrf'),('cfiekz'),('cfif'),('cfif123'),('cfifcfif'),('cfitymrf'),('cfkfdfn'),('cfrehf'),('cfvceyu'),('cfvehfq'),('cfvfhf'),('cfvfzkexifz'),('cfvjktn'),('cfymrf'),('cfytxrf'),('cg9600'),('cgfhnfr'),('cghfibdfq'),('cghfqn'),('cgtwyfp'),('ch'),('ch0c0late'),('ch1234'),('ch123456'),('ch1ck3n'),('ch1cken'),('ch33s3'),('ch33se'),('ch3cooh'),('ch3ls3a'),('ch3rry'),('cha'),('cha123'),('chabela'),('chablis'),('chacal'),('chacha'),('chacha1'),('chacha12'),('chacha123'),('chacha2'),('chachacha'),('chachi'),('chachi1'),('chaching'),('chachita'),('chacho'),('chachou'),('chad'),('chad12'),('chad123'),('chad1234'),('chad85'),('chaddy'),('chadreed22'),('chadwick'),('chadwick1'),('chaingang'),('chaingang1'),('chains'),('chainsaw'),('chainsaw1'),('chair'),('chair1'),('chairman'),('chairs'),('chaise'),('chaitanya'),('chaitu'),('chaka'),('chakkara'),('chakra'),('chalet'),('challenge'),('challenge1'),('challenger'),('chalupa'),('chalupa1'),('chaman'),('chamber'),('chamber1'),('chambers'),('chambers1'),('chameau'),('chameleon'),('chamois'),('chamonix'),('champ'),('champ1'),('champ12'),('champ123'),('champ2'),('champ24'),('champa'),('champagne'),('champagne1'),('champion'),('champion1'),('champion12'),('champion2'),('champions'),('champions1'),('champs'),('champs1'),('champy'),('chan'),('chan123'),('chance'),('chance01'),('chance1'),('chance10'),('chance11'),('chance12'),('chance123'),('chance13'),('chance2'),('chance22'),('chance3'),('chance5'),('chance7'),('chances'),('chancey'),('chanchal'),('chanchan'),('chancho'),('chanda'),('chandan'),('chandana'),('chander'),('chandigarh'),('chandler'),('chandler1'),('chandler12'),('chandler2'),('chandni'),('chandra'),('chandra1'),('chandran'),('chandrika'),('chandru'),('chandu'),('chanel'),('chanel05'),('chanel1'),('chanel11'),('chanel12'),('chanel123'),('chanel2'),('chanel5'),('chanelbag'),('chanelle'),('chanelle1'),('chaney'),('chang'),('changa'),('changa1'),('change'),('change08'),('change09'),('change1'),('change12'),('change123'),('Change1234'),('change2'),('changed'),('changed1'),('changeit'),('changeme'),('changeme1'),('changeme123'),('changeme2'),('changepass'),('changer'),('changes'),('changes1'),('chango'),('chango1'),('channel'),('channel1'),('channing'),('channing1'),('chantal'),('chantal1'),('chante'),('chante1'),('chantel'),('chantel1'),('chantell'),('chantelle'),('chantelle1'),('chanti'),('chantilly'),('chaochao'),('chaos'),('chaos1'),('chaos123'),('chaos13'),('chaos2'),('chaos666'),('chaotic'),('chaotic1'),('chaparra'),('chaparra1'),('chaparrita'),('chaparro'),('chaparro1'),('chapel'),('chapin'),('chapin1'),('chapis'),('chaplain'),('chaplin'),('chapman'),('chapman1'),('chappy'),('chappy1'),('chapstick'),('chapstick1'),('chapter1'),('chapulin'),('char'),('char123'),('character'),('character1'),('characters'),('charan'),('charchar'),('charcoal'),('charcoal1'),('chardonnay'),('charge'),('charger'),('charger06'),('charger1'),('charger2'),('charger21'),('charger69'),('chargers'),('chargers1'),('chargers12'),('chargers13'),('chargers2'),('chargers21'),('charing'),('charis'),('charisma'),('charisma1'),('charissa'),('charisse'),('charito'),('charity'),('charity1'),('charizard'),('charizard1'),('charl0tte'),('charl1e'),('charle'),('charlee'),('charlee1'),('charlene'),('charlene1'),('charles'),('charles!'),('charles.'),('charles01'),('charles1'),('charles10'),('charles11'),('charles12'),('charles123'),('charles13'),('charles2'),('charles21'),('charles22'),('charles23'),('charles3'),('charles4'),('charles5'),('charles6'),('charles69'),('charles7'),('charles8'),('charles9'),('charleston'),('charley'),('charley1'),('charli'),('charli1'),('charli3'),('charlie'),('charlie!'),('charlie.'),('charlie0'),('charlie01'),('charlie02'),('charlie03'),('charlie04'),('charlie05'),('charlie06'),('charlie07'),('charlie08'),('charlie09'),('charlie1'),('charlie10'),('charlie101'),('charlie11'),('charlie12'),('charlie123'),('charlie13'),('charlie14'),('charlie15'),('charlie16'),('charlie17'),('charlie18'),('charlie19'),('charlie2'),('charlie20'),('charlie200'),('charlie21'),('charlie22'),('charlie23'),('charlie24'),('charlie25'),('charlie27'),('charlie3'),('charlie33'),('charlie4'),('charlie5'),('charlie6'),('charlie69'),('charlie7'),('charlie77'),('charlie8'),('charlie88'),('charlie9'),('charlie99'),('charlieb'),('charlieboy'),('charliebrown'),('charliedog'),('charlies'),('charline'),('charlize'),('charlo'),('charlot'),('charlote'),('charlott'),('charlotte'),('charlotte0'),('charlotte1'),('charlotte2'),('charlotte3'),('charlotte7'),('charlotte9'),('charlton'),('charlton1'),('charly'),('charly1'),('charly2004'),('charlyn'),('charm'),('charm1'),('charmaine'),('charmaine1'),('charmander'),('charmed'),('charmed!'),('charmed1'),('charmed12'),('charmed123'),('charmed2'),('charmed3'),('charmedp3'),('charmer'),('charmin'),('charmin1'),('charming'),('charming1'),('charms'),('charon'),('charter'),('charter1'),('chartered'),('chase'),('chase01'),('chase1'),('chase10'),('chase11'),('chase12'),('chase123'),('chase13'),('chase2'),('chase22'),('chase3'),('chase4'),('chase5'),('chaselo'),('chaser'),('chaser1'),('chasity'),('chasity1'),('chasse'),('chasseur'),('chastity'),('chat'),('chata1'),('chatchat'),('chateau'),('chatham'),('chatnoir'),('chato'),('chato1'),('chaton'),('chatte'),('chatter'),('chatter1'),('chatterbox'),('chatting'),('chatty'),('chaucer'),('chaudhary'),('chauhan'),('chauncey'),('chauncey1'),('chaussette'),('chava1'),('chaves'),('chavez'),('chavez1'),('chayank'),('chayanne'),('chaz'),('che'),('che123'),('cheap'),('cheat'),('cheat1'),('cheater'),('cheater!'),('cheater1'),('cheater123'),('cheater2'),('cheaters'),('cheaters1'),('cheating'),('cheating1'),('cheburashka'),('checco'),('cheche'),('cheche1'),('chechen'),('checho'),('check'),('check1'),('check12'),('check123'),('checker'),('checker1'),('checkers'),('checkers1'),('checking'),('checking1'),('checkitout'),('checkmate'),('checkmate1'),('cheddar'),('cheddar1'),('cheeba'),('cheech'),('cheech1'),('cheeko'),('cheeks'),('cheeks1'),('cheeky'),('cheeky1'),('cheekymonkey'),('cheena'),('cheer'),('cheer!'),('cheer01'),('cheer05'),('cheer06'),('cheer07'),('cheer08'),('cheer09'),('cheer1'),('cheer10'),('cheer101'),('cheer11'),('cheer12'),('cheer123'),('cheer13'),('cheer14'),('cheer15'),('cheer16'),('cheer2'),('cheer21'),('cheer22'),('cheer23'),('cheer3'),('cheer4'),('cheer4life'),('cheer5'),('cheer6'),('cheer7'),('cheer8'),('cheer9'),('cheerbabe1'),('cheerful'),('cheergirl1'),('cheering1'),('cheerio'),('cheerio1'),('cheerios'),('cheerios1'),('cheerleade'),('cheerleader'),('cheerleadi'),('cheerleading'),('cheers'),('cheers1'),('cheese'),('cheese!'),('cheese.'),('cheese0'),('cheese01'),('cheese1'),('cheese10'),('cheese101'),('cheese11'),('cheese12'),('cheese123'),('cheese1234'),('cheese13'),('cheese14'),('cheese15'),('cheese2'),('cheese21'),('cheese22'),('cheese23'),('cheese24'),('cheese3'),('cheese33'),('cheese4'),('cheese44'),('cheese5'),('cheese6'),('cheese69'),('cheese7'),('cheese8'),('cheese88'),('cheese9'),('cheese99'),('cheeseball'),('cheeseburger'),('cheesecake'),('cheesehead'),('cheeseman'),('cheesey'),('cheesey1'),('cheesy'),('cheesy1'),('cheeta'),('cheetah'),('cheetah1'),('cheetah12'),('cheetah2'),('cheeto'),('cheeto1'),('cheetos'),('cheetos1'),('cheeze'),('cheeze1'),('cheezit1'),('cheezy'),('chef'),('cheguevara'),('chelita'),('chelito'),('chelito19'),('chellam'),('chelle'),('chelle1'),('chelle1234'),('chello'),('chelly'),('chelly1'),('chels1'),('chelsea'),('chelsea!'),('chelsea.'),('chelsea01'),('chelsea05'),('chelsea06'),('chelsea07'),('chelsea08'),('chelsea09'),('chelsea1'),('chelsea10'),('chelsea11'),('chelsea12'),('chelsea123'),('chelsea13'),('chelsea14'),('chelsea15'),('chelsea16'),('chelsea17'),('chelsea18'),('chelsea2'),('chelsea21'),('chelsea22'),('chelsea23'),('chelsea25'),('chelsea26'),('chelsea3'),('chelsea4'),('chelsea5'),('chelsea6'),('chelsea69'),('chelsea7'),('chelsea8'),('chelsea88'),('chelsea9'),('chelsea99'),('chelseafc'),('chelseafc1'),('chelsey'),('chelsey1'),('chelsi'),('chelsie'),('chelsie1'),('chelsy'),('chem'),('chemical'),('chemical1'),('chemicals'),('chemist'),('chemistry'),('chemistry1'),('chen'),('chen123'),('chenchen'),('cheng'),('chenjian'),('chennai'),('chennai123'),('chepalle'),('cherep'),('cheri'),('cherie'),('cherie1'),('cherif'),('cherise'),('cherish'),('cherish1'),('cherokee'),('cherokee1'),('cherrie'),('cherries'),('cherries1'),('cherry'),('cherry!'),('cherry01'),('cherry07'),('cherry08'),('cherry09'),('cherry1'),('cherry10'),('cherry101'),('cherry11'),('cherry12'),('cherry123'),('cherry1234'),('cherry13'),('cherry14'),('cherry15'),('cherry16'),('cherry17'),('cherry18'),('cherry2'),('cherry21'),('cherry22'),('cherry23'),('cherry24'),('cherry25'),('cherry3'),('cherry4'),('cherry5'),('cherry6'),('cherry69'),('cherry7'),('cherry8'),('cherry88'),('cherry9'),('cherrybomb'),('cherrycoke'),('cherrypie'),('cherrypie1'),('cherrys'),('cherrys1'),('cherrytree'),('cherub'),('cheryl'),('cheryl1'),('chesca'),('cheshire'),('cheska'),('chesney'),('chesney1'),('chess'),('chess1'),('chess123'),('chessie'),('chessie1'),('chessmaster'),('chester'),('chester!'),('chester01'),('chester1'),('chester10'),('chester11'),('chester12'),('chester123'),('chester13'),('chester2'),('chester22'),('chester3'),('chester4'),('chester5'),('chester7'),('chester8'),('chesterfield'),('chestnut'),('chestnut1'),('chetan'),('cheval'),('chevalier'),('chevelle'),('chevelle1'),('chevelle69'),('chevere'),('chevrolet'),('chevrolet1'),('chevron'),('chevy'),('chevy01'),('chevy03'),('chevy04'),('chevy05'),('chevy06'),('chevy07'),('chevy08'),('chevy09'),('chevy1'),('chevy10'),('chevy11'),('chevy12'),('chevy123'),('chevy1500'),('chevy2'),('chevy22'),('chevy24'),('chevy2500'),('chevy3'),('chevy350'),('chevy454'),('chevy4x4'),('chevy55'),('chevy57'),('chevy69'),('chevy88'),('chevy89'),('chevy98'),('chevy99'),('chevyman'),('chevyman1'),('chevys'),('chevys1'),('chevys10'),('chevytruck'),('chevyz71'),('chewbacca'),('chewbacca1'),('chewey'),('chewie'),('chewie1'),('chewy'),('chewy1'),('chewy123'),('chewy2'),('cheyanne'),('cheyanne1'),('cheyenne'),('cheyenne01'),('cheyenne1'),('cheyenne11'),('cheyenne12'),('cheyenne13'),('cheyenne2'),('cheyenne3'),('cheyenne7'),('chhaya'),('chi'),('chi-town'),('chi123'),('chiamaka'),('chiara'),('chiara1'),('chiaretta'),('chiave'),('chibi'),('chiboy'),('chibuike'),('chibuzor'),('chica'),('chica1'),('chica12'),('chica123'),('chica13'),('chicago'),('chicago01'),('chicago08'),('chicago1'),('chicago10'),('chicago11'),('chicago12'),('chicago123'),('chicago13'),('chicago2'),('chicago21'),('chicago22'),('chicago23'),('chicago3'),('chicago4'),('chicago5'),('chicago6'),('chicago7'),('chicago8'),('chicago9'),('chicana'),('chicana1'),('chicano'),('chicano1'),('chicano13'),('chicas'),('chicca'),('chicca39'),('chicco'),('chicco1'),('chicha'),('chicharito'),('chichi'),('chichi1'),('chichi11'),('chichi12'),('chichi123'),('chichi2'),('chicho'),('chick'),('chick1'),('chick12'),('chick123'),('chick2'),('chick3n'),('chicka'),('chicka1'),('chickadee'),('chickboy'),('chicken'),('chicken!'),('chicken.'),('chicken0'),('chicken01'),('chicken1'),('chicken10'),('chicken101'),('chicken11'),('chicken12'),('chicken123'),('chicken13'),('chicken14'),('chicken15'),('chicken2'),('chicken21'),('chicken22'),('chicken23'),('chicken24'),('chicken3'),('chicken4'),('chicken44'),('chicken5'),('chicken6'),('chicken69'),('chicken7'),('chicken8'),('chicken9'),('chicken99'),('chickenbutt'),('chickens'),('chickens1'),('chickie'),('chickie1'),('chicklet'),('chicks'),('chicks1'),('chicky'),('chicky1'),('chico'),('chico01'),('chico1'),('chico11'),('chico12'),('chico123'),('chico13'),('chico2'),('chico3'),('chicony'),('chicos'),('chicosci'),('chidera'),('chidinma'),('chidori'),('chidori1'),('chief'),('chief1'),('chiefs'),('chiefs1'),('chien'),('chienne'),('chiens'),('chigger'),('chigozie'),('chihiro'),('chihuahua'),('chihuahua1'),('chijioke'),('chijioke123'),('chika'),('chika1'),('chiken'),('chiken1'),('chikis'),('chikis1'),('chikita'),('chikita1'),('chilango'),('chilango1'),('child'),('child1'),('childcare'),('childofgod'),('children'),('children1'),('children2'),('children3'),('children4'),('children5'),('children6'),('children7'),('chile'),('chile1'),('chileno'),('chili'),('chili1'),('chilidog'),('chill'),('chill1'),('chiller'),('chilli'),('chilli1'),('chillin'),('chillin1'),('chilling'),('chillout'),('chilly'),('chilly1'),('chimchim'),('chimera'),('chimera1'),('chimie'),('china'),('china1'),('china12'),('china123'),('china13'),('china2'),('chinacat'),('chinadoll'),('chinadoll1'),('chinaman'),('chinaman1'),('chinatown'),('chinatown1'),('chinchilla'),('chinchin'),('chinchin1'),('chinedu'),('chinedu1'),('chinenye'),('chinese'),('chinese1'),('ching'),('chingching'),('chingon'),('chingon1'),('chingy'),('chingy1'),('chinita'),('chinita1'),('chinito'),('chinky'),('chinky1'),('chinna'),('chinni'),('chinnu'),('chino'),('chino1'),('chino12'),('chino123'),('chino13'),('chinois'),('chinonso'),('chinook'),('chinook1'),('chintu'),('chinwe'),('chinyere'),('chiodos1'),('chioma'),('chip'),('chip123'),('chipchip'),('chipie'),('chipmunk'),('chipmunk1'),('chipmunks'),('chipper'),('chipper1'),('chipper10'),('chipper2'),('chippie'),('chippy'),('chippy1'),('chips'),('chips1'),('chips123'),('chipster'),('chiqui'),('chiqui1'),('chiquis'),('chiquis1'),('chiquita'),('chiquita1'),('chiquitin'),('chiquitita'),('chiquito'),('chiquito1'),('chirag'),('chisom'),('chispa'),('chispita'),('chitarra'),('chitchat'),('chito1'),('chitown'),('chitown1'),('chitra'),('chitti'),('chiva1'),('chivas'),('chivas#1'),('chivas01'),('chivas07'),('chivas09'),('chivas1'),('chivas10'),('chivas100'),('chivas101'),('chivas11'),('chivas12'),('chivas123'),('chivas1234'),('chivas13'),('chivas14'),('chivas15'),('chivas16'),('chivas17'),('chivas18'),('chivas19'),('chivas2'),('chivas21'),('chivas22'),('chivas23'),('chivas3'),('chivas4'),('chivas5'),('chivas7'),('chivas8'),('chivas9'),('chivas99'),('chloe'),('chloe01'),('chloe05'),('chloe06'),('chloe07'),('chloe08'),('chloe09'),('chloe1'),('chloe10'),('chloe11'),('chloe12'),('chloe123'),('chloe13'),('chloe2'),('chloe22'),('chloe23'),('chloe3'),('chloe4'),('chloe5'),('chloe6'),('chloe7'),('chloedog'),('chloee'),('chloes'),('cho'),('chobit'),('chobits'),('chobits1'),('chocha'),('chocha1'),('chocho'),('chocho1'),('choclate'),('choclate1'),('choco'),('choco1'),('choco123'),('chocobo'),('chocobo1'),('chococat'),('chocol8'),('chocolat'),('chocolat1'),('chocolat3'),('chocolate'),('chocolate!'),('chocolate.'),('chocolate0'),('chocolate1'),('chocolate11'),('chocolate12'),('chocolate123'),('chocolate2'),('chocolate3'),('chocolate4'),('chocolate5'),('chocolate6'),('chocolate7'),('chocolate8'),('chocolate9'),('chocolates'),('choctaw'),('chode1'),('choice'),('choice1'),('chois777'),('chokolate'),('chola13'),('cholito'),('cholo'),('cholo1'),('cholo123'),('cholo13'),('chomik'),('chomper'),('chomper1'),('chonchon'),('chooch'),('choochoo'),('choochoo1'),('choose'),('choose1'),('choosen1'),('chopchop'),('chopin'),('chopin1'),('choppa1'),('chopper'),('chopper1'),('chopper12'),('chopper123'),('chopper2'),('chopper3'),('chopper69'),('chopper7'),('choppers'),('choppers1'),('chopsuey'),('chorizo'),('chosen'),('chosen1'),('chosenone'),('chouchou'),('chouchou1'),('choucroute'),('choudhary'),('chouette'),('choupette'),('choupi'),('choupinette'),('choupinou'),('chouquette'),('chowchow'),('chowchow1'),('chowdary'),('chowder'),('chowder1'),('chr'),('chr1st1an'),('chris'),('chris!'),('chris#1'),('chris.'),('chris0'),('chris00'),('chris007'),('chris01'),('chris02'),('chris03'),('chris04'),('chris05'),('chris06'),('chris07'),('chris08'),('chris09'),('chris1'),('chris10'),('chris100'),('chris101'),('chris11'),('chris111'),('chris12'),('chris123'),('chris1234'),('chris12345'),('chris13'),('chris14'),('chris143'),('chris15'),('chris16'),('chris17'),('chris18'),('chris19'),('chris1988'),('chris1989'),('chris1990'),('chris1991'),('chris1993'),('chris2'),('chris20'),('chris2006'),('chris2007'),('chris2008'),('chris2009'),('chris2010'),('chris21'),('chris22'),('chris23'),('chris24'),('chris25'),('chris26'),('chris27'),('chris28'),('chris29'),('chris3'),('chris30'),('chris31'),('chris32'),('chris33'),('chris34'),('chris4'),('chris420'),('chris44'),('chris45'),('chris4ever'),('chris4life'),('chris5'),('chris55'),('chris6'),('chris666'),('chris69'),('chris7'),('chris77'),('chris8'),('chris82'),('chris83'),('chris84'),('chris85'),('chris86'),('chris87'),('chris88'),('chris89'),('chris9'),('chris90'),('chris91'),('chris92'),('chris93'),('chris94'),('chris95'),('chris96'),('chris97'),('chris98'),('chris99'),('chrisb'),('chrisb1'),('chrisb2'),('chrisbln'),('chrisbrow1'),('chrisbrown'),('chrisc'),('chrischris'),('chrisi'),('chrism'),('chrisp'),('chrispaul3'),('chriss'),('chriss1'),('chrissi'),('chrissie'),('chrissy'),('chrissy1'),('chrissy123'),('chrissy2'),('christ'),('christ01'),('christ1'),('christ11'),('christ12'),('christ123'),('christ2'),('christ3'),('christ7'),('christ777'),('christa'),('christa1'),('christal'),('christel'),('christelle'),('christen'),('christen1'),('christi'),('christi1'),('christia'),('christiaan'),('christian'),('christian!'),('christian.'),('christian0'),('christian1'),('christian12'),('christian123'),('christian2'),('christian3'),('christian4'),('christian5'),('christian6'),('christian7'),('christian8'),('christian9'),('christiana'),('christiane'),('christiano'),('christie'),('christie1'),('christin'),('christin1'),('christina'),('christina!'),('christina0'),('christina1'),('christina2'),('christina3'),('christina4'),('christina5'),('christina7'),('christina8'),('christina9'),('christine'),('christine!'),('christine0'),('christine1'),('christine2'),('christine3'),('christine5'),('christine7'),('christine8'),('christine9'),('christmas'),('christmas!'),('christmas0'),('christmas1'),('christmas2'),('christmas3'),('christmas7'),('christo'),('christo1'),('christop'),('christoph'),('christoph1'),('christoph89'),('christophe'),('christopher'),('christopher1'),('christos'),('christy'),('christy1'),('chrome'),('chrome1'),('chronic'),('chronic1'),('chronic2'),('chronic420'),('chrono'),('chrono1'),('chronos'),('chrysler'),('chrysler1'),('chrystal'),('chrystal1'),('chu'),('chubbs'),('chubbs1'),('chubby'),('chubby1'),('chubby123'),('chubby2'),('chucha'),('chucha0810'),('chuchay'),('chuchi'),('chuchi1'),('chucho'),('chucho1'),('chuchu'),('chuchu1'),('chuck'),('chuck1'),('chuck12'),('chuck123'),('chuck2'),('chuckie'),('chuckie1'),('chuckles'),('chuckles1'),('chucknorris'),('chucks'),('chucky'),('chucky1'),('chucky12'),('chucky123'),('chucky13'),('chukwu'),('chukwudi'),('chukwuma'),('chula'),('chula1'),('chula12'),('chula123'),('chula13'),('chuleta'),('chulita'),('chulo1'),('chumchum'),('chumley'),('chummy'),('chunchun'),('chunk1'),('chunky'),('chunky1'),('chupacabra'),('chupachups'),('chupala'),('chupamela'),('church'),('church1'),('church12'),('church123'),('church2'),('churchill'),('churchill1'),('chutney'),('chutrung'),('chuy123'),('chyna'),('chyna1'),('chynna'),('ch_vitalij'),('ciao'),('ciao123'),('ciao1234'),('ciaoatutti'),('ciaobella'),('ciaociao'),('ciaociao1'),('ciaociaociao'),('ciaoo'),('ciaooo'),('ciara'),('ciara1'),('ciara12'),('ciara123'),('ciara2'),('ciaran'),('cicamica'),('ciccia'),('ciccina'),('ciccino'),('ciccio'),('ciccio1'),('cicciobello'),('cicciolina'),('cicciona'),('ciccione'),('cicero'),('cicero1324'),('ciclismo'),('cielito'),('cielo'),('cieloazul'),('ciera1'),('cierra'),('cierra1'),('cigar'),('cigarette'),('cigars'),('cimbom'),('cimbom1905'),('cimbombom'),('cin'),('cincin'),('cincinnati'),('cinco'),('cinco5'),('cinder'),('cinder1'),('cinderela'),('cinderella'),('cinders'),('cinders1'),('cindrella'),('cindy'),('cindy01'),('cindy1'),('cindy12'),('cindy123'),('cindy13'),('cindy2'),('cindylou'),('cindys'),('cinema'),('cinema1'),('cinghiale'),('cingular'),('cingular1'),('cinnamon'),('cinnamon1'),('cinque'),('cinta'),('cinta1'),('cinta123'),('cintaku'),('cintaku1'),('cintaq'),('cintasejat'),('cinthia'),('cinthia1'),('cinthya'),('cintia'),('cinzia'),('cioccolata'),('cioccolato'),('ciocolata'),('cipher'),('cipolla'),('cipollina'),('cippalippa'),('ciprian'),('circa1'),('circle'),('circle1'),('circuit'),('circus'),('circus1'),('cirebon'),('cirillo'),('cirilo'),('cirrus'),('cisco'),('cisco1'),('cisco123'),('cisneros'),('citadel'),('citation'),('citibank'),('citizen'),('citizen1'),('citroen'),('citroen1'),('citroenc4'),('citron'),('citrus'),('city'),('cityboy1'),('cityhunter'),('civic'),('civic1'),('civicsi'),('civilwar'),('cj'),('cj1234'),('cj12345'),('cj123456'),('cj:'),('cjcbcrf'),('cjcbnt'),('cjdthitycndj'),('cjhjrf'),('cjkjdtq'),('cjkysirj'),('cjkywt'),('cjmasterinf'),('cjrjkjd'),('cjrjkjdf'),('cjxb2014'),('cjymrf'),('cjytxrf'),('cjytxrj'),('ckfdbr'),('ckflrbq'),('ckflrfz'),('ckiue73jp'),('ckjybr'),('cksdnd12'),('cl'),('cla'),('claire'),('claire01'),('claire1'),('claire12'),('claire123'),('claire2'),('clairebear'),('clancy'),('clancy1'),('clapton'),('clapton1'),('clara'),('clara1'),('clara123'),('clare'),('clare1'),('claremont'),('clarence'),('clarence1'),('claret'),('clarice'),('clarinet'),('clarinet1'),('clarinette'),('clarinha'),('clarion'),('clarissa'),('clarissa1'),('clarisse'),('clarita'),('clarity'),('clark'),('clark1'),('clark123'),('clarke'),('clarke1'),('clarkkent'),('clarkkent1'),('clarkson'),('class'),('class04'),('class05'),('class06'),('class07'),('class08'),('class09'),('class1'),('class10'),('class11'),('class12'),('class2006'),('class2007'),('class2008'),('class2009'),('class2010'),('class2011'),('class2012'),('class2013'),('classic'),('classic1'),('classical'),('classics'),('classified'),('classmate'),('classof05'),('classof06'),('classof07'),('classof08'),('classof09'),('classof10'),('classof11'),('classof12'),('classof13'),('classof200'),('classof201'),('classof2010'),('classof2011'),('classof2012'),('classof99'),('classroom'),('classy'),('classy1'),('claude'),('claude1'),('claudette'),('claudi'),('claudia'),('claudia1'),('claudia12'),('claudia123'),('claudia13'),('claudia2'),('claudia7'),('claudie'),('claudine'),('claudio'),('claudio1'),('claudita'),('claudiu'),('claudius'),('clavier'),('clay'),('claymore'),('clayton'),('clayton1'),('clayton2'),('cle'),('clean'),('clean1'),('cleaner'),('cleaner1'),('cleaning'),('cleaning1'),('clear'),('clear1'),('clearwater'),('clelia'),('clemence'),('clemens'),('clement'),('clement1'),('clemente'),('clemente21'),('clementina'),('clementine'),('clements'),('clemson'),('clemson1'),('cleo'),('cleo12'),('cleo123'),('cleocat'),('cleocleo'),('cleopatra'),('cleopatra1'),('cleopatre'),('clermont'),('cletus'),('cleveland'),('cleveland1'),('cleveland2'),('clever'),('clever1'),('click'),('click1'),('click123'),('click5'),('clicker'),('client'),('cliff'),('cliff1'),('clifford'),('clifford1'),('cliffy'),('clifton'),('clifton1'),('climax'),('climber'),('climber1'),('climbing'),('clinic'),('clinique'),('clint'),('clint1'),('clinton'),('clinton1'),('clipper'),('clipper1'),('clippers'),('clippers1'),('clitoris'),('clo'),('clochette'),('clock'),('clock1'),('clock123'),('clocks'),('clocks1'),('clockwork'),('clockwork1'),('cloclo'),('clones'),('clooney'),('closed'),('closer'),('closer1'),('clothes'),('clothes1'),('clotilde'),('cloud'),('cloud1'),('cloud123'),('cloud7'),('cloud9'),('cloud99'),('clouds'),('clouds1'),('cloudstrife'),('cloudy'),('cloudy1'),('clover'),('clover1'),('clover12'),('clover123'),('clover4'),('clover7'),('clovis'),('clown'),('clown1'),('clown123'),('clowns'),('clowns1'),('club'),('club2030'),('clubber'),('clubpenguin'),('clueless'),('clueless1'),('clumsy'),('cluster'),('clusters'),('clutch'),('clutch1'),('clyde'),('clyde1'),('clyde123'),('cm1234'),('CM6E7Aumn9'),('cme2012'),('cmoney'),('cmoney1'),('cmpunk'),('cmpunk1'),('cms123'),('cneltyn'),('cneltynrf'),('cnfcbr'),('cnfkrth'),('cnfybckfd'),('cnhfcnm'),('cnhfyybr'),('cnhjbntkm'),('cnhjqrf'),('cnhtktw'),('cnhtrjpf'),('cnjvfnjkju'),('cntgfirf'),('cntgfy'),('cntgfyjd'),('cntgfyjdf'),('cnthdf'),('cnthdjxrf'),('cntkkf'),('co2006'),('co2007'),('co2008'),('co2010'),('coach'),('coach1'),('coach123'),('coaching'),('coastal'),('coastal1'),('coaster'),('coaster1'),('cobain'),('cobain1'),('cobaka'),('cobalt'),('cobalt1'),('cobblers'),('cobra'),('cobra1'),('cobra11'),('cobra12'),('cobra123'),('cobra2'),('cobra427'),('cobras'),('cobras1'),('coc'),('coca'),('coca-cola'),('cocacola'),('cocacola!'),('cocacola0'),('cocacola1'),('cocacola10'),('cocacola11'),('cocacola12'),('cocacola123'),('cocacola13'),('cocacola2'),('cocacola3'),('cocacola7'),('cocaina'),('cocaine'),('cocaine1'),('coccinella'),('coccinelle'),('coccodrillo'),('cochise'),('cochise1'),('cochon'),('cock'),('cock12'),('cock123'),('cock69'),('cocker'),('cocker1'),('cockroach'),('cocksucker'),('cocktail'),('cocktail1'),('cocky1'),('coco'),('coco01'),('coco07'),('coco08'),('coco09'),('coco1'),('coco10'),('coco101'),('coco11'),('coco12'),('coco123'),('coco1234'),('coco13'),('coco14'),('coco15'),('coco16'),('coco21'),('coco22'),('coco23'),('coco24'),('coco69'),('coco77'),('coco99'),('cocoa'),('cocoa1'),('cocoa12'),('cocoa123'),('cocoa2'),('cocobean'),('cocochanel'),('cococo'),('cococo1'),('cocococo'),('cocodog'),('cocodrilo'),('cocolino'),('cocoliso'),('cocoloco'),('cocoloco1'),('cocomero'),('coconut'),('coconut1'),('coconut12'),('coconut123'),('coconut2'),('coconuts'),('coconuts1'),('cocoon'),('cocopops'),('cocopuff'),('cocopuff1'),('cocopuffs'),('cocopuffs1'),('cocorico'),('cocotte'),('cod'),('cod12qw75RqYi59n'),('code'),('code123'),('codeblue'),('codegeass'),('codelyoko'),('codeman'),('codeman1'),('codename'),('codename47'),('codered'),('codered1'),('codigo'),('codmw2'),('cody'),('cody01'),('cody07'),('cody08'),('cody10'),('cody101'),('cody11'),('cody12'),('cody123'),('cody1234'),('cody13'),('cody14'),('cody15'),('cody16'),('cody17'),('cody21'),('cody22'),('cody23'),('cody69'),('codybear'),('codybear1'),('codyboy'),('codyboy1'),('codycody'),('codydog'),('codydog1'),('coelho'),('coeur'),('coffee'),('coffee!'),('coffee01'),('coffee1'),('coffee11'),('coffee12'),('coffee123'),('coffee2'),('coffee22'),('coffee3'),('coffee4me'),('coffee7'),('coffeecup'),('cogito'),('coglione'),('cognac'),('cognita'),('coheed'),('coheed1'),('cohiba'),('coimbatore'),('coimbra'),('coincoin'),('cojones'),('cokacola'),('coke'),('coke11'),('coke12'),('coke123'),('coke45'),('cokecoke'),('coklat'),('cokolada'),('col'),('cola'),('cola123'),('colacola'),('colasisi'),('colby'),('colby1'),('colby123'),('colchester'),('cold'),('coldbeer'),('coldfire'),('coldplay'),('coldplay1'),('coldwater'),('cole'),('cole11'),('cole12'),('cole123'),('cole1234'),('cole13'),('coleen'),('colegio'),('coleman'),('coleman1'),('colette'),('colette1'),('colgate'),('colgate1'),('colibri'),('colima1'),('colin'),('colin1'),('colin123'),('coline'),('collect'),('collect1'),('collection'),('collector'),('colleen'),('colleen1'),('college'),('college08'),('college09'),('college1'),('college123'),('college2'),('collette'),('collie'),('collie1'),('collier'),('collin'),('collin1'),('collin12'),('collingwood'),('collins'),('collins1'),('colnago'),('colocolo'),('colocolo1'),('cologne'),('colombe'),('colombia'),('colombia1'),('colombia10'),('colombia12'),('colombia2'),('colombiano'),('colombo'),('colonel'),('colonel1'),('colonia'),('colonial'),('colony'),('color'),('color1'),('color123'),('colorado'),('colorado1'),('colorado12'),('colorado2'),('colores'),('colorful'),('colorguard'),('colors'),('colors1'),('colossus'),('colour'),('colours'),('colt'),('colt1911'),('colt45'),('colten'),('colton'),('colton1'),('colton12'),('coltrane'),('coltrane1'),('colts'),('colts1'),('colts123'),('colts18'),('colts21'),('colts88'),('columbia'),('columbia1'),('columbo'),('columbus'),('columbus1'),('com'),('com123'),('comanche'),('comanche1'),('comandante'),('comander'),('comando'),('comandos'),('combat'),('combat1'),('combat123654'),('combat18'),('comcast'),('comcast1'),('comcom'),('come'),('come2me'),('comeback'),('comedian1'),('comedy'),('comedy1'),('comein'),('comeon'),('comeon1'),('comeon11'),('comeon111'),('comercial'),('comet'),('comet1'),('comet123'),('cometa'),('cometome'),('comets'),('comets1'),('comfort'),('comfort1'),('comics'),('comida'),('coming'),('command'),('command1'),('commander'),('commander1'),('commando'),('commando1'),('commandos'),('comment'),('commerce'),('commerce1'),('commercial'),('commodore'),('commodore1'),('common'),('common1'),('common123'),('commons21'),('commrades'),('communication'),('community'),('community1'),('comp'),('compac'),('compact'),('company'),('company1'),('company123'),('compaq'),('compaq01'),('compaq1'),('compaq11'),('compaq12'),('compaq123'),('compaq13'),('compaq2'),('compaq3'),('compaq6720'),('compass'),('compass1'),('compassion'),('complete'),('complete1'),('complex'),('complex1'),('complicate'),('complicated'),('composer'),('compound'),('compras'),('compton'),('compton1'),('compton13'),('compton310'),('compusa'),('computador'),('computadora'),('computer'),('computer!'),('computer.'),('computer0'),('computer01'),('computer1'),('computer10'),('computer11'),('computer12'),('computer123'),('computer13'),('computer2'),('computer20'),('computer21'),('computer22'),('computer23'),('computer3'),('computer4'),('computer5'),('computer6'),('computer69'),('computer7'),('computer8'),('computer9'),('computers'),('computers1'),('comrade'),('comrades'),('con'),('conair'),('conan'),('conan1'),('conan123'),('conard'),('concac'),('concepcion'),('concept'),('concept1'),('concert'),('concerto'),('concetta'),('concha'),('conchita'),('concon'),('concord'),('concord1'),('concorde'),('concorde1'),('concordia'),('concours'),('concrete'),('concrete1'),('condition'),('condo'),('condom'),('condom1'),('condor'),('condor1'),('condorito'),('coneja'),('conejita'),('conejito'),('conejo'),('conejo1'),('confiance'),('confidence'),('confident'),('confident1'),('confidential'),('config'),('confirm'),('confirm1'),('confirmed'),('conflict'),('confused'),('confused1'),('confused2'),('confusion'),('congress'),('coniglio'),('conker'),('conker1'),('conman'),('connard'),('connect'),('connect1'),('connect123'),('connect2'),('connect4'),('connected'),('connecting'),('connection'),('connections'),('conner'),('conner1'),('conner12'),('conner123'),('conner2'),('connexion'),('connie'),('connie1'),('connie12'),('connie123'),('connie2'),('connolly'),('connor'),('connor01'),('connor02'),('connor03'),('connor04'),('connor05'),('connor06'),('connor07'),('connor08'),('connor1'),('connor10'),('connor11'),('connor12'),('connor123'),('connor13'),('connor2'),('connor3'),('connor4'),('connor5'),('connor7'),('connor99'),('conor'),('conor1'),('conpro73'),('conquer'),('conquest'),('conrad'),('conrad1'),('console'),('constance'),('constance1'),('constance626boilard1987'),('constant'),('constanta'),('constantin'),('constantine'),('constanza'),('construction'),('consuelo'),('consuelo1'),('consult'),('consultant'),('consulting'),('consumer'),('contact'),('contact1'),('contacts'),('contador'),('contender'),('content'),('contessa'),('contest'),('contest1'),('continental'),('continue'),('continue1'),('contour'),('contra'),('contra1'),('contract'),('contractor'),('contrase'),('contrase+�a'),('contrasea'),('contrasena'),('contreras'),('contreras1'),('control'),('control1'),('control2'),('controle'),('controller'),('converse'),('converse1'),('converse12'),('convict'),('convict1'),('conway'),('conway1'),('coo'),('coochie'),('coocoo'),('coocoo1'),('cook'),('cookbook'),('cooker'),('cooki3'),('cookie'),('cookie!'),('cookie.'),('cookie0'),('cookie00'),('cookie01'),('cookie02'),('cookie06'),('cookie07'),('cookie08'),('cookie09'),('cookie1'),('cookie10'),('cookie101'),('cookie11'),('cookie12'),('cookie123'),('cookie1234'),('cookie13'),('cookie14'),('cookie15'),('cookie16'),('cookie17'),('cookie18'),('cookie19'),('cookie2'),('cookie20'),('cookie21'),('cookie22'),('cookie23'),('cookie24'),('cookie25'),('cookie3'),('cookie33'),('cookie4'),('cookie44'),('cookie45'),('cookie5'),('cookie55'),('cookie6'),('cookie69'),('cookie7'),('cookie77'),('cookie8'),('cookie88'),('cookie9'),('cookie99'),('cookiemons'),('cookiemonster'),('cookies'),('cookies!'),('cookies.'),('cookies01'),('cookies1'),('cookies10'),('cookies101'),('cookies11'),('cookies12'),('cookies123'),('cookies13'),('cookies2'),('cookies22'),('cookies23'),('cookies3'),('cookies4'),('cookies5'),('cookies6'),('cookies7'),('cookies8'),('cookies9'),('cooking'),('cooking1'),('cool'),('cool00'),('cool01'),('cool09'),('cool1'),('cool10'),('cool100'),('cool101'),('cool11'),('cool12'),('cool123'),('cool1234'),('cool12345'),('cool123456'),('cool13'),('cool14'),('cool15'),('cool16'),('cool17'),('cool18'),('cool20'),('cool21'),('cool22'),('cool23'),('cool24'),('cool25'),('cool33'),('cool45'),('cool55'),('cool56'),('cool69'),('cool77'),('cool88'),('cool90'),('cool98'),('cool99'),('coolbaby'),('coolbeans'),('coolbeans1'),('coolblue'),('coolboy'),('coolboy1'),('coolboy123'),('coolbreeze'),('coolbuddy'),('coolbuddy1'),('coolcat'),('coolcat1'),('coolcat12'),('coolcat123'),('coolcat2'),('coolcats'),('coolchick'),('coolchick1'),('coolcool'),('coolcool1'),('cooldog'),('cooldog1'),('cooldude'),('cooldude09'),('cooldude1'),('cooldude12'),('cooldude2'),('cooler'),('cooler1'),('cooler12'),('cooler123'),('coolest'),('coolest1'),('cooley'),('coolgirl'),('coolgirl1'),('coolgirl12'),('coolguy'),('coolguy1'),('coolguy123'),('coolguy2'),('coolhand'),('coolie'),('coolie1'),('cooling'),('coolio'),('coolio!'),('coolio1'),('coolio12'),('coolio123'),('coolio2'),('coolkid'),('coolkid1'),('coolkid12'),('coolkid123'),('coolkid2'),('coolkids'),('coolkids1'),('coolman'),('coolman1'),('coolman12'),('coolman123'),('coolman2'),('coolme'),('coolness'),('coolness1'),('coolpix'),('coolwater'),('coolwhip'),('coondog'),('coondog1'),('cooool'),('coop'),('cooper'),('cooper!'),('cooper01'),('cooper06'),('cooper07'),('cooper08'),('cooper09'),('cooper1'),('cooper10'),('cooper11'),('cooper12'),('cooper123'),('cooper13'),('cooper14'),('cooper2'),('cooper21'),('cooper22'),('cooper23'),('cooper24'),('cooper3'),('cooper4'),('cooper5'),('cooper7'),('coopers'),('coors1'),('coorslight'),('cooter'),('cooter1'),('copacabana'),('copain'),('copeland'),('copeland1'),('copenhagen'),('copito'),('copper'),('copper01'),('copper1'),('copper11'),('copper12'),('copper123'),('copper2'),('copper22'),('copperhead'),('copycat'),('copyright'),('copyright1'),('coquelicot'),('coqueta'),('coquin'),('coquine'),('coquito'),('cor'),('cora'),('coracao'),('coral'),('coral1'),('coralie'),('coraline'),('corazon'),('corazon1'),('corazon12'),('corazon123'),('corazon2'),('corazoncito'),('corazones'),('corbin'),('corbin1'),('cordelia'),('cordell'),('cordell1'),('cordell123'),('cordero'),('cordero1'),('cordoba'),('cordova'),('cordova1'),('core2duo'),('COREGMEDIA'),('corentin'),('corey'),('corey1'),('corey11'),('corey12'),('corey123'),('corey2'),('corey8'),('corgan'),('corina'),('corina1'),('corine'),('corinna'),('corinna1'),('corinne'),('corinne1'),('corinthian'),('corinthians'),('corkey'),('corky'),('corky1'),('corleone'),('corleone1'),('corn'),('cornbread'),('cornbread1'),('corncake21'),('corndog'),('corndog1'),('cornel'),('cornelia'),('cornelia1'),('cornelio'),('cornelis'),('cornelius'),('cornelius1'),('cornell'),('cornell1'),('corner'),('corner1'),('cornerstone'),('cornflake'),('cornflakes'),('cornhole'),('cornholio'),('cornwall'),('cornwall1'),('corolla'),('corolla1'),('corona'),('corona1'),('corona12'),('corona123'),('corona13'),('corona2'),('corona69'),('coronado'),('coronado1'),('coronel'),('corporal'),('corporate'),('corporation'),('corpse'),('corpus'),('corrado'),('corrado1'),('correa'),('correct'),('correia'),('correo'),('corrie'),('corrie1'),('corrina'),('corrine'),('corrine1'),('corsa'),('corsa1'),('corsair'),('corsica'),('corsica1'),('cortes'),('cortex'),('cortez'),('cortez1'),('cortina'),('cortland'),('cortney'),('cortney1'),('corvette'),('corvette1'),('corvette2'),('corvette69'),('corwin'),('cory'),('cory12'),('cory123'),('cosanostra'),('cosenza'),('cosette'),('cosimo'),('cosita'),('cosita1'),('cosmic'),('cosmic1'),('cosmin'),('cosmo'),('cosmo1'),('cosmo123'),('cosmo2'),('cosmopolitan'),('cosmos'),('cosmos0901'),('cosmos1'),('cossie'),('costa'),('costa1'),('costa90'),('costantino'),('costanza'),('costarica'),('costarica1'),('costas'),('costel'),('costello'),('cosworth'),('cosworth1'),('cottage'),('cottage1'),('cotton'),('cotton1'),('cotton12'),('cottoncand'),('cottoncandy'),('cou'),('coucou'),('coucou1'),('cougar'),('cougar1'),('cougar12'),('cougars'),('cougars1'),('coumba'),('council'),('counselor'),('countdown'),('counter'),('counter1'),('counter123'),('counterstrike'),('country'),('country1'),('country12'),('country123'),('country2'),('countryboy'),('countrygir'),('countrygirl'),('county'),('county1'),('CountyLib'),('couple'),('coupon'),('coupon1'),('couponmom'),('coupons'),('coupons1'),('couponSC10'),('courage'),('courage1'),('courage9'),('courier'),('court'),('court1'),('court123'),('courtney'),('courtney!'),('courtney01'),('courtney1'),('courtney10'),('courtney11'),('courtney12'),('courtney13'),('courtney14'),('courtney16'),('courtney2'),('courtney22'),('courtney3'),('courtney4'),('courtney5'),('courtney6'),('courtney7'),('courtney8'),('courtney9'),('couscous'),('cousin'),('cousin1'),('cousins'),('cousins1'),('couture'),('couture1'),('covenant'),('covenant1'),('coventry'),('coventry1'),('covergirl'),('covert'),('cow'),('cow123'),('cowabunga'),('cowbell'),('cowboy'),('cowboy!'),('cowboy01'),('cowboy09'),('cowboy1'),('cowboy10'),('cowboy11'),('cowboy12'),('cowboy123'),('cowboy13'),('cowboy2'),('cowboy21'),('cowboy22'),('cowboy23'),('cowboy24'),('cowboy3'),('cowboy5'),('cowboy69'),('cowboy7'),('cowboy8'),('cowboy88'),('cowboy9'),('cowboys'),('cowboys!'),('cowboys#1'),('cowboys01'),('cowboys07'),('cowboys08'),('cowboys09'),('cowboys1'),('cowboys10'),('cowboys11'),('cowboys12'),('cowboys123'),('cowboys13'),('cowboys14'),('cowboys2'),('cowboys21'),('cowboys22'),('cowboys23'),('cowboys24'),('cowboys3'),('cowboys31'),('cowboys33'),('cowboys4'),('cowboys5'),('cowboys69'),('cowboys7'),('cowboys8'),('cowboys81'),('cowboys88'),('cowboys9'),('cowboyup'),('cowboyup1'),('cowboyz1'),('cowcow'),('cowcow1'),('cowgirl'),('cowgirl1'),('cowgirl2'),('cowgirls'),('cowgirlup'),('cowgirlup1'),('cowman'),('cowpie'),('cows'),('cows123'),('coyote'),('coyote1'),('coyotes'),('cozumel'),('cpPzfRC933'),('cpt310'),('cr'),('cr125r'),('Cr1st1an'),('cr250r'),('cra'),('crabby'),('crabby1'),('crabtree'),('crack'),('crack1'),('crack123'),('cracka1'),('cracker'),('cracker1'),('cracker12'),('cracker123'),('cracker2'),('crackerjack'),('crackers'),('crackers1'),('crackhead'),('crackhead1'),('cracovia'),('cradle'),('cradle1'),('cradle666'),('cradleoffilth'),('craft'),('crafter'),('crafts'),('crafty'),('crafty1'),('craig'),('craig1'),('craig123'),('craiova'),('cranberry'),('cranberry1'),('crap'),('crap12'),('crap123'),('crapaud'),('crapola'),('crapper'),('crapper1'),('crappie'),('crappy'),('crappy1'),('crapule'),('crash'),('crash1'),('crash123'),('craven'),('crawfish'),('crawfish1'),('crawford'),('crawford1'),('crawling'),('crayola'),('crayola1'),('crayon'),('crayon1'),('crayons'),('crayons1'),('crazy'),('crazy!'),('crazy01'),('crazy07'),('crazy08'),('crazy09'),('crazy1'),('crazy10'),('crazy101'),('crazy11'),('crazy111'),('crazy12'),('crazy123'),('crazy1234'),('crazy13'),('crazy14'),('crazy15'),('crazy16'),('crazy17'),('crazy18'),('crazy2'),('crazy21'),('crazy22'),('crazy23'),('crazy24'),('crazy3'),('crazy4'),('crazy4life'),('crazy4u'),('crazy4you'),('crazy5'),('crazy6'),('crazy666'),('crazy69'),('crazy7'),('crazy8'),('crazy88'),('crazy8s'),('crazy9'),('crazyass1'),('crazybitch'),('crazyboy'),('crazyboy1'),('crazycat'),('crazychick'),('crazydog'),('crazyfrog'),('crazyfrog1'),('crazygirl'),('crazygirl1'),('crazygirl2'),('crazygurl1'),('crazyhorse'),('crazykid1'),('crazylady'),('crazylady1'),('crazylove'),('crazylove1'),('crazyman'),('crazyman1'),('crazyme'),('crazyone'),('crazzy'),('crazzy1'),('cre'),('cre8tive'),('cream'),('cream1'),('cream123'),('creampie'),('creampuff'),('creamy'),('creamy1'),('creat1ve'),('create'),('create1'),('creatine'),('creation'),('creation1'),('creations'),('creative'),('creative1'),('creative12'),('creative123'),('creative2'),('creativity'),('creator'),('creator1'),('creature'),('creature1'),('credit'),('credit1'),('creed'),('creed1'),('creek1'),('creep'),('creeper'),('creeper1'),('creepy'),('creepy1'),('creole'),('creosote'),('crepusculo'),('crescent'),('crespo'),('cretin'),('cretino'),('crevette'),('crf150'),('crf250'),('crf250r'),('crf450'),('crf450r'),('crfprf'),('crhbgrf'),('cri'),('cricket'),('cricket1'),('cricket11'),('cricket12'),('cricket123'),('cricket2'),('cricket7'),('cricketer'),('crickett'),('cricri'),('crime1'),('criminal'),('criminal1'),('crimson'),('crimson1'),('crip'),('crip12'),('crip123'),('crip13'),('crip4life'),('crip60'),('crip66'),('crippin1'),('crips'),('crips1'),('crips13'),('crips6'),('cris'),('cris12'),('cris123'),('crisis'),('crispin'),('crispy'),('crispy1'),('crissangel'),('crissy'),('crissy1'),('cristal'),('cristal1'),('cristel'),('cristh'),('cristhian'),('cristi'),('cristian'),('cristian1'),('cristian12'),('cristiana'),('cristiane'),('cristiano'),('cristiano1'),('cristiano7'),('cristianor'),('cristianoronaldo'),('cristin'),('cristina'),('cristina1'),('cristina12'),('cristine'),('cristo'),('cristo1'),('cristo7'),('cristobal'),('cristofer'),('cristopher'),('cristovive'),('cristy'),('cristy1'),('critical'),('critter'),('critter1'),('critters'),('crjhgbjy'),('crjhjcnm'),('crjnbyf'),('CrkUrrP954'),('cro'),('croatia'),('croatia1'),('crochet'),('crockett'),('crocodil'),('crocodile'),('crocodile1'),('crocus'),('cromwell'),('cronaldo'),('cronaldo7'),('cronic'),('cronic1'),('cronic420'),('cronin'),('cronos'),('croquette'),('crosby'),('crosby1'),('crosby87'),('croskey'),('cross'),('cross1'),('cross123'),('crossbow'),('crosscountry'),('crossfire'),('crossfire1'),('crossover'),('crossroad'),('crossroads'),('crossword'),('crow'),('CrowBird'),('crowley'),('crown'),('crown1'),('crownvic1'),('cruise'),('cruise1'),('cruiser'),('cruiser1'),('crumpet'),('crunch'),('crunch1'),('crunchie'),('crunchy'),('crunchy1'),('crunk'),('crunk1'),('crusade'),('crusader'),('crusader1'),('crusaders'),('crusaders1'),('crush'),('crush1'),('crusher'),('crusher1'),('crusty'),('crusty1'),('cruz'),('cruz123'),('cruzazul'),('cruzazul1'),('cruzazul10'),('cruzeiro'),('cry'),('crybaby'),('crybaby1'),('crying'),('crypto'),('crysis'),('crystal'),('crystal!'),('crystal01'),('crystal08'),('crystal09'),('crystal1'),('crystal10'),('crystal11'),('crystal12'),('crystal123'),('crystal13'),('crystal14'),('crystal16'),('crystal18'),('crystal2'),('crystal21'),('crystal22'),('crystal23'),('crystal3'),('crystal4'),('crystal5'),('crystal6'),('crystal69'),('crystal7'),('crystal8'),('crystal9'),('crystals'),('crystalsaga'),('cs1234'),('cs123456'),('cshrc'),('csillag'),('cstrike'),('csyekz'),('csyjxtr'),('cs_000'),('ctcnhf'),('ctcnhtyrf'),('ctdfcnjgjkm'),('cth'),('cthlwt'),('ctht'),('ctht:f'),('cthtuf'),('cthulhu'),('cthutq'),('cthuttd'),('cthuttdbx'),('cthuttdf'),('cthuttdyf'),('ctrhtn'),('ctvtyjd'),('ctvtyjdf'),('cualquiera'),('cuatro'),('cuba'),('cuba123'),('cubalibre'),('cuban1'),('cubana'),('cubanita'),('cubanito'),('cubano'),('cubano1'),('cubbie'),('cubbie1'),('cubbies'),('cubbies1'),('cubby'),('cubby1'),('cubs'),('cubs12'),('cubs123'),('cubs1908'),('cubs23'),('cubswin'),('cubswin1'),('cucaracha'),('cucciola'),('cucciolo'),('cuckoo'),('cucumber'),('cucumber1'),('cuddle'),('cuddle1'),('cuddles'),('cuddles1'),('cuddles12'),('cuddles123'),('cuddles2'),('cuenca'),('cuervo'),('cuevas'),('cuisine'),('culiacan1'),('culinary'),('culinary1'),('culito'),('cullen'),('cullen1'),('culo'),('cultura'),('culture'),('culture1'),('cum'),('cumberland'),('cumming'),('cummings'),('cummins'),('cummins1'),('cumshot'),('cunningham'),('cunt'),('cunt12'),('cunt123'),('cunt666'),('cunt69'),('cuntface'),('cuntface1'),('cuore'),('cuoricino'),('cupcake'),('cupcake!'),('cupcake.'),('cupcake01'),('cupcake09'),('cupcake1'),('cupcake10'),('cupcake101'),('cupcake11'),('cupcake12'),('cupcake123'),('cupcake13'),('cupcake14'),('cupcake15'),('cupcake2'),('cupcake21'),('cupcake22'),('cupcake23'),('cupcake24'),('cupcake3'),('cupcake4'),('cupcake5'),('cupcake6'),('cupcake69'),('cupcake7'),('cupcake8'),('cupcake9'),('cupcakes'),('cupcakes1'),('cupcakes12'),('cupid'),('cupid1'),('cupido'),('cupidon'),('cupoftea'),('cuppycake1'),('curious'),('curious1'),('curitiba'),('curley'),('curling'),('curly'),('curly1'),('currency'),('current'),('current1'),('curry'),('curry1'),('curtains'),('curtis'),('curtis1'),('curtis12'),('curtis123'),('curtis2'),('custard'),('custard1'),('custer'),('custodio'),('custom'),('custom1'),('customer'),('customer1'),('customs'),('cute'),('cute01'),('cute07'),('cute08'),('cute09'),('cute10'),('cute101'),('cute11'),('cute12'),('cute123'),('cute1234'),('cute13'),('cute14'),('cute15'),('cute16'),('cute17'),('cute18'),('cute21'),('cute22'),('cute23'),('cuteako'),('cuteako1'),('cuteangel'),('cutebaby'),('cuteboy'),('cuteboy1'),('cutecute'),('cutegirl'),('cutegirl1'),('cutegurl'),('cuteko'),('cuteme'),('cuteness'),('cuteness1'),('cutes'),('cutey'),('cutey1'),('cuthbert'),('cutie'),('cutie!'),('cutie#1'),('cutie01'),('cutie06'),('cutie07'),('cutie08'),('cutie09'),('cutie1'),('cutie10'),('cutie101'),('cutie11'),('cutie12'),('cutie123'),('cutie1234'),('cutie13'),('cutie14'),('cutie15'),('cutie16'),('cutie17'),('cutie18'),('cutie19'),('cutie2'),('cutie21'),('cutie22'),('cutie23'),('cutie24'),('cutie3'),('cutie4'),('cutie45'),('cutie4life'),('cutie5'),('cutie6'),('cutie69'),('cutie7'),('cutie8'),('cutie9'),('cutie95'),('cutiegirl'),('cutiepie'),('cutiepie!'),('cutiepie01'),('cutiepie09'),('cutiepie1'),('cutiepie10'),('cutiepie11'),('cutiepie12'),('cutiepie13'),('cutiepie14'),('cutiepie2'),('cutiepie23'),('cutiepie3'),('cutiepie4'),('cutiepie5'),('cutiepie7'),('cutiepie9'),('cuties'),('cuties1'),('cutify'),('cutlass'),('cutlass1'),('cutter'),('cutter1'),('cuttie'),('cuttie1'),('cuttiepie1'),('cv1230'),('cvb123'),('cvbcvb'),('cvbhyjd'),('cvbhyjdf'),('cvbn'),('cvbn123'),('cvbncvbn'),('cvbnm'),('cvcvcv'),('cvetok'),('cvfqkbr'),('cvthnm'),('cvtifhbrb'),('cvzefh1gkc'),('cxfcnkbdfz'),('cxfcnmt'),('cxfcnmttcnm'),('cxy831126'),('cxzcxz'),('cxzdsaewq'),('cyber'),('cyber1'),('cyber123'),('cyberman'),('cybernet'),('cyberonline'),('cybershot'),('cyborg'),('cycle'),('cycling'),('cyclone'),('cyclone1'),('cyclones'),('cyclones1'),('cyclops'),('cyclops1'),('cyecvevhbr'),('cygnus'),('cygnusx1'),('cyjdsvujljv'),('cynthia'),('cynthia1'),('cynthia12'),('cynthia123'),('cynthia2'),('cypher'),('cypress'),('cypress1'),('cyprus'),('cyprus1'),('cyrano'),('cyrielle'),('cyril'),('cyrille'),('cyrus'),('cyrus1'),('cyt'),('cytuehjxrf'),('cytujdbr'),('cyy813zRvR'),('czarek'),('czarina'),('czarna'),('czarny'),('czekolada'),('czekolada1'),('czesio'),('czsxumtf'),('czz000'),('czz000000'),('czz123456'),('czz224466'),('d'),('d-block'),('d-money'),('d-x-m'),('d0023500'),('d00kie'),('d04081999'),('d0r1nc0urt'),('d11111'),('d111111'),('d123123'),('d12345'),('d123456'),('d1234567'),('d12345678'),('d123456789'),('d1amond'),('d1bd6bc58c1d74df41a957489c9942f5'),('d1d2d3'),('d1d2d3d4'),('d1e234tp'),('d1i2m3a4'),('D1lakiss'),('d21lWz1zjS'),('d2iTsr81jO'),('d2Tqqn28tC'),('d2Xyw89sxJ'),('d4'),('d41d8cd'),('d41d8cd98f00'),('d41d8cd98f00b204e980'),('d54p7xjkha'),('d54q7xjmhx'),('d55555'),('d654321'),('d666666'),('d68pyfuH2V'),('d6ug7epz'),('d71lWz9zjS'),('d7777777'),('d85lWz0zjS'),('d9160847880'),('d9189498'),('d9Zufqd92N'),('da'),('da1234'),('da123456'),('da1andonly'),('da1nonly'),('dabaddest1'),('dabears'),('dabears1'),('dabest'),('dabest1'),('dabomb'),('dabomb1'),('daboss'),('daboss1'),('dabulls'),('dachshund'),('dad'),('dad101'),('dad123'),('dad1234'),('dada'),('dada12'),('dada123'),('dadada'),('dadada1'),('dadadada'),('dadang'),('daddad'),('daddad1'),('daddie'),('daddio'),('daddy'),('daddy!'),('daddy#1'),('daddy\'sgir'),('daddy0'),('daddy01'),('daddy06'),('daddy07'),('daddy08'),('daddy09'),('daddy1'),('daddy10'),('daddy101'),('daddy11'),('daddy12'),('daddy123'),('daddy1234'),('daddy13'),('daddy14'),('daddy15'),('daddy16'),('daddy2'),('daddy21'),('daddy22'),('daddy23'),('daddy24'),('daddy25'),('daddy3'),('daddy33'),('daddy4'),('daddy5'),('daddy6'),('daddy69'),('daddy7'),('daddy8'),('daddy9'),('daddycool'),('daddygirl'),('daddygirl1'),('daddygirl2'),('daddygurl1'),('daddyo'),('daddyo1'),('daddys'),('daddys1'),('daddysboy1'),('daddysgirl'),('daddysgurl'),('daddyyanke'),('daddyyankee'),('dade305'),('dadmom'),('dadmom1'),('dadounet'),('dadsgirl'),('dadsgirl1'),('daedae'),('daedae1'),('daedalus'),('daemon'),('daewoo'),('daewoo1'),('daewoo65'),('daffodil'),('daffodil1'),('daffodils'),('daffy'),('daffy1'),('daffyduck'),('daffyduck1'),('daftpunk'),('daftpunk1'),('dagestan'),('dagestan05'),('dagger'),('dagger1'),('dagmar'),('dagmara'),('dagobert'),('dagreat1'),('dagwood'),('dahlia'),('daiana'),('daidai'),('daili123com'),('daimler'),('dairymilk'),('daisey'),('daisey1'),('daisies'),('daisuke'),('daisuke1'),('daisuki'),('daisy'),('daisy!'),('daisy01'),('daisy06'),('daisy07'),('daisy08'),('daisy09'),('daisy1'),('daisy10'),('daisy101'),('daisy11'),('daisy12'),('daisy123'),('daisy1234'),('daisy13'),('daisy14'),('daisy15'),('daisy2'),('daisy21'),('daisy22'),('daisy23'),('daisy3'),('daisy4'),('daisy5'),('daisy6'),('daisy69'),('daisy7'),('daisy8'),('daisy9'),('daisydog'),('daisydog1'),('daisyduke'),('daisyduke1'),('daisygirl'),('daisymae'),('daisymae1'),('daisymay'),('daisymay1'),('daisys'),('dajana'),('dak0ta'),('dakine'),('daking'),('daking1'),('dakoda1'),('dakota'),('dakota!'),('dakota00'),('dakota01'),('dakota02'),('dakota03'),('dakota04'),('dakota05'),('dakota06'),('dakota07'),('dakota08'),('dakota09'),('dakota1'),('dakota10'),('dakota11'),('dakota12'),('dakota123'),('dakota13'),('dakota14'),('dakota15'),('dakota2'),('dakota21'),('dakota22'),('dakota23'),('dakota3'),('dakota4'),('dakota5'),('dakota6'),('dakota69'),('dakota7'),('dakota8'),('dakota9'),('dakota98'),('dakota99'),('dakotah'),('dal'),('dalailama'),('dalbas73'),('dale'),('dale03'),('dale08'),('dale123'),('dale88'),('dalejr'),('dalejr08'),('dalejr1'),('dalejr8'),('dalejr88'),('dalia'),('dalia1'),('dalibor'),('dalida'),('dalila'),('dalila1'),('dallas'),('dallas!'),('dallas01'),('dallas05'),('dallas06'),('dallas07'),('dallas08'),('dallas09'),('dallas1'),('dallas10'),('dallas11'),('dallas12'),('dallas123'),('dallas13'),('dallas14'),('dallas15'),('dallas2'),('dallas21'),('dallas214'),('dallas22'),('dallas23'),('dallas24'),('dallas3'),('dallas31'),('dallas33'),('dallas4'),('dallas41'),('dallas5'),('dallas69'),('dallas7'),('dallas8'),('dallas81'),('dallas88'),('dallas9'),('dallas99'),('dallascowb'),('dallascowboys'),('dallastx'),('dalmata'),('dalmatian'),('dalmation'),('dalmation1'),('dalton'),('dalton01'),('dalton1'),('dalton12'),('dalton123'),('dalton2'),('dam'),('dam123'),('damage'),('damage1'),('daman'),('daman1'),('damaris'),('damaris1'),('damascus'),('damdam'),('damian'),('damian01'),('damian1'),('damian11'),('damian12'),('damian123'),('damian13'),('damian2'),('damian666'),('damiano'),('damien'),('damien1'),('damien12'),('damien123'),('damien2'),('damien666'),('damilare'),('damilola'),('damilola1'),('damion'),('damion1'),('damir'),('damira.shagabutdinova'),('dammit'),('dammit1'),('damn'),('damn123'),('damned'),('damnit'),('damnit!'),('damnit1'),('damnyou'),('damola'),('damon'),('damon1'),('damon123'),('damsel'),('dan'),('dan123'),('dan1234'),('dan12345'),('dan1el'),('dan1elle'),('dana'),('dana-14'),('dana11'),('dana12'),('dana123'),('dana1234'),('danadana'),('danang'),('dance'),('dance!'),('dance01'),('dance07'),('dance08'),('dance09'),('dance1'),('dance10'),('dance101'),('dance11'),('dance12'),('dance123'),('dance13'),('dance14'),('dance15'),('dance16'),('dance2'),('dance21'),('dance22'),('dance23'),('dance3'),('dance4'),('dance4ever'),('dance4life'),('dance4me'),('dance5'),('dance5678'),('dance7'),('dance8'),('dancedance'),('dancehall'),('dancer'),('dancer!'),('dancer.'),('dancer01'),('dancer07'),('dancer08'),('dancer09'),('dancer1'),('dancer10'),('dancer101'),('dancer11'),('dancer12'),('dancer123'),('dancer13'),('dancer14'),('dancer15'),('dancer16'),('dancer17'),('dancer18'),('dancer2'),('dancer21'),('dancer22'),('dancer23'),('dancer24'),('dancer3'),('dancer4'),('dancer5'),('dancer6'),('dancer7'),('dancer8'),('dancer87'),('dancer88'),('dancer9'),('dancers'),('dancers1'),('dances'),('dancing'),('dancing1'),('dancing123'),('dancing2'),('dancingqueen'),('dandan'),('dandan1'),('dandan123'),('dandandan'),('dandelion'),('dandy'),('dandy1'),('dane'),('danecook1'),('danelle'),('danette'),('dang'),('dangelo'),('danger'),('danger1'),('danger12'),('danger123'),('danger2'),('dangermouse'),('dangerous'),('dangerous1'),('dangerous12'),('dani'),('dani10'),('dani11'),('dani12'),('dani123'),('dani1234'),('dani13'),('dani22'),('dani3l'),('danial'),('danica'),('danica1'),('danidani'),('danie'),('danie1'),('daniel'),('daniel!'),('daniel.'),('daniel0'),('daniel00'),('daniel007'),('daniel01'),('daniel02'),('daniel03'),('daniel04'),('daniel05'),('daniel06'),('daniel07'),('daniel08'),('daniel09'),('daniel1'),('daniel10'),('daniel101'),('daniel11'),('daniel12'),('daniel123'),('daniel1234'),('daniel13'),('daniel14'),('daniel15'),('daniel16'),('daniel17'),('daniel18'),('daniel19'),('daniel1994'),('daniel2'),('daniel20'),('daniel2000'),('daniel2007'),('daniel2008'),('daniel2009'),('daniel2010'),('daniel21'),('daniel22'),('daniel23'),('daniel24'),('daniel25'),('daniel26'),('daniel27'),('daniel28'),('daniel29'),('daniel3'),('daniel30'),('daniel31'),('daniel33'),('daniel4'),('daniel5'),('daniel55'),('daniel6'),('daniel69'),('daniel7'),('daniel77'),('daniel8'),('daniel82'),('daniel83'),('daniel84'),('daniel85'),('daniel86'),('daniel87'),('daniel88'),('daniel89'),('daniel9'),('daniel90'),('daniel91'),('daniel92'),('daniel93'),('daniel94'),('daniel95'),('daniel96'),('daniel97'),('daniel98'),('daniel99'),('daniela'),('daniela.'),('daniela1'),('daniela10'),('daniela12'),('daniela123'),('daniela13'),('daniela2'),('daniele'),('daniele1'),('danielita'),('danielito'),('danielito1'),('daniell'),('daniella'),('daniella1'),('danielle'),('danielle!'),('danielle.'),('danielle01'),('danielle07'),('danielle08'),('danielle09'),('danielle1'),('danielle10'),('danielle11'),('danielle12'),('danielle123'),('danielle13'),('danielle14'),('danielle15'),('danielle16'),('danielle17'),('danielle18'),('danielle19'),('danielle2'),('danielle20'),('danielle21'),('danielle22'),('danielle23'),('danielle3'),('danielle4'),('danielle5'),('danielle6'),('danielle69'),('danielle7'),('danielle8'),('danielle9'),('daniels'),('daniels1'),('daniil'),('danijela'),('danika'),('danika1'),('danil'),('danil123'),('danila'),('danilka'),('danilo'),('danilo1'),('danilov'),('danilova'),('danish'),('danita'),('daniyar'),('dank'),('dank420'),('danman'),('danmark'),('danni'),('danni1'),('dannie'),('dannie1'),('dannielle'),('danny'),('danny!'),('danny01'),('danny06'),('danny07'),('danny08'),('danny09'),('danny1'),('danny10'),('danny101'),('danny11'),('danny12'),('danny123'),('danny1234'),('danny13'),('danny14'),('danny15'),('danny16'),('danny17'),('danny18'),('danny2'),('danny20'),('danny21'),('danny22'),('danny23'),('danny3'),('danny4'),('danny5'),('danny6'),('danny69'),('danny7'),('danny8'),('danny9'),('dannyb'),('dannyboy'),('dannyboy1'),('dannys'),('danone'),('danser'),('dantdm'),('dante'),('dante1'),('dante12'),('dante123'),('dante666'),('dantes'),('dantheman'),('dantheman1'),('dantist'),('danuta'),('danville'),('dany'),('dany123'),('danyel'),('danyelle'),('danzig'),('danzig1'),('danzig666'),('dan_cheb'),('daphne'),('daphne1'),('dapper'),('daquan'),('daquan1'),('dar'),('dar123'),('darby'),('darby1'),('darcy'),('darcy1'),('dardar'),('dardevilk'),('dare'),('dare123'),('daredevil'),('daredevil1'),('darek'),('darek1'),('daria'),('daria1'),('darian'),('darian1'),('darien'),('darien1'),('darina'),('darinka'),('dario'),('dario1'),('darion'),('darion1'),('darius'),('darius1'),('darius12'),('darius123'),('darius2'),('darjeeling'),('dark'),('dark11'),('dark12'),('dark123'),('dark1234'),('dark13'),('dark666'),('darkangel'),('darkangel1'),('darkangel2'),('darkangel6'),('darkblue'),('darkdark'),('darkdevil'),('darkdragon'),('darkelf'),('darker'),('darkfire'),('darkhorse'),('darkknight'),('darklight'),('darklight1'),('darklord'),('darklord1'),('darkman'),('darkman1'),('darkmanx'),('darkmaster'),('darkmoon'),('darkn3ss'),('darknes'),('darkness'),('darkness!'),('darkness0'),('darkness1'),('darkness11'),('darkness12'),('darkness13'),('darkness2'),('darkness3'),('darkness5'),('darkness6'),('darkness66'),('darkness7'),('darknight'),('darknight1'),('darko'),('darkone'),('darkone1'),('darkorbit'),('darkshadow'),('darkside'),('darkside1'),('darksoul'),('darkstar'),('darkstar1'),('darkwing'),('darkwolf'),('darla'),('darla1'),('darlene'),('darlene1'),('darlin'),('darlin1'),('darling'),('darling1'),('darling123'),('darlington'),('darnell'),('darnell1'),('darragh'),('darrel'),('darrell'),('darrell1'),('darren'),('darren1'),('darren12'),('darren123'),('darrin'),('darrin1'),('darrius1'),('darryl'),('darryl1'),('darshan'),('darshana'),('dartagnan'),('darth'),('darth1'),('darthmaul'),('darthvader'),('dartmouth'),('darvin'),('darwin'),('darwin1'),('darya'),('daryl'),('daryl1'),('daryll'),('das'),('das123'),('dasani'),('dasani1'),('dascha'),('dasdas'),('dasdasdas'),('dash'),('dash920'),('dasha'),('dasha1'),('dasha123'),('dasha1996'),('dasha1998'),('dasha2010'),('dashadasha'),('dashawn'),('dashawn1'),('dashboard'),('dashboard1'),('dashenka'),('dasher'),('dasher1'),('dashing'),('dashit1'),('dashka'),('dasilva'),('dastan'),('dat123'),('data'),('database'),('date'),('dateme'),('dates'),('dating'),('dating1'),('datnigga1'),('datsun'),('datuna'),('daughter'),('daughter1'),('daughter2'),('daughters'),('daughters2'),('daughters3'),('daulet'),('dauphin'),('dauphine'),('dauphins'),('dauren'),('dav'),('dav123'),('dave'),('dave01'),('dave11'),('dave12'),('dave123'),('dave1234'),('dave22'),('dave23'),('dave69'),('davedave'),('davenport'),('davenport1'),('davey'),('davey1'),('david'),('david!'),('david.'),('david00'),('david007'),('david01'),('david02'),('david03'),('david04'),('david05'),('david06'),('david07'),('david08'),('david09'),('david1'),('david10'),('david101'),('david11'),('david111'),('david12'),('david123'),('david1234'),('david12345'),('david13'),('david14'),('david15'),('david16'),('david17'),('david18'),('david19'),('david2'),('david20'),('david2000'),('david2006'),('david2007'),('david2008'),('david2009'),('david2010'),('david21'),('david22'),('david23'),('david24'),('david25'),('david26'),('david27'),('david28'),('david29'),('david3'),('david30'),('david33'),('david4'),('david45'),('david5'),('david55'),('david6'),('david666'),('david69'),('david7'),('david77'),('david777'),('david8'),('david87'),('david88'),('david89'),('david9'),('david99'),('davida'),('davidb'),('davidbeckham'),('davidbowie'),('davidc'),('davidd'),('daviddavid'),('davide'),('davide1'),('davidek'),('davidg'),('davidh'),('davidic1'),('davidj'),('davidk'),('davidka'),('davidl'),('davidlee'),('davidm'),('davido'),('davidoff'),('davidp'),('davidr'),('davids'),('davids1'),('davidson'),('davidson1'),('davidstrokov'),('davidt'),('davidvilla'),('davies'),('davila'),('davina'),('davina1'),('davinchi'),('davinci'),('davinci1'),('davion'),('davion1'),('davis'),('davis1'),('davis123'),('davon1'),('dawg'),('dawgs'),('dawgs1'),('dawid'),('dawid1'),('dawid123'),('dawidek'),('dawidek1'),('dawkins'),('dawkins20'),('dawn'),('dawn12'),('dawn123'),('dawood'),('dawson'),('dawson1'),('daxter'),('daxter1'),('day'),('day123'),('dayana'),('dayana1'),('dayanara'),('dayang'),('daybreak'),('daycare'),('daycare1'),('dayday'),('dayday1'),('dayday12'),('dayday123'),('dayday2'),('daydream'),('daydream1'),('daydreamer'),('daylight'),('daylight1'),('daytek'),('dayton'),('dayton1'),('daytona'),('daytona1'),('daytona500'),('daywalker'),('daz3d'),('dazzle'),('dazzle1'),('db'),('db1234'),('dbityrf'),('dbjktnnf'),('dblock'),('dblock1'),('DBM'),('dbnfkbq'),('dbnfkbr'),('dbnfkz'),('dbnzyxbr'),('dbrecz'),('dbrekz'),('dbrf'),('dbrfdbrf'),('dbrnjh'),('dbrnjhbz'),('dbrnjhjdbx'),('dbrnjhjdyf'),('dbyjuhfl'),('dbz123'),('dc'),('dc1234'),('dc123456'),('dcba4321'),('dcltabih01'),('dcshoes'),('dcshoes1'),('dct'),('dct:'),('dctdjkjl'),('dctktyyfz'),('dctulf'),('dctvghbdtn'),('dcwdcw'),('dd'),('dd1234'),('dd123456'),('ddd'),('ddd111'),('ddd123'),('ddd333'),('dddd'),('ddddd'),('ddddd1'),('dddddd'),('dddddd1'),('ddddddd'),('dddddddd'),('ddddddddd'),('dddddddddd'),('ddzj39cb3'),('ddzj49nb3'),('de'),('dea'),('deacon'),('deacon1'),('dead'),('dead12'),('dead123'),('dead13'),('dead666'),('deaddead'),('deaddog'),('deadend'),('deadeye'),('deadfish'),('deadhead'),('deadhead1'),('deadline'),('deadlock'),('deadly'),('deadly1'),('deadman'),('deadman1'),('deadman2'),('deadman8'),('deadmau5'),('deadmeat'),('deadpool'),('deadpool1'),('deadspace'),('deadwood'),('deagle'),('dealer'),('deamon'),('dean'),('dean11'),('dean12'),('dean123'),('deandre'),('deandre1'),('deangelo'),('deangelo1'),('deanna'),('deanna1'),('deanna12'),('deanne'),('deano'),('deano1'),('dear'),('dearbook'),('deardear'),('dearest'),('dearmama'),('death'),('death!'),('death1'),('death101'),('death11'),('death12'),('death123'),('death13'),('death2'),('death2all'),('death2u'),('death3'),('death5'),('death6'),('death666'),('death69'),('death7'),('deathangel'),('deathcore'),('deathmetal'),('deathnote'),('deathnote1'),('deathnote2'),('deathrow'),('deathrow1'),('deaths'),('deathstar'),('deathstar1'),('deathtoall'),('deathwish'),('deathwish1'),('deb'),('deb123'),('debbie'),('debbie01'),('debbie1'),('debbie12'),('debbie123'),('debbie2'),('debbie69'),('debby'),('debil'),('debora'),('debora1'),('deborah'),('deborah1'),('debra'),('debra1'),('debtfree'),('dec'),('decade'),('decatur'),('decatur1'),('december'),('december01'),('december05'),('december06'),('december07'),('december08'),('december09'),('december1'),('december10'),('december11'),('december12'),('december13'),('december14'),('december15'),('december16'),('december17'),('december18'),('december19'),('december2'),('december20'),('december21'),('december22'),('december23'),('december24'),('december25'),('december26'),('december27'),('december28'),('december29'),('december3'),('december30'),('december31'),('december4'),('december5'),('december6'),('december7'),('december8'),('december9'),('decembre'),('decembrie'),('decent'),('deception'),('decker'),('declan'),('declan1'),('decode'),('ded'),('dedamiwa'),('dede'),('dede12'),('dede123'),('dedede'),('dedede1'),('dededede'),('dedewang'),('dedicated'),('dedication'),('dedmoroz'),('dee'),('dee123'),('deedee'),('deedee1'),('deedee11'),('deedee12'),('deedee123'),('deedee13'),('deedee2'),('deedee3'),('deedeedee1'),('deejay'),('deejay1'),('deep'),('deep123'),('deepa'),('deepak'),('deepak123'),('deepali'),('deepblue'),('deeper'),('deepfrequency'),('deepika'),('deeppurple'),('deepsea'),('deepspace9'),('deepthi'),('deepti'),('deer'),('deer12'),('deer123'),('deere1'),('deerhunt'),('deerhunt1'),('deerhunter'),('deerpark'),('deerpark1'),('deerslayer'),('deeter_1'),('deeven'),('deeznuts'),('deeznuts1'),('deeznutz'),('deeznutz1'),('def'),('def123'),('def456'),('default'),('Default05'),('default1'),('default_password'),('defcon'),('defcon1'),('defence'),('defender'),('defender1'),('defender101'),('defense'),('defense1'),('defiance'),('defiant'),('defiant1'),('defjam'),('defjam1'),('defleppard'),('deftones'),('deftones1'),('degrassi'),('degrassi1'),('degree'),('deguzman'),('dehradun'),('dei3mutter'),('deicide'),('deicide666'),('deidara'),('deidre'),('deimos'),('deinemudda'),('deinemutter'),('deion21'),('deirdre'),('deirjj'),('dejavu'),('dejavu1'),('dejesus'),('DEKALB'),('del'),('del123'),('delacruz'),('delacruz1'),('delaney'),('delaney1'),('delano'),('delano1'),('delapan'),('delarosa'),('delatorre'),('delaware'),('delaware1'),('delbert'),('delbert1'),('delboy'),('deleon'),('deleon1'),('delete'),('delete1'),('delete123'),('delete2'),('deleted'),('deleted1'),('delfin'),('delfin1'),('delfina'),('delfines'),('delfino'),('delgado'),('delgado1'),('delhi'),('delhi123'),('delia'),('delia1'),('delicia'),('delicious'),('delicious1'),('delight'),('delight1'),('delilah'),('delilah1'),('delima'),('delirium'),('delirium9111'),('deliver'),('Delivered'),('delivery'),('dell'),('dell10'),('dell11'),('dell12'),('dell123'),('dell1234'),('dell13'),('dell22'),('dell23'),('dell500'),('della'),('della1'),('delldell'),('delldell1'),('delmar'),('delmar1'),('deloitte'),('delonge'),('delorean'),('delores'),('delores1'),('delosreyes'),('delphi'),('delphin'),('delphine'),('delphine1'),('delpiero'),('delpiero10'),('delrosario'),('delsol'),('delta'),('delta1'),('delta12'),('delta123'),('delta2'),('delta3'),('delta4'),('delta5'),('delta7'),('delta88'),('delta9'),('deltaforce'),('deltas'),('deluge'),('deluxe'),('deluxe1'),('delvalle'),('dem'),('demain'),('demarco'),('demarcus'),('demarcus1'),('demarrer'),('dembel'),('demented'),('dementia'),('dementor'),('demeter'),('demetra'),('demetria'),('demetrio'),('demetrius'),('demetrius1'),('demi'),('demi123'),('demian'),('demilovato'),('demo'),('demo123'),('democrat'),('demola'),('demolay'),('demolition'),('demon'),('demon1'),('demon12'),('demon123'),('demon1234'),('demon12345'),('demon13'),('demon1q2w3e'),('demon1q2w3e4r'),('demon1q2w3e4r5t'),('demon2'),('demon6'),('demon666'),('demond'),('demond1'),('demonhunter'),('demonic'),('demonic1'),('demonio'),('demons'),('demons1'),('demonyo'),('dempsey'),('dempsey1'),('den'),('den123'),('den1ks'),('den1ska'),('den221991'),('denali'),('denali1'),('denden'),('denden1'),('deneme'),('denhaag'),('denice'),('denied'),('denilson'),('deniro'),('denis'),('denis1'),('denis12'),('denis123'),('denis1991'),('denis1992'),('denis1994'),('denis1995'),('denis1996'),('denis1997'),('denis1998'),('denisa'),('denisdenis'),('denise'),('denise01'),('denise07'),('denise08'),('denise09'),('denise1'),('denise10'),('denise11'),('denise12'),('denise123'),('denise13'),('denise14'),('denise15'),('denise18'),('denise2'),('denise21'),('denise22'),('denise23'),('denise3'),('denise5'),('denise69'),('denise7'),('deniska'),('denisov'),('deniss'),('denisse'),('denisse1'),('denis_nazarenko'),('deniz'),('denizli'),('denmark'),('denmark1'),('dennis'),('dennis01'),('dennis1'),('dennis10'),('dennis11'),('dennis12'),('dennis123'),('dennis13'),('dennis2'),('dennis22'),('dennis23'),('denny'),('denny1'),('dennys'),('denpasar'),('dental'),('dental1'),('dentist'),('dentist1'),('dentista'),('denton'),('denver'),('denver07'),('denver1'),('denver12'),('denver123'),('denver15'),('denver2'),('denver3'),('denver303'),('denver7'),('denya2531914'),('denzel'),('denzel1'),('denzil'),('deonte1'),('depeche'),('depeche1'),('depeche101'),('depechemode'),('deportivo'),('depressed'),('depressed1'),('depression'),('deputy'),('deputy1'),('der'),('der123'),('derbeder'),('derby'),('derby1'),('derder'),('derecho'),('dereck'),('derector-85'),('derek'),('derek1'),('derek12'),('derek123'),('derek2'),('derekjeter'),('derevo'),('derf'),('derfderf'),('derick'),('derick1'),('derp'),('derp12!@'),('derparol'),('derrick'),('derrick1'),('derrick12'),('derrick123'),('derrick2'),('des'),('des123'),('desadesa'),('desant'),('descartes'),('descent'),('desdemona'),('desdes'),('desember'),('desert'),('desert1'),('desertrose'),('deshaun1'),('deshawn'),('deshawn1'),('desi'),('desi123'),('desiderata'),('desiderio'),('design'),('design1'),('design123'),('designdeal'),('designer'),('designer1'),('designs'),('desirae'),('desirae1'),('desire'),('desire1'),('desiree'),('desiree1'),('desiree12'),('desiree123'),('desiree2'),('deskjet'),('deskjet1'),('desktop'),('desktop1'),('desmond'),('desmond1'),('desmond123'),('desperado'),('desperado1'),('desperados'),('desperate'),('dessert'),('dessie'),('destin'),('destin1'),('destination'),('destinee'),('destinee1'),('destiney'),('destiney1'),('destini'),('destini1'),('destino'),('destiny'),('destiny!'),('destiny.'),('destiny01'),('destiny02'),('destiny04'),('destiny05'),('destiny06'),('destiny07'),('destiny08'),('destiny09'),('destiny1'),('destiny10'),('destiny11'),('destiny12'),('destiny123'),('destiny13'),('destiny14'),('destiny15'),('destiny2'),('destiny21'),('destiny22'),('destiny23'),('destiny3'),('destiny4'),('destiny5'),('destiny6'),('destiny69'),('destiny7'),('destiny8'),('destiny9'),('destiny99'),('destroy'),('destroy1'),('destroyer'),('destroyer1'),('destruction'),('det313'),('details'),('detective'),('detective1'),('determination'),('determined'),('dethklok'),('dethklok1'),('detroit'),('detroit1'),('detroit12'),('detroit2'),('detroit3'),('detroit313'),('detroit7'),('deuce'),('deuce1'),('deuce2'),('deuce22'),('deus'),('deuseamor'),('deusefiel'),('deusex'),('deutsch'),('deutsch1'),('deutschlan'),('deutschland'),('dev'),('dev123'),('devan1'),('devante'),('devante1'),('devastator'),('devdas'),('develop'),('developer'),('development'),('devendra'),('devera'),('device'),('devika'),('devil'),('devil1'),('devil12'),('devil123'),('devil13'),('devil2'),('devil6'),('devil666'),('devil69'),('devilboy'),('devildog'),('devildog1'),('devildriver'),('devilish'),('devilish1'),('deviljin'),('deville'),('devilman'),('devilman1'),('devilmaycr'),('devilmaycry'),('devilmaycry4'),('devils'),('devils1'),('devilz'),('devin'),('devin1'),('devin11'),('devin12'),('devin123'),('devin13'),('devin2'),('devin23'),('devin3'),('devin7'),('devina'),('devine'),('devine1'),('devious'),('devious1'),('devlin'),('devochka'),('devon'),('devon1'),('devon11'),('devon12'),('devon123'),('devon2'),('devonte'),('devonte1'),('devotion'),('dewa19'),('dewalt'),('dewayne'),('dewayne1'),('dewdrop'),('dewey'),('dewey1'),('dewitt'),('dexter'),('dexter01'),('dexter1'),('dexter10'),('dexter11'),('dexter12'),('dexter123'),('dexter13'),('dexter2'),('dexter21'),('dexter22'),('dexter5'),('deyanira'),('dezember'),('dezembro'),('df'),('dfa72dfj'),('dfaeff34232'),('dfasnewa'),('dfcbkbcf'),('dfcbkbq'),('dfcbkmtd'),('dfcbkmtdf'),('dfcbktr'),('dfcmrf'),('dfcz'),('dfczcghjcbnm'),('dfczdfcz'),('dfdbkjy'),('dfdfdf'),('dfg'),('dfg123'),('dfg5Fhg5VGFh1'),('dfgdfg'),('dfgdfgdfg'),('dfghjc'),('dfghjk'),('dfghjkl'),('dfhdfhf'),('dfhtybr'),('dfkmrbhbz'),('dfkthbq'),('dfkthbz'),('dfkthf'),('dfktyjr'),('dfktynby'),('dfktynbyf'),('dfktynbyrf'),('dflbvrf'),('dfvgbh'),('dfy.if'),('dfymrf'),('dfytxrf'),('dg123456'),('dgaf420'),('DGf68Yg'),('dgkallday'),('dgkallday1'),('dgonni86'),('dhananjay'),('dhanya'),('dharma'),('dharma1'),('dheeraj'),('dhillon'),('dhiraj'),('dhjnvytyjub'),('dhtlbyf'),('di'),('dia'),('diabetes'),('diabetes1'),('diable'),('diablo'),('diablo01'),('diablo1'),('diablo11'),('diablo12'),('diablo123'),('diablo13'),('diablo2'),('diablo22'),('diablo3'),('diablo6'),('diablo666'),('diablo69'),('diablos'),('diabolik'),('diabolika'),('diabolo'),('diadora'),('diallo'),('dialog'),('diamant'),('diamante'),('diamante1'),('diamond'),('diamond!'),('diamond.'),('diamond01'),('diamond06'),('diamond07'),('diamond08'),('diamond09'),('diamond1'),('diamond10'),('diamond11'),('diamond12'),('diamond123'),('diamond13'),('diamond14'),('diamond15'),('diamond16'),('diamond17'),('diamond18'),('diamond2'),('diamond21'),('diamond22'),('diamond23'),('diamond24'),('diamond3'),('diamond4'),('diamond5'),('diamond6'),('diamond69'),('diamond7'),('diamond8'),('diamond9'),('diamonds'),('diamonds1'),('diamonds12'),('diamonds2'),('diana'),('diana01'),('diana1'),('diana10'),('diana11'),('diana12'),('diana123'),('diana13'),('diana14'),('diana15'),('diana1998'),('diana2'),('diana22'),('diana23'),('diana3'),('diana5'),('diana7'),('dianaa'),('dianadiana'),('dianas'),('diandra'),('diane'),('diane1'),('diane123'),('dianita'),('dianita1'),('diank123'),('dianka'),('dianna'),('dianna1'),('dianne'),('dianne1'),('dianochka'),('dianochka1924'),('diaper'),('diapers'),('diarra'),('diavolo'),('dibble'),('dic'),('dicembre'),('diciembre'),('diciembre1'),('diciembre2'),('dick'),('dick01'),('dick101'),('dick11'),('dick12'),('dick123'),('dick1234'),('dick13'),('dick22'),('dick23'),('dick69'),('dickdick'),('dickens'),('dickens1'),('dicker'),('dickey'),('dickface'),('dickface1'),('dickhead'),('dickhead1'),('dickhead12'),('dickhead2'),('dickhead69'),('dickie'),('dickie1'),('dickies'),('dickies1'),('dickinson'),('dicks'),('dicks1'),('dickson'),('dicksucker'),('dickweed'),('dickweed1'),('dicky'),('dictionary'),('did'),('diddle'),('diddlina'),('diddy'),('diddy1'),('didi'),('didi123'),('dididi'),('didididi'),('didier'),('didine'),('didou'),('die'),('die123'),('die666'),('diebitch1'),('diedie'),('diedie1'),('diediedie'),('diego'),('diego01'),('diego1'),('diego10'),('diego11'),('diego12'),('diego123'),('diego13'),('diego2'),('diegos'),('dieguito'),('diehard'),('diehard1'),('diesel'),('diesel01'),('diesel1'),('diesel11'),('diesel12'),('diesel123'),('diesel2'),('diesel69'),('diet'),('dietcoke'),('dietcoke1'),('dieter'),('dietpepsi'),('dietpepsi1'),('dietrich'),('dieumerci'),('different'),('different1'),('difficult'),('dig'),('digger'),('digger1'),('digger12'),('diggler'),('digimon'),('digimon1'),('digimon123'),('digital'),('digital1'),('digital123'),('dignity'),('dikoalam'),('diksha'),('dil'),('dilara'),('dilbert'),('dilbert1'),('dildil'),('dildo'),('dildo1'),('dildo69'),('dilemma'),('diletta'),('dillan'),('diller'),('dilligaf'),('dilligaf1'),('dillinger'),('dillion'),('dillion1'),('dillon'),('dillon01'),('dillon1'),('dillon11'),('dillon12'),('dillon123'),('dillon2'),('dilshod'),('dim'),('dima'),('dima007'),('dima12'),('dima123'),('dima1234'),('dima12345'),('dima1984'),('dima1986'),('dima1987'),('dima1988'),('dima1989'),('dima1990'),('dima1991'),('dima1992'),('dima199219921'),('dima1993'),('dima1994'),('dima1995'),('dima1996'),('dima1997'),('dima1998'),('dima1999'),('dima2000'),('dima2002'),('dima2009'),('dima2010'),('dima35360'),('dima777'),('dimabilan'),('dimadima'),('dimafilippov'),('dimanche'),('dimapet09'),('dimaraja'),('dimarik'),('dimas'),('dimas34rus'),('dimasik'),('dimastic'),('dimdim'),('dime10'),('dimebag'),('dimebag1'),('dimension'),('dimension1'),('dimepiece1'),('dimitr692010'),('dimitri'),('dimitri1'),('dimitris'),('dimlimonov'),('dimmuborgir'),('dimo4ka'),('dimochka'),('dimok091'),('dimon'),('dimon1'),('dimond'),('dimond1'),('dimple'),('dimple1'),('dimples'),('dimples1'),('dimples2'),('dimulya.vasilenko'),('din'),('din123'),('dina'),('dina123'),('dinadina'),('dinamit'),('dinamita'),('dinamo'),('dinamo1'),('dinara'),('dindin'),('dindon'),('dinero'),('dinero1'),('dinesh'),('dinesh123'),('dingbat'),('dingbat1'),('dingding'),('dingdong'),('dingdong1'),('dinger'),('dingle'),('dingle1'),('dingo'),('dingo1'),('dingo123'),('dingus'),('dinheiro'),('dinky'),('dinky1'),('dinmamma'),('dinmamma1'),('dinner'),('dinner1'),('dino'),('dino11'),('dino12'),('dino123'),('dino1234'),('dinodino'),('dinosaur'),('dinosaur1'),('dinosaurio'),('dinosaurs'),('dinosaurus'),('dinozavr'),('diocane'),('diogenes'),('diogo'),('diogo123'),('dionis'),('dionisio'),('dionne'),('dionne1'),('dios777'),('diosesamor'),('DIOSESFIEL'),('diosmeama'),('diosmio'),('diosteama'),('diosteamo'),('dipali'),('dipika'),('diplom'),('diploma'),('diplomat'),('diplomat1'),('diplomats1'),('dipo01'),('dipper'),('dipset'),('dipset1'),('dipset12'),('dipset123'),('dipset2'),('dipset23'),('dipset3'),('dipset5'),('dipset7'),('dipshit'),('dipshit1'),('dipstick'),('dipstick1'),('direct'),('direct1'),('direction'),('director'),('director1'),('direito'),('direktor'),('direngrey'),('dirk'),('dirk41'),('dirt'),('dirtbag'),('dirtbag1'),('dirtbike'),('dirtbike1'),('dirtbike12'),('dirtbike2'),('dirtbike7'),('dirtbiker1'),('dirtbikes'),('dirtbikes1'),('dirty'),('dirty1'),('dirty12'),('dirty123'),('dirty30'),('dirty69'),('dirtydog'),('dirtysouth'),('dis'),('disaster'),('disaster1'),('disc'),('disciple'),('disciple1'),('discipline'),('disco'),('disco1'),('disco123'),('discount'),('discover'),('discover1'),('discovery'),('discovery1'),('discreet'),('discus'),('dishant'),('disney'),('disney!'),('disney01'),('disney07'),('disney08'),('disney1'),('disney10'),('disney11'),('disney12'),('disney123'),('disney13'),('disney2'),('disney22'),('disney3'),('disney365'),('disney411'),('disney5'),('disney7'),('disneyland'),('disorder'),('dispatch'),('dispatch1'),('display'),('distance'),('disturbed'),('disturbed1'),('disturbed2'),('ditto'),('ditto1'),('diva'),('diva01'),('diva07'),('diva08'),('diva09'),('diva10'),('diva101'),('diva11'),('diva12'),('diva123'),('diva1234'),('diva13'),('diva14'),('diva16'),('diva21'),('diva22'),('diva23'),('diva4life'),('divadiva'),('divagirl'),('divagirl1'),('diver'),('diver1'),('divers'),('diversion'),('diversity'),('divina'),('divina1'),('divine'),('divine1'),('diving'),('divinity'),('divino'),('division'),('division1'),('divorce'),('divorce1'),('divorce2'),('divorced'),('divorced1'),('divx'),('divya'),('dIWtgm8492'),('dixie'),('dixie01'),('dixie1'),('dixie12'),('dixie123'),('dixie2'),('dixie3'),('dixiedog'),('dixiedog1'),('dixon'),('dixon1'),('dizzle'),('dizzle1'),('dizzy'),('dizzy1'),('dizzy123'),('dj'),('dj1234'),('dj12345'),('dj123456'),('dj4life'),('djamel'),('djamila'),('django'),('django1'),('djdjdj'),('djdjfedor'),('djdjxrf'),('djdxbr'),('djedenhit'),('djembe'),('djerba'),('djeter'),('djeter2'),('djghjc'),('djhjyf'),('djhjyf010'),('djhvbrc'),('djibouti'),('djibril'),('djkjlz'),('djkrjd'),('djkrjdf'),('djkrjlfd'),('djkujuhfl'),('djkxbwf'),('djljktq'),('djmaikl86'),('djon.net'),('djtatko'),('djtiesto'),('dkair8dda'),('dkflbckfd'),('dkflbckfdf'),('dkflbdjcnjr'),('dkflbr'),('dkflbvbh'),('dkflbvbhjdbx'),('dkflbvbhjdyf'),('dkssud'),('dkssud12'),('dKxjIzc282'),('dkz1999'),('dlfaor09'),('DlNVHvu492'),('dm1234'),('dmb2010'),('dmband'),('Dmedcn23sd'),('dmitri'),('dmitriev'),('dmitrii'),('dmitrii-skargo'),('dmitrij'),('dmitrij.mironov2014'),('dmitriy'),('dmitry'),('dmoney'),('dmoney1'),('dmsgk0103'),('dmwdmw'),('dmx123'),('dnangel'),('dnflwlq'),('dnina666'),('dnstuff'),('do'),('dobber'),('doberman'),('doberman1'),('dobermann'),('doc'),('doc123'),('docdoc'),('docent'),('dochka'),('docinho'),('docker'),('dockers'),('docrafts'),('docteur'),('doctor'),('doctor1'),('doctor12'),('doctor123'),('doctorwho'),('doctorwho1'),('document'),('dod'),('dodge'),('dodge01'),('dodge1'),('dodge123'),('dodge1500'),('dodge2'),('dodge2500'),('dodge99'),('dodger'),('dodger1'),('dodgeram'),('dodgeram1'),('dodgers'),('dodgers1'),('dodgers11'),('dodgers12'),('dodgers123'),('dodgers13'),('dodgers2'),('dodgers3'),('dodgers5'),('dodgers99'),('dodges'),('dodgeviper'),('dodo'),('dodo12'),('dodo123'),('dododo'),('dododo1'),('dodododo'),('dodong'),('doeboy1'),('dog'),('dog100'),('dog101'),('dog111'),('dog123'),('dog1234'),('dog12345'),('dog123456'),('dog4life'),('dogbert'),('dogbone'),('dogbone1'),('dogboy'),('dogboy1'),('dogbreath'),('dogbreath1'),('dogcat'),('dogcat1'),('dogdog'),('dogdog1'),('dogdogdog'),('dogeatdog'),('dogface'),('dogface1'),('dogfight'),('dogfish'),('dogfood'),('dogfood1'),('dogg'),('dogger'),('doggie'),('doggie1'),('doggie12'),('doggie123'),('doggie2'),('doggie3'),('doggies'),('doggies1'),('doggies2'),('doggone'),('doggy'),('doggy1'),('doggy11'),('doggy12'),('doggy123'),('doggy2'),('doggy3'),('doggy4'),('doggy5'),('doggy6'),('doggy69'),('doggy7'),('doggydog'),('doggydog1'),('doggys'),('doggys1'),('doggystyle'),('doghouse'),('doghouse1'),('doglover'),('doglover1'),('dogma'),('dogma1'),('dogman'),('dogman1'),('dogmeat'),('dogpound'),('dogpound1'),('dogs'),('dogs101'),('dogs11'),('dogs12'),('dogs123'),('dogs1234'),('dogshit'),('dogshit1'),('dogsrule'),('dogsrule1'),('dogstar'),('dogtown'),('dogtown1'),('dogwood'),('dogwood1'),('doherty'),('doit'),('doitnow'),('dok74rus'),('dokken'),('doktor'),('dol'),('dolapo'),('dolce'),('dolce1'),('dolcevita'),('dolemite'),('dolfijn'),('dolfin'),('dolgushina.76'),('dolina'),('doll'),('dollar'),('dollar1'),('dollar123'),('dollarbill'),('dollarking5'),('dollars'),('dollars1'),('dollbaby'),('dollface'),('dollface1'),('dollhouse'),('dollie'),('dollie1'),('dolly'),('dolly1'),('dolly12'),('dolly123'),('dolores'),('dolores1'),('dolphin'),('dolphin!'),('dolphin01'),('dolphin1'),('dolphin10'),('dolphin11'),('dolphin12'),('dolphin123'),('dolphin13'),('dolphin2'),('dolphin21'),('dolphin22'),('dolphin23'),('dolphin3'),('dolphin4'),('dolphin5'),('dolphin6'),('dolphin69'),('dolphin7'),('dolphin8'),('dolphin9'),('dolphine'),('dolphins'),('dolphins!'),('dolphins1'),('dolphins12'),('dolphins13'),('dolphins2'),('dolphins3'),('dolphins7'),('dom'),('dom123'),('domain'),('domain123'),('domani'),('domdom'),('dome'),('dome69'),('domenic'),('domenica'),('domenico'),('domi'),('domina'),('dominate'),('domination'),('dominator'),('dominator1'),('dominga'),('domingo'),('domingo1'),('domingos'),('dominguez'),('dominguez1'),('domini'),('dominic'),('dominic1'),('dominic12'),('dominic123'),('dominic2'),('dominic3'),('dominic5'),('dominic7'),('dominica'),('dominican'),('dominican1'),('dominican2'),('dominicana'),('dominicano'),('dominick'),('dominick1'),('dominik'),('dominik1'),('dominik123'),('dominika'),('dominika1'),('dominion'),('dominion1'),('dominique'),('dominique1'),('dominique2'),('domino'),('domino1'),('domino11'),('domino12'),('domino123'),('domino2'),('dominos'),('dominos1'),('dominus'),('don'),('don123'),('don12345'),('donald'),('donald01'),('donald1'),('donald12'),('donald123'),('donald2'),('donald356'),('donaldduck'),('donatella'),('donatello'),('donato'),('donavan'),('donavan1'),('donbosco'),('doncaster'),('dondon'),('dondon1'),('done'),('donegal'),('dong'),('dongdong'),('donita'),('donjuan'),('donjuan1'),('donkey'),('donkey1'),('donkey11'),('donkey12'),('donkey123'),('donkey2'),('donkey3'),('donkey69'),('donkey7'),('donkeykong'),('donkeys'),('donna'),('donna1'),('donna12'),('donna123'),('donna2'),('donnas'),('donnell'),('donnell1'),('donnelly'),('donner'),('donnie'),('donnie1'),('donny'),('donny1'),('donomar'),('donomar1'),('donotenter'),('donovan'),('donovan1'),('donskihv'),('donsun123'),('dont'),('dont4get'),('dontae1'),('dontask'),('dontcare'),('dontcare1'),('donte1'),('dontforget'),('donthate'),('donthate1'),('dontknow'),('dontknow1'),('donttouch'),('dontworry'),('donut'),('donut1'),('donuts'),('donuts1'),('donvito1'),('doo'),('doobie'),('doobie1'),('doodah'),('doodie'),('doodie1'),('doodle'),('doodle1'),('doodle12'),('doodle123'),('doodle2'),('doodlebug'),('doodlebug1'),('doodles'),('doodles1'),('doodoo'),('doodoo1'),('doodoo2'),('doofus'),('doogie'),('doogie1'),('dookenr1'),('dookie'),('dookie1'),('dookie2'),('dooley'),('dooley1'),('doolittle'),('doom'),('doom12'),('doom123'),('doom666'),('doomdoom'),('doomed'),('Doomsayer.2.7mords.V'),('Doomsayer.2.7mords.VV'),('doomsday'),('doomsday1'),('door'),('doorbell'),('doordie'),('doorknob'),('doorknob1'),('doors'),('doors1'),('doozer'),('dope'),('dope123'),('dopeboy1'),('dopeman1'),('dopey'),('dopey1'),('dor'),('dora'),('dora11'),('dora12'),('dora123'),('dorado'),('doradora'),('doraemon'),('doraemon1'),('dorcas'),('doreen'),('doreen1'),('doremi'),('doremi123'),('doremifa'),('doremon'),('dorian'),('dorian1'),('doriane'),('dorina'),('dorine'),('doris'),('doris1'),('doris123'),('dorita'),('doritos'),('doritos1'),('dork'),('dork12'),('dork123'),('dorky1'),('doroga'),('dorota'),('dorota1'),('dorotea'),('dorothea'),('dorothee'),('dorothy'),('dorothy1'),('dorothy2'),('dorotka'),('dorsey'),('dortmund'),('dortmund09'),('dortmund1'),('dos'),('dossantos'),('dotcom'),('dotdot'),('dothedew'),('dothedew1'),('dotnet'),('dottie'),('dottie1'),('dottore'),('dotty1'),('dou'),('double'),('double07'),('double1'),('double2'),('double7'),('doubled'),('doubled1'),('doublej'),('douche'),('douche1'),('douchebag'),('douchebag1'),('doudou'),('doudou1'),('doudoune'),('doug'),('doug123'),('dougal'),('doughboy'),('doughboy1'),('doughnut'),('doughnut1'),('dougie'),('dougie1'),('douglas'),('douglas1'),('douglas12'),('douglas123'),('douglas2'),('douglass'),('dounia'),('doutdes'),('dovbeshkosushova.1972'),('dove'),('dove797'),('dowitcher'),('down'),('down4life'),('downey'),('downhill'),('downhill1'),('download'),('download1'),('downloads'),('downtown'),('downtown1'),('downunder'),('dozer'),('dozer1'),('dozer123'),('dpbk1234'),('dpetrucco2'),('dr'),('dr.dre'),('dr.karaul'),('dr.pepper'),('dr0wssap'),('dr1234'),('dr4g0n'),('dr4life'),('dra'),('drache'),('drachen'),('draco'),('draco1'),('dracon'),('draconis'),('dracula'),('dracula1'),('drag0n'),('dragan'),('dragana'),('dragao'),('drago'),('drago1'),('dragon'),('dragon!'),('dragon.'),('dragon0'),('dragon00'),('dragon007'),('dragon01'),('dragon02'),('dragon05'),('dragon06'),('dragon07'),('dragon08'),('dragon09'),('dragon1'),('dragon10'),('dragon100'),('dragon101'),('dragon11'),('dragon12'),('dragon123'),('dragon1234'),('dragon13'),('dragon14'),('dragon15'),('dragon16'),('dragon17'),('dragon18'),('dragon19'),('dragon2'),('dragon20'),('dragon2000'),('dragon21'),('dragon22'),('dragon23'),('dragon24'),('dragon25'),('dragon26'),('dragon27'),('dragon28'),('dragon3'),('dragon30'),('dragon31'),('dragon32'),('dragon33'),('dragon34'),('dragon4'),('dragon42'),('dragon420'),('dragon44'),('dragon45'),('dragon5'),('dragon52'),('dragon55'),('dragon56'),('dragon6'),('dragon64'),('dragon66'),('dragon666'),('dragon67'),('dragon69'),('dragon7'),('dragon75'),('dragon76'),('dragon77'),('dragon777'),('dragon78'),('dragon79'),('dragon8'),('dragon81'),('dragon82'),('dragon83'),('dragon84'),('dragon85'),('dragon86'),('dragon87'),('dragon88'),('dragon89'),('dragon9'),('dragon90'),('dragon91'),('dragon92'),('dragon93'),('dragon94'),('dragon95'),('dragon96'),('dragon97'),('dragon98'),('dragon99'),('dragonage'),('dragonbal1'),('dragonball'),('dragonball1'),('dragonballgt'),('dragonballz'),('dragonballz1'),('dragone'),('dragones'),('dragonfable'),('dragonfire'),('dragonfly'),('dragonfly1'),('dragonfly2'),('dragonfly3'),('dragonfly7'),('dragonforce'),('dragonheart'),('dragonite'),('dragonking'),('dragonlady'),('dragonlance'),('dragonlord'),('dragonman'),('dragonmaster'),('dragons'),('dragons1'),('dragons11'),('dragons12'),('dragons123'),('dragons13'),('dragons2'),('dragons3'),('dragons5'),('dragons7'),('dragonslayer'),('dragonz'),('dragoon'),('dragoon1'),('dragos'),('dragoste'),('Dragoste123'),('dragrace'),('dragstar'),('dragster'),('dragster1'),('drake'),('drake1'),('drake12'),('drake123'),('draken'),('drakon'),('drakula'),('drama'),('drama1'),('drama101'),('drama123'),('dramaqueen'),('drandreb'),('dranzer'),('draper'),('draven'),('draven1'),('dravid'),('drawing'),('dre'),('dre123'),('dread1'),('dreads'),('dream'),('dream1'),('dream12'),('dream123'),('dream13'),('dream2'),('dream5'),('dream7'),('dreambig'),('dreambig1'),('dreamboy'),('dreamcast'),('dreamcast1'),('dreamcatcher'),('dreamer'),('dreamer1'),('dreamer12'),('dreamer123'),('dreamer13'),('dreamer2'),('dreamer3'),('dreamer7'),('dreamer8'),('dreamers'),('dreamgirl'),('dreamgirl1'),('dreaming'),('dreaming1'),('dreamland'),('dreamon'),('dreamon1'),('dreams'),('dreams.'),('dreams1'),('dreams12'),('dreams123'),('dreams2'),('dreamteam'),('dreamteam1'),('dreamtheater'),('dreamweaver'),('dreamworld'),('dreamy'),('dreamz'),('dreday'),('dreday1'),('dredre'),('dredre1'),('dresden'),('dresden1'),('dressage'),('dressup'),('drevil'),('drew'),('drew11'),('drew12'),('drew123'),('drew1234'),('drew13'),('drew22'),('drewdrew'),('drexel'),('dri'),('drift'),('drift1'),('drifter'),('drifter1'),('drifting'),('driftking'),('driftking1'),('driftwood'),('driller'),('drilling'),('drink'),('drink1'),('drink7up'),('drinking'),('drinking1'),('drinks'),('dripik'),('drive'),('driven'),('driver'),('driver1'),('driver8'),('driving'),('drizzt'),('drizzt1'),('drjynfrnt'),('DRM199019902323'),('dro'),('drogba'),('drogba11'),('dron'),('droopy'),('droopy1'),('dropdead'),('dropdead1'),('dropkick'),('drowssap'),('drowssap1'),('drowssap12'),('drowssap2'),('drozdovaksusha'),('drpepper'),('drpepper1'),('drpepper12'),('drpepper2'),('drpepper23'),('drpepper3'),('drpepper7'),('dru'),('drugfree'),('drugs'),('drugs1'),('drugsty'),('drum'),('drumandbass'),('drumer'),('drumline'),('drumline1'),('drummer'),('drummer1'),('drummer12'),('drummer123'),('drummer2'),('drummer3'),('drummer7'),('drummerboy'),('drummers'),('drumming'),('drummond'),('drumnbass'),('drumnbass1'),('drums'),('drums1'),('drums123'),('drumset'),('drumset1'),('drumstick'),('drunk'),('drunk1'),('drunken'),('drywall'),('drywall1'),('ds'),('ds1234'),('ds123456'),('dsa123'),('dsadsa'),('dsadsadsa'),('dsdsds'),('DSK4R9bskh'),('DsmVssQ955'),('DsmWssR955'),('dst1913'),('dt123456'),('dthjxrf'),('dthjybrf'),('dthjybxrf'),('dthyjcnm'),('dtkjcbgtl'),('dtlmvf'),('dtown214'),('dtxyjcnm'),('dtythf'),('du8484'),('dua82'),('duality'),('duane'),('duane1'),('duarte'),('dub'),('dubai'),('dubai123'),('dublin'),('dublin1'),('Dublin16'),('dublin22'),('dubois'),('dubstep'),('duc'),('ducados'),('ducati'),('ducati1'),('ducati1098'),('ducati748'),('ducati916'),('ducati996'),('ducati999'),('duchess'),('duchess1'),('duchesse'),('duck'),('duck11'),('duck12'),('duck123'),('duckduck'),('duckduck1'),('duckhunter'),('duckie'),('duckie1'),('duckies'),('duckies1'),('duckling'),('duckman'),('duckman1'),('ducks'),('ducks1'),('ducky'),('ducky1'),('ducky123'),('ducky2'),('dud'),('dude'),('dude01'),('dude10'),('dude101'),('dude11'),('dude12'),('dude123'),('dude1234'),('dude13'),('dude14'),('dude15'),('dude21'),('dude22'),('dude23'),('dude33'),('dude55'),('dude69'),('dude77'),('dudedude'),('dudedude1'),('dudeman'),('dudeman1'),('dudes'),('dudes1'),('dudette'),('dudinha'),('dudley'),('dudley1'),('dudu'),('dudu123'),('dududu'),('dudule'),('dud_1995'),('duece2'),('duende'),('duffbeer'),('duffer'),('duffman'),('duffy'),('duffy1'),('dugong'),('duh123'),('duhast'),('duhduh'),('duhduh1'),('duisburg'),('duke'),('duke01'),('duke07'),('duke08'),('duke10'),('duke11'),('duke12'),('duke123'),('duke1234'),('duke13'),('duke21'),('duke22'),('duke23'),('duke33'),('duke3d'),('dukedog'),('dukedog1'),('dukeduke'),('dukenukem'),('dukes1'),('dukester'),('dulce'),('dulce1'),('dulce123'),('dulcemaria'),('dulcinea'),('duluth'),('dum'),('dumass'),('dumass1'),('dumb'),('dumbass'),('dumbass!'),('dumbass1'),('dumbass123'),('dumbass2'),('dumbbitch'),('dumbbitch1'),('dumbdumb'),('dumbfuck1'),('dumbledore'),('dumbo'),('dumbo1'),('dumbshit1'),('dumdum'),('dumdum1'),('dumitru'),('dummies'),('dummy'),('dummy1'),('dummy123'),('dumnezeu'),('dumpling'),('dumpster'),('dun'),('dunamis'),('dunbar'),('duncan'),('duncan1'),('duncan12'),('duncan123'),('duncan21'),('dundee'),('dundee1'),('dune2000'),('dungeon'),('dungeon1'),('dunhill'),('dunkin'),('dunkin1'),('dunlop'),('dunno'),('dunno1'),('dupa'),('dupa11'),('dupa12'),('dupa123'),('dupa1234'),('dupa666'),('dupablada'),('dupadupa'),('dupadupa1'),('dupeczka'),('dupont'),('dupont24'),('dur'),('duracell'),('duramax'),('duran'),('duran1'),('duran2'),('durand'),('duranduran'),('durango'),('durango1'),('durant35'),('durban'),('durham'),('durham1'),('durian'),('dus'),('duskolyan'),('duster'),('duster1'),('dustin'),('dustin!'),('dustin01'),('dustin1'),('dustin11'),('dustin12'),('dustin123'),('dustin13'),('dustin14'),('dustin2'),('dustin23'),('dustin3'),('dustin69'),('dustin7'),('dusty'),('dusty1'),('dusty12'),('dusty123'),('dusty2'),('dustydog'),('dustydog1'),('dutch'),('dutch1'),('dutches'),('dutches1'),('dutchess'),('dutchess1'),('dutchman'),('duval1'),('duval904'),('dvd123'),('dvddvd'),('dvorak'),('dwade03'),('dwade3'),('dwayne'),('dwayne1'),('dwayne3'),('dwight'),('dwight1'),('dx1234'),('dylan'),('dylan!'),('dylan01'),('dylan02'),('dylan03'),('dylan04'),('dylan05'),('dylan06'),('dylan07'),('dylan08'),('dylan09'),('dylan1'),('dylan10'),('dylan11'),('dylan12'),('dylan123'),('dylan13'),('dylan14'),('dylan15'),('dylan2'),('dylan22'),('dylan23'),('dylan3'),('dylan4'),('dylan5'),('dylan6'),('dylan7'),('dylan8'),('dylan99'),('dylandog'),('dylans'),('dymkovpavel'),('dynamic'),('dynamic1'),('dynamite'),('dynamite1'),('dynamo'),('dynasty'),('dynasty1'),('dynomite'),('dziubek'),('dzxtckfd'),('e'),('e-eremeeva1976'),('e-mail'),('e.ovcharova'),('e10adc3949ba59abbe56'),('e12345'),('e123456'),('e1234567'),('e12345678'),('e123456789'),('e23456'),('E2yFp41B'),('e3r4t5y6'),('e3w2q1'),('e5FhxkqIBw'),('e65r82kni2'),('e65r82mnj2'),('e65r82mpj2'),('e6fc37'),('e6pz84qfCJ'),('e7yvsskj'),('e8sZn4e5zC'),('e93c50'),('eadgbe'),('eager'),('eagle'),('eagle01'),('eagle1'),('eagle11'),('eagle12'),('eagle123'),('eagle2'),('eagle3'),('eagle5'),('eagle7'),('eagleeye'),('eagleone'),('eagles'),('eagles!'),('eagles01'),('eagles05'),('eagles06'),('eagles07'),('eagles08'),('eagles09'),('eagles1'),('eagles10'),('eagles11'),('eagles12'),('eagles123'),('eagles13'),('eagles14'),('eagles15'),('eagles2'),('eagles20'),('eagles21'),('eagles22'),('eagles23'),('eagles24'),('eagles25'),('eagles3'),('eagles33'),('eagles36'),('eagles4'),('eagles5'),('eagles69'),('eagles7'),('eagles8'),('eagles81'),('eagles9'),('eagles99'),('eanovozhilov'),('earl'),('earnest'),('earnhardt'),('earnhardt3'),('earnhardt8'),('earth'),('earth1'),('earth123'),('earthquake'),('easier'),('east'),('east12'),('east123'),('east13'),('east1999'),('eastcoast'),('eastcoast1'),('eastenders'),('easter'),('easter1'),('eastern'),('eastern1'),('easton'),('easton1'),('eastpak'),('eastside'),('eastside02'),('eastside1'),('eastside12'),('eastside13'),('eastside14'),('eastside2'),('eastside21'),('eastside23'),('eastside3'),('eastside4'),('eastside5'),('eastside6'),('eastwest'),('eastwood'),('eastwood1'),('easy'),('easy12'),('easy123'),('easy1234'),('easyas123'),('easyeasy'),('easymoney'),('easyrider'),('easyspiro'),('easytocrack1'),('eat'),('eatadick'),('eating'),('eatme'),('eatme1'),('eatme123'),('eatme2'),('eatme69'),('eatmenow'),('eatmyshorts'),('eatpussy'),('eatpussy1'),('eatpussy69'),('eatshit'),('eatshit!'),('eatshit1'),('eatshit2'),('eatshit69'),('eazy-e'),('eazye1'),('ebay'),('EBEANS'),('ebenezer'),('ebony'),('ebony1'),('ebony123'),('ecapsym1'),('ecaterina'),('ecgt'),('echelon'),('echizen18'),('echo'),('echo123'),('echoecho'),('echoes'),('ecko72'),('eclair'),('eclipse'),('eclipse1'),('eclipse2'),('eclipse3'),('eclipse7'),('eclipse99'),('ecology'),('economia'),('economic'),('economics'),('economist'),('ecstasy'),('ecuador'),('ecuador1'),('ecureuil'),('ed'),('ed1234'),('ed123456'),('edalwin12'),('edberg'),('edcrfv'),('edcvfr'),('edd'),('eddie'),('eddie01'),('eddie1'),('eddie11'),('eddie12'),('eddie123'),('eddie13'),('eddie2'),('eddie23'),('eddie3'),('eddie4'),('eddie5'),('eddie69'),('eddie7'),('eddies'),('eddy'),('eddy12'),('eddy123'),('ededed'),('edelweiss'),('eden'),('edgar'),('edgar1'),('edgar12'),('edgar123'),('edgar13'),('edgard'),('edgardo'),('edgardo1'),('edge'),('edgewood'),('edhardy'),('edhardy1'),('edi'),('edifier'),('edinburgh'),('edinburgh1'),('edison'),('edison1'),('edith'),('edith1'),('edition'),('editor'),('edIz27v1kQ'),('edmond'),('edmond1'),('edmonton'),('edmonton1'),('edmund'),('edmund1'),('edmundo'),('edoardo'),('edouard'),('edu'),('edu123'),('edu2008'),('eduard'),('eduarda'),('eduardito'),('eduardo'),('eduardo1'),('eduardo10'),('eduardo12'),('eduardo123'),('eduardo13'),('eduardo2'),('educate'),('education'),('education1'),('edvard'),('edw'),('edward'),('edward!'),('edward.'),('edward01'),('edward08'),('edward09'),('edward1'),('edward10'),('edward101'),('edward11'),('edward12'),('edward123'),('edward1234'),('edward13'),('edward14'),('edward15'),('edward16'),('edward17'),('edward18'),('edward1901'),('edward2'),('edward21'),('edward22'),('edward23'),('edward24'),('edward25'),('edward3'),('edward4'),('edward5'),('edward6'),('edward69'),('edward7'),('edward8'),('edward9'),('edwardcull'),('edwardcullen'),('edwardo'),('edwards'),('edwards1'),('edwards99'),('edwige'),('edwin'),('edwin1'),('edwin123'),('edwina'),('edxk20qMfS'),('ee19920528'),('eee'),('eee123'),('eee333'),('eeee'),('eeeee'),('eeeee1'),('eeeeee'),('eeeeee1'),('eeeeeee'),('eeeeeeee'),('eeeeeeeeee'),('eeyore'),('eeyore1'),('eeyore12'),('eeyore123'),('eeyore2'),('EFB'),('effect'),('efimkin_igor'),('efnesonline'),('efrain'),('efrain1'),('efsane'),('egghead'),('egghead1'),('eggman'),('eggnog'),('eggplant'),('eggplant1'),('eggroll'),('eggroll1'),('eggs'),('egipto'),('egitto'),('ego'),('egoist'),('egor'),('egor.vasilin'),('egorka'),('egorov'),('egorova'),('egorov_maxim'),('egshm1'),('egypt'),('egypt1'),('egypte'),('egyptian'),('Eh1K9oh335'),('ehdgnl12'),('ehlb3c18TW'),('ehlbcTW'),('ei33a'),('eiffel'),('eiffel65'),('eight'),('eight8'),('eight88'),('eight888'),('eightball'),('eightball1'),('eightball8'),('eighteen'),('eighteen18'),('eighty8'),('eiknon11'),('eileen'),('eileen1'),('eindhoven'),('einstein'),('einstein1'),('eintracht'),('eistee'),('eitaeita'),('ekaterina'),('ekbnrf'),('ekmzyf'),('ekx1x3k9BS'),('el'),('el1zabeth'),('ela'),('elaina'),('elaine'),('elaine01'),('elaine1'),('elaine12'),('elaine123'),('elaine2'),('elamor'),('elanor'),('elantra'),('elbarto'),('elbereth'),('elbert'),('elcamino'),('elcamino1'),('elcubano1893A'),('eldiablo'),('eldorado'),('eldorado1'),('ele'),('eleanor'),('eleanor1'),('eleazar'),('electra'),('electra1'),('electric'),('electric1'),('electrical'),('electrician'),('electro'),('electro1'),('electron'),('electronic'),('electronica'),('electronics'),('elefant'),('elefant1'),('elefante'),('elefante1'),('elegance'),('elegant'),('elektra'),('elektra1'),('elektrik'),('elektro'),('elektro73'),('element'),('element!'),('element.'),('element0'),('element1'),('element11'),('element12'),('element123'),('element13'),('element14'),('element2'),('element3'),('element4'),('element5'),('element6'),('element69'),('element7'),('element8'),('element9'),('elemental'),('elemental1'),('elementary'),('elements'),('elements1'),('elena'),('elena1'),('elena12'),('elena123'),('elena2010'),('elenaelena'),('elenanesterova'),('elenas'),('elenberg'),('elendil'),('elenita'),('elenka'),('elensobko'),('elenst14'),('eleonor'),('eleonora'),('eleonore'),('elephant'),('elephant!'),('elephant1'),('elephant11'),('elephant12'),('elephant123'),('elephant2'),('elephant3'),('elephant5'),('elephant7'),('elephants'),('elephants1'),('elessar'),('elettra'),('elevation'),('elevator'),('eleven'),('eleven1'),('eleven11'),('elfenlied'),('elfriede'),('elgato'),('elgato1'),('elgordo'),('elguapo'),('eli'),('eli123'),('eliana'),('eliana1'),('eliane'),('elias'),('elias1'),('elias123'),('elie3173'),('elieli'),('eliezer'),('elijah'),('elijah01'),('elijah03'),('elijah04'),('elijah05'),('elijah06'),('elijah07'),('elijah08'),('elijah09'),('elijah1'),('elijah10'),('elijah11'),('elijah12'),('elijah123'),('elijah13'),('elijah2'),('elijah23'),('elijah3'),('elijah4'),('elijah5'),('elijah7'),('elina'),('elinor'),('eliott'),('elisa'),('elisa1'),('elisa123'),('elisabet'),('elisabeth'),('elisabeth1'),('elisabetta'),('elise'),('elise1'),('elise123'),('eliseo'),('elisha'),('elisha1'),('eliska'),('elissa'),('elite'),('elite1'),('elite123'),('elixir'),('eliza'),('eliza1'),('eliza123'),('elizabet'),('elizabeth'),('elizabeth!'),('elizabeth.'),('elizabeth0'),('elizabeth1'),('elizabeth12'),('elizabeth123'),('elizabeth2'),('elizabeth3'),('elizabeth4'),('elizabeth5'),('elizabeth6'),('elizabeth7'),('elizabeth8'),('elizabeth9'),('elizaveta'),('eljefe'),('ell'),('ella'),('ella12'),('ella123'),('ellabella'),('ellabella1'),('ellada'),('ellaine'),('ellamae'),('ellarose'),('elle'),('ellehcim'),('ellen'),('ellen1'),('ellen123'),('ellie'),('ellie1'),('ellie12'),('ellie123'),('ellie2'),('elliemae'),('elliemae1'),('elliemay'),('elliot'),('elliot1'),('elliott'),('elliott1'),('ellipsis'),('ellis'),('ellis1'),('ellison'),('ellobo'),('elloco'),('elloco1'),('elmatador'),('elmejor'),('elmejor1'),('elmer'),('elmer1'),('elmira'),('elmo'),('elmo01'),('elmo11'),('elmo12'),('elmo123'),('elmo1234'),('elmo13'),('elmo14'),('elmo15'),('elmo22'),('elmo23'),('elmo69'),('elmoelmo'),('elmwood'),('elnegro'),('elnegro1'),('elnene'),('elnene1'),('elnino'),('elnumero1'),('elo'),('elocin'),('elodie'),('eloelo'),('elohim'),('eloisa'),('eloise'),('eloise1'),('elpapi'),('elpapi1'),('elpaso'),('elpaso1'),('elrey1'),('elrond'),('elsa'),('elsalvador'),('elshadai'),('elshaddai'),('elsie'),('elsie1'),('eltigre'),('elton1'),('eltonjohn'),('eltoro'),('elunico'),('elvin'),('elvina'),('elvira'),('elvira1'),('elvira198927'),('elvis'),('elvis01'),('elvis1'),('elvis11'),('elvis12'),('elvis123'),('elvis13'),('elvis1977'),('elvis2'),('elvis69'),('elvis77'),('elvislives'),('elvisp'),('elvisp1'),('elvispresley'),('elviss'),('elway07'),('elway7'),('elwood'),('elwood1'),('elwooo'),('elynca96'),('elyssa'),('elzbieta'),('ema'),('ema123'),('emachine'),('emachine1'),('emachines'),('emachines1'),('emachines2'),('email'),('email1'),('email123'),('EMAILONLY'),('eman'),('eman123'),('emanon'),('emanuel'),('emanuel1'),('emanuela'),('emanuele'),('embassy'),('embassy1'),('embrace'),('emelec'),('emelia'),('emelie'),('emeline'),('emerald'),('emerald1'),('emerald7'),('emeralds'),('emeraude'),('emergency'),('emergency1'),('emerica'),('emerica1'),('emerica2'),('emerson'),('emerson1'),('emery1'),('emi'),('emi123'),('emil'),('emilee'),('emilee1'),('emilia'),('emilia1'),('emiliana'),('emiliano'),('emiliano1'),('emilie'),('emilie1'),('emilien'),('emilio'),('emilio1'),('emilka'),('emilly'),('emily'),('emily!'),('emily01'),('emily02'),('emily03'),('emily04'),('emily05'),('emily06'),('emily07'),('emily08'),('emily09'),('emily1'),('emily10'),('emily101'),('emily11'),('emily12'),('emily123'),('emily1234'),('emily13'),('emily14'),('emily15'),('emily16'),('emily17'),('emily18'),('emily2'),('emily2005'),('emily21'),('emily22'),('emily23'),('emily3'),('emily4'),('emily5'),('emily6'),('emily69'),('emily7'),('emily8'),('emily9'),('emily99'),('emilyann'),('emilyrose'),('emilys'),('emin3m'),('eminem'),('eminem!'),('eminem.'),('eminem01'),('eminem1'),('eminem10'),('eminem11'),('eminem12'),('eminem123'),('eminem1234'),('eminem13'),('eminem14'),('eminem15'),('eminem17'),('eminem2'),('eminem21'),('eminem22'),('eminem23'),('eminem3'),('eminem313'),('eminem4'),('eminem5'),('eminem6'),('eminem69'),('eminem7'),('eminem8'),('eminem88'),('eminemd12'),('emirates'),('emirhan'),('emm'),('emma'),('emma01'),('emma02'),('emma03'),('emma04'),('emma05'),('emma06'),('emma07'),('emma08'),('emma09'),('emma1'),('emma10'),('emma11'),('emma12'),('emma123'),('emma1234'),('emma13'),('emma14'),('emma2000'),('emma2003'),('emma2004'),('emma2005'),('emma2006'),('emma2007'),('emma2008'),('emma2009'),('emma2010'),('emma21'),('emma22'),('emma23'),('emma99'),('emmaemma'),('emmagrace'),('emmagrace1'),('emmajane'),('emmajean'),('emmalee'),('emmalee1'),('emmalou'),('emmalou1'),('emmalouise'),('emmanuel'),('emmanuel1'),('emmanuel12'),('emmanuel123'),('emmanuel2'),('emmanuel7'),('emmanuella'),('emmanuelle'),('emmarose'),('emmarose1'),('emmawatson'),('emmett'),('emmett1'),('emmie1'),('emmitt'),('emmitt22'),('emmy'),('emmylou'),('emo'),('emo101'),('emo123'),('emo1234'),('emo4ever'),('emo4life'),('emo666'),('emoboy'),('emoboy1'),('emocore'),('emoemo'),('emoemo1'),('emogirl'),('emogirl1'),('emogurl'),('emokid'),('emokid1'),('emokid123'),('emolove'),('emolove1'),('emolover'),('emoney'),('emoney1'),('emopunk'),('emopunk1'),('emotion'),('emotion1'),('emotional'),('emotional1'),('emotions'),('emo_limonad'),('emperador'),('emperor'),('emperor1'),('empire'),('empire1'),('empires'),('emploi'),('employment'),('emporio'),('emprego'),('empress'),('empress1'),('empty'),('emre123'),('emreemre'),('emyeuanh'),('enamorada'),('enamorada1'),('enamorado'),('encarta'),('enchanted'),('encore'),('encore1'),('encounter'),('encule'),('enculer'),('encyclopedia'),('endeavour'),('ender'),('ender1'),('endless'),('endless1'),('endlesslove'),('endurance'),('enduro'),('enemy'),('energia'),('energie'),('energizer'),('energizer1'),('energy'),('energy1'),('energy123'),('energystar'),('enfant'),('enfants'),('enfermagem'),('enfermera'),('enfield'),('enforcer'),('eng'),('engage'),('engel'),('engel00007'),('engel1'),('engelchen'),('engelchen1'),('engenharia'),('engine'),('engine1'),('engineer'),('engineer1'),('engineering'),('england'),('england1'),('england10'),('england12'),('england123'),('england2'),('england66'),('england7'),('english'),('english1'),('english12'),('english123'),('english2'),('english3'),('enigma'),('enigma1'),('eniola'),('enjoi1'),('enjoy'),('enjoy1'),('enjoylife'),('enocnayr'),('enomis'),('enough'),('enrica'),('enrico'),('enrico1'),('enrique'),('enrique1'),('enrique123'),('enriquez'),('ensemble'),('ensenada'),('enteng'),('enter'),('enter1'),('enter12'),('enter123'),('enter2'),('enter7'),('enterme'),('enternow'),('enterprise'),('enterprise1'),('enters'),('entertainment'),('entrada'),('entrance'),('entrar'),('entropy'),('enTu6ea64H'),('envelope'),('environment'),('envision'),('envision1'),('enyvbuois'),('enzo'),('enzyme'),('eoce59cL9U'),('epa650'),('ephraim'),('epiphany'),('epiphone'),('epiphone1'),('episode1'),('epsilon'),('epsilon1'),('epson'),('epson1'),('eqeS606898'),('equilibrium'),('equinox'),('equinox1'),('equity'),('equityDev'),('eR2SizO241'),('eragon'),('eragon1'),('eragon123'),('eraser'),('eraser1'),('erasmus'),('erast.82'),('erasure'),('ercole'),('erdbeere'),('erection'),('eremei_vasechkin'),('erenity'),('ererer'),('erevan'),('erfolg'),('erhfbyf'),('eri'),('eric'),('eric01'),('eric07'),('eric08'),('eric09'),('eric10'),('eric11'),('eric12'),('eric123'),('eric1234'),('eric13'),('eric14'),('eric15'),('eric16'),('eric17'),('eric18'),('eric21'),('eric22'),('eric23'),('eric24'),('eric69'),('erica'),('erica1'),('erica11'),('erica12'),('erica123'),('erica13'),('erica2'),('ericeric'),('erick'),('erick1'),('erick12'),('erick123'),('erick1234'),('ericka'),('ericka1'),('erickson'),('ericson'),('ericsson'),('ericsson1'),('erik'),('erik12'),('erik123'),('erika'),('erika1'),('erika12'),('erika123'),('erika13'),('erika2'),('erika22'),('erikas'),('erikerik'),('erikson'),('erin'),('erin11'),('erin12'),('erin123'),('erine!'),('eritrea'),('erlan'),('erlinda'),('ermakova'),('ernest'),('ernest1'),('ernest97'),('ernestina'),('ernestine'),('ernesto'),('ernesto1'),('ernestsantikov'),('ernie'),('ernie1'),('ernie123'),('erofka'),('eros'),('erotic'),('erotica'),('eroticy'),('errereer'),('erreway'),('error'),('ERS'),('ersatz'),('ert'),('ert123'),('ertert'),('ertyui'),('ervin'),('erwann'),('erwin'),('erwin1'),('eryyv588'),('erzurum'),('escada'),('escaflowne'),('escalade'),('escalade1'),('escalante'),('escape'),('escape1'),('escapethef'),('escargot'),('escobar'),('escobar1'),('escola'),('escondido'),('escorpiao'),('escorpio'),('escorpion'),('escorpion1'),('escort'),('escort1'),('escuela'),('esenin'),('esercito'),('esidez57'),('eskimo'),('eskimo1'),('esmeralda'),('esmeralda1'),('esmeralda2'),('esoteric'),('esp'),('espace'),('espada'),('espagne'),('espana'),('espana1'),('espanha'),('espanol'),('especial'),('espejo'),('esperanca'),('esperance'),('esperanto'),('esperanza'),('esperanza1'),('espero'),('espinosa'),('espinoza'),('espinoza1'),('espiritu'),('espoir'),('esponja'),('esposito'),('espresso'),('esprit'),('esqueci'),('esquire'),('essence'),('essence1'),('essendon'),('essendon1'),('essential'),('essj408'),('est'),('establish'),('estate'),('esteban'),('esteban1'),('esteem'),('estefani'),('estefania'),('estefania1'),('estefany'),('estela'),('estela1'),('estella'),('estella1'),('estelle'),('estelle1'),('ester'),('estetica'),('esther'),('esther1'),('esther12'),('esther123'),('estonia'),('estopa'),('estrada'),('estrada1'),('estrela'),('estrela1'),('estrelas'),('estrelinha'),('estrella'),('estrella1'),('estrella10'),('estrella12'),('estrella13'),('estrella2'),('estrella5'),('estrella7'),('estrellas'),('estrellita'),('estudante'),('estudiante'),('estudio'),('estupida'),('estupido'),('eszter'),('eternal'),('eternal1'),('eternel'),('eternity'),('eternity1'),('ethan'),('ethan01'),('ethan03'),('ethan04'),('ethan05'),('ethan06'),('ethan07'),('ethan08'),('ethan09'),('ethan1'),('ethan10'),('ethan11'),('ethan12'),('ethan123'),('ethan2'),('ethan3'),('ethan4'),('ethan5'),('EthanRyan01'),('ethel'),('ethel1'),('ethernet'),('ethiopia'),('ethiopia1'),('etienne'),('etienne1'),('etnies'),('etnies1'),('EtnXtxSa65'),('etoile'),('etoiles'),('eTravelmoleOptin'),('ettore'),('eu'),('euamojesus'),('euclid'),('EUdlEKB645'),('eueueu'),('eugene'),('eugene1'),('eugene12'),('eugene2'),('eugenia'),('eugenia1'),('eugenie'),('eugenio'),('eulalia'),('eumeamo'),('eumesma'),('eumesmo'),('eunice'),('eunice1'),('euphoria'),('eureka'),('eureka1'),('eureka7'),('euro2008'),('euro2012'),('eurogunz'),('euronics'),('europa'),('europa1'),('europe'),('europe1'),('eusebio'),('eusitu'),('euskadi'),('euteamo'),('euzinha'),('eva'),('eva123'),('evaeva'),('evamaria'),('evan'),('evan11'),('evan12'),('evan123'),('evanescenc'),('evanescence'),('evangelina'),('evangeline'),('evangelion'),('evangelist'),('evans'),('evans1'),('evaristo'),('evasion'),('eve'),('eve123'),('evelin'),('evelina'),('eveline'),('evelyn'),('evelyn1'),('evelyn12'),('evelyn123'),('evelyn2'),('evelyne'),('evenflow'),('events'),('everafter'),('everclear'),('everclear1'),('everest'),('everest1'),('everett'),('everett1'),('evergreen'),('evergreen1'),('everlast'),('everlast1'),('everlastin'),('everlasting'),('everlong'),('evermore'),('everquest'),('everquest1'),('everquest2'),('everton'),('everton1'),('everton11'),('everton123'),('everton1878'),('evertonfc'),('evertonfc1'),('every1'),('everybody'),('everyday'),('everyday1'),('everyone'),('everything'),('everytime'),('evette'),('evette1'),('evgeni'),('evgenia'),('evgenii'),('evgenii-shenderovich'),('evgenij'),('evgeniy'),('evgeniya'),('evgenkac'),('evgeny'),('evgesha'),('evh5150'),('evial_marina'),('evicka'),('evidence'),('evil'),('evil123'),('evil13'),('evil666'),('evildead'),('evildead1'),('evildick'),('evilone'),('evolution'),('evolution1'),('evolution2'),('evolution7'),('evolution8'),('evolution9'),('evolve'),('evony1'),('evony123'),('evony192'),('evropa'),('evybwf'),('ewan'),('ewanko'),('ewankosayo'),('ewelina'),('ewelina1'),('ewelinka'),('ewq123'),('ewq321'),('ewqdsacxz'),('ewqewq'),('ewunia'),('example'),('exbntkm'),('excal007'),('excaliber'),('excalibur'),('excalibur1'),('excel'),('excellence'),('excellent'),('excellent1'),('excelsior'),('exchange'),('excite'),('exclusive'),('exclusive1'),('executive'),('executor'),('exercise'),('exeter'),('Exi'),('Exigent'),('exitos'),('EXIT_WINDOW'),('exodia'),('exodus'),('exodus1'),('exotic'),('exotic1'),('expedition'),('expensive'),('experience'),('experiment'),('expert'),('expert12'),('explode'),('exploited'),('explore'),('explore1'),('explorer'),('explorer1'),('explosion'),('export'),('express'),('express1'),('expresso'),('extasy'),('extensa'),('extension'),('extra'),('extra1'),('extrem'),('extreme'),('extreme1'),('extremo'),('eybdth'),('eybdthcbntn'),('eyeball'),('eyeball1'),('eyeballs'),('eyecandy'),('eyecandy1'),('eyeliner1'),('eyeshield'),('eyeshield21'),('ezekiel'),('ezekiel1'),('Ezekiel11989'),('Ezekiel11991'),('ezequiel'),('ezequiel1'),('e_dovich'),('f'),('f00bar'),('f00tba11'),('f00tball'),('f0lhVBoK'),('f0rever'),('f12345'),('f123456'),('f1234567'),('f12345678'),('f123456789'),('f14tomcat'),('f15eagle'),('f1f2f3'),('f1f2f3f4'),('f1f2f3f4f5'),('f1uUHZa723'),('f22raptor'),('f246865h'),('f4u*123'),('f5GhyjqHAv'),('f75s83nqk3'),('f76t93nqk3'),('f76t94prm4'),('f:'),('fab'),('fab123'),('fabian'),('fabian1'),('fabian12'),('fabian123'),('fabiana'),('fabiano'),('fabien'),('fabienne'),('fabietto'),('fabio'),('fabio1'),('fabio123'),('fabiola'),('fabiola1'),('fable2'),('fabolous'),('fabolous1'),('fabregas'),('fabregas4'),('fabric'),('fabric1'),('fabrice'),('fabricio'),('fabrizio'),('fabulous'),('fabulous1'),('faca210898'),('face'),('face123'),('face2face'),('faceb00k'),('facebook'),('facebook1'),('facebook11'),('facebook12'),('facebook123'),('facebook2'),('facebox'),('faceoff'),('facial'),('facile'),('fackyou'),('factor'),('factory'),('factory1'),('facundo'),('fade2black'),('fadila'),('faerie'),('fafa'),('fafafa'),('fafnir'),('fag123'),('fagboy1'),('faget1'),('fagg0t'),('fagget'),('fagget1'),('faggot'),('faggot!'),('faggot.'),('faggot1'),('faggot12'),('faggot123'),('faggot2'),('faggot6'),('faggot69'),('fahbrf'),('faheem'),('fahjlbnf'),('fahrenheit'),('fai'),('failure'),('fairbanks'),('fairfax'),('fairfield'),('fairfield1'),('fairies'),('fairies1'),('fairlady'),('fairlane'),('fairmont'),('fairplay'),('fairview'),('fairway'),('fairways'),('fairy'),('fairy1'),('fairy123'),('fairydust'),('fairydust1'),('fairytail'),('fairytale'),('fairytale1'),('faisal'),('faisal1'),('faisal123'),('faisalabad'),('faith'),('faith01'),('faith06'),('faith07'),('faith08'),('faith09'),('faith1'),('faith10'),('faith101'),('faith11'),('faith12'),('faith123'),('faith13'),('faith2'),('faith21'),('faith22'),('faith23'),('faith3'),('faith4'),('faith5'),('faith56'),('faith6'),('faith7'),('faith77'),('faith777'),('faithful'),('faithful1'),('faithfull'),('faithingod'),('faithless'),('faiths'),('faithy'),('faizal'),('faizan'),('fajardo'),('fake'),('fake01'),('fake08'),('fake101'),('fake11'),('fake12'),('fake123'),('fake1234'),('fake13'),('fake22'),('fake69'),('fakeass1'),('fakebitch1'),('fakefake'),('fakefake1'),('fakegirl1'),('fakeid1'),('fakename'),('fakename1'),('fakeone1'),('fakepage1'),('faker'),('faker1'),('fakespace1'),('faktor'),('fal'),('falcao'),('falco'),('falcon'),('falcon01'),('falcon1'),('falcon10'),('falcon11'),('falcon12'),('falcon123'),('falcon13'),('falcon16'),('falcon2'),('falcon3'),('falcon5'),('falcon69'),('falcon7'),('falcons'),('falcons07'),('falcons1'),('falcons12'),('falcons2'),('falcons7'),('fall2007'),('fall2008'),('Fall2011'),('fallen'),('fallen1'),('fallen12'),('fallen123'),('fallen13'),('fallen2'),('fallen3'),('fallenange'),('fallenangel'),('fallen_angel'),('falling'),('falling1'),('fallinlove'),('fallon'),('fallon1'),('fallou'),('fallout'),('fallout1'),('fallout2'),('fallout3'),('falloutboy'),('falp5050'),('fam'),('fam1ly'),('famar219948'),('famiglia'),('familia'),('familia1'),('familia10'),('familia123'),('familia4'),('familia5'),('familie'),('families'),('familiyafamiliya'),('famille'),('family'),('family!'),('family#1'),('family.'),('family01'),('family03'),('family04'),('family05'),('family06'),('family07'),('family08'),('family09'),('family1'),('family10'),('family101'),('family11'),('family12'),('family123'),('family1234'),('family13'),('family14'),('family15'),('family1st'),('family2'),('family21'),('family22'),('family23'),('family3'),('family4'),('family5'),('family6'),('family7'),('family8'),('family9'),('familyguy'),('familyguy1'),('familyguy2'),('familylove'),('familyof4'),('familyof5'),('familyof6'),('famous'),('famous!'),('famous1'),('famous11'),('famous12'),('famous123'),('famous13'),('famous2'),('famous21'),('famous23'),('famous3'),('famous5'),('famous7'),('fan'),('fan123'),('fanatic'),('fanatik'),('fanculo'),('fancy'),('fancy1'),('fancypants'),('fandango'),('fandango1'),('fandome1'),('fanfan'),('fang2008'),('fangfang'),('fannie'),('fannie1'),('fanny'),('fanny1'),('fanny123'),('fanta'),('fanta1'),('fanta123'),('fantacy'),('fantasia'),('fantasia1'),('fantasma'),('fantastic'),('fantastic1'),('fantastic4'),('fantastico'),('fantasy'),('fantasy1'),('fantasy12'),('fantasy2'),('fantasy7'),('fantasy8'),('fantik'),('fantom'),('fantomas'),('far'),('far123'),('faraday'),('farah'),('farah1'),('farah123'),('faramir'),('faraon'),('faraway'),('farcry'),('farcry2'),('fardubay'),('farewell'),('farfalla'),('farfallina'),('farfar'),('fargo1'),('farhad'),('farhan'),('farhan123'),('farhana'),('farhat'),('farheen'),('farid'),('farida'),('farina'),('farkas'),('farley'),('farley1'),('farm'),('farmacia'),('farmall'),('farmboy'),('farmboy1'),('farmer'),('farmer1'),('farmers'),('farmers1'),('farmgirl'),('farmhouse'),('farming'),('farmville'),('farooq'),('farouk'),('farrah'),('farrah1'),('farrell'),('farrell1'),('fars419'),('farscape'),('farscape1'),('farside'),('farside1'),('fart'),('fart12'),('fart123'),('farted'),('farter'),('farter1'),('fartface'),('fartface1'),('fartfart'),('farthead'),('farthead1'),('farting'),('farting1'),('fartman'),('fartman1'),('farts'),('farts1'),('farzana'),('fas'),('fashion'),('fashion!'),('fashion1'),('fashion101'),('fashion12'),('fashion123'),('fashion2'),('fashion7'),('fashionist'),('fashionista'),('fast'),('fast123'),('fastback'),('fastball'),('fastball1'),('fastcar'),('fastcar1'),('fastcars'),('fastcars1'),('faster'),('faster1'),('fastfood'),('fastlane'),('fastrack'),('fasttrack'),('fat'),('fat123'),('fatal1'),('fatal1ty'),('fatality'),('fatamorgana'),('fatass'),('fatass1'),('fatass12'),('fatass123'),('fatass13'),('fatass2'),('fatass3'),('fatass69'),('fatbastard'),('fatbitch'),('fatbitch1'),('fatboi1'),('fatboy'),('fatboy01'),('fatboy1'),('fatboy10'),('fatboy11'),('fatboy12'),('fatboy123'),('fatboy13'),('fatboy2'),('fatboy21'),('fatboy23'),('fatboy3'),('fatboy5'),('fatboy69'),('fatboy7'),('fatboy99'),('fatboyslim'),('fatcat'),('fatcat1'),('fatcat12'),('fatcat123'),('fatcat2'),('fatcow'),('fatcow1'),('fatdaddy'),('fatdaddy1'),('fatdog'),('fatdog1'),('fate'),('fatema'),('fatfat'),('fatfat1'),('fatfuck1'),('fatgirl'),('fatgirl1'),('fathead'),('fathead1'),('father'),('father1'),('father12'),('father123'),('father12345'),('father2'),('fathima'),('fatiha'),('fatima'),('fatima1'),('fatima12'),('fatima123'),('fatimah'),('fatime'),('fatina'),('fatjoe'),('fatjoe1'),('fatkid'),('fatkid1'),('fatma'),('fatman'),('fatman1'),('fatman12'),('fatman123'),('fatman2'),('fatouma'),('fatoumata'),('fatpussy'),('fatso1'),('fattie'),('fattie1'),('fatty'),('fatty1'),('fatty12'),('fatty123'),('fatty2'),('fatty5'),('faulkner'),('faustina'),('faustine'),('faustino'),('fausto'),('fauzan'),('favola'),('favored1'),('favorit'),('favorite'),('favorite1'),('favorites'),('favour'),('favour1'),('favoured'),('favourite'),('favre04'),('favre4'),('faye'),('faygo1'),('fazer600'),('fb1907'),('FBi11213'),('fbobh_'),('fbU89bxx5F'),('fcbarca'),('fcbarcelona'),('fcbayern'),('fcbayern1'),('fcinter'),('fckgwrhqq2'),('fcporto'),('fdcnhfkbz'),('fdfd'),('fdfdfd'),('fdfnfh'),('fdfyufhl'),('fdhjhf'),('fdsa'),('fdsafdsa'),('fdsfds'),('fduecn'),('feanor'),('fear'),('fearless'),('fearless1'),('feather'),('feather1'),('feathers'),('feathers1'),('feb'),('febbraio'),('febrero'),('februari'),('february'),('february1'),('february10'),('february11'),('february12'),('february13'),('february14'),('february15'),('february16'),('february17'),('february18'),('february19'),('february2'),('february20'),('february21'),('february22'),('february23'),('february24'),('february26'),('february27'),('february28'),('febuary'),('fed'),('fedcba'),('fede'),('federal'),('federal1'),('federation'),('federer'),('federer1'),('federica'),('federica1'),('federico'),('federico1'),('feder_1941'),('fedex'),('fedex1'),('fedor'),('fedora'),('fedorov'),('fedorov717'),('fedorova'),('fedotovsa76'),('feedback'),('feeder'),('feedme'),('feefee'),('feefee1'),('feelgood'),('feeling'),('feelings'),('feelmylove'),('feet'),('fefe'),('fefefe'),('feifei'),('fel'),('felice'),('felicia'),('felicia1'),('feliciano'),('felicidad'),('felicidad1'),('felicidade'),('felicidades'),('felicita'),('felicitas'),('felicity'),('felicity1'),('feliks'),('felina'),('feline'),('felino'),('felipe'),('felipe01'),('felipe1'),('felipe10'),('felipe12'),('felipe123'),('felipe13'),('felisa'),('felix'),('felix.1957'),('felix01'),('felix1'),('felix11'),('felix12'),('felix123'),('felix13'),('felix1952'),('felix2'),('felixthecat'),('felixx'),('feliz'),('fellini'),('fellow'),('fellowes'),('fellowship'),('felony'),('felony1'),('felton'),('female'),('female1'),('femi'),('femist22'),('femme'),('femmes'),('fen'),('Fenchel55'),('fencing'),('fender'),('fender!'),('fender.'),('fender01'),('fender1'),('fender11'),('fender12'),('fender123'),('fender2'),('fender3'),('fender5'),('fender69'),('fender7'),('fener'),('fener1'),('fener1907'),('fenerbahce'),('fenerbahce1907'),('fenerli'),('fengfeng'),('fengshui'),('fenice'),('feniks'),('fenix'),('fenix1'),('fenohasina39'),('fenomeno'),('fenrir'),('fenris'),('fenster'),('fenton'),('fenway'),('fenway1'),('fenwick'),('fer'),('fer123'),('feram0n'),('feranmi'),('ferari'),('ferarri'),('fercho'),('ferda'),('ferdie'),('ferdinand'),('ferdinand1'),('ferdinando'),('ferec'),('ferfer'),('fergie'),('fergie1'),('fergie12'),('fergis'),('fergus'),('fergus1'),('ferguson'),('ferguson1'),('ferhat'),('fericire'),('feride51'),('ferien'),('fermat'),('fermer'),('fermin'),('fernan'),('fernand'),('fernand0'),('fernanda'),('fernanda1'),('fernanda12'),('fernande'),('fernandes'),('fernandez'),('fernandez1'),('fernandito'),('fernando'),('fernando.'),('fernando1'),('fernando10'),('fernando12'),('fernando123'),('fernando13'),('fernando2'),('fernando9'),('fernandotorres'),('ferndale'),('fernie'),('ferrara'),('ferrari'),('ferrari01'),('ferrari1'),('ferrari12'),('ferrari123'),('ferrari2'),('ferrari355'),('ferrari360'),('ferrari430'),('ferrari7'),('ferrarif1'),('ferrarif40'),('ferrarif430'),('ferrarif50'),('ferrary'),('ferreira'),('ferrer'),('ferrero'),('ferret'),('ferret1'),('ferrets'),('ferris'),('ferris1'),('ferrum'),('fester'),('fester1'),('festina'),('festival'),('festival1'),('festus'),('fetish'),('feuerwehr'),('feuerwehr1'),('fever'),('fevral'),('fevrier'),('feyenoord'),('feyenoord1'),('ff'),('ff123456'),('fff'),('fff111'),('fff123'),('ffff'),('fffff'),('fffff1'),('ffffff'),('ffffff1'),('fffffff'),('ffffffff'),('fffffffff'),('ffffffffff'),('ffffffffffff'),('fffjjj'),('fgdfgdfg'),('fgfgfg'),('fgFr56Hfve6'),('fggjkbyfhbq007'),('fgh'),('fgh123'),('fghfgh'),('fghfghfgh'),('fghjkl'),('fghtkm'),('fgjrfkbgcbc'),('fgjrfkbgcbc34'),('fgntrf'),('fgrd58es24'),('fgtkmcby'),('fgtkmcbyrf'),('fh'),('fH1hM1wL'),('fhbirf'),('fhbyjxrf'),('fhctybq'),('fhifdby'),('fhnehxbr'),('fhntv'),('fhntv1998'),('fhntvbq'),('fhntvrf'),('fhtylf'),('fhutynbyf'),('fhvfutljy'),('fialka'),('fiamma'),('fiammalex1@hotmail.it'),('fiat'),('fiat500'),('fiatpunto'),('fiatuno'),('fibonacci'),('ficelle'),('fickdich'),('fickdich1'),('ficken'),('ficken1'),('ficken123'),('ficken666'),('ficken69'),('ficken76'),('ficker'),('fiction'),('fiction1'),('fiddle'),('fiddle1'),('fiddler'),('fidel'),('fidel1'),('fidele'),('fidelidade'),('fidelio'),('fidelio1'),('fidelis'),('fidelity'),('fidget'),('fidodido'),('field'),('fields'),('fierce'),('fierce1'),('fiesta'),('FieSta01'),('fiesta1'),('fietsbel'),('fifa'),('fifa06'),('fifa07'),('fifa08'),('fifa09'),('fifa10'),('fifa11'),('fifa2000'),('fifa2002'),('fifa2005'),('fifa2006'),('fifa2007'),('fifa2008'),('fifa2009'),('fifa2010'),('fifa2011'),('fifafifa'),('fifi'),('fifi123'),('fififi'),('fifnfy'),('fifteen'),('fifteen15'),('fifty'),('fifty5'),('fifty50'),('fiftycent'),('figaro'),('figaro1'),('fight'),('fight1'),('fight123'),('fightclub'),('fightclub1'),('fighter'),('fighter1'),('fighters'),('fighting'),('fighting1'),('figment'),('figueroa'),('figueroa1'),('figure'),('figure8'),('figvam'),('fil'),('filatovaev1981'),('filatov_and'),('filbert'),('file'),('filefront'),('filemon'),('files'),('filhos'),('filimon'),('filip'),('filip1'),('filip123'),('filipa'),('filipe'),('filipek'),('filipina'),('filipino'),('filipino1'),('filipp'),('filippo'),('filippo1'),('filler'),('filles'),('fillmore'),('film'),('film@123'),('filomena'),('filosofia'),('filou'),('filsdepute'),('filter'),('filthy'),('filthy1'),('filudskou'),('fin'),('final'),('final1'),('final123'),('final7'),('finale'),('finalfanta'),('finalfantasy'),('finalfantasy7'),('finally'),('finally1'),('finance'),('finance1'),('financial'),('financial123'),('finch'),('find1234'),('findajob'),('finder'),('findjob'),('findlove'),('findme'),('findme1'),('findus'),('find_pass'),('fine'),('fineboy'),('fines'),('finest'),('finest1'),('finestra'),('finger'),('finger1'),('finger11'),('fingers'),('fingers1'),('finish'),('finite'),('finland'),('finland1'),('finlandia'),('finlay'),('finley'),('finley1'),('finn'),('finnegan'),('finnigan'),('finster'),('fiocco'),('fiona'),('fiona1'),('fiona123'),('fiore'),('fiorella'),('fiorellino'),('fiorello'),('fiorentina'),('fir'),('firakoki'),('firdaus'),('fire'),('fire01'),('fire10'),('fire101'),('fire11'),('fire12'),('fire123'),('fire1234'),('fire13'),('fire21'),('fire22'),('fire23'),('fire666'),('fire69'),('fire911'),('fireandice'),('fireball'),('fireball1'),('fireball12'),('fireball2'),('firebird'),('firebird1'),('fireblade'),('fireblade1'),('firebolt'),('fireboy'),('firecracker'),('firedog'),('firedog1'),('firedragon'),('firefighte'),('firefighter'),('firefire'),('firefire1'),('fireflies'),('firefly'),('firefly1'),('firefox'),('firefox1'),('firehawk'),('firehouse'),('firehouse1'),('fireman'),('fireman1'),('fireman12'),('fireman2'),('firenze'),('firenze1'),('fireplace'),('firestar'),('firestar1'),('firestarter'),('firestone'),('firestone1'),('firestorm'),('firestorm1'),('firetruck'),('firetruck1'),('firewall'),('firewall1'),('firewater'),('firewire'),('firewood'),('firework'),('fireworks'),('fireworks1'),('firman'),('first'),('first1'),('firstborn'),('firstlady'),('firstlove'),('firstlove1'),('fis'),('fisch'),('fische'),('fischer'),('fischer1'),('fish'),('fish01'),('fish10'),('fish11'),('fish12'),('fish123'),('fish1234'),('fish13'),('fish22'),('fish23'),('fish69'),('fishbaracuda'),('fishbone'),('fishbone1'),('fishbowl'),('fishboy'),('fishcake'),('fisher'),('fisher1'),('fisher12'),('fisher2'),('fisherman'),('fisherman1'),('fishers'),('fishes'),('fishes1'),('fishface'),('fishface1'),('fishfish'),('fishfish1'),('fishfood'),('fishfood1'),('fishhead'),('fishhead1'),('fishie'),('fishies'),('fishin'),('fishin1'),('fishing'),('fishing!'),('fishing01'),('fishing1'),('fishing101'),('fishing11'),('fishing12'),('fishing123'),('fishing2'),('fishing3'),('fishing4'),('fishing5'),('fishing69'),('fishing7'),('fishka'),('fishlips'),('fishman'),('fishman1'),('fishon'),('fishpond'),('fishstick1'),('fishsticks'),('fishtank'),('fishtank1'),('fishy'),('fishy1'),('fishy12'),('fishy123'),('fishy2'),('fisica'),('fisioterapia'),('fister'),('fit4life'),('fitch1'),('fitness'),('fitness1'),('fitter'),('fitzgerald'),('five'),('five55'),('fivekids'),('fivestar'),('fivestar1'),('fizika'),('fizzle'),('fizzle1'),('fj5tx19HiT'),('fjfjfj'),('fjodorova-natashenka'),('fk'),('fK3456abc'),('fkbcrf'),('fkbyf'),('fkbyf001'),('fkbyjxrf'),('fkbyrf'),('fkg7h4f3v6'),('fkkjxrf'),('fkm'),('fkm:'),('fkmabz'),('fkmnthyfnbdf'),('fktdnbyf'),('fktirf'),('fktrcf'),('fktrcfylh'),('fktrcfylh1'),('fktrcfylhf'),('fktrcfylhjdbx'),('fktrcfylhjdyf'),('fktrctq'),('fktrcttdf'),('fktyeirf'),('fktyf'),('fktyjxrf'),('fktyrf'),('fl0wer'),('fla'),('flaca1'),('flaco1'),('flaka1'),('flakes'),('flakita'),('flame'),('flame1'),('flame123'),('flameboy'),('flameboy1'),('flamenco'),('flamenco1'),('flamengo'),('flamengo1'),('flamengo10'),('flamer'),('flames'),('flames1'),('flames12'),('flaming'),('flamingo'),('flamingo1'),('flamme'),('flanagan'),('flanders'),('flanker'),('flapjack'),('flapjack1'),('flappy'),('flaquita'),('flaquito'),('flash'),('flash1'),('flash12'),('flash123'),('flash2'),('flash3'),('flash5'),('flashback'),('flasher'),('flashlight'),('flashman'),('flashpoint'),('flashy'),('flashy1'),('flatblocker'),('flathead'),('flatland'),('flatline'),('flatout'),('flatron'),('flatron1'),('flavia'),('flavie'),('flavien'),('flavio'),('flavius'),('flavor'),('flavor1'),('flavour'),('flawless'),('flawless1'),('flblfc'),('fldjrfn'),('fleetwood'),('fleetwood1'),('flego0815'),('fleming'),('fleming1'),('flemming'),('fler_2351'),('fletch'),('fletch1'),('fletcher'),('fletcher1'),('fleur'),('fleurs'),('flex'),('flexible'),('flexible1'),('flhtyfkby'),('flicka'),('flicker'),('flight'),('flight1'),('flight23'),('fling1'),('fling123'),('flint'),('flint1'),('flintstone'),('flip'),('flip12'),('flip123'),('flipflop'),('flipflop1'),('flipmode'),('flipmode1'),('flipper'),('flipper1'),('flipper2'),('flippy'),('flipside'),('flipside1'),('flirt'),('flirt1'),('flirty'),('flirty1'),('flo'),('flo123'),('floare'),('float'),('flocke'),('flocon'),('floflo'),('floortje'),('floppy'),('floppy1'),('flopsy'),('flor'),('flor123'),('flora'),('flora1'),('florcita'),('florecita'),('florence'),('florence1'),('florencia'),('florencia1'),('florencio'),('florent'),('florentin'),('florentina'),('florentino'),('flores'),('flores1'),('flores12'),('flores123'),('flores13'),('floresta'),('florian'),('florian1'),('floriana'),('floriane'),('floricienta'),('florida'),('florida!'),('florida01'),('florida06'),('florida07'),('florida08'),('florida09'),('florida1'),('florida10'),('florida11'),('florida12'),('florida123'),('florida13'),('florida2'),('florida22'),('florida3'),('florida4'),('florida5'),('florida6'),('florida7'),('florida8'),('florida9'),('florin'),('florina'),('florinda'),('florine'),('floripa'),('floris'),('florzinha'),('flossie'),('flossie1'),('flossy'),('flossy1'),('flounder'),('flounder1'),('flower'),('flower!'),('flower.'),('flower0'),('flower01'),('flower08'),('flower09'),('flower1'),('flower10'),('flower101'),('flower11'),('flower12'),('flower123'),('flower1234'),('flower13'),('flower14'),('flower15'),('flower16'),('flower17'),('flower18'),('flower2'),('flower21'),('flower22'),('flower23'),('flower24'),('flower3'),('flower33'),('flower4'),('flower45'),('flower5'),('flower6'),('flower69'),('flower7'),('flower77'),('flower8'),('flower88'),('flower9'),('flower99'),('flowergirl'),('flowerpot'),('flowerpot1'),('flowerpowe'),('flowerpower'),('flowers'),('flowers!'),('flowers.'),('flowers1'),('flowers11'),('flowers12'),('flowers123'),('flowers2'),('flowers22'),('flowers3'),('flowers4'),('flowers5'),('flowers7'),('flowers8'),('floyd'),('floyd1'),('floyd123'),('fltkbyf'),('flubber'),('flubber1'),('fluff'),('fluff1'),('fluffy'),('fluffy!'),('fluffy01'),('fluffy1'),('fluffy10'),('fluffy11'),('fluffy12'),('fluffy123'),('fluffy13'),('fluffy2'),('fluffy22'),('fluffy3'),('fluffy5'),('fluffy69'),('fluffy7'),('fluminense'),('flute'),('flute1'),('flutes'),('flutterby'),('fluturas'),('flvbybcnhfnjh'),('fly'),('fly123'),('flyaway'),('flyaway1'),('flyboy'),('flyboy1'),('flyer'),('flyer1'),('flyers'),('flyers1'),('flyers88'),('flyfish'),('flyfish1'),('flyfishing'),('flyfly'),('flygirl'),('flygirl1'),('flyguy'),('flyguy1'),('flyhigh'),('flyhigh1'),('flying'),('flying1'),('flyleaf'),('flyleaf1'),('fnaf'),('fnkfynblf'),('fob123'),('focker'),('focus'),('focus1'),('focus123'),('focused'),('focused1'),('fodase'),('fofinha'),('fofinho'),('foggia'),('foghorn'),('fokker'),('foks8484'),('folake'),('folashade'),('folder'),('folgore'),('folk74'),('folks6'),('follar'),('folletto'),('follow'),('followme'),('fomalex10'),('fondoom'),('fonseca'),('fontaine'),('fontana'),('fonzie'),('foo'),('foobar'),('foobar1'),('food'),('food11'),('food12'),('food123'),('food1234'),('foodfood'),('foodie'),('foofighter'),('foofighters'),('foofoo'),('foofoo1'),('fool'),('foolish'),('foolish1'),('foolproof'),('foosball'),('foot'),('footba11'),('footbal'),('footbal1'),('football'),('football!'),('football#1'),('football.'),('football0'),('football00'),('football01'),('football02'),('football03'),('football04'),('football05'),('football06'),('football07'),('football08'),('football09'),('football1'),('football10'),('football101'),('football11'),('football12'),('football123'),('football13'),('football14'),('football15'),('football16'),('football17'),('football18'),('football19'),('football2'),('football20'),('football21'),('football22'),('football23'),('football24'),('football25'),('football26'),('football27'),('football28'),('football29'),('football3'),('football30'),('football31'),('football32'),('football33'),('football34'),('football35'),('football36'),('football37'),('football38'),('football4'),('football40'),('football41'),('football42'),('football43'),('football44'),('football45'),('football46'),('football47'),('football48'),('football49'),('football5'),('football50'),('football51'),('football52'),('football53'),('football54'),('football55'),('football56'),('football57'),('football58'),('football59'),('football6'),('football60'),('football61'),('football62'),('football63'),('football64'),('football65'),('football66'),('football67'),('football68'),('football69'),('football7'),('football70'),('football71'),('football72'),('football73'),('football74'),('football75'),('football76'),('football77'),('football78'),('football79'),('football8'),('football80'),('football81'),('football82'),('football83'),('football84'),('football85'),('football86'),('football87'),('football88'),('football89'),('football9'),('football90'),('football91'),('football92'),('football93'),('football94'),('football95'),('football96'),('football97'),('football98'),('football99'),('footballer'),('foothill'),('footie'),('footloose'),('footprints'),('footy1'),('for'),('forbes'),('forbidden'),('forbidden1'),('force'),('force1'),('forces'),('ford'),('ford01'),('ford11'),('ford12'),('ford123'),('ford1234'),('ford150'),('ford2000'),('ford2001'),('ford250'),('ford350'),('ford351'),('ford69'),('ford88'),('ford99'),('fordescort'),('fordf100'),('fordf150'),('fordf250'),('fordf350'),('fordfiesta'),('fordfocus'),('fordfocus1'),('fordford'),('fordgt'),('fordgt40'),('fordham'),('fordman'),('fordman1'),('fordmondeo'),('fordmustang'),('fordranger'),('fordtruck'),('fordtruck1'),('foreman'),('foreman1'),('forensic'),('foreplay'),('foresight'),('forest'),('forest1'),('forest12'),('forest123'),('forester'),('forever'),('forever!'),('forever.'),('forever0'),('forever01'),('forever07'),('forever08'),('forever09'),('forever1'),('forever10'),('forever11'),('forever12'),('forever123'),('forever13'),('forever14'),('forever15'),('forever16'),('forever17'),('forever18'),('forever2'),('forever21'),('forever22'),('forever23'),('forever24'),('forever25'),('forever27'),('forever3'),('forever4'),('forever5'),('forever6'),('forever69'),('forever7'),('forever8'),('forever9'),('foreveralone'),('foreverand'),('foreverlov'),('foreverlove'),('forevermor'),('foreveryou'),('foreveryoung'),('forfun'),('forfun1'),('forget'),('forget1'),('forget12'),('forget123'),('forget2'),('forgetful'),('forgetful1'),('forgetit'),('forgetit1'),('forgetme'),('forgetmenot'),('forgin'),('forgive'),('forgive1'),('forgiveme'),('forgiven'),('forgiven1'),('forgot'),('forgot1'),('forgot2'),('forgotit'),('forgotten'),('forgotten1'),('forklift'),('forlife'),('forlife1'),('forlove'),('format'),('formation'),('formel1'),('formentera'),('formula'),('formula1'),('formule1'),('forreal'),('forreal1'),('forrest'),('forrest1'),('forsaken'),('forsaken1'),('forsale'),('forsberg'),('forsberg21'),('forsythe'),('fortaleza'),('fortis'),('fortress'),('fortuna'),('fortuna1'),('fortuna95'),('fortunate'),('fortunato'),('fortune'),('fortune1'),('forty2'),('fortytwo'),('forum'),('forum1'),('forum123'),('forward'),('forward1'),('foryou'),('forza'),('forzainter'),('forzaitalia'),('forzajuve'),('forzalazio'),('forzalecce'),('forzamilan'),('forzanapoli'),('forzaroma'),('forzatoro'),('foshizzle'),('foshizzle1'),('fosho1'),('fossil'),('fossil1'),('foster'),('foster1'),('fosters'),('fosters1'),('fotbal'),('fotball'),('fotboll'),('fotinia-66'),('fotograf'),('fotografia'),('fottiti'),('fou'),('foufou'),('foufoune'),('foundation'),('founder'),('fountain'),('fountain1'),('four'),('four20'),('four44'),('four4444'),('fourboys'),('fourfour'),('fourier'),('fourkids'),('fourkids4'),('fourteen'),('fourteen14'),('fourtwenty'),('fouzia'),('fowler'),('fowler1'),('fox'),('fox123'),('foxfire'),('foxfire1'),('foxfox'),('foxglove'),('foxhound'),('foxmulder'),('foxpass'),('foxracing'),('foxracing1'),('foxracing2'),('foxtrot'),('foxtrot1'),('foxxy1'),('foxy'),('foxy12'),('foxy123'),('foxylady'),('foxylady1'),('foxyroxy'),('foxyroxy1'),('fozzie'),('fpna23aAS1'),('FQI3P8arjg'),('FQRG7CS493'),('fquekm'),('fr'),('fr1ends'),('fr33d0m'),('fr33dom'),('fra'),('fractal'),('fraggle'),('fraggle1'),('fragile'),('fragile1'),('fragola'),('fragolina'),('fraise'),('framboise'),('fran'),('fran123'),('franca'),('francais'),('france'),('france1'),('france12'),('france123'),('france2'),('france98'),('frances'),('frances1'),('frances2'),('francesc'),('francesca'),('francesca1'),('francesco'),('francesco1'),('franchesca'),('francheska'),('franchise'),('franchise1'),('franci'),('francia'),('francine'),('francine1'),('francis'),('francis1'),('francis12'),('francis123'),('francis2'),('francis3'),('francisca'),('francisca1'),('francisco'),('francisco1'),('francisco2'),('franck'),('francky'),('franco'),('franco1'),('franco123'),('francois'),('francois1'),('francoise'),('francy'),('franek'),('frank'),('frank01'),('frank1'),('frank10'),('frank11'),('frank12'),('frank123'),('frank1234'),('frank13'),('frank2'),('frank21'),('frank22'),('frank3'),('frank5'),('frank69'),('frank7'),('franka'),('frankenstein'),('frankfurt'),('frankfurt1'),('franki'),('frankie'),('frankie!'),('frankie01'),('frankie1'),('frankie11'),('frankie12'),('frankie123'),('frankie13'),('frankie2'),('frankie3'),('frankie4'),('frankie5'),('frankie7'),('frankiero1'),('frankies'),('franklin'),('franklin1'),('franklin12'),('franklin2'),('franklyn'),('franko'),('frankreich'),('franks'),('franks1'),('franky'),('franky1'),('frankzappa'),('frannie'),('frannie1'),('franny'),('franny1'),('franta'),('frantic'),('frant_nat'),('franz'),('franz1'),('franzi'),('franziska'),('fraser'),('fraser1'),('frasier'),('fratello'),('fraud'),('frazer'),('frazier'),('frazier1'),('frdfhbev'),('frdfvfhby'),('fre'),('freak'),('freak!'),('freak1'),('freak101'),('freak11'),('freak12'),('freak123'),('freak13'),('freak2'),('freak666'),('freak69'),('freakazoid'),('freakout'),('freaks'),('freaks1'),('freakshow'),('freakshow1'),('freaky'),('freaky1'),('freaky12'),('freaky123'),('freaky2'),('freaky69'),('freccia'),('frechdachs'),('freckle'),('freckles'),('freckles1'),('fred'),('fred01'),('fred10'),('fred11'),('fred12'),('fred123'),('fred1234'),('fred13'),('fred1994'),('fred20'),('fred22'),('fred69'),('freddie'),('freddie1'),('freddie123'),('freddie2'),('freddo'),('freddurst'),('freddy'),('freddy!'),('freddy01'),('freddy1'),('freddy11'),('freddy12'),('freddy123'),('freddy13'),('freddy2'),('freddy3'),('freddy7'),('frederic'),('frederic1'),('frederick'),('frederick1'),('frederico'),('frederik'),('frederique'),('fredfred'),('fredfred1'),('fredo'),('fredom'),('fredperry'),('fredrick'),('fredrick1'),('fredrik'),('fredy'),('fredy1'),('free'),('free11'),('free12'),('free123'),('free1234'),('free13'),('free22'),('free23'),('free2beme'),('free2bme'),('free2rhyme'),('free4all'),('free4ever'),('free4life'),('free4me'),('freeatlast'),('freebee'),('freebie'),('freebies'),('freebird'),('freebird1'),('freed0m'),('freedom'),('freedom!'),('freedom.'),('freedom0'),('freedom01'),('freedom06'),('freedom07'),('freedom08'),('freedom09'),('freedom1'),('freedom10'),('freedom101'),('freedom11'),('freedom12'),('freedom123'),('freedom13'),('freedom2'),('freedom200'),('freedom201'),('freedom2010'),('freedom21'),('freedom22'),('freedom23'),('freedom3'),('freedom4'),('freedom4me'),('freedom5'),('freedom55'),('freedom6'),('freedom69'),('freedom7'),('freedom77'),('freedom8'),('freedom88'),('freedom9'),('freedoms'),('freefall'),('freefall1'),('freefood'),('freefree'),('freefree1'),('freelance'),('freelancer'),('freeland'),('freelander'),('freelife'),('freelove'),('freemail'),('freeman'),('freeman1'),('freeman2'),('freeme'),('freeme1'),('freemind'),('freemoney'),('freemusic'),('freenet'),('freepass'),('freeporn'),('freeport'),('freeport1'),('freeride'),('freerider'),('freesex'),('freespirit'),('freestuff'),('freestyle'),('freestyle1'),('freestyler'),('freetime'),('freetown'),('freeuser'),('freeway'),('freeway1'),('freewill'),('freewilly'),('freeze'),('freeze1'),('freeze112'),('freezer'),('fregis'),('fregna'),('freiburg'),('freight'),('freiheit'),('freiheit89'),('freinds'),('freitag'),('freitas'),('fremont'),('fremont1'),('french'),('french1'),('frenchfrie'),('frenchfries'),('frenchfry'),('frenchfry1'),('frenchie'),('frenchie1'),('frenchkiss'),('frenchy'),('frenchy1'),('frends'),('frenzy'),('fresa1'),('fresas'),('fresca'),('fresco'),('fresh'),('fresh08'),('fresh09'),('fresh1'),('fresh10'),('fresh101'),('fresh11'),('fresh12'),('fresh123'),('fresh13'),('fresh14'),('fresh2'),('fresh21'),('fresh22'),('fresh23'),('fresh2def'),('fresh3'),('fresh5'),('freshboy'),('freshman'),('freshman09'),('freshman1'),('freshmen'),('freshstart'),('fresita'),('fresita1'),('fresno'),('fresno1'),('fresno559'),('freund'),('freunde'),('freunde1'),('freya'),('freya1'),('frfltvbz'),('fri'),('FRI3Q9arjg'),('frida'),('frida1'),('friday'),('friday01'),('friday1'),('friday11'),('friday12'),('friday123'),('friday13'),('friday2'),('fridge'),('fridolin'),('frieda'),('friedrich'),('friend'),('friend!'),('friend1'),('friend11'),('friend12'),('friend123'),('friend2'),('friend3'),('friend4'),('friend5'),('friend7'),('friendly'),('friendly1'),('friendofArriane'),('friendofEarning$1'),('friendofemily'),('friendofEveryEmailyouproc'),('friendofGerly'),('friendofjoan'),('friendofThenext18peoplew'),('friendofYOUCANMAKE$200-'),('friends'),('friends!'),('friends.'),('friends0'),('friends01'),('friends06'),('friends07'),('friends08'),('friends09'),('friends1'),('friends10'),('friends101'),('friends11'),('friends12'),('friends123'),('friends13'),('friends14'),('friends15'),('friends16'),('friends2'),('friends21'),('friends22'),('friends23'),('friends3'),('friends33'),('friends4'),('friends4ev'),('friends4ever'),('friends4li'),('friends4me'),('friends5'),('friends6'),('friends7'),('friends8'),('friends9'),('friendsfor'),('friendsforever'),('friendship'),('friendship1'),('friendss'),('friendster'),('friendster1'),('friendz'),('friendz1'),('frighten'),('frijolito'),('frimousse'),('fripon'),('fripouille'),('frisbee'),('frisbee1'),('frisco'),('frisco1'),('frisco415'),('friskie'),('frisky'),('frisky1'),('fritz'),('fritz1'),('fritz123'),('fritzi'),('fritzie'),('fritzy'),('fro'),('frodo'),('frodo1'),('frodo123'),('frodon'),('frog'),('frog11'),('frog12'),('frog123'),('frog1234'),('frog13'),('frog22'),('frog69'),('frogfrog'),('frogger'),('frogger1'),('frogger2'),('froggie'),('froggie1'),('froggies'),('froggies1'),('froggy'),('froggy!'),('froggy01'),('froggy1'),('froggy101'),('froggy11'),('froggy12'),('froggy123'),('froggy13'),('froggy2'),('froggy22'),('froggy3'),('froggy5'),('froggy69'),('froggy7'),('froglegs'),('froglegs1'),('frogman'),('frogman1'),('frogs'),('frogs1'),('frogs123'),('frogs2'),('froilan'),('frolov'),('frolova'),('fromage'),('front242'),('frontech'),('frontera'),('frontier'),('frontier1'),('frontline'),('frontline1'),('frosch'),('frost'),('frost1'),('frostbite'),('frosty'),('frosty1'),('frosty12'),('frosty123'),('frozen'),('frozen1'),('FrqNj0Zf5P'),('frufru'),('fruit'),('fruit1'),('fruitbat'),('fruitcake'),('fruitcake1'),('fruitloop'),('fruitloop1'),('fruitloops'),('fruits'),('fruity'),('fruity1'),('frusciante'),('frytol'),('fs.swl'),('fs7600'),('fsd9shtyut'),('fslhggi'),('ftbfrvlg17'),('FTrCVh5732'),('ftw666'),('fu00190'),('fu7u4a#$$$'),('fubar'),('fubar09'),('fubar1'),('fubu05'),('fuc'),('fuchurli'),('fuck'),('fuck!!'),('fuck-off'),('fuck-you'),('fuck.you'),('fuck00'),('fuck01'),('fuck07'),('fuck08'),('fuck09'),('fuck0ff'),('fuck1'),('fuck10'),('fuck101'),('fuck11'),('fuck111'),('fuck12'),('fuck123'),('fuck1234'),('fuck12345'),('fuck123456'),('fuck13'),('fuck14'),('fuck15'),('fuck16'),('fuck17'),('fuck18'),('fuck1t'),('fuck1you'),('fuck21'),('fuck22'),('fuck23'),('fuck24'),('fuck33'),('fuck3r'),('fuck420'),('fuck50'),('fuck55'),('fuck66'),('fuck666'),('fuck69'),('fuck77'),('fuck777'),('fuck88'),('fuck89'),('fuck99'),('fuck999'),('fuckabitch'),('fuckaduck'),('fuckaduck1'),('fuckall'),('fuckall1'),('fuckass'),('fuckass1'),('fuckbitch1'),('fuckbitche'),('fuckbitches'),('fuckbuddy'),('fucked'),('fucked1'),('fuckedup'),('fuckedup1'),('fuckem'),('fuckem1'),('fuckemall'),('fucker'),('fucker!'),('fucker.'),('fucker01'),('fucker1'),('fucker11'),('fucker12'),('fucker123'),('fucker13'),('fucker2'),('fucker21'),('fucker22'),('fucker23'),('fucker3'),('fucker4'),('fucker5'),('fucker6'),('fucker666'),('fucker69'),('fucker7'),('fucker8'),('fucker9'),('fuckers'),('fuckers!'),('fuckers1'),('fuckevery1'),('fuckface'),('fuckface1'),('fuckface2'),('fuckfuck'),('fuckfuck1'),('fuckfuckfuck'),('fuckhaters'),('fuckhead'),('fuckhead1'),('fuckher'),('fuckher1'),('fuckher2'),('fuckhim1'),('fuckhoes1'),('fuckin'),('fuckin1'),('fucking'),('fucking1'),('fucking123'),('fucking2'),('fucking69'),('fuckingshit'),('fuckit'),('fuckit!'),('fuckit.'),('fuckit1'),('fuckit11'),('fuckit12'),('fuckit123'),('fuckit13'),('fuckit2'),('fuckit3'),('fuckit420'),('fuckit5'),('fuckit69'),('fuckit7'),('fuckitall'),('fuckitall1'),('fuckl0v3'),('fuckl0ve'),('fucklife'),('fucklife1'),('fucklov3'),('fucklove'),('fucklove!'),('fucklove09'),('fucklove1'),('fucklove10'),('fucklove12'),('fucklove13'),('fucklove14'),('fucklove2'),('fucklove21'),('fucklove23'),('fucklove3'),('fucklove4'),('fucklove69'),('fucklove7'),('fuckm3'),('fuckme'),('fuckme!'),('fuckme.'),('fuckme1'),('fuckme11'),('fuckme12'),('fuckme123'),('fuckme13'),('fuckme2'),('fuckme21'),('fuckme22'),('fuckme23'),('fuckme3'),('fuckme4'),('fuckme420'),('fuckme5'),('fuckme6'),('fuckme666'),('fuckme69'),('fuckme7'),('fuckmehard'),('fuckmenow'),('fuckmyass'),('fuckmylife'),('fuckmyspac'),('fucknut'),('fucknut1'),('fuckof'),('fuckoff'),('fuckoff!'),('fuckoff.'),('fuckoff0'),('fuckoff01'),('fuckoff09'),('fuckoff1'),('fuckoff11'),('fuckoff12'),('fuckoff123'),('fuckoff13'),('fuckoff2'),('fuckoff21'),('fuckoff22'),('fuckoff23'),('fuckoff3'),('fuckoff4'),('fuckoff420'),('fuckoff5'),('fuckoff6'),('fuckoff666'),('fuckoff69'),('fuckoff7'),('fuckoff8'),('fuckoff88'),('fuckoff9'),('fuckshit'),('fuckshit1'),('fuckstick'),('fuckstick1'),('fucktard'),('fucktard1'),('fuckth1s'),('fuckthat'),('fuckthat1'),('fuckthemall'),('fuckthewor'),('fucktheworld'),('fuckthis'),('fuckthis!'),('fuckthis1'),('fuckthis12'),('fuckthis2'),('fuckthissh'),('fuckthisshit'),('fucktop8'),('fucku'),('fucku!'),('fucku.'),('fucku09'),('fucku1'),('fucku11'),('fucku12'),('fucku123'),('fucku13'),('fucku2'),('fucku21'),('fucku22'),('fucku23'),('fucku3'),('fucku4'),('fucku5'),('fucku6'),('fucku666'),('fucku69'),('fucku7'),('fucku8'),('fucku9'),('fuckuall'),('fuckuall1'),('fuckubitch'),('fuckup'),('fuckup1'),('fucky0u'),('fuckya'),('fuckya1'),('fuckyeah'),('fuckyeah1'),('fuckyou'),('fuckyou!'),('fuckyou!!'),('fuckyou.'),('fuckyou0'),('fuckyou00'),('fuckyou01'),('fuckyou02'),('fuckyou06'),('fuckyou07'),('fuckyou08'),('fuckyou09'),('fuckyou1'),('fuckyou10'),('fuckyou100'),('fuckyou101'),('fuckyou11'),('fuckyou111'),('fuckyou12'),('fuckyou123'),('fuckyou13'),('fuckyou14'),('fuckyou15'),('fuckyou16'),('fuckyou17'),('fuckyou18'),('fuckyou187'),('fuckyou19'),('fuckyou2'),('fuckyou20'),('fuckyou21'),('fuckyou22'),('fuckyou23'),('fuckyou24'),('fuckyou25'),('fuckyou26'),('fuckyou27'),('fuckyou3'),('fuckyou32'),('fuckyou321'),('fuckyou33'),('fuckyou4'),('fuckyou420'),('fuckyou44'),('fuckyou45'),('fuckyou5'),('fuckyou55'),('fuckyou6'),('fuckyou66'),('fuckyou666'),('fuckyou69'),('fuckyou7'),('fuckyou77'),('fuckyou78'),('fuckyou8'),('fuckyou86'),('fuckyou87'),('fuckyou88'),('fuckyou89'),('fuckyou9'),('fuckyou90'),('fuckyou92'),('fuckyou99'),('fuckyouall'),('fuckyouass'),('fuckyoubit'),('fuckyoubitch'),('fuckyoutoo'),('fuck_off'),('fuck_you'),('fudge'),('fudge1'),('fudge123'),('fuentes'),('fuerte'),('fugazi'),('fujifilm'),('fujitsu'),('fujitsu1'),('fujitvpass'),('fuk19600'),('fukoff'),('fuku00198'),('fukyou'),('fukyou1'),('fulcrum'),('fulham'),('fulham1'),('fullaccess'),('fullback'),('fuller'),('fuller1'),('fullerton'),('fullerton1'),('fullhouse'),('fullhouse1'),('fullmetal'),('fullmetal1'),('fullmoon'),('fullmoon1'),('fulmine'),('fulton'),('fulvio'),('fumanchu'),('fun'),('fun123'),('fun4all'),('fun4me'),('function'),('funeral'),('funeral1'),('funfun'),('funfun1'),('funfunfun'),('fungible'),('fungus'),('funhouse'),('funk'),('funky'),('funky1'),('funky123'),('funkymonkey'),('funkytown'),('funkytown1'),('funmilayo'),('funmilola'),('funny'),('funny1'),('funny12'),('funny123'),('funny2'),('funny3'),('funny5'),('funny7'),('funnybunny'),('funnyface'),('funnygirl'),('funnygirl1'),('funnyguy'),('funnyman'),('funnyman1'),('funstuff'),('funtik'),('funtime'),('funtime1'),('funtimes'),('funtimes1'),('FupYuxTa66'),('FupYuxTb66'),('furball'),('furball1'),('furby1'),('furious'),('furious1'),('furkan'),('furman'),('furniture'),('furniture1'),('fusion'),('fusion1'),('fusion12'),('fussball'),('fussball1'),('fussel'),('futbol'),('futbol1'),('futbol10'),('futbol7'),('futebol'),('futsal'),('futura'),('futurama'),('futurama1'),('future'),('future1'),('future12'),('future123'),('futuro'),('futyn007'),('fuzzball'),('fuzzball1'),('fuzzy'),('fuzzy1'),('fuzzy123'),('fvcnthlfv'),('fvthbrf'),('fx-one'),('fxnocp14'),('fxzZ75'),('fxzZ75$yer'),('fxzZ75yer'),('fy'),('fy.njxrf'),('fy.nrf'),('fyabcf'),('fybcbvjdf'),('fyfcnfcbz'),('fyfnjkbq'),('fyfnjkbq777'),('fyfnjkmtdyf'),('fyfrjylf'),('fyfyfc'),('fylh.if'),('fylh.irf'),('fylhsq'),('fylhtq'),('fylhtq12'),('fylhtqrf'),('fylhttdf'),('fylhttdyf'),('fynjif'),('fynjirf'),('fynjy'),('fynjybj'),('fynjybyf'),('fynjyjdf'),('fysihz5g'),('fytxrf'),('fyujk.fyukf.87'),('fyutkbyf'),('fyutkjr'),('fyutkjxtr'),('fyyeirf'),('fyyf'),('fyz'),('fyzfyz'),('g'),('g-money'),('g-unit'),('g-unit1'),('g-unot'),('g00ber'),('g00dluck'),('g00dPa$$w0rD'),('g00gl3'),('g00gle'),('g0ldfish'),('g123098'),('g12345'),('g123456'),('g1234567'),('g12345678'),('g123456789'),('g13916055158'),('g1hp'),('g1nger'),('g4life'),('g76t94prm4'),('g76u94prm4'),('g86u94psn5'),('g86ua5qsn5'),('g9l2d1fzPY'),('gaara'),('gaara1'),('gaara12'),('gaara123'),('gaar_vitalik73'),('gab'),('gab123'),('gabbana'),('gabber'),('gabbiano'),('gabbie'),('gabbie1'),('gabby'),('gabby01'),('gabby1'),('gabby10'),('gabby11'),('gabby12'),('gabby123'),('gabby13'),('gabby2'),('gabby3'),('gabby5'),('gabby7'),('gabe'),('gabe12'),('gabe123'),('gabgab'),('gabi'),('gabi123'),('gabika'),('gabita'),('gabriel'),('gabriel.'),('gabriel01'),('gabriel05'),('gabriel06'),('gabriel07'),('gabriel08'),('gabriel09'),('gabriel1'),('gabriel10'),('gabriel11'),('gabriel12'),('gabriel123'),('gabriel13'),('gabriel14'),('gabriel15'),('gabriel17'),('gabriel2'),('gabriel21'),('gabriel22'),('gabriel23'),('gabriel3'),('gabriel4'),('gabriel5'),('gabriel6'),('gabriel7'),('gabriel8'),('gabriel9'),('gabriela'),('gabriela1'),('gabriela12'),('gabriela2'),('gabriela7'),('gabriele'),('gabriele1'),('gabrielito'),('gabriell'),('gabriella'),('gabriella1'),('gabrielle'),('gabrielle1'),('gabrielle2'),('gaby'),('gaby12'),('gaby123'),('gaby13'),('gadget'),('gadget1'),('gadjieva.gulmira'),('gady123'),('gaelle'),('gaetan'),('gaetano'),('gaffer'),('gag5691'),('gaga'),('gaga123'),('gagaga'),('gagagaga'),('gagarin'),('gage'),('gage123'),('gagged'),('gago'),('gagoako'),('gagoka'),('gaia'),('gail'),('gajanan'),('gal'),('gal220'),('gala'),('galactica'),('galadriel'),('galahad'),('galaktika'),('galang'),('galant'),('galapagos'),('galata'),('galatasara'),('galatasaray'),('galatasaray1905'),('galatea'),('galaxia'),('galaxie'),('galaxy'),('galaxy1'),('galaxy123'),('galicia'),('galileo'),('galileo1'),('galina'),('galina-davidyuk'),('galina9181'),('galindo'),('galinka'),('galinkaru'),('galinka_korneeva'),('gallagher'),('gallagher1'),('gallant'),('gallardo'),('gallardo1'),('gallego'),('gallegos'),('gallery'),('gallery1'),('galleta'),('gallina'),('gallito'),('gallo'),('gallo1'),('galloway'),('galvez'),('galway'),('gam'),('gamaliel'),('gambia'),('gambino'),('Gambion32'),('gambit'),('gambit1'),('gamble'),('gamble1'),('gambler'),('gambler1'),('gamboa'),('game'),('game11'),('game12'),('game123'),('game1234'),('gameboy'),('gameboy1'),('gameboy2'),('gamecock'),('gamecock1'),('gamecocks'),('gamecocks1'),('gamecube'),('gamecube1'),('gamefreak'),('gamefreak1'),('gamegame'),('gamemaster'),('gameon'),('gameover'),('gameover1'),('gameplay'),('gamer'),('gamer1'),('gamer12'),('gamer123'),('gamer4life'),('gamers'),('gamers1'),('games'),('games1'),('games12'),('games123'),('games2'),('gamess'),('gamestar'),('gamestop'),('gamestop1'),('gametime'),('gametime1'),('gaming'),('gamlet'),('gamma'),('gamma1'),('gammaray'),('gampang'),('gan'),('ganapathi'),('ganapathy'),('ganapati'),('ganda'),('ganda1'),('gandaako'),('gandako'),('gandako1'),('gandakoh'),('gandalf'),('gandalf1'),('gandhi'),('gandolf'),('gandon'),('ganesh'),('ganesh1'),('ganesh123'),('ganesha'),('ganesha1'),('ganeshji'),('gang'),('gang123'),('gangbang'),('gangbang1'),('ganggang'),('gangrel'),('gangsta'),('gangsta!'),('gangsta.'),('gangsta01'),('gangsta1'),('gangsta10'),('gangsta101'),('gangsta11'),('gangsta12'),('gangsta123'),('gangsta13'),('gangsta14'),('gangsta15'),('gangsta2'),('gangsta21'),('gangsta22'),('gangsta23'),('gangsta3'),('gangsta4'),('gangsta5'),('gangsta6'),('gangsta69'),('gangsta7'),('gangsta74'),('gangsta8'),('gangsta9'),('gangstah'),('gangstar'),('gangstar1'),('gangster'),('gangster!'),('gangster1'),('gangster10'),('gangster11'),('gangster12'),('gangster13'),('gangster14'),('gangster2'),('gangster23'),('gangster3'),('gangster4'),('gangster5'),('gangster6'),('gangster7'),('gangsters'),('ganja'),('ganja1'),('ganja123'),('ganja420'),('ganjaman'),('ganjubas'),('gannon'),('ganondorf'),('ganpati'),('gansta'),('gansta1'),('ganster'),('ganster1'),('ganteng'),('ganteng1'),('gar'),('garage'),('garage1'),('garance'),('garant'),('garbage'),('garbage1'),('garcia'),('garcia1'),('garcia10'),('garcia12'),('garcia123'),('garcia13'),('garcia2'),('garden'),('garden1'),('gardener'),('gardenia'),('gardening'),('gardens'),('gardner'),('gardner1'),('garena'),('gareth'),('gareth1'),('garfield'),('garfield1'),('garfield12'),('garfield2'),('garfield7'),('garfild'),('gargamel'),('gargoyle'),('garibaldi'),('garima'),('garion'),('garland'),('garland1'),('garlic'),('garner'),('garnet'),('garnet1'),('garnett'),('garnett21'),('garnett5'),('garnier'),('garret'),('garret1'),('garrett'),('garrett1'),('garrett12'),('garrett123'),('garrett2'),('garrett3'),('garrison'),('garrison1'),('garry'),('garry1'),('garten'),('garth'),('garth1'),('garuda'),('gary'),('gary12'),('gary123'),('gary1234'),('gas'),('gasgas'),('gasman'),('gasolina'),('gasoline'),('gaspar'),('gaspard'),('gaspare'),('gasparin'),('gasper'),('gaston'),('gaston1'),('gastone'),('gat'),('gate13'),('gatekeeper'),('gates'),('gateway'),('gateway1'),('gateway11'),('gateway12'),('gateway123'),('gateway2'),('gateway200'),('gateway2000'),('gateway3'),('gateway5'),('gateway7'),('gather'),('gathering'),('gatina_albina'),('gatinha'),('gatinho'),('gatita'),('gatita1'),('gatito'),('gatito1'),('gatitos'),('gato'),('gato12'),('gato123'),('gatogato'),('gatonegro'),('gator'),('gator1'),('gator12'),('gator123'),('gator2'),('gatorade'),('gatorade1'),('gators'),('gators01'),('gators1'),('gators11'),('gators12'),('gators123'),('gators15'),('gators2'),('gatsby'),('gatsby1'),('gatt'),('gattina'),('gattino'),('gatto'),('gattone'),('gattuso'),('gatubela'),('gaucho'),('gaudens'),('gauloises'),('gaurav'),('gaurav123'),('gautam'),('gauthier'),('gavgav'),('gavilan'),('gavin'),('gavin1'),('gavin123'),('gavin2'),('gaviota'),('gavrik'),('gavroche'),('gay'),('gay101'),('gay123'),('gay1234'),('gay4life'),('gayass1'),('gayASSfagpastebinleaks'),('gayathri'),('gayatri'),('gayboy'),('gayboy1'),('gayfag1'),('gaygay'),('gaygay1'),('gaygaygay'),('gayguy1'),('gaylord'),('gaylord1'),('gayman'),('gayman1'),('gayness1'),('gaypride'),('gaypride1'),('gaysex'),('gazebo'),('gazelle'),('gazeta'),('gazette'),('gazprom'),('gb15kv99'),('gbaby1'),('gbcmrf'),('gbemisola'),('gbenga'),('gbgbcmrf'),('gbgrf'),('gbhfvblf'),('gbjyth'),('gblfhfc'),('gblfhfcs'),('gbljhfc'),('gbljhfcs'),('gbolahan'),('gbpltw'),('gbrfxe'),('gbyudby'),('gcb'),('gcheckout'),('gd4life'),('gdcc9921'),('gdn7414'),('ge0rge'),('gearhead'),('gears1'),('gears2'),('gearsofwar'),('gearsofwar2'),('gecko'),('gecko1'),('gedeon'),('gee123'),('geegee'),('geegee1'),('geelong'),('geelong1'),('geetanjali'),('geetha'),('geezer'),('gefccgag'),('geforce'),('gegcbr'),('gege'),('gegege'),('geheim'),('geheim1'),('geheim123'),('geibcnbr'),('geirby'),('geisha'),('gelato'),('gem'),('gembel'),('gembird'),('gemelas'),('gemelli'),('gemelos'),('gemeni'),('gemgem'),('gemini'),('gemini01'),('gemini06'),('gemini1'),('gemini11'),('gemini12'),('gemini123'),('gemini13'),('gemini17'),('gemini18'),('gemini2'),('gemini21'),('gemini22'),('gemini23'),('gemini3'),('gemini5'),('gemini6'),('gemini69'),('gemini7'),('gemini77'),('gemini88'),('geminis'),('gemma'),('gemma1'),('gemma123'),('gemstone'),('gen'),('gena'),('genaro'),('gendarme'),('gender'),('gendut'),('gene'),('general'),('general01'),('general1'),('general123'),('general2'),('generale'),('generallee'),('generals'),('generals1'),('generation'),('generator'),('generic'),('generic1'),('genesis'),('genesis01'),('genesis1'),('genesis11'),('genesis12'),('genesis123'),('genesis2'),('genesis3'),('genesis7'),('genetics'),('geneva'),('geneva1'),('geneve'),('genevieve'),('genevieve1'),('gengen'),('genial'),('genie'),('genius'),('genius1'),('genius12'),('genius123'),('geniusnet'),('geniusv'),('gennadiy'),('gennaio'),('gennaro'),('genoa1893'),('genocide'),('genova'),('genoveva'),('gentle'),('gentle1'),('gentleman'),('gentry'),('genuine'),('genuine1'),('geo'),('geo123'),('geoff'),('geoff1'),('geoffrey'),('geoffrey1'),('geogeo'),('geografia'),('geography'),('geology'),('geometra'),('geometry'),('geordie'),('geordie1'),('georg'),('george'),('george!'),('george.'),('george01'),('george06'),('george07'),('george08'),('george09'),('george1'),('george10'),('george11'),('george12'),('george123'),('george1234'),('george13'),('george14'),('george15'),('george16'),('george17'),('george18'),('george2'),('george21'),('george22'),('george23'),('george24'),('george25'),('george27'),('george3'),('george4'),('george5'),('george6'),('george69'),('george7'),('george77'),('george8'),('george9'),('george99'),('georges'),('georgetown'),('georgette'),('georgi'),('georgia'),('georgia01'),('georgia1'),('georgia11'),('georgia12'),('georgia123'),('georgia2'),('georgia3'),('georgia7'),('georgiana'),('georgie'),('georgie1'),('georgina'),('georgina1'),('georgiy'),('georgy'),('gepard'),('geppetto'),('ger'),('gerald'),('gerald1'),('gerald123'),('geraldine'),('geraldine1'),('geraldo'),('geranium'),('gerard'),('gerard!'),('gerard1'),('gerard12'),('gerard123'),('gerard2'),('gerardo'),('gerardo1'),('gerardway'),('gerardway1'),('gerasim'),('gerber'),('gerber1'),('gerbera'),('gerbil'),('gerbil1'),('gerger'),('gerhard'),('gericom'),('gerlinde'),('germain'),('germaine'),('german'),('german1'),('german123'),('germania'),('germany'),('germany1'),('germany123'),('germany2'),('geroin'),('gerome'),('geronimo'),('geronimo1'),('geronto'),('gerrard'),('gerrard08'),('gerrard1'),('gerrard8'),('gerrit'),('gerry'),('gerry1'),('gershwin'),('gerson'),('gertie'),('gertie1'),('gertrude'),('gertrude1'),('gestapo'),('gesundheit'),('get'),('get2work'),('getajob'),('getalife'),('getalife1'),('getatme1'),('getaway'),('getbent'),('getcrunk1'),('getdown'),('getfucked'),('getfucked1'),('gethigh'),('gethigh1'),('gethigh420'),('getit'),('getit1'),('getjob'),('getlaid'),('getlikeme1'),('getlost'),('getlost1'),('getlow'),('getmein'),('getmoney'),('getmoney!'),('getmoney$'),('getmoney07'),('getmoney08'),('getmoney09'),('getmoney1'),('getmoney10'),('getmoney11'),('getmoney12'),('getmoney2'),('getmoney21'),('getmoney22'),('getmoney23'),('getmoney24'),('getmoney3'),('getmoney4'),('getmoney5'),('getmoney6'),('getmoney7'),('getoff'),('getout'),('getout1'),('getpaid'),('getpaid1'),('getrdone'),('getrdone1'),('getreal'),('getrich'),('getrich1'),('getsilly1'),('getsmart'),('getsome'),('getsome1'),('gettherefast'),('gettysburg'),('geujdrf'),('gewinner'),('gf'),('gfccdjhl'),('gfcgjhn'),('gfdkbr'),('gfdkeif'),('gfdkjd'),('gfdkjdf'),('gfgekz'),('gfgf'),('gfgfgf'),('gfgfgfgf'),('gfgfvfvf'),('gfghbrf'),('gfgjxrf'),('gfh'),('gfhfdjp'),('gfhfif'),('gfhfljrc'),('gfhfpbn'),('gfhfyjz'),('gfhjdjp'),('gfhjk123'),('gfhjkm'),('gfhjkm1'),('gfhjkm11'),('gfhjkm12'),('gfhjkm123'),('gfhjkm12345'),('gfhjkm13'),('gfhjkm1998'),('gfhjkm2'),('gfhjkm777'),('gfhjkmgfhjkm'),('gfhjkmm'),('gfhjkmrf'),('gfhjkmxbr'),('gfhjkzytn'),('gfhkfvtyn'),('gfhnbpfy'),('gfhreh'),('gfhtym'),('gfkmvf'),('gfnhbjn'),('gfnhbr'),('gforce'),('gfs2z6wb'),('gfyfcjybr'),('gfynthf'),('gfyt63gd'),('gg'),('gg1234'),('gg123456'),('ggg'),('ggg111'),('ggg123'),('gggg'),('ggggg'),('ggggg1'),('gggggg'),('gggggg1'),('ggggggg'),('gggggggg'),('ggggggggg'),('gggggggggg'),('ggolob'),('ggunit1'),('ghalina_1971'),('ghana'),('ghana1'),('ghana123'),('ghandi'),('ghazal'),('ghb'),('ghbdfn'),('ghbdtn'),('ghbdtn1'),('ghbdtn12'),('ghbdtn123'),('ghbdtnbr'),('ghbdtnbrb'),('ghbdtndctv'),('ghbdtnekmrb'),('ghbdtnghbdtn'),('ghbdtngjrf'),('ghbdtnrfrltkf'),('ghbhjlf'),('ghbjhbntn'),('ghblehjr'),('ghblehrb'),('ghbphfr'),('ghbrjk'),('ghbrjkbcn'),('ghbrjkmyj'),('ghbynth'),('ghbywtccf'),('gheniagabb'),('gheorghe'),('ghetto'),('ghetto1'),('ghetto12'),('ghetto123'),('ghetto2'),('ghfdlf'),('ghfplybr'),('ghgh'),('ghghgh'),('ghghgh1'),('ghghghgh'),('ghhh47hj7649'),('ghislain'),('ghislaine'),('ghj'),('ghj100'),('ghj123'),('ghjcgtrn'),('ghjcnb'),('ghjcnbnenrf'),('ghjcnbvtyz'),('ghjcnj'),('ghjcnj123'),('ghjcnjgfhjkm'),('ghjcnjghjcnj'),('ghjcnjkjk'),('ghjcnjnfr'),('ghjcnjq'),('ghjcnjqgfhjkm'),('ghjcnjrdfibyj'),('ghjcnjrdfif'),('ghjcnjz'),('ghjdthrf'),('ghjgecr'),('ghjghj'),('ghjghjghj'),('ghjhjr'),('ghjkju'),('ghjkl'),('ghjnjnbg'),('ghjnjrjk'),('ghjrehfnehf'),('ghjrehjh'),('ghjuhfvvbcn'),('ghjuhfvvf'),('ghjuhtcc'),('ghkdf14'),('gholovach75'),('ghost'),('ghost1'),('ghost12'),('ghost123'),('ghost13'),('ghost2'),('ghost5'),('ghost666'),('ghost7'),('ghostdog'),('ghostface'),('ghostface1'),('ghostman'),('ghostrecon'),('ghostrider'),('ghosts'),('ghosts1'),('ghrhfh'),('ghrimachiova64'),('ghtdtl123'),('ghtktcnm'),('ghtpbltyn'),('ghusieva1958'),('ghzybr'),('gia'),('giacomino'),('giacomo'),('giacomo1'),('giada'),('giadina'),('giallo'),('giancarlo'),('gianfranco'),('giangi'),('gianluca'),('gianmarco'),('gianna'),('gianna1'),('gianni'),('gianni1'),('giant'),('giant1'),('giants'),('giants08'),('giants1'),('giants10'),('giants11'),('giants12'),('giants123'),('giants21'),('giants25'),('giants56'),('gibbon'),('gibbons'),('gibraltar'),('gibson'),('gibson01'),('gibson1'),('gibson12'),('gibson123'),('gibson2'),('gibsonsg'),('gibsonsg1'),('giddyup'),('gideon'),('gideon1'),('gidget'),('gidget1'),('gidrometeoburo'),('gifema'),('gifted'),('gifted1'),('gig'),('gigabyte'),('gigaman8891'),('gigant'),('gigante'),('giggity'),('giggity1'),('giggle'),('giggle1'),('giggles'),('giggles1'),('giggles12'),('giggles123'),('giggles13'),('giggles2'),('gigglez1'),('giggs11'),('giggsy'),('gigi'),('gigi12'),('gigi123'),('gigigi'),('gigigigi'),('gigino'),('gigolo'),('gil'),('gil123'),('gilang'),('gilbert'),('gilbert1'),('gilbert2'),('gilberto'),('gilberto1'),('gilera'),('gilgamesh'),('gilipollas'),('gilles'),('gillespie'),('gillette'),('gillian'),('gillian1'),('gilligan'),('gilligan1'),('gillingham'),('gillou'),('gilmore'),('gilmore1'),('gilmour'),('gin'),('gina'),('gina12'),('gina123'),('ginagina'),('ginebra'),('ginette'),('ginevra'),('ginger'),('ginger!'),('ginger.'),('ginger00'),('ginger01'),('ginger02'),('ginger06'),('ginger07'),('ginger08'),('ginger09'),('ginger1'),('ginger10'),('ginger101'),('ginger11'),('ginger12'),('ginger123'),('ginger1234'),('ginger13'),('ginger14'),('ginger15'),('ginger16'),('ginger17'),('ginger18'),('ginger2'),('ginger21'),('ginger22'),('ginger23'),('ginger24'),('ginger3'),('ginger33'),('ginger4'),('ginger5'),('ginger6'),('ginger69'),('ginger7'),('ginger77'),('ginger8'),('ginger88'),('ginger9'),('ginger99'),('gingerale'),('gingerbread'),('gingersnap'),('gingging'),('gingin'),('ginny'),('ginny1'),('gino'),('ginogino'),('ginola'),('gintonic'),('ginuwine'),('ginuwine1'),('gio'),('gio123'),('gioconda'),('giogio'),('gioia'),('giordano'),('giorgi'),('giorgia'),('giorgina'),('giorgio'),('giorgio1'),('giotto'),('giovana'),('giovani'),('giovanna'),('giovanna1'),('giovanni'),('giovanni1'),('giovanni123'),('giovanny'),('gipper'),('girafa'),('girafe'),('giraffa'),('giraffe'),('giraffe1'),('girasol'),('girasole'),('girassol'),('giratina'),('giresun28'),('girija'),('girish'),('girl'),('girl10'),('girl101'),('girl11'),('girl12'),('girl123'),('girl1234'),('girl13'),('girl14'),('girl15'),('girl22'),('girl23'),('girl69'),('girlfriend'),('girlgirl'),('girlie'),('girlie1'),('girlpower'),('girlpower1'),('girls'),('girls1'),('girls101'),('girls12'),('girls123'),('girls2'),('girls3'),('girls4'),('girls5'),('girls69'),('girlsrock'),('girlsrock1'),('girlsrule'),('girlsrule1'),('girlss'),('girly'),('girly1'),('girly12'),('girly123'),('girlygirl'),('girlygirl1'),('gisela'),('gisele'),('gisella'),('giselle'),('giselle1'),('gismo'),('gismo1'),('gisselle'),('gitana'),('gitano'),('gitara'),('gitara1'),('gitarre'),('gitler'),('gitrdone'),('gitrdone1'),('giuditta'),('giugno'),('giulia'),('giulia1'),('giuliana'),('giuliano'),('giulietta'),('giulio'),('giuseppe'),('giuseppe1'),('giuseppina'),('giusy'),('giveit2me'),('giveme'),('givenchy'),('gixxer'),('gizmo'),('gizmo01'),('gizmo1'),('gizmo10'),('gizmo11'),('gizmo12'),('gizmo123'),('gizmo13'),('gizmo2'),('gizmo22'),('gizmo3'),('gizmo5'),('gizmo69'),('gizmo7'),('gizmos'),('gizmos1'),('gizzie'),('gizzmo'),('gizzmo1'),('gizzy'),('gizzy1'),('gj'),('gjcaixxx'),('gjgeufq'),('gjgjdf'),('gjhjctyjr'),('gjhjkm'),('gjikbdctyf'),('gjikbyf'),('gjitkyf'),('gjkbujy'),('gjkbyf'),('gjkbyjxrf'),('gjkbyrf'),('gjkzrjdf'),('gjlcnfdf'),('gjlfhjr'),('gjmptw'),('gjpbnbd'),('gjrtvjy'),('gjujlf'),('gjvbljh'),('gjyjxrf'),('gjyxbr'),('gkfytnf'),('glacier'),('glacier1'),('gladbach'),('gladiador'),('gladiator'),('gladiator1'),('gladiatore'),('gladiolus'),('gladis'),('gladstone'),('gladys'),('gladys1'),('glafira110169'),('glaiza'),('glamorous'),('glamorous1'),('glamour'),('glamour1'),('glamur'),('glasgow'),('glasgow1'),('glass'),('glass1'),('glass123'),('glasses'),('glasses1'),('glassjaw'),('glassman'),('gldfzPY'),('Gleiser4'),('glen'),('glenda'),('glenda1'),('glendale'),('glendale1'),('glenn'),('glenn1'),('glenn123'),('glenwood'),('glenwood1'),('glider'),('glitter'),('glitter1'),('glitter2'),('glo'),('global'),('global1'),('global123'),('globe'),('globe1'),('globus'),('glock'),('glock17'),('glock19'),('glock21'),('glock22'),('glock23'),('glock40'),('glock45'),('glock9'),('gloire'),('gloria'),('gloria1'),('gloria12'),('gloria123'),('gloria2'),('glorioso'),('glorious'),('glorious1'),('glory'),('glory1'),('glory123'),('glory2god'),('glorytogod'),('gloucester'),('glover'),('glover1'),('gloves'),('gluxov70'),('gmail'),('gmail.com'),('gmail123'),('gman'),('gman123'),('gmoney'),('gmoney1'),('gn9gu44s'),('gnaget'),('gnbxrf'),('gnocca'),('gnomes'),('gnomik'),('gnu'),('gnusmas'),('go'),('go1234'),('go2hell'),('go49ers'),('go4itnow'),('go4jobs'),('goahead'),('goal'),('goalie'),('goalie1'),('goalkeeper'),('goarmy'),('goarmy1'),('goat'),('goats'),('goaway'),('goaway!'),('goaway1'),('gobble'),('gobears'),('gobears1'),('gobigred'),('goblin'),('goblin1'),('goblue'),('goblue1'),('gobucks'),('gobucks1'),('gocards'),('gocards1'),('gocats'),('gocubs'),('gocubs1'),('god'),('god101'),('god111'),('god123'),('god1234'),('god12345'),('god1st'),('god4ever'),('god4life'),('god4me'),('god666'),('god7507'),('god777'),('godawgs'),('godawgs1'),('godbless'),('godbless1'),('godblessme'),('godblessu'),('godblessus'),('godblessyou'),('godchild'),('goddamn1'),('goddess'),('goddess1'),('goddey'),('goderdzikarxjxv'),('godess'),('godfather'),('godfather1'),('godfather2'),('godfirst'),('godfirst1'),('godfrey'),('godfrey1'),('godgod'),('godgod1'),('godgrace'),('godhelp'),('godhelpme'),('godhelpme1'),('godiM001'),('godis'),('godis#1'),('godis1'),('godisable'),('godisgood'),('godisgood!'),('godisgood1'),('godisgood2'),('godisgood7'),('godisgr8'),('godisgreat'),('godislove'),('godislove1'),('godislove2'),('godislove7'),('godisone'),('godiva'),('godjesus'),('godknows'),('godlike'),('godlike1'),('godlove'),('godlove1'),('godloveme'),('godloves'),('godloves1'),('godlovesme'),('godman'),('godofwar'),('godofwar1'),('godofwar2'),('godofwar3'),('godrocks'),('godrocks1'),('godrules'),('godrules1'),('godschild'),('godschild1'),('godsent'),('godsfavor'),('godsgift'),('godsgift1'),('godsgirl'),('godsgrace'),('godslove'),('godslove1'),('godsmack'),('godsmack1'),('godson'),('godson1'),('godspeed'),('godspeed1'),('godsson1'),('godswill'),('godswill1'),('godtime'),('goducks'),('goducks1'),('goduke'),('godwin'),('godwin1'),('godzila'),('godzilla'),('godzilla1'),('godzilla2'),('goeagles'),('goethe'),('gofast'),('gofish'),('gofish1'),('gofman_osk'),('goforit'),('goforit1'),('gofuckyour'),('gofuckyourself'),('gogators'),('gogators1'),('gogeta'),('gogeta1'),('gogetit'),('gogetta'),('gogetta1'),('gogetter'),('goggles'),('gogiants'),('gogirl'),('gogirl1'),('gogo'),('gogo12'),('gogo123'),('gogogo'),('gogogo1'),('gogogogo'),('gogreen'),('gogreen1'),('gohabsgo'),('gohan'),('gohan1'),('gohard'),('gohard1'),('gohawks'),('goheels'),('gohogs'),('gohome'),('gohome1'),('goirish'),('goirish1'),('gokart'),('gokhan'),('gokil'),('goku'),('goku12'),('goku123'),('gokussj4'),('gol'),('golaso64'),('gold'),('gold11'),('gold12'),('gold123'),('gold1234'),('gold44'),('goldberg'),('goldberg1'),('goldcoast'),('golddigger'),('golden'),('golden01'),('golden1'),('golden11'),('golden12'),('golden123'),('golden2'),('golden22'),('golden7'),('goldenboy'),('goldenboy1'),('goldeneye'),('goldeneye1'),('goldengate'),('goldengirl'),('goldensun'),('goldfinger'),('goldfish'),('goldfish1'),('goldfish12'),('goldfish2'),('goldflake'),('goldgold'),('goldie'),('goldie1'),('goldie12'),('goldie123'),('goldie2'),('goldilocks'),('goldleaf'),('goldman'),('goldmember'),('goldmine'),('goldorak'),('goldrush'),('goldsmith'),('goldstar'),('goldstar1'),('goldwing'),('goldwing1'),('goldy'),('goldy1'),('goleafsgo'),('golf'),('golf01'),('golf11'),('golf12'),('golf123'),('golf1234'),('golf18'),('golf22'),('golf4fun'),('golf69'),('golf72'),('golfball'),('golfball1'),('golfclub'),('golfcourse'),('golfer'),('golfer01'),('golfer1'),('golfer11'),('golfer12'),('golfer123'),('golfer2'),('golfer69'),('golfgolf'),('golfgti'),('golfing'),('golfing1'),('golfinho'),('golfman'),('golfnut'),('golfpro'),('golfpro1'),('golfr32'),('golftdi'),('golfvr6'),('golga.70'),('golgo13'),('goliat'),('goliath'),('goliath1'),('gollum'),('gollum1'),('golosa'),('golosa69'),('golova'),('golovizina_elena'),('golubinskij.87'),('goluboglazka08'),('goman1985'),('gomets'),('gomez'),('gomez1'),('gomez123'),('gonavy'),('gonavy1'),('goncalo'),('goncalves'),('gondon'),('gondor'),('gone'),('gonefishin'),('gonefishing'),('gonoles'),('gonoles1'),('gonzaga'),('gonzaga1'),('gonzales'),('gonzales1'),('gonzalez'),('gonzalez1'),('gonzalez12'),('gonzalo'),('gonzalo1'),('gonzo'),('gonzo1'),('gonzo123'),('goo'),('goober'),('goober1'),('goober12'),('goober123'),('goober2'),('goobers'),('good'),('good11'),('good12'),('good123'),('good1234'),('good12345'),('good123456'),('Good123654'),('good2go'),('good4me'),('good4now'),('good4u'),('good4you'),('goodboy'),('goodboy1'),('goodboy123'),('goodbullet'),('goodbye'),('goodbye1'),('goodbye2'),('goodcharlotte'),('goodday'),('goodday1'),('gooddog'),('goodfella1'),('goodfellas'),('goodfood'),('goodfriend'),('goodgame'),('goodgirl'),('goodgirl1'),('goodgod'),('goodgod1'),('goodgood'),('goodgood1'),('goodguy'),('goodguy1'),('goodie'),('goodie1'),('goodies'),('goodies1'),('goodison'),('goodjob'),('goodlife'),('goodlife1'),('goodlooking'),('goodlord'),('goodlove'),('goodluck'),('goodluck1'),('goodluck123'),('goodman'),('goodman1'),('goodmorning'),('goodmother'),('goodness'),('goodness1'),('goodnews'),('goodnight'),('goodnight1'),('goodone'),('goodpussy'),('goodpussy1'),('goodrich'),('goodsex'),('goodstuff'),('goodtime'),('goodtime1'),('goodtimes'),('goodtimes1'),('goodtogo'),('goodwife'),('goodwill'),('goodwill1'),('goodwin'),('goodwin1'),('goodwoman'),('goodwood'),('goody'),('goody1'),('goody2shoe'),('goodyear'),('goodyear1'),('goofball'),('goofball1'),('goofy'),('goofy1'),('goofy12'),('goofy123'),('goofy13'),('goofy2'),('googie'),('google'),('google!'),('google.'),('google.com'),('google01'),('google1'),('google10'),('google11'),('google12'),('google123'),('google1234'),('google13'),('google2'),('google21'),('google22'),('google23'),('google3'),('google4'),('google5'),('google6'),('google69'),('google7'),('google8'),('google9'),('googlecheckout'),('googles'),('googletester'),('googly'),('googoo'),('googoo1'),('goomba'),('goon12'),('goon123'),('goon4life'),('gooner'),('gooner1'),('goonie'),('goonie1'),('goonies'),('goonies1'),('goons1'),('goonsquad1'),('goose'),('goose1'),('goose123'),('goosebumps'),('goosey'),('gopack'),('gopal'),('gopher'),('gopher1'),('Gopher12'),('gophers'),('gopinath'),('gopnik'),('gor'),('gorams'),('gorda1'),('gordie'),('gordis'),('gordita'),('gordita1'),('gordito'),('gordito1'),('gordo'),('gordo1'),('gordo12'),('gordo123'),('gordo13'),('gordo2'),('gordon'),('gordon1'),('gordon12'),('gordon123'),('gordon24'),('gorgeous'),('gorgeous1'),('gorges'),('gorila'),('gorilla'),('gorilla1'),('gorillas'),('gorillaz'),('gorillaz1'),('gorlonis'),('gorman'),('gorodok'),('gosia'),('gosia1'),('gosiaczek'),('gosling'),('gospel'),('gospel1'),('gossip'),('gossip1'),('gossipgirl'),('gostosa'),('gostoso'),('got'),('got2go'),('gotcha'),('gotcha!'),('gotcha1'),('gotcha2'),('gotenks'),('gotenks1'),('goth666'),('gotham'),('gothic'),('gothic1'),('gothic12'),('gothic123'),('gothic13'),('gothic2'),('gothic3'),('gothic666'),('gothica'),('gothika'),('gotigers'),('gotigers1'),('gotika'),('gotmilk'),('gotmilk1'),('gotmilk2'),('gotmilk?'),('gotmoney1'),('gotohell'),('gotohell1'),('gotribe'),('gotrice'),('gotti'),('gotti1'),('gotyou1'),('gougou'),('gouranga'),('gourmet'),('government'),('governor'),('govind'),('govinda'),('govols'),('govols1'),('GoxyBoib'),('goyj2010'),('gr'),('gr33nday'),('gr8ful'),('gr8one'),('gra'),('grace'),('grace01'),('grace05'),('grace06'),('grace07'),('grace08'),('grace1'),('grace10'),('grace11'),('grace12'),('grace123'),('grace13'),('grace17'),('grace2'),('grace22'),('grace23'),('grace3'),('grace4'),('grace4me'),('grace5'),('grace7'),('grace777'),('gracee'),('graceful'),('graceland'),('graceland1'),('graces'),('gracey'),('gracey1'),('gracia'),('gracias'),('gracie'),('gracie!'),('gracie01'),('gracie03'),('gracie05'),('gracie06'),('gracie07'),('gracie08'),('gracie09'),('gracie1'),('gracie10'),('gracie11'),('gracie12'),('gracie123'),('gracie13'),('gracie2'),('gracie22'),('gracie3'),('gracie4'),('gracie5'),('gracie7'),('graciela'),('graciela1'),('gracious'),('grad06'),('grad07'),('grad08'),('grad09'),('grad2006'),('grad2007'),('grad2008'),('grad2009'),('grad2010'),('grade6'),('graduate'),('graduate08'),('graduate1'),('graduation'),('grady'),('grady1'),('graeme'),('graffiti'),('graffiti1'),('grafton'),('graham'),('graham1'),('grahm'),('gramma'),('gramma1'),('grammar'),('grammy'),('grammy1'),('gramps'),('granada'),('granada1'),('granat'),('granata'),('grand'),('grand1'),('grandad'),('grandad1'),('grandam'),('grandam1'),('grandchase'),('grandchildren'),('grande'),('grande1'),('grandkids'),('grandkids1'),('grandkids2'),('grandkids3'),('grandkids4'),('grandkids5'),('grandkids6'),('grandkids7'),('grandma'),('grandma!'),('grandma01'),('grandma1'),('grandma11'),('grandma12'),('grandma123'),('grandma2'),('grandma3'),('grandma4'),('grandma5'),('grandma6'),('grandma7'),('grandma8'),('grandmaster'),('grandmom'),('grandmom1'),('grandmother'),('grandpa'),('grandpa1'),('grandpa2'),('grandprix'),('grandprix1'),('grandslam'),('grandson'),('grandson1'),('grandtheft'),('grange'),('granger'),('granger1'),('granit'),('granite'),('granite1'),('granny'),('granny1'),('granny12'),('granny2'),('granny3'),('granny5'),('grant'),('grant1'),('grant123'),('granville'),('grape'),('grape1'),('grapeape'),('grapefruit'),('grapes'),('grapes1'),('grapevine'),('graphic'),('graphics'),('graphics1'),('grass'),('grass1'),('grasshoppe'),('grasshopper'),('grateful'),('grateful1'),('gratis'),('gratis1'),('gratis123'),('gratitude'),('gravedigger'),('graves'),('graveyard'),('gravity'),('gravity1'),('gravy1'),('gray'),('grayson'),('grayson1'),('graywolf'),('grazia'),('graziano'),('grazie'),('graziella'),('gre'),('grease'),('grease1'),('great'),('great1'),('great123'),('great8'),('greatdane'),('greatday'),('greatday1'),('greater'),('greater1'),('greatest'),('greatest1'),('greatgod'),('greatman'),('greatness'),('greatness1'),('greatone'),('greatone1'),('greats'),('greatwhite'),('grecia'),('greece'),('greece1'),('greedisgood'),('greedy'),('greedy1'),('greek'),('greek1'),('green'),('green!'),('green.'),('green00'),('green01'),('green06'),('green07'),('green08'),('green09'),('green1'),('green10'),('green100'),('green101'),('green11'),('green111'),('green12'),('green123'),('green1234'),('green12345'),('green13'),('green14'),('green15'),('green16'),('green17'),('green18'),('green19'),('green2'),('green20'),('green21'),('green22'),('green23'),('green24'),('green25'),('green26'),('green27'),('green28'),('green3'),('green32'),('green321'),('green33'),('green34'),('green4'),('green42'),('green420'),('green44'),('green45'),('green5'),('green55'),('green6'),('green66'),('green69'),('green7'),('green77'),('green777'),('green8'),('green88'),('green89'),('green9'),('green99'),('greenapple'),('greenbay'),('greenbay1'),('greenbay4'),('greenbean'),('greenbean1'),('greenday'),('greenday!'),('greenday.'),('greenday1'),('greenday10'),('greenday11'),('greenday12'),('greenday123'),('greenday13'),('greenday14'),('greenday2'),('greenday21'),('greenday3'),('greenday4'),('greenday5'),('greenday6'),('greenday7'),('greenday9'),('greendog'),('greene'),('greene1'),('greeneggs'),('greener'),('greeneyes'),('greeneyes1'),('greeneyes2'),('greenfield'),('greenfrog'),('greenfrog1'),('greengirl'),('greengrass'),('greengreen'),('greenhouse'),('greenie'),('greenland'),('greenlantern'),('greenleaf'),('greenlight'),('greenman'),('greenman1'),('greenpeace'),('greens'),('greens1'),('greentea'),('greentea1'),('greentree'),('greentree1'),('greenville'),('greenway'),('greenwich'),('greenwood'),('greenwood1'),('greeny'),('greeny1'),('greetings'),('greg'),('greg11'),('greg12'),('greg123'),('greg1234'),('greggy'),('gregoire'),('gregor'),('gregorio'),('gregory'),('gregory1'),('gregory123'),('gregory2'),('gregory3'),('gregory7'),('gremio'),('gremlin'),('gremlin1'),('gremlins'),('grenada'),('grenade'),('grendel'),('grendel1'),('grenoble'),('grenouille'),('greshnik'),('greta'),('greta1'),('gretchen'),('gretchen1'),('gretel'),('gretta'),('gretta1'),('gretzky'),('gretzky99'),('grey'),('greygoose'),('greygoose1'),('greyhound'),('greyhound1'),('greyson'),('greywolf'),('gri'),('gribouille'),('griffen'),('griffey'),('griffey1'),('griffey24'),('griffin'),('griffin1'),('griffith'),('griffon'),('grigri'),('grih-rom'),('grihan'),('grillo'),('grillz1'),('grimreaper'),('grinch'),('grinch1'),('grind1'),('grindcore'),('grinder'),('grinder1'),('grinding'),('Grine89'),('grinface'),('gringa'),('gringo'),('gringo1'),('griselda'),('griselda1'),('grisette'),('grisha'),('grishin0308'),('grisou'),('grissom'),('grizzly'),('grizzly1'),('gro'),('groceries'),('grocery'),('gromit'),('gromit1'),('groningen'),('groove'),('groove1'),('groovy'),('groovy1'),('groucho'),('groucho1'),('ground'),('grounded'),('grounded1'),('groundhog'),('group'),('group1'),('groupd1'),('Groupd2013'),('grove1'),('grover'),('grover1'),('growth'),('gruby12'),('grumpy'),('grumpy1'),('grumpy13'),('grundig'),('grunge'),('grunge1'),('grunt'),('grunt1'),('gryffindor'),('gryphon'),('grzegorz'),('grzesiek'),('gs1905'),('gshock'),('gsxr1000'),('gsxr1100'),('gsxr1300'),('gsxr600'),('gsxr750'),('gta123'),('gtagta'),('gtasanandreas'),('gtavicecity'),('gthcbr'),('gthdsq'),('gthtcnhjqrf'),('gtivr6'),('gtkmvtyb'),('gtkmvtym'),('gtnheirf'),('gtnhjczy'),('gtnhjd'),('gtnhjdbx'),('gtnhjdf'),('gtnhjdyf'),('gtxtymrf'),('gu1tar'),('guacamole'),('guadalajar'),('guadalajara'),('guadalupe'),('guadalupe1'),('guadalupe2'),('guadeloupe'),('gualapmi'),('guam671'),('guanajuato'),('guapa'),('guapo'),('guapo1'),('guarana'),('guard1'),('guardian'),('guardian1'),('guardian101'),('guardians'),('guatemala'),('guatemala1'),('guatemala2'),('guayaquil'),('gucci'),('gucci1'),('gucci12'),('gucci123'),('gucci2'),('guccimane'),('guccimane1'),('gucio'),('gudiya'),('gudrun'),('guera1'),('guero1'),('guerra'),('guerra1'),('guerreiro'),('guerrero'),('guerrero1'),('guess'),('guess1'),('guess123'),('guess2'),('guessit'),('guessit1'),('guessit22'),('guessthis1'),('guesswhat'),('guesswhat1'),('guesswho'),('guesswho1'),('guest'),('guest1'),('guevara'),('guevara1'),('guevarra'),('gui'),('gui123'),('guido'),('guido1'),('guigui'),('guild'),('guildwars'),('guildwars1'),('guilherme'),('guilherme1'),('guillaume'),('guillaume1'),('guille'),('guillermo'),('guillermo1'),('guilty'),('guilty1'),('guimaraes'),('guinea'),('guineapig'),('guiness'),('guiness1'),('guinness'),('guinness1'),('guismo'),('guitar'),('guitar!'),('guitar.'),('guitar01'),('guitar1'),('guitar10'),('guitar101'),('guitar11'),('guitar12'),('guitar123'),('guitar13'),('guitar14'),('guitar15'),('guitar2'),('guitar21'),('guitar22'),('guitar23'),('guitar3'),('guitar4'),('guitar5'),('guitar6'),('guitar666'),('guitar69'),('guitar7'),('guitar77'),('guitar8'),('guitar9'),('guitare'),('guitare1'),('guitarhero'),('guitarist'),('guitarist1'),('guitarman'),('guitarman1'),('guitarra'),('guitarra1'),('guitars'),('guitars1'),('guizmo'),('gujunpyo'),('guldaniya.galina'),('gulfik'),('gulliver'),('gulmira'),('gulnara'),('gulnaz'),('gulshan'),('gumball'),('gumball1'),('gumbo1'),('gumby'),('gumby1'),('gumdrop'),('gumdrop1'),('gummy'),('gummy1'),('gummybear'),('gummybear1'),('gummybears'),('gumption'),('gun'),('gun123'),('gunawan'),('gunblade'),('gunbound'),('gundam'),('gundam00'),('gundam01'),('gundam1'),('gundam123'),('gundamseed'),('gundamwing'),('gungrave'),('gungun'),('gunit'),('gunit1'),('gunit12'),('gunit123'),('gunit2'),('gunit5'),('gunit50'),('gunjan'),('gunman'),('gunnar'),('gunnar1'),('gunner'),('gunner01'),('gunner1'),('gunner11'),('gunner12'),('gunner123'),('gunner2'),('gunners'),('gunners1'),('gunot1'),('guns'),('gunshot'),('gunslinger'),('gunsmoke'),('gunsnroses'),('gunter'),('gunther'),('gunther1'),('guntis'),('guntur'),('guo150'),('gupta'),('gurl123'),('gurpreet'),('guru'),('guru123'),('guru1234'),('gurudev'),('guruguru'),('guruji'),('gurunanak'),('gus'),('gus123'),('gusanito'),('gusano'),('gusgus'),('gusgus1'),('gussie'),('gustav'),('gustav1'),('gustave'),('gustavo'),('gustavo1'),('gustavo12'),('gustavo123'),('guster'),('gutentag'),('guthrie'),('gutierrez'),('gutierrez1'),('gutschein'),('gutta1'),('gutter'),('gutter1'),('guwahati'),('guwapo'),('guy'),('guy123'),('guyana'),('guyana1'),('guyg56fghf'),('guyguy'),('guyssuck'),('guyssuck1'),('guyver'),('guyver1'),('guzel.t.f'),('guzman'),('guzman1'),('gv5235523532'),('gvinpinka123'),('GvqJvxVb76'),('GvqZvxUb76'),('gwada971'),('gwadada'),('gwapa'),('gwapako'),('gwapings'),('gwapito'),('gwapo'),('gwapo1'),('gwapo123'),('gwapoako'),('gwapoko'),('gwarmonster'),('gwen'),('gwendoline'),('gwendolyn'),('gwendolyn1'),('gwerty'),('gwerty123'),('gwiazda'),('gwyneth'),('gxtkrf'),('Gy3Yt2RGLs'),('gygypyfyyyposhy'),('gymnast'),('gymnast1'),('gymnastics'),('gypsie'),('gypsy'),('gypsy1'),('gypsy123'),('gznybwf'),('gznybwf13'),('g_alisa1502'),('h'),('h-town'),('h00ters'),('h0ckey'),('h0ller'),('h0llyw00d'),('h0td0g'),('h0ttie'),('h12345'),('h123456'),('h1234567'),('h12345678'),('h123456789'),('h1992iding'),('h1h1h1'),('H1xp2z2duK'),('h2oh2o'),('h2opolo'),('H2vWDuBjX4'),('h36js3gGoF'),('h3llokitty'),('h4ck3r'),('h4HgAipGzu'),('h4t3cr3w'),('h80lsa'),('h87va5rtp6'),('H8LLP9F'),('h97e7IjwwB'),('ha'),('ha1234'),('ha123456'),('habana'),('habbo1'),('habbo123'),('habeeb'),('habib'),('habiba'),('habibi'),('habibi1'),('habitat'),('habitat1'),('hacienda'),('hack'),('hack123'),('hacked'),('hacked1'),('hacked123'),('hacker'),('hacker1'),('hacker12'),('hacker123'),('hacker2'),('hackers'),('hackers1'),('hacking'),('hackme'),('hackthis1'),('hadassah'),('haddock'),('hades'),('hadiza'),('hadley'),('hadoken'),('hadouken'),('hafida'),('hagakure'),('haggard'),('haggard1'),('haggis'),('hagrid'),('haha'),('haha101'),('haha11'),('haha12'),('haha123'),('haha1234'),('haha12345'),('haha13'),('haha22'),('haha23'),('haha69'),('hahabitch1'),('hahaha'),('hahaha!'),('hahaha.'),('hahaha1'),('hahaha11'),('hahaha12'),('hahaha123'),('hahaha2'),('hahaha3'),('hahaha5'),('hahaha6'),('hahaha7'),('hahahaha'),('hahahaha1'),('hahahahaha'),('hahahehe'),('hahalol'),('hahalol1'),('hai'),('hai123'),('haider'),('haihai'),('haikal'),('hailee'),('hailee1'),('hailey'),('hailey01'),('hailey03'),('hailey04'),('hailey05'),('hailey06'),('hailey07'),('hailey08'),('hailey1'),('hailey11'),('hailey12'),('hailey123'),('hailey13'),('hailey2'),('hailey3'),('hailey5'),('hailey7'),('hailie'),('hailie1'),('hailmary'),('hair'),('hair123'),('hairball'),('hairball1'),('haircut'),('haircut1'),('hairdresser'),('hairspray'),('hairspray1'),('hairy1'),('haiti1'),('haitian1'),('hajduk'),('hajime'),('hakan'),('hakeem'),('hakeem1'),('hakim'),('hakima'),('hakkinen'),('hakr'),('hakuna'),('hakunamatata'),('hal'),('hal9000'),('halamadrid'),('halcon'),('halcyon'),('haleigh'),('haleigh1'),('haleluya'),('haley'),('haley01'),('haley1'),('haley11'),('haley12'),('haley123'),('haley13'),('haley2'),('haley3'),('haley6'),('halflife'),('halflife1'),('halflife2'),('halfmoon'),('halfpint'),('halfpint1'),('halibut'),('halifax'),('halifax1'),('halima'),('halina'),('hall'),('hallelujah'),('haller'),('halley'),('hallie'),('hallie1'),('hallihallo'),('halliwell'),('halliwell1'),('hallmark'),('hallo'),('hallo!'),('hallo1'),('hallo11'),('hallo12'),('hallo123'),('hallo1234'),('hallo12345'),('hallo2'),('hallodu'),('hallodu1'),('halloduda'),('hallohallo'),('Hallombn001'),('halloo'),('hallow'),('halloween'),('halloween1'),('halloween2'),('halloween3'),('hallucinationse'),('halo'),('halo02'),('halo03'),('halo10'),('halo11'),('halo117'),('halo12'),('halo123'),('halo1234'),('halo12345'),('halo13'),('halo2'),('halo21'),('halo219'),('halo22'),('halo23'),('halo3'),('halo33'),('halo360'),('halo3odst'),('halo3rocks'),('halo3rules'),('halohalo'),('halohalo007'),('haloreach'),('halowars'),('halowars1'),('ham'),('ham123'),('hamada'),('hamasaki'),('hambone'),('hambone1'),('hamburg'),('hamburg1'),('hamburg15'),('hamburger'),('hamburger1'),('hamdan'),('hameed'),('hamham'),('hamid'),('hamida'),('hamilton'),('hamilton1'),('hamish'),('hamish1'),('hamlet'),('hamlet1'),('hammad'),('hammarby'),('hammed'),('hammer'),('hammer01'),('hammer1'),('hammer11'),('hammer12'),('hammer123'),('hammer2'),('hammer69'),('hammerfall'),('hammerhead'),('hammers'),('hammers1'),('hammertime'),('hammie'),('hammond'),('hammond1'),('hammy'),('hammy1'),('hammy123'),('hampshire'),('hampster'),('hampster1'),('hampton'),('hampton1'),('hamradio'),('hamster'),('hamster1'),('hamster12'),('hamster123'),('hamster2'),('hamster3'),('hamsters'),('hamsters1'),('hamtaro'),('hamtaro1'),('hamulakvitaly'),('hamza'),('hamza1'),('hamza123'),('hamzah'),('han'),('han123'),('hana'),('hanahana'),('hanakimi'),('hanako'),('hanane'),('hancock'),('hancock1'),('hand'),('handbag'),('handball'),('handball1'),('handel'),('handicap'),('handle'),('handoi'),('handsome'),('handsome1'),('handy'),('handy1'),('handyman'),('handyman1'),('hang10'),('hangar18'),('hanger18'),('hangman'),('hangman1'),('hangover'),('hanhan'),('hanhphuc'),('hanibal'),('hanicka'),('hanifa'),('hanihani'),('hank'),('hank123'),('hanka'),('hanna'),('hanna1'),('hanna12'),('hanna123'),('hannah'),('hannah!'),('hannah.'),('hannah00'),('hannah01'),('hannah02'),('hannah03'),('hannah04'),('hannah05'),('hannah06'),('hannah07'),('hannah08'),('hannah09'),('hannah1'),('hannah10'),('hannah101'),('hannah11'),('hannah12'),('hannah123'),('hannah1234'),('hannah13'),('hannah14'),('hannah15'),('hannah16'),('hannah17'),('hannah18'),('hannah19'),('hannah2'),('hannah20'),('hannah21'),('hannah22'),('hannah23'),('hannah24'),('hannah25'),('hannah3'),('hannah4'),('hannah5'),('hannah6'),('hannah69'),('hannah7'),('hannah77'),('hannah8'),('hannah88'),('hannah9'),('hannah95'),('hannah96'),('hannah97'),('hannah98'),('hannah99'),('hannahmont'),('hannahmontana'),('hannan'),('hannelore'),('hannes'),('hannes1'),('hannibal'),('hannibal1'),('hannie'),('hannover'),('hannover96'),('hanover'),('hanover1'),('hans'),('hans123'),('hans4Queck'),('hansel'),('hansen'),('hansen1'),('hanshans'),('hansi'),('hansol'),('hansol1'),('hansolo'),('hansolo1'),('hanson'),('hanson1'),('hanspeter'),('hanswurst'),('hanter'),('hantu123'),('hanuman'),('hanuman1'),('hanumanji'),('hao123'),('hao123456'),('haohao'),('hap'),('hapiness'),('hapkido'),('happening'),('happie'),('happines'),('happiness'),('happiness!'),('happiness1'),('happiness2'),('happiness7'),('happy'),('happy!'),('happy.'),('happy00'),('happy01'),('happy06'),('happy07'),('happy08'),('happy09'),('happy1'),('happy10'),('happy100'),('happy101'),('happy11'),('happy111'),('happy12'),('happy123'),('happy1234'),('happy12345'),('happy13'),('happy14'),('happy15'),('happy16'),('happy17'),('happy18'),('happy2'),('happy2007'),('happy2008'),('happy2009'),('happy2010'),('happy2011'),('happy21'),('happy22'),('happy23'),('happy24'),('happy25'),('happy2be'),('happy2bme'),('happy2day'),('happy3'),('happy321'),('happy33'),('happy4'),('happy420'),('happy4ever'),('happy4me'),('happy4u'),('happy5'),('happy55'),('happy6'),('happy69'),('happy7'),('happy77'),('happy777'),('happy8'),('happy88'),('happy9'),('happy99'),('happybirth'),('happybirthday'),('happyboy'),('happybunny'),('happycat'),('happyday'),('happyday1'),('happydays'),('happydays1'),('happydog'),('happyface'),('happyface1'),('happyfamily'),('happyfeet'),('happyfeet1'),('happyfeet2'),('happygirl'),('happygirl1'),('happyhappy'),('happyhour'),('happylife'),('happylove'),('happyman'),('happyman1'),('happyme'),('happyme1'),('happyness'),('happyness1'),('happynewyear'),('happyone'),('happys'),('happytime'),('happyy'),('har'),('harajuku'),('harakiri'),('harald'),('harbor'),('harbor1'),('harbour'),('hard'),('hardaway'),('hardball'),('hardbody1'),('hardc0re'),('hardcock'),('hardcore'),('hardcore!'),('hardcore.'),('hardcore1'),('hardcore12'),('hardcore13'),('hardcore2'),('hardcore3'),('hardcore4'),('hardcore69'),('hardcore7'),('hardcore88'),('harddick'),('harder'),('hardhead'),('hardhead1'),('hardik'),('harding'),('harding1'),('hardman'),('hardon'),('hardrock'),('hardrock1'),('hardstyle'),('hardstyle1'),('hardware'),('hardware1'),('hardwood'),('hardwork'),('hardwork1'),('hardy'),('hardy1'),('hardy123'),('harekrishna'),('harekrsna'),('hareram'),('harerama'),('harhar'),('hari'),('hari123'),('haribo'),('haribo1'),('haribol'),('hariharan'),('harika'),('harimau'),('harini'),('hariom'),('harish'),('haritha'),('harlan'),('harlee'),('harlem'),('harlem1'),('harlequin'),('harley'),('harley!'),('harley.'),('harley00'),('harley01'),('harley02'),('harley03'),('harley04'),('harley05'),('harley06'),('harley07'),('harley08'),('harley09'),('harley1'),('harley10'),('harley101'),('harley11'),('harley12'),('harley123'),('harley13'),('harley14'),('harley15'),('harley17'),('harley2'),('harley21'),('harley22'),('harley23'),('harley24'),('harley3'),('harley33'),('harley4'),('harley5'),('harley55'),('harley6'),('harley66'),('harley69'),('harley7'),('harley77'),('harley8'),('harley88'),('harley883'),('harley9'),('harley95'),('harley96'),('harley97'),('harley98'),('harley99'),('harleyd'),('harleyd1'),('harleydavidson'),('harleydog'),('harlie'),('harlow'),('harman'),('harman1'),('harmon'),('harmonia'),('harmonica'),('harmonie'),('harmony'),('harmony1'),('harmony2'),('harmony7'),('harold'),('harold1'),('harold123'),('haroon'),('harper'),('harper1'),('harpoon'),('harpreet'),('harrier'),('harriet'),('harriet1'),('harrington'),('harris'),('harris1'),('harris123'),('harrison'),('harrison1'),('harrison12'),('harrison2'),('harry'),('harry01'),('harry1'),('harry10'),('harry11'),('harry12'),('harry123'),('harry1234'),('harry13'),('harry2'),('harry22'),('harry24'),('harry3'),('harry5'),('harry6'),('harry7'),('harrydog'),('harryp'),('harryp1'),('harrypotte'),('harrypotter'),('harrypotter1'),('harrys'),('harrystyles'),('harsh'),('harsh123'),('harsha'),('harshini'),('harshit'),('harshita'),('hartford'),('hartford1'),('hartley'),('hartman'),('hartmann'),('hartnett'),('haruka'),('haruna'),('harvard'),('harvard1'),('harvest'),('harvest1'),('harvey'),('harvey01'),('harvey1'),('harvey12'),('harvey123'),('harvey2'),('harvick'),('harvick29'),('has'),('has202020'),('hasan'),('hasan1'),('hasan123'),('hase'),('haseeb'),('haseena'),('haselko'),('hash'),('hashem'),('hashim'),('hashish'),('hasina'),('haslo'),('haslo1'),('haslo123'),('hassan'),('hassan1'),('hassan12'),('hassan123'),('hassen'),('hastalavista'),('hastings'),('hastings1'),('hat'),('hat123'),('hatchet'),('hatchet1'),('hate'),('hate12'),('hate123'),('hate13'),('hate2love'),('hate666'),('hatebreed'),('hatebreed1'),('hated1'),('hatelife'),('hatelove'),('hatelove1'),('hateme'),('hateme1'),('hateme2'),('hater'),('hater1'),('hater12'),('hater123'),('hater2'),('haters'),('haters1'),('haters12'),('haters123'),('haters2'),('haterz'),('haterz1'),('hateu2'),('hateyou'),('hateyou1'),('hateyou2'),('hatfield'),('hatice'),('hatred'),('hatred1'),('hatter'),('hatteras'),('hattie'),('hattie1'),('hattrick'),('haunted'),('haunted1'),('havana'),('havana1'),('haveaniceday'),('havefaith'),('havefaith1'),('havefun'),('havefun1'),('haven1'),('havingfun'),('havoc1'),('hawaii'),('hawaii!'),('hawaii01'),('hawaii05'),('hawaii06'),('hawaii07'),('hawaii08'),('hawaii09'),('hawaii1'),('hawaii11'),('hawaii12'),('hawaii123'),('hawaii2'),('hawaii3'),('hawaii5'),('hawaii50'),('hawaii7'),('hawaii808'),('hawaii99'),('hawaiian'),('hawaiian1'),('hawk'),('hawk1020'),('hawk12'),('hawker'),('hawkesbury93'),('hawkeye'),('hawkeye1'),('hawkeyes'),('hawkeyes1'),('hawkins'),('hawkins1'),('hawks'),('hawks1'),('hawkwind'),('hawthorn'),('hawthorn1'),('hawthorne'),('hawthorne1'),('hay'),('hay123'),('hayabusa'),('hayabusa1'),('hayastan'),('hayate'),('hayati'),('haydee'),('hayden'),('hayden01'),('hayden05'),('hayden06'),('hayden07'),('hayden08'),('hayden09'),('hayden1'),('hayden11'),('hayden12'),('hayden123'),('hayden2'),('hayden3'),('hayes1'),('hayhay'),('hayhay1'),('haylee'),('haylee1'),('hayleigh'),('hayley'),('hayley1'),('hayley12'),('hayley123'),('haylie'),('haylie1'),('haynes'),('hayward'),('hayward1'),('hayward510'),('haywood'),('hazard'),('hazard1'),('haze420'),('hazel'),('hazel1'),('hazel123'),('hazeleyes'),('hazelnut'),('hazmat'),('hazzard'),('hbhc8290826'),('hbk123'),('hbk169'),('hbw'),('hbxfhl'),('Hd764nW5d7E1vb1'),('hdfcbank'),('he'),('he635789'),('hea'),('head'),('headache'),('headbanger'),('headhunter'),('headphones'),('headshot'),('headshot1'),('headstrong'),('healer'),('healing'),('healing1'),('health'),('health1'),('healthcare'),('healthy'),('healthy1'),('heart'),('heart1'),('heart12'),('heart123'),('heart13'),('heart14'),('heart2'),('heart3'),('heart5'),('heart7'),('heartagram'),('heartbeat'),('heartbeat1'),('heartbreak'),('heartbreaker'),('heartbroke'),('heartbroken'),('heartland'),('heartless'),('heartless1'),('hearts'),('hearts!'),('hearts1'),('hearts11'),('hearts12'),('hearts123'),('hearts13'),('hearts2'),('hearts3'),('hearts5'),('hearts7'),('hearty'),('heat'),('heat32'),('heater'),('heath'),('heath1'),('heather'),('heather!'),('heather.'),('heather01'),('heather07'),('heather08'),('heather09'),('heather1'),('heather10'),('heather11'),('heather12'),('heather123'),('heather13'),('heather14'),('heather15'),('heather16'),('heather17'),('heather18'),('heather2'),('heather21'),('heather22'),('heather23'),('heather3'),('heather4'),('heather5'),('heather6'),('heather69'),('heather7'),('heather8'),('heather9'),('heatwave'),('heaven'),('heaven!'),('heaven01'),('heaven07'),('heaven08'),('heaven09'),('heaven1'),('heaven10'),('heaven11'),('heaven12'),('heaven123'),('heaven13'),('heaven17'),('heaven2'),('heaven22'),('heaven3'),('heaven4'),('heaven5'),('heaven7'),('heaven77'),('heaven777'),('heavenly'),('heavenly1'),('heavens'),('heavensent'),('heavy'),('heavy1'),('heavymetal'),('hebrew'),('hebrides'),('hecate'),('heccrbq'),('hecfkrf'),('heckfy'),('heckfyxbr'),('hecnfv'),('hector'),('hector1'),('hector12'),('hector123'),('hector13'),('hector2'),('hedgehog'),('hedgehog1'),('hedimaptfcorp'),('hedwig'),('heehee'),('heeren981a'),('heffer'),('hehe'),('hehe12'),('hehe123'),('hehehaha'),('hehehe'),('hehehe1'),('hehehe123'),('hehehehe'),('heidelberg'),('heidi'),('heidi1'),('heidi123'),('heidi2'),('heihei'),('heineken'),('heineken1'),('heinlein'),('heinrich'),('heinz'),('heinz57'),('heitor250493'),('hej123'),('hejhej'),('hejhej1'),('hejhej123'),('hejhejhej'),('hejmeddig'),('hejsan'),('hejsan1'),('hejsan123'),('heka6w2'),('hektor'),('hel'),('helado'),('helder'),('helen'),('helen1'),('helen123'),('helena'),('helena1'),('helena123'),('helene'),('helene1'),('helenka'),('helga'),('helga_557634'),('helicopter'),('helikopter'),('helios'),('helium'),('helives'),('hell'),('hell00'),('hell0kitty'),('hell12'),('hell123'),('hell666'),('hellas'),('hellbound'),('hellboy'),('hellboy1'),('hellboy123'),('hellboy2'),('hellboy666'),('hellcat'),('hellen'),('heller'),('hellfire'),('hellfire1'),('hellgate'),('hellhell'),('hellhound'),('hellion'),('hellno'),('hellno1'),('hello'),('hello!'),('hello!!'),('hello.'),('hello0'),('hello00'),('hello007'),('hello01'),('hello07'),('hello08'),('hello09'),('hello1'),('hello10'),('hello100'),('hello101'),('hello11'),('hello111'),('hello12'),('hello123'),('hello1234'),('hello12345'),('hello13'),('hello14'),('hello15'),('hello16'),('hello17'),('hello18'),('hello2'),('hello20'),('hello21'),('hello22'),('hello23'),('hello24'),('hello25'),('hello2me'),('hello2u'),('hello2u2'),('hello2you'),('hello3'),('hello321'),('hello33'),('hello34'),('hello4'),('hello44'),('hello45'),('hello456'),('hello5'),('hello55'),('hello56'),('hello6'),('hello66'),('hello666'),('hello69'),('hello7'),('hello77'),('hello777'),('hello8'),('hello88'),('hello89'),('hello9'),('hello90'),('hello98'),('hello99'),('hello999'),('helloall'),('hellobaby'),('hellodolly'),('hellogoodbye'),('hellohello'),('hellohi'),('hellohi1'),('hellokitty'),('hellokitty1'),('hellokitty123'),('helloma'),('helloman'),('hellomate'),('hellome'),('hellome1'),('hellomoto'),('hellomoto1'),('helloo'),('helloo1'),('hellos'),('hellos1'),('hellosimon'),('hellothere'),('hellou'),('hellow'),('hellow1'),('helloween'),('helloworld'),('helloyou'),('helloyou1'),('hellraiser'),('hellsbells'),('hellsing'),('hellsing1'),('hellspawn'),('hellya'),('hellya1'),('hellyea'),('hellyea1'),('hellyeah'),('hellyeah1'),('helmet'),('helmet1'),('helmut'),('heloisa'),('heloise'),('help'),('help12'),('help123'),('help1234'),('help4me'),('help911'),('helpdesk'),('helper'),('helper1'),('helphelp'),('helpme'),('helpme!'),('helpme1'),('helpme11'),('helpme12'),('helpme123'),('helpme2'),('helpmegod'),('helpmelord'),('helsinki'),('hemalatha'),('hemant'),('hemanth'),('hemi'),('hemi426'),('hemicuda'),('hemingway'),('hemligt'),('hemlock'),('hemmelig'),('hen'),('henderson'),('henderson1'),('hendra'),('hendrik'),('hendrix'),('hendrix1'),('hendrix2'),('hendrix69'),('henkie'),('henley'),('hennessy'),('hennessy1'),('henni1907'),('hennie'),('henning'),('henri'),('henrietta'),('henriette'),('henrik'),('henrique'),('henry'),('henry01'),('henry1'),('henry11'),('henry12'),('henry123'),('henry13'),('henry14'),('henry2'),('henry3'),('henry5'),('henry7'),('henry8'),('henrys'),('henson'),('hentai'),('hentai1'),('hepburn'),('her'),('herald'),('herbal'),('herbalife'),('herbalife1'),('herbert'),('herbert1'),('herbie'),('herbie1'),('herbie53'),('herbsmd'),('herbst'),('hercule'),('hercules'),('hercules1'),('here'),('hereford'),('hereiam'),('heretic'),('herewego'),('heriberto'),('heritage'),('heritage1'),('herkules'),('herman'),('herman1'),('hermana'),('hermann'),('hermann1'),('hermano'),('hermanos'),('hermes'),('hermes1'),('hermie'),('hermina617berno1990f6i'),('hermine'),('herminia'),('hermione'),('hermione1'),('hermit'),('hermitage'),('hermosa'),('hermosa1'),('hermoso'),('hernan'),('hernan1'),('hernandez'),('hernandez1'),('hernandez2'),('hernando'),('hero'),('hero12'),('hero123'),('herobrine'),('heroes'),('heroes1'),('heroes5'),('herohero'),('herohonda'),('heroin'),('heroine'),('herpderp'),('herrera'),('herrera1'),('herring'),('hershey'),('hershey1'),('hershey12'),('hershey123'),('hershey2'),('hershey3'),('hershey7'),('hersheys'),('hertha'),('herve'),('heslo'),('heslo1'),('heslo123'),('hesloheslo'),('hesoyam'),('hesoyam1'),('hesoyam123'),('hester'),('hester1'),('hester23'),('heterosexual'),('hetfield'),('Hevhk43n9J'),('hewitt'),('hewlett'),('hewlett1'),('hey'),('hey123'),('hey1234'),('hey12345'),('heybabe'),('heybabe1'),('heybaby'),('heybaby1'),('heydude'),('heydude1'),('heygirl'),('heygirl1'),('heyhey'),('heyhey!'),('heyhey1'),('heyhey11'),('heyhey12'),('heyhey123'),('heyhey2'),('heyheyhey'),('heyheyhey1'),('heyjude'),('heyjude1'),('heyman'),('heyman1'),('heynow'),('heynow1'),('heythere'),('heythere1'),('heyy'),('heyyou'),('heyyou1'),('heyyou2'),('hezekiah'),('hf'),('hf:'),('hfccdtn'),('hfcgbplzq'),('hfleuf'),('hfljcnm'),('hfpdjl'),('hfrtnf'),('hfvbkm'),('hfvd3425f'),('hfytnrb'),('hfytnrf'),('hg'),('hg0209'),('hgf4h3fhf'),('hgfdsa'),('hggih'),('hghghg'),('hgrFQg4577'),('HGxnewx11'),('hh123456'),('hhh'),('hhh123'),('hhhh'),('hhhhh'),('hhhhh1'),('hhhhhh'),('hhhhhh1'),('hhhhhh7'),('hhhhhhh'),('hhhhhhhh'),('hhhhhhhhh'),('hhhhhhhhhh'),('hi'),('hi123'),('hi1234'),('hi12345'),('hi123456'),('hiawatha'),('hibees'),('hibernia'),('hibernian'),('hibiscus'),('hicham'),('hichem'),('hickey'),('hickory'),('hickory1'),('hidalgo'),('hidalgo1'),('hidayah'),('hidayat'),('hidden'),('hidden1'),('hideki'),('hifive'),('higgins'),('higgins1'),('high'),('high123'),('high420'),('highbury'),('highbury1'),('higher'),('higher1'),('highfive'),('highheel'),('highheels'),('highland'),('highland1'),('highlander'),('highlands'),('highlife'),('highlife1'),('highschool'),('highspeed'),('hightimes'),('hightimes1'),('highway'),('highway1'),('highway61'),('highwind'),('hihello'),('hihi'),('hihi12'),('hihi123'),('hihihi'),('hihihi1'),('hihihi12'),('hihihi123'),('hihihi3'),('hihihihi'),('hihihihi1'),('hijack'),('hijodeputa'),('hijoputa'),('hikari'),('hikaru'),('hiking'),('hilario'),('hilary'),('hilary1'),('hilaryduff'),('hilda'),('hilda1'),('hildegard'),('hilfiger'),('hill'),('hillary'),('hillary1'),('hillbilly'),('hillbilly1'),('hillcrest'),('hillcrest1'),('hillside'),('hillside1'),('hillsong'),('hilltop'),('hilltop1'),('hillview'),('hilton'),('hilton1'),('him123'),('him666'),('himalaya'),('himani'),('himanshu'),('himawari'),('himera'),('himitsu'),('himmel'),('himom1'),('himura'),('hinata'),('hinata1'),('hinder'),('hinder1'),('hindustan'),('hindustani'),('hip'),('hip-hop'),('hiphop'),('hiphop!'),('hiphop.'),('hiphop01'),('hiphop1'),('hiphop10'),('hiphop101'),('hiphop11'),('hiphop12'),('hiphop123'),('hiphop13'),('hiphop2'),('hiphop23'),('hiphop3'),('hiphop4'),('hiphop5'),('hiphop7'),('hipolito'),('hipopotamo'),('hippie'),('hippie1'),('hippo'),('hippo1'),('hippo123'),('hippopo'),('hippos'),('hippos1'),('hippy'),('hippy1'),('hireme'),('hiroki'),('hiroko'),('hiromi'),('hirondelle'),('hiroshi'),('hiroshima'),('hiroyuki'),('hirsch'),('hisgrace'),('hisham'),('hismatdan'),('histoire'),('historia'),('history'),('history1'),('history278'),('hit'),('hitachi'),('hitachi1'),('hitchcock'),('hitech'),('hitesh'),('hithere'),('hithere1'),('hitler'),('hitler1'),('hitler123'),('hitler666'),('hitler88'),('hitman'),('hitman1'),('hitman11'),('hitman12'),('hitman123'),('hitman2'),('hitman23'),('hitman47'),('hitokiri'),('hitomi'),('hitsugaya'),('Hiuyt75f'),('hiya'),('hj'),('hj:'),('hjccbz'),('hjcnbckfd'),('hjcnbr'),('hjcnjd'),('hjhjhj'),('hjkl'),('hjlbjy'),('hjlbntkb'),('hjlbyf'),('hjpjxrf'),('hjvfirf'),('hjvfyjd'),('hjvfyjdf'),('hjvfynbrf'),('hjvjxrf'),('hk'),('hlubkoj1'),('hm9958123'),('hmfan1'),('hoang123'),('hoanganh'),('hobart'),('hobbes'),('hobbes1'),('hobbit'),('hobbit1'),('hobie1'),('hobiecat'),('hobo'),('hobo123'),('hoboken'),('hochzeit'),('hockey'),('hockey!'),('hockey.'),('hockey00'),('hockey01'),('hockey07'),('hockey08'),('hockey09'),('hockey1'),('hockey10'),('hockey101'),('hockey11'),('hockey12'),('hockey123'),('hockey13'),('hockey14'),('hockey15'),('hockey16'),('hockey17'),('hockey18'),('hockey19'),('hockey2'),('hockey20'),('hockey21'),('hockey22'),('hockey23'),('hockey24'),('hockey25'),('hockey26'),('hockey27'),('hockey28'),('hockey29'),('hockey3'),('hockey30'),('hockey31'),('hockey33'),('hockey35'),('hockey4'),('hockey44'),('hockey5'),('hockey55'),('hockey6'),('hockey66'),('hockey69'),('hockey7'),('hockey77'),('hockey8'),('hockey87'),('hockey88'),('hockey89'),('hockey9'),('hockey91'),('hockey97'),('hockey99'),('hocuspocus'),('hodges'),('hoe123'),('hoebag1'),('hoffman'),('hoffman1'),('hoffmann'),('hoffnung'),('hogan'),('hogan1'),('hogehoge'),('hogwarts'),('hogwarts1'),('hoho'),('hohoho'),('hohoho1'),('hohohoho'),('hoi123'),('hoihoi'),('hoilamgi'),('hokage'),('hokej'),('hokies'),('hokies1'),('hokuto'),('hol'),('hola'),('hola10'),('hola11'),('hola12'),('hola123'),('hola1234'),('hola12345'),('hola123456'),('hola22'),('holahola'),('holahola1'),('holanda'),('holaquetal'),('holas'),('holdem'),('holden'),('holden01'),('holden05'),('holden1'),('holden123'),('holdenv8'),('holder'),('holdon'),('hole'),('holein1'),('holeinone'),('holger'),('holiday'),('holiday1'),('holiday123'),('holiday2'),('holidays'),('holidays1'),('holidaysecure123'),('holidaysecure123$'),('holiness'),('holla'),('holla!'),('holla1'),('holla12'),('holla123'),('holla2'),('hollaback'),('hollaback1'),('holland'),('holland1'),('holler'),('holler1'),('holley'),('holley1'),('holliday'),('hollie'),('hollie1'),('hollie99'),('hollis'),('hollis1'),('hollister'),('hollister!'),('hollister.'),('hollister0'),('hollister1'),('hollister2'),('hollister3'),('hollister4'),('hollister5'),('hollister6'),('hollister7'),('hollister8'),('hollister9'),('hollow'),('hollow1'),('holloway'),('hollowman'),('holly'),('holly01'),('holly1'),('holly11'),('holly12'),('holly123'),('holly13'),('holly2'),('holly22'),('holly23'),('holly3'),('holly5'),('holly7'),('hollydog'),('hollydog1'),('hollywood'),('hollywood!'),('hollywood0'),('hollywood1'),('hollywood2'),('hollywood3'),('hollywood4'),('hollywood5'),('hollywood6'),('hollywood7'),('hollywood8'),('hollywood9'),('hollyy'),('holmes'),('holmes1'),('holstein'),('holsten'),('holuha00'),('holy'),('holybible'),('holybible1'),('holycow'),('holycow1'),('holycrap'),('holycrap1'),('holycross'),('holyghost'),('holyghost1'),('holyholy'),('holymoly'),('holysh!t'),('holyshit'),('holyshit!'),('holyshit1'),('holyspirit'),('hom'),('hombre'),('home'),('home0401'),('home11'),('home12'),('home123'),('home1234'),('home12345'),('homealone'),('homebase'),('homeboy'),('homeboy1'),('homebrew'),('homedepot'),('homedepot1'),('homegirl'),('homegirl1'),('homegrown'),('homehome'),('homeland'),('homeless'),('homeless1'),('homelesspa'),('homepage'),('homer'),('homer1'),('homer12'),('homer123'),('homer2'),('homerj'),('homero'),('homero1'),('homers'),('homers1'),('homersimpson'),('homerun'),('homerun1'),('homes'),('homes1'),('homeschool'),('homeslice1'),('homestar'),('homestar1'),('homestead'),('homestead1'),('homesweethome'),('hometown'),('hometown1'),('homework'),('homework1'),('homeworld'),('homey1'),('homie'),('homie1'),('homie12'),('homie123'),('homie13'),('homie2'),('homie3'),('homies'),('homies1'),('homies13'),('hommer'),('homo'),('homo12'),('homo123'),('homosexual'),('hon'),('honda'),('honda00'),('honda01'),('honda02'),('honda03'),('honda04'),('honda05'),('honda06'),('honda07'),('honda08'),('honda1'),('honda10'),('honda100'),('honda11'),('honda12'),('honda123'),('honda1234'),('honda125'),('honda13'),('honda150'),('honda2'),('honda2000'),('honda21'),('honda22'),('honda23'),('honda250'),('honda3'),('honda300'),('honda4'),('honda400'),('honda400ex'),('honda450'),('honda450r'),('honda5'),('honda500'),('honda6'),('honda600'),('honda69'),('honda7'),('honda750'),('honda8'),('honda80'),('honda85'),('honda88'),('honda89'),('honda90'),('honda91'),('honda92'),('honda93'),('honda94'),('honda95'),('honda96'),('honda97'),('honda98'),('honda99'),('hondaaccord'),('hondacbr'),('hondacity'),('hondacivic'),('hondacr'),('hondacr125'),('hondacr250'),('hondacrv'),('hondacrx'),('hondas'),('hondas1'),('hondas2000'),('honden'),('honduras'),('honduras1'),('honduras12'),('honest'),('honest1'),('honest3'),('honesty'),('honesty1'),('honey'),('honey!'),('honey01'),('honey05'),('honey06'),('honey07'),('honey08'),('honey09'),('honey1'),('honey10'),('honey101'),('honey11'),('honey12'),('honey123'),('honey1234'),('honey13'),('honey14'),('honey143'),('honey15'),('honey16'),('honey17'),('honey18'),('honey19'),('honey2'),('honey20'),('honey21'),('honey215'),('honey22'),('honey23'),('honey24'),('honey25'),('honey27'),('honey28'),('honey3'),('honey4'),('honey5'),('honey6'),('honey69'),('honey7'),('honey8'),('honey88'),('honey9'),('honeyb'),('honeybabe'),('honeybaby'),('honeybear'),('honeybear1'),('honeybee'),('honeybee1'),('honeybun'),('honeybun1'),('honeybunch'),('honeybunny'),('honeycoh'),('honeycomb'),('honeydew'),('honeydip1'),('honeydog'),('honeygirl'),('honeygirl1'),('honeyhoney'),('honeyko'),('honeykoh'),('honeylove'),('honeymoon'),('honeypie'),('honeypot'),('honeyq'),('honeys'),('honeys1'),('honeywell'),('honeyy'),('honeyz'),('hongkong'),('hongkong1'),('honney'),('honolulu'),('honolulu1'),('honor'),('honor1'),('honour'),('honza'),('honzik'),('hoobastank'),('hooch'),('hooch1'),('hoochie'),('hoochie1'),('hood'),('hood12'),('hood123'),('hoodnigga1'),('hoodrat1'),('hoodrich1'),('hoodstar1'),('hookem'),('hookem1'),('hooker'),('hooker1'),('hooker2'),('hooker69'),('hookup'),('hooligan'),('hooligan1'),('hooligans'),('hooper'),('hooper1'),('hoopla'),('hoops'),('hoops1'),('hoosier'),('hoosier1'),('hoosiers'),('hoosiers1'),('hooter'),('hooter1'),('hooters'),('hooters1'),('hooters2'),('hooters69'),('hootie'),('hootie1'),('hoova52'),('hoover'),('hoover1'),('hoover6'),('hoover74'),('hope'),('hope01'),('hope11'),('hope12'),('hope123'),('hope1234'),('hope13'),('hope22'),('hope23'),('hope4me'),('hopeful'),('hopeful1'),('hopefull'),('hopehope'),('hopeless'),('hopeless1'),('hopewell'),('hophop'),('hoping'),('hopkins'),('hopkins1'),('hoppel'),('hopper'),('hopper1'),('hoppy1'),('hopscotch'),('hor'),('horace'),('horace1'),('horacio'),('horatio'),('horizon'),('horizon1'),('horizons'),('horndog'),('hornet'),('hornet01'),('hornet1'),('hornet600'),('hornets'),('hornets1'),('horney'),('horney1'),('horny'),('horny1'),('horny123'),('horny2'),('horny4u'),('horny69'),('horosho'),('horror'),('horror1'),('horse'),('horse1'),('horse10'),('horse11'),('horse12'),('horse123'),('horse13'),('horse2'),('horse3'),('horse4'),('horse5'),('horse7'),('horselover'),('horseman'),('horsepower'),('horses'),('horses!'),('horses01'),('horses1'),('horses10'),('horses101'),('horses11'),('horses12'),('horses123'),('horses13'),('horses2'),('horses22'),('horses3'),('horses4'),('horses5'),('horses7'),('horseshit'),('horseshoe'),('horseshoe1'),('horsey'),('horsey1'),('horst'),('hortense'),('horton'),('horton1'),('horus'),('hosanna'),('hospice'),('hospital'),('hospital1'),('hossam'),('hostel'),('hostmaster'),('hot'),('hot101'),('hot123'),('hot1234'),('hot2trot'),('hot4you'),('hot97hot'),('hotaru'),('hotass'),('hotass1'),('hotbabe'),('hotbabe1'),('hotbabes'),('hotbaby1'),('hotbitch'),('hotbitch1'),('hotboi1'),('hotbox'),('hotboy'),('hotboy1'),('hotboy12'),('hotboy123'),('hotboy2'),('hotboy23'),('hotboy3'),('hotboy5'),('hotboy7'),('hotboys'),('hotboys1'),('hotboyz1'),('hotcakes'),('hotchick'),('hotchick1'),('hotchick12'),('hotchicks'),('hotchicks1'),('hotdamn'),('hotdog'),('hotdog!'),('hotdog01'),('hotdog1'),('hotdog11'),('hotdog12'),('hotdog123'),('hotdog2'),('hotdog22'),('hotdog23'),('hotdog3'),('hotdog5'),('hotdog6'),('hotdog69'),('hotdog7'),('hotdogs'),('hotdogs1'),('hotel'),('hotel1'),('hotels'),('hotgirl'),('hotgirl1'),('hotgirl12'),('hotgirl123'),('hotgirl2'),('hotgirls'),('hotgirls1'),('hotgurl'),('hotgurl1'),('hotguy'),('hotguy1'),('hothead'),('hothot'),('hothot1'),('hothothot'),('hotie1'),('hotline'),('hotline1'),('hotlips'),('hotlips1'),('hotlove'),('hotmail'),('hotmail.'),('hotmail.co'),('hotmail.com'),('hotmail1'),('hotmail11'),('hotmail12'),('hotmail123'),('hotmail2'),('hotmail3'),('hotmail5'),('hotmail7'),('hotmails'),('hotmale'),('hotmama'),('hotmama1'),('hotmama12'),('hotmama123'),('hotmama2'),('hotmamma'),('hotmamma1'),('hotman'),('hotman1'),('hotmom'),('hotmom1'),('hotmomma'),('hotmomma1'),('hotness'),('hotness1'),('hotone'),('hotone1'),('hotpants'),('hotpants1'),('hotpink'),('hotpink1'),('hotpink2'),('hotpocket1'),('hotpussy'),('hotrod'),('hotrod1'),('hotrod12'),('hotrod123'),('hotrod2'),('hotrod69'),('hotsauce'),('hotsauce1'),('hotsex'),('hotsex1'),('hotsex69'),('hotshit'),('hotshit1'),('hotshot'),('hotshot1'),('hotshots'),('hotspot'),('hotspur'),('hotstuff'),('hotstuff!'),('hotstuff1'),('hotstuff10'),('hotstuff12'),('hotstuff2'),('hotstuff69'),('hott'),('hott123'),('hottest1'),('hotti3'),('hottie'),('hottie!'),('hottie#1'),('hottie.'),('hottie0'),('hottie00'),('hottie01'),('hottie05'),('hottie06'),('hottie07'),('hottie08'),('hottie09'),('hottie1'),('hottie10'),('hottie101'),('hottie11'),('hottie12'),('hottie123'),('hottie1234'),('hottie13'),('hottie14'),('hottie15'),('hottie16'),('hottie17'),('hottie18'),('hottie19'),('hottie2'),('hottie20'),('hottie21'),('hottie22'),('hottie23'),('hottie24'),('hottie25'),('hottie27'),('hottie3'),('hottie33'),('hottie34'),('hottie4'),('hottie44'),('hottie45'),('hottie4u'),('hottie5'),('hottie55'),('hottie6'),('hottie69'),('hottie7'),('hottie8'),('hottie88'),('hottie9'),('hottie911'),('hottie92'),('hottie93'),('hottie94'),('hottie95'),('hottie99'),('hotties'),('hotties1'),('hottness'),('hottness1'),('hottopic'),('hottopic1'),('hottstuff'),('hottstuff1'),('hottub'),('hotty'),('hotty1'),('hotty101'),('hotty12'),('hotty123'),('hotty2'),('hotwater'),('hotwheels'),('hotwheels1'),('hotwings'),('houdini'),('houdini1'),('houghton'),('hounddog'),('hounddog1'),('hounds'),('houria'),('house'),('house1'),('house11'),('house12'),('house123'),('house2'),('house3'),('house4'),('house5'),('housemusic'),('houses'),('houses1'),('housewife'),('housing'),('houston'),('houston1'),('houston12'),('houston123'),('houston13'),('houston2'),('houston23'),('houston281'),('houston3'),('houston5'),('houston7'),('houston713'),('hovno'),('how'),('howard'),('howard1'),('howard12'),('howard123'),('howard2'),('howareyou'),('howareyou1'),('Howareyou123'),('howdy'),('howdy1'),('howdy123'),('howell'),('howhigh'),('howie'),('howie1'),('HPG2N89qif'),('HPH2N89qif'),('hpl'),('hpotter'),('hppavilion'),('hrenota1'),('hrithik'),('hrustem65'),('hrvatska'),('hs'),('hs16Andi3Z'),('hs:'),('hshn7669'),('hshshs'),('hsm123'),('htlbcrf'),('htown1'),('htown713'),('htrkfvf'),('htt//members.cumfiesta.com/'),('http'),('http://www'),('htubcnhfwbz'),('htubyf'),('huahua'),('huang'),('huang123'),('huangfeisuny'),('huangjin1987'),('huanhuan'),('huawei'),('hubba1'),('hubbabubba'),('hubbard'),('hubbard1'),('hubble'),('hubby'),('hubby1'),('hubert'),('hubert1'),('hubertus'),('huckleberry'),('hudson'),('hudson1'),('huevos'),('HuF7dkGd'),('hug'),('huggies'),('huggies1'),('huggybear'),('hughes'),('hughes1'),('hugo'),('hugo12'),('hugo123'),('hugo1234'),('hugo854lataille1988'),('hugoboss'),('hugoboss1'),('hugohugo'),('hugues'),('huguette'),('huguito'),('huhbbhzu78'),('huhu'),('huhuhu'),('huihui'),('hujhuj'),('hulaanmo'),('hulagirl'),('huligan'),('hulk'),('hulk12'),('hulk123'),('hulkhogan'),('hulkhogan1'),('hulkster'),('hulkster1'),('hullcity'),('hullcity1'),('humaira'),('human'),('human1'),('humanity'),('humanoid'),('humans'),('humberto'),('humberto1'),('humble'),('humble1'),('humboldt'),('humbug'),('humility'),('hummel'),('hummer'),('hummer1'),('hummer12'),('hummer123'),('hummer2'),('hummer3'),('hummer69'),('hummerh1'),('hummerh2'),('hummerh3'),('hummingbir'),('hummingbird'),('humphrey'),('humphrey1'),('humtum'),('hun'),('hund'),('hundred'),('hung'),('hung123'),('hungary'),('hunger'),('hungry'),('hungry1'),('hunnie'),('hunnie1'),('hunny'),('hunny1'),('hunnybunny'),('hunt'),('hunt3r'),('hunter'),('hunter!'),('hunter.'),('hunter00'),('hunter01'),('hunter02'),('hunter03'),('hunter04'),('hunter05'),('hunter06'),('hunter07'),('hunter08'),('hunter09'),('hunter1'),('hunter10'),('hunter101'),('hunter11'),('hunter12'),('hunter123'),('hunter1234'),('hunter13'),('hunter14'),('hunter15'),('hunter16'),('hunter17'),('hunter18'),('hunter19'),('hunter2'),('hunter20'),('hunter21'),('hunter22'),('hunter23'),('hunter24'),('hunter25'),('hunter26'),('hunter27'),('hunter28'),('hunter3'),('hunter33'),('hunter4'),('hunter44'),('hunter45'),('hunter5'),('hunter55'),('hunter6'),('hunter66'),('hunter666'),('hunter69'),('hunter7'),('hunter77'),('hunter8'),('hunter88'),('hunter89'),('hunter9'),('hunter94'),('hunter95'),('hunter96'),('hunter97'),('hunter98'),('hunter99'),('hunters'),('hunters1'),('hunterx'),('hunting'),('hunting1'),('hunting101'),('hunting12'),('hunting123'),('hunting2'),('huntington'),('huntress'),('huracan'),('hurensohn'),('hurensohn1'),('hurley'),('hurley1'),('hurricane'),('hurricane1'),('hurricane2'),('hurricanes'),('husain'),('husan0890'),('husband'),('husband1'),('huseyin'),('husker'),('husker1'),('huskers'),('huskers1'),('huskies'),('huskies1'),('husky'),('husky1'),('husqvarna'),('hussain'),('hussain1'),('hussein'),('hustla'),('hustla1'),('hustle'),('hustle1'),('hustler'),('hustler1'),('hustlin1'),('hutch'),('hutch1'),('hutchins'),('hutchinson'),('huxley'),('huy123'),('huyhuy'),('HvqJvxVb76'),('HwrIwxWc76'),('hX28o9e646'),('hyacinth'),('hybrid'),('hybrid1'),('hyderabad'),('hydro'),('hydro1'),('hydro420'),('hydrogen'),('hyper'),('hyper1'),('hyperion'),('hyperlite'),('hyperlite1'),('hyphy1'),('hyphy101'),('hyrule'),('hysteria'),('hyundai'),('hyundai1'),('i'),('i&lt'),('i&lt:3you'),('i.love.you'),('i12345'),('i123456'),('i1234567'),('i123456789'),('i18bzbk3ay8'),('i23456'),('i234i234i234'),('i4gotit'),('i4IfBinFyu'),('i5sTWf1rCX'),('i81u812'),('i84Avh9ltI'),('i97wb6sxq7'),('i98xb7sxr7'),('i<3you'),('iam'),('iam2cool'),('iamalone'),('iamawesome'),('iamblessed'),('iamcool'),('iamcool!'),('iamcool1'),('iamcool123'),('iamcool2'),('iamcrazy'),('iamcute'),('iamfree'),('iamgay'),('iamgay1'),('iamgod'),('iamgod1'),('iamgood'),('iamgreat'),('iamhappy'),('iamhere'),('iamhot'),('iamhot1'),('iaminlove'),('iamking'),('iamlegend'),('iamlegend1'),('iamlucky'),('iamme'),('iamme1'),('iamno1'),('iamnumber1'),('iamrich'),('iamsam'),('iamsexy'),('iamsexy1'),('iamsocool'),('iamsocool1'),('iamthe1'),('iamthebest'),('iamthebest1'),('iamtheking'),('iamtheman'),('iamtheman1'),('iamtheone'),('iamtheone1'),('iamwhatiam'),('ian'),('ian123'),('ianian'),('ianuarie'),('ib6ub9'),('ibadan'),('ibanez'),('ibanez1'),('ibanezjs'),('ibarra'),('ibelieve'),('ibicguwjic'),('ibiza'),('ibiza1'),('ibm'),('ibookg4'),('ibragim'),('ibrahim'),('ibrahim1'),('ibrahim123'),('ibrahima'),('ibrahimovic'),('ibukun'),('icandoit'),('icanfly'),('icare123'),('icarly'),('icarly1'),('icarus'),('ice'),('ice-cream'),('ice123'),('iceage'),('iceage1'),('iceage2'),('icebaby'),('iceberg'),('iceberg1'),('icebox'),('icebox1'),('icecold'),('icecold1'),('icecream'),('icecream!'),('icecream.'),('icecream1'),('icecream10'),('icecream11'),('icecream12'),('icecream123'),('icecream13'),('icecream2'),('icecream22'),('icecream23'),('icecream3'),('icecream4'),('icecream5'),('icecream6'),('icecream7'),('icecream8'),('icecream9'),('icecube'),('icecube1'),('icefire'),('icegirl'),('icehockey'),('icehouse'),('icehouse1'),('iceice'),('iceice1'),('iceicebaby'),('iceland'),('iceland1'),('iceman'),('iceman01'),('iceman1'),('iceman11'),('iceman12'),('iceman123'),('iceman13'),('iceman2'),('iceman21'),('iceman22'),('iceman23'),('iceman3'),('iceman69'),('iceman7'),('icequeen'),('icetea'),('icetea1'),('icewater'),('ich'),('ich123'),('ichbin'),('ichbincool'),('ichbins'),('ichiban'),('ichich'),('ichigo'),('ichigo1'),('ichiro'),('ichiro51'),('ichliebedi'),('ichliebedich'),('ichunddu'),('icp123'),('icp420'),('icp666'),('icross'),('icthus01'),('icu812'),('iCXkyB7972'),('Id6c3wr6uN'),('ida123'),('iddqd'),('iddqdidkfa'),('idefix'),('identity'),('idinahui'),('idiot'),('idiot1'),('idiot123'),('idiota'),('idiots'),('idk123'),('idk1234'),('idlewild'),('idon'),('idon\'tknow'),('idontcare'),('idontcare1'),('idonthave1'),('idontknow'),('idontknow!'),('idontknow.'),('idontknow1'),('idontknow2'),('idontknow3'),('idontno'),('idontno1'),('idriss'),('idspispopd'),('idunno'),('idunno1'),('if'),('if6was9'),('ifeanyi'),('ifeoluwa'),('ifeoma'),('ifiksr'),('iforget'),('iforget1'),('iforgot'),('iforgot!'),('iforgot1'),('iforgot2'),('iforgotit'),('ifuckyou1987'),('ifycjyhekbn'),('iG4abOX4'),('igaev90'),('igetmoney'),('igetmoney1'),('igetmoney2'),('iggy'),('iggypop'),('iglesia'),('iglesias'),('ignacio'),('ignacio1'),('ignatius'),('ignatova_1978_09'),('ignazio'),('ignition'),('ignoranto'),('igor'),('igor123'),('igorek'),('igorek-filatov'),('igorigor'),('igot5onit'),('igromania'),('iguana'),('iguana1'),('ih8you'),('ihate1'),('ihateboys'),('ihateboys1'),('ihateher1'),('ihatehim'),('ihatehim1'),('ihatelife'),('ihatelife1'),('ihatelove'),('ihateme'),('ihatemen'),('ihatemen1'),('ihatemylif'),('ihatemylife'),('ihatemyself'),('ihateschool'),('ihatethis'),('ihatethis1'),('ihatethisgame'),('ihateu'),('ihateu!'),('ihateu1'),('ihateu12'),('ihateu123'),('ihateu2'),('ihatey0u'),('ihateyou'),('ihateyou!'),('ihateyou.'),('ihateyou1'),('ihateyou11'),('ihateyou12'),('ihateyou2'),('ihateyou22'),('ihateyou3'),('ihateyou4'),('ihateyou5'),('ihateyou6'),('ihateyou7'),('ihateyou9'),('ihave2kids'),('ihave3kids'),('ihave4kids'),('iheartu2'),('iheartyou'),('iheartyou1'),('iheartyou2'),('iii'),('iiii'),('iiiii'),('iiiiii'),('iiiiiii'),('iiiiiiii'),('iiiiiiiiii'),('iiyama'),('ijeoma'),('ijfrnhf7yhcy54bhy0cd'),('ijrjkfl'),('ijrjkflrf'),('ika123'),('iKAa4Kr257'),('ikaika'),('ikarus'),('ikbengek'),('ike02banaA'),('ikechukwu'),('ikenna'),('ikickass'),('ikillyou'),('ikke'),('iklo'),('il0v3y0u'),('il0vehim'),('il0veme'),('il0veu'),('il0vey0u'),('il0veyou'),('ilaria'),('ilayda'),('ilcerchio'),('ildiko'),('ilds4edad'),('ileana'),('ilenia'),('ilham'),('ilia16739'),('iliana'),('ilike69'),('ilikecheese'),('ilikeeggs'),('ilikegirls'),('ilikeit'),('ilikepie'),('ilikepie!'),('ilikepie1'),('ilikepie12'),('ilikepie123'),('ilikepie2'),('ilikesex'),('ilikeu'),('ilikeu123'),('ilikeyou'),('ilikeyou1'),('illegal'),('illidan'),('illini'),('illini1'),('illinois'),('illinois1'),('illmatic'),('illmatic1'),('illuminati'),('illusion'),('illusion1'),('illusions'),('ilmiocane'),('ilo'),('iloilo'),('ilona'),('ilonka'),('ilov3u'),('ilov3you'),('ilove'),('ilove!'),('ilove$'),('ilove...'),('ilove1'),('ilove10'),('ilove11'),('ilove12'),('ilove123'),('ilove1234'),('ilove13'),('ilove14'),('ilove143'),('ilove15'),('ilove16'),('ilove17'),('ilove18'),('ilove2'),('ilove21'),('ilove22'),('ilove23'),('ilove24'),('ilove3'),('ilove4'),('ilove420'),('ilove5'),('ilove6'),('ilove69'),('ilove7'),('ilove8'),('ilove9'),('ilove?'),('iloveaaron'),('iloveadam'),('iloveadam1'),('iloveaj'),('ilovealex'),('ilovealex!'),('ilovealex1'),('ilovealex2'),('iloveallah'),('iloveallman'),('iloveamber'),('iloveamy'),('iloveamy1'),('iloveandre'),('iloveandy'),('iloveandy1'),('iloveangel'),('iloveanime'),('iloveanna'),('iloveanna1'),('iloveash1'),('iloveashle'),('iloveausti'),('ilovebeer'),('ilovebeer1'),('iloveben'),('iloveben1'),('ilovebill'),('ilovebilly'),('iloveblue'),('ilovebob'),('ilovebobby'),('iloveboobi'),('iloveboobs'),('iloveboys'),('iloveboys!'),('iloveboys1'),('iloveboys2'),('ilovebrad1'),('ilovebrand'),('ilovebrian'),('ilovebritt'),('ilovebryan'),('ilovecake'),('ilovecandy'),('ilovecats'),('ilovecats1'),('ilovechad'),('ilovechad1'),('ilovecheese'),('ilovechris'),('ilovecock'),('ilovecock1'),('ilovecody'),('ilovecody1'),('iloved1'),('ilovedad'),('ilovedad1'),('ilovedaddy'),('ilovedan'),('ilovedan1'),('ilovedance'),('ilovedanie'),('ilovedanny'),('ilovedave'),('ilovedave1'),('ilovedavid'),('ilovedick'),('ilovedick1'),('ilovedj'),('ilovedogs'),('ilovedogs1'),('ilovedogs2'),('ilovedylan'),('iloveemily'),('iloveemma'),('iloveeric'),('iloveeric1'),('ilovefood'),('ilovefood1'),('ilovegirls'),('ilovegod'),('ilovegod!'),('ilovegod1'),('ilovegod12'),('ilovegod2'),('ilovegod7'),('ilovegreen'),('ilovegreg'),('iloveher'),('iloveher!'),('iloveher1'),('iloveher12'),('iloveher2'),('ilovehim'),('ilovehim!'),('ilovehim.'),('ilovehim08'),('ilovehim09'),('ilovehim1'),('ilovehim10'),('ilovehim11'),('ilovehim12'),('ilovehim13'),('ilovehim14'),('ilovehim2'),('ilovehim22'),('ilovehim23'),('ilovehim3'),('ilovehim4'),('ilovehim5'),('ilovehim7'),('ilovehorses'),('iloveian'),('iloveindia'),('iloveit'),('iloveit1'),('ilovej'),('ilovej1'),('ilovejack'),('ilovejack1'),('ilovejacob'),('ilovejake'),('ilovejake1'),('ilovejames'),('ilovejamie'),('ilovejason'),('ilovejay'),('ilovejay1'),('ilovejb'),('ilovejc'),('ilovejeff'),('ilovejeff1'),('ilovejen'),('ilovejen1'),('ilovejenny'),('ilovejess'),('ilovejess1'),('ilovejesse'),('ilovejessi'),('ilovejesus'),('ilovejim'),('ilovejimmy'),('ilovejoe'),('ilovejoe1'),('ilovejoey'),('ilovejoey1'),('ilovejohn'),('ilovejohn1'),('ilovejon'),('ilovejon1'),('ilovejorda'),('ilovejose'),('ilovejose1'),('ilovejosh'),('ilovejosh!'),('ilovejosh1'),('ilovejosh2'),('ilovejuan1'),('ilovejusti'),('ilovejustin'),('ilovekate'),('ilovekatie'),('ilovekayla'),('ilovekelly'),('ilovekevin'),('ilovekim'),('ilovekim1'),('ilovekiss'),('ilovekyle'),('ilovekyle1'),('ilovelaura'),('ilovelee'),('ilovelife'),('ilovelife1'),('ilovelisa'),('ilovelisa1'),('iloveliz1'),('ilovelove'),('ilovelucy'),('ilovelucy1'),('iloveluis'),('iloveluis1'),('iloveluke'),('iloveluke1'),('ilovem3'),('ilovemama'),('ilovemaria'),('ilovemark'),('ilovemark1'),('ilovemary'),('ilovemary1'),('ilovematt'),('ilovematt!'),('ilovematt1'),('ilovematt2'),('ilovemax'),('ilovemax1'),('iloveme'),('iloveme!'),('iloveme.'),('iloveme01'),('iloveme08'),('iloveme09'),('iloveme1'),('iloveme10'),('iloveme101'),('iloveme11'),('iloveme12'),('iloveme123'),('iloveme13'),('iloveme14'),('iloveme15'),('iloveme16'),('iloveme18'),('iloveme2'),('iloveme21'),('iloveme22'),('iloveme23'),('iloveme3'),('iloveme4'),('iloveme5'),('iloveme6'),('iloveme69'),('iloveme7'),('iloveme8'),('iloveme9'),('ilovemegan'),('ilovemen'),('ilovemen1'),('ilovemicha'),('ilovemike'),('ilovemike!'),('ilovemike1'),('ilovemike2'),('ilovemom'),('ilovemom!'),('ilovemom1'),('ilovemom12'),('ilovemom2'),('ilovemommy'),('ilovemoney'),('ilovemum'),('ilovemusic'),('ilovemybab'),('ilovemybaby'),('ilovemyboo'),('ilovemyboy'),('ilovemycat'),('ilovemydad'),('ilovemydog'),('ilovemyfam'),('ilovemyfamily'),('ilovemyindia'),('ilovemykid'),('ilovemykids'),('ilovemylif'),('ilovemylife'),('ilovemymom'),('ilovemymother'),('ilovemymum'),('ilovemysel'),('ilovemyself'),('ilovemysis'),('ilovemyson'),('ilovemyspa'),('ilovemywif'),('ilovemywife'),('ilovenick'),('ilovenick!'),('ilovenick1'),('ilovenick2'),('ilovenikki'),('iloveno1'),('iloveny'),('iloveny1'),('ilovepat'),('ilovepaul'),('ilovepaul1'),('ilovepie'),('ilovepie1'),('ilovepink'),('ilovepink1'),('ilovepizza'),('iloveporn'),('ilovepussy'),('ilovericky'),('iloverob'),('iloverob1'),('iloverock'),('iloveryan'),('iloveryan!'),('iloveryan1'),('ilovesam'),('ilovesam!'),('ilovesam1'),('ilovesara'),('ilovesara1'),('ilovesarah'),('ilovescott'),('ilovesean'),('ilovesean1'),('ilovesex'),('ilovesex1'),('ilovesex2'),('ilovesex69'),('iloveshane'),('iloveshawn'),('iloveshoes'),('ilovesocce'),('ilovesoccer'),('ilovesome1'),('ilovesos'),('ilovesos1'),('ilovesteph'),('ilovesteve'),('ilovetaylo'),('ilovethisgame'),('ilovetim'),('ilovetim1'),('ilovetom'),('ilovetom1'),('ilovetony'),('ilovetony1'),('ilovetyler'),('iloveu'),('iloveu!'),('iloveu.'),('iloveu0'),('iloveu01'),('iloveu07'),('iloveu08'),('iloveu09'),('iloveu1'),('iloveu10'),('iloveu101'),('iloveu11'),('iloveu12'),('iloveu123'),('iloveu1234'),('iloveu13'),('iloveu14'),('iloveu143'),('iloveu15'),('iloveu16'),('iloveu17'),('iloveu18'),('iloveu2'),('iloveu21'),('iloveu22'),('iloveu23'),('iloveu24'),('iloveu3'),('iloveu4'),('iloveu4eva'),('iloveu4eve'),('iloveu5'),('iloveu6'),('iloveu69'),('iloveu7'),('iloveu8'),('iloveu88'),('iloveu9'),('iloveubaby'),('iloveumummy'),('iloveweed'),('iloveweed1'),('ilovewill'),('ilovewill1'),('ilovey'),('ilovey0u'),('iloveyew'),('iloveyou'),('iloveyou!'),('iloveyou!!'),('iloveyou*'),('iloveyou.'),('iloveyou..'),('iloveyou0'),('iloveyou00'),('iloveyou01'),('iloveyou02'),('iloveyou03'),('iloveyou04'),('iloveyou05'),('iloveyou06'),('iloveyou07'),('iloveyou08'),('iloveyou09'),('iloveyou1'),('iloveyou10'),('iloveyou11'),('iloveyou12'),('iloveyou123'),('iloveyou1234'),('iloveyou13'),('iloveyou14'),('iloveyou143'),('iloveyou15'),('iloveyou16'),('iloveyou17'),('iloveyou18'),('iloveyou19'),('iloveyou2'),('iloveyou20'),('iloveyou21'),('iloveyou22'),('iloveyou23'),('iloveyou24'),('iloveyou25'),('iloveyou26'),('iloveyou27'),('iloveyou28'),('iloveyou29'),('iloveyou3'),('iloveyou30'),('iloveyou31'),('iloveyou32'),('iloveyou33'),('iloveyou34'),('iloveyou4'),('iloveyou42'),('iloveyou44'),('iloveyou45'),('iloveyou4e'),('iloveyou4ever'),('iloveyou5'),('iloveyou55'),('iloveyou56'),('iloveyou6'),('iloveyou66'),('iloveyou69'),('iloveyou7'),('iloveyou77'),('iloveyou78'),('iloveyou8'),('iloveyou87'),('iloveyou88'),('iloveyou89'),('iloveyou9'),('iloveyou90'),('iloveyou91'),('iloveyou92'),('iloveyou93'),('iloveyou94'),('iloveyou95'),('iloveyou96'),('iloveyou97'),('iloveyou98'),('iloveyou99'),('iloveyou<3'),('iloveyoual'),('iloveyouba'),('iloveyoubaby'),('iloveyouda'),('iloveyouf'),('iloveyoufo'),('iloveyouja'),('iloveyoujo'),('iloveyouma'),('iloveyoumo'),('iloveyouso'),('iloveyousomuch'),('iloveyouto'),('iloveyoutoo'),('iloveyouu'),('iloveyouu1'),('iloveyoux3'),('iloveyu'),('ilovezac1'),('ilovezach'),('ilovezach1'),('ilovezack1'),('ilu123'),('ilusha'),('ilusion'),('iluv'),('iluv69'),('iluvchris1'),('iluvgod'),('iluvgod1'),('iluvher1'),('iluvhim'),('iluvhim!'),('iluvhim1'),('iluvhim2'),('iluvjesus'),('iluvjesus1'),('iluvme'),('iluvme!'),('iluvme1'),('iluvme123'),('iluvme2'),('iluvmlml'),('iluvmom1'),('iluvmymom1'),('iluvmyself'),('iluvsum1'),('iluvu'),('iluvu!'),('iluvu1'),('iluvu12'),('iluvu123'),('iluvu13'),('iluvu2'),('iluvu22'),('iluvu3'),('iluvu4eva'),('iluvu4ever'),('iluvyou'),('iluvyou!'),('iluvyou1'),('iluvyou2'),('ily101'),('ily123'),('ily1234'),('ily143'),('ily4ever'),('ilya'),('ilya_al_80'),('im'),('im2cool'),('im2cute'),('im2sexy'),('imabeast'),('imabeast1'),('imabitch'),('imabitch1'),('imafag1'),('image'),('image1'),('images'),('imagination'),('imagine'),('imagine1'),('imahoe1'),('imalone'),('imaloser'),('imaloser1'),('imani'),('imani1'),('imanuel'),('imapimp'),('imapimp1'),('imaslut1'),('imation'),('imation1'),('imawesome'),('imawesome1'),('imback'),('imback1'),('imbecil'),('imbored'),('imbored1'),('imcool'),('imcool!'),('imcool1'),('imcool12'),('imcool123'),('imcool2'),('imcute'),('imcute1'),('imelda'),('imesh'),('imfake1'),('imfree'),('imgay'),('imgay1'),('imgay12'),('imgay123'),('imgay2'),('imgay69'),('imhappy'),('imhere'),('imhot1'),('imhotep'),('iminlove'),('iminlove1'),('iminlove2'),('imissu'),('imissu1'),('imissu2'),('imissyou'),('imissyou!'),('imissyou1'),('imissyou2'),('imkool1'),('immaculate'),('immanuel'),('immortal'),('immortal1'),('imnumber1'),('imogen'),('imogen1'),('imortal'),('impact'),('impact1'),('impala'),('impala1'),('impala64'),('impalass'),('imperator'),('imperia'),('imperial'),('imperial1'),('imperio'),('imperium'),('import'),('import1'),('important'),('important1'),('imposible'),('impossible'),('impression'),('impretty'),('impreza'),('impreza1'),('impulse'),('impulse1'),('impulse101'),('imran'),('imran1'),('imran123'),('imrankhan'),('imsexy'),('imsexy1'),('imsexy2'),('imsingle'),('imsocool'),('imsocool1'),('imsofly1'),('imsohood1'),('imsohot1'),('imsorry'),('imsosexy'),('imthe1'),('imthebest'),('imthebest1'),('imtheman'),('imtheman1'),('imtheone'),('imtheshit1'),('imyaimyaimya'),('imyours'),('in'),('in2806rbk'),('in2deep'),('ina123'),('inactive1996Aug'),('inar_ka'),('incase322'),('inception'),('inchallah'),('include'),('incognito'),('incognito1'),('income'),('incoming'),('incomplete'),('incorrect'),('incorrect1'),('increase'),('incredible'),('incubus'),('incubus1'),('ind'),('inday'),('indeed'),('independen'),('independence'),('independent'),('independiente'),('index'),('index0088'),('india'),('india1'),('india12'),('india123'),('india1234'),('india1947'),('india321'),('india@123'),('indian'),('indian1'),('indian12'),('indian123'),('indiana'),('indiana1'),('indianajones'),('Indianalib'),('indianer'),('indians'),('indians1'),('indica'),('indie1'),('indien'),('indiglo'),('indigo'),('indigo1'),('indira'),('indochine'),('indonesia'),('indonesia1'),('indore'),('indra'),('industrial'),('industry'),('indy'),('indy500'),('Indya123'),('indya123D'),('ineedajob'),('ineedlove'),('ineedmoney'),('ineedu'),('ineedyou'),('ines'),('inessa'),('infamous'),('infamous1'),('infante'),('infantry'),('infantry1'),('infected'),('infernal'),('inferno'),('inferno1'),('inferno666'),('infierno'),('infinite'),('infinite1'),('infiniti'),('infiniti1'),('infinito'),('infinity'),('infinity1'),('infinity8'),('infirmiere'),('inflames'),('inflames1'),('info'),('info123'),('infoinfo'),('inform'),('informatica'),('informatika'),('informatio'),('information'),('informatique'),('infosys'),('infotech'),('ingeborg'),('ingegnere'),('ingenieria'),('ingeniero'),('ingenieur'),('ingeras'),('inglaterra'),('ingles'),('inglewood'),('ingo10477'),('ingoditrust'),('ingodwetrust'),('ingram'),('ingres'),('ingrid'),('ingrid1'),('inibif47'),('inicio'),('iniesta'),('initiald'),('initialD09'),('INJECT'),('inkognito'),('inl0ve'),('inline'),('inlinked'),('inlove'),('inlove!'),('inlove07'),('inlove08'),('inlove09'),('inlove1'),('inlove12'),('inlove123'),('inlove13'),('inlove2'),('inlove3'),('inlove4'),('inlovewith'),('inmaculada'),('inmortal'),('inna'),('innabuk'),('innainna'),('innamorata'),('innocence'),('innocent'),('innocent1'),('innocuous'),('innov8510'),('innova'),('innovation'),('innovision'),('innuendo'),('insane'),('insane1'),('insane2'),('insanity'),('insanity1'),('insect'),('insecure'),('insert'),('insert1'),('inshallah'),('inside'),('inside1'),('insider'),('insight'),('insight1'),('insignia'),('insomnia'),('insomnia1'),('insomniac'),('inspector'),('inspector1'),('inspiration'),('inspire'),('inspire1'),('inspired'),('inspiron'),('inspiron1'),('install'),('instant'),('instant1'),('instinct'),('institute'),('instructor'),('instrument'),('insurance'),('insurance1'),('int'),('intan'),('integer'),('integra'),('integra1'),('integral'),('integrity'),('integrity1'),('intel'),('intel1'),('intel123'),('inteligente'),('intelinside'),('intelligent'),('intense'),('intense1'),('inter'),('inter1'),('inter10'),('inter123'),('inter1908'),('interdit'),('interest'),('interesting'),('interests'),('interface'),('interior'),('interiors'),('interista'),('intermilan'),('intern'),('internacional'),('internal'),('internatio'),('international'),('internazionale'),('internet'),('internet!'),('internet.'),('internet01'),('internet1'),('internet11'),('internet12'),('internet123'),('internet2'),('internet3'),('internet5'),('internet7'),('interpol'),('interpol1'),('intheend'),('intimate'),('intouch'),('intranet'),('intrepid'),('intrepid1'),('intrigue'),('intruder'),('intruder1'),('intuition'),('inuyasha'),('inuyasha!'),('inuyasha.'),('inuyasha1'),('inuyasha10'),('inuyasha11'),('inuyasha12'),('inuyasha123'),('inuyasha13'),('inuyasha15'),('inuyasha2'),('inuyasha3'),('inuyasha5'),('inuyasha6'),('inuyasha7'),('invader'),('invader1'),('invaderzim'),('invalid'),('invasion'),('invent'),('inventor'),('inverness'),('invest'),('investment'),('investor'),('invictus'),('invincible'),('invisible'),('invisible1'),('invu4uraqt'),('inzaghi'),('ioana'),('ioanna'),('ioioio'),('iolanda'),('iomega'),('ionel23'),('ionela'),('ionut'),('ionutz'),('iop123'),('iop890'),('iopiop'),('iopjkl12'),('iPad'),('ipanema'),('iphone'),('iphone1'),('iphone123'),('iphone3g'),('iphone3gs'),('iphone4'),('iphone4s'),('ipod'),('ipod11'),('ipod12'),('ipod123'),('ipod13'),('ipodnano'),('ipodnano1'),('ipodtouch'),('ipodtouch1'),('ipswich'),('ipswich1'),('ira'),('ira.klopot'),('ira123'),('ira202909'),('iraira'),('irakli'),('ireland'),('ireland1'),('ireland2'),('ireland3'),('ireland7'),('irene'),('irene1'),('irene123'),('irenka'),('irfan'),('irfan123'),('irina'),('irina1'),('irina123'),('irina280374'),('irinabrig'),('irinka'),('iris'),('iris123'),('irish'),('irish1'),('irish12'),('irish123'),('irish13'),('irish2'),('irish3'),('irish7'),('irisha'),('irishka'),('irishman'),('iriska'),('irland'),('irlanda'),('iro4ka'),('irochka'),('irochka-ova'),('irock'),('irock!'),('irock1'),('irock101'),('irock11'),('irock12'),('irock123'),('irock13'),('irock2'),('irocz28'),('iron'),('iron666'),('ironfist'),('ironhead'),('ironhorse'),('ironmaiden'),('ironman'),('ironman1'),('ironman12'),('ironman123'),('ironman2'),('ironman3'),('irule'),('irule1'),('irule123'),('irvine'),('irving'),('irving1'),('isa'),('isa123'),('isaac'),('isaac1'),('isaac12'),('isaac123'),('isaac2'),('isabel'),('isabel01'),('isabel1'),('isabel11'),('isabel12'),('isabel123'),('isabel13'),('isabel2'),('isabel972'),('isabela'),('isabela1'),('isabelita'),('isabell'),('isabell1'),('isabella'),('isabella01'),('isabella07'),('isabella08'),('isabella09'),('isabella1'),('isabella10'),('isabella11'),('isabella12'),('isabella13'),('isabella2'),('isabella3'),('isabella4'),('isabella5'),('isabella7'),('isabelle'),('isabelle1'),('isadora'),('isaiah'),('isaiah01'),('isaiah05'),('isaiah06'),('isaiah07'),('isaiah08'),('isaiah1'),('isaiah11'),('isaiah12'),('isaiah123'),('isaiah2'),('isaiah3'),('isaiah4'),('isaiah5'),('isaiah7'),('isaias'),('isatelt'),('isaulov.a'),('iscool'),('iseedeadpeople'),('iseeyou'),('iseeyou2'),('ishaan'),('ishika'),('ishita'),('ishmael'),('ishola'),('ishtar'),('isiah1'),('isidora'),('isidore'),('isidoro'),('isidro'),('isis'),('iskandar'),('iskander'),('islam'),('islam1'),('islam123'),('islamabad'),('islamic'),('island'),('island1'),('islander'),('islander1'),('islanders'),('islandgirl'),('islcollective'),('ismael'),('ismael1'),('ismail'),('ismail1'),('ismail123'),('iso9001'),('isobel'),('isolde'),('isotta'),('israel'),('israel1'),('israel12'),('israel123'),('isreal'),('issac1'),('issues'),('istanbul'),('istanbul1'),('istanbul34'),('istina'),('istvan'),('isuck1'),('isuckdick1'),('it'),('itachi'),('itachi1'),('itachi123'),('italia'),('italia06'),('italia1'),('italia10'),('italia2006'),('italia90'),('italian'),('italian1'),('italiana'),('italiano'),('italiano1'),('italie'),('italien'),('italy'),('italy1'),('italy123'),('itdxtyrj'),('ithaca'),('itisme'),('itiswell'),('its'),('its420'),('itsallgood'),('itsasecret'),('itsme'),('itsme1'),('itsme123'),('itsme2'),('itsmine'),('itsmylife'),('itsover'),('itsover1'),('ittybitty'),('ittybitty1'),('itunes'),('itunes1'),('iubire'),('iubireamea'),('iubita'),('iulian'),('iuliana'),('iurkeawov'),('iuytrewq'),('ivan'),('ivan10'),('ivan11'),('ivan12'),('ivan123'),('ivan1234'),('ivan13'),('ivan1980'),('ivan1989'),('ivan1990'),('ivan1991'),('ivan1992'),('ivan1993'),('ivan1994'),('ivan1995'),('ivan1996'),('ivan2010'),('ivana'),('ivana1'),('ivancito'),('ivanhoe'),('ivanivan'),('ivanka'),('ivankaterinchenko'),('ivanko'),('ivanna'),('ivanov'),('ivanov2305'),('ivanova'),('ivanovamotya'),('ivanovich'),('iverson'),('iverson03'),('iverson1'),('iverson23'),('iverson3'),('ivette'),('ivette1'),('ivonne'),('ivonne1'),('ivor631996'),('ivory'),('ivory1'),('ivy123'),('iw14Fi9j'),('iw14Fi9jwQa'),('iw14Fi9jxL'),('iwantsex'),('iwantu'),('iwantyou'),('iwantyou1'),('iwashere'),('iwillwin'),('iwonka'),('IxrHx2Xc87'),('izabel'),('izabela'),('izabella'),('izabella1'),('izmir35'),('izumrud'),('izzit'),('izzy'),('izzy12'),('izzy123'),('i_love_you'),('j'),('j00000'),('j000000'),('j0hnny'),('j0nathan'),('j0rdan'),('j0seph'),('j0shua'),('j11111'),('j111111'),('j121212'),('j123098'),('j123123'),('j12345'),('j123456'),('j1234567'),('j12345678'),('j123456789'),('j1j2j3'),('J1V1fp2BXm'),('j38ifUbn'),('j3nn1f3r'),('j3nnif3r'),('j3nnifer'),('j3qq4h7h2v'),('j3r3my'),('j3ss1ca'),('j3ssica'),('j4n4jel4'),('j54321'),('j55555'),('j5644574'),('j654321'),('j666666'),('j696969'),('j7777777'),('j8675309'),('j:'),('ja'),('ja1234'),('ja123456'),('ja8xb7txr8'),('ja8yc7txs8'),('ja8yc8uxsx'),('jab123'),('jabalpur'),('jabari'),('jabari1'),('jabba1'),('jabbar'),('jabber'),('jabberwocky'),('jablay'),('jablko'),('jabroni'),('jabroni1'),('jabulani'),('jac'),('jac123'),('jacaranda'),('jacare'),('jacek'),('jacek1'),('jacinta'),('jacinta1'),('jacinto'),('jack'),('jack00'),('jack007'),('jack01'),('jack02'),('jack03'),('jack04'),('jack05'),('jack06'),('jack07'),('jack08'),('jack09'),('jack1'),('jack10'),('jack101'),('jack11'),('jack111'),('jack12'),('jack123'),('jack1234'),('jack12345'),('jack13'),('jack14'),('jack15'),('jack16'),('jack17'),('jack2000'),('jack2005'),('jack2006'),('jack2007'),('jack2008'),('jack2009'),('jack2010'),('jack21'),('jack22'),('jack23'),('jack24'),('jack25'),('jack33'),('jack5225'),('jack55'),('jack666'),('jack69'),('jack77'),('jack88'),('jack99'),('jackal'),('jackal1'),('jackandjill'),('jackaroo'),('jackass'),('jackass!'),('jackass.'),('jackass01'),('jackass1'),('jackass101'),('jackass11'),('jackass12'),('jackass123'),('jackass13'),('jackass2'),('jackass22'),('jackass23'),('jackass3'),('jackass4'),('jackass5'),('jackass69'),('jackass7'),('jackass9'),('jackbauer'),('jackblack'),('jackblack1'),('jackdaniel'),('jackdaniels'),('jackdog'),('jackdog1'),('jackel'),('jacket'),('jacket025'),('jackets'),('jackets1'),('jackfrost'),('jackhammer'),('jackie'),('jackie!'),('jackie01'),('jackie08'),('jackie09'),('jackie1'),('jackie10'),('jackie11'),('jackie12'),('jackie123'),('jackie13'),('jackie14'),('jackie15'),('jackie16'),('jackie17'),('jackie18'),('jackie2'),('jackie21'),('jackie22'),('jackie23'),('jackie3'),('jackie4'),('jackie5'),('jackie6'),('jackie69'),('jackie7'),('jackiechan'),('jackjack'),('jackjack1'),('jackjill'),('jacklyn'),('jackman'),('jackman1'),('jackmore1'),('jacko'),('jacko1'),('jackoff'),('jackoff1'),('jackpot'),('jackpot1'),('jackrabbit'),('jackryan'),('jacks'),('jacks0n'),('jacks1'),('jackson'),('jackson!'),('jackson.'),('jackson01'),('jackson05'),('jackson06'),('jackson07'),('jackson08'),('jackson09'),('jackson1'),('jackson10'),('jackson11'),('jackson12'),('jackson123'),('jackson13'),('jackson14'),('jackson2'),('jackson21'),('jackson22'),('jackson23'),('jackson24'),('jackson3'),('jackson4'),('jackson5'),('jackson6'),('jackson7'),('jackson8'),('jackson9'),('jacksonville'),('jacksparrow'),('jackster'),('jacky'),('jacky1'),('jacky123'),('jaclyn'),('jaclyn1'),('jacob'),('jacob!'),('jacob01'),('jacob02'),('jacob03'),('jacob04'),('jacob05'),('jacob06'),('jacob07'),('jacob08'),('jacob09'),('jacob1'),('jacob10'),('jacob101'),('jacob11'),('jacob12'),('jacob123'),('jacob1234'),('jacob13'),('jacob14'),('jacob15'),('jacob16'),('jacob17'),('jacob18'),('jacob2'),('jacob21'),('jacob22'),('jacob23'),('jacob3'),('jacob4'),('jacob5'),('jacob6'),('jacob7'),('jacob8'),('jacob9'),('jacob99'),('jacoba'),('jacobblack'),('jacobo'),('jacobs'),('jacobs1'),('jacoby'),('jacoby1'),('jacopo'),('jacque'),('jacque1'),('jacqueline'),('jacques'),('jacques1'),('jacqui'),('jacqui1'),('jacquie'),('jada'),('jada12'),('jada123'),('jadakiss'),('jadakiss1'),('jadawera'),('jade'),('jade01'),('jade07'),('jade08'),('jade10'),('jade11'),('jade12'),('jade123'),('jade1234'),('jade13'),('jade22'),('jade23'),('jadebibou'),('jaded1'),('jadejade'),('jaden'),('jaden1'),('jaden123'),('jaden2'),('jadensmith'),('jadore'),('jadzia'),('jaeger'),('jaejoong'),('jaelyn'),('jaffa1'),('jafjkshf7y6w34rjd'),('jag'),('jag123'),('jagannath'),('jagdish'),('jager1'),('jagger'),('jagger1'),('jagoda'),('jagr68'),('jaguar'),('jaguar1'),('jaguar12'),('jaguar123'),('jaguares'),('jaguars'),('jaguars1'),('jahbless'),('jahjah'),('jahjah1'),('jahlove'),('jahoda'),('jai'),('jai123'),('jaiden'),('jaiden1'),('jaiganesh'),('jaigurudev'),('jaihanuman'),('jaihind'),('jaijai'),('jailbird'),('jailbird1'),('jaimaa'),('jaimatadi'),('jaimatadi1'),('jaimataki'),('jaime'),('jaime1'),('jaime123'),('jaimee'),('jaimie'),('jaimie1'),('jaimito'),('jaipur'),('jairam'),('jairus'),('jaisairam'),('jaishiv'),('jaishreeram'),('jaishriram'),('jaisriram'),('jaja'),('jaja12'),('jaja123'),('jajaja'),('jajaja1'),('jajajaja'),('jak'),('jak123'),('jakarta'),('jakarta1'),('jakarta10'),('jake'),('jake00'),('jake01'),('jake02'),('jake05'),('jake06'),('jake07'),('jake08'),('jake09'),('jake1'),('jake10'),('jake101'),('jake11'),('jake12'),('jake123'),('jake1234'),('jake13'),('jake14'),('jake15'),('jake16'),('jake17'),('jake18'),('jake2000'),('jake2006'),('jake2008'),('jake21'),('jake22'),('jake23'),('jake24'),('jake5253'),('jake69'),('jake77'),('jake88'),('jake99'),('jakedog'),('jakedog1'),('jakejake'),('jakejake1'),('jakeman'),('jakers'),('jakers1'),('jakester'),('jakester1'),('jakey'),('jakey1'),('jakeyboy'),('jakjak'),('jakob'),('jakob1'),('jakub'),('jakub1'),('jakubko'),('jalapeno'),('jalaram'),('jaleel'),('jalen'),('jalen1'),('jalisco'),('jalisco1'),('jalisco13'),('jam'),('jam123'),('jamaal'),('jamaal1'),('jamaica'),('jamaica1'),('jamaica12'),('jamaica123'),('jamaica2'),('jamaica7'),('jamaican'),('jamaican1'),('jamaika'),('jamais'),('jamajka'),('jamal'),('jamal1'),('jamal12'),('jamal123'),('jamal2'),('jamar1'),('jamari'),('jamari1'),('jambo'),('jambon'),('jamboree'),('jameel'),('jamel1'),('james'),('james!'),('james.'),('james00'),('james007'),('james01'),('james02'),('james03'),('james04'),('james05'),('james06'),('james07'),('james08'),('james09'),('james1'),('james10'),('james101'),('james11'),('james111'),('james12'),('james123'),('james1234'),('james12345'),('james13'),('james14'),('james143'),('james15'),('james16'),('james17'),('james18'),('james19'),('james2'),('james20'),('james2007'),('james2008'),('james2009'),('james2010'),('james21'),('james22'),('james23'),('james24'),('james25'),('james26'),('james27'),('james28'),('james29'),('james3'),('james30'),('james31'),('james32'),('james33'),('james34'),('james4'),('james420'),('james44'),('james45'),('james5'),('james55'),('james6'),('james666'),('james69'),('james7'),('james77'),('james8'),('james87'),('james88'),('james89'),('james9'),('james92'),('james93'),('james94'),('james99'),('jamesa'),('jamesb'),('jamesbond'),('jamesbond0'),('jamesbond007'),('jamesbond1'),('jamesbond7'),('jamesbrown'),('jamesc'),('jamesd'),('jamesdean'),('jamesdean1'),('jamesh'),('jamesjames'),('jamesk'),('jamesl'),('jameslee'),('jamesm'),('jameson'),('jameson1'),('jamesp'),('jamesr'),('jamess'),('jamess1'),('jamest'),('jamestown'),('jamesw'),('jamesy'),('jamezerazz'),('jamie'),('jamie!'),('jamie01'),('jamie07'),('jamie08'),('jamie1'),('jamie10'),('jamie11'),('jamie12'),('jamie123'),('jamie13'),('jamie14'),('jamie15'),('jamie2'),('jamie21'),('jamie22'),('jamie23'),('jamie3'),('jamie4'),('jamie5'),('jamie6'),('jamie69'),('jamie7'),('jamielee'),('jamielynn'),('jamies'),('jamieson'),('jamil'),('jamila'),('jamila1'),('jamilah'),('jamiroquai'),('jamison'),('jamison1'),('jamjam'),('jamjam1'),('jammer'),('jammer1'),('jammers'),('jammie'),('jammin'),('jammin1'),('jamming'),('jamrock1'),('jamshedpur'),('jamuna'),('jan'),('jan123'),('jana'),('jana123'),('janae1'),('janaina'),('janajana'),('janaki'),('janani'),('janay1'),('jancok'),('jandi'),('jandikkz'),('jandre007'),('jane'),('jane12'),('jane123'),('jane1234'),('jane22'),('janedoe'),('janeiro'),('janejane'),('janek'),('janek1'),('janela'),('janell'),('janelle'),('janelle1'),('janeman'),('janessa'),('janessa1'),('janet'),('janet1'),('janet12'),('janet123'),('janeth'),('janeth1'),('janette'),('janette1'),('janeway'),('jangan'),('janganlupa'),('janica'),('janice'),('janice1'),('janice123'),('janicka'),('janie'),('janie1'),('janika'),('janina'),('janina1'),('janine'),('janine1'),('janis'),('janita'),('janiya1'),('janiyah1'),('janjan'),('janjan1'),('janjanjan'),('janka'),('janna'),('jannaarhipova'),('jannah'),('jannat'),('jannet'),('jannie'),('jannik'),('jannis'),('janosch'),('jansen'),('jansport'),('jansport1'),('janssen'),('januar'),('januari'),('january'),('january01'),('january08'),('january09'),('january1'),('january10'),('january11'),('january12'),('january13'),('january14'),('january15'),('january16'),('january17'),('january18'),('january19'),('january2'),('january20'),('january21'),('january22'),('january23'),('january24'),('january25'),('january26'),('january27'),('january28'),('january29'),('january3'),('january30'),('january31'),('january4'),('january5'),('january6'),('january7'),('january8'),('january9'),('janusz'),('janvier'),('japan'),('japan1'),('japan123'),('japan4'),('japanese'),('japanese1'),('japanese92'),('japierdole'),('japorms'),('jaquan'),('jaquan1'),('jaqueline'),('jaqueline1'),('jar'),('jaramillo'),('jarda'),('jardin'),('jared'),('jared1'),('jared12'),('jared123'),('jared2'),('jaredleto'),('jaredleto1'),('jarek'),('jarek1'),('jarell'),('jarell1'),('jarhead'),('jarhead1'),('jarjar'),('jarjar1'),('jaroslav'),('jarox1301!'),('jarred'),('jarred1'),('jarrett'),('jarrett1'),('jarrett88'),('jarrod'),('jarrod1'),('jarule'),('jarule1'),('jarvis'),('jarvis1'),('jas'),('jas123'),('jasm1ne'),('jasmin'),('jasmin-ris'),('jasmin01'),('jasmin1'),('jasmin11'),('jasmin12'),('jasmin123'),('jasmin13'),('jasmin2'),('jasmin3'),('jasmina'),('jasmina1'),('jasmine'),('jasmine!'),('jasmine.'),('jasmine01'),('jasmine02'),('jasmine03'),('jasmine04'),('jasmine05'),('jasmine06'),('jasmine07'),('jasmine08'),('jasmine09'),('jasmine1'),('jasmine10'),('jasmine101'),('jasmine11'),('jasmine12'),('jasmine123'),('jasmine13'),('jasmine14'),('jasmine15'),('jasmine16'),('jasmine17'),('jasmine18'),('jasmine19'),('jasmine2'),('jasmine20'),('jasmine21'),('jasmine22'),('jasmine23'),('jasmine24'),('jasmine29'),('jasmine3'),('jasmine4'),('jasmine5'),('jasmine6'),('jasmine69'),('jasmine7'),('jasmine8'),('jasmine9'),('jasmine99'),('jasmyn'),('jason'),('jason!'),('jason01'),('jason05'),('jason06'),('jason07'),('jason08'),('jason09'),('jason1'),('jason10'),('jason101'),('jason11'),('jason12'),('jason123'),('jason1234'),('jason13'),('jason14'),('jason143'),('jason15'),('jason16'),('jason17'),('jason18'),('jason19'),('jason2'),('jason20'),('jason21'),('jason22'),('jason23'),('jason24'),('jason25'),('jason26'),('jason27'),('jason28'),('jason3'),('jason30'),('jason33'),('jason4'),('jason420'),('jason5'),('jason6'),('jason69'),('jason7'),('jason77'),('jason8'),('jason88'),('jason9'),('jason99'),('jasonb'),('jasond'),('jasonjason'),('jasonlee'),('jasonm'),('jasons'),('jasons1'),('jasonx'),('jasper'),('jasper!'),('jasper01'),('jasper08'),('jasper09'),('jasper1'),('jasper10'),('jasper11'),('jasper12'),('jasper123'),('jasper13'),('jasper2'),('jasper21'),('jasper22'),('jasper23'),('jasper3'),('jasper5'),('jasper7'),('jasper99'),('jaspreet'),('JaspyB1990'),('java'),('java123'),('javajava'),('javelin'),('javi'),('javi123'),('javier'),('javier01'),('javier1'),('javier10'),('javier11'),('javier12'),('javier123'),('javier13'),('javier15'),('javier2'),('javier23'),('javier3'),('javier7'),('javiera'),('javito'),('javon1'),('jaw138whet330'),('jawa350'),('jawbreaker'),('jax123'),('jaxon1'),('jaxson'),('jaxson1'),('jay'),('jay-jay'),('jay101'),('jay123'),('jay1234'),('jay12345'),('jaya'),('jayann'),('jayant'),('jayanthi'),('jayar'),('jayashree'),('jayasree'),('jaybee'),('jaybird'),('jaybird1'),('jayboy'),('jaycee'),('jaycee1'),('jaychou'),('jayda1'),('jayde1'),('jaydee'),('jaydee1'),('jayden'),('jayden01'),('jayden02'),('jayden03'),('jayden04'),('jayden05'),('jayden06'),('jayden07'),('jayden08'),('jayden09'),('jayden1'),('jayden10'),('jayden11'),('jayden12'),('jayden123'),('jayden13'),('jayden2'),('jayden21'),('jayden22'),('jayden23'),('jayden3'),('jayden4'),('jayden5'),('jayden7'),('jaydog'),('jaydon'),('jaydon1'),('jayesh'),('jayhawk'),('jayhawk1'),('jayhawks'),('jayhawks1'),('jayjay'),('jayjay01'),('jayjay1'),('jayjay10'),('jayjay11'),('jayjay12'),('jayjay123'),('jayjay13'),('jayjay14'),('jayjay2'),('jayjay22'),('jayjay23'),('jayjay3'),('jayjay5'),('jayjay6'),('jayjay7'),('jaykay'),('jayla1'),('jaylee'),('jaylen'),('jaylen1'),('jaylin'),('jaylin1'),('jaylon'),('jaylon1'),('jaylyn'),('jaylynn1'),('jayman'),('jayman1'),('jaymar'),('jaymark'),('jaymataji'),('jayme1'),('jaymie'),('jayne'),('jayne1'),('jaypee'),('jayshree'),('jayson'),('jayson1'),('jayvee'),('jaz123'),('jazmin'),('jazmin1'),('jazmin12'),('jazmin123'),('jazmine'),('jazmine1'),('jazmine2'),('jazmyn'),('jazmyn1'),('jazz'),('jazz01'),('jazz11'),('jazz12'),('jazz123'),('jazz1234'),('jazz13'),('jazzbass'),('jazzer'),('jazzie'),('jazzie1'),('jazzjazz'),('jazzman'),('jazzman1'),('jazzmin'),('jazzmin1'),('jazzmine'),('jazzmine1'),('jazzy'),('jazzy01'),('jazzy08'),('jazzy09'),('jazzy1'),('jazzy10'),('jazzy101'),('jazzy11'),('jazzy12'),('jazzy123'),('jazzy13'),('jazzy14'),('jazzy15'),('jazzy2'),('jazzy3'),('jazzy5'),('jazzy7'),('jb1234'),('jb12345'),('jb123456'),('jbaby1'),('jbgR3v7n3B'),('jbond007'),('jc1234'),('jc12345'),('jc123456'),('jcdenis1'),('Jcfs32014'),('jchrist'),('jd1234'),('jd123456'),('jdd04257'),('jDnazp972X'),('jdq4j8Lu3A'),('je'),('jea'),('JEAdmin'),('jealous'),('jealous1'),('jean'),('jean12'),('jean123'),('jean1234'),('jeancarlos'),('jeanclaude'),('jeanette'),('jeanette1'),('jeanie'),('jeanie1'),('jeanine'),('jeanine1'),('jeanjean'),('jeanlouis'),('jeanluc'),('jeanmarc'),('jeanmarie'),('jeanna'),('jeanne'),('jeanne1'),('jeannette'),('jeannette1'),('jeannie'),('jeannie1'),('jeannine'),('jeannot'),('jeanny'),('jeanpaul'),('jeanpierre'),('jeans'),('jebise'),('jeck23'),('jeddah'),('jedi'),('jedidiah'),('jediknight'),('jedimaster'),('jeep'),('jeep123'),('jeep4x4'),('jeep95'),('jeep99'),('jeepcj7'),('jeeper'),('jeepers'),('jeepers1'),('jeepjeep'),('jeepster'),('jeetkunedo'),('jeevan'),('jeeves'),('jeezy1'),('jeferson'),('jeff'),('jeff01'),('jeff11'),('jeff12'),('jeff123'),('jeff1234'),('jeff13'),('jeff21'),('jeff22'),('jeff23'),('jeff24'),('jeff69'),('jefferson'),('jefferson1'),('jefferson2'),('jeffery'),('jeffery1'),('jeffgordon'),('jeffhardy'),('jeffhardy1'),('jeffhardy2'),('jeffjeff'),('jeffrey'),('jeffrey1'),('jeffrey12'),('jeffrey123'),('jeffrey2'),('jeffrey3'),('jeffrey7'),('jeffry'),('jehova'),('jehova1'),('jehovah'),('jehovah1'),('jehovah7'),('jejeje'),('jeka-ka85'),('jekan860803'),('jekjek'),('jelena'),('jelena1'),('jello'),('jello1'),('jello123'),('jelly'),('jelly1'),('jelly12'),('jelly123'),('jelly2'),('jellybaby'),('jellybean'),('jellybean!'),('jellybean1'),('jellybean2'),('jellybean3'),('jellybean7'),('jellybeans'),('jellybelly'),('jellyfish'),('jellyfish1'),('jellytots'),('jelszo'),('jembut'),('jemima'),('jemjem'),('jemma1'),('jemoeder'),('jemoeder1'),('jen'),('jen123'),('jenalyn'),('jenelle'),('jenelyn'),('jenica'),('jenifer'),('jenifer1'),('jeniffer'),('jenjen'),('jenjen1'),('jenkins'),('jenkins1'),('jenn'),('jenn12'),('jenn123'),('jenn1fer'),('jenn5366'),('jenna'),('jenna1'),('jenna12'),('jenna123'),('jenna2'),('jenna3'),('jenner'),('jenni'),('jenni1'),('jenni123'),('jennie'),('jennie1'),('jennifer'),('jennifer!'),('jennifer.'),('jennifer01'),('jennifer07'),('jennifer08'),('jennifer09'),('jennifer1'),('jennifer10'),('jennifer11'),('jennifer12'),('jennifer123'),('jennifer13'),('jennifer14'),('jennifer15'),('jennifer16'),('jennifer17'),('jennifer18'),('jennifer19'),('jennifer2'),('jennifer20'),('jennifer21'),('jennifer22'),('jennifer23'),('jennifer24'),('jennifer25'),('jennifer3'),('jennifer4'),('jennifer5'),('jennifer6'),('jennifer69'),('jennifer7'),('jennifer8'),('jennifer88'),('jennifer9'),('jennings'),('jennings1'),('jennjenn'),('jenny'),('jenny01'),('jenny07'),('jenny08'),('jenny09'),('jenny1'),('jenny10'),('jenny101'),('jenny11'),('jenny12'),('jenny123'),('jenny1234'),('jenny13'),('jenny14'),('jenny15'),('jenny16'),('jenny17'),('jenny18'),('jenny2'),('jenny20'),('jenny21'),('jenny22'),('jenny23'),('jenny24'),('jenny3'),('jenny4'),('jenny5'),('jenny6'),('jenny69'),('jenny7'),('jenny8'),('jennyfer'),('jennylyn'),('jennys'),('jennyt'),('jenova'),('jensen'),('jensen1'),('jenson'),('jenya'),('jeopardy'),('jepoy'),('jer'),('jer2911'),('jerald'),('jerbear'),('jeremi'),('jeremiah'),('jeremiah1'),('jeremiah12'),('jeremiah2'),('jeremiah29'),('jeremiah2911'),('jeremiah3'),('jeremiah7'),('jeremias'),('jeremie'),('jeremy'),('jeremy!'),('jeremy01'),('jeremy06'),('jeremy07'),('jeremy08'),('jeremy09'),('jeremy1'),('jeremy10'),('jeremy11'),('jeremy12'),('jeremy123'),('jeremy13'),('jeremy14'),('jeremy15'),('jeremy16'),('jeremy17'),('jeremy18'),('jeremy2'),('jeremy21'),('jeremy22'),('jeremy23'),('jeremy24'),('jeremy3'),('jeremy4'),('jeremy5'),('jeremy6'),('jeremy69'),('jeremy7'),('jeremy8'),('jeric'),('jerica'),('jericho'),('jericho1'),('jerick'),('jerico'),('jerjer'),('jerk'),('jerk123'),('jerk77'),('jerkface'),('jerkface1'),('jerkin'),('jerkoff'),('jerkoff1'),('jermaine'),('jermaine1'),('jeroen'),('jerome'),('jerome1'),('jerome12'),('jerome123'),('jerome2'),('jeronimo'),('jerrey232x'),('jerrod'),('jerry'),('jerry01'),('jerry1'),('jerry11'),('jerry12'),('jerry123'),('jerry13'),('jerry2'),('jerry3'),('jerry5'),('jerryg'),('jerrylee'),('jerrys'),('jersey'),('jersey1'),('jersey12'),('jersey2'),('jerseygirl'),('jerson'),('jerusalem'),('jerusalem1'),('jerwin'),('jes'),('jes123'),('jesaispas'),('jeshua'),('jesica'),('jesica1'),('jesika'),('jesper'),('jess'),('jess01'),('jess08'),('jess10'),('jess11'),('jess12'),('jess123'),('jess1234'),('jess13'),('jess14'),('jess15'),('jess16'),('jess18'),('jess1ca'),('jess21'),('jess22'),('jess23'),('jess5377'),('jess69'),('jessa'),('jesse'),('jesse!'),('jesse.'),('jesse01'),('jesse1'),('jesse10'),('jesse101'),('jesse11'),('jesse12'),('jesse123'),('jesse1234'),('jesse13'),('jesse14'),('jesse15'),('jesse16'),('jesse18'),('jesse2'),('jesse21'),('jesse22'),('jesse23'),('jesse3'),('jesse4'),('jesse5'),('jesse69'),('jesse7'),('jessee'),('jessejames'),('jessem'),('jessem1'),('jessi'),('jessi1'),('jessi123'),('jessica'),('jessica!'),('jessica.'),('jessica0'),('jessica00'),('jessica01'),('jessica02'),('jessica03'),('jessica04'),('jessica05'),('jessica06'),('jessica07'),('jessica08'),('jessica09'),('jessica1'),('jessica10'),('jessica101'),('jessica11'),('jessica12'),('jessica123'),('jessica13'),('jessica14'),('jessica15'),('jessica16'),('jessica17'),('jessica18'),('jessica19'),('jessica2'),('jessica20'),('jessica21'),('jessica22'),('jessica23'),('jessica24'),('jessica25'),('jessica26'),('jessica27'),('jessica28'),('jessica3'),('jessica33'),('jessica4'),('jessica5'),('jessica6'),('jessica69'),('jessica7'),('jessica77'),('jessica8'),('jessica87'),('jessica88'),('jessica89'),('jessica9'),('jessica90'),('jessica91'),('jessica92'),('jessica93'),('jessica94'),('jessica95'),('jessica99'),('jessie'),('jessie!'),('jessie.'),('jessie01'),('jessie07'),('jessie08'),('jessie09'),('jessie1'),('jessie10'),('jessie11'),('jessie12'),('jessie123'),('jessie13'),('jessie14'),('jessie15'),('jessie16'),('jessie2'),('jessie21'),('jessie22'),('jessie23'),('jessie3'),('jessie4'),('jessie5'),('jessie69'),('jessie7'),('jessika'),('jessika1'),('jessjess'),('jessy'),('jessy1'),('jessy123'),('jester'),('jester1'),('jesucristo'),('jesuis'),('jesuisla'),('jesus'),('jesus!'),('jesus#1'),('jesus.'),('jesus00'),('jesus001'),('jesus007'),('jesus01'),('jesus03'),('jesus05'),('jesus06'),('jesus07'),('jesus08'),('jesus09'),('jesus1'),('jesus10'),('jesus100'),('jesus101'),('jesus11'),('jesus111'),('jesus12'),('jesus123'),('jesus1234'),('jesus12345'),('jesus13'),('jesus14'),('jesus143'),('jesus15'),('jesus16'),('jesus17'),('jesus18'),('jesus19'),('jesus1st'),('jesus2'),('jesus20'),('jesus2000'),('jesus2006'),('jesus2007'),('jesus2008'),('jesus2009'),('jesus2010'),('jesus2011'),('jesus21'),('jesus22'),('jesus23'),('jesus24'),('jesus247'),('jesus25'),('jesus27'),('jesus3'),('jesus316'),('jesus33'),('jesus333'),('jesus4'),('jesus4ever'),('jesus4life'),('jesus4me'),('jesus4u'),('jesus5'),('jesus6'),('jesus666'),('jesus69'),('jesus7'),('jesus77'),('jesus777'),('jesus8'),('jesus88'),('jesus89'),('jesus9'),('jesus99'),('jesusa'),('jesusc'),('jesusc1'),('jesuschris'),('jesuschrist'),('jesuschrist1'),('jesuscrist'),('jesuscristo'),('jesusfreak'),('jesusgod'),('jesusis'),('jesusis#1'),('jesusis1'),('jesusislor'),('jesusislord'),('jesusislove'),('jesusito'),('jesusjesus'),('jesuslives'),('jesuslord'),('jesuslove'),('jesuslove1'),('jesusloveme'),('jesusloves'),('jesuslovesme'),('jesusmary'),('jesusmeama'),('jesusrocks'),('jesusrules'),('jesuss'),('jesuss1'),('jesussaves'),('jesusteama'),('jesusteamo'),('jet'),('jet\'aime'),('jet123'),('jetaime'),('jetaime1'),('jetbalance'),('jeter'),('jeter02'),('jeter1'),('jeter2'),('jethro'),('jethro1'),('jetjet'),('jetlee'),('jets'),('jetset'),('jetski'),('jetski1'),('jetsmets'),('jetson'),('jetta'),('jetta1'),('jettavr6'),('jew123'),('jewel'),('jewel1'),('jewel123'),('jewell'),('jewell1'),('jewelry'),('jewelry1'),('jewels'),('jewels1'),('jewish'),('jewish1'),('jezebel'),('jezebel1'),('jFgvCqBuzUG'),('jg1234'),('jG3h4HFn'),('jgordon24'),('jgthfnjh'),('jh'),('jh1234'),('jh5thrwgefsdfs'),('jhajha'),('jhane'),('jhenny'),('jhgfdsa'),('jhjhjh'),('jhkjdf'),('jhon'),('jhonatan'),('jhoncena'),('jhonjhon'),('jhonny'),('jhonny1'),('ji394su3'),('jiajia'),('jianfei000'),('Jiang520'),('jiang8kevin'),('jianjian'),('jibopogie'),('jiefang007'),('jiefang998'),('jiejie'),('jigga'),('jigga1'),('jiggaman'),('jiggaman1'),('jigger'),('jigglypuff'),('jiggy1'),('jigsaw'),('jigsaw1'),('jihoo'),('jiji'),('jijiji'),('jilipollas'),('jill'),('jill123'),('jillian'),('jillian1'),('jillybean'),('jim'),('jim123'),('jimbeam'),('jimbeam1'),('jimbo'),('jimbo1'),('jimbo123'),('jimbob'),('jimbob1'),('jimboy'),('jimboy123'),('jimelen'),('jimena'),('jimenez'),('jimenez1'),('jimi'),('jimihendrix'),('jimjam'),('jimjim'),('jimjim1'),('jimjones'),('jimjones1'),('jimmie'),('jimmie1'),('jimmie48'),('jimmorrison'),('jimmy'),('jimmy!'),('jimmy01'),('jimmy1'),('jimmy10'),('jimmy11'),('jimmy12'),('jimmy123'),('jimmy1234'),('jimmy13'),('jimmy14'),('jimmy2'),('jimmy21'),('jimmy22'),('jimmy23'),('jimmy3'),('jimmy4'),('jimmy5'),('jimmy6'),('jimmy69'),('jimmy7'),('jimmy8'),('jimmy9'),('jimmyb'),('jimmyboy'),('jimmyd'),('jimmyjimmy'),('jimmypage'),('jimmys'),('jin123'),('jingjing'),('jingle'),('jingle1'),('jingles'),('jingles1'),('jinjin'),('jinkazama'),('jinky'),('jinx'),('jirafa'),('jirka'),('jitendra'),('jitterbug'),('jitterbug1'),('jiujitsu'),('jiujitsu1'),('jiushiaini'),('jj'),('jj1234'),('jj12345'),('jj123456'),('jjcG16dj5K'),('jjj'),('jjj111'),('jjj123'),('jjjj'),('jjjjj'),('jjjjj1'),('jjjjj5'),('jjjjjj'),('jjjjjj1'),('jjjjjj6'),('jjjjjjj'),('jjjjjjjj'),('jjjjjjjjj'),('jjjjjjjjjj'),('jk'),('jk1234'),('jk123456'),('jkiuztdftL57'),('jkjk'),('jkjkjk'),('jkjkjk1'),('jkl'),('jkl123'),('jkl456'),('jkl789'),('jkljkl'),('jkmuf'),('jkmxbr'),('jktctymrf'),('jktu'),('jktxrf'),('jktymrf'),('jkz'),('jkz123'),('jkzjkz'),('jl1234'),('jlbyjxrf'),('jlbyjxtcndj'),('jledfyxbr'),('jm0753'),('jm1234'),('jm123456'),('jman123'),('jmc123'),('JMFxL78nhe'),('JMFxL78phe'),('jmjmjm'),('jmoney'),('jmoney1'),('jndfkb'),('jnkwear1'),('jo'),('jo1234'),('joachim'),('joakim'),('joan'),('joan123'),('joana'),('joana1'),('joanie'),('joaninha'),('joann'),('joann1'),('joanna'),('joanna1'),('joanna12'),('joanna123'),('joanna2'),('joanne'),('joanne1'),('joanne123'),('joao'),('joao123'),('joaopaulo'),('joaopedro'),('joaovitor'),('joaquim'),('joaquin'),('joaquin1'),('job'),('job123'),('job314'),('job4me'),('jobelle'),('jobert'),('jobhunt'),('jobjob'),('jobless'),('jobros1'),('jobs'),('jobs123'),('jobs4me'),('jobsearch'),('jobsearch1'),('jobseeker'),('jobshop2002'),('jocelyn'),('jocelyn1'),('jocelyne'),('jochen'),('jocker'),('jockey'),('jodeci'),('jodete'),('jodie'),('jodie1'),('jodie123'),('jody'),('joe'),('joe101'),('joe123'),('joe1234'),('joe12345'),('joeblack'),('joeblow'),('joebob'),('joebob1'),('joeboxer'),('joeboy'),('joecool'),('joecool1'),('joedirt'),('joedirt1'),('joejoe'),('joejoe1'),('joejoe12'),('joejoe123'),('joejoe2'),('joejoejoe'),('joejonas'),('joejonas!'),('joejonas1'),('joejonas12'),('joejonas2'),('joel'),('joel11'),('joel12'),('joel123'),('joel1234'),('joel13'),('joel23'),('joelito'),('joelle'),('joelle1'),('joelmadden'),('joemalyn15'),('joemama'),('joemama1'),('joemar'),('joepie'),('joesph'),('joesph1'),('joey'),('joey01'),('joey07'),('joey10'),('joey101'),('joey11'),('joey12'),('joey123'),('joey1234'),('joey13'),('joey14'),('joey15'),('joey16'),('joey21'),('joey22'),('joey23'),('joey666'),('joey69'),('joeyboy'),('joeyjoey'),('jogabonito'),('joh'),('johan'),('johan1'),('johan123'),('johana'),('johana1'),('johann'),('johanna'),('johanna1'),('johanne'),('johannes'),('johannes1'),('john'),('john!20130605at1753'),('john01'),('john0316'),('john05'),('john06'),('john07'),('john08'),('john09'),('john1'),('john10'),('john101'),('john1010'),('john11'),('john117'),('john12'),('john123'),('john1234'),('john12345'),('john123456'),('john13'),('john14'),('john15'),('john16'),('john17'),('john18'),('john19'),('john20'),('john21'),('john22'),('john23'),('john24'),('john25'),('john2567'),('john26'),('john27'),('john3'),('john316'),('john33'),('john3:16'),('john44'),('john55'),('john5646'),('john69'),('John7502gee'),('john77'),('john88'),('john99'),('johnathan'),('johnathan1'),('johnathon'),('johnathon1'),('johnboy'),('johnboy1'),('johncarlo'),('johncena'),('johncena!'),('johncena01'),('johncena1'),('johncena10'),('johncena11'),('johncena12'),('johncena13'),('johncena2'),('johncena23'),('johncena3'),('johncena5'),('johncena54'),('johncena7'),('johncena8'),('johncena9'),('johndavid'),('johndeer'),('johndeer1'),('johndeere'),('johndeere1'),('johndeere2'),('johndoe'),('johndoe1'),('johngalt'),('johnjohn'),('johnjohn1'),('johnlennon'),('johnlock'),('johnmark'),('johnmayer'),('johnnie'),('johnnie1'),('johnny'),('johnny!'),('johnny.'),('johnny01'),('johnny07'),('johnny08'),('johnny1'),('johnny10'),('johnny11'),('johnny12'),('johnny123'),('johnny13'),('johnny14'),('johnny15'),('johnny16'),('johnny18'),('johnny1959'),('johnny2'),('johnny21'),('johnny22'),('johnny23'),('johnny3'),('johnny4'),('johnny5'),('johnny55'),('johnny6'),('johnny69'),('johnny7'),('johnny77'),('johnny8'),('johnny9'),('johnny99'),('johnnyb'),('johnnyboy'),('johnnyboy1'),('johnnycash'),('johnnydepp'),('johnpaul'),('johnpaul1'),('johnrey'),('johnsmith'),('johnson'),('johnson1'),('johnson11'),('johnson12'),('johnson123'),('johnson2'),('johnson3'),('johnson4'),('johnson48'),('johnson5'),('johnson7'),('johnston'),('johnston1'),('johnwayne'),('johnwayne1'),('johny'),('johny1'),('joiner'),('joinme'),('joint'),('joints'),('jojo'),('jojo01'),('jojo07'),('jojo08'),('jojo09'),('jojo10'),('jojo101'),('jojo11'),('jojo12'),('jojo123'),('jojo1234'),('jojo13'),('jojo14'),('jojo15'),('jojo16'),('jojo18'),('jojo21'),('jojo22'),('jojo23'),('jojo24'),('jojo69'),('jojo99'),('jojoba'),('jojojo'),('jojojo1'),('jojojojo'),('joke'),('joke123'),('joker'),('joker007'),('joker01'),('joker1'),('joker10'),('joker101'),('joker11'),('joker12'),('joker123'),('joker1234'),('joker13'),('joker14'),('joker15'),('joker17'),('joker18'),('joker2'),('joker21'),('joker22'),('joker23'),('joker3'),('joker4'),('joker420'),('joker45'),('joker5'),('joker6'),('joker666'),('joker69'),('joker7'),('joker777'),('joker8'),('joker88'),('joker9'),('joker99'),('jokerjoker'),('jokerman'),('jokers'),('jokers1'),('joking'),('joking1'),('jolanda'),('jolanta'),('jolene'),('jolene1'),('jolie'),('jolie1'),('jolina'),('jolinek33'),('jollibee'),('jolly'),('jolly1'),('jolly123'),('jollyroger'),('jologs'),('jomacapa'),('jomama'),('jomama1'),('jomar'),('jomari'),('jomarie'),('jomblo'),('jon'),('jon101'),('jon123'),('jonah'),('jonah1'),('jonalyn'),('jonas'),('jonas!'),('jonas1'),('jonas10'),('jonas101'),('jonas11'),('jonas12'),('jonas123'),('jonas13'),('jonas14'),('jonas15'),('jonas2'),('jonas3'),('jonas7'),('jonasbros1'),('jonasbroth'),('jonasbrothers'),('jonatan'),('jonathan'),('jonathan!'),('jonathan.'),('jonathan01'),('jonathan07'),('jonathan08'),('jonathan09'),('jonathan1'),('jonathan10'),('jonathan11'),('jonathan12'),('jonathan123'),('jonathan13'),('jonathan14'),('jonathan15'),('jonathan16'),('jonathan17'),('jonathan18'),('jonathan19'),('jonathan2'),('jonathan20'),('jonathan21'),('jonathan22'),('jonathan23'),('jonathan3'),('jonathan4'),('jonathan5'),('jonathan6'),('jonathan69'),('jonathan7'),('jonathan8'),('jonathan9'),('jonathon'),('jonathon1'),('jonbonjovi'),('jonboy'),('jones'),('jones1'),('jones12'),('jones123'),('jones2'),('jonesy'),('jongjong'),('jonjon'),('jonjon1'),('jonnie'),('jonny'),('jonny1'),('jonny12'),('jonny123'),('jonny5'),('jonnyboy'),('jonson'),('joojoo'),('Joonah'),('jopajopa'),('joplin'),('jor'),('jor23dan'),('jordan'),('jordan!'),('jordan.'),('jordan0'),('jordan00'),('jordan01'),('jordan02'),('jordan03'),('jordan04'),('jordan05'),('jordan06'),('jordan07'),('jordan08'),('jordan09'),('jordan1'),('jordan10'),('jordan101'),('jordan11'),('jordan12'),('jordan123'),('jordan1234'),('jordan13'),('jordan14'),('jordan15'),('jordan16'),('jordan17'),('jordan18'),('jordan19'),('jordan2'),('jordan20'),('jordan21'),('jordan22'),('jordan23'),('jordan2323'),('Jordan2345'),('jordan24'),('jordan25'),('jordan26'),('jordan27'),('jordan28'),('jordan29'),('jordan3'),('jordan32'),('jordan33'),('jordan34'),('jordan4'),('jordan44'),('jordan45'),('jordan5'),('jordan55'),('jordan6'),('jordan69'),('jordan7'),('jordan77'),('jordan8'),('jordan88'),('jordan89'),('jordan9'),('jordan90'),('jordan91'),('jordan92'),('jordan93'),('jordan94'),('jordan95'),('jordan96'),('jordan97'),('jordan98'),('jordan99'),('jordana'),('jordans'),('jordans1'),('jordans23'),('jorden'),('jorden1'),('jorden23'),('jordi'),('jordie'),('jordin'),('jordon'),('jordon1'),('jordon23'),('jordy'),('jordy1'),('jordyn'),('jordyn1'),('jorge'),('jorge1'),('jorge10'),('jorge12'),('jorge123'),('jorge13'),('jorge2'),('jorge23'),('jorgeluis'),('jorgito'),('jorgito1'),('jos'),('jos123'),('joschi'),('jose'),('jose01'),('jose07'),('jose09'),('jose10'),('jose11'),('jose12'),('jose123'),('jose1234'),('jose12345'),('jose123456'),('jose13'),('jose14'),('jose15'),('jose16'),('jose17'),('jose18'),('jose19'),('Jose1995'),('jose20'),('jose21'),('jose22'),('jose23'),('jose24'),('jose25'),('jose27'),('jose69'),('joseangel'),('joseantonio'),('josecarlos'),('josef'),('josefa'),('josefina'),('josefina1'),('josefine'),('josejose'),('joselin'),('joselito'),('joselito1'),('joselo'),('joseluis'),('joseluis1'),('joselyn'),('joselyn1'),('josema'),('josemanuel'),('josemaria'),('josemiguel'),('joseph'),('joseph!'),('joseph.'),('joseph00'),('joseph01'),('joseph02'),('joseph03'),('joseph04'),('joseph05'),('joseph06'),('joseph07'),('joseph08'),('joseph09'),('joseph1'),('joseph10'),('joseph11'),('joseph12'),('joseph123'),('joseph1234'),('joseph13'),('joseph14'),('joseph15'),('joseph16'),('joseph17'),('joseph18'),('joseph19'),('joseph2'),('joseph20'),('joseph21'),('joseph22'),('joseph23'),('joseph24'),('joseph25'),('joseph3'),('joseph4'),('joseph5'),('joseph6'),('joseph69'),('joseph7'),('joseph77'),('joseph8'),('joseph88'),('joseph89'),('joseph9'),('joseph99'),('josephine'),('josephine1'),('josesito'),('josette'),('josette1'),('josh'),('josh01'),('josh06'),('josh07'),('josh08'),('josh09'),('josh1'),('josh10'),('josh101'),('josh11'),('josh12'),('josh123'),('josh1234'),('josh13'),('josh14'),('josh15'),('josh16'),('josh17'),('josh18'),('josh19'),('josh20'),('josh21'),('josh22'),('josh23'),('josh24'),('josh69'),('josh88'),('joshie'),('joshie1'),('joshjosh'),('joshua'),('joshua!'),('joshua.'),('joshua00'),('joshua01'),('joshua02'),('joshua03'),('joshua04'),('joshua05'),('joshua06'),('joshua07'),('joshua08'),('joshua09'),('joshua1'),('joshua10'),('joshua11'),('joshua12'),('joshua123'),('joshua1234'),('joshua13'),('joshua14'),('joshua15'),('joshua16'),('joshua17'),('joshua18'),('joshua19'),('joshua2'),('joshua20'),('joshua21'),('joshua22'),('joshua23'),('joshua24'),('joshua25'),('joshua26'),('joshua27'),('joshua28'),('joshua3'),('joshua4'),('joshua5'),('joshua6'),('joshua69'),('joshua7'),('joshua77'),('joshua8'),('joshua88'),('joshua89'),('joshua9'),('joshua95'),('joshua96'),('joshua97'),('joshua98'),('joshua99'),('joshy'),('joshy1'),('josiah'),('josiah1'),('josiane'),('josie'),('josie1'),('josie123'),('josue'),('josue1'),('josue123'),('joujou'),('jourdan'),('journal'),('journalist'),('journey'),('journey1'),('jovan'),('jovan1'),('jovana'),('jovelyn'),('joven'),('jovita'),('joy'),('joy123'),('joyce'),('joyce1'),('joyce123'),('joycee'),('joyful'),('joyful1'),('joyjoy'),('joyjoy1'),('joyous'),('joyride'),('joystick'),('jp1234'),('jp123456'),('jp72l05w'),('jr1234'),('jr12345'),('jr123456'),('jr1234567'),('jrcfyf'),('jrcfyjxrf'),('jrock1'),('js1234'),('js123456'),('jsbach'),('jsmith'),('jt1234'),('ju2002'),('juan'),('juan01'),('juan10'),('juan11'),('juan12'),('juan123'),('juan1234'),('juan13'),('juan14'),('juan15'),('juan16'),('juan17'),('juan18'),('juan21'),('juan22'),('juan23'),('juan316'),('juana'),('juana1'),('juanca'),('juancamilo'),('juancarlos'),('juancho'),('juancito'),('juandavid'),('juandiego'),('juanes'),('juanita'),('juanita1'),('juanito'),('juanito1'),('juanjo'),('juanjose'),('juanjuan'),('juanluis'),('juanma'),('juanmanuel'),('juanmiguel'),('juanpablo'),('juanpablo1'),('juarez'),('juarez1'),('jubilee'),('jubilee1'),('jubjub'),('judas'),('judaspriest'),('jude'),('judge'),('judge1'),('judgement'),('judith'),('judith1'),('judoka'),('judson'),('judy'),('judy123'),('judyann'),('juegos'),('juehtw'),('juelz1'),('juergen'),('juggal0'),('juggalette'),('juggalo'),('juggalo1'),('juggalo123'),('juggalo13'),('juggalo17'),('juggalo2'),('juggalo420'),('juggalo6'),('juggalo666'),('juggalo69'),('juggernaut'),('juggle'),('jughead'),('jughead1'),('juice'),('juice1'),('juice123'),('juice2'),('juicebox'),('juicebox1'),('juicey'),('juicey1'),('juicy'),('juicy1'),('juicy12'),('juicy123'),('juicy2'),('juicy69'),('juicyfruit'),('juillet'),('jujitsu'),('juju'),('juju12'),('juju123'),('juju1987'),('jujuba'),('jujube'),('jujubean'),('jujubee'),('jujubee1'),('jujuju'),('jujuju1'),('jujujuju'),('jujuvivi'),('jukebox'),('jukebox1'),('jul'),('julchen'),('jules'),('jules1'),('juli'),('juli123'),('julia'),('julia.olga'),('julia01'),('julia1'),('julia10'),('julia11'),('julia12'),('julia123'),('julia13'),('julia2'),('julia3'),('julia5'),('julia7'),('juliadronina1996'),('juliajulia'),('julian'),('julian01'),('julian05'),('julian06'),('julian07'),('julian08'),('julian09'),('julian1'),('julian10'),('julian11'),('julian12'),('julian123'),('julian13'),('julian14'),('julian15'),('Julian1705'),('julian2'),('julian22'),('julian23'),('julian3'),('julian5'),('julian7'),('juliana'),('juliana1'),('juliana123'),('juliane'),('julianna'),('julianna1'),('julianne'),('julianne1'),('juliano'),('julias'),('julia_eduardovna'),('julie'),('julie01'),('julie1'),('julie12'),('julie123'),('julie13'),('julie2'),('julie2811'),('julieann'),('julieanne'),('julien'),('julien1'),('julienne'),('julies'),('juliet'),('juliet1'),('juliet123'),('julieta'),('julieta1'),('julietta'),('juliette'),('juliette1'),('julija'),('julija2010x'),('julinha'),('julio'),('julio1'),('julio10'),('julio11'),('julio12'),('julio123'),('julio13'),('julio2'),('juliocesar'),('julissa'),('julissa1'),('julita'),('julito'),('julius'),('julius1'),('julius123'),('juliya'),('july'),('july01'),('july02'),('july03'),('july04'),('july05'),('july06'),('july07'),('july0788'),('july08'),('july09'),('july10'),('july11'),('july12'),('july123'),('july13'),('july14'),('july15'),('july16'),('july17'),('july18'),('july19'),('july1980'),('july1982'),('july1983'),('july1984'),('july1985'),('july1986'),('july1987'),('july1988'),('july1989'),('july1990'),('july1991'),('july1992'),('july1993'),('july1994'),('july1995'),('july1996'),('july1997'),('july20'),('july2004'),('july2005'),('july2006'),('july2007'),('july2008'),('july2009'),('july21'),('july22'),('july23'),('july24'),('july25'),('july26'),('july27'),('july28'),('july2801!'),('july29'),('july30'),('july31'),('july4th'),('jumanji'),('jumanji1'),('jumbo'),('jumbo1'),('jumeaux'),('jumoke'),('jumong'),('jump'),('jump123'),('jump23'),('jump4joy'),('jumper'),('jumper1'),('jumpin'),('jumping'),('jumping1'),('jumpjet'),('jumpjump'),('jumpman'),('jumpman1'),('jumpman23'),('jumpoff1'),('jumpstart'),('jumpstyle'),('jun'),('jun123'),('junaid'),('junction'),('Jundian2011xr'),('june'),('june01'),('june02'),('june03'),('june04'),('june05'),('june06'),('june07'),('june08'),('june09'),('june10'),('june11'),('june12'),('june123'),('june13'),('june14'),('june15'),('june16'),('june17'),('june18'),('june19'),('june1979'),('june1980'),('june1981'),('june1982'),('june1983'),('june1984'),('june1985'),('june1986'),('june1987'),('june1988'),('june1989'),('june1990'),('june1991'),('june1992'),('june1993'),('june1994'),('june1995'),('june1996'),('june1997'),('june1998'),('june1999'),('june20'),('june2000'),('june2002'),('june2003'),('june2004'),('june2005'),('june2006'),('june2007'),('june2008'),('june2009'),('june2010'),('june21'),('june22'),('june23'),('june24'),('june25'),('june26'),('june27'),('june28'),('june29'),('june30'),('june88'),('juneau'),('junebug'),('junebug1'),('junebug2'),('junejune'),('jungfrau'),('jungle'),('jungle1'),('junglist'),('juninho'),('junior'),('junior!'),('junior.'),('junior00'),('junior01'),('junior02'),('junior03'),('junior04'),('junior05'),('junior06'),('junior07'),('junior08'),('junior09'),('junior1'),('junior10'),('junior11'),('junior12'),('junior123'),('junior1234'),('junior13'),('junior14'),('junior15'),('junior16'),('junior17'),('junior18'),('junior19'),('junior2'),('junior20'),('junior21'),('junior22'),('junior23'),('junior24'),('junior25'),('junior26'),('junior27'),('junior28'),('junior3'),('junior33'),('junior4'),('junior420'),('junior5'),('junior6'),('junior69'),('junior7'),('junior77'),('junior8'),('junior88'),('junior9'),('junior99'),('juniors'),('juniper'),('juniper1'),('junito'),('junito1'),('junjun'),('junjun1'),('junk'),('junk123'),('junker'),('junkfood'),('junkie'),('junkie1'),('junkjunk'),('junkmail'),('junkmail1'),('junkyard'),('junkyard1'),('juno'),('junpyo'),('junpyo1'),('jupiler'),('jupiter'),('jupiter1'),('jupiter2'),('jupiter5'),('jupiter7'),('jurassic'),('jurassic5'),('jurgen'),('jus'),('jussi69'),('just'),('just12'),('just123'),('just1n'),('just4fun'),('just4me'),('just4now'),('just4u'),('just4you'),('justblaze1'),('justdance'),('justdoit'),('justdoit1'),('juster'),('justforfun'),('justforme'),('justforyou'),('justice'),('justice01'),('justice1'),('justice11'),('justice12'),('justice123'),('justice2'),('justice3'),('justice4'),('justice7'),('justicia'),('justin'),('justin!'),('justin.'),('justin0'),('justin00'),('justin01'),('justin02'),('justin03'),('justin04'),('justin05'),('justin06'),('justin07'),('justin08'),('justin09'),('justin1'),('justin10'),('justin101'),('justin11'),('justin12'),('justin123'),('justin1234'),('justin13'),('justin14'),('justin15'),('justin16'),('justin17'),('justin18'),('justin19'),('justin2'),('justin20'),('justin21'),('justin22'),('justin23'),('justin24'),('justin25'),('justin26'),('justin27'),('justin28'),('justin3'),('justin31'),('justin33'),('justin4'),('justin5'),('justin6'),('justin69'),('justin7'),('justin77'),('justin8'),('justin87'),('justin88'),('justin89'),('justin9'),('justin91'),('justin92'),('justin94'),('justin95'),('justin96'),('justin97'),('justin98'),('justin99'),('justina'),('justina1'),('justinb'),('justinbeib'),('justinbibe'),('justinbieb'),('justinbieber'),('justincase'),('justindrew'),('justine'),('justine1'),('justine123'),('justinlove'),('justintime'),('justlooking'),('justlove'),('justme'),('justme!'),('justme1'),('justme12'),('justme123'),('justme2'),('justme3'),('justus'),('justus1'),('justus2'),('justus3'),('justyna'),('justyna1'),('justynka'),('juve'),('juvenile'),('juvenile1'),('juventini'),('juventino'),('juventus'),('juventus1'),('juventus10'),('JxsGx2Yd87'),('jyothi'),('jyoti'),('jyotsna'),('JysGy2Yd87'),('jza90supra'),('k'),('k.'),('k.,bvfz'),('k.,bvsq'),('k.,jdm'),('k.,k.'),('k.,k.nt,z'),('k.:'),('k.ljxrf'),('k.lvbkf'),('k.u.r.t'),('k11111'),('k111111'),('k123098'),('k123123'),('k12345'),('k123456'),('k1234567'),('k12345678'),('k123456789'),('k1k2k3'),('k1k2k3k4'),('k1ll3r'),('k1ller'),('k1mberly'),('k2010302'),('k25061405u'),('k3ZeChmExt'),('k3ZeDhmExs'),('k43a5vZtoX'),('k47Rizxt2G'),('k55555'),('k654321'),('k7777777'),('K9g2xpce1E'),('kabal'),('kabayo'),('kaboom'),('kaboom1'),('kabouter'),('kabuki'),('kabuto'),('kacenka'),('kacey1'),('kacper'),('kacper1'),('kacper123'),('kacperek'),('kaczka'),('kaczor'),('kaden'),('kaden1'),('kaden10'),('kadence'),('kadence1'),('kader'),('kadett'),('kaduna'),('kaelyn'),('kafedra_oisp'),('kaffee'),('kagandahan'),('kagome'),('kagome1'),('kahina'),('kahitano'),('kahlua'),('kahlua1'),('kahne9'),('kahraman'),('kahuna'),('kahuna1'),('kai'),('kai123'),('kaibigan'),('kaiden'),('kaiden1'),('kaifer124'),('kaikai'),('kaikai1'),('kaila'),('kaila1'),('kailash'),('kailee'),('kailee1'),('kailey'),('kailey1'),('kailua'),('kailyn'),('kairos'),('kaiser'),('kaiser1'),('kaitlin'),('kaitlin1'),('kaitlyn'),('kaitlyn1'),('kaitlyn12'),('kaitlyn123'),('kaitlyn2'),('kaitlyn3'),('kaitlyn7'),('kaitlynn'),('kaitlynn1'),('kaizen'),('kaizer'),('kajtek'),('kak'),('kaka'),('kaka10'),('kaka11'),('kaka12'),('kaka123'),('kaka1234'),('kaka22'),('kakadu'),('kakaka'),('kakaka1'),('kakakaka'),('kakarot'),('kakaroto'),('kakashi'),('kakashi1'),('kakashi12'),('kakashi123'),('kakashi21'),('kakashka'),('kakaska'),('kakawka'),('kakdela'),('kakka'),('kakka1'),('kakka123'),('kakosja'),('kaktus'),('kaktus1'),('kaktys'),('kal'),('kal-el'),('kala'),('kalafior'),('kalamata'),('kalamazoo'),('kalambur'),('kalani'),('kalani1'),('kalash'),('kalashnikov'),('kalbo'),('kaleb'),('kaleb1'),('kaleb123'),('kaleigh'),('kaleigh1'),('kalender'),('kaley1'),('kalhonaho'),('kali'),('kaliber44'),('kalifornia'),('kaligula'),('kalima'),('kaliman'),('kalimantan'),('kalimera'),('kalimero'),('kalina'),('kalinin'),('kalinina'),('kaliningrad'),('kalinka'),('kalle'),('kalle1'),('kalle123'),('kalleanka'),('kallie'),('kallie1'),('kalpana'),('kalpesh'),('kalvin'),('kalyan'),('kalyani'),('kam'),('kam123'),('kamal'),('kamal1'),('kamal123'),('kamala'),('kamara'),('kamari'),('kamari1'),('kamasutra'),('kamasutra1'),('kamazist.tsobenko'),('kambal'),('kambing'),('kambing1'),('kamehameha'),('kamel'),('kameleon'),('kamelia'),('kamelot'),('kamenrider'),('kamera'),('kameron'),('kameron1'),('kamikadze'),('kamikaze'),('kamikaze1'),('kamikazee'),('kamil'),('kamil1'),('kamil12'),('kamil123'),('kamil555'),('kamila'),('kamila1'),('kamilek'),('kamilek1'),('kamilka'),('kamilla'),('kamille'),('kamiloza'),('kamina'),('kamini'),('kamisama'),('kamkam'),('kamlesh'),('kamogelo'),('kamote'),('kampala'),('kampret'),('kamran'),('kamron'),('kamryn'),('kamryn1'),('kan'),('kanabis'),('kanada'),('kaname'),('kanarya'),('kanchan'),('kanchana'),('kancil'),('kandi'),('kandi1'),('kandice1'),('kandy'),('kandy1'),('kane'),('kane12'),('kane123'),('kangar00'),('kangaroo'),('kangaroo1'),('kangaroo2'),('kangaroos'),('kangen'),('kangkang'),('kangoo'),('kangourou'),('kangta'),('kanika'),('kanishka'),('kankan'),('kanker'),('kannan'),('kanpur'),('kansas'),('kansas1'),('kansascity'),('kantot'),('kantutan'),('kanwal'),('kanye1'),('kanyewest'),('kanyewest1'),('kapej111'),('kapitan'),('kaplan'),('kapoor'),('kapow'),('kappa'),('kappa1'),('kappa1911'),('kapusta'),('kar'),('kar123'),('kara'),('kara123'),('kara2711'),('karabas'),('karabo'),('karachi'),('karachi1'),('karachi123'),('karadeniz'),('karaganda'),('karakartal'),('karaman'),('karamba'),('karamel'),('karamelka'),('karan'),('karan123'),('karandash'),('karaoke'),('karaoke1'),('karappinha'),('karapuz'),('karate'),('karate1'),('karate12'),('karate123'),('karate2'),('karatedo'),('karateka'),('karatekid'),('karatekid1'),('karavan'),('kardelen'),('kardon'),('karebear'),('karebear1'),('kareem'),('kareem1'),('kareena'),('karel'),('karelia'),('karen'),('karen01'),('karen1'),('karen10'),('karen11'),('karen12'),('karen123'),('karen13'),('karen15'),('karen2'),('karen22'),('karena'),('karencita'),('karenina'),('karens'),('kari'),('kari123'),('karibu'),('karim'),('karim1'),('karim123'),('karima'),('karime'),('karin'),('karin1'),('karina'),('karina01'),('karina1'),('karina10'),('karina11'),('karina12'),('karina123'),('karina13'),('karina14'),('karina15'),('karina2'),('karine'),('karine73'),('karinka'),('karishma'),('karisma'),('karissa'),('karissa1'),('karito'),('karizma'),('karkar'),('karl'),('karla'),('karla1'),('karla12'),('karla123'),('karla13'),('karlee'),('karlee1'),('karlie'),('karlita'),('karlita1'),('karlitos'),('karlmarx'),('karlos'),('karlson'),('karma'),('karma1'),('karma123'),('karman'),('karmen'),('karnataka'),('karo13'),('karol'),('karol1'),('karol123'),('karola'),('karolcia'),('karolek'),('karolina'),('karolina1'),('karoline'),('karolinka'),('karolinka1'),('karpenko'),('karpov'),('karpova'),('karsten'),('kartal'),('kartal1903'),('karthi'),('karthick'),('karthik'),('karthika'),('kartik'),('kartika'),('kartina'),('karting'),('kartoffel'),('kartoffelpuffer'),('kartoshka'),('karukera'),('karuna'),('karusev_spb'),('kas'),('kasabian'),('kasablanka'),('kasandra'),('kasandra1'),('kasey'),('kasey1'),('kasey123'),('kasey9'),('kashif'),('kashish'),('kashmir'),('kashmir1'),('kashmoney1'),('kashyap'),('kasia'),('kasia1'),('kasia123'),('kasimir'),('kasiunia'),('kaskad'),('kasparov'),('kasper'),('kasper1'),('kasper123'),('kaspersky'),('kassandra'),('kassandra1'),('kassidy'),('kassidy1'),('kassie'),('kassie1'),('kassy1'),('kasturi'),('kasumi'),('kat'),('kat123'),('kata'),('katalin'),('katalina'),('katana'),('katana1'),('katara'),('katarina'),('katarina1'),('katarzyna'),('katarzyna1'),('katasandi'),('katastrofa'),('kate'),('kate11'),('kate12'),('kate123'),('kate1234'),('katekate'),('katelin'),('katelyn'),('katelyn1'),('katelyn12'),('katelyn2'),('katelynn'),('katelynn1'),('katena'),('katenka'),('katenok'),('katerina'),('katerina1'),('katerine'),('katerinka'),('katharina'),('katharina1'),('katharine'),('katherin'),('katherine'),('katherine0'),('katherine1'),('katherine2'),('katherine3'),('katherine7'),('kathie'),('kathleen'),('kathleen1'),('kathleen12'),('kathmandu'),('kathmandu1'),('kathrin'),('kathrina'),('kathrine'),('kathryn'),('kathryn1'),('kathy'),('kathy1'),('kathy12'),('kathy123'),('kathy2'),('kati-leva'),('katia'),('katia1'),('katica'),('katie'),('katie!'),('katie01'),('katie06'),('katie07'),('katie08'),('katie09'),('katie1'),('katie10'),('katie101'),('katie11'),('katie12'),('katie123'),('katie1234'),('katie13'),('katie14'),('katie15'),('katie16'),('katie17'),('katie18'),('katie2'),('katie21'),('katie22'),('katie23'),('katie3'),('katie4'),('katie5'),('katie6'),('katie69'),('katie7'),('katie8'),('katie9'),('katieb'),('katiebug'),('katiebug1'),('katies'),('katika'),('katina'),('katinas'),('katinka'),('katita'),('katja'),('katka'),('katkat'),('katkat1'),('katlyn'),('katlyn1'),('katmandu'),('katorse'),('katrin'),('katrina'),('katrina1'),('katrina12'),('katrina123'),('katrina2'),('katrine'),('katrinka'),('katten'),('katter'),('kattie'),('katty'),('katusha'),('katushka'),('katy'),('katy12'),('katy123'),('katya'),('katya1'),('katya123'),('katyakatya'),('katydid'),('katyperry'),('katyusha'),('katze'),('katze1'),('katzen'),('kaulitz'),('kaulitz1'),('kaulitz89'),('kaunas'),('kaushal'),('kaushik'),('kavita'),('kavitha'),('kavkaz'),('kawaii'),('kawaii1'),('kawasaki'),('kawasaki1'),('kawasaki12'),('kawasaki7'),('kay'),('kay123'),('kaya'),('kayak'),('kayak1'),('kayaking'),('kaycee'),('kaycee1'),('kaycie1'),('kaydee'),('kayden'),('kayden1'),('kaydence'),('kaydence1'),('kaydenlee'),('kaykay'),('kaykay1'),('kaykay12'),('kaykay123'),('kaykay2'),('kayla'),('kayla!'),('kayla01'),('kayla03'),('kayla05'),('kayla06'),('kayla07'),('kayla08'),('kayla09'),('kayla1'),('kayla10'),('kayla101'),('kayla11'),('kayla12'),('kayla123'),('kayla1234'),('kayla13'),('kayla14'),('kayla15'),('kayla16'),('kayla17'),('kayla18'),('kayla2'),('kayla21'),('kayla22'),('kayla23'),('kayla3'),('kayla4'),('kayla5'),('kayla6'),('kayla69'),('kayla7'),('kayla8'),('kayla9'),('kaylah'),('kaylah1'),('kaylan'),('kaylas'),('kaylee'),('kaylee01'),('kaylee06'),('kaylee07'),('kaylee08'),('kaylee1'),('kaylee11'),('kaylee12'),('kaylee123'),('kaylee2'),('kaylee3'),('kayleigh'),('kayleigh1'),('kayley'),('kayley1'),('kaylie'),('kaylie1'),('kaylin'),('kaylin1'),('kaylyn'),('kaylyn1'),('kaylynn'),('kaylynn1'),('kayode'),('kayode1'),('kayseri'),('kayseri38'),('kazakhstan'),('kazakov'),('kazakova'),('kazama'),('kazanova'),('kazantip'),('kazbek'),('kazeem'),('kazuki'),('kazuma'),('kazumi'),('kazuya'),('ka_dJKHJsy6'),('kb1234'),('kb9zc8uxtx'),('kbcbxrf'),('kbctyjr'),('kbkbxrf'),('kbnthfnehf'),('kbpfdtnf'),('kbpjxrf'),('kbytqrf'),('kc1234'),('kcchiefs'),('kdwcNpA362'),('keagan'),('keane16'),('keanu'),('keanu1'),('keaton'),('keaton1'),('keebler'),('keebler1'),('keegan'),('keegan1'),('keekee'),('keekee1'),('keeley'),('keeley1'),('keely1'),('keenan'),('keenan1'),('keens_1'),('keeper'),('keeper1'),('keepit100'),('keepitreal'),('keepout'),('keepout1'),('keepout8'),('keepsmiling'),('keerthana'),('keerthi'),('keesha'),('keesha1'),('kehinde'),('kehinde1'),('keineahnung'),('keines'),('keira'),('keira1'),('keisha'),('keisha1'),('keisuke'),('keith'),('keith1'),('keith12'),('keith123'),('keith2'),('kejan82'),('keke'),('keke09'),('keke10'),('keke11'),('keke12'),('keke123'),('keke13'),('keke14'),('kekeke'),('kekette'),('keksik'),('kel'),('kel123'),('kelantan'),('kelebek'),('kelechi'),('kelinci'),('kellen'),('keller'),('keller1'),('kelley'),('kelley1'),('kelli'),('kelli1'),('kellie'),('kellie1'),('kellogg'),('kelly'),('kelly!'),('kelly01'),('kelly1'),('kelly10'),('kelly101'),('kelly11'),('kelly12'),('kelly123'),('kelly1234'),('kelly13'),('kelly14'),('kelly15'),('kelly16'),('kelly17'),('kelly2'),('kelly21'),('kelly22'),('kelly23'),('kelly3'),('kelly4'),('kelly5'),('kelly6'),('kelly69'),('kelly7'),('kellyann'),('kellykelly'),('kellys'),('kelsea'),('kelsey'),('kelsey!'),('kelsey01'),('kelsey1'),('kelsey10'),('kelsey11'),('kelsey12'),('kelsey123'),('kelsey13'),('kelsey14'),('kelsey2'),('kelsey3'),('kelsey7'),('kelsie'),('kelsie1'),('keluarga'),('kelvin'),('kelvin1'),('kelvin123'),('kemper'),('ken'),('ken123'),('kendal'),('kendal1'),('kendall'),('kendall1'),('kendall2'),('kendra'),('kendra1'),('kendra12'),('kendra123'),('kendra2'),('kendrick'),('kendrick1'),('keneth'),('kenguru'),('kenji'),('kenjie'),('kenken'),('kenken1'),('kenmore'),('kennedi1'),('kennedy'),('kennedy1'),('kennedy12'),('kennedy123'),('kennedy2'),('kenneth'),('kenneth1'),('kenneth12'),('kenneth123'),('kenneth2'),('kenneth3'),('kenneth7'),('kenney'),('kennwort'),('kennwort1'),('kenny'),('kenny01'),('kenny1'),('kenny10'),('kenny11'),('kenny12'),('kenny123'),('kenny13'),('kenny2'),('kenny23'),('kenny3'),('kenny5'),('kenny6'),('kenny69'),('kenny7'),('kennyg'),('kennys'),('kenobi'),('kenseth17'),('kenshi21'),('kenshin'),('kenshin1'),('kenshiro'),('kensington'),('kent'),('kentavr'),('kenton'),('kentucky'),('kentucky1'),('kenwood'),('kenwood1'),('kenworth'),('kenworth1'),('kenya'),('kenya1'),('kenyan'),('kenyatta'),('kenyatta1'),('kenyon'),('kenz4u'),('kenzie'),('kenzie1'),('kenzie11'),('kenzie12'),('kenzie123'),('Kenzie14'),('kenzie2'),('kenzo'),('keparat'),('kepompong'),('ker'),('kerala'),('kerberos'),('keren'),('keri'),('kermit'),('kermit1'),('kernel'),('keroppi'),('keroro'),('kerouac'),('kerri'),('kerri1'),('kerrie'),('kerrigan'),('kerry'),('kerry1'),('kerry123'),('kerstin'),('kerstin1'),('kerwin'),('kesha'),('kesha1'),('keshav'),('keshawn1'),('keshia'),('keshia1'),('kessler'),('kestrel'),('ketchup'),('ketchup1'),('ketrin'),('kettle'),('kev'),('kev123'),('kevco33'),('kevin'),('kevin!'),('kevin01'),('kevin05'),('kevin06'),('kevin07'),('kevin08'),('kevin09'),('kevin1'),('kevin10'),('kevin101'),('kevin11'),('kevin12'),('kevin123'),('kevin1234'),('kevin12345'),('kevin13'),('kevin14'),('kevin15'),('kevin16'),('kevin17'),('kevin18'),('kevin19'),('kevin2'),('kevin20'),('kevin21'),('kevin22'),('kevin23'),('kevin24'),('kevin25'),('kevin27'),('kevin3'),('kevin4'),('kevin5'),('kevin6'),('kevin69'),('kevin7'),('kevin8'),('kevin9'),('kevin99'),('kevina'),('kevinb'),('kevinbg01'),('kevine'),('kevinm'),('kevinn'),('kevins'),('kevins1'),('Kevnwo128'),('kexifz'),('key'),('key123'),('keyblade'),('keyblade1'),('keyboard'),('keyboard1'),('keykey'),('keykey1'),('keynbr'),('keys'),('keyshawn'),('keystone'),('keystone1'),('keywest'),('keywest1'),('keyword'),('keziah'),('kfc123'),('kfcnjxrf'),('kfgekz'),('kfgjxrf'),('kfhbcf'),('kfkfkf'),('kfvgjxrf'),('kfx400'),('kfylsi'),('khadija'),('khadija1'),('khadijah'),('khairul'),('khaled'),('khalid'),('khalid1'),('khalid123'),('khalifa'),('khalil'),('khalil1'),('khalsa'),('khan'),('khan12'),('khan123'),('khan1234'),('khan786'),('khankhan'),('khanna'),('kharen'),('khattak'),('khmer1'),('khongbiet'),('khongco'),('khongnho'),('khulet'),('khuljasimsim'),('khurram'),('khushboo'),('khushbu'),('khushi'),('kia123'),('kiakia'),('kiana'),('kiana1'),('kianna'),('kianna1'),('kiara'),('kiara1'),('kiara12'),('kiara123'),('kibbles'),('kibbles1'),('kick'),('kickass'),('kickass!'),('kickass1'),('kickass123'),('kickass2'),('kickball'),('kickboxer'),('kickboxing'),('kicker'),('kicker1'),('kickers'),('kickflip'),('kickflip1'),('kickit'),('kickme'),('kicsim'),('kid'),('kid123'),('kid1412'),('kidman'),('kidney'),('kidrock'),('kidrock1'),('kids'),('kids02'),('kids03'),('kids04'),('kids12'),('kids123'),('kids1234'),('kidskids'),('kiefer'),('kiekeboe'),('kiera1'),('kieran'),('kieran1'),('kieran123'),('kieron'),('kierra'),('kierra1'),('kiersten'),('kiersten1'),('kiesha'),('kiesha1'),('kiffen'),('kifj9n7bfu'),('kigali'),('kik'),('kika'),('kikakika'),('kikay'),('kikelomo'),('kIkeunyw'),('kiki'),('kiki00'),('kiki01'),('kiki07'),('kiki09'),('kiki10'),('kiki101'),('kiki11'),('kiki12'),('kiki123'),('kiki1234'),('kiki13'),('kiki14'),('kiki15'),('kiki16'),('kiki21'),('kiki22'),('kiki23'),('kiki88'),('kiki89'),('kiki99'),('kikiki'),('kikiki1'),('kikikiki'),('kikimora'),('kikina'),('kikinou'),('kikiriki'),('kikito'),('kikka'),('kikker'),('kiklop'),('kiko'),('kiko123'),('kikokiko'),('kikou'),('kikugalanetroot'),('kikumaru'),('kil'),('kiler'),('kiley1'),('kilgore'),('kilian'),('kilimanjaro'),('kilkenny'),('kill'),('kill11'),('kill12'),('kill123'),('kill1234'),('kill3r'),('kill666'),('killa'),('killa1'),('killa11'),('killa12'),('killa123'),('killa13'),('killa14'),('killa187'),('killa2'),('killa21'),('killa22'),('killa23'),('killa3'),('killa4'),('killa5'),('killa6'),('killa69'),('killa7'),('killa9'),('killacam'),('killacam1'),('killah'),('killah1'),('killall'),('killall1'),('killas'),('killas1'),('killaz'),('killaz1'),('killbill'),('killbill1'),('killbill2'),('killed'),('killemall'),('killemall1'),('killer'),('killer!'),('killer.'),('killer0'),('killer00'),('killer007'),('killer01'),('killer07'),('killer08'),('killer09'),('killer1'),('killer10'),('killer100'),('killer101'),('killer11'),('killer12'),('killer123'),('killer1234'),('killer12345'),('killer13'),('killer14'),('killer15'),('killer16'),('killer17'),('killer18'),('killer187'),('killer19'),('killer2'),('killer20'),('killer21'),('killer22'),('killer23'),('killer24'),('killer25'),('killer27'),('killer3'),('killer321'),('killer33'),('killer34'),('killer4'),('killer420'),('killer44'),('killer45'),('killer5'),('killer55'),('killer56'),('killer6'),('killer66'),('killer666'),('killer69'),('killer7'),('killer77'),('killer777'),('killer78'),('killer8'),('killer87'),('killer88'),('killer89'),('killer9'),('killer90'),('killer91'),('killer911'),('killer92'),('killer93'),('killer94'),('killer95'),('killer96'),('killer98'),('killer99'),('killerbee'),('killerbee1'),('killerboy'),('killerin66'),('killerman'),('killerman1'),('killers'),('killers1'),('killers123'),('killers2'),('killian'),('killian1'),('killie'),('killing'),('killing1'),('killjoy'),('killjoy1'),('killkill'),('killkill1'),('killme'),('killme1'),('killme123'),('killme2'),('killme666'),('killmenow'),('killroy'),('killswitch'),('killua'),('killyou'),('killyou1'),('killzone'),('killzone1'),('killzone2'),('kilo'),('kilo123'),('kilokilo'),('kilroy'),('kim'),('kim123'),('kim1234'),('kim12345'),('kimak1'),('kimani'),('kimba'),('kimba1'),('kimball'),('kimber'),('kimber1'),('kimber45'),('kimberley'),('kimberley1'),('kimberly'),('kimberly01'),('kimberly1'),('kimberly10'),('kimberly11'),('kimberly12'),('kimberly13'),('kimberly2'),('kimberly3'),('kimberly5'),('kimberly7'),('kimbo'),('kimbo1'),('kimbum'),('kimbum1'),('kimchi'),('kimera'),('kimerald'),('kimi'),('kimikimi'),('kimiko'),('kimkim'),('kimkim1'),('kimmer'),('kimmie'),('kimmie1'),('kimmy'),('kimmy1'),('kimmy12'),('kimmy123'),('kimono'),('kimora'),('kimora1'),('kims89'),('kimura'),('kin'),('kinder'),('kinder1'),('kinderen'),('kindergarten'),('kindness'),('kindred'),('kinetic'),('king'),('king00'),('king007'),('king01'),('king05'),('king06'),('king07'),('king08'),('king09'),('king1'),('king10'),('king101'),('king11'),('king12'),('king123'),('king1234'),('king12345'),('king123456'),('king13'),('king14'),('king15'),('king16'),('king17'),('king18'),('king19'),('king20'),('king21'),('king22'),('king23'),('king24'),('king25'),('king32'),('king33'),('king34'),('king360'),('king420'),('king44'),('king45'),('king4life'),('king55'),('king66'),('king666'),('king69'),('king77'),('king88'),('king99'),('kinga'),('kinga1'),('kingarthur'),('kingcobra'),('kingdavid'),('kingdom'),('kingdom1'),('kingdom12'),('kingdom123'),('kingdom2'),('kingdom7'),('kingdomhea'),('kingdomhearts'),('kingdomhearts2'),('kinger'),('kingfish'),('kingfish1'),('kingfish11'),('kingfisher'),('kingjames'),('kingjames1'),('kingjames2'),('kingjames23'),('kingkhan'),('kingking'),('kingking1'),('kingkong'),('kingkong1'),('kingkong12'),('kingkong2'),('kinglove'),('kinglove1'),('kinglove5'),('kingmaker'),('kingman'),('kingman1'),('kingme'),('kingme1'),('kingofking'),('kingofkings'),('kingofpop'),('kingpin'),('kingpin1'),('kings'),('kings1'),('kings10'),('kings123'),('kings2'),('kings5'),('kingsize'),('kingsley'),('kingsley1'),('kingss'),('kingston'),('kingston1'),('kingston12'),('kingsway'),('kingswood'),('kingtut'),('kingtut1'),('kinjal'),('kinkin'),('kinky'),('kinky1'),('kinky69'),('Kinomoto89'),('kinsey'),('kinshasa'),('kinyabuzova.eleonora'),('kipelov'),('kipling'),('kippen'),('kipper'),('kipper1'),('kir'),('kir-ettk'),('kira'),('kira12'),('kira123'),('kirakira'),('kiran'),('kiran1'),('kiran123'),('kirana'),('kirankumar'),('kirara'),('kirby'),('kirby1'),('kirby123'),('kirienko_svetlana'),('kirik26trimyasov'),('kirikou'),('kirill'),('kirill.kirillov.2013'),('kirill123'),('Kirill1990'),('kirill1998'),('kirill999_97'),('kirk'),('kirkland'),('kirkland1'),('kirkwood'),('kirsche'),('kirsten'),('kirsten1'),('kirstie'),('kirstie1'),('kirstin'),('kirstin1'),('kirsty'),('kirsty1'),('kis'),('kisa'),('kisakisa'),('kisame'),('kisha1'),('kishan'),('kishor'),('kishore'),('kiska'),('kiska123'),('kiskis'),('kismat'),('kismet'),('kiss'),('kiss01'),('kiss100'),('kiss11'),('kiss12'),('kiss123'),('kiss1234'),('kiss13'),('kiss1947'),('kiss22'),('kiss23'),('kiss69'),('kissa123'),('kissable'),('kissarmy'),('kissass'),('kissass1'),('kisser'),('kisses'),('kisses!'),('kisses01'),('kisses1'),('kisses11'),('kisses12'),('kisses123'),('kisses13'),('kisses2'),('kisses22'),('kisses23'),('kisses3'),('kisses4'),('kisses4u'),('kisses5'),('kisses69'),('kisses7'),('kissing'),('kissing1'),('kissit'),('kisska'),('kisskiss'),('kisskiss1'),('kisskiss12'),('kisskiss2'),('kisslove'),('kissm3'),('kissme'),('kissme!'),('kissme1'),('kissme11'),('kissme12'),('kissme123'),('kissme13'),('kissme2'),('kissme22'),('kissme23'),('kissme3'),('kissme4'),('kissme5'),('kissme69'),('kissme7'),('kissmebaby'),('kissmoko'),('kissmyass'),('kissmyass!'),('kissmyass1'),('kissmyass2'),('kissthis'),('kissthis1'),('kissy1'),('kissyou'),('kisulya'),('kisumu'),('kit'),('kitana'),('kitcat'),('kitchen'),('kitchen1'),('kitesurf'),('kitkat'),('kitkat1'),('kitkat11'),('kitkat12'),('kitkat123'),('kitkat13'),('kitkat2'),('kitkit'),('kitsune'),('kitsune1'),('kitten'),('kitten!'),('kitten01'),('kitten1'),('kitten10'),('kitten11'),('kitten12'),('kitten123'),('kitten13'),('kitten2'),('kitten22'),('kitten3'),('kitten4'),('kitten5'),('kitten6'),('kitten69'),('kitten7'),('kittens'),('kittens1'),('kittens12'),('kittens123'),('kittens2'),('kittens3'),('kittie'),('kittie1'),('kitties'),('kitties1'),('kitties2'),('kittiwake'),('kitty'),('kitty!'),('kitty.'),('kitty01'),('kitty06'),('kitty07'),('kitty08'),('kitty09'),('kitty1'),('kitty10'),('kitty101'),('kitty11'),('kitty12'),('kitty123'),('kitty1234'),('kitty13'),('kitty14'),('kitty15'),('kitty16'),('kitty17'),('kitty18'),('kitty2'),('kitty21'),('kitty22'),('kitty23'),('kitty24'),('kitty25'),('kitty3'),('kitty4'),('kitty5'),('kitty55'),('kitty6'),('kitty666'),('kitty69'),('kitty7'),('kitty77'),('kitty8'),('kitty88'),('kitty9'),('kitty99'),('kittycat'),('kittycat!'),('kittycat1'),('kittycat12'),('kittycat2'),('kittycat3'),('kittygirl'),('kittykat'),('kittykat1'),('kittykat12'),('kittykat2'),('kittykitty'),('kittylove'),('kittys'),('kittys1'),('kittyy'),('kiwi'),('kiwi12'),('kiwi123'),('kiwikiwi'),('kizzie'),('kizzy1'),('kj'),('kj1234'),('kjgfnf'),('kjhgfdsa'),('kjifhf'),('kjiflm'),('kjiflrf'),('kjkbnf'),('kjkjkj'),('kjkszpj'),('kjkszpj1'),('kjrjvjnbd'),('kjv1611'),('kjyljy'),('kk'),('kk1234'),('kk12345'),('kk123456'),('kkk'),('kkk111'),('kkk123'),('kkk666'),('kkk999'),('kkkk'),('kkkkk'),('kkkkk1'),('kkkkkk'),('kkkkkk1'),('kkkkkk6'),('kkkkkkk'),('kkkkkkkk'),('kkkkkkkkk'),('kkkkkkkkkk'),('kl098709'),('kl1234'),('kl123456'),('klaipeda'),('klapaucius'),('klara'),('klasse'),('klaster'),('klaudia'),('klaudia01'),('klaudia1'),('klaus'),('klaus1'),('klausi'),('klavier'),('kleber'),('kleenex'),('kleenex1'),('kleine'),('kleiner'),('kleopatra'),('klg604'),('klimenko'),('klimov'),('klinger1'),('klingon'),('klingon1'),('klizma'),('klk123'),('klklkl'),('klm123'),('klmklm'),('klo123'),('klokan'),('kloklo'),('klondike'),('klondike1'),('klootzak'),('klop'),('klopik'),('klopklop'),('klubnichka'),('klubnika'),('kluivert'),('km1234'),('kmdbwf'),('kmdtyjr'),('kmg365'),('kmk420'),('kmzwa8awaa'),('kmzway87aa'),('Knackwurst8853'),('knickers'),('knicks'),('knicks1'),('knicks33'),('knight'),('knight01'),('knight1'),('knight11'),('knight12'),('knight123'),('knight2'),('knightrider'),('knights'),('knights1'),('knitter'),('knitting'),('knives'),('knockers'),('knockknock'),('knockout'),('knockout1'),('knopka'),('knopo4ka'),('knopochka'),('knowledge'),('knowledge1'),('knoxville'),('knoxville1'),('knuckles'),('knuckles1'),('knuddel'),('knuffel'),('knulla'),('koala'),('koala1'),('koala123'),('koalabear'),('koalas'),('koala_1995'),('kobayashi'),('kobe'),('kobe08'),('kobe12'),('kobe123'),('kobe23'),('kobe24'),('kobe81'),('kobebryant'),('kobebryant24'),('kobena'),('kobina'),('kobold'),('kobra'),('kobra11'),('kocham'),('kocham1'),('kochamcie'),('kochamcie1'),('kochanie'),('kochanie1'),('kociak'),('kocicka'),('kocka'),('kodabear'),('kodaira523'),('kodak'),('kodak1'),('kodiak'),('kodiak1'),('koenig'),('koffie'),('kofola'),('kohinoor'),('koikoi'),('kok'),('kokain'),('kokakola'),('kokanee'),('koketka'),('kokito'),('koko'),('koko11'),('koko12'),('koko123'),('koko1234'),('kokoko'),('kokoko1'),('kokokoko'),('kokolo'),('kokoloko'),('kokomo'),('kokomo1'),('kokopelli'),('kokoro'),('kokos'),('kokot'),('kokotko'),('kokowawa'),('kol'),('kola'),('kolade'),('kolakola'),('kolawole'),('kolbasa'),('kolejorz'),('kolesnik'),('koleso'),('kolibri'),('koliko'),('kolkata'),('kolkol'),('Kolkol90'),('koller'),('kollol'),('kolo'),('kolobok'),('kolodiy'),('kolokol'),('kolokolo'),('kolokoy'),('kolovrat'),('kolton'),('kolya'),('kolyan'),('komando'),('komarov'),('komarova'),('komatsu'),('kombat'),('kometa'),('komltptfcorp'),('komnatnyy88'),('komo123'),('komodo'),('komodo1'),('kompages4u'),('kompas'),('komputer'),('komputer1'),('Komputer12'),('kon'),('kona'),('konakona'),('konami'),('kondom'),('kondor'),('kondrat'),('konfeta'),('konfetina-kis'),('konfetka'),('kongkong'),('konichiwa'),('konijn'),('konnichiwa'),('konoha'),('konrad'),('konrad1'),('konstantin'),('kontakt'),('kontol'),('kontol1'),('kontol123'),('konvict'),('kookai'),('kookie'),('kookie1'),('kookoo'),('kookoo1'),('kool'),('kool-aid'),('kool101'),('kool11'),('kool12'),('kool123'),('kool1234'),('kool13'),('kool23'),('koolaid'),('koolaid1'),('koolaid2'),('kooldude'),('koolio'),('koolio1'),('koolkat'),('koolkat1'),('koolkid'),('koolkid1'),('koolkool'),('koolsavas'),('kopa1961'),('kopernik'),('kopilka'),('kopretina'),('kopytko'),('kor'),('korea'),('korea1'),('korean'),('korean1'),('korede'),('korina'),('korn'),('korn12'),('korn123'),('korn1234'),('korn666'),('korn69'),('kornelia'),('kornkorn'),('korokozabr'),('korolev'),('koroleva'),('korona'),('korostelev_3333'),('korova'),('korsar'),('kos'),('kosama'),('koshechka'),('kosher'),('koshka'),('kosmos'),('kosmos1'),('kosova'),('kosova1'),('kosova123'),('kosovo'),('kostas'),('kostia'),('kostik'),('koston'),('kostroma'),('kostya'),('kostyan'),('kot'),('kot123'),('koteczek'),('kotek'),('kotek1'),('kotenok'),('kotik'),('kotikova_n_m'),('kotkot'),('kotkova37'),('kotmichanik'),('kotopes'),('kotopes_o'),('kotova'),('kotova.69'),('kotovam85'),('kotovas-70'),('kotova_74'),('kotovichvalentina'),('kotox76'),('kottayam'),('kotya_bagdan'),('kotyk22'),('koukou'),('koupelna'),('kourtney'),('kourtney1'),('kovach8'),('kovalenko'),('kovalev'),('kovaleva'),('kovalevagn2057'),('kovalha'),('kovalienko63'),('kovalskaya-t'),('kovrnatasha'),('kovshikova1981'),('kowalski'),('kozerog'),('kozlik'),('kozlov'),('kozlova'),('Kp9v1ro7lH'),('kpkp1ee9W'),('KR6sjhs412'),('kraftwerk'),('kraken'),('krakow'),('kramer'),('kramer1'),('krasava'),('krasavchik'),('krasavica'),('krasnodar'),('krasota'),('krasotka'),('kratos'),('kratos1'),('kravchenko'),('krayzie'),('krazy'),('krazy1'),('kreator'),('kretsaha53'),('kri'),('krick.bk'),('kris'),('kris10'),('kris12'),('kris123'),('kris1234'),('krish'),('krish123'),('krisha'),('krishan'),('krishana'),('krishna'),('krishna1'),('krishna123'),('krishnaa'),('krishnan'),('kriska'),('krisna'),('krissy'),('krissy1'),('krista'),('krista1'),('kristal'),('kristal1'),('kristall'),('kristel'),('kristen'),('kristen1'),('kristen12'),('kristen123'),('kristen2'),('kristen3'),('kristen7'),('kristi'),('kristi1'),('kristian'),('kristian1'),('kristie'),('kristie1'),('kristin'),('kristin1'),('kristina'),('kristina1'),('kristina12'),('kristina2'),('kristine'),('kristine1'),('kristinka'),('kristo'),('kristof'),('kristofer'),('kristoffer'),('kristopher'),('kristy'),('kristy1'),('kristyn'),('kritika'),('krizia'),('kroger'),('krokodil'),('krokodyl'),('krokus'),('krolik'),('kronos'),('kronos1'),('kropka'),('kroshka'),('kruemel'),('kruger'),('krusty'),('krusty1'),('krypto'),('krypton'),('krypton1'),('kryptonite'),('krysta'),('krysta1'),('krystal'),('krystal1'),('krystal2'),('krystel'),('krystian'),('krystian1'),('krystle'),('krystle1'),('krystyna'),('krystyna56'),('krzysiek'),('krzysiek1'),('krzysztof'),('ks120473'),('ksenia'),('ksenija'),('kseniya'),('ksenya'),('ksooz'),('ksusha'),('ksushapanda'),('kswiss'),('kswiss1'),('ksyukha1990'),('ksyusha'),('ksyusha.kulagina.91'),('ksyuta76'),('kt'),('kthfkthf'),('kthjxrf'),('ktitymrf'),('ktjybl'),('ktm125'),('ktm250'),('ktm450'),('ktnj2010'),('ktrcec'),('ktutylf'),('ktv910'),('ktvt6tn9'),('ktybyuhfl'),('ktyecbr'),('ktyecmrf'),('ktyecz'),('ktyf'),('ktyfktyf'),('ktyjxrf'),('ktyxbr'),('kuana230345'),('kuba'),('kuba12'),('kuba123'),('kubicek'),('kubnik'),('kubota'),('kubrick'),('kubus'),('kubus1'),('kuchelaeva'),('kuchen'),('kuchierova1994'),('kuchinovao'),('kucing'),('kucing1'),('kucing123'),('kucingku'),('kudakova.83'),('kudielia.anna'),('kudrina1962'),('kudrjashova62'),('kudryavcevavalya'),('kujawka98'),('kukareku'),('kukatov86'),('kukolka'),('kuku'),('kukuku'),('kukuruku'),('kukuruza'),('kukushka'),('kulangot'),('kuldeep'),('kulet'),('kuliiev.79'),('kulikova'),('kulit'),('kulkarni'),('kulot'),('kumar'),('kumar1'),('kumar123'),('kumar1989'),('kumara'),('kumaran'),('kumari'),('kumars'),('kumasi'),('kumkum'),('kundalini'),('kundan'),('kundera'),('kungen'),('kungfu'),('kungfu1'),('kunimi92'),('kuning'),('kuningan'),('kunkle70'),('kupa'),('kupa123'),('kupal'),('kuponatora'),('kupukupu'),('kurakura'),('kurama'),('kurama1'),('kurapika'),('kurczak'),('kurdistan'),('kurdistan1'),('kurenai'),('kurgan'),('kurmangazieva_gulmira'),('kurnia'),('kurniawan'),('kuroneko'),('kurosaki'),('kursant'),('kurt'),('kurt123'),('kurtcobain'),('kurtis'),('kurtis1'),('kurwa'),('kurwa1'),('kurwa123'),('kurwamac'),('kurwamac1'),('kusanagi'),('kush'),('kush420'),('kushal'),('kusuma'),('kuttan'),('kuuipo'),('kuwait'),('kuznecovviktorr'),('kuzya-ser'),('kvartira'),('kwabena'),('kwame1'),('kwiatek'),('kwiatek1'),('kwiatuszek'),('kx250f'),('kxdw0980'),('kyla'),('kyle'),('kyle01'),('kyle07'),('kyle08'),('kyle10'),('kyle11'),('kyle12'),('kyle123'),('kyle1234'),('kyle13'),('kyle14'),('kyle15'),('kyle16'),('kyle18'),('kyle21'),('kyle22'),('kyle23'),('kyle69'),('kylee'),('kylee1'),('kyleigh'),('kyleigh1'),('kylekyle'),('kyler1'),('kylian'),('kylie'),('kylie1'),('kylie123'),('kyllian'),('kyokushin'),('KytFy2xd97'),('KytFy2xd98'),('kyuubi'),('kzkmrf'),('kzktxrf'),('kzkzkz'),('kzueirf'),('l'),('l00000'),('l00ser'),('l0ll0l'),('l0llip0p'),('l0nd0n'),('l0v3m3'),('l0vel0ve'),('l0vely'),('l0veme'),('l0vers'),('l0vey0u'),('l0veyou'),('l11111'),('l111111'),('l123123'),('l12345'),('l123456'),('l1234567'),('l12345678'),('l123456789'),('l1nk3d1n'),('l1nked1n'),('l1o2v3e4'),('l1qoH9wq2U'),('l1v3rp00l'),('l1verp00l'),('l1verpool'),('l33tsupah4x0r'),('l3tm31n'),('l3tm3in'),('L58jkdjP!m'),('L5L5L5'),('l654321'),('l6ho3tg7WB'),('la'),('la1234'),('la123456'),('lab'),('labas123'),('labebe'),('labella'),('labelle'),('labello'),('labirint'),('lablab'),('laboratorio'),('labrador'),('labrador1'),('labtec'),('labtec1'),('labyrinth'),('lac'),('lacey'),('lacey1'),('lacey123'),('lachen'),('lachlan'),('lachlan1'),('lachula1'),('lacie1'),('lacika'),('lacoste'),('lacoste1'),('lacrimosa'),('lacrimosa1'),('lacroix'),('lacrosse'),('lacrosse1'),('lacrosse11'),('lacrosse12'),('lacrosse13'),('lacrosse2'),('lacrosse21'),('lacrosse22'),('lacrosse3'),('lacrosse4'),('lacrosse5'),('lacrosse7'),('lacrosse9'),('lad'),('lada'),('ladder'),('ladder1'),('ladder49'),('laddie'),('laddie1'),('ladeda'),('ladida'),('ladies'),('ladies1'),('ladiesman'),('ladiesman1'),('ladiesman2'),('ladonna'),('lady'),('lady.procenko71'),('lady01'),('lady08'),('lady10'),('lady11'),('lady12'),('lady123'),('lady1234'),('lady13'),('lady14'),('lady21'),('lady22'),('lady23'),('ladybird'),('ladybird1'),('ladyblue'),('ladybug'),('ladybug!'),('ladybug01'),('ladybug08'),('ladybug1'),('ladybug10'),('ladybug11'),('ladybug12'),('ladybug123'),('ladybug13'),('ladybug2'),('ladybug22'),('ladybug3'),('ladybug4'),('ladybug5'),('ladybug6'),('ladybug7'),('ladybug8'),('ladybug9'),('ladybugs'),('ladybugs1'),('ladydi'),('ladydog'),('ladydog1'),('ladygaga'),('ladygaga1'),('ladygaga12'),('ladygirl'),('ladyinred'),('ladyjane'),('ladykiller'),('ladylady'),('ladylove'),('ladylove1'),('ladyluck'),('ladyluck1'),('ladyred'),('ladysman1'),('laetitia'),('lafamilia'),('lafamilia1'),('lafayette'),('lafayette1'),('laffytaffy'),('laflaca'),('lafleur'),('lafouine'),('lafrance'),('lagartija'),('lagarto'),('lagata'),('lagbaja'),('lagnaf'),('lagoon'),('lagrange'),('laguna'),('laguna1'),('laguna2'),('lagwagon'),('lahmy1'),('lahore'),('lahore1'),('lahore123'),('lahoumti'),('laika'),('laika1'),('laila'),('laila1'),('laila123'),('lailas'),('lainey'),('lajolla'),('lake'),('lakehouse'),('lakeland'),('lakeland1'),('laker1'),('laker24'),('lakers'),('lakers!'),('lakers#1'),('lakers01'),('lakers08'),('lakers09'),('lakers1'),('lakers10'),('lakers11'),('lakers12'),('lakers123'),('lakers13'),('lakers15'),('lakers2'),('lakers21'),('lakers22'),('lakers23'),('lakers24'),('lakers3'),('lakers32'),('lakers33'),('lakers34'),('lakers4'),('lakers5'),('lakers7'),('lakers8'),('lakers88'),('lakeshore'),('lakeside'),('lakeside1'),('laketahoe'),('lakeview'),('lakeview1'),('lakewood'),('lakewood1'),('lakilaki'),('lakota'),('lakota1'),('lakshmi'),('lakshmi1'),('lakshya'),('laksjd'),('lal'),('lala'),('lala01'),('lala07'),('lala09'),('lala10'),('lala101'),('lala11'),('lala12'),('lala123'),('lala1234'),('lala13'),('lala14'),('lala15'),('lala16'),('lala18'),('lala21'),('lala22'),('lala23'),('lala24'),('lala69'),('lalaine'),('lalakers'),('lalakers1'),('lalakers24'),('lalala'),('lalala!'),('lalala.'),('lalala1'),('lalala11'),('lalala12'),('lalala123'),('lalala13'),('lalala2'),('lalala22'),('lalala3'),('lalala4'),('lalala5'),('lalala6'),('lalala7'),('lalala99'),('lalalala'),('lalalala1'),('lalalalala'),('lalaland'),('lalaland1'),('lalang'),('lalelu'),('lalita'),('lalitha'),('lalito'),('lalito1'),('lalla'),('lalo'),('lalo12'),('lalo123'),('lalo13'),('laloca'),('laloca1'),('lalola'),('laluna'),('lam'),('lam123'),('lama'),('lamalama'),('lamar'),('lamar1'),('lamar12'),('lamar123'),('lamar2'),('lambada'),('lambchop'),('lambchop1'),('lambda'),('lambert'),('lambert1'),('lambo'),('lambo1'),('lambofgod'),('lambofgod1'),('lamborghin'),('lamborghini'),('lamborgini'),('lambretta'),('lambretta1'),('lame'),('lame12'),('lame123'),('lamejor'),('lamejor1'),('lamer'),('lamina'),('lamination'),('lamine'),('lamisma'),('lammas'),('lamont'),('lamont1'),('lamont2'),('lamour'),('lampada'),('lampara'),('lampard'),('lampard08'),('lampard1'),('lampard123'),('lampard8'),('lampshade'),('lampshade1'),('lampung'),('lan'),('lan123'),('lana'),('lana123'),('lanalana'),('lananh'),('lancaster'),('lancaster1'),('lance'),('lance1'),('lance123'),('lancelot'),('lancelot1'),('lancer'),('lancer1'),('lancers'),('lancers1'),('lancia'),('Lancia037'),('lancome'),('land'),('landcruiser'),('landen'),('landen1'),('lander'),('landlord'),('landmark'),('landon'),('landon01'),('landon05'),('landon06'),('landon07'),('landon08'),('landon09'),('landon1'),('landon12'),('landon123'),('landon2'),('landon3'),('landrover'),('landrover1'),('landry'),('landscape'),('landscape1'),('landser'),('lane'),('lanegra'),('lanena'),('lanena1'),('laney1'),('langer'),('langga'),('langka04'),('langlang'),('langley'),('langston'),('language'),('lanie'),('lanier'),('lanlan'),('lanlan1234'),('lansing'),('lansing1'),('lantern'),('lanzarote'),('laobidenko'),('laoboi.'),('lapierre'),('lapin'),('lapine'),('lapinou'),('lapins'),('lapo4ka'),('lapochka'),('laposte'),('laptop'),('laptop1'),('laptop12'),('laptop123'),('laputa'),('lar'),('lara'),('lara123'),('LARA1308'),('laracroft'),('laracroft1'),('laralara'),('laranja'),('Larded'),('laredo'),('laredo1'),('larenga'),('larina'),('larisa'),('larisa1'),('larissa'),('larissa1'),('larissa123'),('larkin'),('larousse'),('larry'),('larry1'),('larry12'),('larry123'),('larry2'),('larry33'),('larrybird'),('larryboy'),('larrys'),('lars'),('larsen'),('larson'),('larson1'),('larsson'),('larsson7'),('laruku'),('las'),('lasagna'),('lasagne'),('lasalle'),('lasalle1'),('laser'),('laser1'),('laser123'),('laserjet'),('lasers'),('lashae'),('lashae1'),('lashawn'),('lashawn1'),('lashay'),('lashay1'),('lasher'),('laska'),('laska1'),('laspalmas'),('lassie'),('lassie1'),('last'),('last.fm'),('last123'),('lastborn'),('lastchance'),('lastchaos'),('lastfm'),('lastfm1'),('lastfm123'),('lastfmpass'),('lastname'),('lastochka'),('lastpass'),('lasttime'),('lasvegas'),('lasvegas1'),('lasvegas12'),('lasvegas2'),('lasvegas7'),('laszlo'),('latasha'),('latasha1'),('lateef'),('lateralus'),('lateralus1'),('latifa'),('latifah'),('latin'),('latin1'),('latina'),('latina1'),('latina12'),('latina123'),('latina13'),('latina2'),('latinking1'),('latinking5'),('latinlover'),('latino'),('latino1'),('latinoheat'),('latinos'),('latisha'),('latisha1'),('latitude'),('latitude1'),('latoya'),('latoya1'),('latrell'),('latrell1'),('latrice'),('latrice1'),('latvia'),('lau'),('laugh'),('laugh1'),('laughing'),('laughing1'),('laughter'),('laughter1'),('laulau'),('launch'),('laundry'),('laur3n'),('laura'),('laura!'),('laura01'),('laura1'),('laura10'),('laura11'),('laura12'),('laura123'),('laura1234'),('laura13'),('laura14'),('laura15'),('laura16'),('laura17'),('laura18'),('laura2'),('laura21'),('laura22'),('laura23'),('laura3'),('laura5'),('laura69'),('laura7'),('lauraa'),('laurab'),('laurah'),('laural'),('lauram'),('lauras'),('laure'),('laureen'),('laurel'),('laurel1'),('laurel12creek'),('lauren'),('lauren!'),('lauren.'),('lauren00'),('lauren01'),('lauren02'),('lauren05'),('lauren06'),('lauren07'),('lauren08'),('lauren09'),('lauren1'),('lauren10'),('lauren11'),('lauren12'),('lauren123'),('lauren13'),('lauren14'),('lauren15'),('lauren16'),('lauren17'),('lauren18'),('lauren19'),('lauren2'),('lauren21'),('lauren22'),('lauren23'),('lauren24'),('lauren3'),('lauren4'),('lauren5'),('lauren6'),('lauren69'),('lauren7'),('lauren8'),('lauren88'),('lauren9'),('lauren99'),('laurence'),('laurence1'),('laurens'),('laurent'),('laurent1'),('laurentiu'),('lauretta'),('laurette'),('lauriane'),('laurie'),('laurie1'),('laurine'),('laurinha'),('lauris'),('laurita'),('laurita1'),('lauryn'),('lauryn1'),('lausanne'),('lautaro'),('lavalamp'),('lavalamp1'),('lavanda'),('lavander'),('lavanya'),('lavelle'),('lavender'),('lavender1'),('lavern'),('laverne'),('laverne1'),('lavezzi'),('lavida'),('lavidaesbella'),('lavidaloca'),('lavieestbelle'),('lavigne'),('lavigne1'),('lavina'),('lavinia'),('lavoro'),('law'),('law123'),('lawlaw'),('lawless'),('lawless1'),('lawliet'),('lawman'),('lawnmower'),('lawnmower1'),('lawrence'),('lawrence1'),('lawrence2'),('lawson'),('lawson1'),('lawton'),('lawyer'),('lawyer1'),('lax123'),('lax4life'),('laxman'),('layla'),('layla1'),('layla123'),('laylay'),('laylay1'),('layne1'),('layout1'),('layout2'),('layouts!'),('layouts.'),('layouts1'),('layouts123'),('layton'),('lazarev'),('lazareva'),('lazaro'),('lazaro1'),('lazarus'),('lazarus1'),('lazio'),('lazio1900'),('lazy'),('lazyboy'),('lazyboy1'),('lbc562'),('lbfyjxrf'),('lbhtrnjh'),('lbvekmrf'),('lbvekz'),('lbvf'),('lbvfcbr'),('lbvflbvf'),('lbvjxrf'),('lbyfhf'),('lbyfvj'),('lbyjpfdh'),('lc519QlpuU'),('lctstens'),('lcv7bry1cf'),('ldgend'),('le'),('lea'),('lea123'),('leader'),('leader1'),('leadership'),('leafar'),('leafs'),('leafs1'),('league'),('leah'),('leah12'),('leah123'),('leahcim'),('lealea'),('leander'),('leandra'),('leandra1'),('leandro'),('leandro1'),('leandro123'),('leann1'),('leanna'),('leanna1'),('leanne'),('leanne1'),('leapfrog'),('learn'),('learning'),('learning1'),('leather'),('leather1'),('leavemealo'),('leavemealone'),('leaves'),('lebanon'),('lebanon1'),('lebedev'),('lebedeva'),('lebesgue'),('leblanc'),('leboss'),('lebowski'),('lebron'),('lebron1'),('lebron23'),('lebron6'),('lebronjame'),('lebronjames'),('lebronjames23'),('lechat'),('lechuga'),('leckmich'),('lecturer'),('lectures'),('ledesma'),('ledzep'),('ledzep1'),('ledzeppeli'),('ledzeppelin'),('lee'),('lee123'),('lee1234'),('lee12345'),('lee1993'),('leeann'),('leeann1'),('leeanne'),('leeds'),('leeds1'),('leeds123'),('leedsunited'),('leedsutd'),('leedsutd1'),('leelee'),('leelee1'),('leelee12'),('leelee123'),('leelee2'),('leeloo'),('leelou'),('leeminho'),('leeroy'),('leeroy1'),('leeryan'),('leet1337'),('left4dead'),('left4dead2'),('lefthand'),('lefty'),('lefty1'),('leg'),('legacy'),('legacy1'),('legal'),('legal1'),('legalize'),('legaspi'),('legend'),('legend01'),('legend1'),('legend12'),('legend123'),('legend2'),('Legend22'),('legenda'),('legenda1'),('legendary'),('legendary1'),('legends'),('legends1'),('legia'),('legia1'),('legia1916'),('legion'),('legion1'),('legioner'),('lego'),('lego123'),('legoland'),('legolas'),('legolas1'),('legolas2'),('legolego'),('legoman'),('legoman1'),('legrand'),('lehjxrf'),('lehman'),('leicester'),('leicester1'),('leigh'),('leigh1'),('leigh123'),('leigha'),('leighann'),('leighann1'),('leighton'),('leighton1'),('leika1'),('Leika86'),('leila'),('leila1'),('leilani'),('leilani1'),('leilei'),('leinad'),('leipzig'),('lekker'),('lekkerding'),('leland'),('leland1'),('lele'),('lele12'),('lele123'),('lelele'),('lelewa123'),('leliane50934'),('leloto'),('lelouch'),('lemah'),('lemans'),('lemieux'),('lemieux66'),('lemmein'),('lemming'),('lemmings'),('lemon'),('lemon1'),('lemon12'),('lemon123'),('lemon2'),('lemon8'),('lemonade'),('lemonade1'),('lemondrop'),('lemondrop1'),('lemonhead'),('lemonhead1'),('lemonlime'),('lemonlime1'),('lemons'),('lemons1'),('lemons123'),('lemontree'),('lemuel'),('len'),('len4ik31'),('lena'),('lena11'),('lena12'),('lena123'),('lena1234'),('lena2010'),('lena5stars'),('lenalena'),('lenard'),('lenchik'),('lenicka'),('lenin'),('lenina'),('leningrad'),('lenka'),('lenlen'),('lennart'),('lennie'),('lennon'),('lennon1'),('lennox'),('lennox1'),('lenny'),('lenny1'),('lenny123'),('leno4ka'),('lenochka'),('lenora'),('lenore'),('lenovo'),('lensois'),('lenusik'),('lenyi'),('len_nik44'),('len_rin_kagamine_02'),('leo'),('leo123'),('leo1234'),('leo12345'),('leo123456'),('leoleo'),('leoleo1'),('leoleoleo'),('leolion'),('LEOlong1985'),('leomessi'),('leomessi10'),('leon'),('leon01'),('leon11'),('leon12'),('leon123'),('leon1234'),('leon13'),('leona'),('leona1'),('leonard'),('leonard1'),('leonardo'),('leonardo1'),('leonardo10'),('leonardo12'),('leonardo123'),('leonardo2'),('leoncino'),('leoncito'),('leone'),('leonel'),('leonel1'),('leones'),('leonessa'),('leonhart'),('leonid'),('leonida'),('leonidas'),('leonidas1'),('leonie'),('leonie1'),('leonleon'),('leonor'),('leonora'),('leopard'),('leopard1'),('leopard2'),('leopardo'),('leopards'),('leopold'),('leopold1'),('leopoldo'),('leothelion'),('lepidus'),('leprechaun'),('lera'),('lera123'),('leralera'),('lerato'),('lero4ka'),('lerochka'),('lerolero'),('leroy'),('leroy1'),('leroy123'),('les'),('les123'),('lesbian'),('lesbian1'),('lesbian2'),('lesbian69'),('lesbiana'),('lesbians'),('lesbians1'),('lesbica'),('lesbo'),('lesbo1'),('lesedi'),('lesego'),('lesley'),('lesley1'),('leslie'),('leslie01'),('leslie1'),('leslie11'),('leslie12'),('leslie123'),('leslie13'),('leslie2'),('leslie3'),('lesnik'),('lespaul'),('lespaul1'),('lessthan3'),('lestari'),('lestat'),('lestat1'),('lester'),('lester1'),('lester123'),('leszek'),('let'),('lethal'),('lethal1'),('leticia'),('leticia1'),('leticia123'),('letitbe'),('letitia'),('letizia'),('letlet'),('letme1n'),('letmein'),('letmein!'),('letmein.'),('letmein0'),('letmein01'),('letmein1'),('letmein11'),('letmein12'),('letmein123'),('letmein2'),('letmein22'),('letmein3'),('letmein69'),('letmein7'),('letmein9'),('letmein99'),('letmeinnow'),('letmeout'),('letmesee'),('leto-nataly'),('leto2010'),('letras'),('letsdoit'),('letsfuck'),('letsgetit1'),('letsgo'),('letsgo1'),('letsplay'),('letsrock'),('letter'),('letter1'),('letters'),('letters1'),('lettuce'),('lettuce1'),('leumas'),('lev'),('levana928'),('levani'),('level'),('level1'),('level27'),('level42'),('levent'),('levente'),('levenyatko2007'),('leverkusen'),('levi'),('levi12'),('levi123'),('leviathan'),('levis501'),('levski'),('levski1914'),('lewis'),('lewis1'),('lewis12'),('lewis123'),('lewis2'),('lex'),('lex123'),('lexa'),('lexa-let4ik'),('lexa.maxus'),('lexa290195'),('lexaafanasiev84'),('lexi'),('lexi12'),('lexi123'),('lexicon'),('lexie'),('lexie1'),('lexie123'),('lexington'),('lexington1'),('lexir777'),('lexis1'),('lexmark'),('lexmark1'),('lexor123'),('lexus'),('lexus1'),('lexus123'),('lexus300'),('lexusis300'),('lexy123'),('leyla'),('leyton'),('le_den_ec'),('lf'),('lfc123'),('lfc1892'),('lfc4life'),('lfhbyf'),('lfiekmrf'),('lfiekz'),('lfieyz'),('lfif'),('lfiflfif'),('lfitymrf'),('lfplhfgthvf'),('lfybbk'),('lfybkf'),('lfybkjdf'),('lfybkrf'),('lfytxrf'),('lgkp500'),('lh6209lh'),('Lh6RjX44qb'),('lhbjkjubz2957704'),('lhepmz'),('lhfrjy'),('li'),('li0903'),('li123456'),('lia123'),('LIAISONS'),('lialia'),('liam'),('liam123'),('liana'),('liana1'),('lianna'),('lianne'),('liar'),('liarliar'),('liarliar1'),('lib'),('libby'),('libby1'),('libby123'),('libellula'),('libellule'),('libelula'),('libera'),('liberal'),('liberate'),('liberation'),('liberdade'),('liberia'),('libero'),('liberta'),('libertad'),('libertad1'),('libertas'),('liberte'),('libertine'),('liberty'),('liberty1'),('liberty123'),('liberty2'),('liberty7'),('libido'),('libra'),('libra1'),('libra10'),('libra123'),('libran'),('librarian'),('library'),('library1'),('libras'),('lichking'),('lick'),('licker'),('licker1'),('lickit'),('lickit1'),('lickme'),('lickme1'),('lickme2'),('lickme69'),('licorice'),('licorice1'),('licorne'),('lidia'),('lidia1'),('lidiya'),('liebe'),('liebe1'),('lieben'),('liebling'),('liefde'),('liefie'),('lietuva'),('liezel'),('life'),('life09'),('life101'),('life11'),('life12'),('life123'),('life1234'),('life13'),('life21'),('life22'),('life23'),('lifeboat'),('lifegoeson'),('lifeguard'),('lifeguard1'),('lifehouse'),('lifehouse1'),('lifeisgood'),('lifeislife'),('lifeless'),('lifelife'),('lifeline'),('liferocks'),('lifesgood'),('lifestyle'),('lifestyle1'),('lifesucks'),('lifesucks!'),('lifesucks1'),('lifesucks2'),('lifesux'),('lifesux1'),('lifetec'),('lifetime'),('lifetime1'),('ligabue'),('ligaya'),('light'),('light1'),('light12'),('light123'),('lightblue'),('lightbulb'),('lightbulb1'),('lighter'),('lighter1'),('lightfoot'),('lighthouse'),('lightimes'),('lighting'),('lighting1'),('lightning'),('lightning1'),('lightning2'),('Lightpower12345'),('lights'),('lights1'),('lightsaber'),('lightyear'),('lihenan'),('like'),('like123'),('likeaboss'),('likehouse'),('likeme'),('likeme1'),('likemike'),('likeyou'),('lil'),('lil123'),('lila'),('lila123'),('lilac'),('lilacs'),('lilangel'),('lilangel1'),('lilbaby1'),('lilbear'),('lilbear1'),('lilbit'),('lilbit1'),('lilbitch'),('lilbitch1'),('lilboo1'),('lilboosie'),('lilboosie1'),('lilboy'),('lilboy1'),('lilbro1'),('lilchris'),('lilchris1'),('lilcutie1'),('lild12'),('lild123'),('lildaddy1'),('lildee'),('lildee1'),('lildevil'),('lildevil1'),('lildude'),('lildude1'),('lilfizz'),('lilfizz1'),('lilflip'),('lilflip1'),('lilgirl'),('lilgirl1'),('lili'),('lili12'),('lili123'),('lili1234'),('lilia'),('lilian'),('lilian1'),('liliana'),('liliana1'),('liliane'),('lilibeth'),('lilica'),('lilies'),('lilika'),('lilili'),('lililili'),('liline'),('liliput'),('lilita'),('lilith'),('lilith1'),('liliya'),('lilj123'),('liljay'),('liljay1'),('liljj1'),('liljoe'),('liljoe1'),('liljohn'),('liljohn1'),('liljon'),('liljon1'),('lilkim'),('lilkim1'),('lilla'),('lilli'),('lilli1'),('lilli2006'),('lillian'),('lillian1'),('lillian2'),('lilliana'),('lillie'),('lillie1'),('lillies'),('lilliput'),('lillo'),('lilly'),('lilly01'),('lilly07'),('lilly08'),('lilly09'),('lilly1'),('lilly11'),('lilly12'),('lilly123'),('lilly13'),('lilly2'),('lilly3'),('lilly5'),('lilly7'),('lillypad'),('lilmama'),('lilmama01'),('lilmama07'),('lilmama08'),('lilmama09'),('lilmama1'),('lilmama10'),('lilmama11'),('lilmama12'),('lilmama123'),('lilmama13'),('lilmama14'),('lilmama15'),('lilmama2'),('lilmama23'),('lilmama3'),('lilmama4'),('lilmama5'),('lilmama7'),('lilmamma1'),('lilman'),('lilman07'),('lilman08'),('lilman1'),('lilman11'),('lilman12'),('lilman123'),('lilman13'),('lilman2'),('lilman23'),('lilman3'),('lilmike'),('lilmike1'),('lilmomma'),('lilmomma1'),('lilmoney1'),('lilnigga1'),('lilo'),('lilo123'),('lilolilo'),('lilone'),('lilone1'),('lilone13'),('lilou'),('lilpimp'),('lilpimp1'),('lilred'),('lilred1'),('lilrob'),('lilrob1'),('lilromeo'),('lilsaint'),('lilsexy'),('lilsexy1'),('lilshorty1'),('lilsis'),('lilsis1'),('lilwayne'),('lilwayne09'),('lilwayne1'),('lilwayne10'),('lilwayne11'),('lilwayne12'),('lilwayne13'),('lilwayne2'),('lilwayne23'),('lilwayne3'),('lilwayne4'),('lilwayne5'),('lilwayne7'),('lilweezy1'),('lily'),('lily01'),('lily07'),('lily11'),('lily12'),('lily123'),('lily1234'),('lily13'),('lilylily'),('lilypad'),('lilypad1'),('lilyrose'),('lima'),('limabean'),('limanlly'),('limaperu'),('lime'),('limegreen'),('limegreen1'),('limegreen2'),('limelight'),('limerick'),('limestone'),('limewire'),('limewire1'),('limited'),('limited1'),('limited2'),('limoges'),('limonada'),('limonade'),('limone'),('limonyk'),('limpbizkit'),('limpopo'),('lin'),('lin123'),('lin456'),('lina'),('lina123'),('lina90'),('linalina'),('linares'),('lincogo1'),('lincoln'),('lincoln1'),('lincoln2'),('lincoln8187'),('lincon'),('linda'),('linda01'),('linda1'),('linda10'),('linda11'),('linda12'),('linda123'),('linda13'),('linda15'),('linda2'),('linda22'),('linda23'),('linda3'),('linda5'),('linda69'),('linda7'),('lindaa'),('lindalinda'),('lindas'),('lindau'),('linde'),('linden'),('linden1'),('lindinha'),('lindona'),('lindros'),('lindros88'),('lindsay'),('lindsay1'),('lindsay12'),('lindsay123'),('lindsay2'),('lindsay7'),('lindsey'),('lindsey!'),('lindsey1'),('lindsey12'),('lindsey123'),('lindsey2'),('lindsey3'),('lindsey7'),('lindy1'),('line'),('lineage'),('lineage2'),('linebacker'),('lineika'),('lineman'),('lineman1'),('linette'),('lineup1'),('linger'),('lingerie'),('lingling'),('lingling1'),('link'),('link11'),('link12'),('link123'),('link1234'),('link123456'),('link2011'),('link4me'),('linkbuild'),('linked'),('linked01'),('linked1'),('linked11'),('linked123'),('linked1n'),('linked2011'),('linked4me'),('linkedin'),('linkedin.com'),('linkedin01'),('linkedin1'),('linkedin10'),('linkedin11'),('linkedin12'),('linkedin123'),('linkedin1234'),('linkedin13'),('linkedin2'),('linkedin2010'),('linkedin2011'),('linkedin2012'),('linkedin22'),('linkedin23'),('linkedin4me'),('linkedin69'),('linkedin7'),('linkedin77'),('linkedin8'),('linkedin99'),('linkedinlinkedin'),('linkedinpass'),('linkedinpassword'),('linkedinpw'),('linkedln'),('linkedout'),('linkedpass'),('linker'),('linkin'),('linkin1'),('linkin12'),('linkin123'),('linking'),('linkinpark'),('linkinpark1'),('linklink'),('linkme'),('linkmein'),('linkpass'),('links123'),('links234'),('linksys'),('linksys1'),('linlin'),('linnea'),('linsey'),('lintang'),('linton'),('linus'),('linus1'),('linusd8'),('linux'),('linux1'),('linux123'),('linwood'),('linwood1'),('lion'),('lion12'),('lion123'),('lion1234'),('lionel'),('lionel1'),('lionelmessi'),('lioness'),('lioness1'),('lionheart'),('lionheart1'),('lionking'),('lionking1'),('lionking2'),('lionlion'),('lionne'),('lions'),('lions1'),('lions123'),('lipgloss'),('lipgloss1'),('lipgloss12'),('lipgloss2'),('lipovv70'),('lips'),('lipstick'),('lipstick1'),('lipton'),('lipton1'),('lipy110593'),('liquid'),('liquid1'),('lis'),('lisa'),('lisa01'),('lisa10'),('lisa11'),('lisa12'),('lisa123'),('lisa1234'),('lisa13'),('lisa14'),('lisa15'),('lisa21'),('lisa22'),('lisa23'),('lisa25'),('lisa69'),('lisaann'),('lisalisa'),('lisalisa1'),('lisamarie'),('lisamarie1'),('lisandro'),('lisbeth'),('lisboa'),('lisbon'),('lisbon67'),('lisenkogv'),('lisenok'),('lisette'),('lisette1'),('lisichka'),('lisicyna704'),('lissa1'),('lissette'),('lissette1'),('listen'),('listen1'),('lister'),('listopad'),('listopad.iuliia'),('liteon'),('literatura'),('literature'),('lithium'),('lithium1'),('lithuania'),('litosik'),('little'),('little1'),('little11'),('little12'),('little123'),('little2'),('little3'),('little4'),('little5'),('littleangel'),('littlebear'),('littlebit'),('littlebit1'),('littlebit2'),('littleboy'),('littleboy1'),('littled'),('littled1'),('littledog'),('littlefoot'),('littlegirl'),('littleguy'),('littlelady'),('littleman'),('littleman1'),('littleman2'),('littleman3'),('littlemiss'),('littleone'),('littleone1'),('littlered'),('littlered1'),('littlestar'),('liu123'),('liu123456'),('liuchang'),('liuyang'),('liv'),('live'),('live12'),('live123'),('live2die'),('live2love'),('live2ride'),('live4ever'),('live4god'),('live4him'),('live4life'),('live4love'),('livefree'),('livelaughl'),('livelaughlove'),('livelife'),('livelife1'),('livelife2'),('livelove'),('livelove1'),('liver'),('liver1'),('liverp00l'),('liverpoo'),('liverpool'),('liverpool!'),('liverpool.'),('liverpool0'),('liverpool01'),('liverpool05'),('liverpool08'),('liverpool09'),('liverpool1'),('liverpool10'),('liverpool11'),('liverpool12'),('liverpool123'),('liverpool1892'),('liverpool2'),('liverpool3'),('liverpool4'),('liverpool5'),('liverpool6'),('liverpool7'),('liverpool8'),('liverpool9'),('liverpoolf'),('liverpoolfc'),('livestrong'),('livewire'),('livewire1'),('livia'),('living'),('living1'),('livinglife'),('livingston'),('livorno'),('lixiang'),('liyah1'),('liyana'),('liz'),('liz123'),('liza'),('liza12'),('liza123'),('lizaliza'),('lizard'),('lizard1'),('lizard12'),('lizard123'),('lizard2'),('lizardking'),('lizards'),('lizasp07'),('lizaveta'),('lizbeth'),('lizbeth1'),('lizeth'),('lizeth1'),('lizette'),('lizette1'),('lizottes'),('lizzard'),('lizzard1'),('lizzie'),('lizzie01'),('lizzie1'),('lizzie12'),('lizzie123'),('lizzie2'),('lizzy'),('lizzy1'),('lizzy12'),('lizzy123'),('lizzy2'),('lj'),('Lj352d1ib31'),('lj:'),('ljames23'),('ljhjuf'),('ljrnjh'),('ljubav'),('ljxehrf'),('ljxtymrf'),('lk123456'),('lkj123'),('lkj65b6666'),('lkjh'),('lkjhg'),('lkjhg1'),('lkjhgf'),('lkjhgf1'),('lkjhgfd'),('lkjhgfds'),('lkjhgfdsa'),('lkjhgfdsa1'),('lkjlkj'),('lklklk'),('ll123456'),('llama'),('llama1'),('llama123'),('llama2'),('llamas'),('llamas1'),('llcoolj'),('llcoolj1'),('LLE1234'),('llewellyn'),('lll'),('lll123'),('llll'),('llll.70'),('lllll'),('lllll1'),('llllll'),('llllll1'),('lllllll'),('llllllll'),('llllllllll'),('lloyd'),('lloyd1'),('lloyd123'),('lluvia'),('lm292979'),('lmao'),('lmao12'),('lmao123'),('lmapacey'),('lmfao1'),('lmfao123'),('lmnop123'),('lo'),('loaded'),('loaded1'),('loader'),('loading'),('lobito'),('lobkova.1979'),('lobo'),('lobo123'),('lobster'),('lobster1'),('loca'),('loca12'),('loca123'),('loca13'),('local1'),('localoca'),('location'),('lochness'),('lock'),('lockdown'),('lockdown1'),('locked'),('locked1'),('locker'),('locker1'),('lockhart'),('lockheed'),('lockout'),('locksmith'),('lockwood'),('loco'),('loco10'),('loco11'),('loco12'),('loco123'),('loco1234'),('loco13'),('loco22'),('loco23'),('loco69'),('locoloco'),('locomotive'),('locos1'),('locos13'),('locura'),('locust'),('locutus'),('lofasz'),('log'),('logan'),('logan01'),('logan04'),('logan05'),('logan06'),('logan07'),('logan08'),('logan09'),('logan1'),('logan10'),('logan11'),('logan12'),('logan123'),('logan13'),('logan2'),('logan21'),('logan22'),('logan23'),('logan3'),('logan4'),('logan5'),('logan6'),('logan7'),('logans'),('logcabin'),('logger'),('logic'),('logic1'),('logical'),('logical1'),('login'),('login1'),('login123'),('logistics'),('logitech'),('logitech1'),('logitech12'),('logitech123'),('logitech2'),('logmein'),('logos'),('logout'),('loh123'),('loirinha'),('lois'),('loislane'),('loka12'),('loka123'),('loka13'),('lokaloka'),('lokesh'),('loki'),('loki123'),('lokiju'),('lokillo'),('lokiloki'),('lokita'),('lokita1'),('lokita13'),('lokito'),('loklok'),('loko'),('loko12'),('loko123'),('loko13'),('lokoloko'),('lokomoko'),('lokomotiv'),('lokomotiva'),('lokoporti'),('lokote13'),('lol'),('lol000'),('lol1'),('lol100'),('lol101'),('lol111'),('lol123'),('lol123123'),('lol1234'),('lol12345'),('lol123456'),('lol123456789'),('lol123lol'),('lol1lol'),('lol321'),('lol666'),('lol999'),('lola'),('lola01'),('lola10'),('lola11'),('lola12'),('lola123'),('lola1234'),('lola13'),('lola22'),('lola23'),('lolada'),('lolade'),('lolalola'),('lolalola1'),('lolazo'),('lolcats'),('lolek'),('lolek1'),('lolek11'),('lolek123'),('loli'),('lolilol'),('lolipop'),('lolipop0'),('lolipop1'),('lolipop12'),('lolipop123'),('lolipop2'),('lolita'),('lolita1'),('lolita12'),('lolita123'),('lolitas'),('lolito'),('loll'),('loller'),('lolli'),('lollie'),('lollie1'),('lolliepop'),('lolliepop1'),('lollies'),('lollies1'),('lollip0p'),('lollipop'),('lollipop!'),('lollipop.'),('lollipop0'),('lollipop00'),('lollipop1'),('lollipop10'),('lollipop11'),('lollipop12'),('lollipop123'),('lollipop13'),('lollipop2'),('lollipop3'),('lollipop5'),('lollipop69'),('lollipop7'),('lollipop8'),('lollipop9'),('lollipops'),('lollo'),('lollol'),('lollol1'),('lollol11'),('lollol12'),('lollol123'),('lollol2'),('lollollol'),('lollollol1'),('lolly'),('lolly1'),('lolly123'),('lollypop'),('lollypop!'),('lollypop1'),('lollypop12'),('lollypop2'),('lolman'),('lolman123'),('lolnoob'),('lolo'),('lolo00'),('lolo009'),('lolo11'),('lolo12'),('lolo123'),('lolo1234'),('lolo13'),('lolo22'),('lolo90'),('lolo99'),('lolol'),('lolol1'),('lolol123'),('lololo'),('lololo1'),('lololol'),('lololol1'),('lolololo'),('lolomg'),('lolote'),('lolotte'),('lolpop'),('lolsmileyf'),('lolwut'),('lolypop'),('lolz'),('lolz123'),('lombard'),('lombardi'),('lombardo'),('lon'),('london'),('london!'),('london00'),('London01'),('london05'),('london06'),('london07'),('london08'),('london09'),('london1'),('london10'),('london11'),('london12'),('london123'),('london1234'),('london13'),('london2'),('london20'),('london2008'),('london2009'),('london2010'),('london2011'),('london2012'),('london21'),('london22'),('london23'),('london24'),('london3'),('london4'),('london44'),('london5'),('london55'),('london66'),('london7'),('london77'),('london88'),('london9'),('london99'),('londonboy'),('londoner'),('londra'),('londres'),('londyn'),('loneliness'),('lonely'),('lonely1'),('lonely2'),('lonelygirl'),('loner1'),('lonesome'),('lonestar'),('lonestar1'),('lonewolf'),('lonewolf1'),('long'),('long123'),('longbeach'),('longbeach1'),('longboard'),('longboard1'),('longbow'),('longdick'),('longdong'),('longer'),('longfellow'),('longhair'),('longhair1'),('longhorn'),('longhorn1'),('longhorns'),('longhorns1'),('longhorns2'),('longhorns3'),('longhorns7'),('longisland'),('longjohn'),('longlegs'),('longlife'),('longlive'),('longlong'),('longman'),('longshot'),('longtime'),('longview'),('longview1'),('longwood'),('lonley'),('lonley1'),('lonnie'),('lonnie1'),('lonsdale'),('lonsdale1'),('loo'),('Looby123'),('look'),('look12'),('look123'),('lookatme'),('lookatme1'),('looker'),('lookin'),('looking'),('looking1'),('looking123'),('looking2'),('looking4'),('looking4u'),('lookingforlove'),('looklook'),('lookout'),('lookout1'),('lookup'),('lool'),('looloo'),('looloo1'),('loomis'),('looney'),('looney1'),('loop'),('loop1206ssdsff'),('looper'),('looping'),('looploop'),('loopy'),('loopy1'),('looser'),('looser1'),('looser123'),('lop123'),('lop1346781'),('lopas123'),('lopata'),('lopew'),('lopez'),('lopez1'),('lopez12'),('lopez123'),('lopez13'),('lopez2'),('loplop'),('loquesea'),('loquillo'),('loquita'),('loquito'),('lor'),('lora'),('loraine'),('lord'),('lord12'),('lord123'),('lord1234'),('lordgod'),('lordik'),('lordjesus'),('lordjesus1'),('lordlord'),('lordoftherings'),('lordshiva'),('lordvader'),('loreal'),('loredana'),('lorelai'),('lorelei'),('lorella'),('loren'),('loren1'),('lorena'),('lorena1'),('lorena12'),('lorena123'),('lorene'),('lorenita'),('lorenz'),('lorenza'),('lorenzo'),('lorenzo1'),('lorenzo123'),('lorenzo2'),('loreta'),('loreto'),('loretta'),('loretta1'),('lori'),('lori123'),('loriann'),('lorie'),('lorien'),('lorik197110'),('lorikeet'),('lorin'),('loris'),('lorna'),('lorna1'),('lorraine'),('lorraine1'),('lorrie'),('los'),('losangeles'),('losenord'),('loser'),('loser!'),('loser.'),('loser0'),('loser00'),('loser01'),('loser07'),('loser08'),('loser09'),('loser1'),('loser10'),('loser101'),('loser11'),('loser12'),('loser123'),('loser1234'),('loser12345'),('loser13'),('loser14'),('loser15'),('loser16'),('loser17'),('loser2'),('loser21'),('loser22'),('loser23'),('loser24'),('loser3'),('loser4'),('loser44'),('loser45'),('loser4life'),('loser5'),('loser55'),('loser6'),('loser69'),('loser7'),('loser8'),('loser9'),('loser99'),('loserface'),('loserface1'),('losers'),('losers1'),('losers2'),('loshara'),('lost'),('lost12'),('lost123'),('lost4815162342'),('lost4ever'),('lostlove'),('lostlove1'),('lostsoul'),('lostsoul1'),('lothar'),('lothlorien'),('lotion'),('lotion1'),('lotlot'),('lotte'),('lottery'),('lottery1'),('lottie'),('lottie1'),('lotto'),('lotus'),('lotus1'),('lotus123'),('lotus7'),('lotusnotes'),('lou'),('lou123'),('louane'),('louann'),('louanne'),('loubna'),('loudog'),('louie'),('louie1'),('louie123'),('louie2'),('louis'),('louis1'),('louis12'),('louis123'),('Louis12345'),('louis14'),('louis2'),('louisa'),('louisa1'),('louise'),('louise!'),('louise01'),('louise1'),('louise11'),('louise12'),('louise123'),('louise13'),('louise14'),('louise2'),('louise21'),('louise22'),('louise23'),('louise3'),('louise7'),('louisiana'),('louisiana1'),('louisville'),('louisvuitton'),('loulou'),('loulou1'),('loulou12'),('loulou123'),('loulou2'),('loulou22'),('louloute'),('louloutte'),('louna'),('lounge'),('lourdes'),('lourdes1'),('lov'),('lov3ly'),('lov3m3'),('lovable'),('lovable1'),('love'),('love!!'),('love#1'),('love&hate'),('love&lt'),('love&lt:3'),('love..'),('love00'),('love000'),('love001'),('love007'),('love01'),('love02'),('love03'),('love04'),('love05'),('love06'),('love07'),('love08'),('love09'),('love1'),('love10'),('love100'),('love1004'),('love101'),('love1010'),('love102'),('love11'),('love111'),('love1111'),('love112'),('love12'),('love121'),('love1212'),('love123'),('love1234'),('love12345'),('love123456'),('love123456789'),('love13'),('love1313'),('love1314'),('love14'),('love143'),('love15'),('love16'),('love17'),('love18'),('love19'),('love1980'),('love1981'),('love1982'),('love1983'),('love1984'),('love1985'),('love1986'),('love1987'),('love1988'),('love1989'),('love1990'),('love1991'),('love1992'),('love1993'),('love1994'),('love1995'),('love1996'),('love1997'),('love1998'),('love1999'),('love1god'),('love1love'),('love2'),('love20'),('love200'),('love2000'),('love2001'),('love2002'),('love2003'),('love2004'),('love2005'),('love2006'),('love2007'),('love2008'),('love2009'),('love2010'),('love2011'),('love2012'),('love2013'),('love209'),('love21'),('love210'),('love213'),('love214'),('love22'),('love222'),('love23'),('love234'),('love24'),('love247'),('love25'),('love26'),('love27'),('love28'),('love29'),('love2dance'),('love2fuck'),('love2hate'),('love2live'),('love2love'),('love2me'),('love2shop'),('love2sing'),('love2u'),('love2you'),('love30'),('love31'),('love32'),('love321'),('love33'),('love333'),('love34'),('love345'),('love35'),('love36'),('love37'),('love38'),('love40'),('love41'),('love411'),('love42'),('love420'),('love43'),('love44'),('love444'),('love45'),('love456'),('love46'),('love47'),('love48'),('love4all'),('love4eva'),('love4ever'),('love4ever1'),('love4god'),('love4him'),('love4life'),('love4love'),('love4me'),('love4real'),('love4u'),('love4you'),('love50'),('love52'),('love520'),('love54'),('love55'),('love555'),('love56'),('love5683'),('love57'),('love63'),('love64'),('love65'),('love66'),('love666'),('love67'),('love68'),('love69'),('love6969'),('love72'),('love73'),('love74'),('love75'),('love76'),('love77'),('love777'),('love777321777'),('love7777'),('love78'),('love789'),('love79'),('love80'),('love81'),('love82'),('love83'),('love831'),('love84'),('love85'),('love86'),('love87'),('love88'),('love888'),('love89'),('love90'),('love900'),('love91'),('love911'),('love92'),('love93'),('love94'),('love95'),('love96'),('love97'),('love98'),('love99'),('love999'),('love<3'),('loveable'),('loveable1'),('loveable2'),('loveall'),('lovealways'),('loveandhate'),('loveandpeace'),('loveangel'),('loveangel1'),('lovebaby'),('lovebaby1'),('lovebird'),('lovebird1'),('lovebirds'),('lovebirds1'),('lovebites'),('loveboat'),('loveboy'),('lovebug'),('lovebug!'),('lovebug1'),('lovebug10'),('lovebug101'),('lovebug11'),('lovebug12'),('lovebug123'),('lovebug13'),('lovebug2'),('lovebug22'),('lovebug3'),('lovebug4'),('lovebug5'),('lovebug69'),('lovebug7'),('lovebugs'),('lovebunny'),('lovecats'),('lovechild'),('lovechild1'),('lovecraft'),('loved'),('loved1'),('lovedad'),('loveday'),('lovedetoi'),('lovedove'),('lovee'),('lovee1'),('loveee'),('loveel'),('lovefamily'),('loveforeve'),('loveforever'),('lovegame'),('lovegirl'),('lovegirl1'),('lovegod'),('lovegod1'),('loveguru'),('lovehate'),('lovehate1'),('loveheart'),('loveher'),('loveher1'),('lovehim'),('lovehim1'),('lovehim2'),('lovehina'),('lovehina1'),('lovehurt'),('lovehurts'),('lovehurts!'),('lovehurts1'),('lovehurts2'),('lovehurts3'),('loveindia'),('loveing'),('loveis'),('loveis1'),('loveisall'),('loveisblin'),('loveisblind'),('loveisgod'),('loveisgood'),('loveislife'),('loveislove'),('loveispain'),('loveisreal'),('loveit'),('loveit1'),('loveit2'),('lovejesus'),('lovejesus1'),('lovejones'),('lovejoy'),('lovejoy1'),('lovekids'),('lovekills'),('lovekills1'),('lovekiss'),('lovekita'),('loveko'),('lovekoto'),('lovelace'),('loveland'),('loveless'),('loveless1'),('lovelife'),('lovelife!'),('lovelife1'),('lovelife12'),('lovelife2'),('lovelife3'),('lovelife7'),('loveline'),('lovell'),('lovelost'),('lovelove'),('lovelove!'),('lovelove1'),('lovelove12'),('lovelove123'),('lovelove2'),('lovelove3'),('lovelove7'),('lovelovelo'),('lovelovelove'),('lovely'),('lovely!'),('lovely.'),('lovely01'),('lovely07'),('lovely08'),('lovely09'),('lovely1'),('lovely10'),('lovely101'),('lovely11'),('lovely12'),('lovely123'),('lovely1234'),('lovely13'),('lovely14'),('lovely15'),('lovely16'),('lovely17'),('lovely18'),('lovely19'),('lovely2'),('lovely20'),('lovely21'),('lovely22'),('lovely23'),('lovely24'),('lovely25'),('lovely3'),('lovely4'),('lovely5'),('lovely6'),('lovely69'),('lovely7'),('lovely77'),('lovely8'),('lovely88'),('lovely9'),('lovelyboy'),('lovelyday'),('lovelygirl'),('lovelylady'),('lovelyme'),('lovelyn'),('lovem3'),('lovemama'),('loveman'),('loveme'),('loveme!'),('loveme.'),('loveme0'),('loveme01'),('loveme07'),('loveme08'),('loveme09'),('loveme1'),('loveme10'),('loveme101'),('loveme11'),('loveme12'),('loveme123'),('loveme1234'),('loveme13'),('loveme14'),('loveme143'),('loveme15'),('loveme16'),('loveme17'),('loveme18'),('loveme19'),('loveme2'),('loveme20'),('loveme21'),('loveme22'),('loveme23'),('loveme24'),('loveme25'),('loveme3'),('loveme33'),('loveme4'),('loveme4eva'),('loveme4eve'),('loveme4ever'),('loveme4me'),('loveme5'),('loveme6'),('loveme69'),('loveme7'),('loveme77'),('loveme8'),('loveme88'),('loveme89'),('loveme9'),('loveme99'),('lovemebaby'),('lovemedo'),('lovemenot'),('lovemenow'),('lovemom'),('lovemom1'),('lovemoney'),('lovemonkey'),('lovemusic'),('lovemusic1'),('lovemy'),('lovemybaby'),('lovemykids'),('lovemylife'),('lovemyself'),('loveno1'),('loveone'),('loveone1'),('lovepeace'),('lovepeace1'),('lovepink'),('lovepink1'),('lovepussy'),('lovepussy1'),('lover'),('lover!'),('lover#1'),('lover.'),('lover01'),('lover06'),('lover07'),('lover08'),('lover09'),('lover1'),('lover10'),('lover101'),('lover11'),('lover12'),('lover123'),('lover1234'),('lover12345'),('lover13'),('lover14'),('lover15'),('lover16'),('lover17'),('lover18'),('lover19'),('lover2'),('lover20'),('lover21'),('lover22'),('lover23'),('lover24'),('lover25'),('lover3'),('lover33'),('lover34'),('lover4'),('lover44'),('lover45'),('lover4ever'),('lover4life'),('lover5'),('lover55'),('lover56'),('lover6'),('lover69'),('lover7'),('lover77'),('lover8'),('lover88'),('lover89'),('lover9'),('lover99'),('loverboy'),('loverboy1'),('loverboy12'),('loverboy2'),('loverboy3'),('loverboy69'),('loverboy7'),('lovergirl'),('lovergirl1'),('lovergirl2'),('lovergurl'),('lovergurl1'),('loverlover'),('loverman'),('loverman1'),('lovers'),('lovers!'),('lovers.'),('lovers01'),('lovers07'),('lovers08'),('lovers09'),('lovers1'),('lovers10'),('lovers101'),('lovers11'),('lovers12'),('lovers123'),('lovers13'),('lovers14'),('lovers2'),('lovers21'),('lovers22'),('lovers23'),('lovers3'),('lovers4'),('lovers4eve'),('lovers5'),('lovers6'),('lovers69'),('lovers7'),('lovers8'),('lovers9'),('loverz'),('loverz1'),('loves'),('loves1'),('loves123'),('loves2'),('lovesex'),('lovesex1'),('lovesex69'),('lovesexy'),('lovesick'),('lovesick1'),('lovesit1'),('lovesloves'),('lovesong'),('lovespell'),('lovespell1'),('lovess'),('lovestar'),('lovestinks'),('lovestory'),('lovestory1'),('lovestruck'),('lovesu'),('lovesucks'),('lovesucks!'),('lovesucks1'),('lovesucks2'),('lovesux'),('lovesux1'),('lovesyou'),('loveth'),('loveu'),('loveu!'),('loveu1'),('loveu12'),('loveu123'),('loveu13'),('loveu2'),('loveu3'),('loveu4'),('loveu4ever'),('loveu7'),('loveumom'),('loveworld'),('lovex3'),('lovey'),('lovey1'),('loveya'),('loveya!'),('loveya1'),('loveya12'),('loveya123'),('loveya2'),('loveydovey'),('loveyou'),('loveyou!'),('loveyou.'),('loveyou01'),('loveyou08'),('loveyou09'),('loveyou1'),('loveyou10'),('loveyou11'),('loveyou12'),('loveyou123'),('loveyou13'),('loveyou14'),('loveyou143'),('loveyou15'),('loveyou2'),('loveyou21'),('loveyou22'),('loveyou23'),('loveyou3'),('loveyou4'),('loveyou5'),('loveyou6'),('loveyou69'),('loveyou7'),('loveyou8'),('loveyou9'),('loveyu'),('love_me'),('love_you'),('lovie1'),('lovin1'),('loving'),('loving1'),('loving12'),('loving123'),('loving2'),('lovinglife'),('lovingme'),('lovingu'),('lovingyou'),('lovingyou1'),('lovinit'),('lovinlife'),('lovinlife1'),('lowell'),('lowell1'),('lowes48'),('lowlife'),('lowlife1'),('lowlow'),('lowrider'),('lowrider1'),('lowrider13'),('loxlox'),('loxpider'),('loyal1'),('loyalty'),('loyalty1'),('loyola'),('lozano'),('lozer1'),('lozinka'),('lozinka1'),('lp123456'),('lpl'),('lplplp'),('LPPnLdTZX'),('lpz93sssKqw8Q'),('LqFg4HWt'),('lssy123'),('lsu123'),('lsutigers'),('lsutigers1'),('ltdjxrf'),('lthgfhjkm'),('lthmvj'),('lthtdj'),('lthtdyz'),('ltkmaby'),('ltleirf'),('ltr450'),('ltybc'),('ltybcrf'),('ltybcrj1992'),('ltymub'),('ltz400'),('luana'),('luanda'),('luansantana'),('lubasha'),('lubimaya'),('luc'),('luca'),('lucaluca'),('lucario'),('lucas'),('lucas01'),('lucas1'),('lucas10'),('lucas11'),('lucas12'),('lucas123'),('lucas1234'),('lucas13'),('lucas2'),('lucas22'),('lucas23'),('lucas3'),('lucas5'),('lucass'),('lucatoni'),('lucerito'),('lucero'),('lucero1'),('lucette'),('luchino'),('luchito'),('lucia'),('lucia1'),('lucia123'),('lucian'),('luciana'),('luciana1'),('luciano'),('luciano1'),('lucie'),('lucie1'),('lucien'),('lucienne'),('lucifer'),('lucifer1'),('lucifer6'),('lucifer666'),('lucifero'),('lucila'),('lucile'),('lucilla'),('lucille'),('lucille1'),('lucinda'),('lucinda1'),('lucinka'),('lucio'),('luciole'),('lucious1'),('lucius'),('luck'),('lucka'),('luckey'),('luckey1'),('luckie'),('luckie1'),('luckies'),('lucknow'),('lucky'),('lucky!'),('lucky#7'),('lucky007'),('lucky01'),('lucky02'),('lucky05'),('lucky06'),('lucky07'),('lucky08'),('lucky09'),('lucky1'),('lucky10'),('lucky100'),('lucky101'),('lucky11'),('lucky111'),('lucky12'),('lucky123'),('lucky1234'),('lucky13'),('lucky14'),('lucky15'),('lucky16'),('lucky17'),('lucky18'),('lucky19'),('lucky2'),('lucky20'),('lucky21'),('lucky22'),('lucky23'),('lucky24'),('lucky25'),('lucky26'),('lucky27'),('lucky3'),('lucky33'),('lucky4'),('lucky44'),('lucky4me'),('lucky5'),('lucky6'),('lucky69'),('lucky7'),('lucky77'),('lucky777'),('lucky8'),('lucky88'),('lucky888'),('lucky9'),('lucky99'),('luckyboy'),('luckyboy1'),('luckycat'),('luckycharm'),('luckydog'),('luckydog1'),('luckyduck'),('luckygirl'),('luckygirl1'),('luckylady'),('luckylucky'),('luckyluke'),('luckyman'),('luckyme'),('luckyme1'),('luckyone'),('luckyone1'),('luckys'),('luckys1'),('luckystar'),('luckystar1'),('luckystrike'),('luckyy'),('lucozade'),('lucrecia'),('lucretia'),('lucrezia'),('lucy'),('lucy01'),('lucy07'),('lucy08'),('lucy10'),('lucy101'),('lucy11'),('lucy12'),('lucy123'),('lucy1234'),('lucy13'),('lucy14'),('lucy22'),('lucy23'),('lucycat'),('lucydog'),('lucydog1'),('lucygirl'),('lucylou'),('lucylou1'),('lucylu'),('lucylu1'),('lucylucy'),('luda'),('ludacris'),('ludacris1'),('ludhiana'),('ludi1234'),('ludivine'),('ludmila'),('ludmilla'),('ludovic'),('ludovica'),('ludovico'),('ludwig'),('ludwig1'),('lufthansa'),('lugano'),('luglio'),('lugnut'),('luigi'),('luigi1'),('luigi123'),('luis'),('luis01'),('luis10'),('luis11'),('luis12'),('luis123'),('luis1234'),('luis123456'),('luis13'),('luis14'),('luis15'),('luis16'),('luis17'),('luis18'),('luis19'),('luis20'),('luis21'),('luis22'),('luis23'),('luis24'),('luis69'),('luisa'),('luisa1'),('luisa123'),('luisalberto'),('luisangel'),('luiscarlos'),('luisfigo'),('luisito'),('luisito1'),('luisluis'),('luismi'),('luismiguel'),('luisteamo'),('luiza'),('luk'),('luka'),('lukaluka'),('lukas'),('lukas1'),('lukas123'),('lukasek'),('lukasz'),('lukasz1'),('lukasz12'),('lukaszek'),('luke'),('luke01'),('luke11'),('luke12'),('luke123'),('luke1234'),('luke13'),('luke22'),('lukeluke'),('lukinhas'),('lukino'),('lukman'),('lulita'),('lullaby'),('lulu'),('lulu01'),('lulu10'),('lulu11'),('lulu12'),('lulu123'),('lulu1234'),('lulu13'),('lulu22'),('lulu889jdddd'),('lulubell'),('lulubelle'),('lululu'),('lululu1'),('lulululu'),('luluzinha'),('lumber'),('lumber1'),('lumberjack'),('lumiere'),('lumina'),('luminita'),('lumpy1'),('lun'),('luna'),('luna01'),('luna10'),('luna11'),('luna12'),('luna123'),('luna1234'),('luna13'),('luna22'),('lunallena'),('lunaluna'),('lunanueva'),('lunar'),('lunarossa'),('lunatic'),('lunatic1'),('lunatica'),('lunatik'),('lunch'),('lunchbox'),('lunchbox1'),('lunetta'),('lunette'),('lunita'),('luntik'),('lupashku89'),('lupe12'),('lupe123'),('lupe13'),('lupetto'),('lupin'),('lupin3'),('lupita'),('lupita1'),('lupita12'),('lupita123'),('lupita13'),('luqman'),('lurdes'),('luscious'),('luscious1'),('lust'),('luther'),('luther1'),('lutheran'),('luthien'),('lutscher'),('luv'),('luv123'),('luv2dance'),('luv2fish'),('luv2luv'),('luv2shop'),('luv2sing'),('luv4eva'),('luv4ever'),('luv4life'),('luv4me'),('luvbug'),('luvbug1'),('luver1'),('luvluv'),('luvme'),('luvme1'),('luvme2'),('luvu4eva'),('luvu4ever'),('luvya'),('luvya1'),('luvya2'),('luvyou'),('luxeon'),('luxury'),('luzifer'),('luzmaria'),('lvbnhbq'),('lvbnhbtdf'),('Lwf1681688'),('lwxlwx'),('lxgiwyl'),('lyalya'),('lydcc20091314'),('lydia'),('lydia1'),('lydia123'),('lynda'),('lynda1'),('lyndon'),('lyndsay'),('lyndsey'),('lyndsey1'),('lynette'),('lynette1'),('lynlyn'),('lynn'),('lynn01'),('lynn07'),('lynn08'),('lynn09'),('lynn10'),('lynn11'),('lynn12'),('lynn123'),('lynn1234'),('lynn13'),('lynn14'),('lynn15'),('lynn16'),('lynn21'),('lynn22'),('lynn23'),('lynn69'),('lynne'),('lynne1'),('lynnette'),('lynnette1'),('lynnie'),('lynnlynn'),('lynsey'),('lynwood1'),('lyon69'),('lyonnais'),('lyric1'),('lyrical1'),('lyrics'),('lytdybr'),('lyts123'),('lytWa813iB'),('lyubov'),('lyudmila'),('lyva84'),('lz110110'),('Lzhan16889'),('LztEz2xe98'),('LzuDz2xe98'),('m'),('m00000'),('m000000'),('m00m00'),('m00nlight'),('M01759766727'),('m0nk3y'),('m0nkey'),('m0nst3r'),('m0nster'),('m0rgan'),('m0t0r0la'),('m0ther'),('m11111'),('m111111'),('m121212'),('m123098'),('m123123'),('m123321'),('m12345'),('m123456'),('m1234567'),('m12345678'),('m123456789'),('m123456m'),('m1911a1'),('m1am1b3ach'),('m1ch3ll3'),('m1cha3l'),('m1chael'),('m1chelle'),('M1chp00h'),('m1ckey'),('m1dn1ght'),('m1garand'),('m1i2k3e4'),('m1m1m1'),('m1m2m3'),('m1m2m3m4'),('m1m2m3m4m5'),('m1space'),('m1ul9x9i20'),('m2g7U6O397'),('m2YdEgkDws'),('m3lissa'),('m3tallica'),('m3xico'),('m55555'),('m654321'),('m666666'),('m696969'),('m7777777'),('m8a8vHr6'),('m987654321'),('m@d!z'),('ma'),('ma123123123'),('ma1234'),('ma12345'),('ma123456'),('maadurga'),('maarten'),('mabait'),('mabel'),('mabel1'),('mabelle'),('mabuhay'),('Maburro'),('mac'),('mac123'),('macaco'),('macarena'),('macario'),('macaroni'),('macaroni1'),('macbeth'),('macbeth1'),('macbook'),('macbook1'),('macbookpro'),('macca1'),('macchia'),('macchina'),('macdaddy'),('macdaddy1'),('macdonald'),('macdre'),('macdre1'),('macduff'),('macedonia'),('macegorova.mariya'),('macey1'),('macgyver'),('machado'),('macherie'),('machete'),('machin'),('machina'),('machine'),('machine1'),('machines'),('machines1'),('macho'),('macho01'),('macho1'),('macho123'),('machoman'),('machoman1'),('machukreeva'),('machupichu'),('macias'),('macie1'),('maciej'),('maciek'),('maciek06'),('maciek1'),('maciek123'),('macika'),('macintosh'),('macintosh1'),('mack'),('mack10'),('mack11'),('mack12'),('mack123'),('mackay'),('mackdaddy'),('mackdaddy1'),('mackenzie'),('mackenzie1'),('mackenzie2'),('mackey'),('mackie'),('mackie1'),('macky'),('macleod'),('macmac'),('macmac1'),('macman'),('macondo'),('maconha'),('macross'),('macska'),('macy'),('mad'),('mad123'),('mad1son'),('madafaka'),('madagascar'),('madagaskar'),('madalena'),('madalin'),('madalina'),('madalyn'),('madame'),('madara'),('madarchod'),('madcat'),('madcow'),('madcow1'),('maddalena'),('madden'),('madden06'),('madden07'),('madden08'),('madden09'),('madden1'),('madden10'),('madden11'),('madden12'),('maddi1'),('maddie'),('maddie!'),('maddie01'),('maddie05'),('maddie06'),('maddie07'),('maddie08'),('maddie09'),('maddie1'),('maddie10'),('maddie11'),('maddie12'),('maddie123'),('maddie13'),('maddie2'),('maddie22'),('maddie3'),('maddie4'),('maddie5'),('maddie7'),('maddison'),('maddison1'),('maddog'),('maddog1'),('maddog11'),('maddog12'),('maddog123'),('maddog2'),('maddog2020'),('maddog69'),('maddox'),('maddox1'),('maddux'),('maddux31'),('maddy'),('maddy1'),('maddy12'),('maddy123'),('maddy2'),('madeinchina'),('madeira'),('madelaine'),('madeleine'),('madeleine1'),('madeline'),('madeline1'),('madelyn'),('madelyn1'),('madera'),('madhatter'),('madhatter1'),('madhav'),('madhavan'),('madhavi'),('madhouse'),('madhouse1'),('madhu'),('madhu123'),('madhukar'),('madhumita'),('madhura'),('madhuri'),('madi'),('madiha'),('madina'),('madinina'),('madinina972'),('madison'),('madison!'),('madison.'),('madison01'),('madison02'),('madison03'),('madison04'),('madison05'),('madison06'),('madison07'),('madison08'),('madison09'),('madison1'),('madison10'),('madison11'),('madison12'),('madison123'),('madison13'),('madison14'),('madison2'),('madison200'),('madison21'),('madison22'),('madison23'),('madison3'),('madison4'),('madison5'),('madison6'),('madison7'),('madison8'),('madison9'),('madison99'),('madisyn'),('madisyn1'),('madlen'),('madmad'),('madman'),('madman1'),('madman123'),('madmax'),('madmax1'),('madness'),('madness1'),('madness7'),('madoka'),('madona'),('madonna'),('madonna1'),('Madonna12'),('madonna2'),('madras'),('madremia'),('madrid'),('madrid1'),('madrid10'),('madrigal'),('madryt'),('madsen'),('madtubes'),('madura'),('madurai'),('madyson'),('madyson1'),('madzia'),('madzia1'),('mae'),('mae123'),('maegan'),('maella1311'),('maelle'),('maelys'),('maemae'),('maemae1'),('maestra'),('maestro'),('maestro1'),('maeteamo'),('maeva'),('mafalda'),('mafalda1'),('maffia'),('mafia'),('mafia1'),('mafia123'),('mafia13'),('mafia2'),('mafiawars'),('mafiawars1'),('mafille'),('mafioso'),('mag'),('mag123'),('magadan'),('magali'),('magalie'),('magallanes'),('magaly'),('maganda'),('maganda1'),('magandaako'),('magazin'),('magazine'),('magazine1'),('magda'),('magda1'),('magda123'),('magdalena'),('magdalena1'),('magdalene'),('magdalo'),('magdeburg'),('magelang'),('magellan'),('magenta'),('magenta1'),('maggie'),('maggie!'),('maggie.'),('maggie00'),('maggie01'),('maggie02'),('maggie03'),('maggie04'),('maggie05'),('maggie06'),('maggie07'),('maggie08'),('maggie09'),('maggie1'),('maggie10'),('maggie101'),('maggie11'),('maggie12'),('maggie123'),('maggie1234'),('maggie13'),('maggie14'),('maggie15'),('maggie16'),('maggie17'),('maggie18'),('maggie2'),('maggie21'),('maggie22'),('maggie23'),('maggie24'),('maggie25'),('maggie3'),('maggie33'),('maggie4'),('maggie5'),('maggie55'),('maggie6'),('maggie69'),('maggie7'),('maggie77'),('maggie8'),('maggie88'),('maggie9'),('maggie99'),('maggiedog'),('maggiemae'),('maggiemae1'),('maggiemay'),('maggiemay1'),('maggio'),('maggot'),('maggot1'),('maggot666'),('maggy'),('maggy1'),('magic'),('magic-n12'),('magic01'),('magic1'),('magic10'),('magic101'),('magic11'),('magic12'),('magic123'),('magic13'),('magic2'),('magic21'),('magic22'),('magic23'),('magic3'),('magic32'),('magic5'),('magic6'),('magic69'),('magic7'),('magic8'),('magic9'),('magica'),('magical'),('magical1'),('magicaroma'),('magician'),('magician1'),('magick'),('magick1'),('magicman'),('magicman1'),('magico'),('magics'),('magique'),('magister'),('magistr'),('magiya'),('magma9824660'),('magnat'),('magnavox'),('magnet'),('magnet1'),('magnetic'),('magneto'),('magnifico'),('magno07'),('magno456'),('magnolia'),('magnolia1'),('magnum'),('magnum1'),('magnum357'),('magnum44'),('magnus'),('magnus1'),('magodeoz'),('magodeoz1'),('magomed'),('magoo'),('magoo1'),('magpie'),('magpie1'),('magpies'),('magpies1'),('maguire'),('magyar'),('mah'),('maha'),('mahadev'),('mahal'),('mahal1'),('mahalakshmi'),('mahalaxmi'),('mahalcoh'),('mahalkita'),('mahalkita1'),('mahalkita2'),('mahalko'),('mahalko1'),('mahalkoh'),('mahalo'),('mahalq'),('mahalqoh'),('maharaj'),('maharaja'),('maharani'),('maharashtra'),('maharot'),('mahatma'),('mahaveer'),('mahavir'),('mahendra'),('mahesh'),('mahesh123'),('mahima'),('mahimahi'),('mahina'),('mahindra'),('mahler'),('mahmood'),('mahmoud'),('mahmoud1'),('mahmud'),('mahmudali1987'),('mahmut'),('mahnoor'),('mahogany'),('mahoney'),('mahusay'),('mai'),('mai123'),('maiale'),('maianbinh'),('maicol'),('maiden'),('maiden1'),('maiden666'),('maik1996'),('maika2006'),('maikel'),('mail'),('mail.ru'),('mail123'),('mailbox'),('mailbox1'),('mailkuliev'),('mailliw'),('mailmail'),('mailman'),('mailman1'),('mailme'),('mailru'),('maimai'),('maimaiyeuem'),('maimouna'),('maimuna'),('maimuta'),('main'),('maine'),('maine1'),('mainman'),('mainstream'),('mainstreet'),('maint'),('maintain'),('maintenance'),('mainz05'),('maisie'),('maisie1'),('maison'),('maison1'),('maitai'),('maitland571ka1994'),('maitre'),('maiyeu'),('maiyeuem'),('maja'),('majeczka'),('majeed'),('majestic'),('majestic1'),('majestic12'),('majesty'),('majesty1'),('majiajun'),('majiajun8888'),('majka'),('majmun'),('major'),('major1'),('major123'),('mak'),('mak123'),('mak301988'),('makaka'),('makana'),('makanan'),('makarena'),('makarenko'),('makaron'),('makaroni'),('makarov'),('makarova'),('makassar'),('makati'),('makaveli'),('makaveli1'),('makaveli7'),('makavelli'),('makayla'),('makayla1'),('makayla2'),('makayla3'),('makayla5'),('makcim'),('make'),('makedonija'),('makeit'),('makeitso'),('makelove'),('makeme'),('makeme1'),('makemoney'),('makemoney1'),('makemyday'),('makena'),('makenna'),('makenna1'),('makenzie'),('makenzie1'),('makeup'),('makeup1'),('makimaki'),('makina'),('making'),('makita'),('makmak'),('makoto'),('maks'),('maks.abramov.99.99'),('maks123'),('maksat'),('maksik'),('maksim'),('maksim.bychkov.1986'),('maksim1'),('maksim123'),('maksim2425'),('maksimilian_nasirov'),('maksimka'),('maksimka876'),('maksimov'),('maksimus'),('maksmaks'),('maksus_2003'),('maktub'),('makulet'),('makulit'),('mal'),('mal123'),('mala'),('malabar'),('malachi'),('malachi1'),('malachi2'),('malacka'),('malade'),('malaga'),('malagu'),('malaguti'),('malaika'),('malaikat'),('malaka'),('malaka1'),('malakai'),('malakai1'),('malakas'),('malakas1'),('malaki'),('malala'),('malamute'),('malandi'),('malang'),('malaria'),('malathi'),('malatya'),('malatya44'),('malawi'),('malaya'),('malayalam'),('malaysia'),('malaysia1'),('malboro'),('malboro1'),('malcolm'),('malcolm1'),('malcolmx'),('malcom'),('malcom1'),('maldini'),('maldini3'),('maldita'),('maldita1'),('malditah'),('maldito'),('maldives'),('maldonado'),('maldonado1'),('malena'),('malena1'),('malenka'),('malfoy'),('malgorzata'),('malgosia'),('malhotra'),('malhotra493ozzy1991282151'),('mali'),('malia1'),('malibog'),('malibu'),('malibu1'),('malibu2'),('malice'),('malice1'),('malick'),('malik'),('malik1'),('malik12'),('malik123'),('malik2'),('malika'),('malika1'),('malin'),('malina'),('malina1'),('malina_bratsk'),('malinda'),('malini'),('malinka'),('malish'),('malishka'),('malkin71'),('mallard'),('mallard1'),('mallari'),('mallika'),('mallorca'),('mallorca1'),('mallory'),('mallory1'),('mallow'),('mallrats'),('malmal'),('malmsteen'),('malone'),('malone1'),('maloney'),('malossi'),('malou'),('malta'),('maltese'),('maltese1'),('maluca'),('maluco'),('malutka'),('malvern'),('malvina'),('malysh'),('malyshka'),('mam'),('mam123'),('mama'),('mama00'),('mama01'),('mama07'),('mama08'),('mama09'),('mama1'),('mama10'),('mama11'),('mama111'),('mama12'),('mama123'),('mama1234'),('mama12345'),('mama123456'),('mama13'),('mama14'),('mama15'),('mama16'),('mama17'),('mama18'),('mama19'),('mama1960'),('mama1961'),('mama1963'),('mama1964'),('mama1970'),('mama1995'),('mama1997'),('mama20'),('mama2000'),('mama2008'),('mama2009'),('mama2010'),('mama2011'),('mama21'),('mama22'),('mama23'),('mama24'),('mama25'),('mama33'),('mama45'),('mama55'),('mama69'),('mama77'),('mama777'),('mama88'),('mama99'),('mamababa'),('mamabear'),('mamabear1'),('mamacita'),('mamacita1'),('mamadou'),('mamaia'),('mamako'),('mamaku'),('mamaliga'),('mamalove'),('mamama'),('mamama1'),('mamamama'),('mamamama1'),('mamamary'),('mamamia'),('mamamia1'),('maman'),('maman1'),('maman123'),('mamana'),('mamang'),('mamani'),('mamanjetaime'),('mamanjtm'),('mamanpapa'),('mamans'),('mamapapa'),('mamapapa1'),('mamapapa123'),('mamas1'),('mamasboy'),('mamasboy1'),('mamasgirl1'),('mamasha'),('mamasita'),('mamasita1'),('mamata'),('mamatata'),('mamateamo'),('mamatha'),('mamaypapa'),('mambo'),('mambo1'),('mambo5'),('mamedov'),('mamere'),('mami'),('mami12'),('mami123'),('mamica'),('mamichula1'),('mamie'),('Mamika10'),('mamikawada'),('mamimami'),('mamina'),('maminka'),('mamipapi'),('mamita'),('mamita1'),('mamka'),('mamma'),('mamma1'),('mamma123'),('mammam'),('mammamia'),('mammamia1'),('mammas'),('mammina'),('mammoth'),('mammoth1'),('mamo4ka'),('mamochka'),('mamont'),('mamoune'),('mamounette'),('mamour'),('mamuka'),('mamula'),('mamulya'),('mamusia'),('mamusia1'),('mam_p'),('man'),('man111'),('man123'),('man1234'),('man12345'),('man123456'),('man2man'),('man55580'),('mana'),('manage'),('management'),('manager'),('manager1'),('managua'),('manali'),('manalo'),('manamana'),('manana'),('manasa'),('manasi'),('manatee'),('manatee1'),('manboy'),('mancha'),('manchas'),('manchester'),('manchester1'),('manchester123'),('manchesterunited'),('manchita'),('manchitas'),('mancini'),('mancity'),('mancity1'),('manda'),('manda1'),('manda123'),('mandala'),('mandalay'),('mandar'),('mandarin'),('mandarina'),('mandarine'),('mandarinka'),('mandarino'),('mandds1mg6bv8re'),('mandee'),('mandeep'),('mandela'),('mandi'),('mandi1'),('mandie'),('mandie1'),('mandingo'),('mandingo1'),('mando1'),('mandolin'),('mandragora'),('mandrake'),('mandy'),('mandy01'),('mandy1'),('mandy11'),('mandy12'),('mandy123'),('mandy13'),('mandy2'),('maneater'),('maneater1'),('manfred'),('manfred1'),('manga'),('manga1'),('manga123'),('mangal'),('mangala'),('mangalore'),('mangas'),('manger'),('mangesh'),('mango'),('mango1'),('mango12'),('mango123'),('mango2'),('mango5'),('mangoes'),('mangos'),('mangos1'),('mangusta'),('manhater'),('manhattan'),('manhattan1'),('manhunt'),('mani'),('mani123'),('mania'),('maniac'),('maniac1'),('maniak'),('maniek'),('maniez'),('manifest'),('manika'),('manikandan'),('manila'),('manila1'),('manilyn'),('manimani'),('manin-d'),('manina'),('manis'),('manish'),('manish123'),('manisha'),('manita'),('manitoba'),('manitou'),('manjit'),('manju'),('manju123'),('manjula'),('manjunath'),('manjusha'),('manka198707'),('mankind'),('mankind1'),('manman'),('manman1'),('manman11'),('manman12'),('manman123'),('manman2'),('manman3'),('manmanman'),('manmohan'),('mann'),('manner'),('mannheim'),('mannie'),('mannie1'),('manning'),('manning1'),('manning10'),('manning18'),('manny'),('manny1'),('manny12'),('manny123'),('manny13'),('manny2'),('manny24'),('mano'),('manofgod'),('manofsteel'),('manohar'),('manoj'),('manoj123'),('manojkumar'),('manoka'),('manola'),('manolete'),('manolito'),('manolo'),('manolo1'),('manomano'),('manon'),('manorama'),('manouche'),('manovitskaya'),('manowar'),('manowar1'),('manpower'),('manpreet'),('mansfield'),('mansfield1'),('mansion'),('manson'),('manson1'),('manson6'),('manson666'),('manson69'),('mansoor'),('mansour'),('mansur'),('mantap'),('mantas'),('mantha'),('mantis'),('mantis1'),('mantle'),('mantle7'),('mantra'),('manu'),('manu11'),('manu12'),('manu123'),('manu1234'),('manu4eva'),('manu4life'),('manual'),('manuel'),('manuel.'),('manuel01'),('manuel1'),('manuel10'),('manuel11'),('manuel12'),('manuel123'),('manuel13'),('manuel14'),('manuel15'),('manuel18'),('manuel2'),('manuel21'),('manuel22'),('manuel23'),('manuel3'),('manuel5'),('manuel7'),('manuela'),('manuela1'),('manuelita'),('manuelito'),('manuelito1'),('manuella'),('manuliktatyana'),('manumanu'),('manunited'),('manunited1'),('manunited7'),('manusia'),('manutd'),('manutd01'),('manutd07'),('manutd1'),('manutd10'),('manutd11'),('manutd12'),('manutd123'),('manutd7'),('manutd99'),('manwhore'),('manwhore1'),('manyak'),('manzana'),('manzana1'),('manzanita'),('manzano'),('maomao'),('mapache'),('mapamapa7'),('maple'),('maple1'),('maple12'),('maple123'),('mapleleaf'),('mapleleafs'),('maples'),('maplestory'),('maplewood'),('MaprCheM56458'),('mapuce'),('maquina'),('mar'),('mar123'),('mara'),('mara123'),('mara13'),('maracaibo'),('maracuja'),('maradona'),('maradona1'),('maradona10'),('marajade'),('maramara'),('maranata'),('maranatha'),('maranda'),('maranda1'),('maranello'),('marat'),('marathon'),('marathon1'),('maratik'),('maraton'),('marauder'),('maravilha'),('maravilhosa'),('maravilla'),('maravilla1'),('marbella'),('marble'),('marble1'),('marbles'),('marbles1'),('marc'),('marc12'),('marc123'),('marcel'),('marcel1'),('marcel12'),('marcel123'),('marcela'),('marcela1'),('marcelina'),('marcelino'),('marcelita'),('marcell'),('marcell1'),('marcella'),('marcella1'),('marcelle'),('marcello'),('marcello1'),('marcelo'),('marcelo1'),('marcelo123'),('march'),('march01'),('march03'),('march05'),('march06'),('march07'),('march08'),('march09'),('march1'),('march10'),('march11'),('march12'),('march123'),('march13'),('march14'),('march15'),('march16'),('march17'),('march18'),('march19'),('march1993'),('march2'),('march20'),('march2007'),('march2008'),('march2009'),('march21'),('march22'),('march23'),('march24'),('march25'),('march26'),('march27'),('march28'),('march29'),('march3'),('march30'),('march31'),('march4'),('march5'),('march6'),('march7'),('march8'),('march9'),('marche'),('marchelle27'),('marci'),('marcia'),('marcia1'),('marcial'),('marciano'),('marcie'),('marcie1'),('marcin'),('marcin1'),('marcin123'),('marcinek'),('marcio'),('marco'),('marco1'),('marco11'),('marco12'),('marco123'),('marco13'),('marco2'),('marcoantonio'),('marcolino'),('marconi'),('marcopolo'),('marcopolo1'),('marcos'),('marcos1'),('marcos10'),('marcos12'),('marcos123'),('marcos13'),('marcus'),('marcus01'),('marcus06'),('marcus07'),('marcus08'),('marcus09'),('marcus1'),('marcus10'),('marcus11'),('marcus12'),('marcus123'),('marcus13'),('marcus14'),('marcus15'),('marcus2'),('marcus21'),('marcus22'),('marcus23'),('marcus3'),('marcus4'),('marcus5'),('marcus7'),('marcus99'),('marcy'),('marcy1'),('mardan'),('mardigras'),('marduk'),('marduk666'),('mare'),('marecek'),('mareike'),('marek'),('marek1'),('marek123'),('marek14michal'),('maremare'),('maremma'),('margaret'),('margaret1'),('margareta'),('margareth'),('margarette'),('margarida'),('margarita'),('margarita1'),('margarita2'),('margaritka'),('margaux'),('marge'),('marge1'),('margera'),('margera1'),('margherita'),('margie'),('margie1'),('margit'),('margo'),('margo.emi'),('margo1'),('margosha'),('margot'),('margot1'),('margret'),('marguerite'),('marhaba'),('mari'),('mari10'),('mari11'),('mari12'),('mari123'),('mari1234'),('mari13'),('mari15'),('maria'),('maria-demidchik'),('maria-fam'),('maria.'),('maria01'),('maria05'),('maria07'),('maria08'),('maria09'),('maria1'),('maria10'),('maria11'),('maria12'),('maria123'),('maria1234'),('maria12345'),('maria13'),('maria14'),('maria15'),('maria16'),('maria17'),('maria18'),('maria19'),('maria2'),('maria20'),('maria2010'),('maria21'),('maria22'),('maria23'),('maria24'),('maria25'),('maria26'),('maria27'),('maria3'),('maria4'),('maria5'),('maria6'),('maria666'),('maria69'),('maria7'),('maria8'),('maria88'),('maria9'),('mariaa'),('mariac'),('mariachi'),('mariaclara'),('mariaeduarda'),('mariaelena'),('mariafernanda'),('mariage'),('mariagoncharenko'),('mariagrazia'),('mariah'),('mariah01'),('mariah1'),('mariah10'),('mariah11'),('mariah12'),('mariah123'),('mariah13'),('mariah2'),('mariah3'),('mariah7'),('mariahcarey'),('mariaisabel'),('mariajose'),('mariajose1'),('marialuisa'),('marialuiza'),('mariam'),('mariam1'),('mariama'),('mariamaria'),('mariami'),('marian'),('marian1'),('mariana'),('mariana1'),('mariana12'),('mariana123'),('mariana2'),('mariane'),('marianela'),('mariangela'),('marianita'),('mariann'),('marianna'),('marianna1'),('mariannaz2'),('marianne'),('marianne1'),('mariano'),('mariano1'),('mariapaula'),('mariapia'),('mariarita'),('mariarosa'),('marias'),('mariateresa'),('maria_q'),('maribel'),('maribel1'),('maribeth'),('marica'),('maricar'),('maricarmen'),('maricel'),('maricela'),('maricela1'),('maricon'),('maricon1'),('maricris'),('marie'),('marie!'),('marie.'),('marie01'),('marie02'),('marie03'),('marie05'),('marie06'),('marie07'),('marie08'),('marie09'),('marie1'),('marie10'),('marie101'),('marie11'),('marie12'),('marie123'),('marie1234'),('marie13'),('marie14'),('marie15'),('marie16'),('marie17'),('marie18'),('marie19'),('marie2'),('marie20'),('marie21'),('marie22'),('marie23'),('marie24'),('marie25'),('marie26'),('marie27'),('marie28'),('marie3'),('marie33'),('marie4'),('marie5'),('marie6'),('marie69'),('marie7'),('marie77'),('marie8'),('marie86'),('marie87'),('marie88'),('marie89'),('marie9'),('marie90'),('marie91'),('marie92'),('marie93'),('marie94'),('marie95'),('marie99'),('mariee'),('marieke'),('mariel'),('mariel1'),('mariela'),('mariela1'),('mariella'),('marielle'),('marielwfledlow'),('mariem'),('maries'),('marieta'),('marietta'),('marietta1'),('mariette'),('marife'),('marifer'),('marigold'),('mariguana'),('marihuana'),('marihuana1'),('marija'),('marijana'),('marijke'),('marijo'),('marijuana'),('marijuana1'),('marijuana2'),('marijuana4'),('marijuana420'),('marika'),('marika1'),('mariko'),('marilena'),('marilia'),('marilin'),('marillion'),('marilou'),('marilu'),('marilyn'),('marilyn1'),('marilyn59'),('marilynmanson'),('marimar'),('marimari'),('marimax.85'),('marimba'),('marin'),('marin1'),('marina'),('marina.shapovalo'),('marina.ushakovaznuv'),('marina01'),('marina1'),('marina10'),('marina11'),('marina12'),('marina123'),('marina13'),('marina2'),('marina2010'),('marina22'),('marina23'),('marina88'),('marinadeduxinaa'),('marinamarina'),('marinaorlova1991'),('marinara'),('marina_stryazhkova'),('marine'),('marine01'),('marine1'),('marine11'),('marine12'),('marine123'),('marine13'),('marine2'),('marinel'),('marinela'),('marinella'),('mariner'),('mariner1'),('marinero'),('mariners'),('mariners1'),('marines'),('marines1'),('marines12'),('marines2'),('marinette'),('marinho'),('marininys'),('marinka'),('marino'),('marino1'),('marino13'),('marino4ka'),('marinochka'),('marinochka.zhelannaya'),('mario'),('mario01'),('mario1'),('mario10'),('mario11'),('mario12'),('mario123'),('mario1234'),('mario13'),('mario14'),('mario140773'),('mario15'),('mario18'),('mario2'),('mario21'),('mario22'),('mario23'),('mario3'),('mario4'),('mario5'),('mario6'),('mario64'),('mario66'),('mario69'),('mario7'),('mario8'),('mario9'),('mariobros'),('mariokart'),('mariola'),('mariomario'),('marion'),('marion1'),('marios'),('mariposa'),('mariposa1'),('mariposa11'),('mariposa12'),('mariposa2'),('mariposa7'),('mariposas'),('mariposita'),('mariquita'),('marisa'),('marisa1'),('marisela'),('marisela1'),('marisha'),('marishka'),('mariska'),('marisol'),('marisol1'),('marissa'),('marissa1'),('marissa12'),('marissa123'),('marissa13'),('marissa2'),('marissa3'),('marissa5'),('marissa7'),('marist'),('marita'),('marita1'),('marites'),('maritime'),('marito'),('maritza'),('maritza1'),('marius'),('marius1'),('marius123'),('mariusz'),('mariusz1'),('marivic'),('mariya'),('mariz'),('mariza'),('marjan'),('marjorie'),('marjorie1'),('mark'),('mark01'),('mark06'),('mark07'),('mark08'),('mark09'),('mark1'),('mark10'),('mark11'),('mark12'),('mark123'),('mark1234'),('mark12345'),('mark13'),('mark14'),('mark15'),('mark16'),('mark17'),('mark18'),('mark21'),('mark22'),('mark23'),('mark24'),('mark25'),('mark69'),('markanthon'),('markel'),('marker'),('marker1'),('market'),('market1'),('marketa'),('marketing'),('marketing1'),('markie'),('markie1'),('markis'),('markiz'),('markiza'),('markjohn'),('markjoseph'),('markmark'),('marko'),('marko1'),('marko123'),('markos'),('markov'),('markova'),('markovka'),('markus'),('markus1'),('markus123'),('marky'),('marky1'),('markymark'),('mark_963'),('marla1'),('marlboro'),('marlboro1'),('marlboro12'),('marlboro2'),('marlboro20'),('marlee'),('marlee1'),('marleen'),('marlen'),('marlen1'),('marlena'),('marlena1'),('marlene'),('marlene1'),('marley'),('marley01'),('marley08'),('marley09'),('marley1'),('marley10'),('marley11'),('marley12'),('marley123'),('marley13'),('marley2'),('marley22'),('marley3'),('marley420'),('marley7'),('marlies'),('marlin'),('marlin1'),('marlins'),('marlins1'),('marlon'),('marlon1'),('marlon123'),('marlou'),('marlow'),('marlowe'),('marlyn'),('marmaduke'),('marmalade'),('marmalade1'),('marmar'),('marmar1'),('marmara'),('marmaris'),('marmelad'),('marmelade'),('marmeladka'),('marmite'),('marmite1'),('marmot'),('marmota'),('marmotte'),('marnie'),('maroc'),('marocain'),('marocco'),('marokko'),('maroon'),('maroon5'),('marques'),('marques1'),('marquette'),('marquette1'),('marquez'),('marquez1'),('marquis'),('marquis1'),('marquise'),('marquise1'),('marrakech'),('marriage'),('marriage1'),('married'),('married06'),('married07'),('married08'),('married1'),('married2'),('marriott'),('marriott1'),('marron'),('marruecos'),('marryme'),('mars'),('mars123'),('mars13'),('marsbar'),('marseille'),('marseille1'),('marseille13'),('marsel'),('marsh1'),('marsha'),('marsha1'),('marsha11'),('marshal'),('marshal1'),('marshall'),('marshall1'),('marshall12'),('marshall2'),('marshall3'),('marshmallow'),('marshmello'),('marshmellow'),('marsik'),('marsmars'),('marsupilami'),('mart'),('mart1n'),('marta'),('marta1'),('marta123'),('marta7'),('martas'),('martel'),('martell'),('martello'),('marten'),('martes'),('martha'),('martha1'),('martha12'),('martha123'),('martha2'),('marthe'),('marti'),('martial'),('martian'),('martie'),('martijn'),('martin'),('martin!'),('martin.'),('martin01'),('martin06'),('martin07'),('martin08'),('martin09'),('martin1'),('martin10'),('martin11'),('martin12'),('martin123'),('martin1234'),('martin13'),('martin14'),('martin15'),('martin16'),('martin17'),('martin18'),('martin2'),('martin20'),('martin21'),('martin22'),('martin23'),('martin24'),('martin25'),('martin3'),('martin4'),('martin5'),('martin6'),('martin69'),('martin7'),('martin77'),('martin8'),('martin88'),('martin99'),('martina'),('martina1'),('martina123'),('martine'),('martine1'),('martinek'),('martinez'),('martinez1'),('martinez12'),('martinez13'),('martinez2'),('martinha'),('martini'),('martini1'),('martinique'),('martinka'),('martinko'),('martino'),('martins'),('martins1'),('martita'),('martusia'),('marty'),('marty1'),('marty123'),('martyn'),('martyna'),('martyna1'),('martynka'),('maruja'),('marusa'),('marusia'),('maruska'),('marusya'),('maruthi'),('maruti'),('marvel'),('marvel1'),('marvel5454'),('marvellous'),('marvelous'),('marvelous1'),('marvin'),('marvin01'),('marvin1'),('marvin11'),('marvin12'),('marvin123'),('marvin13'),('marvin2'),('marwan'),('marwin'),('mary'),('mary01'),('mary10'),('mary11'),('mary12'),('mary123'),('mary1234'),('mary13'),('mary14'),('mary15'),('mary16'),('mary18'),('mary21'),('mary22'),('mary23'),('mary420'),('mary69'),('maryam'),('maryam1'),('maryan'),('maryana'),('maryann'),('maryann1'),('maryanne'),('maryanne1'),('marybeth'),('marybeth1'),('maryellen'),('marygrace'),('maryj420'),('maryjan3'),('maryjane'),('maryjane!'),('maryjane.'),('maryjane1'),('maryjane12'),('maryjane13'),('maryjane2'),('maryjane3'),('maryjane4'),('maryjane42'),('maryjane420'),('maryjane69'),('maryjane7'),('maryjean'),('maryjo'),('maryjoy'),('marykate'),('marykate1'),('marykay'),('marykay1'),('maryland'),('maryland1'),('marylin'),('maryline'),('marylou'),('marylou1'),('marymary'),('marymary1'),('maryna'),('marypoppins'),('maryrose'),('maryse'),('marysia'),('marysia1'),('marzena'),('marzia'),('marzipan'),('mar_prod'),('mas'),('mas123'),('masahiro'),('masaka'),('masaki'),('masakra'),('masala'),('masamasa'),('masamune'),('masamune1'),('masana'),('masato'),('masaya'),('mascara'),('mascha'),('mascot'),('mascota'),('mascotte'),('Mase4ever'),('maserati'),('mash4077'),('masha'),('masha1'),('masha123'),('masha1998'),('mashamasha'),('mashenka'),('mashimaro'),('mashina'),('mashka'),('masina'),('masini'),('masjnj67'),('maslo'),('maslo123'),('masloboinikova1987'),('maslova'),('masmas'),('mason'),('mason01'),('mason06'),('mason07'),('mason08'),('mason1'),('mason11'),('mason12'),('mason123'),('mason2'),('mason3'),('mason5'),('masons'),('masood'),('masquerade'),('massacre'),('massacre1'),('massage'),('massage1'),('massari'),('masseffect'),('massena00'),('massey'),('massey1'),('massi'),('massilia'),('massimiliano'),('massimo'),('massimo1'),('massive'),('massive1'),('mast3r'),('master'),('master!'),('master.'),('master0'),('master00'),('master007'),('master01'),('master07'),('master08'),('master09'),('master1'),('master10'),('master101'),('master11'),('master12'),('master123'),('master1234'),('master12345'),('master13'),('master14'),('master15'),('master16'),('master17'),('master18'),('master2'),('master20'),('master2006'),('master21'),('master22'),('master23'),('master24'),('master25'),('master3'),('master33'),('master4'),('master45'),('master5'),('master55'),('master6'),('master66'),('master666'),('master69'),('master7'),('MaStEr77'),('master777'),('master8'),('master88'),('master89'),('master9'),('master99'),('masterblaster'),('mastercard'),('masterchief'),('masterkey'),('masterman'),('mastermind'),('masterone'),('masterp'),('masterp1'),('masterpiece'),('masterplan'),('masters'),('masters1'),('mastiff'),('masyanya'),('mat'),('mat123'),('mata'),('matador'),('matador1'),('matahari'),('mataji'),('matamata'),('matarani'),('matata'),('match'),('match1'),('matchbox'),('matchbox20'),('matches'),('mate'),('mate1'),('mate1.com'),('mate123'),('matej'),('matematica'),('matematicas'),('matematik'),('matematika'),('mateo'),('mateo1'),('mateo123'),('mater1'),('materazzi'),('materia'),('material'),('mates'),('mateus'),('mateus123'),('mateusz'),('mateusz1'),('mateusz12'),('mateusz123'),('mateuszek'),('math'),('math12'),('math123'),('mathematic'),('mathematics'),('matheo'),('mather'),('mathers'),('matheus'),('matheus1'),('matheus123'),('mathew'),('mathew1'),('mathew12'),('mathew123'),('mathews'),('mathews1'),('mathias'),('mathias1'),('mathieu'),('mathieu1'),('mathilda'),('mathilde'),('mathis'),('mathys'),('mati'),('mati123'),('matias'),('matias1'),('matias123'),('matilda'),('matilda1'),('matilde'),('matilde1'),('matisse'),('matisse1'),('matita'),('matkhau'),('matlock'),('matmat'),('matr1x'),('matrassesotk'),('matrimonio'),('matrix'),('matrix00'),('matrix007'),('matrix01'),('matrix1'),('matrix10'),('matrix11'),('matrix12'),('matrix123'),('matrix13'),('matrix2'),('matrix21'),('matrix22'),('matrix23'),('matrix3'),('matrix69'),('matrix7'),('matrix99'),('matrixx'),('matros'),('matt'),('matt00'),('matt01'),('matt06'),('matt07'),('matt08'),('matt09'),('matt1'),('matt10'),('matt101'),('matt11'),('matt12'),('matt123'),('matt1234'),('matt13'),('matt14'),('matt15'),('matt16'),('matt17'),('matt18'),('matt19'),('matt1988'),('matt20'),('matt21'),('matt22'),('matt23'),('matt24'),('matt25'),('matt6288'),('matt633'),('matt69'),('matt77'),('matt88'),('matt99'),('matteo'),('matteo1'),('matter'),('matter1'),('mattew'),('matth3w'),('matthardy'),('matthardy1'),('matthew'),('matthew!'),('matthew.'),('matthew0'),('matthew01'),('matthew02'),('matthew03'),('matthew04'),('matthew05'),('matthew06'),('matthew07'),('matthew08'),('matthew09'),('matthew1'),('matthew10'),('matthew11'),('matthew12'),('matthew123'),('matthew13'),('matthew14'),('matthew15'),('matthew16'),('matthew17'),('matthew18'),('matthew19'),('matthew2'),('matthew20'),('matthew21'),('matthew22'),('matthew23'),('matthew24'),('matthew25'),('matthew26'),('matthew3'),('matthew4'),('matthew5'),('matthew6'),('matthew69'),('matthew7'),('matthew77'),('matthew8'),('matthew88'),('matthew9'),('matthew95'),('matthew98'),('matthew99'),('matthews'),('matthews1'),('matthias'),('matthias1'),('matthieu'),('mattia'),('mattias'),('mattie'),('mattie1'),('mattingly'),('mattman'),('mattman1'),('mattmatt'),('mattmatt1'),('matty'),('matty1'),('matty123'),('mature'),('matute'),('matveev'),('matveev792010'),('matveeva'),('matvei'),('matvey'),('matyas2001'),('matylda'),('matysek'),('mau'),('maui'),('maulana'),('maulwurf'),('maumau'),('maureen'),('maureen1'),('mauri'),('maurice'),('maurice1'),('maurice2'),('maurice3'),('maurice4'),('mauricio'),('mauricio1'),('mauritius'),('maurizio'),('mauro'),('mauro1'),('maus'),('mauser'),('mausi'),('mausi1'),('mautauaja'),('maver1ck'),('maveric'),('maverick'),('maverick1'),('maverick12'),('maverick2'),('maverick7'),('mavericks'),('mavericks1'),('maverik'),('mavipies'),('mavriciy'),('mavrick'),('mavrick1'),('mavs41'),('mawmaw'),('mawmaw1'),('max'),('max.kirilov.90'),('max007'),('max100'),('max101'),('max111'),('max123'),('max1234'),('max12345'),('max123456'),('max1992'),('max1994'),('max1997'),('max1998'),('max2000'),('max2005'),('max2006'),('max2007'),('max2008'),('max2009'),('max2010'),('max333'),('max666'),('max6751'),('max777'),('maxa-06'),('maxa-78'),('maxamillion'),('maxcat'),('maxchislov'),('maxdog'),('maxdog1'),('maxell'),('maxell1'),('maxemys'),('maxence'),('maxi'),('maxi123'),('maxie'),('maxie1'),('maxie123'),('maxim'),('maxim1'),('maxim123'),('maxim1935'),('maxim3999'),('maxima'),('maxima1'),('maxime'),('maxime1'),('maximilian'),('maximiliano'),('maximius'),('maximka'),('maximo'),('maximo1'),('maximova.60'),('maximova_elena77'),('maximovie'),('maximum'),('maximum1'),('maximus'),('maximus1'),('maximus123'),('maximus1393'),('maximus2'),('maxine'),('maxine1'),('maxine123'),('maxito'),('maxix565656'),('maxman'),('maxmax'),('maxmax1'),('maxmax123'),('maxmaxmax'),('maxmotives'),('maxonina22'),('maxou'),('maxpayne'),('maxpower'),('maxpower1'),('maxpredator'),('maxthedog'),('maxtor'),('maxwell'),('maxwell01'),('maxwell1'),('maxwell11'),('maxwell12'),('maxwell123'),('maxwell2'),('maxwell3'),('maxwell5'),('maxwell7'),('maxx'),('maxxxx'),('max_masha'),('may'),('may123'),('may1980'),('may1982'),('may1984'),('may1985'),('may1986'),('may1987'),('may1988'),('may1989'),('may1990'),('may1991'),('may1992'),('may1993'),('may1994'),('may1995'),('may1996'),('may1998'),('may2000'),('may2005'),('may2006'),('may2007'),('may2008'),('may2009'),('maya'),('maya12'),('maya123'),('maya1234'),('mayaki'),('mayamaya'),('mayang'),('mayank'),('mayann'),('mayara'),('maybach'),('maybe'),('maybe1'),('mayberry'),('mayday'),('mayday1'),('mayfair'),('mayfair1'),('mayfield'),('mayfield1'),('mayflower'),('mayflower1'),('mayhem'),('mayhem1'),('mayhem666'),('mayita'),('mayito'),('maymay'),('maymay1'),('maynard'),('maynard1'),('mayo'),('mayotte'),('mayowa'),('mayquinn2'),('mayra'),('mayra1'),('mayra123'),('mayrik67'),('mayumi'),('mayuri'),('mazafaka'),('mazahaka'),('mazatlan'),('mazda'),('mazda1'),('mazda123'),('mazda3'),('mazda323'),('mazda323f'),('mazda6'),('mazda626'),('mazdamx3'),('mazdamx5'),('mazdamx6'),('mazdarx7'),('mazdarx8'),('mazinger'),('mazsola'),('mb1234'),('mb123456'),('mbahurip'),('mbrim'),('mbtVibranike'),('mc'),('mc1234'),('mc123456'),('mc9Ad9w2ux'),('mcaBdaw2vx'),('mcafee'),('mcbride'),('mccarthy'),('mccartney'),('mccormick'),('mcdonald'),('mcdonald1'),('mcdonalds'),('mcdonalds1'),('mcflurry!'),('mcfly'),('mcfly1'),('mcfly123'),('mcgrady'),('mcgrady1'),('mcgrath'),('mcgregor'),('mcguire'),('mchammer'),('mcintosh'),('mckayla'),('mckayla1'),('mckenna'),('mckenna1'),('mckenzie'),('mckenzie1'),('mckinley'),('mckinley1'),('mckinney'),('mclaren'),('mclaren1'),('mclarenf1'),('mclean'),('mcleod'),('mclovin'),('mclovin1'),('mcnabb'),('mcnabb5'),('mcqueen'),('mcr123'),('mcr666'),('md1234'),('MD1998PB'),('md2020'),('me'),('me&you'),('me1212'),('me123'),('me1234'),('me12345'),('me123456'),('me2you'),('me4ever'),('me4life'),('me4you'),('meadow'),('meadow1'),('meadows'),('meadows1'),('meagan'),('meagan1'),('meaghan'),('meaghan1'),('meandme'),('meandu'),('meandu1'),('meandu2'),('meandyou'),('meandyou1'),('meandyou2'),('meangirls1'),('meanie1'),('meat'),('meatball'),('meatball1'),('Meatball99'),('meatballs'),('meathead'),('meathead1'),('meatloaf'),('meatloaf1'),('meatman'),('meatwad'),('meatwad1'),('mecanica'),('mecanico'),('mecca1'),('mechanic'),('mechanic1'),('mechanical'),('mechelle'),('mechta'),('med'),('medecine'),('medeiros'),('medellin'),('medellin1'),('mede_voda'),('media'),('media1'),('media123'),('mediawire'),('medic'),('medic1'),('medical'),('medical1'),('medicina'),('medicine'),('medicine1'),('medico'),('medieval'),('medina'),('medina1'),('medion'),('medion1'),('medion123'),('meditation'),('mediterraneo'),('medium'),('medrano'),('medtech'),('medusa'),('medusa1'),('meduza'),('medved'),('medvedev'),('medvedeva'),('medvidek'),('mee'),('mee123'),('meeeee'),('meeka1'),('meeko'),('meeko1'),('meemee'),('meemee1'),('meena'),('meenakshi'),('meerkat'),('meesha'),('meeting'),('meetme'),('mefisto'),('meg'),('meg123'),('mega'),('mega123'),('megabyte'),('megadeath'),('megadeth'),('megadeth1'),('megafon'),('megaman'),('megaman1'),('megaman12'),('megaman123'),('megaman2'),('megaman3'),('megamanx'),('megamega'),('megan'),('megan!'),('megan01'),('megan1'),('megan10'),('megan11'),('megan12'),('megan123'),('megan13'),('megan14'),('megan15'),('megan16'),('megan2'),('megan21'),('megan22'),('megan23'),('megan3'),('megan4'),('megan5'),('megan6'),('megan69'),('megan7'),('megane'),('meganfox'),('megans'),('Megaparol'),('megaparol12345'),('megapolis'),('megasecret'),('megastar'),('megatron'),('megatron1'),('meggie'),('meggie1'),('meghan'),('meghan1'),('meghan12'),('meghana'),('meghna'),('megmeg'),('megryan'),('megumi'),('megusta'),('mehdi'),('mehmet'),('mehmet123'),('mehran'),('meiling'),('meimei'),('meinschatz'),('meisha'),('meister'),('meister1'),('meiyoumima'),('mel'),('mel123'),('melancia'),('melani'),('melania'),('melanie'),('melanie!'),('melanie01'),('melanie1'),('melanie11'),('melanie12'),('melanie123'),('melanie13'),('melanie2'),('melanie3'),('melanie7'),('melany'),('melati'),('melbourne'),('melbourne1'),('melchior'),('melchor'),('melena'),('melendez'),('meli'),('meli123'),('melike'),('melimelo'),('melina'),('melina1'),('melinda'),('melinda1'),('meline'),('melisa'),('melisa1'),('melissa'),('melissa!'),('melissa.'),('melissa01'),('melissa07'),('melissa08'),('melissa09'),('melissa1'),('melissa10'),('melissa11'),('melissa12'),('melissa123'),('melissa13'),('melissa14'),('melissa15'),('melissa16'),('melissa17'),('melissa18'),('melissa19'),('melissa2'),('melissa21'),('melissa22'),('melissa23'),('melissa24'),('melissa25'),('melissa3'),('melissa4'),('melissa5'),('melissa6'),('melissa69'),('melissa7'),('melissa8'),('melissa9'),('melita'),('melkor'),('mellie'),('mellisa'),('mellissa'),('mello1'),('mellon'),('mellon1'),('mellow'),('mellow1'),('melly'),('melly1'),('melmel'),('melmel1'),('melnik'),('melnikova'),('melo'),('melo123'),('melo15'),('melocoton'),('melodi'),('melodia'),('melodie'),('melodie1'),('melody'),('melody1'),('melody12'),('melody123'),('meloman'),('melon'),('melon1'),('melon123'),('melone'),('melons'),('melove'),('melrose'),('melrose1'),('meltdown'),('meltem'),('melton'),('melusine'),('melville'),('melvin'),('melvin1'),('melvin12'),('melvin123'),('melvin2'),('member'),('member1'),('members'),('membership'),('meme'),('meme10'),('meme11'),('meme12'),('meme123'),('meme1234'),('meme13'),('meme22'),('meme23'),('memek'),('mememe'),('mememe!'),('mememe1'),('mememe12'),('mememe123'),('mememe2'),('mememe3'),('memememe'),('memememe1'),('memento'),('mementomori'),('memere'),('memito'),('memo'),('memo123'),('memole'),('memorex'),('memorex1'),('memoria'),('memorial'),('memorial1'),('memories'),('memories1'),('memory'),('memory1'),('memphis'),('memphis1'),('memphis10'),('memphis2'),('memphis901'),('memyself'),('memyself&i'),('memyself1'),('memyselfan'),('memyselfandi'),('memyselfi'),('men'),('men123'),('menace'),('menace1'),('mendel'),('mendes'),('mendez'),('mendez1'),('mendoza'),('mendoza1'),('meneses'),('mengmeng'),('menina'),('meninblack'),('menmen'),('menmenmen'),('menorca'),('mensah'),('mensuck'),('mensuck1'),('mental'),('mental1'),('mentari'),('menthol'),('menthol1'),('mentira'),('mentira1'),('mentiras'),('mentiroso'),('mentor'),('mentos'),('meomeo'),('meonly'),('meonly1'),('meow'),('meow11'),('meow12'),('meow123'),('meow1234'),('meowmeow'),('meowmeow1'),('meowmix'),('meowmix1'),('mephisto'),('mer'),('mercado'),('mercado1'),('merced'),('merced209'),('mercedes'),('mercedes01'),('mercedes1'),('mercedes11'),('mercedes12'),('mercedes123'),('mercedes2'),('mercedes3'),('mercedes7'),('mercedesbenz'),('mercedez'),('mercedez1'),('mercer'),('mercer1'),('merchant'),('merci'),('mercredi'),('mercure'),('mercurial'),('mercurio'),('mercury'),('mercury1'),('mercury7'),('mercy'),('mercy1'),('mercy123'),('merda'),('merda1'),('merda123'),('merdaccia'),('merde'),('merdeka'),('merdes'),('meredith'),('meredith1'),('merengue'),('merganser'),('merhaba'),('meriam'),('merida'),('meridian'),('meridian1'),('meriem'),('merijaan'),('merino'),('meriva'),('merkur'),('merlin'),('merlin01'),('merlin1'),('merlin11'),('merlin12'),('merlin123'),('merlin13'),('merlin2'),('merlin69'),('merlin7'),('merlino'),('merlot'),('merlot1'),('merlyn'),('mermaid'),('mermaid1'),('mermaid2'),('mermaids'),('mermer'),('merrick'),('merrick1'),('merrill'),('merrill1'),('merritt'),('merry'),('merry1'),('mersedes'),('merve'),('merveille'),('mervin'),('meryem'),('mes'),('mesedka'),('mesha1'),('meshmesh'),('message'),('message1'),('messages'),('messenger'),('messenger1'),('messer'),('messi'),('messi1'),('messi10'),('messi123'),('messi19'),('messiah'),('messiah1'),('messier'),('messier11'),('messina'),('messy1'),('mester'),('mestre'),('met'),('metal'),('metal!'),('metal1'),('metal12'),('metal123'),('metal13'),('metal2'),('metal4ever'),('metal4life'),('metal6'),('metal666'),('metal69'),('metalcore'),('metalgear'),('metalgear1'),('metalhead'),('metalhead1'),('metalica'),('metalica1'),('metalika'),('metall'),('metall1ca'),('metallic'),('metallica'),('metallica!'),('metallica.'),('metallica0'),('metallica1'),('metallica123'),('metallica2'),('metallica3'),('metallica4'),('metallica5'),('metallica6'),('metallica666'),('metallica7'),('metallica8'),('metallica9'),('metalman'),('metals'),('metatron'),('meteor'),('meteora'),('meteora1'),('method'),('method1'),('methodist'),('methodman'),('methodman1'),('methos'),('metin2'),('metoo'),('metoyou'),('metro'),('metro1'),('metro123'),('metro2033'),('metroid'),('metroid1'),('metropol'),('metropolis'),('mets'),('mets123'),('mets1986'),('mets86'),('meuamor'),('mewmew'),('mewmew1'),('mewtwo'),('mewtwo1'),('mex123'),('mexic0'),('mexicali'),('mexicali1'),('mexican'),('mexican1'),('mexican10'),('mexican12'),('mexican123'),('mexican13'),('mexican14'),('mexican15'),('mexican2'),('mexican3'),('mexican4li'),('mexican5'),('mexican7'),('mexicana'),('mexicana1'),('mexicano'),('mexicano1'),('mexicano13'),('mexico'),('mexico!'),('mexico#1'),('mexico.'),('mexico00'),('mexico01'),('mexico06'),('mexico07'),('mexico08'),('mexico09'),('mexico1'),('mexico10'),('mexico100'),('mexico101'),('mexico11'),('mexico12'),('mexico123'),('mexico1234'),('mexico13'),('mexico14'),('mexico15'),('mexico16'),('mexico17'),('mexico18'),('mexico19'),('mexico2'),('mexico20'),('mexico2009'),('mexico2010'),('mexico21'),('mexico22'),('mexico23'),('mexico24'),('mexico25'),('mexico3'),('mexico4'),('mexico5'),('mexico6'),('mexico619'),('mexico69'),('mexico7'),('mexico77'),('mexico8'),('mexico86'),('mexico88'),('mexico9'),('mexico90'),('mexico99'),('mg1234'),('mgoblue'),('mgreen39'),('mhaldita'),('mhine'),('mhine1'),('mhinekoh'),('mi'),('mia'),('mia123'),('mia1234'),('mia30'),('mia305'),('miahamm9'),('miami'),('miami1'),('miami11'),('miami12'),('miami123'),('miami13'),('miami2'),('miami23'),('miami3'),('miami305'),('miamia'),('miamia1'),('miamibeach'),('miamiheat'),('miamiheat1'),('miamiheat3'),('miamor'),('miamor1'),('miamor2'),('miamore'),('miangel'),('miaomiao'),('miaumiau'),('mibebe'),('mibebe1'),('mic'),('mic123'),('micael'),('micaela'),('micaela1'),('micah'),('micah1'),('micasa'),('mich'),('mich3ll3'),('micha'),('micha1'),('micha3l'),('michae1'),('michael'),('michael!'),('michael.'),('michael0'),('michael00'),('michael01'),('michael02'),('michael03'),('michael04'),('michael05'),('michael06'),('michael07'),('michael08'),('michael09'),('michael1'),('michael10'),('michael101'),('michael11'),('michael12'),('michael123'),('michael13'),('michael14'),('michael15'),('michael16'),('michael17'),('michael18'),('michael19'),('michael2'),('michael20'),('michael200'),('michael21'),('michael22'),('michael23'),('michael24'),('michael25'),('michael26'),('michael27'),('michael28'),('michael29'),('michael3'),('michael30'),('michael31'),('michael32'),('michael33'),('michael34'),('michael4'),('michael44'),('michael5'),('michael50'),('michael55'),('michael6'),('michael69'),('michael7'),('michael77'),('michael8'),('michael84'),('michael85'),('michael86'),('michael87'),('michael88'),('michael89'),('michael9'),('michael90'),('michael91'),('michael92'),('michael93'),('michael94'),('michael95'),('michael96'),('michael97'),('michael98'),('michael99'),('michaela'),('michaela1'),('michaelj'),('michaeljac'),('michaeljackson'),('michaels'),('michaels1'),('michal'),('michal1'),('michal12'),('michal123'),('michalek'),('miche11e'),('micheal'),('micheal1'),('micheal12'),('micheal123'),('micheal2'),('micheal23'),('micheal3'),('micheal7'),('michel'),('michel1'),('michel123'),('michel69.69'),('michela'),('michelangelo'),('michele'),('michele1'),('michele2'),('michelin'),('micheline'),('michelino'),('michell'),('michell1'),('michelle'),('michelle!'),('michelle.'),('michelle0'),('michelle00'),('michelle01'),('michelle02'),('michelle03'),('michelle05'),('michelle06'),('michelle07'),('michelle08'),('michelle09'),('michelle1'),('michelle10'),('michelle11'),('michelle12'),('michelle123'),('michelle13'),('michelle14'),('michelle15'),('michelle16'),('michelle17'),('michelle18'),('michelle19'),('michelle2'),('michelle20'),('michelle21'),('michelle22'),('michelle23'),('michelle24'),('michelle25'),('michelle26'),('michelle27'),('michelle28'),('michelle29'),('michelle3'),('michelle30'),('michelle33'),('michelle4'),('michelle5'),('michelle6'),('michelle69'),('michelle7'),('michelle77'),('michelle8'),('michelle88'),('michelle89'),('michelle9'),('michelle99'),('michi'),('michi1'),('michi123'),('michigan'),('michigan1'),('michigan12'),('michigan2'),('michiko'),('michoacan'),('michoacan1'),('michou'),('micione'),('mick'),('mickael'),('mickey'),('mickey!'),('mickey.'),('mickey00'),('mickey01'),('mickey02'),('mickey05'),('mickey06'),('mickey07'),('mickey08'),('mickey09'),('mickey1'),('mickey10'),('mickey101'),('mickey11'),('mickey12'),('mickey123'),('mickey1234'),('mickey13'),('mickey14'),('mickey15'),('mickey16'),('mickey17'),('mickey18'),('mickey19'),('mickey2'),('mickey20'),('mickey21'),('mickey22'),('mickey23'),('mickey24'),('mickey25'),('mickey27'),('mickey28'),('mickey3'),('mickey33'),('mickey4'),('mickey5'),('mickey6'),('mickey69'),('mickey7'),('mickey77'),('mickey8'),('mickey88'),('mickey9'),('mickey99'),('mickeymous'),('mickeymouse'),('mickie'),('mickie1'),('micky'),('micky1'),('micky123'),('mickymouse'),('micmac'),('micmic'),('micorazon'),('micro'),('micro1'),('micro123'),('microbiology'),('microlab'),('microlad'),('micron'),('micron1'),('microphone'),('micros'),('microsoft'),('microsoft1'),('microsoft2'),('microwave'),('microwave1'),('midas1'),('MidCont'),('middle'),('middle1'),('middleton'),('midget'),('midget1'),('midland'),('midland1'),('midnight'),('midnight!'),('midnight01'),('midnight1'),('midnight10'),('midnight11'),('midnight12'),('midnight13'),('midnight2'),('midnight22'),('midnight3'),('midnight4'),('midnight5'),('midnight6'),('midnight69'),('midnight7'),('midnight8'),('midnight9'),('midnite'),('midnite1'),('midori'),('midtown'),('midway'),('midway1'),('midwest'),('midwest1'),('midwife'),('miercoles'),('mierda'),('mierda1'),('mierda123'),('miespacio1'),('mifamilia'),('mifamilia1'),('mighty'),('mighty1'),('mightymouse'),('mignon'),('migrationsandeep'),('migrationschool'),('miguel'),('miguel.'),('miguel01'),('miguel1'),('miguel10'),('miguel11'),('miguel12'),('miguel123'),('miguel13'),('miguel14'),('miguel15'),('miguel17'),('miguel18'),('miguel2'),('miguel21'),('miguel22'),('miguel23'),('miguel3'),('miguel5'),('miguel7'),('miguelange'),('miguelangel'),('miguelito'),('miguelito1'),('miha-nov'),('mihaela'),('mihai'),('mihail'),('mihail-saratov'),('mihailpezhemskii'),('mihail_alekseevskiy406'),('mihaita'),('mik'),('mika'),('mika12'),('mika123'),('mikado'),('mikael'),('Mikael412'),('mikaela'),('mikaela1'),('mikaella'),('mikail'),('mikala'),('mikalyalia'),('mikamika'),('mikasa'),('mikayla'),('mikayla1'),('mike'),('mike00'),('mike007'),('mike01'),('mike02'),('mike03'),('mike04'),('mike05'),('mike06'),('mike07'),('mike08'),('mike09'),('mike1'),('mike10'),('mike101'),('mike11'),('mike12'),('mike123'),('mike1234'),('mike12345'),('mike123456'),('mike13'),('mike14'),('mike143'),('mike15'),('mike16'),('mike17'),('mike18'),('mike19'),('mike1985'),('mike20'),('mike2000'),('mike2006'),('mike2007'),('mike2008'),('mike2009'),('mike2010'),('mike21'),('mike22'),('mike23'),('mike24'),('mike25'),('mike26'),('mike27'),('mike28'),('mike29'),('mike30'),('mike31'),('mike32'),('mike33'),('mike34'),('mike420'),('mike44'),('mike45'),('mike4ever'),('mike55'),('mike6453'),('mike66'),('mike666'),('mike69'),('mike77'),('mike87'),('mike88'),('mike89'),('mike92'),('mike99'),('mikee'),('mikejones'),('mikejones1'),('mikejones2'),('mikel'),('mikel1'),('mikela'),('mikele'),('mikemike'),('mikemike1'),('mikes'),('mikes1'),('mikesch'),('miketyson'),('mikevick7'),('mikey'),('mikey01'),('mikey1'),('mikey10'),('mikey11'),('mikey12'),('mikey123'),('mikey13'),('mikey2'),('mikey21'),('mikey22'),('mikey23'),('mikey3'),('mikey5'),('mikey6'),('mikey69'),('mikey7'),('mikhail'),('mikhailova-w'),('mikhayildopy'),('miki'),('miki123'),('mikie1'),('mikimaus'),('mikimiki'),('mikkel'),('mikki'),('mikki1'),('mikmik'),('miko'),('mikola'),('mikolaj'),('mikolaj1'),('mikomiko'),('mil'),('mila'),('mila123'),('mila90974'),('milacek'),('milacik'),('milady'),('milagro'),('milagros'),('milagros1'),('milamber'),('milamila'),('milan'),('milan1'),('milan123'),('milan1899'),('milan22'),('milan4ever'),('milan7'),('milan88'),('milana'),('milanac'),('milanello'),('milani'),('milanista'),('milanisti'),('milankasanakoeva'),('milano'),('milano1'),('milanova-kira'),('milashka'),('milay-ven2011'),('milaya'),('mildred'),('mildred1'),('mildseven'),('milena'),('milena1'),('milena699803'),('milenium'),('milenka'),('miles'),('miles1'),('miles123'),('milesdavis'),('milestone'),('miley'),('miley1'),('miley10'),('miley101'),('miley11'),('miley12'),('miley123'),('miley15'),('miley16'),('miley2'),('mileycyrus'),('milford'),('milford1'),('milhouse'),('milica'),('milind'),('milion'),('militaire'),('militar'),('military'),('military1'),('milito'),('milk'),('milk12'),('milk123'),('milka'),('milka1'),('milkbone'),('milkdud1'),('milkman'),('milkman1'),('milkmilk'),('milkshake'),('milkshake1'),('milkshake2'),('milky'),('milky1'),('milkyway'),('milkyway1'),('milla'),('millan'),('millard'),('mille'),('millencolin'),('millenium'),('millenium1'),('millennium'),('miller'),('miller01'),('miller1'),('miller10'),('miller11'),('miller12'),('miller123'),('miller13'),('miller2'),('miller21'),('miller22'),('miller23'),('miller3'),('miller30'),('miller31'),('miller5'),('miller69'),('miller7'),('millerlite'),('millers'),('millertime'),('millhouse'),('millicent'),('millie'),('millie01'),('millie1'),('millie11'),('millie12'),('millie123'),('millie2'),('milligan'),('million'),('million1'),('Million2'),('millionair'),('millionaire'),('millioner'),('millions'),('millions1'),('millonario'),('millonarios'),('millos'),('millos13'),('millsberry'),('millwall'),('millwall1'),('milly'),('milly1'),('milly123'),('milo'),('milo11'),('milo12'),('milo123'),('milo1234'),('milomilo'),('milonga'),('milord'),('milos'),('milosc'),('milou'),('milton'),('milton1'),('milwaukee'),('milwaukee1'),('mim'),('mima'),('mima123'),('mimama'),('mimamamemima'),('mimamima'),('mimi'),('mimi01'),('mimi07'),('mimi08'),('mimi09'),('mimi10'),('mimi11'),('mimi12'),('mimi123'),('mimi1234'),('mimi13'),('mimi14'),('mimi15'),('mimi16'),('mimi21'),('mimi22'),('mimi23'),('mimi88'),('mimimi'),('mimimi1'),('mimimimi'),('mimine'),('mimino'),('mimita'),('mimmo'),('mimosa'),('mimoza'),('min'),('min123'),('mina'),('mina123'),('minako'),('minakshi'),('minami'),('minamina'),('minato'),('minchia'),('mindanao'),('mindfreak'),('mindfreak1'),('mindgame'),('mindless'),('mindless1'),('mindy'),('mindy1'),('mindy123'),('mine'),('mine11'),('mine12'),('mine123'),('mine1234'),('mine4ever'),('mine69'),('minecraft'),('minecraft1'),('minecraft12'),('minecraft123'),('minemine'),('minemine1'),('mineonly'),('mineral'),('minerva'),('minerva1'),('minette'),('minger'),('mingming'),('mingus'),('minh123'),('minhamae'),('minhasenha'),('minhavida'),('mini'),('mini12'),('mini123'),('mini1234'),('mini14'),('minicalibra'),('miniclip'),('miniclip1'),('minicooper'),('minidisc'),('minimal'),('minimal1'),('miniman'),('miniman1'),('minimax'),('minime'),('minime1'),('minime123'),('minime2'),('minimi'),('minimini'),('minimo'),('minimoto'),('minimum'),('minimum1'),('minina'),('minino'),('minion'),('minister'),('minister1'),('ministry'),('ministry1'),('minka'),('minkia'),('minkova_i'),('minmin'),('minnesota'),('minnesota1'),('minnette'),('minnie'),('minnie01'),('minnie1'),('minnie10'),('minnie11'),('minnie12'),('minnie123'),('minnie13'),('minnie2'),('minnie22'),('minnie3'),('minnie4'),('minnie5'),('minnie7'),('minniemous'),('minniemouse'),('minnow'),('minolta'),('minombre'),('minority'),('minotaur'),('minotauro'),('minou'),('minoucha'),('minouche'),('minous'),('minstrel'),('mintal24'),('minty'),('minty1'),('minute'),('miomio'),('mir'),('mir-180991'),('mira'),('mira123'),('miraa_84'),('mirabel'),('mirabella'),('mirabelle'),('miracle'),('miracle1'),('miracle2'),('miracle7'),('miracles'),('miraflores'),('mirage'),('mirage1'),('miramar'),('miramira'),('mirana'),('miranda'),('miranda1'),('miranda11'),('miranda12'),('miranda123'),('miranda13'),('miranda2'),('miranda3'),('miranda5'),('miranda7'),('miranda9'),('mirantte'),('mirasol'),('mircea'),('mireia'),('mireille'),('mirek'),('mirela'),('mirella'),('mirellabroersma1987570'),('mireya'),('mireya1'),('miriam'),('miriam1'),('miriam123'),('mirian'),('miriana'),('mirinda'),('mirjam'),('mirjana'),('mirka'),('mirko'),('mirlan_o'),('miroku'),('mironov'),('mironova'),('miroslav'),('miroslava'),('mirror'),('mirror1'),('mirtillo'),('miruna'),('mis'),('mis3amores'),('misael'),('misael1'),('misaki'),('misamisa'),('misamores'),('misato'),('misbah'),('misbebes'),('misch.sosnin'),('mischa'),('mischa1'),('mischief'),('mischief1'),('misericordia'),('misery'),('misery1'),('misfit'),('misfit1'),('misfits'),('misfits1'),('misfits138'),('mish777'),('misha'),('misha1'),('misha123'),('mishaghbdtn'),('mishanna1936'),('mishanya'),('mishas001'),('mishel'),('mishijos'),('mishka'),('mishka1'),('mishmish'),('mishra'),('mishutka'),('misia'),('misia1'),('misiaczek'),('misiaczek1'),('misiek'),('misiek1'),('misiek123'),('misio'),('misiu'),('misiu1'),('miska'),('miss'),('miss-evgeniya-93'),('miss.marina.nikolaeva.2013'),('miss123'),('missbitch1'),('missey'),('missie'),('missie1'),('missika'),('missile'),('missing'),('missing1'),('missingu'),('missingyou'),('mission'),('mission1'),('mission123'),('mission2'),('missionary'),('missions'),('mississipp'),('mississippi'),('mississippi1'),('misskitty'),('misskitty1'),('missme'),('missmolly'),('missouri'),('missouri1'),('misspiggy'),('misspiggy1'),('misspriss'),('misspriss1'),('missthang'),('missthang1'),('missy'),('missy01'),('missy08'),('missy1'),('missy10'),('missy101'),('missy11'),('missy12'),('missy123'),('missy1234'),('missy13'),('missy14'),('missy2'),('missy21'),('missy22'),('missy23'),('missy3'),('missy4'),('missy5'),('missy6'),('missy69'),('missy7'),('missy8'),('missydog'),('missymoo'),('missyou'),('missyou1'),('missyou2'),('mistake'),('mistake1'),('mister'),('mister1'),('mister12'),('mister123'),('mister2'),('misterio'),('mistero'),('misterx'),('mistery'),('mistic'),('mistica'),('mistico'),('mistie'),('mistigri'),('mistral'),('mistress'),('mistress1'),('mistrz'),('misty'),('misty01'),('misty1'),('misty11'),('misty12'),('misty123'),('misty13'),('misty2'),('misty5'),('misty7'),('mistyblue'),('mistycat'),('mistydog'),('mit'),('mitali'),('mitch'),('mitch1'),('mitch123'),('mitchel'),('mitchel1'),('mitchell'),('mitchell1'),('mitchell12'),('mitchell2'),('mitchie'),('mitchy'),('mithrandir'),('mithun'),('mitia159'),('mitica'),('mitico'),('mito.lo'),('mitsou'),('mitsubishi'),('mittal'),('mitten'),('mittens'),('mittens1'),('mittens2'),('mityukova.anya'),('mitzi'),('mitzi1'),('mitzie'),('miuaybecv'),('miumiu'),('mivida'),('mivida1'),('mividaloca'),('mixail'),('mixaxa2003'),('mixmaster'),('mixtape'),('mixtape1'),('miyaka'),('miyamoto'),('miyavi'),('miyuki'),('miyvarxar'),('mizio970'),('mizpah'),('mizuki'),('mizuno'),('mizzou'),('mizzou1'),('mj1234'),('mj12345'),('mj123456'),('mj2323'),('mj2345'),('mjdh065'),('mjdsf11'),('mjmj12'),('mjmjmj'),('mjolnir'),('mjordan'),('mjordan23'),('mjuan5ogm'),('mk1234'),('mk123456'),('mkal2707'),('mkalancea'),('mkjhgf1996'),('mklmkl22'),('mkmkmk'),('mknaxhxeh8yp3tf'),('mko09ijn'),('mko0nji9'),('mkolendzyan'),('mkomko'),('mks.01'),('mks33'),('mkvdari'),('mlb229'),('MLqdakf8yt'),('mm'),('mm123123'),('mm1234'),('mm12345'),('mm123456'),('mm170667'),('MM744m1'),('mmakssimka'),('mmedinaa'),('mmklub'),('mmm'),('mmm111'),('mmm123'),('mmm333'),('mmm666'),('mmmm'),('mmmmm'),('mmmmm1'),('mmmmmm'),('mmmmmm1'),('mmmmmm6'),('mmmmmmm'),('mmmmmmm1'),('mmmmmmmm'),('mmmmmmmmm'),('mmmmmmmmmm'),('mmmnnn'),('mmo110110'),('mmouse'),('mnb123'),('mnbmnb'),('mNbmNbmNb'),('mnbv'),('mnbvc'),('mnbvc1'),('mnbvcx'),('mnbvcx1'),('mnbvcxy'),('mnbvcxz'),('mnbvcxz1'),('mnbvcxz12'),('mnbvcxz123'),('mnenrad6983616'),('mnmnmn'),('mo'),('mo1234'),('mo123456'),('mob123'),('mob4life'),('mobbdeep'),('mobil'),('mobil1'),('mobila'),('mobile'),('mobile1'),('mobile123'),('mobiline_b'),('mobius'),('mobius1'),('mobster'),('mobster1'),('mobsters1'),('mobydick'),('moc.oohay'),('mocanuv'),('mocha'),('mocha1'),('mocha123'),('mockingbird'),('moctar'),('Mod7tygrysow'),('model'),('model1'),('model123'),('modeling'),('modeling1'),('modelo'),('models'),('models1'),('modem'),('modena'),('modern'),('modern1'),('moderncombat'),('modernwarf'),('modernwarfare'),('modernwarfare2'),('modest'),('modesto'),('modesto1'),('modesto209'),('modified'),('modupe'),('moe'),('moe123'),('moeder'),('moejoe'),('moemoe'),('moemoe1'),('mogul'),('mogwai'),('mogychajagopa'),('moh'),('moh123'),('mohamad'),('mohamed'),('mohamed1'),('mohamed12'),('mohamed123'),('mohammad'),('mohammad1'),('mohammed'),('mohammed1'),('mohammed123'),('mohan'),('mohan123'),('mohana'),('mohanlal'),('mohawk'),('mohawk1'),('mohini'),('mohit'),('mohitb123'),('mohsen'),('mohsin'),('moi'),('moi123'),('moiettoi'),('moimeme'),('moimoi'),('moimoi1'),('moimoimoi'),('moinmoin'),('moises'),('moises1'),('mojehaslo'),('mojisola'),('mojito'),('mojo'),('mojo12'),('mojo123'),('mojo69'),('mojojojo'),('mojojojo1'),('mojomojo'),('mojurus5575566'),('mokona'),('mokong'),('moksha'),('mol'),('mol.kos'),('molchanova_tlt'),('moldova'),('moliere'),('molina'),('molina1'),('molko24bog'),('molley'),('mollie'),('mollie01'),('mollie1'),('mollie12'),('mollie123'),('mollie2'),('molly'),('molly!'),('molly01'),('molly06'),('molly07'),('molly08'),('molly09'),('molly1'),('molly10'),('molly101'),('molly11'),('molly12'),('molly123'),('molly1234'),('molly13'),('molly14'),('molly15'),('molly2'),('molly21'),('molly22'),('molly23'),('molly24'),('molly3'),('molly4'),('molly5'),('molly6'),('molly69'),('molly7'),('molly8'),('molly9'),('molly99'),('mollyb'),('mollycat'),('mollydog'),('mollydog1'),('mollygirl'),('mollygirl1'),('mollymolly'),('mollymoo'),('mollymoo1'),('mollys'),('moloko'),('molotok'),('molotov'),('molson'),('molson1'),('mom'),('mom&dad'),('mom101'),('mom123'),('mom1234'),('mom12345'),('mom4life'),('momanddad'),('momanddad1'),('momanddad2'),('mombasa'),('momdad'),('momdad1'),('momdad12'),('momdad123'),('momdad2'),('moment'),('moments'),('momentum'),('momma'),('momma1'),('momma12'),('momma123'),('momma2'),('momma3'),('mommasboy1'),('mommie'),('mommie1'),('mommie2'),('mommom'),('mommom1'),('mommy'),('mommy!'),('mommy#1'),('mommy01'),('mommy02'),('mommy03'),('mommy06'),('mommy07'),('mommy08'),('mommy09'),('mommy1'),('mommy10'),('mommy101'),('mommy11'),('mommy12'),('mommy123'),('mommy1234'),('mommy13'),('mommy14'),('mommy143'),('mommy15'),('mommy16'),('mommy18'),('mommy2'),('mommy21'),('mommy22'),('mommy23'),('mommy24'),('mommy25'),('mommy27'),('mommy2be'),('mommy3'),('mommy30'),('mommy32'),('mommy33'),('mommy34'),('mommy4'),('mommy5'),('mommy6'),('mommy69'),('mommy7'),('mommy77'),('mommy8'),('mommy9'),('mommydaddy'),('mommygirl1'),('mommyof2'),('mommyof3'),('mommyof4'),('mommys'),('mommys1'),('mommysgirl'),('momndad'),('momndad1'),('momo'),('momo10'),('momo11'),('momo12'),('momo123'),('momo1234'),('momo13'),('momo22'),('momof2'),('momof3'),('momof4'),('momof5'),('momof6'),('momoko'),('momomo'),('momomo1'),('momomomo'),('momoney'),('momoney1'),('momsgirl1'),('mon'),('mon123'),('mona'),('mona12'),('mona123'),('mona1234'),('monaco'),('monaco1'),('monae1'),('monaghan'),('monalisa'),('monalisa1'),('monaliza'),('monaliza2786'),('monami'),('monamona'),('monamour'),('monange'),('monarch'),('monarch1'),('monaro'),('monbebe'),('moncheri'),('monchi'),('moncho'),('moncoeur'),('monday'),('monday01'),('monday1'),('monday11'),('monday12'),('monday123'),('monday2'),('mondeo'),('mondeo1'),('mondieu'),('mondragon'),('monella'),('monet'),('monet1'),('monette'),('money'),('money!'),('money$'),('money$$'),('money.'),('money0'),('money00'),('money007'),('money01'),('money05'),('money06'),('money07'),('money08'),('money09'),('money1'),('money10'),('money100'),('money1000'),('money101'),('money11'),('money111'),('money12'),('money123'),('money1234'),('money12345'),('money13'),('money14'),('money15'),('money16'),('money17'),('money18'),('money19'),('money2'),('money20'),('money2007'),('money2008'),('money2009'),('money2010'),('money2011'),('money21'),('money22'),('money23'),('money24'),('money247'),('money25'),('money26'),('money27'),('money3'),('money32'),('money321'),('money33'),('money34'),('money4'),('money420'),('money44'),('money45'),('money4940'),('money4life'),('money4me'),('money5'),('money55'),('money56'),('money6'),('money66'),('money666'),('money69'),('money7'),('money77'),('money777'),('money8'),('money88'),('money888'),('money89'),('money9'),('money99'),('moneybag'),('moneybags'),('moneybags1'),('moneyboy'),('moneyboy1'),('moneymaker'),('moneyman'),('moneyman1'),('moneyman12'),('moneyman2'),('moneyman87'),('Moneyme56'),('moneymike1'),('moneymoney'),('moneys'),('moneys1'),('moneytalks'),('moneyy'),('moneyy1'),('mongo'),('mongo1'),('mongol'),('mongolia'),('mongoose'),('mongoose1'),('moni'),('moni123'),('monia'),('monica'),('monica.'),('monica01'),('monica1'),('monica10'),('monica11'),('monica12'),('monica123'),('monica13'),('monica14'),('monica15'),('monica2'),('monica21'),('monica22'),('monica23'),('monica3'),('monica5'),('monica69'),('monica7'),('monies'),('monika'),('monika1'),('monika11'),('monika12'),('monika123'),('monimoni'),('monina'),('monique'),('monique01'),('monique1'),('monique11'),('monique12'),('monique123'),('monique13'),('monique2'),('monique21'),('monique23'),('monique3'),('monique4'),('monique5'),('monique7'),('monisha'),('monisia'),('monita'),('monito'),('monitor'),('monitor1'),('monk'),('monk3y'),('monkee'),('monkey'),('monkey!'),('monkey.'),('monkey0'),('monkey00'),('monkey007'),('monkey01'),('monkey02'),('monkey03'),('monkey04'),('monkey05'),('monkey06'),('monkey07'),('monkey08'),('monkey09'),('monkey1'),('monkey10'),('monkey100'),('monkey101'),('monkey11'),('monkey111'),('monkey12'),('monkey123'),('monkey1234'),('monkey12345'),('monkey13'),('monkey14'),('monkey15'),('monkey16'),('monkey17'),('monkey18'),('monkey19'),('monkey2'),('monkey20'),('monkey21'),('monkey22'),('monkey23'),('monkey24'),('monkey25'),('monkey26'),('monkey27'),('monkey28'),('monkey29'),('monkey3'),('monkey30'),('monkey31'),('monkey32'),('monkey321'),('monkey33'),('monkey34'),('monkey4'),('monkey42'),('monkey420'),('monkey44'),('monkey45'),('monkey5'),('monkey55'),('monkey56'),('monkey6'),('monkey66'),('monkey666'),('monkey67'),('monkey68'),('monkey69'),('monkey7'),('monkey76'),('monkey77'),('monkey777'),('monkey78'),('monkey79'),('monkey8'),('monkey80'),('monkey81'),('monkey82'),('monkey83'),('monkey84'),('monkey85'),('monkey86'),('monkey87'),('monkey88'),('monkey89'),('monkey9'),('monkey90'),('monkey91'),('monkey911'),('monkey92'),('monkey93'),('monkey94'),('monkey95'),('monkey96'),('monkey97'),('monkey98'),('monkey99'),('monkeyass1'),('monkeyball'),('monkeyballs'),('monkeyboy'),('monkeyboy1'),('monkeybut1'),('monkeybutt'),('monkeyface'),('monkeygirl'),('monkeylove'),('monkeyman'),('monkeyman1'),('monkeyman2'),('monkeynuts'),('monkeypoo'),('monkeys'),('monkeys!'),('monkeys1'),('monkeys101'),('monkeys11'),('monkeys12'),('monkeys123'),('monkeys13'),('monkeys2'),('monkeys3'),('monkeys4'),('monkeys5'),('monkeys7'),('monkeyz'),('monkfish'),('monkie'),('monkies'),('monkies1'),('monkmonk'),('monmon'),('monmouth'),('mono'),('mono123'),('monolit'),('monolith'),('monomono'),('mononoke'),('monopoli'),('monopoly'),('monopoly1'),('monoxide17'),('monp5haynes'),('monroe'),('monroe1'),('monserrat'),('monsieur'),('monsoon'),('monsoon1'),('monsta'),('monsta1'),('monster'),('monster!'),('monster.'),('monster0'),('monster01'),('monster08'),('monster09'),('monster1'),('monster10'),('monster101'),('monster11'),('monster12'),('monster123'),('monster13'),('monster14'),('monster15'),('monster16'),('monster17'),('monster18'),('monster2'),('monster21'),('monster22'),('monster23'),('monster24'),('monster3'),('monster33'),('monster4'),('monster5'),('monster6'),('monster666'),('monster69'),('monster7'),('monster77'),('monster8'),('monster88'),('monster9'),('monster99'),('monstercha'),('monsters'),('monsters1'),('monstr'),('montag'),('montagna'),('montagne'),('montague'),('montana'),('montana1'),('montana12'),('montana123'),('montana16'),('montana2'),('montana3'),('montana7'),('montano'),('montauk'),('montblanc'),('monte'),('monte1'),('montecarlo'),('montecristo'),('montego'),('monteiro'),('montel'),('montella'),('montenegro'),('monterey'),('monterey1'),('montero'),('montero1'),('monterrey'),('monterrey1'),('montes'),('montesa'),('montessori'),('montevideo'),('montez'),('montez1'),('montgom2409'),('montgomery'),('monthy25'),('montoya'),('montoya1'),('montpellier'),('montre'),('montreal'),('montreal1'),('montrose'),('montse'),('montserrat'),('monty'),('monty1'),('monty123'),('montydog'),('monument'),('monyet'),('moo'),('moo123'),('moochie'),('moochie1'),('moocow'),('moocow1'),('moocow123'),('moocow2'),('moody'),('moody1'),('moogle'),('mookie'),('mookie1'),('mookie12'),('mookie123'),('mookie2'),('moomin'),('moomoo'),('moomoo!'),('moomoo1'),('moomoo11'),('moomoo12'),('moomoo123'),('moomoo2'),('moomoo22'),('moomoo3'),('moomoo7'),('moon'),('moon11'),('moon12'),('moon123'),('moon1234'),('moon13'),('moon22'),('moonbeam'),('moonbeam1'),('moonchild'),('moondance'),('moondog'),('moondog1'),('mooney'),('mooney1'),('moonflower'),('moonie'),('moonie1'),('moonlight'),('moonlight1'),('moonlight2'),('moonlight7'),('moonlite'),('moonman'),('moonman1'),('moonmoon'),('moonpie'),('moonpie1'),('moonraker'),('moonriver'),('moonshadow'),('moonshine'),('moonshine1'),('moonspell'),('moonstar'),('moonstar1'),('moonstone'),('moonwalk'),('moonwalker'),('mooo'),('mooooo'),('moore'),('moore1'),('moorea'),('moose'),('moose1'),('moose11'),('moose12'),('moose123'),('moose13'),('moose2'),('moose3'),('moosehead'),('mooseman'),('mooses'),('mooses1'),('moosey'),('moosey1'),('moosie'),('mopar'),('mopar1'),('moppel'),('moppie'),('mor'),('morado'),('morado1'),('morales'),('morales1'),('morango'),('morangos'),('morbid'),('morbid1'),('mordor'),('mordva1783'),('more'),('moreira'),('morelia'),('morelia1'),('morelle45'),('moremoney'),('moremoney1'),('moremore'),('morena'),('morena1'),('morena13'),('morenaza'),('morenike'),('morenita'),('morenita1'),('morenito'),('moreno'),('moreno1'),('morfeo'),('morgan'),('morgan!'),('morgan.'),('morgan00'),('morgan01'),('morgan02'),('morgan03'),('morgan04'),('morgan05'),('morgan06'),('morgan07'),('morgan08'),('morgan09'),('morgan1'),('morgan10'),('morgan11'),('morgan12'),('morgan123'),('morgan13'),('morgan14'),('morgan15'),('morgan16'),('morgan17'),('morgan18'),('morgan2'),('morgan21'),('morgan22'),('morgan23'),('morgan24'),('morgan3'),('morgan4'),('morgan5'),('morgan6'),('morgan69'),('morgan7'),('morgan8'),('morgan9'),('morgan98'),('morgan99'),('morgana'),('morgana1'),('morgane'),('morgen'),('morgoth'),('moriah'),('moriarty'),('morientes'),('morita'),('moritz'),('moritz1'),('morkovka'),('morley'),('mormon'),('mormon1'),('mormor'),('morning'),('morning1'),('morning21'),('morningstar'),('morocco'),('morocco1'),('morocha'),('moron'),('moron1'),('moroni'),('morozov'),('morozova'),('morozovavalya28'),('morpheus'),('morpheus1'),('morphine'),('morrigan'),('morris'),('morris1'),('morris12'),('morris123'),('morrison'),('morrison1'),('morrissey'),('morrissey1'),('morrow'),('morrowind'),('morrowind1'),('mortadelo'),('mortal'),('mortal1'),('mortalkombat'),('morten'),('mortgage'),('mortgage1'),('morticia'),('mortimer'),('mortimer1'),('mortis'),('morton'),('morton1'),('mosaic'),('moschino'),('moscow'),('moscow1'),('moscowcallin'),('mosdef'),('moses'),('moses1'),('moses123'),('moshco'),('moshkin1998'),('mosima11'),('moskau'),('moskow'),('moskva'),('mosquito'),('moss032'),('moss18'),('moss81'),('moss84'),('mossberg'),('mossimo'),('mossyoak'),('mossyoak1'),('mostafa'),('mostaganem'),('mostar'),('mostro'),('mostwanted'),('mot'),('mot2passe'),('motard'),('motdepasse'),('motdepasse1'),('mother'),('mother!'),('mother.'),('mother01'),('mother02'),('mother03'),('mother1'),('mother10'),('mother11'),('mother12'),('mother123'),('mother1234'),('mother13'),('mother2'),('mother21'),('mother22'),('mother23'),('mother3'),('mother4'),('mother5'),('mother6'),('mother69'),('mother7'),('mother8'),('motherfuck'),('motherfucker'),('motherfucker1'),('motherhood'),('motherland'),('motherlode'),('motherlove'),('mothermary'),('motherof2'),('motherof3'),('motherof4'),('motherof5'),('mothers'),('mothers1'),('motherwell'),('motion'),('motion1'),('motita'),('motivated'),('motivation'),('motley'),('motley1'),('motleycrue'),('motmot'),('moto'),('moto123'),('motocros'),('motocross'),('motocross1'),('motocross2'),('motogp'),('motoguzzi'),('motoko'),('motomoto'),('motor'),('motor1'),('motorbike'),('motorbike1'),('motorcross'),('motorcycle'),('motorhead'),('motorhead1'),('motorka'),('motorola'),('motorola1'),('motorola12'),('motorola2'),('motorolav3'),('motorolla'),('motorrad'),('motors'),('motorsport'),('motown'),('motown1'),('motrya.larina'),('motylek'),('mou'),('mouche'),('mouette'),('mouhamed'),('moulin'),('moulinrouge'),('mouloud'),('mouloudia'),('moumita'),('moumou'),('moumoune'),('mounette'),('mounia'),('mounika'),('mounir'),('mountain'),('mountain1'),('mountain2'),('mountainde'),('mountaindew'),('mountains'),('mountains1'),('mourad'),('mouse'),('mouse1'),('mouse11'),('mouse12'),('mouse123'),('mouse13'),('mouse2'),('mouse3'),('mousepad'),('mouser'),('mouses'),('mousetrap'),('mousey'),('mousey1'),('mousie'),('moussa'),('mousse'),('moustache'),('moustapha'),('moustic'),('moustique'),('mouton'),('movado'),('moveme'),('movement'),('movement1'),('moveon'),('movie'),('movie1'),('movies'),('movies1'),('moviestar'),('moving'),('movingon'),('movingon1'),('movistar'),('mowgli'),('moxie1'),('moymoy'),('mozart'),('mozart1'),('mozellbranou81e'),('mozilla'),('mozilla1'),('mp3mp3'),('mp3player'),('mpc2000'),('mpeater'),('mpnaduysi'),('mpower'),('mr'),('mr.stas192'),('mr1234'),('mrbean'),('mrbear'),('mrcool'),('mrdmarina'),('mrf11277215'),('mrkitty'),('mrkitty1'),('mrmagoo'),('mrniceguy'),('mrs.brown'),('ms'),('ms.cc.gg'),('ms.dolgikh'),('ms.polza'),('ms0083jxj'),('ms1234'),('ms123456'),('mshelp12'),('mskitty'),('msn123'),('msnmsn'),('MTIzNDU2'),('mtndew'),('mu'),('mu080295'),('mu0LFpv2'),('muaythai'),('muaythai1'),('mubarak'),('muchacha'),('muchlove'),('muckel'),('mudar123'),('muddy1'),('mudkip'),('mudok'),('mudvayne'),('mudvayne1'),('mueller'),('muenchen'),('muerte'),('mufasa'),('mufasa1'),('muff1n'),('muffdiver'),('muffie'),('muffin'),('muffin!'),('muffin01'),('muffin1'),('muffin10'),('muffin11'),('muffin12'),('muffin123'),('muffin13'),('muffin14'),('muffin2'),('muffin21'),('muffin22'),('muffin23'),('muffin3'),('muffin4'),('muffin5'),('muffin6'),('muffin69'),('muffin7'),('muffinman'),('muffinman1'),('muffins'),('muffins1'),('muffy'),('muffy1'),('muggins'),('muggle'),('muggsy'),('mughal'),('mugsy1'),('mugwell15'),('mugwump'),('muhaha'),('muhamad'),('muhamed'),('muhammad'),('muhammad1'),('muhammed'),('muhammet'),('muhkuh'),('muhon'),('muhtar'),('mujahid'),('mujeres'),('mukesh'),('mul'),('mulberry'),('mulder'),('mulder1'),('mullen'),('mullen1'),('muller'),('mullet'),('mullet1'),('mulligan'),('mulligan1'),('mullins'),('multan'),('multik'),('multimedia'),('multipass'),('multipla'),('multiplelog'),('multisync'),('mum'),('mum123'),('mumanddad'),('mumanddad1'),('mumbai'),('mumdad'),('mumdad1'),('mummum'),('mummy'),('mummy1'),('mummy123'),('mummy2'),('mummydaddy'),('mummypapa'),('mummys'),('mumtaz'),('mumu'),('mumumu'),('munch'),('munch1'),('munchen'),('munchie'),('munchie1'),('munchies'),('munchies1'),('munchkin'),('munchkin1'),('munchy'),('munchy1'),('mundial'),('muneca'),('muneca1'),('munich'),('municipal'),('munira'),('munkey'),('munkey1'),('munmun'),('munna'),('munnabhai'),('munson'),('munster'),('munster1'),('muppet'),('muppet1'),('muppets'),('mur'),('murakami'),('murali'),('murano'),('murat'),('murat123'),('muratti'),('murcia'),('murcielago'),('murda1'),('murder'),('murder1'),('murder187'),('murder666'),('murdoch'),('murdock'),('murdock1'),('murena'),('muriel'),('murielle'),('murillo'),('murilo'),('murmansk'),('murmur'),('murphy'),('murphy01'),('murphy1'),('murphy10'),('murphy11'),('murphy12'),('murphy123'),('murphy13'),('murphy2'),('murphy22'),('murphy3'),('murphy7'),('murray'),('murray1'),('murtaza'),('murthy'),('muruga'),('murugan'),('murzik'),('murzilka'),('mus'),('musa'),('musa123'),('musa123456'),('musashi'),('musashi1'),('muscat'),('muschi'),('muschi1'),('muscle'),('muscle1'),('muscles'),('muscles1'),('muse'),('museum'),('mushka'),('mushr00m'),('mushroom'),('mushroom1'),('mushroomka'),('mushrooms'),('mushrooms1'),('music'),('music!'),('music.'),('music000'),('music01'),('music06'),('music07'),('music08'),('music09'),('music1'),('music10'),('music101'),('music11'),('music12'),('music123'),('music1234'),('music12345'),('music13'),('music14'),('music15'),('music16'),('music17'),('music18'),('music2'),('music2008'),('music2009'),('music2010'),('music21'),('music22'),('music23'),('music24'),('music25'),('music3'),('music4'),('music40'),('music45'),('music4ever'),('music4life'),('music4me'),('music4u'),('music5'),('music6'),('music666'),('music69'),('music7'),('music77'),('music8'),('music88'),('music9'),('music99'),('music=life'),('musica'),('musica.'),('musica1'),('musica10'),('musica123'),('musica2'),('musical'),('musical1'),('musicas'),('musicbox'),('musician'),('musician1'),('musicislif'),('musicislife'),('musick'),('musiclove1'),('musiclover'),('musicman'),('musicman1'),('musicmusic'),('musico'),('musicovery'),('musicrocks'),('musics'),('musift10'),('musik'),('musik1'),('musika'),('musique'),('musique1'),('muskaan'),('muskan'),('muskie'),('muslim'),('muslim1'),('muslimah'),('mussolini'),('mustafa'),('mustafa1'),('mustafa123'),('mustang'),('mustang!'),('mustang.'),('mustang00'),('mustang01'),('mustang02'),('mustang03'),('mustang04'),('mustang05'),('mustang06'),('mustang07'),('mustang08'),('mustang09'),('mustang1'),('mustang10'),('mustang11'),('mustang12'),('mustang123'),('mustang13'),('mustang14'),('mustang2'),('mustang200'),('mustang21'),('mustang22'),('mustang23'),('mustang24'),('mustang3'),('mustang302'),('mustang4'),('mustang5'),('mustang5.0'),('mustang50'),('mustang500'),('mustang6'),('mustang64'),('mustang65'),('mustang66'),('mustang67'),('mustang68'),('mustang69'),('mustang7'),('mustang73'),('mustang77'),('mustang8'),('mustang86'),('mustang87'),('mustang88'),('mustang89'),('mustang9'),('mustang90'),('mustang91'),('mustang92'),('mustang93'),('mustang94'),('mustang95'),('mustang96'),('mustang97'),('mustang98'),('mustang99'),('mustanggt'),('mustanggt1'),('mustangs'),('mustangs1'),('mustapha'),('mustard'),('mustard1'),('musyka85'),('mutabor'),('mutalim.gusenov'),('mutant'),('muthafucka'),('muthoni'),('mutiara'),('mutley'),('mutley1'),('mutter'),('mutter1'),('muttley'),('muttley1'),('mutual'),('muyiwa'),('muzaffar'),('muzica'),('muziek'),('muzik1'),('muzika'),('muzyka'),('mV46VkMz10'),('mvick7'),('mvp123'),('mw0501'),('mw0720'),('mwangi'),('mxyzptlk'),('my'),('my-space'),('my.space'),('my1234'),('my123456'),('my1andonly'),('my1baby'),('my1love'),('my1space'),('my1stlove'),('my204856'),('my2angels'),('my2babies'),('my2boys'),('my2boyz'),('my2cats'),('my2dogs'),('my2girls'),('my2kids'),('my2sons'),('my3angels'),('my3babies'),('my3boys'),('my3dogs'),('my3girls'),('my3kids'),('my3loves'),('my3sons'),('my4babies'),('my4boys'),('my4girls'),('my4kids'),('my4sons'),('my5kids'),('my6kids'),('mya123'),('myaccount'),('myaccount1'),('myangel'),('myangel1'),('myangels'),('myass1'),('mybabe'),('mybabe1'),('mybabies'),('mybabies1'),('mybabies2'),('mybabies3'),('mybaby'),('mybaby!'),('mybaby01'),('mybaby07'),('mybaby08'),('mybaby09'),('mybaby1'),('mybaby12'),('mybaby123'),('mybaby13'),('mybaby2'),('mybaby3'),('mybaby4'),('mybaby7'),('mybabyboy'),('mybabyboy1'),('mybabygirl'),('myband1'),('mybirthday'),('mybitch'),('mybitch1'),('myblocker'),('myboo'),('myboo1'),('myboo2'),('mybossmyhero1'),('myboys'),('myboys1'),('myboys2'),('myboys3'),('mybrother'),('mybuddy'),('mybuddy1'),('mybusiness'),('mycats'),('mychem1'),('mychemical'),('mychemicalromance'),('mychildren'),('mycomputer'),('mydad1'),('mydaddy'),('mydaddy1'),('mydarling'),('mydear'),('mydestiny'),('mydick'),('mydick1'),('mydog'),('mydog1'),('mydogs'),('mydream'),('mydreams'),('myebiz123'),('myemail'),('myface'),('myfamily'),('myfamily1'),('myfamily4'),('myfamily5'),('myfather'),('myfriend'),('myfriend1'),('myfriends'),('myfriends1'),('myfuture'),('mygame'),('mygirl'),('mygirl1'),('mygirl2'),('mygirls'),('mygirls1'),('mygirls2'),('mygirls3'),('mygirls4'),('mygod1'),('mygodisgood'),('myheart'),('myheart1'),('myhero'),('myhome'),('myhoney'),('myhoney1'),('myhope'),('myhouse'),('myhouse1'),('myhumps1'),('myhusband'),('myindia'),('myjesus'),('myjesus1'),('myjobs'),('mykids'),('mykids02'),('mykids03'),('mykids04'),('mykids1'),('mykids123'),('mykids2'),('mykids3'),('mykids4'),('mykids5'),('myking'),('mykonos'),('myl0ve'),('mylady'),('mylastfm'),('mylene'),('myles'),('myles1'),('mylfard'),('mylife'),('mylife08'),('mylife09'),('mylife1'),('mylife11'),('mylife12'),('mylife123'),('mylife2'),('mylife3'),('mylink'),('mylinkedin'),('mylord'),('mylord1'),('mylove'),('mylove!'),('mylove.'),('mylove01'),('mylove07'),('mylove08'),('mylove09'),('mylove1'),('mylove10'),('mylove11'),('mylove12'),('mylove123'),('mylove1234'),('mylove12345'),('mylove13'),('mylove14'),('mylove15'),('mylove16'),('mylove18'),('mylove2'),('mylove21'),('mylove22'),('mylove23'),('mylove24'),('mylove3'),('mylove4'),('mylove4u'),('mylove5'),('mylove6'),('mylove69'),('mylove7'),('mylovely'),('myloveone'),('mylover'),('mylover1'),('myloves'),('mymail'),('mymama'),('myman1'),('mymom1'),('mymommy'),('mymommy1'),('mymoney'),('mymoney1'),('mymother'),('mymother1'),('mymummy'),('mymusic'),('mymusic1'),('mymymy'),('mymyspace'),('mymyspace1'),('myname'),('myname1'),('myname12'),('myname123'),('myname2'),('mynameis'),('mynameis1'),('mynameiskhan'),('mynewlife'),('mynigga'),('mynigga1'),('mynoob'),('mynumber1'),('myonly1'),('myparents'),('mypass'),('mypass1'),('mypass123'),('mypassphrase'),('mypassw0rd'),('mypassword'),('mypassword1'),('myplace'),('myplace1'),('myprince'),('myprincess'),('myriam'),('myrtille'),('myrtle'),('myrtle1'),('myschool'),('mysecret'),('mysecret1'),('myself'),('myself1'),('myself123'),('myself2'),('myshit'),('myshit1'),('mysister'),('myson1'),('mysons'),('mysore'),('mysoul'),('mysp'),('mysp4c3'),('mysp4ce'),('mysp@ce'),('myspac3'),('myspace'),('myspace!'),('myspace#1'),('myspace*'),('myspace.'),('myspace.1'),('myspace.co'),('myspace0'),('myspace00'),('myspace001'),('myspace007'),('myspace01'),('myspace02'),('myspace03'),('myspace05'),('myspace06'),('myspace07'),('myspace08'),('myspace09'),('myspace1'),('myspace1!'),('myspace10'),('myspace100'),('myspace101'),('myspace11'),('myspace111'),('myspace12'),('myspace121'),('myspace123'),('myspace13'),('myspace14'),('myspace15'),('myspace16'),('myspace17'),('myspace18'),('myspace19'),('myspace197'),('myspace198'),('myspace199'),('myspace2'),('myspace20'),('myspace200'),('myspace201'),('myspace21'),('myspace22'),('myspace23'),('myspace24'),('myspace25'),('myspace26'),('myspace27'),('myspace28'),('myspace29'),('myspace3'),('myspace30'),('myspace31'),('myspace32'),('myspace321'),('myspace33'),('myspace34'),('myspace4'),('myspace420'),('myspace44'),('myspace45'),('myspace4me'),('myspace5'),('myspace55'),('myspace56'),('myspace6'),('myspace66'),('myspace666'),('myspace67'),('myspace69'),('myspace7'),('myspace75'),('myspace76'),('myspace77'),('myspace777'),('myspace78'),('myspace79'),('myspace8'),('myspace81'),('myspace82'),('myspace83'),('myspace84'),('myspace85'),('myspace86'),('myspace87'),('myspace88'),('myspace89'),('myspace9'),('myspace90'),('myspace91'),('myspace92'),('myspace93'),('myspace94'),('myspace95'),('myspace96'),('myspace98'),('myspace99'),('myspace999'),('myspace?'),('myspacepas'),('myspacesuc'),('mystere'),('mysterio'),('mysterio1'),('mysterio61'),('mysterio619'),('mysterious'),('mystery'),('mystery1'),('mystic'),('mystic1'),('mystical'),('mystical1'),('mystikal'),('mystique'),('mystuff'),('mystuff1'),('myszka'),('myszka1'),('mythology'),('mythreesons'),('mytime'),('mytime1'),('mywife'),('mywife1'),('myword'),('myworld'),('myworld1'),('myyolo'),('myzone'),('myzoosk'),('my_komp_777'),('my_space'),('mz.sexy'),('mzyankin'),('n'),('n.kmgfy'),('n00dle'),('n00dles'),('N0=Acc3ss'),('n0thing'),('n0vember'),('n111011'),('n12345'),('n123456'),('n1234567'),('n12345678'),('n123456789'),('n1cholas'),('n1cole'),('n1frdz'),('n1gger'),('n1n2n3'),('n1rvana'),('n2deep'),('n2XcFgjCvr'),('N8ZGT5P0sHw='),('na'),('nabeel'),('nabil'),('nabila'),('nabilah'),('nachito'),('nacho'),('nacho1'),('nacho123'),('nachos'),('nachos1'),('nacional'),('nacional1'),('nacional10'),('nad'),('nad123'),('nada'),('nada123'),('nadanada'),('nadeem'),('nadegda'),('nadege'),('nadejda'),('nadezda'),('nadezhda'),('nadia'),('nadia1'),('nadia123'),('nadine'),('nadine1'),('nadine123'),('nadira'),('nadiya'),('nadjaem'),('nadroj'),('nadya'),('naenae'),('naenae1'),('nafanya'),('nafisa'),('nafnaf'),('nagamani'),('nagano'),('nagaraju'),('nagasaki'),('nagato'),('nagel'),('nagendra'),('nagesh'),('nagrom'),('nahuel'),('naiara'),('nailpolish'),('nails1'),('naima'),('nairobi'),('nakamura'),('nakata'),('naked'),('naked1'),('nakita'),('nakita1'),('nala'),('nala123'),('naledi'),('nalini'),('nallepuh'),('nam123'),('namaskar'),('namaste'),('namaste1'),('namaste78'),('name'),('name123'),('nameles'),('nameless'),('nameless1'),('namibia'),('namita'),('namnam'),('namour'),('namrata'),('nan'),('nan123'),('nana'),('nana01'),('nana06'),('nana07'),('nana08'),('nana09'),('nana10'),('nana11'),('nana12'),('nana123'),('nana1234'),('nana13'),('nana14'),('nana15'),('nana16'),('nana18'),('nana21'),('nana22'),('nana23'),('nanakwame'),('nanana'),('nanana1'),('nananana'),('nanay'),('nanayaw'),('nancy'),('nancy1'),('nancy12'),('nancy123'),('nancy13'),('nancy2'),('nancydrew'),('nanda'),('nanda123'),('nandan'),('nandhini'),('nandini'),('nandita'),('nando'),('nando1'),('nando123'),('nanette'),('nani'),('nani123'),('nani17'),('nanita'),('nanito'),('nanna'),('nanna1'),('nannan'),('nanner'),('nannie'),('nanny'),('nanny1'),('nanny123'),('nano'),('nano123'),('nanonano'),('nanook'),('nanook1'),('nanou'),('nanou4552'),('nantes'),('nantes44'),('nantucket'),('naomi'),('naomi1'),('naomi123'),('naomie'),('naosei'),('napalm'),('naples'),('naples1'),('napolean'),('napoleon'),('napoleon1'),('napoleone'),('napoletano'),('napoli'),('napoli1'),('napoli10'),('napoli1926'),('nappy1'),('napster'),('napster1'),('nar'),('naranja'),('narashchivaiunoghti'),('narasimha'),('narayan'),('narayana'),('narayanan'),('narcis'),('narciso'),('narcisse'),('narendra'),('naresh'),('nargis'),('nargiz-a'),('nargiza'),('nariman'),('narkoman'),('narnia'),('narnia1'),('naruhina'),('narusegawa'),('narut0'),('naruto'),('naruto!'),('naruto.'),('naruto0'),('naruto00'),('naruto01'),('naruto07'),('naruto08'),('naruto09'),('naruto1'),('naruto10'),('naruto100'),('naruto101'),('naruto11'),('naruto12'),('naruto123'),('naruto1234'),('naruto13'),('naruto14'),('naruto15'),('naruto16'),('naruto17'),('naruto18'),('naruto19'),('naruto2'),('naruto20'),('naruto21'),('naruto22'),('naruto23'),('naruto24'),('naruto25'),('naruto3'),('naruto33'),('naruto4'),('naruto45'),('naruto5'),('naruto55'),('naruto6'),('naruto666'),('naruto69'),('naruto7'),('naruto77'),('naruto8'),('naruto88'),('naruto89'),('naruto9'),('naruto90'),('naruto91'),('naruto92'),('Naruto924'),('naruto93'),('naruto94'),('naruto95'),('naruto96'),('naruto97'),('naruto98'),('naruto99'),('narutofan1'),('narutokun'),('narutouzumaki'),('nas'),('nas123'),('nasa'),('nasaud'),('nascar'),('nascar01'),('nascar03'),('nascar08'),('nascar09'),('nascar1'),('nascar11'),('nascar12'),('nascar123'),('nascar14'),('nascar17'),('nascar18'),('nascar2'),('nascar20'),('nascar24'),('nascar29'),('nascar3'),('nascar38'),('nascar48'),('nascar6'),('nascar8'),('nascar88'),('nascar9'),('nascar99'),('nascimento'),('nasdaq'),('naseem'),('nasfat12'),('nash'),('nash13'),('nashi1996'),('nashville'),('nashville1'),('nasigoreng'),('nasir1'),('nasrat'),('nasreen'),('nasrin'),('nassau'),('nasser'),('nassim'),('nassima'),('nastasia'),('nastena'),('nastenabendel'),('nastenka'),('nastia'),('nastik'),('nastina33592'),('nastja'),('nastusha'),('nasty'),('nasty1'),('nasty123'),('nasty69'),('nastya'),('nastya-b86'),('nastya1'),('nastya12'),('nastya123'),('nastya1995'),('nastya1996'),('nastya1997'),('nastya1998'),('nastya2010'),('nastyaanciferova'),('nastyanastya'),('nastygirl'),('nastygirl1'),('nat'),('nat123'),('nat5g'),('nata'),('nata12'),('nata123'),('nata271283'),('natacha'),('natacion'),('nataha'),('natala'),('natale'),('natalee'),('natali'),('natali1'),('natalia'),('natalia1'),('natalia12'),('natalia123'),('natalia2'),('natalie'),('natalie!'),('natalie01'),('natalie06'),('natalie07'),('natalie08'),('natalie1'),('natalie10'),('natalie11'),('natalie12'),('natalie123'),('natalie13'),('natalie2'),('natalie23'),('natalie3'),('natalie4'),('natalie5'),('natalie7'),('natalie8'),('natalie9'),('natalija'),('natalina'),('nataliya'),('nataliystre'),('natalja'),('natalka'),('natalka1'),('nataly'),('nataly1'),('natalya'),('natalya.dmitrieva.1978'),('natanael'),('natanata'),('natas666'),('natasa'),('natascha'),('natasha'),('natasha1'),('natasha11'),('natasha12'),('natasha123'),('natasha13'),('natasha2'),('natasha3'),('natasha7'),('natasha_19.65'),('natashka'),('natation'),('natatuma79'),('natawa'),('nataxa'),('nata_titj25'),('nate'),('nate01'),('nate11'),('nate12'),('nate123'),('nate1234'),('nate13'),('nate23'),('natedog'),('natedog1'),('natedogg'),('natedogg1'),('nath'),('nathalia'),('nathalie'),('nathalie1'),('nathaly'),('nathan'),('nathan!'),('nathan.'),('nathan00'),('nathan01'),('nathan02'),('nathan03'),('nathan04'),('nathan05'),('nathan06'),('nathan07'),('nathan08'),('nathan09'),('nathan1'),('nathan10'),('nathan11'),('nathan12'),('nathan123'),('nathan1234'),('nathan13'),('nathan14'),('nathan15'),('nathan16'),('nathan17'),('nathan18'),('nathan19'),('nathan2'),('nathan21'),('nathan22'),('nathan23'),('nathan24'),('nathan3'),('nathan4'),('nathan5'),('nathan6'),('nathan69'),('nathan7'),('nathan8'),('nathan9'),('nathan98'),('nathan99'),('nathanael'),('nathaniel'),('nathaniel1'),('nathaniel2'),('nathen'),('nathen1'),('nati.beridze.92'),('natiichen999'),('nation'),('nation1'),('national'),('national1'),('native'),('native1'),('natividad'),('natnat'),('natnat1'),('natsume'),('natty'),('natty1'),('natura'),('natural'),('natural1'),('nature'),('nature1'),('natureza'),('natusik'),('naty123'),('naufal'),('naughty'),('naughty1'),('naughty69'),('nausicaa'),('nautica'),('nautica1'),('nautical'),('nautilus'),('navajo'),('navara'),('navarro'),('navarro1'),('naveed'),('naveen'),('navidad'),('navigator'),('navigator1'),('navneet'),('navy'),('navyblue'),('navyseal'),('navyseal1'),('navyseals'),('nay123'),('nayana'),('nayara'),('nayarit1'),('nayeli'),('nayeli1'),('naynay'),('naynay1'),('naynay12'),('naynay123'),('naynay2'),('naz-74'),('naz123'),('nazanin'),('nazar'),('nazareno'),('nazaret'),('nazareth'),('nazarov'),('nazarova'),('nazgul'),('nazira'),('nb'),('nba123'),('nbalive'),('nbanba'),('nbibyf'),('nbnfybr'),('nbuhbwf'),('nbuhtyjr'),('NBvBB32fa9'),('nbvcxw'),('nbvcxz'),('nbvehrf'),('nbvfnb'),('nbvjatq'),('nbvjif'),('nbvjirf'),('nbvjityrj'),('ncaBeax2vx'),('ncc-1701'),('ncc1701'),('ncc1701a'),('ncc1701d'),('ncc1701e'),('ncc74656'),('ncstate1'),('nd2Ia8v8aZ'),('nd4spd'),('ndaCebx2wx'),('ndubuisi'),('ne'),('ne1469'),('nebraska'),('nebraska1'),('nebula'),('necaxa'),('necro666'),('necromancer'),('necronomicon'),('nectar'),('nectar2011'),('nederland'),('nederland1'),('nedved'),('nedved11'),('need'),('need4speed'),('needajob'),('needforspeed'),('needjob'),('needle'),('needles'),('needletail'),('needlove'),('needmoney'),('needwork'),('neelam'),('neelima'),('neenee'),('neenee1'),('neeraj'),('nefertari'),('nefertiti'),('negative'),('negative1'),('neger123'),('negra'),('negra1'),('negrita'),('negrita1'),('negrito'),('negrito1'),('negro'),('negro1'),('negro123'),('negros'),('neguinha'),('neha'),('neha123'),('nehemiah'),('nehemiah1'),('neighbor'),('neil'),('neisha'),('neisha1'),('nekoneko'),('nelinka'),('nellie'),('nellie1'),('nelly'),('nelly1'),('nelly12'),('nelly123'),('nelly2'),('nelson'),('nelson01'),('nelson1'),('nelson11'),('nelson12'),('nelson123'),('nelson2'),('nemanja'),('nemesis'),('nemesis1'),('nemezida'),('nemo'),('nemo11'),('nemo12'),('nemo123'),('nemochkao1975'),('nemonemo'),('nemtudom'),('nena'),('nena11'),('nena12'),('nena123'),('nena13'),('nena14'),('nena15'),('nena23'),('nenalinda'),('nene'),('nene10'),('nene11'),('nene12'),('nene123'),('nene13'),('nene14'),('nene15'),('nene16'),('nene23'),('nenene'),('neneng'),('nenette'),('neng2000'),('nenita'),('nenita1'),('neo'),('neo123'),('neogeo'),('neon'),('neoneo'),('neopet'),('neopet12'),('neopets'),('neopets1'),('neopets10'),('neopets11'),('neopets12'),('neopets13'),('neopets22'),('neophyte'),('nepal'),('nepal1'),('nepal123'),('nepali'),('nepenthe'),('nephew'),('nephilim'),('neptun'),('neptune'),('neptune1'),('nerd'),('nerd123'),('nerina'),('nerissa'),('nermal'),('nermin'),('nero'),('nerone'),('neronero'),('neruda'),('nesakysiu'),('nescafe'),('nesha1'),('neslihan'),('neslyxovska'),('nesrine'),('ness'),('nessa'),('nessa1'),('nessa12'),('nessa123'),('nessa1234'),('nessie'),('nessie1'),('nessuna'),('nessuno'),('nestea'),('nester'),('nestle'),('nestle1'),('nestor'),('nestor1'),('net'),('net123'),('netball'),('netball1'),('netgear'),('netgear1'),('netlog'),('netnet'),('netscape'),('netscape1'),('netti-88'),('nettie'),('nettie1'),('netwerk'),('network'),('network1'),('network123'),('networking'),('networks'),('neuken'),('neumann'),('neutron'),('nevada'),('nevada1'),('nevaeh'),('nevaeh06'),('nevaeh07'),('nevaeh08'),('nevaeh1'),('nevaeh2'),('never'),('never1'),('never123'),('never2'),('never4get'),('neveragain'),('neverdie'),('neverever'),('neverever1'),('neverforget'),('nevergiveu'),('nevergiveup'),('neverguess'),('neverland'),('neverland1'),('nevermind'),('nevermind1'),('nevermore'),('nevermore1'),('neversaydie'),('neversayne'),('neversaynever'),('nevershout'),('nevertarget7'),('neverwinter'),('never_desponding'),('nevets'),('nevets1'),('neviem'),('neville'),('neville1'),('nevim'),('new'),('new-york'),('new123'),('new2me'),('new975wen'),('newage'),('newark'),('newark1'),('newbaby'),('newbaby1'),('newbie'),('newbie1'),('newborn'),('newborn1'),('newboyz'),('newcall'),('newcar'),('newcastle'),('newcastle1'),('newcastle9'),('newday'),('newday1'),('newdelhi'),('newdom'),('newengland'),('newera'),('newera1'),('newfie'),('newfoundland'),('newgame9'),('newgirl'),('newguy'),('newholland'),('newhome'),('newhope'),('newhope1'),('newhouse'),('newhouse1'),('newjersey'),('newjersey1'),('newjob'),('newjob1'),('newlife'),('newlife07'),('newlife08'),('newlife09'),('newlife1'),('newlife10'),('newlife11'),('newlife12'),('newlife123'),('newlife2'),('newlife201'),('newlife2010'),('newlife2011'),('newlife3'),('newlife4me'),('newlife7'),('newlook'),('newlove'),('newlove1'),('newlove12'),('newman'),('newman1'),('newman12'),('newme09'),('newme1'),('newmexico'),('newmexico1'),('newmoney'),('newmoney1'),('newmoon'),('newmoon1'),('newmoon2'),('newnew'),('newnew1'),('newone'),('newone1'),('neworder'),('neworleans'),('Neworleans12345'),('newpass'),('newpass1'),('newpasswor'),('newpassword'),('newport'),('newport01'),('newport1'),('newport100'),('newport12'),('newport123'),('newport2'),('newport20'),('newport3'),('newport69'),('newport7'),('newports'),('newports1'),('news'),('newshoes'),('newsletter'),('newspaper'),('newspaper1'),('newstart'),('newstart1'),('newthree51'),('newton'),('newton1'),('newtown'),('newuser'),('newuser1'),('newvision'),('newworld'),('newyear'),('newyear08'),('newyear09'),('newyear1'),('newyork'),('newyork!'),('newyork.'),('newyork01'),('newyork07'),('newyork08'),('newyork09'),('newyork1'),('newyork10'),('newyork11'),('newyork12'),('newyork123'),('newyork13'),('newyork14'),('newyork2'),('newyork21'),('newyork22'),('newyork23'),('newyork3'),('newyork4'),('newyork5'),('newyork6'),('newyork69'),('newyork7'),('newyork8'),('newyork9'),('newyorkcity'),('newyorker'),('newyourk'),('newzealand'),('new_user'),('next'),('nextage'),('nextel'),('nextel1'),('nexus'),('nexus1'),('nexus6'),('neymar'),('neymar11'),('nezabudka'),('neznam'),('nfbcbz'),('nfhfcjdf'),('nfhfrfy'),('nfnfhby'),('nfnmzyf'),('nfnmzyrf'),('nfqcjy'),('nfvfhf'),('nfvthkfy'),('nfy.if'),('nfy.irf'),('nfymrf'),('nfytxrf'),('nfyz'),('nfyz123'),('nfyznfyz'),('ngentot'),('nglw9840'),('ngocanh'),('ngockhoa'),('nguyen'),('nguyen1'),('nguyen123'),('nguyen4'),('nguyen4thewin'),('NhA7EbF6kP'),('nhanngu'),('nhf'),('nhfnfnf'),('nhfrnjh'),('nhoemnhieu'),('nia123'),('niagara'),('niallhoran'),('niania'),('nibbles'),('nibbles1'),('nic'),('nic0le'),('nic123'),('nicaragua'),('nicaragua1'),('niccolo'),('nice'),('nice12'),('nice123'),('niceass'),('niceboy'),('niceday'),('nicegirl'),('nicegirl1'),('niceguy'),('niceguy1'),('nicenice'),('niceone'),('nicetry'),('nicetry1'),('nich0las'),('nichelle'),('nichelle1'),('nichol'),('nichola'),('nicholas'),('nicholas!'),('nicholas.'),('nicholas01'),('nicholas1'),('nicholas10'),('nicholas11'),('nicholas12'),('nicholas123'),('nicholas13'),('nicholas14'),('nicholas16'),('nicholas2'),('nicholas21'),('nicholas22'),('nicholas3'),('nicholas4'),('nicholas5'),('nicholas6'),('nicholas7'),('nicholas8'),('nicholas9'),('nichole'),('nichole1'),('nichole12'),('nichole123'),('nichole2'),('nichole3'),('nichole7'),('nichols'),('nichols1'),('nicholson'),('nick'),('nick01'),('nick05'),('nick06'),('nick07'),('nick08'),('nick09'),('nick1'),('nick10'),('nick101'),('nick11'),('nick12'),('nick123'),('nick1234'),('nick12345'),('nick13'),('nick14'),('nick15'),('nick16'),('nick17'),('nick18'),('nick19'),('nick2000'),('nick21'),('nick22'),('nick23'),('nick24'),('nick25'),('nick33'),('nick69'),('nick88'),('nick92'),('nick99'),('nickcarter'),('nickel'),('nickel1'),('nickelback'),('nickey'),('nicki'),('nicki1'),('nicki123'),('nickie'),('nickie1'),('nickiminaj'),('nickj1'),('nickjonas'),('nickjonas!'),('nickjonas1'),('nickjonas2'),('nicklas'),('nickle'),('nickname'),('nicknick'),('nicknick1'),('nicko'),('nickolas'),('nickolas1'),('nicky'),('nicky1'),('nicky12'),('nicky123'),('nicky2'),('niclas'),('nicnic'),('nico'),('nico12'),('nico123'),('nico1234'),('nico39'),('nicodemus'),('nicol'),('nicol3'),('nicola'),('nicola1'),('nicolae'),('nicolai'),('nicolas'),('nicolas01'),('nicolas1'),('nicolas10'),('nicolas12'),('nicolas123'),('nicolas2'),('nicolas7'),('nicole'),('nicole!'),('nicole.'),('nicole0'),('nicole00'),('nicole01'),('nicole02'),('nicole03'),('nicole04'),('nicole05'),('nicole06'),('nicole07'),('nicole08'),('nicole09'),('nicole1'),('nicole10'),('nicole101'),('nicole11'),('nicole12'),('nicole123'),('nicole1234'),('nicole13'),('nicole14'),('nicole15'),('nicole16'),('nicole17'),('nicole18'),('nicole19'),('nicole2'),('nicole20'),('nicole21'),('nicole22'),('nicole23'),('nicole24'),('nicole25'),('nicole26'),('nicole27'),('nicole28'),('nicole29'),('nicole3'),('nicole30'),('nicole31'),('nicole32'),('nicole33'),('nicole34'),('nicole4'),('nicole44'),('nicole5'),('nicole6'),('nicole69'),('nicole7'),('nicole77'),('nicole8'),('nicole82'),('nicole83'),('nicole84'),('nicole85'),('nicole86'),('nicole87'),('nicole88'),('nicole89'),('nicole9'),('nicole90'),('nicole91'),('nicole92'),('nicole93'),('nicole94'),('nicole95'),('nicole96'),('nicole97'),('nicole98'),('nicole99'),('nicoleta'),('nicoletta'),('nicolette'),('nicolette1'),('nicolina'),('nicolino'),('nicolle'),('nicolle1'),('nicolo'),('niconico'),('nicotheo'),('nicotine'),('nicusor'),('nideknil'),('nidhi'),('nielsen'),('nietzsche'),('nieves'),('niewiem'),('niewiem1'),('nif686'),('nifemi'),('nigel'),('nigel1'),('niger1'),('nigeria'),('nigeria1'),('nigerian'),('nigg3r'),('nigga'),('nigga!'),('nigga.'),('nigga01'),('nigga1'),('nigga10'),('nigga101'),('nigga11'),('nigga12'),('nigga123'),('nigga13'),('nigga14'),('nigga15'),('nigga2'),('nigga21'),('nigga22'),('nigga23'),('nigga3'),('nigga4'),('nigga4life'),('nigga5'),('nigga6'),('nigga69'),('nigga7'),('nigga9'),('niggaplz1'),('niggas'),('niggas1'),('niggaz'),('niggaz1'),('nigger'),('nigger!'),('nigger.'),('nigger1'),('nigger11'),('nigger12'),('nigger123'),('nigger13'),('nigger2'),('nigger22'),('nigger23'),('nigger3'),('nigger4'),('nigger420'),('nigger5'),('nigger6'),('nigger666'),('nigger69'),('nigger7'),('nigger8'),('nigger9'),('niggers'),('niggers1'),('night'),('night1'),('night123'),('nightcrawler'),('nightfall'),('nightfire'),('nighthawk'),('nighthawk1'),('nightingale'),('nightjar'),('nightmare'),('nightmare1'),('nightmare2'),('nightmare6'),('nightowl'),('nightrider'),('nights'),('nightshade'),('nightwing'),('nightwish'),('nightwish1'),('nightwolf'),('nihao123'),('nihaoma'),('niharika'),('nihongo'),('nijmegen'),('nik'),('nik123'),('nika'),('nika123'),('nika135'),('nikanika'),('nika_kisa88'),('nike'),('nike01'),('nike10'),('nike11'),('nike12'),('nike123'),('nike1234'),('nike13'),('nike14'),('nike15'),('nike21'),('nike22'),('nike23'),('nike24'),('nike90'),('nikeair'),('nikeair1'),('nikenike'),('nikesb1'),('nikhil'),('niki'),('niki12'),('niki123'),('nikiniki'),('nikita'),('nikita01'),('nikita1'),('nikita10'),('nikita11'),('nikita12'),('nikita123'),('nikita13'),('nikita1995'),('nikita1996'),('nikita1997'),('nikita1998'),('nikita1999'),('nikita2'),('nikita2000'),('nikita2001'),('nikita2002'),('nikita2010'),('nikita98'),('nikita99'),('nikitin'),('nikitina'),('nikitka'),('nikito'),('nikitos'),('nikitosik'),('nikka'),('nikka1'),('nikki'),('nikki!'),('nikki01'),('nikki06'),('nikki07'),('nikki08'),('nikki09'),('nikki1'),('nikki10'),('nikki101'),('nikki11'),('nikki12'),('nikki123'),('nikki1234'),('nikki13'),('nikki14'),('nikki15'),('nikki16'),('nikki17'),('nikki18'),('nikki2'),('nikki21'),('nikki22'),('nikki23'),('nikki24'),('nikki3'),('nikki4'),('nikki5'),('nikki6'),('nikki69'),('nikki7'),('nikki8'),('nikki9'),('nikkie'),('nikkie1'),('nikkisixx'),('nikko'),('nikko1'),('nikky1'),('niklas'),('niklas1'),('niknik'),('niko'),('niko123'),('nikol'),('nikola'),('nikola1'),('nikola123'),('nikolaev'),('nikolaeva'),('nikolaevna'),('nikolai'),('nikolai1'),('nikolaj'),('nikolas'),('nikolas1'),('nikolaus'),('nikolay'),('nikolay_thebest'),('nikole'),('nikole1'),('nikoleta'),('nikolina'),('nikolka'),('nikon'),('nikoniko'),('nikos'),('nikprommet'),('nikusha'),('nilesh'),('nimbus'),('nimbus2000'),('nimisha'),('nimitz'),('nimrod'),('nimrod1'),('nin'),('nina'),('nina01'),('nina10'),('nina11'),('nina12'),('nina123'),('nina1234'),('nina13'),('nina22'),('ninanina'),('nine'),('nine11'),('nine99'),('nineball'),('ninenine'),('niners'),('niners1'),('niners49'),('nineteen'),('nineteen19'),('ninette'),('ningning'),('ninguna'),('nini'),('nini12'),('nini123'),('niniko'),('ninini'),('nininini'),('ninja'),('ninja!'),('ninja1'),('ninja101'),('ninja11'),('ninja12'),('ninja123'),('ninja13'),('ninja2'),('ninja250'),('ninja3'),('ninja5'),('ninja6'),('ninja636'),('ninja666'),('ninja69'),('ninja7'),('ninja9'),('ninjaman'),('ninjas'),('ninjas1'),('ninjasaga'),('ninjutsu'),('nino'),('nino123'),('ninochka'),('ninonino'),('nintend0'),('nintendo'),('nintendo1'),('nintendo12'),('nintendo2'),('nintendo64'),('nintendods'),('nipper'),('nipper1'),('nipple'),('nipple1'),('nipples'),('nipples1'),('nippon'),('nique1'),('niranjan'),('nirankar'),('nirmal'),('nirmala'),('nirvana'),('nirvana!'),('nirvana.'),('nirvana1'),('nirvana11'),('nirvana12'),('nirvana123'),('nirvana13'),('nirvana2'),('nirvana3'),('nirvana5'),('nirvana6'),('nirvana666'),('nirvana69'),('nirvana7'),('nirvana8'),('nirvana9'),('nirvana94'),('nisha'),('nisha1'),('nisha123'),('nishant'),('nishizhu'),('nissan'),('nissan01'),('nissan1'),('nissan12'),('nissan123'),('nissan2'),('nissan240'),('nissan300'),('nissan350'),('nissan350z'),('nisse'),('nita'),('nitesh'),('nithya'),('nitin'),('nitin123'),('nitram'),('nitram1'),('nitro'),('nitro1'),('nitro123'),('nitrogen'),('nitrous'),('nitrous1'),('nitsuj'),('nittany'),('nittany1'),('niunia'),('niunia1'),('nivedita'),('nivram'),('nixon'),('nixon1'),('niyah1'),('nj2mp73t'),('nj9st4ye3f'),('njdevils'),('njhnbr'),('njhyflj'),('njhygtfTB567'),('nji90okm'),('njkcnsq'),('njkmrjz'),('njqjnf'),('nkechi'),('nkechi1'),('nkechi12'),('nks230kjs82'),('nmnmnm'),('nmt89109328673'),('NN'),('nnamdi'),('nnanna'),('nnenna'),('nnn'),('nnnn'),('nnnnn'),('nnnnnn'),('nnnnnn1'),('nnnnnnn'),('nnnnnnnn'),('nnnnnnnnnn'),('no'),('no1234'),('no1butme'),('no1cares'),('no1knows'),('noaccess'),('noAccess99'),('NOAdmin'),('noah'),('noah01'),('noah06'),('noah07'),('noah08'),('noah11'),('noah12'),('noah123'),('noah1234'),('noah2007'),('noahsark'),('nobiles'),('nobita'),('noble'),('noble1'),('nobody'),('nobody1'),('nochance'),('nocturne'),('noddy1'),('nodnarb1'),('nodoubt'),('nodoubt1'),('nodrog'),('noel'),('noel12'),('noel123'),('noelia'),('noelle'),('noelle1'),('noemi'),('noemi1'),('noemie'),('noentry'),('nofear'),('nofear1'),('nofx'),('nogard'),('noggin'),('nognog'),('nogueira'),('noidea'),('noiembrie'),('noisette'),('nok'),('nokia'),('nokia1'),('nokia11'),('nokia1100'),('nokia12'),('nokia123'),('nokia1234'),('nokia12345'),('nokia1600'),('nokia2'),('nokia2000'),('nokia2700'),('nokia3100'),('nokia3110'),('nokia3120'),('nokia3200'),('nokia3210'),('nokia3220'),('nokia3230'),('nokia3250'),('nokia3310'),('nokia3650'),('nokia5'),('nokia5130'),('nokia5200'),('nokia5228'),('nokia5230'),('nokia5300'),('nokia5310'),('nokia5320'),('nokia5530'),('nokia5610'),('nokia5700'),('nokia5800'),('nokia6020'),('nokia6120'),('nokia6131'),('nokia6210'),('nokia6230'),('nokia6230i'),('nokia6233'),('nokia6280'),('nokia6300'),('nokia6303'),('nokia6500'),('nokia6600'),('nokia6610'),('nokia6630'),('nokia6680'),('nokia6700'),('nokia7210'),('nokia73'),('nokia7610'),('nokia8210'),('nokia8800'),('nokia95'),('nokiaa'),('nokiae51'),('nokiae63'),('nokiae65'),('nokiae71'),('nokian'),('nokian70'),('nokian72'),('nokian73'),('nokian80'),('nokian81'),('nokian82'),('nokian90'),('nokian95'),('nokian97'),('nokianokia'),('nokias'),('nokiax2'),('nokiax6'),('noknok'),('nolan'),('nolan1'),('nolase'),('noles1'),('nolimit'),('nolimit1'),('nolimits'),('nolongthing'),('nolose'),('nolove'),('nolove1'),('nolwenn'),('nomad'),('nomad1'),('nomads'),('nomames'),('nomar5'),('nomeacuerdo'),('nomelase'),('nomercy'),('nomercy1'),('nomoney'),('nomore'),('nomore1'),('nomorerack'),('non'),('noname'),('noname1'),('noname123'),('noncapa09'),('none'),('none12'),('none123'),('nonenone'),('noneya'),('noneya1'),('nonlaso'),('nonloso'),('nonmember'),('nonna'),('nonnie'),('nonnie1'),('nono'),('nono12'),('nono123'),('nonono'),('nonono1'),('nononono'),('nonoy'),('nonpayment'),('nonsense'),('nonstop'),('nonudity!'),('noob'),('noob123'),('noobie'),('noobnoob'),('noodle'),('noodle1'),('noodle12'),('noodle123'),('noodle2'),('noodles'),('noodles1'),('noodles123'),('noodles2'),('nookie'),('nookie1'),('noone'),('noone1'),('nooneknows'),('noonie'),('noonie1'),('noonoo'),('nopasaran'),('nopass'),('nopass1'),('nopasswo'),('nopassword'),('nope'),('noproblem'),('nor'),('nora'),('nora123'),('noranora'),('norbert'),('norbert1'),('norberto'),('norcal'),('norcal1'),('norcal14'),('nordic'),('noreen'),('noregrets'),('noregrets1'),('norfolk'),('norfolk1'),('noriko'),('norita'),('norma'),('norma1'),('norma123'),('normajean'),('normajean1'),('normal'),('normal1'),('norman'),('norman1'),('norman12'),('norman123'),('normandie'),('normandy'),('norris'),('norris1'),('norte14'),('norte4'),('norteno14'),('nortex4'),('north'),('north1'),('north123'),('north14'),('northeast'),('northeast1'),('northern'),('northern1'),('northshore'),('northside'),('northside1'),('northside2'),('northside4'),('northstar'),('northstar1'),('northwest'),('northwest1'),('northwood'),('norton'),('norton1'),('norway'),('norway1'),('norwegen'),('norwich'),('norwich1'),('norwood'),('norwood1'),('nose'),('nose123'),('nosey1'),('nosferatu'),('nosferatu1'),('noshit'),('nosmoking'),('nosoup4u'),('nostalgia'),('nostradamus'),('nostress'),('nostromo'),('not'),('not2day'),('not4me'),('not4u2c'),('not4u2no'),('not4you'),('notagain'),('notagain1'),('notebook'),('notebook1'),('notengo'),('notforyou'),('nothanks'),('nothing'),('nothing!'),('nothing.'),('nothing0'),('nothing1'),('nothing11'),('nothing12'),('nothing123'),('nothing2'),('nothing3'),('nothing7'),('nothings123'),('notice'),('notime'),('notme1'),('notmine'),('notnot'),('notnow'),('notorious'),('notorious1'),('notreal'),('notreal1'),('notredame'),('notredame1'),('notrust'),('notrust1'),('nottelling'),('notthat'),('nottingham'),('notvalid'),('notyou'),('notyours'),('notyours1'),('not_needed'),('nou'),('nougat'),('noumea'),('nounette'),('nounou'),('nounoune'),('nounours'),('nouveau'),('nov'),('nov151963'),('nov1988'),('nova'),('nova123'),('novanova'),('novartis'),('novasenha'),('novell'),('novell123'),('november'),('november01'),('november05'),('november06'),('november07'),('november08'),('november09'),('november1'),('november10'),('november11'),('november12'),('november13'),('november14'),('november15'),('november16'),('november17'),('november18'),('november19'),('november2'),('november20'),('november21'),('november22'),('november23'),('november24'),('november25'),('november26'),('november27'),('november28'),('november29'),('november3'),('november30'),('november4'),('november5'),('november6'),('november7'),('november8'),('november9'),('novembre'),('novembro'),('novgorod'),('novice'),('noviembre'),('noviembre1'),('noviembre2'),('novikov'),('novikova'),('novita'),('novo'),('novosibirsk'),('now'),('noway'),('noway1'),('noway123'),('nowayjose'),('nowayout'),('nowehaslo'),('nowhere'),('nowitzki41'),('nownow'),('noworries'),('noxious'),('noynoy'),('nrfxtyrj'),('ns'),('nssadmin'),('nsync'),('nsync1'),('nt'),('nthvbyfnjh'),('ntktajy'),('ntktdbpjh'),('nuages'),('nubian'),('nuclear'),('nuclear1'),('nudist'),('nuevavida'),('nugent'),('nugget'),('nugget1'),('nugget12'),('nuggets'),('nuggets1'),('nuggets15'),('nuggets3'),('NUL'),('NULL'),('numark'),('numb3rs'),('numba1'),('number'),('number01'),('number1'),('number10'),('number11'),('number12'),('number123'),('number13'),('number14'),('number15'),('number16'),('number17'),('number18'),('number19'),('number1dad'),('number1fan'),('number1mom'),('number1son'),('number2'),('number20'),('number21'),('number22'),('number23'),('number24'),('number25'),('number27'),('number3'),('number32'),('number33'),('number34'),('number4'),('number41'),('number44'),('number5'),('number55'),('number6'),('number69'),('number7'),('number8'),('number88'),('number9'),('number99'),('numberone'),('numberone1'),('numbers'),('numbers1'),('numbers123'),('numbnuts'),('numero'),('numero1'),('numero10'),('numerouno'),('numlock'),('numlock1'),('nummer1'),('nummero1'),('nuncamas'),('nunu12'),('nunu123'),('nunzia'),('nunzio'),('nuo0725nuo'),('nupe1911'),('nur'),('nurbek'),('nurlan'),('nurse'),('nurse1'),('nurse123'),('nurse2'),('nursery'),('nurses'),('nurses1'),('nursing'),('nursing08'),('nursing1'),('nursultan'),('nurudeen'),('nurul'),('nusha.88'),('nusrat'),('nust007'),('nutcase'),('nutcracker'),('nutella'),('nutella1'),('nutmeg'),('nutmeg1'),('nutrition'),('nuts'),('nutsack'),('nutsack1'),('nutter'),('nutter1'),('nuttertool'),('nuttertools'),('nutty'),('nutty1'),('nuvola'),('nvidia'),('nwo4life'),('Nwolf72'),('nx74205'),('nyasha'),('nyc123'),('nygiants'),('nygiants1'),('nyjets'),('nyjets1'),('nyknicks'),('nylons'),('nymets'),('nymets1'),('nympho'),('nyq28Giz1Z'),('nyquist'),('nyt'),('nyuszi'),('nyyankees'),('nyyankees1'),('n_pletneva'),('N�odefinido'),('o'),('o0o0o0'),('o0o0o0o0'),('o12345'),('o123456'),('o1234567'),('o123456789'),('o23456'),('O67l2xzfvN'),('o8lhE2z7bO'),('oakcliff1'),('oakdale'),('oakland'),('oakland1'),('oakland510'),('oakley'),('oakley1'),('oakridge'),('oaktree'),('oaktree1'),('oakwood'),('oakwood1'),('oasis'),('oasis1'),('oasis123'),('Oassw0rd'),('oatmeal'),('oatmeal1'),('oaxaca'),('obama'),('obama08'),('obama09'),('obama1'),('obama2008'),('obama2009'),('obelisk'),('obelix'),('oberon'),('obi4amte'),('obinna'),('obituary'),('obiwan'),('obiwan1'),('oblivion'),('oblivion1'),('obrien'),('obsession'),('obsidian'),('obvious'),('obvious1'),('oc247ngUcZ'),('ocampo'),('ocarina'),('ocean'),('ocean1'),('ocean11'),('ocean12'),('ocean123'),('ocean13'),('oceane'),('oceanic'),('oceano'),('oceans'),('oceans1'),('oceans11'),('oceans12'),('oceanside'),('oceanside1'),('ocelot'),('ochoa1'),('oconnor'),('OcPOOok325'),('oct'),('octagon'),('octave'),('octavia'),('octavia1'),('octavian'),('octavio'),('octavio1'),('october'),('october01'),('october02'),('october03'),('october05'),('october06'),('october07'),('october08'),('october09'),('october1'),('october10'),('october11'),('october12'),('october13'),('october14'),('october15'),('october16'),('october17'),('october18'),('october19'),('october2'),('october20'),('october21'),('october22'),('october23'),('october24'),('october25'),('october26'),('october27'),('october28'),('october29'),('october3'),('october30'),('october31'),('october4'),('october5'),('october6'),('october7'),('october8'),('october9'),('octobre'),('octopus'),('octopus1'),('octubre'),('oddball'),('oddball1'),('oddjob'),('oddworld'),('odessa'),('odessa1'),('odette'),('odeyemi'),('odie'),('odin'),('odunayo'),('odysseus'),('odyssey'),('odyssey1'),('odz1w1rB9T'),('ofelia'),('office'),('office1'),('office123'),('officer'),('officer1'),('official'),('official1'),('offline'),('offroad'),('offroad1'),('offshore'),('offspring'),('offspring1'),('offthewall'),('oficina'),('oficinag3'),('ogechi'),('ogplanet'),('oguzhan'),('ohbaby'),('ohbaby1'),('ohcaptain'),('ohio'),('ohio123'),('ohiostate'),('ohiostate1'),('ohiostate2'),('ohmnamah23'),('ohmygod'),('ohmygod!'),('ohmygod1'),('ohmygosh'),('ohshit'),('ohshit!'),('ohshit1'),('ohsnap1'),('ohyeah'),('ohyeah!'),('ohyeah1'),('oicu812'),('oieoie'),('oigres'),('oilers'),('oilers1'),('oinkoink'),('oioi00'),('oioioi'),('oioioi0'),('oioioi1'),('oiseau'),('ojitos'),('ok'),('ok1234'),('ok123456'),('ok20.07'),('okay'),('okay12'),('okay123'),('okcomputer'),('okechukwu'),('okein'),('okidoki'),('okiedokie'),('okinawa'),('okinawa1'),('oklahoma'),('oklahoma1'),('oklick'),('okmijn'),('okmijnuhb'),('okmnji'),('okocha'),('okok'),('okokok'),('okokok1'),('okokokok'),('oks65b6666'),('oksana'),('oksana1'),('oksana130279'),('oksanaorgadykova'),('oksanav-13'),('oksanka'),('oktober'),('ola'),('ola123'),('olabisi'),('olabode'),('oladapo'),('oladele'),('oladimeji'),('oladipupo'),('olaide'),('olaitan'),('olajide'),('olajumoke'),('olakunle'),('olalekan'),('olalekan1'),('olamide'),('olamide1'),('olamilekan'),('olaniyi'),('olanrewaju'),('olaola'),('olaolaola'),('olaolu'),('olaoluwa'),('olarewaju'),('olasunkanmi'),('olateju'),('olatunde'),('olatunji'),('olawale'),('olawale1'),('olawunmi'),('olayemi'),('olayinka'),('olayinka1'),('olayiwola'),('old'),('olddog'),('oldfart'),('oldfart1'),('oldham'),('oldies'),('oldlady'),('oldman'),('oldman1'),('oldnavy'),('oldnavy1'),('olds442'),('oldschool'),('oldschool1'),('oldskool'),('oldskool1'),('oldsmobile'),('oldspice'),('oldspice1'),('oldtimer'),('oldtrafford'),('ole'),('ole4ka'),('oleander'),('olechka'),('olechka061187'),('oleg'),('oleg-andry'),('oleg.jann'),('oleg123'),('oleg1992'),('oleg1995'),('oleg1996'),('oleg1997'),('oleg1998'),('oleg272727'),('oleg2ci'),('oleginator1'),('olegoleg'),('olegshut'),('olemiss'),('olemiss1'),('olenka'),('oleole'),('olesia'),('olesya'),('olesya.kolchina'),('olga'),('olga.kazakova_85'),('olga.lekarewa'),('olga.ponomarenko.2012'),('olga.rumyanceva.1985'),('olga12'),('olga123'),('olga1234'),('olga1987'),('olga2010'),('olgaolga'),('olgastrashney'),('olgha.pietrova.1979'),('oli'),('oli123'),('olidata'),('olifant'),('olimpia'),('olimpia1'),('olimpo'),('olinda'),('olioli'),('olitec00'),('olivares'),('olive'),('olive1'),('olive123'),('oliveira'),('olivejuice'),('oliveoil'),('oliver'),('oliver!'),('oliver00'),('oliver01'),('oliver06'),('oliver07'),('oliver08'),('oliver09'),('oliver1'),('oliver10'),('oliver11'),('oliver12'),('oliver123'),('oliver13'),('oliver14'),('oliver15'),('oliver16'),('oliver2'),('oliver21'),('oliver22'),('oliver23'),('oliver3'),('oliver4'),('oliver5'),('oliver6'),('oliver69'),('oliver7'),('oliver77'),('oliver8'),('oliver88'),('oliver9'),('oliver99'),('olivera'),('olives'),('olivetti'),('olivia'),('olivia!'),('olivia01'),('olivia02'),('olivia03'),('olivia04'),('olivia05'),('olivia06'),('olivia07'),('olivia08'),('olivia09'),('olivia1'),('olivia10'),('olivia11'),('olivia12'),('olivia123'),('olivia13'),('olivia14'),('olivia15'),('olivia16'),('olivia2'),('olivia21'),('olivia22'),('olivia23'),('olivia3'),('olivia4'),('olivia5'),('olivia6'),('olivia7'),('olivia8'),('olivia99'),('olivier'),('olivier1'),('oliwia'),('oliwka'),('ollie'),('ollie1'),('ollie123'),('olo65b6666'),('ololade'),('ololo123'),('ololoeva-99'),('ololol'),('olololo'),('olqa_motosova'),('olubunmi'),('oluchi'),('olufemi'),('olufiz14'),('olugbenga'),('olumide'),('olumide1'),('olusegun'),('oluseun'),('olushola'),('olusola'),('oluwa'),('oluwadare'),('oluwafemi'),('oluwakemi'),('oluwasegun'),('oluwaseun'),('oluwaseun1'),('oluwaseyi'),('oluwatobi'),('oluwatosin'),('oluwatoyin'),('oluwole'),('olvido'),('olya'),('olya.i.02'),('olyashev12'),('olympe'),('olympia'),('olympia1'),('olympiakos'),('olympic'),('olympic1'),('olympics'),('olympique'),('olympus'),('olympus1'),('om'),('omalley'),('omar'),('omar10'),('omar11'),('omar12'),('omar123'),('omar1234'),('omar13'),('omar23'),('omarbravo9'),('omari1'),('omarion'),('omarion1'),('omarion2'),('omarion21'),('omaromar'),('omega'),('omega1'),('omega12'),('omega123'),('omega13'),('omega2'),('omega3'),('omega5'),('omega7'),('omegared'),('omegas'),('omen666'),('omerta'),('omfg123'),('omg'),('omg123'),('omg1234'),('omg12345'),('omg199'),('omg999'),('omglol'),('omglol1'),('omgomg'),('omgomg1'),('omgomg123'),('omgomgomg'),('omgwtf'),('omgwtf1'),('omgwtfbbq'),('omicron'),('omnamahshivay'),('Omni'),('omnislash'),('omolade'),('omolara'),('omolola'),('omomom'),('omonoia'),('omooba'),('omotayo'),('omotola'),('omowunmi'),('omoyah1'),('omsainath'),('omsairam'),('omsakthi'),('omshanti'),('omshantiom'),('omsrisairam'),('onamrdiu'),('ondine'),('ondra'),('one'),('one111'),('one123'),('one1love'),('one1one'),('one1two2'),('one234'),('one2345'),('one23456'),('one2one'),('one2three'),('one2three4'),('one4all'),('oneandonly'),('oneblood'),('oneblood1'),('oneday'),('oneday1'),('onedirecti'),('onedirection'),('onegod'),('oneill'),('onelife'),('onelove'),('onelove!'),('onelove.'),('onelove1'),('onelove12'),('onelove123'),('onelove13'),('onelove2'),('onelove3'),('onelove4'),('onelove420'),('onelove69'),('onelove7'),('oneluv'),('oneluv1'),('oneman'),('onemoretime'),('oneone'),('oneone1'),('onepiece'),('onepiece1'),('oneshot'),('onetime'),('onetime1'),('onetreehill'),('onetwo'),('onetwo1'),('onetwo12'),('onetwo3'),('onetwo34'),('onetwothree'),('oneway'),('oneway1'),('onfire'),('onimusha'),('onion'),('onion1'),('onions'),('onizuka'),('onkelz'),('online'),('online1'),('online12'),('online123'),('online2'),('only'),('only14me'),('only1god'),('only1love'),('only1me'),('only4me'),('only4u'),('only4you'),('onlygod'),('onlylove'),('onlyme'),('onlyme1'),('onlyone'),('onlyone1'),('onlyyou'),('onlyyou1'),('onmyown'),('onmyown1'),('onspeed'),('ontario'),('ontario1'),('ontheroad'),('onyebuchi'),('onyeka'),('onyx'),('oogabooga'),('ooicu812'),('oojs4ykl'),('ooo'),('ooo000'),('oooo'),('oooo0000'),('ooooo'),('ooooo0'),('ooooo1'),('oooooo'),('oooooo1'),('ooooooo'),('oooooooo'),('oooooooooo'),('oops'),('opanka'),('opaopa'),('opel'),('opelastra'),('opelastra123'),('opelcorsa'),('opelvectra'),('open'),('open12'),('open123'),('open1234'),('open4me'),('opendoor'),('openit'),('openme'),('opennow'),('opennow1'),('openopen'),('opensaysme'),('opensesame'),('openup'),('openup1'),('opera'),('opera1'),('operation'),('operation1'),('operations'),('operator'),('operator1'),('opernhaus1'),('opeyemi'),('opeyemi1'),('ophelia'),('ophelia1'),('ophelie'),('opium'),('opiumbaron'),('opopop'),('opopopop'),('opossum'),('opportunity'),('ops111'),('optic99'),('optical'),('optical1'),('optima'),('optimist'),('optimistic'),('optimus'),('optimus1'),('optimusprime'),('option'),('option1'),('options'),('optiplex'),('optiplex1'),('optiquest'),('optout'),('opus'),('ora'),('oracle'),('oracle1'),('oracle123'),('oralsex'),('oran31'),('orange'),('orange!'),('orange.'),('orange01'),('orange07'),('orange08'),('orange09'),('orange1'),('orange10'),('orange11'),('orange12'),('orange123'),('orange1234'),('orange13'),('orange14'),('orange15'),('orange16'),('orange17'),('orange18'),('orange19'),('orange2'),('orange20'),('orange21'),('orange22'),('orange23'),('orange24'),('orange25'),('orange27'),('orange3'),('orange33'),('orange4'),('orange44'),('orange5'),('orange55'),('orange6'),('orange66'),('orange69'),('orange7'),('orange77'),('orange8'),('orange88'),('orange9'),('orange99'),('orangejuice'),('oranges'),('oranges1'),('oranges2'),('orangina'),('orangutan'),('orazio'),('orbit'),('orbit1'),('orbita'),('orbital'),('orca'),('orchard'),('orchard1'),('orchestra'),('orchid'),('orchid1'),('orchidea'),('orchidee'),('orchids'),('ordenador'),('order'),('order66'),('orders'),('ordinary'),('ordinateur'),('oregon'),('oregon1'),('orellana'),('oreo'),('oreo01'),('oreo10'),('oreo11'),('oreo12'),('oreo123'),('oreo1234'),('oreo13'),('oreo14'),('oreo22'),('oreocookie'),('oreoluwa'),('oreooreo'),('oreste'),('organic'),('organic1'),('orgasm'),('orgazm'),('oriana'),('oriane'),('orient'),('oriental'),('oriente'),('oriflame'),('oriflame_1910'),('origami'),('origin'),('original'),('original1'),('original21'),('orioles'),('orioles1'),('orion'),('orion1'),('orion123'),('orion2'),('orione'),('oriyomi'),('orlando'),('orlando!'),('orlando1'),('orlando11'),('orlando12'),('orlando123'),('orlando13'),('orlando2'),('orlando3'),('orlando5'),('orlando7'),('orlandobloom'),('orlane'),('orleans'),('orleans1'),('orlova'),('ornella'),('orochi'),('orochimaru'),('orologio'),('orphee'),('orpheus'),('orquidea'),('orsetto'),('ortega'),('ortega1'),('orthodox'),('ortiz'),('ortiz1'),('ortiz34'),('orville'),('orwell'),('orwell1984'),('osama'),('osasuna'),('osborne'),('osbourne'),('oscar'),('oscar01'),('oscar1'),('oscar10'),('oscar11'),('oscar12'),('oscar123'),('oscar1234'),('oscar13'),('oscar14'),('oscar15'),('oscar2'),('oscar21'),('oscar22'),('oscar23'),('oscar3'),('oscar4'),('oscar5'),('oscar69'),('oscar7'),('oscardog'),('oscardog1'),('oscarito'),('oscars'),('oscars1'),('oscarwilde'),('osho'),('osipov'),('osipova'),('osiris'),('osiris1'),('osito'),('osito1'),('ositos'),('oskar'),('oskar1'),('oskar123'),('oskarek'),('osman'),('osman123'),('oso123'),('osorio'),('osprey'),('ossi2000'),('ostrich'),('ostrov'),('osvaldo'),('osvaldo1'),('oswald'),('oswaldo'),('oswaldo1'),('osynadepu'),('otello'),('othello'),('othello1'),('other1'),('others'),('otherside'),('otilia'),('otioti'),('otis'),('otis123'),('otrebor'),('ottawa'),('otter'),('otter1'),('otters'),('otto'),('ottobre'),('ottoman'),('ottootto'),('Ou171423'),('ou29q6666'),('ou812'),('ou8122'),('ou8123'),('ou812345'),('ou8124me'),('ou8125150'),('ou812ic'),('ou812ou812'),('ouioui'),('ouk29q6666'),('our3kids'),('ourson'),('ousmane'),('oussama'),('outback'),('outback1'),('outcast'),('outcast1'),('outdoor'),('outdoors'),('outkast'),('outkast1'),('outlander'),('outlaw'),('outlaw1'),('outlaw2'),('outlaw69'),('outlaws'),('outlaws1'),('outlawz'),('outlawz1'),('outlook'),('outreach'),('outside'),('outside1'),('outsider'),('outsider1'),('outsiders'),('outubro'),('ovation'),('ovation1'),('ovechkin'),('ovechkin8'),('over'),('over2yangshuo'),('over9000'),('overcome'),('overcomer'),('overdose'),('overdrive'),('overflow'),('overit1'),('overkill'),('overkill1'),('overload'),('overlook'),('overlord'),('overlord1'),('override'),('overseas'),('overtime'),('ovidiu'),('oviedo'),('ovr220278'),('owahodarea'),('owen'),('owen10'),('owen123'),('owens81'),('ownage'),('ownage1'),('ownage123'),('owned'),('owned1'),('owned123'),('owner'),('owner@hr.com'),('owolabi'),('owt243yGbh'),('owt243yGbJ'),('oxana.o'),('oxford'),('oxford1'),('oxnard805'),('oxygen'),('oxygen1'),('oxymoron'),('oyatayo'),('oyekunle'),('oyindamola'),('oyster'),('ozzie'),('ozzie1'),('ozzy'),('ozzy12'),('ozzy123'),('ozzy666'),('p'),('p.i.m.p'),('p00000'),('p000000'),('p00hbear'),('p00kie'),('p00p00'),('p00per'),('p00pie'),('p00pp00p'),('p0k3m0n'),('p0kem0n'),('p0kemon'),('p0o9i8'),('p0o9i8u7'),('p0o9i8u7y6'),('p0p0p0'),('p0pc0rn'),('p0pcorn'),('p0rnstar'),('p12345'),('p123456'),('p1234567'),('p12345678'),('p123456789'),('P1466186'),('p1assword1'),('p1mp1n'),('p1mpin'),('p1p2p3'),('p1p2p3p4'),('p1ssword'),('p2ssw0rd'),('p2ssword'),('p2WcFfjCvr'),('p2XcFgjCvr'),('p3anut'),('p3avbwjw'),('p3pp3r'),('P3Rat54797'),('p455w0rd'),('p455word'),('p4ssw0rd'),('p4ssword'),('P4vKINRw6x'),('p51mustang'),('p5415420'),('p6264758'),('p7678287'),('p8ntball'),('p939468'),('p@$$w0rd'),('p@$$word'),('p@55w0rd'),('p@55word'),('P@ssw0rd'),('p@ssword'),('P@ssword1'),('pa'),('Pa$$w0rd'),('pa$$word'),('pA1ub65udD'),('pa22word'),('pa33word'),('pa44word'),('pa55w0rd'),('pa55word'),('pa55wrd1'),('pa88word'),('paakow'),('paarden'),('pablito'),('pablito1'),('pablo'),('pablo1'),('pablo10'),('pablo12'),('pablo123'),('pablos'),('pac'),('pacers'),('pacers1'),('pacers31'),('pacheco'),('pacheco1'),('pachuca'),('pachuca1'),('paciencia'),('pacific'),('pacific1'),('pacifica'),('pacifico'),('pacino'),('package'),('packard'),('packard1'),('packardbell'),('packer'),('packer1'),('packers'),('packers04'),('packers1'),('packers12'),('packers123'),('packers2'),('packers4'),('packman'),('pacman'),('pacman1'),('pacman12'),('pacman123'),('pacman2'),('paco'),('paco12'),('paco123'),('pacopaco'),('pacsun1'),('pacute'),('pad'),('padang'),('padawan'),('paddington'),('paddle'),('paddy'),('paddy1'),('paddy123'),('padfoot'),('padilla'),('padilla1'),('padisco'),('padlock'),('padmaja'),('padmavathi'),('padmini'),('padova'),('padrepio'),('padres'),('padres1'),('padrino'),('pagan1'),('pagani'),('paganini'),('page'),('pagedown'),('pageup'),('paige'),('paige01'),('paige1'),('paige11'),('paige12'),('paige123'),('paige13'),('paige2'),('paige3'),('pain'),('painislove'),('painkiller'),('painless'),('paint'),('paint1'),('paintball'),('paintball0'),('paintball1'),('paintball2'),('paintball3'),('paintball4'),('paintball5'),('paintball7'),('paintball8'),('paintball9'),('painter'),('painter1'),('painting'),('painting1'),('paints'),('paisley'),('paisley1'),('paiste'),('paixao'),('pajarito'),('pajaro'),('pajero'),('pak123'),('pakalolo'),('pakistan'),('pakistan1'),('pakistan12'),('pakistan123'),('pakistan12345'),('pakistan1947'),('pakistan2'),('pakistan47'),('pakistan786'),('pakistani'),('pakistani1'),('pakito'),('pakkness'),('pakpak'),('pal'),('palace'),('palace1'),('palacio'),('palacios'),('paladin'),('paladin1'),('palangga'),('palani'),('palawan'),('palembang'),('palencia'),('palermo'),('palermo1'),('palesa'),('palestina'),('palestine'),('palestine1'),('palestra'),('paleta'),('palito'),('pallas'),('pallavi'),('pallavolo'),('pallina'),('pallino'),('pallmall'),('pallmall1'),('pallone'),('palma'),('palmeiras'),('palmer'),('palmer1'),('palmetto'),('palmier'),('palmira'),('palmtree'),('palmtree1'),('palmtrees'),('paloalto'),('paloma'),('paloma1'),('paloma123'),('palomino'),('palomita'),('palomo'),('paluso00'),('pam'),('pam123'),('pamela'),('pamela01'),('pamela1'),('pamela11'),('pamela12'),('pamela123'),('pamela2'),('pamelita'),('pampam'),('pampers'),('pampers1'),('pamplona'),('pan'),('pan123'),('panacea'),('panache'),('panama'),('panama1'),('panasonic'),('panasonic1'),('panasonik'),('panatha'),('panatha13'),('panathinaikos'),('pancake'),('pancake1'),('pancakes'),('pancakes1'),('pancha'),('panchita'),('panchito'),('panchito1'),('pancho'),('pancho1'),('pancho12'),('pancho123'),('pancho13'),('panda'),('panda!'),('panda01'),('panda1'),('panda10'),('panda101'),('panda11'),('panda12'),('panda123'),('panda13'),('panda14'),('panda2'),('panda21'),('panda22'),('panda23'),('panda3'),('panda4'),('panda5'),('panda6'),('panda7'),('pandabear'),('pandabear1'),('pandapanda'),('pandas'),('pandas1'),('panda_3108'),('pandemonium'),('pandey'),('pandit'),('pandita'),('pandora'),('pandora1'),('panganiban'),('pangeran'),('panget'),('panget1'),('pangetako'),('pangetka'),('pangga'),('pangit'),('pangit1'),('pangitka'),('panhead'),('panic'),('panic!'),('panic1'),('panic123'),('panico'),('panino'),('pankaj'),('pankaj123'),('panmen188'),('pannekoek'),('panocha'),('panocha1'),('panorama'),('panpan'),('pantalon'),('pantat'),('pantek'),('panter'),('pantera'),('pantera1'),('pantera12'),('pantera123'),('pantera2'),('pantera3'),('pantera6'),('pantera666'),('pantera69'),('panther'),('panther1'),('panther10'),('panther11'),('panther12'),('panther123'),('panther13'),('panther2'),('panther21'),('panther3'),('panther4'),('panther5'),('panther6'),('panther7'),('panther9'),('panthera'),('panthere'),('panthers'),('panthers!'),('panthers08'),('panthers09'),('panthers1'),('panthers10'),('panthers11'),('panthers12'),('panthers13'),('panthers2'),('panthers23'),('panthers3'),('panthers5'),('panthers7'),('panthers89'),('panties'),('panties1'),('pants'),('pants1'),('pantufa'),('pantyhose'),('pantyhose1'),('panzer'),('panzer1'),('paokara'),('paokara4'),('paola'),('paola1'),('paola12'),('paola123'),('paoletta'),('paolina'),('paolino'),('paolita'),('paolo'),('paolo1'),('paolo123'),('paopao'),('pap'),('papa'),('papa01'),('papa10'),('papa11'),('papa12'),('papa123'),('papa1234'),('papabear'),('papabear1'),('papacito'),('papagaio'),('papagal'),('papaji'),('papako'),('papamama'),('papamama1'),('papamaman'),('papamummy'),('papang'),('papapa'),('papapa1'),('papapapa'),('paparazi'),('paparazzi'),('paparoach'),('paparoach1'),('papasito'),('papasito1'),('papaslexzy'),('papasmurf'),('papasmurf1'),('papatoma1'),('papatya'),('papaya'),('papaya1'),('papaye'),('paper'),('paper1'),('paper12'),('paper123'),('paper2'),('papera'),('paperboy'),('paperboy1'),('paperclip'),('paperclip1'),('papercut'),('papercut1'),('paperina'),('paperino'),('papermate'),('papermate1'),('papero'),('papers'),('papers1'),('papi'),('papi12'),('papi123'),('papichulo'),('papichulo1'),('papier'),('papillon'),('papillon1'),('papino'),('papito'),('papito1'),('papoose'),('papoose1'),('papounet'),('pappa'),('pappa1'),('pappa123'),('pappagallo'),('pappas'),('pappy'),('pappy1'),('paprika'),('paprika1'),('papucho'),('papusa'),('papuskin'),('papyrus'),('paquita'),('paquito'),('par'),('parabellum'),('parabola'),('paracetamol'),('parachute'),('parade'),('paradigm'),('paradigma'),('paradis'),('paradise'),('paradise1'),('paradise2'),('paradise7'),('paradiso'),('paradox'),('paradox1'),('paragon'),('paragon1'),('paraguay'),('paraiso'),('parakeet'),('paralegal'),('paralelepipedo'),('paramedic'),('paramedic1'),('paramon'),('paramore'),('paramore!'),('paramore1'),('paramore12'),('paramount'),('paramount1'),('parana'),('paranoia'),('paranoid'),('paranoid1'),('paranormal'),('parasite'),('parazit'),('pardon'),('paredes'),('parekoy'),('parent'),('parent1'),('parents'),('parents1'),('paresh'),('parfait'),('parfenovav'),('parfum'),('parigi'),('paris'),('paris01'),('paris07'),('paris1'),('paris10'),('paris11'),('paris12'),('paris123'),('paris13'),('paris2'),('paris2010'),('paris3'),('paris5'),('paris7'),('paris75'),('parish'),('parishilton'),('parisien'),('parisparis'),('pariss'),('parissg'),('park'),('parker'),('parker01'),('parker08'),('parker09'),('parker1'),('parker10'),('parker11'),('parker12'),('parker123'),('parker13'),('parker2'),('parker22'),('parker3'),('parker9'),('parking'),('parkour'),('parkour1'),('parkside'),('parkside1'),('parkur'),('parkview'),('parkway'),('parkway1'),('parlament'),('parliament'),('parol'),('parol1'),('parol123'),('parola'),('parola1'),('Parola12'),('parola123'),('parola33'),('parolamea'),('parole'),('paroli'),('paroll'),('parolparol'),('parool'),('parovoz'),('parris'),('parrish'),('parrish1'),('parrot'),('parrot1'),('parrotlet'),('parsifal'),('parsley'),('parsons'),('parsons1'),('partha'),('partizan'),('partizan1'),('partner'),('partner1'),('partners'),('partridge'),('PARTS'),('PartSites'),('party'),('party!'),('party1'),('party101'),('party12'),('party123'),('party2'),('party5'),('party69'),('partyboy'),('partyboy1'),('partygirl'),('partygirl1'),('partyhard1'),('partyof5'),('partyone'),('partytime'),('partytime1'),('parvathi'),('parvathy'),('parvati'),('parveen'),('pas'),('pas100'),('pas123'),('pasadena'),('pasadena1'),('pasaway'),('pasaway1'),('pascal'),('pascal1'),('pascale'),('pascaline'),('pascha'),('pascua'),('pascual'),('pasha'),('pasha1'),('pasha123'),('pashka'),('pashtet'),('pasion'),('paska123'),('pasodeblas'),('paspas'),('PASpass1234'),('pasport'),('pasquale'),('pass'),('pass-word'),('pass.word'),('pass00'),('pass007'),('pass01'),('pass1'),('pass10'),('pass11'),('pass12'),('pass123'),('pass1234'),('pass12345'),('pass123456'),('Pass12sa'),('pass13'),('pass1478'),('pass1word'),('pass2'),('pass22'),('pAss2244'),('pass23'),('pass2word'),('pass420'),('pass4me'),('pass4word'),('pass55'),('pass9876'),('pass99'),('pass@123'),('pass@word1'),('passage'),('passat'),('passat1'),('passcode'),('passcode1'),('passe'),('passed'),('passenger'),('passer'),('passer1'),('passer2009'),('passer2010'),('passer2011'),('passera'),('passerotto'),('passes'),('passing'),('passion'),('passion1'),('passion12'),('passion123'),('passion2'),('passion3'),('passion4'),('passion69'),('passion7'),('passion8'),('passionate'),('passione'),('passions'),('passions1'),('passme'),('passme1'),('passord'),('passord1'),('passover'),('passpass'),('passpass1'),('passport'),('passport1'),('passrett222'),('passsword'),('passw'),('passw0rd'),('passw0rd!'),('passw0rd1'),('passw3rd'),('passward'),('passward1'),('passwd'),('passwd1'),('passwerd'),('passwerd1'),('passwo'),('passwor'),('passwor1'),('password'),('password!'),('password!!'),('password#1'),('password*'),('password-1'),('password.'),('password..'),('password.1'),('password0'),('password00'),('password001'),('password007'),('password01'),('password02'),('password03'),('password04'),('password05'),('password06'),('password07'),('password08'),('password09'),('password1'),('password1!'),('password1.'),('password10'),('password100'),('password101'),('password11'),('password111'),('password12'),('password123'),('password1234'),('password12345'),('password123456'),('password1234567'),('password12345678'),('password123456789'),('password13'),('password14'),('password15'),('password16'),('password17'),('password18'),('password19'),('password2'),('password20'),('password2010'),('password2011'),('password21'),('password22'),('password23'),('password24'),('password25'),('password26'),('password27'),('password28'),('password29'),('password3'),('password30'),('password31'),('password32'),('password321'),('password33'),('password34'),('password35'),('password36'),('password37'),('password4'),('password40'),('password41'),('password42'),('password420'),('password43'),('password44'),('password45'),('password47'),('password5'),('password50'),('password51'),('password52'),('password54'),('password55'),('password56'),('password57'),('password6'),('password64'),('password65'),('password66'),('password666'),('password67'),('password69'),('password7'),('password71'),('password72'),('password73'),('password74'),('password75'),('password76'),('password77'),('password777'),('password78'),('password79'),('password8'),('password80'),('password81'),('password82'),('password83'),('password84'),('password85'),('password86'),('password87'),('password88'),('password89'),('password9'),('password90'),('password91'),('password92'),('password93'),('password94'),('password95'),('password96'),('password97'),('password98'),('password99'),('password:'),('password?'),('password@1'),('password@123'),('passwordd'),('passwordd1'),('passwordko'),('passwordnew'),('passwordpassword'),('passwords'),('passwords1'),('password_1'),('password_Rr'),('passworld'),('passwort'),('passwort!'),('passwort1'),('passwort12'),('passwort123'),('passwrd'),('pass_2011'),('pass_Rrewq'),('pass_rRR'),('pass_word'),('pasta'),('pasta1'),('pasta123'),('pastel'),('pasteur'),('pastis'),('pastis51'),('pastor'),('pastor1'),('pastorius'),('pastrana'),('pastry'),('pasuma12'),('paswoord'),('pasword'),('pasword1'),('pasword123'),('pat'),('pat123'),('patagonia'),('patanahi'),('patapouf'),('patata'),('patata1'),('patate'),('patates'),('patatina'),('patato'),('patch'),('patch1'),('patch123'),('patches'),('patches01'),('patches1'),('patches11'),('patches12'),('patches123'),('patches2'),('patches3'),('patches7'),('patchy'),('patel'),('paterson'),('paterson1'),('pathan'),('pathetic'),('pathfinder'),('pathology'),('patience'),('patience1'),('patient'),('patita'),('patito'),('patito1'),('patitofeo'),('patman'),('pato'),('pato123'),('patoche'),('patou'),('patpat'),('patr1ck'),('patria'),('patric'),('patrice'),('patrice1'),('patricia'),('patricia1'),('patricia12'),('patricia2'),('patricia3'),('patricio'),('patricio1'),('patrick'),('patrick!'),('patrick.'),('patrick01'),('patrick07'),('patrick08'),('patrick09'),('patrick1'),('patrick10'),('patrick11'),('patrick12'),('patrick123'),('patrick13'),('patrick14'),('patrick15'),('patrick16'),('patrick17'),('patrick18'),('patrick2'),('patrick21'),('patrick22'),('patrick23'),('patrick24'),('patrick3'),('patrick4'),('patrick5'),('patrick6'),('patrick69'),('patrick7'),('patrick8'),('patrick9'),('patrik'),('patrik1'),('patriot'),('patriot1'),('patriots'),('patriots1'),('patriots12'),('patriots2'),('patrizia'),('patrizio'),('patrol'),('patron'),('patron1'),('patrycja'),('patrycja1'),('patryk'),('patryk1'),('patryk123'),('pats12'),('patsy'),('patsy1'),('pattaya'),('patterson'),('patterson1'),('patti'),('patti1'),('pattie'),('pattinson'),('patton'),('patton1'),('patty'),('patty1'),('patty12'),('patty123'),('pattycake'),('pau'),('pauko97'),('paul'),('paul01'),('paul11'),('paul12'),('paul123'),('paul1234'),('paul13'),('paul21'),('paul22'),('paul23'),('paul69'),('paula'),('paula04'),('paula1'),('paula12'),('paula123'),('paulchen'),('pauleta'),('paulette'),('paulette1'),('paulie'),('paulie1'),('paulin'),('paulina'),('paulina1'),('paulina123'),('pauline'),('pauline1'),('paulinha'),('paulinho'),('paulinka'),('paulino'),('paulita'),('pauljohn'),('paulo'),('paulo1'),('paulo123'),('paulpaul'),('paulus'),('paulwall1'),('paupau'),('pavani'),('pavankumar'),('pavel'),('pavel1'),('pavel123'),('pavement'),('pavilion'),('pavilion1'),('pavithra'),('pavlenko'),('pavlik'),('pavlin'),('pavlina'),('pavlov'),('pavlova'),('pawel'),('pawel1'),('pawel123'),('pawelek'),('pawelek1'),('pawpaw'),('pawpaw1'),('pax123'),('paxton'),('paxton1'),('payaso'),('payaso1'),('payaso13'),('payatot'),('payback'),('payback1'),('payday'),('payday1'),('payment'),('payne1'),('payroll'),('payton'),('payton01'),('payton1'),('payton12'),('payton34'),('pazaway'),('pazeamor'),('pazyamor'),('pazzainter'),('pazzword'),('pazzword123'),('pbvfktnj'),('pbyfblf'),('PCwAC33gb9'),('pdbDfby2xx'),('pdiddy'),('pdiddy1'),('pdq4RV'),('pdtplf'),('pdtpljxrf'),('pe'),('PE#5GZ29PTZMSE'),('pea'),('peabody'),('peabody1'),('peace'),('peace!'),('peace&love'),('peace.'),('peace01'),('peace08'),('peace09'),('peace1'),('peace10'),('peace101'),('peace11'),('peace12'),('peace123'),('peace1234'),('peace13'),('peace14'),('peace15'),('peace2'),('peace21'),('peace22'),('peace23'),('peace2u'),('peace3'),('peace4'),('peace420'),('peace4all'),('peace4me'),('peace5'),('peace69'),('peace7'),('peace77'),('peace8'),('peace9'),('peaceandlo'),('peaceandlove'),('peaceful'),('peaceful1'),('peacelove'),('peacelove1'),('peacemaker'),('peaceman'),('peaceout'),('peaceout1'),('peaces'),('peach'),('peach1'),('peach12'),('peach123'),('peaches'),('peaches!'),('peaches01'),('peaches08'),('peaches09'),('peaches1'),('peaches10'),('peaches11'),('peaches12'),('peaches123'),('peaches13'),('peaches2'),('peaches21'),('peaches22'),('peaches23'),('peaches3'),('peaches4'),('peaches5'),('peaches6'),('peaches69'),('peaches7'),('peaches8'),('peaches9'),('peachie'),('peachtree'),('peachy'),('peachy1'),('peacock'),('peacock1'),('peanut'),('peanut!'),('peanut.'),('peanut00'),('peanut01'),('peanut02'),('peanut03'),('peanut04'),('peanut05'),('peanut06'),('peanut07'),('peanut08'),('peanut09'),('peanut1'),('peanut10'),('peanut101'),('peanut11'),('peanut12'),('peanut123'),('peanut1234'),('peanut13'),('peanut14'),('peanut15'),('peanut16'),('peanut17'),('peanut18'),('peanut2'),('peanut21'),('peanut22'),('peanut23'),('peanut24'),('peanut3'),('peanut33'),('peanut4'),('peanut5'),('peanut6'),('peanut69'),('peanut7'),('peanut77'),('peanut8'),('peanut88'),('peanut9'),('peanut99'),('peanutbutt'),('peanutbutter'),('peanuts'),('peanuts1'),('peanuts2'),('peanuts5'),('peapod'),('pearce'),('pearl'),('pearl1'),('pearl123'),('pearl2'),('pearljam'),('pearljam1'),('pearljam10'),('pearls'),('pearls1'),('pearly'),('pearson'),('pearson1'),('peavey'),('pebble'),('pebbles'),('pebbles01'),('pebbles1'),('pebbles12'),('pebbles123'),('pebbles2'),('pebbles3'),('pebbles7'),('pebDfcz3yx'),('pebEfcz3yx'),('pecker'),('pecker1'),('peckerwood'),('pecora'),('pedagogia'),('pedarsag'),('peddler'),('pedersen'),('pedigree'),('pedrinho'),('pedrito'),('pedrito1'),('pedro'),('pedro1'),('pedro10'),('pedro12'),('pedro123'),('pedro13'),('pedro2'),('pedros'),('pedrosa'),('peejay'),('peekab00'),('peekaboo'),('peekaboo1'),('peepee'),('peepee1'),('peeper'),('peepers'),('peepers1'),('peeps'),('peeps1'),('peewee'),('peewee1'),('peewee11'),('peewee12'),('peewee123'),('peewee13'),('peewee2'),('peewee3'),('pegase'),('pegaso'),('pegasus'),('pegasus1'),('peggy'),('peggy1'),('peggy123'),('peggysue'),('pegleg'),('peinture'),('pejsek'),('pekanbaru'),('pekida30'),('pekmabz'),('pekpek'),('pelado'),('pelangi'),('pelayo'),('pele'),('pele10'),('peleleco'),('pelican'),('pelican1'),('pelicano'),('peligro'),('pelikan'),('pelle'),('pelon1'),('pelon123'),('pelon13'),('pelota'),('pelota1'),('pelotudo'),('peluche'),('peluche1'),('peluchin'),('peludo'),('pelumi'),('pelusa'),('pelusa1'),('pelusita'),('peluso'),('pembroke'),('pen'),('pen123'),('penang'),('pencil'),('pencil1'),('pencil12'),('pencil123'),('pencil2'),('pendeja'),('pendeja1'),('pendejo'),('pendejo1'),('pendragon'),('pendragon1'),('pendulum'),('pene'),('penelopa'),('penelope'),('penelope1'),('penfold'),('pengpeng'),('penguin'),('penguin!'),('penguin1'),('penguin11'),('penguin12'),('penguin123'),('penguin13'),('penguin2'),('penguin22'),('penguin3'),('penguin4'),('penguin5'),('penguin7'),('penguin8'),('penguin9'),('penguins'),('penguins1'),('penis'),('penis!'),('penis.'),('penis1'),('penis11'),('penis12'),('penis123'),('penis2'),('penis22'),('penis3'),('penis5'),('penis666'),('penis69'),('penis7'),('peniss'),('penner'),('penney'),('pennie'),('pennies'),('pennstate'),('pennstate1'),('penny'),('penny01'),('penny1'),('penny11'),('penny12'),('penny123'),('penny2'),('penny3'),('penny5'),('penny7'),('pennydog'),('pennylane'),('pennylane1'),('pennys'),('pennywise'),('pennywise1'),('penpen'),('pensacola'),('pensacola1'),('penshoppe'),('pentagon'),('pentagram'),('pentax'),('penthouse'),('pentium'),('pentium1'),('pentium2'),('pentium3'),('pentium4'),('people'),('people!'),('people.'),('people1'),('people11'),('people12'),('people123'),('people2'),('people22'),('people3'),('people4'),('people5'),('people7'),('people9'),('peoples'),('peoples1'),('peoria'),('pep'),('pepe'),('pepe12'),('pepe123'),('pepe1234'),('pepepe'),('pepepepe'),('pepere'),('peperoni'),('pepete'),('pepette'),('pepino'),('pepita'),('pepite'),('pepito'),('pepito1'),('peppe'),('pepper'),('pepper!'),('pepper.'),('pepper00'),('pepper01'),('pepper02'),('pepper06'),('pepper07'),('pepper08'),('pepper09'),('pepper1'),('pepper10'),('pepper101'),('pepper11'),('pepper12'),('pepper123'),('pepper1234'),('pepper13'),('pepper14'),('pepper15'),('pepper16'),('pepper2'),('pepper21'),('pepper22'),('pepper23'),('pepper24'),('pepper3'),('pepper33'),('pepper4'),('pepper5'),('pepper6'),('pepper69'),('pepper7'),('pepper77'),('pepper8'),('pepper88'),('pepper9'),('pepper99'),('pepperdog'),('peppermint'),('pepperoni'),('pepperoni1'),('peppers'),('peppers1'),('peppie'),('peppino'),('peppone'),('peppy'),('peppy1'),('pepsi'),('pepsi01'),('pepsi1'),('pepsi10'),('pepsi101'),('pepsi11'),('pepsi12'),('pepsi123'),('pepsi13'),('pepsi2'),('pepsi21'),('pepsi22'),('pepsi23'),('pepsi24'),('pepsi3'),('pepsi5'),('pepsi69'),('pepsi7'),('pepsicola'),('pepsicola1'),('pepsie'),('pepsimax'),('pepsimax1'),('pepsis'),('pequena'),('per'),('perach'),('peralta'),('percival'),('percussion'),('percy'),('percy1'),('perdana'),('peregrine'),('pereira'),('perempuan'),('perez'),('perez1'),('perez123'),('perfect'),('perfect1'),('perfect10'),('perfect12'),('perfect123'),('perfect2'),('perfect7'),('perfection'),('perfecto'),('performance'),('perfume'),('perfume1'),('pericles'),('perico'),('perico1'),('peridot'),('period'),('periwinkle'),('perkele'),('perkele1'),('perkins'),('perkins1'),('perla'),('perla1'),('perlas'),('perlita'),('permanent'),('permata'),('pernille'),('perola'),('perpignan'),('perras'),('perrin'),('perrine'),('perrita'),('perrito'),('perrito1'),('perritos'),('perro'),('perro1'),('perro12'),('perro123'),('perroloco'),('perros'),('perros1'),('perry'),('perry1'),('perry123'),('persempre'),('persephone'),('perseus'),('pershing'),('persia'),('persian'),('persian1'),('persib'),('persija'),('persik'),('persimmon'),('persoff'),('person'),('person1'),('persona'),('personal'),('personal1'),('personale'),('personne'),('personnel'),('peruano'),('perugia'),('perumal'),('pervert'),('pervert1'),('pes2009'),('pes2010'),('pescado'),('pescador'),('pescara'),('pesciolino'),('peshawar'),('pessac'),('pet'),('pet123'),('petals'),('petanque'),('petardo'),('petasse'),('pete'),('pete12'),('pete123'),('pete379'),('peter'),('peter01'),('peter1'),('peter10'),('peter11'),('peter12'),('peter123'),('peter1234'),('peter13'),('peter2'),('peter22'),('peter23'),('peter3'),('peter5'),('peter69'),('peter7'),('peterbilt'),('peterbilt1'),('peterbuilt'),('peterburg'),('peterpan'),('peterpan1'),('peterpan2'),('peterpeter'),('peters'),('peters1'),('petersen'),('peterson'),('peterson1'),('peterson28'),('petete'),('petewentz'),('petewentz1'),('petey'),('petey1'),('petey123'),('petike'),('petite'),('petpet'),('petr'),('petra'),('petra1'),('petra123'),('petram'),('petrenko'),('petrik'),('petro'),('petrol'),('petroleum'),('petronas'),('petros'),('petrov'),('petrova'),('petrovich'),('petrovna'),('petrucci'),('petruha'),('petrus'),('petruska'),('petshop'),('petter'),('petting'),('petula'),('petunia'),('petunia1'),('peugeot'),('peugeot1'),('peugeot106'),('peugeot206'),('peugeot306'),('peugeot307'),('peugeot406'),('pewdiepie'),('peyton'),('peyton01'),('peyton08'),('peyton1'),('peyton12'),('peyton18'),('pf'),('pf:'),('pfchfytw'),('pferde'),('pfhbyf'),('pfhfpf'),('pfkegf'),('pflybwf'),('pfqwtdf'),('pfqxbr'),('pfqxjyjr'),('pfqxtyjr'),('pft'),('pft:'),('pfuflrf'),('pg260365'),('ph0enix'),('phalanx'),('phantom'),('phantom1'),('phantom2'),('phantom7'),('phantoms'),('pharaoh'),('pharaon'),('pharma'),('pharmacie'),('pharmacist'),('pharmacy'),('pharmacy1'),('pharrell'),('phat'),('phatboy1'),('phatfarm'),('phatty'),('phatty1'),('pheasant'),('phelps'),('phenix'),('phenom'),('pheobe'),('pheobe1'),('pheonix'),('pheonix1'),('phi'),('phialpha'),('phil'),('phil123'),('phil413'),('philadelphia'),('philip'),('philip1'),('philip12'),('philip123'),('philipp'),('philipp1'),('philippa'),('philippe'),('philippe1'),('philippine'),('philippines'),('philips'),('philips1'),('philips123'),('phillies'),('phillies08'),('phillies1'),('phillip'),('phillip1'),('phillip123'),('phillip2'),('phillips'),('phillips1'),('philly'),('philly1'),('philly123'),('philly2'),('philly215'),('philly3'),('philomena'),('philosophy'),('philou'),('phiphi'),('phish'),('phish1'),('phish420'),('pho'),('phobos'),('phoebe'),('phoebe01'),('phoebe1'),('phoebe12'),('phoebe123'),('phoenix'),('phoenix!'),('phoenix01'),('phoenix1'),('phoenix11'),('phoenix12'),('phoenix123'),('phoenix13'),('phoenix2'),('phoenix3'),('phoenix5'),('phoenix602'),('phoenix69'),('phoenix7'),('phoenix8'),('phoenix888'),('phoenix9'),('phone'),('phone1'),('phone12'),('phone123'),('phone2'),('phones'),('phones1'),('photo'),('photo1'),('photo123'),('photograph'),('photography'),('photon'),('photos'),('photos1'),('photoshop'),('phuket'),('phuong'),('phx602'),('phyllis'),('phyllis1'),('physical'),('physics'),('physics1'),('physio'),('pi31415'),('pi314159'),('piaggio'),('pianist'),('piankova72'),('piano'),('piano1'),('piano123'),('pianoforte'),('pianoman'),('pianoman1'),('pianos'),('piapia'),('piazza'),('piazza31'),('pic'),('picachu'),('picard'),('picard1'),('picaso'),('picasso'),('picasso1'),('picchio'),('piccione'),('piccola'),('piccolina'),('piccolo'),('piccolo1'),('pichon'),('pickle'),('pickle!'),('pickle1'),('pickle11'),('pickle12'),('pickle123'),('pickle13'),('pickle2'),('pickle3'),('pickle7'),('pickles'),('pickles!'),('pickles1'),('pickles12'),('pickles123'),('pickles2'),('pickles3'),('pickles7'),('pickup'),('pickwick'),('picnic'),('picolo'),('picsou'),('picture'),('picture1'),('pictures'),('pictures1'),('pidaras'),('pidoras'),('pie'),('pie123'),('pieces'),('piedmont'),('pieface'),('pieface1'),('pieisgood'),('pieman'),('pieman1'),('piepie'),('piepie1'),('pierce'),('pierce1'),('pierce34'),('piercing'),('pierina'),('pierino'),('pierluigi'),('piero'),('pierpaolo'),('pierre'),('pierre1'),('pierre123'),('pierrick'),('pierrot'),('pies'),('piesek'),('piesek1'),('pieter'),('pietje'),('pietra'),('pietro'),('piffish'),('pig'),('pig123'),('pigdog'),('pigeon'),('pigeon1'),('piggie'),('piggie1'),('piggies'),('piggies1'),('piggy'),('piggy1'),('piggy12'),('piggy123'),('piggy2'),('piggy3'),('piggy5'),('piggys'),('piglet'),('piglet01'),('piglet1'),('piglet12'),('piglet123'),('piglet2'),('pigman'),('pigpen'),('pigpig'),('pigs'),('pika'),('pika12'),('pikachu'),('pikachu1'),('pikachu12'),('pikachu123'),('pikachu2'),('pikachu25'),('pikapika'),('pikmin'),('piknik'),('pikolo'),('pilar'),('pilates'),('pilchard'),('pilgrim'),('pilgrim1'),('piligrim'),('pilipinas'),('pilipino'),('pillar'),('pillow'),('pillow1'),('pillow123'),('pillows'),('pilot'),('pilot1'),('pilot123'),('pilote'),('piloto'),('pilots'),('pilou'),('pilsner'),('pimaout'),('pimboli'),('pimenta'),('pimentel'),('pimmel'),('pimousse'),('pimp'),('pimp#1'),('pimp00'),('pimp01'),('pimp02'),('pimp05'),('pimp06'),('pimp07'),('pimp08'),('pimp09'),('pimp10'),('pimp100'),('pimp101'),('pimp11'),('pimp12'),('pimp123'),('pimp1234'),('pimp12345'),('pimp13'),('pimp14'),('pimp15'),('pimp16'),('pimp17'),('pimp18'),('pimp19'),('pimp20'),('pimp2006'),('pimp21'),('pimp22'),('pimp23'),('pimp24'),('pimp25'),('pimp32'),('pimp33'),('pimp34'),('pimp420'),('pimp44'),('pimp45'),('pimp4life'),('pimp55'),('pimp69'),('pimp77'),('pimp88'),('pimp89'),('pimp90'),('pimp92'),('pimp99'),('pimpc1'),('pimpdaddy'),('pimpdaddy1'),('pimpdaddy2'),('pimpen1'),('pimper1'),('pimpette'),('pimpette1'),('pimpim'),('pimpin'),('pimpin!'),('pimpin.'),('pimpin0'),('pimpin01'),('pimpin06'),('pimpin07'),('pimpin08'),('pimpin09'),('pimpin1'),('pimpin10'),('pimpin101'),('pimpin11'),('pimpin12'),('pimpin123'),('pimpin13'),('pimpin14'),('pimpin15'),('pimpin16'),('pimpin2'),('pimpin21'),('pimpin22'),('pimpin23'),('pimpin24'),('pimpin3'),('pimpin4'),('pimpin420'),('pimpin5'),('pimpin6'),('pimpin69'),('pimpin7'),('pimpin8'),('pimpin9'),('pimping'),('pimping1'),('pimpjuice'),('pimpjuice1'),('pimpman1'),('pimpollo'),('pimppimp'),('pimppimp1'),('pimps'),('pimps1'),('pimpshit'),('pimpshit1'),('pimpster'),('pimpster1'),('pin'),('pinacolada'),('pinarello'),('pinball'),('pinball1'),('pincopallino'),('pindakaas'),('pineapple'),('pineapple!'),('pineapple1'),('pineapple2'),('pineapple3'),('pineapple7'),('pineapples'),('pinecone'),('pinecone1'),('pineda'),('pinetree'),('pinetree1'),('pinewood'),('ping'),('ping123'),('pingouin'),('pingping'),('pingpong'),('pingpong1'),('pingu'),('pinguin'),('pinguino'),('pingvin'),('pinhead'),('pinhead1'),('pinheiro'),('pinina'),('pink'),('pink!!'),('pink00'),('pink01'),('pink02'),('pink03'),('pink04'),('pink05'),('pink06'),('pink07'),('pink08'),('pink09'),('pink10'),('pink100'),('pink101'),('pink11'),('pink12'),('pink123'),('pink1234'),('pink12345'),('pink13'),('pink14'),('pink143'),('pink15'),('pink16'),('pink17'),('pink18'),('pink19'),('pink20'),('pink21'),('pink22'),('pink23'),('pink24'),('pink25'),('pink26'),('pink27'),('pink28'),('pink32'),('pink321'),('pink33'),('pink44'),('pink45'),('pink55'),('pink66'),('pink69'),('pink77'),('pink86'),('pink87'),('pink88'),('pink89'),('pink90'),('pink91'),('pink92'),('pink93'),('pink94'),('pink95'),('pink96'),('pink99'),('pinkerton'),('pinkey'),('pinkey1'),('pinkflower'),('pinkfloyd'),('pinkfloyd1'),('pinkgirl'),('pinkgirl1'),('pinki'),('pinkie'),('pinkie1'),('pinkish'),('pinklady'),('pinklady1'),('pinklove'),('pinklove1'),('pinklover'),('pinklover1'),('pinkness'),('pinkpanthe'),('pinkpanther'),('pinkpig'),('pinkpink'),('pinkpink1'),('pinkrose'),('pinkrose1'),('pinkstar'),('pinky'),('pinky!'),('pinky01'),('pinky09'),('pinky1'),('pinky10'),('pinky101'),('pinky11'),('pinky12'),('pinky123'),('pinky13'),('pinky14'),('pinky2'),('pinky21'),('pinky22'),('pinky23'),('pinky3'),('pinky4'),('pinky5'),('pinky6'),('pinky69'),('pinky7'),('pinky8'),('pinkys'),('pinnacle'),('pinnacle1'),('pino'),('pinocchio'),('pinocho'),('pinokio'),('pinoy'),('pinoy1'),('pinoyako'),('pinpin'),('pinpon'),('pintail'),('pinto'),('pinto1'),('pintoo'),('pintura'),('pinuccio'),('piolin'),('piolin1'),('pioneer'),('pioneer1'),('pioneers'),('pioner'),('piopio'),('piotr'),('piotr1'),('piotrek'),('piotrek1'),('piotrus'),('pioupiou'),('pip'),('pipe'),('pipeline'),('pipeline1'),('piper'),('piper1'),('piper123'),('piper2'),('pipers'),('pipetka'),('pipi'),('pipi1000'),('pipicaca'),('pipino'),('pipipi'),('pipiska'),('pipo'),('pipoca'),('pipopipo'),('pippa'),('pippa1'),('pippen'),('pippen33'),('pipper'),('pippi'),('pippin'),('pippin1'),('pippo'),('pippo1'),('pippo123'),('pippone'),('pippopippo'),('pippy1'),('piramida'),('piramide'),('piranha'),('pirata'),('pirata1'),('piratas'),('pirate'),('pirate1'),('pirate12'),('pirate123'),('pirate13'),('pirate2'),('pirates'),('pirates!'),('pirates1'),('pirates12'),('pirates123'),('pirates2'),('pirates3'),('pirelli'),('pirouette'),('pirulito'),('pirulo'),('pisang'),('pisces'),('pisces1'),('piscina'),('piscine'),('piscis'),('pisellino'),('pisello'),('pisellone'),('pisica'),('pisicuta'),('pisolo'),('piss'),('pissant'),('pissed'),('pissed1'),('pissedoff'),('pissedoff1'),('pisser'),('pissoff'),('pissoff1'),('pistache'),('pistol'),('pistol1'),('pistola'),('piston'),('piston1'),('pistons'),('pistons1'),('pit'),('pitagoras'),('Pitapooe1'),('pitbul'),('pitbull'),('pitbull1'),('pitbull12'),('pitbull123'),('pitbull13'),('pitbull2'),('pitbull23'),('pitbull3'),('pitbull5'),('pitbull69'),('pitbull7'),('pitbulls'),('pitbulls1'),('pitcher'),('pitcher1'),('pitchou'),('pitchoune'),('piter'),('pitiponc'),('pittbull'),('pittbull1'),('pittsburgh'),('pituca'),('pitufa'),('pitufina'),('pitufo'),('piupiu'),('pivoine'),('pixie'),('pixie1'),('pixie123'),('pixiedust'),('pixiedust1'),('pixies'),('pixies1'),('piyush'),('pizarro'),('pizda'),('pizdec'),('pizza'),('pizza!'),('pizza1'),('pizza10'),('pizza101'),('pizza11'),('pizza12'),('pizza123'),('pizza1234'),('pizza13'),('pizza2'),('pizza21'),('pizza22'),('pizza23'),('pizza3'),('pizza4'),('pizza5'),('pizza6'),('pizza7'),('pizza9'),('pizzaboy'),('pizzahut'),('pizzahut1'),('pizzaman'),('pizzaman1'),('pizzapie'),('pizzapie1'),('pizzapizza'),('pizzas'),('pizzas1'),('pizzeria'),('pjkeirf'),('pjkjnj'),('pk3x7w9W'),('pl'),('pla'),('placebo'),('placebo1'),('placement'),('plague'),('plaisir'),('planb1'),('planb123'),('plane'),('planes'),('planet'),('planet1'),('planeta'),('planete'),('plankova2012'),('plankton'),('planner'),('planner1'),('planning'),('PlanoTX'),('plant'),('plant1'),('planta'),('plants'),('plants1'),('plasma'),('plasma1'),('plaster'),('plastic'),('plastic1'),('plastics'),('plastik'),('platano'),('platano1'),('platina'),('platini'),('platinum'),('platinum1'),('plato'),('plato1'),('platon'),('platoon'),('platypus'),('platypus1'),('play'),('play12'),('play123'),('play2win'),('play4fun'),('play69'),('playa'),('playa1'),('playa12'),('playa123'),('playa13'),('playa2'),('playa23'),('playa4life'),('playa5'),('playa69'),('playas'),('playas1'),('playaz'),('playb0y'),('playball'),('playball1'),('playbill'),('playboi'),('playboi1'),('playboy'),('playboy!'),('playboy.'),('playboy01'),('playboy07'),('playboy08'),('playboy09'),('playboy1'),('playboy10'),('playboy101'),('playboy11'),('playboy12'),('playboy123'),('playboy13'),('playboy14'),('playboy15'),('playboy16'),('playboy17'),('playboy18'),('playboy2'),('playboy21'),('playboy22'),('playboy23'),('playboy3'),('playboy4'),('playboy5'),('playboy6'),('playboy69'),('playboy7'),('playboy8'),('playboy9'),('playboys'),('player'),('player!'),('player01'),('player07'),('player08'),('player09'),('player1'),('player10'),('player101'),('player11'),('player12'),('player123'),('player13'),('player14'),('player15'),('player16'),('player17'),('player18'),('player2'),('player21'),('player22'),('player23'),('player24'),('player3'),('player4'),('player5'),('player6'),('player69'),('player7'),('player8'),('player9'),('players'),('players1'),('playful'),('playful1'),('playgame'),('playgames'),('playgirl'),('playgirl1'),('playgirl69'),('playground'),('playgurl'),('playhard'),('playing'),('playing1'),('playmaker'),('playmate'),('playmate1'),('playnow'),('playplay'),('playstatio'),('playstation'),('playstation1'),('playstation2'),('playstation3'),('playtime'),('playtime1'),('plazma'),('pleasant'),('pleasant1'),('please'),('please!'),('please1'),('please11'),('please12'),('please123'),('please2'),('please3'),('pleaseme'),('pleasure'),('pleasure1'),('plenty'),('pleomax'),('pletnevakaterina'),('plies1'),('pljhjdmt'),('plm123'),('plmokn'),('plokij'),('plokij1'),('plokijuh'),('plombier'),('plonker'),('plop'),('ploplo'),('plopplop'),('ploppy'),('ploppy10'),('plovdiv'),('plover'),('plplpl'),('pluisje'),('plumber'),('plumber1'),('plumbing'),('plumbing1'),('plumeria'),('plumes'),('plummer'),('plus44'),('pluto'),('pluto1'),('pluto123'),('pluton'),('plymouth'),('plymouth1'),('png'),('PnUfSci218'),('po'),('po918dg'),('pobeda'),('pocahontas'),('pochacco'),('pocholo'),('pochta'),('pocitac'),('pocket'),('pocket1'),('pocket12'),('pockets'),('pockets1'),('pocoloco'),('pocoyo'),('poczta'),('poczta1'),('POD-FIF'),('podarok'),('poderosa'),('poderoso'),('podolski'),('podstava'),('poekie'),('poepen'),('poepen19'),('poepie'),('poesia'),('poesje'),('poet'),('poetic1'),('poetry'),('poetry1'),('pogi'),('pogi123'),('pogiako'),('pogiako1'),('pogiako123'),('pogiko'),('pogime'),('pogo'),('pogoda'),('pohekale'),('pohoda'),('poi'),('poi098'),('poi123'),('poilkj'),('poilkjmnb'),('poilut'),('point'),('point1'),('pointblank'),('pointbreak'),('pointe'),('pointer'),('pointer1'),('pointers'),('pointjor'),('points'),('poipoi'),('poipoi1'),('poipoipoi'),('poirot'),('poison'),('poison1'),('poisonivy'),('poisson'),('poissons'),('poiu'),('poiu07'),('poiu0987'),('poiu1234'),('poiupoiu'),('poiuy'),('poiuy1'),('poiuy123'),('poiuy6'),('poiuyt'),('poiuyt1'),('poiuyt12'),('poiuyt123'),('poiuyt5'),('poiuytr'),('poiuytre'),('poiuytrew1'),('poiuytrewq'),('poiuytrewq1'),('poiuytreza'),('pok'),('pok29q6666'),('poke'),('poke123'),('pokemon'),('pokemon!'),('pokemon.'),('pokemon0'),('pokemon00'),('pokemon01'),('pokemon09'),('pokemon1'),('pokemon10'),('pokemon100'),('pokemon101'),('pokemon11'),('pokemon12'),('pokemon123'),('pokemon1234'),('pokemon12345'),('pokemon13'),('pokemon14'),('pokemon15'),('pokemon2'),('pokemon21'),('pokemon22'),('pokemon23'),('pokemon3'),('pokemon4'),('pokemon5'),('pokemon6'),('pokemon69'),('pokemon7'),('pokemon8'),('pokemon88'),('pokemon9'),('pokemon90'),('pokemon98'),('pokemon99'),('pokemons'),('poker'),('poker1'),('poker123'),('poker21'),('pokerface'),('pokerface1'),('pokers'),('pokerstar'),('pokesmot'),('pokey'),('pokey1'),('pokhara'),('poklop'),('poknat'),('pokopushkin'),('pokora'),('pokpok'),('pokwang'),('pol'),('pol123'),('polaco'),('poland'),('poland1'),('polar'),('polar1'),('polarbear'),('polarbear1'),('polaris'),('polaris1'),('polaroid'),('Polenka1'),('polgara'),('poli'),('police'),('police01'),('police1'),('police11'),('police12'),('police123'),('police2'),('police9'),('police911'),('policeman'),('policeman1'),('policia'),('policja'),('policy'),('policy1'),('poligon'),('polikloh00000'),('polilla'),('polina'),('polina1'),('polinesia'),('polini'),('polinka'),('polinochka'),('polipo'),('polipoli'),('polish'),('polish1'),('polisi'),('polita'),('polite'),('politics'),('polito'),('polizei'),('polizia'),('polk'),('polka'),('polka1'),('polkadot'),('polkadot1'),('polkadots'),('polkadots1'),('polkaudio'),('polkaudio1'),('polki'),('polkmn'),('polkovnik'),('pollack1'),('pollard'),('pollen'),('pollita'),('pollito'),('pollito1'),('pollo'),('pollo1'),('pollo12'),('pollo123'),('pollock'),('pollon'),('pollop'),('pollos'),('pollution'),('pollux'),('polly'),('polly1'),('polly123'),('pollyanna'),('PolniyPizdec0211'),('PolniyPizdec1102'),('PolniyPizdec110211'),('polo'),('polo00'),('polo11'),('polo12'),('polo123'),('polo1234'),('polo13'),('polo90'),('polo99'),('polochon'),('pololo'),('polonez'),('polonia'),('polonia1'),('polopo'),('polopolo'),('polopolo1'),('polosport'),('polpetta'),('polpol'),('polpol11'),('polpolpol'),('polska'),('polska1'),('polska11'),('polska12'),('polska123'),('polska2'),('poltava'),('polymer'),('pom'),('pomalo123'),('pomidor'),('pomme'),('pommes'),('pommes123'),('pomodoro'),('pomona'),('pomona1'),('pomona909'),('pompey'),('pompey1'),('pompier'),('pompiers'),('pompino'),('pompom'),('pompom1'),('pompon'),('ponce'),('ponce1'),('ponchik'),('poncho'),('poncho1'),('ponderosa'),('pongo'),('pongo1'),('pongpong'),('ponies'),('ponies1'),('ponorogo'),('ponpon'),('pontiac'),('pontiac1'),('pontiacg6'),('pontianak'),('pontus'),('pony'),('pony123'),('ponyboy'),('ponyboy1'),('ponytail'),('poo'),('poo123'),('poobear'),('poobear1'),('pooch'),('pooch1'),('poochie'),('poochie1'),('poochie2'),('poochy'),('poodie'),('poodie1'),('poodle'),('poodle1'),('poodles'),('poodles1'),('pooface'),('pooface1'),('pooh'),('pooh01'),('pooh06'),('pooh07'),('pooh08'),('pooh09'),('pooh10'),('pooh11'),('pooh12'),('pooh123'),('pooh1234'),('pooh13'),('pooh14'),('pooh15'),('pooh16'),('pooh17'),('pooh18'),('pooh21'),('pooh22'),('pooh23'),('pooh24'),('pooh69'),('poohbaby1'),('poohbear'),('poohbear!'),('poohbear01'),('poohbear07'),('poohbear08'),('poohbear09'),('poohbear1'),('poohbear10'),('poohbear11'),('poohbear12'),('poohbear13'),('poohbear14'),('poohbear15'),('poohbear16'),('poohbear17'),('poohbear18'),('poohbear19'),('poohbear2'),('poohbear20'),('poohbear21'),('poohbear22'),('poohbear23'),('poohbear3'),('poohbear4'),('poohbear5'),('poohbear6'),('poohbear69'),('poohbear7'),('poohbear8'),('poohbear9'),('poohead'),('poohead1'),('poohpooh'),('poohpooh1'),('pooja'),('pooja123'),('pooka1'),('pookey'),('pookey1'),('pookie'),('pookie!'),('pookie01'),('pookie08'),('pookie1'),('pookie10'),('pookie11'),('pookie12'),('pookie123'),('pookie13'),('pookie14'),('pookie2'),('pookie21'),('pookie22'),('pookie23'),('pookie3'),('pookie4'),('pookie5'),('pookie69'),('pookie7'),('pookiebear'),('pooky'),('pooky1'),('pool'),('pool123'),('poolpool'),('poolshark'),('poonam'),('poontang'),('poontang1'),('pooo'),('pooooo'),('poooop'),('pooop'),('poop'),('poop00'),('poop01'),('poop09'),('poop1'),('poop10'),('poop101'),('poop11'),('poop111'),('poop12'),('poop123'),('poop1234'),('poop12345'),('poop13'),('poop14'),('poop15'),('poop21'),('poop22'),('poop23'),('poop24'),('poop25'),('poop33'),('poop44'),('poop45'),('poop55'),('poop666'),('poop69'),('poop77'),('poop88'),('poop90'),('poop99'),('poopdick'),('poopdick1'),('pooper'),('pooper1'),('pooper12'),('pooper123'),('pooper2'),('poopers'),('poopers1'),('poopey'),('poopey1'),('poopface'),('poopface1'),('poophead'),('poophead1'),('poopie'),('poopie!'),('poopie1'),('poopie12'),('poopie123'),('poopie2'),('poopie3'),('poopies'),('poopies1'),('pooping'),('pooping1'),('poopmaster'),('poopoo'),('poopoo!'),('poopoo0'),('poopoo1'),('poopoo11'),('poopoo12'),('poopoo123'),('poopoo2'),('poopoo22'),('poopoo3'),('poopoo9'),('poopoopoo'),('pooppoop'),('pooppoop1'),('poops'),('poops1'),('poopsie'),('poopsie1'),('poopstain'),('poopstain1'),('poopy'),('poopy!'),('poopy1'),('poopy11'),('poopy12'),('poopy123'),('poopy2'),('poopy3'),('poopy5'),('poopy6'),('poopy7'),('poopypants'),('poornima'),('poot62'),('pooter'),('pooter1'),('pootie'),('pootie1'),('pop'),('pop101'),('pop123'),('pop1234'),('pop12345'),('pop168168'),('popapopa'),('popcorn'),('popcorn!'),('popcorn.'),('popcorn1'),('popcorn10'),('popcorn101'),('popcorn11'),('popcorn12'),('popcorn123'),('popcorn13'),('popcorn2'),('popcorn22'),('popcorn23'),('popcorn3'),('popcorn4'),('popcorn5'),('popcorn6'),('popcorn7'),('popcorn8'),('popcorn9'),('popeye'),('popeye1'),('popeye123'),('popeyes'),('popkorn'),('poplar'),('popo'),('popo00'),('popo09'),('popo12'),('popo123'),('popo1234'),('popokatepetl'),('popolo'),('popop'),('popopo'),('popopo1'),('popopopo'),('popov'),('popova'),('popovkin83'),('poppa1'),('poppen'),('popper'),('popper1'),('poppers'),('poppet'),('poppie'),('poppie1'),('poppies'),('poppin'),('poppin1'),('poppin5'),('poppins'),('poppop'),('poppop1'),('poppop12'),('poppop123'),('poppoppop'),('poppy'),('poppy1'),('poppy12'),('poppy123'),('poppy2'),('poppydog'),('poppys'),('poprocks'),('poprocks1'),('pops'),('popsicle'),('popsicle1'),('popstar'),('popstar1'),('popstar123'),('poptart'),('poptart1'),('poptart2'),('poptarts'),('poptarts1'),('poptropica'),('popular'),('popular1'),('por'),('porche'),('porche911'),('porcinet'),('porcodio'),('porcodio1'),('porcupine'),('porfavor'),('pork'),('porkchop'),('porkchop1'),('porker'),('porky'),('porky1'),('porkypig'),('porn'),('porn123'),('porn69'),('porno'),('porno1'),('porno123'),('porno69'),('pornos'),('pornostar'),('pornporn'),('pornstar'),('pornstar1'),('pornstar69'),('poroto'),('porque'),('porridge'),('porsche'),('porsche1'),('porsche9'),('porsche911'),('porsche944'),('porsha'),('porsha1'),('porshe'),('porshe911'),('porsiempre'),('portable'),('portakal'),('portal'),('porter'),('porter1'),('portfolio'),('portia'),('portia1'),('portillo'),('portis26'),('portishead'),('portland'),('portland1'),('portman'),('porto'),('portocala'),('portos'),('portsmouth'),('portugal'),('portugal1'),('portugal12'),('portugal17'),('portugal7'),('portugues'),('portvale'),('poseidon'),('poseidon1'),('poseinfopass'),('poser1'),('poser2'),('positano'),('positive'),('positive1'),('positivo'),('posoxina.88'),('possible'),('possible1'),('possum'),('possum1'),('post'),('postal'),('postal1'),('postal2'),('postcard'),('poster'),('postit'),('postman'),('postman1'),('postoffice'),('pot'),('pot123'),('pot420'),('potapova'),('potato'),('potato1'),('potato12'),('potato123'),('potatoe'),('potatoe1'),('potatoes'),('potatoes1'),('potential'),('potenza'),('pothead'),('pothead1'),('pothead2'),('pothead420'),('pothead69'),('potpot'),('potter'),('potter1'),('potter11'),('potter12'),('potter123'),('potter13'),('potter2'),('potter7'),('potters'),('pottery'),('pou'),('poubelle'),('pouetpouet'),('poulet'),('poulette'),('pounce'),('pouncer'),('pounds'),('poupee'),('poupette'),('poupou'),('poupoune'),('pourquoi'),('poussin'),('poussy'),('PovlmLy727'),('povray14'),('pow'),('powder'),('powder1'),('powell'),('powell1'),('power'),('power01'),('power1'),('power10'),('power11'),('power12'),('power123'),('power1234'),('power12345'),('power13'),('power2'),('power22'),('power23'),('power3'),('power4'),('power5'),('power6'),('power7'),('power8'),('power9'),('power99'),('Power999'),('powerade'),('powerade1'),('powerball'),('powered'),('powerful'),('powerful1'),('powerfull'),('powerhouse'),('powerman'),('powerman1'),('powermax'),('powerof3'),('powerplay'),('powerpower'),('powerpuff'),('powerpuff1'),('powerrange'),('powerranger'),('powerrangers'),('powers'),('powers1'),('powerslave'),('powerstroke'),('powerup'),('powpow'),('powwow'),('poypoy'),('pozitiv'),('poznan'),('pp'),('pp123456'),('ppoo0099'),('ppp'),('ppp000'),('ppp111'),('ppp123'),('pppp'),('ppppp'),('ppppp0'),('ppppp1'),('pppppp'),('pppppp1'),('ppppppp'),('pppppppp'),('ppppppppp'),('pppppppppp'),('pqntmt1247'),('pr'),('pr1nc3ss'),('pr1nce'),('pr1ncess'),('pra'),('prabha'),('prabhakar'),('prabhu'),('prachi'),('practical'),('practice'),('practice1'),('prada'),('prada1'),('pradeep'),('pragati'),('prague'),('pragya'),('prairie'),('praise'),('praise1'),('praisegod'),('praisegod1'),('praisehim'),('praisethelord'),('prajakta'),('prakash'),('praktikum'),('praline'),('pramila'),('pramod'),('pranav'),('prancer'),('prancer1'),('prank1'),('prankster1'),('prapor'),('prasad'),('prasad123'),('prasanna'),('prasanth'),('prashant'),('prashanth'),('pratama'),('pratap'),('prateek'),('pratham'),('pratibha'),('pratik'),('pratiksha'),('pratima'),('pravda'),('praveen'),('praveena'),('pravin'),('praxis'),('pray4me'),('prayer'),('prayer1'),('prayers'),('prdel'),('prdelka'),('pre'),('preacher'),('preacher1'),('preciosa'),('preciosa1'),('precioso'),('precious'),('precious!'),('precious01'),('precious1'),('precious10'),('precious11'),('precious12'),('precious13'),('precious2'),('precious3'),('precious5'),('precious7'),('precision'),('predator'),('predator1'),('predator2'),('preethi'),('preeti'),('preety'),('preety1'),('pregmar2'),('pregnant'),('pregnant1'),('prelude'),('prelude1'),('premier'),('premier1'),('premiere'),('premium'),('premium1'),('prenses'),('preppy'),('preppy1'),('prerna'),('presario'),('presario1'),('preschool'),('prescott'),('present'),('president'),('president1'),('presidente'),('presley'),('presley1'),('press'),('pressure'),('pressure1'),('prestige'),('prestige1'),('prestigio'),('presto'),('presto1'),('preston'),('preston1'),('preston12'),('preston123'),('preston2'),('preston3'),('pretender'),('pretinha'),('pretoria'),('pretty'),('pretty!'),('pretty01'),('pretty07'),('pretty08'),('pretty09'),('pretty1'),('pretty10'),('pretty101'),('pretty11'),('pretty12'),('pretty123'),('pretty13'),('pretty14'),('pretty15'),('pretty16'),('pretty17'),('pretty18'),('pretty2'),('pretty21'),('pretty22'),('pretty23'),('pretty3'),('pretty4'),('pretty5'),('pretty6'),('pretty7'),('pretty8'),('pretty9'),('prettyboi1'),('prettyboy'),('prettyboy1'),('prettyboy2'),('prettyboys'),('prettygirl'),('prettygurl'),('prettyinpink'),('prettylady'),('prettyme'),('prettyme1'),('prettypink'),('prettywoman'),('pretzel'),('pretzel1'),('preview1'),('prezident'),('pri'),('price'),('price1'),('priceless'),('priceless1'),('pride'),('pride1'),('pridprid'),('pridurok'),('priest'),('priest1'),('prieto'),('prieto77'),('prikol'),('prikoluxa'),('prima'),('primary'),('primavara'),('primavera'),('primavera1'),('primax'),('prime'),('prime1'),('primera'),('primetime'),('primetime1'),('primetime2'),('primo'),('primo1'),('primrose'),('primrose1'),('primus'),('primus1'),('princ3ss'),('prince'),('prince!'),('prince01'),('prince07'),('prince08'),('prince09'),('prince1'),('prince10'),('prince11'),('prince12'),('prince123'),('prince1234'),('prince13'),('prince14'),('prince1999'),('prince2'),('prince21'),('prince22'),('prince23'),('prince3'),('prince33'),('prince4'),('prince5'),('prince55'),('prince69'),('prince7'),('prince99'),('princes'),('princes1'),('princesa'),('princesa1'),('princesa12'),('princesa2'),('princesita'),('princess'),('princess!'),('princess#1'),('princess*'),('princess.'),('princess0'),('princess00'),('princess01'),('princess02'),('princess03'),('princess04'),('princess05'),('princess06'),('princess07'),('princess08'),('princess09'),('princess1'),('princess10'),('princess101'),('princess11'),('princess12'),('princess123'),('princess13'),('princess14'),('princess15'),('princess16'),('princess17'),('princess18'),('princess19'),('princess2'),('princess20'),('princess21'),('princess22'),('princess23'),('princess24'),('princess25'),('princess26'),('princess27'),('princess28'),('princess29'),('princess3'),('princess30'),('princess31'),('princess32'),('princess33'),('princess34'),('princess4'),('princess44'),('princess45'),('princess5'),('princess55'),('princess56'),('princess6'),('princess66'),('princess69'),('princess7'),('princess77'),('princess78'),('princess8'),('princess81'),('princess82'),('princess83'),('princess84'),('princess85'),('princess86'),('princess87'),('princess88'),('princess89'),('princess9'),('princess90'),('princess91'),('princess92'),('princess93'),('princess94'),('princess95'),('princess96'),('princess97'),('princess98'),('princess99'),('princessa'),('princessa1'),('princesse'),('princesse1'),('princeton'),('princeton1'),('principal'),('principe'),('principe1'),('principessa'),('princy'),('pringle'),('pringles'),('pringles1'),('prinsesa'),('print'),('printemps'),('printer'),('printer1'),('printesa'),('printing'),('prinzessin'),('priora'),('prisca'),('priscila'),('priscilla'),('priscilla1'),('prishtina'),('prisma'),('prison'),('prison1'),('prisonbreak'),('prisoner'),('prissy'),('prissy1'),('pritam'),('privacy'),('privacy1'),('privado'),('privat'),('private'),('private1'),('private123'),('private2'),('privet'),('privet1'),('privet123'),('privetik'),('privs'),('priya'),('priya1'),('priya123'),('priyaa'),('priyam'),('priyanka'),('priyanka1'),('prizrak'),('pro'),('pro100'),('pro123'),('probation1'),('problem'),('problem1'),('process'),('prodigy'),('prodigy1'),('produce'),('produce1'),('producer'),('producer1'),('product'),('production'),('profesional'),('profesor'),('profesora'),('profession'),('professional'),('professionaltools'),('professor'),('professor1'),('professora'),('profeta'),('profile'),('profile1'),('profissional'),('profit'),('profit1'),('progamer'),('program'),('program1'),('programmer'),('progress'),('progress1'),('progressive'),('project'),('project1'),('project123'),('project8'),('project86'),('projects'),('projectsadminx'),('proline'),('prometeo'),('prometheus'),('promise'),('promise1'),('promise123'),('promise2'),('promises'),('promo1'),('promote1'),('promotion'),('promotion1'),('pronto'),('propaganda'),('propane'),('propel1'),('property'),('property1'),('prophecy'),('prophet'),('prophet1'),('prospect'),('prospect1'),('prosper'),('prosper1'),('prosperity'),('prospero'),('prosto'),('prosto_chelkynchik'),('prostreet'),('prosvirkind'),('protect'),('protect1'),('protected'),('protection'),('protector'),('protege'),('protein'),('proteus'),('protocol'),('proton'),('protoss'),('protoss1'),('prototype'),('protozoa'),('prout'),('proute'),('proutprout'),('prov356'),('prova'),('provence'),('proverbs'),('proverbs1'),('proverbs31'),('proverbs35'),('proverka'),('providence'),('provider'),('proview'),('proview1'),('prowler'),('prowler1'),('prozac'),('prozukin-shift'),('prudence'),('prudence1'),('prueba'),('prunelle'),('przemek'),('przemek1'),('przyjaciolki'),('ps2ps2'),('psalm119'),('psalm121'),('psalm139'),('psalm23'),('psalm91'),('psalms'),('psalms23'),('psalms91'),('pseudo'),('psicologa'),('psicologia'),('psp123'),('psp71835'),('psppsp'),('psyche'),('psycho'),('psycho1'),('psycho13'),('psycho666'),('psycho69'),('psychology'),('psytrance'),('pt120439'),('ptcruiser'),('pthrfkj'),('ptktysq'),('ptybnxtvgbjy'),('public'),('public1'),('publicidad'),('pucca'),('puccini'),('puck'),('puddin'),('puddin1'),('pudding'),('pudding1'),('puddle'),('puddles'),('puddles1'),('puddy1'),('pudge'),('pudge1'),('puebla'),('pueblo'),('puerta'),('puerto'),('puerto1'),('puertorico'),('puff'),('puffdaddy'),('puffer'),('puffetta'),('puffin'),('puffin1'),('puffpuff'),('puffy'),('puffy1'),('puggy1'),('pugsley'),('pugsley1'),('pugsly'),('pujols5'),('pukimak'),('pulamea'),('pulcino'),('pulguita'),('pulpfiction'),('pulsar'),('pulsar1'),('pulsar150'),('pulsar180'),('puma'),('puma12'),('Puma123'),('pumapuma'),('pumas'),('pumas1'),('pumas10'),('pumas12'),('pumas123'),('pumas13'),('pumba1'),('pumbaa'),('pumkin'),('pumkin1'),('pumper'),('pumpk1n'),('pumpkin'),('pumpkin!'),('pumpkin01'),('pumpkin1'),('pumpkin11'),('pumpkin12'),('pumpkin123'),('pumpkin13'),('pumpkin2'),('pumpkin22'),('pumpkin3'),('pumpkin4'),('pumpkin5'),('pumpkin7'),('pumpkin8'),('pumpkin9'),('pumpkinpie'),('pumpkins'),('pumpkins1'),('pumpum'),('punani'),('punch1'),('puneet'),('punisher'),('punisher1'),('punjab'),('punjab1'),('punjabi'),('punjabi1'),('punk'),('punk01'),('punk101'),('punk11'),('punk12'),('punk123'),('punk1234'),('punk13'),('punk14'),('punk4life'),('punk666'),('punk69'),('punk77'),('punkass'),('punkass1'),('punker'),('punker1'),('punkers'),('punkie'),('punkie1'),('punkin'),('punkin1'),('punkista'),('punkpunk'),('punkrock'),('punkrock!'),('punkrock1'),('punkrock10'),('punkrocker'),('punks'),('punksnotdead'),('punky'),('punky1'),('puntacana'),('punto'),('punyeta'),('pup'),('pup123'),('pupetta'),('pupkin'),('pupp!e'),('puppet'),('puppet1'),('puppie'),('puppies'),('puppies!'),('puppies1'),('puppies12'),('puppies123'),('puppies2'),('puppies3'),('puppies4'),('puppies5'),('puppies7'),('puppup'),('puppy'),('puppy!'),('puppy01'),('puppy1'),('puppy10'),('puppy101'),('puppy11'),('puppy12'),('puppy123'),('puppy13'),('puppy2'),('puppy22'),('puppy3'),('puppy4'),('puppy5'),('puppy6'),('puppy7'),('puppy8'),('puppy9'),('puppydog'),('puppydog1'),('puppylove'),('puppylove1'),('puppylove2'),('puppylover'),('puppyluv'),('puppyluv1'),('puppys'),('puppys1'),('pupsik'),('pupuce'),('pur'),('puravida'),('purchase'),('purchasing'),('purdue'),('purdue1'),('purelove'),('purgen'),('purity'),('purity1'),('purnama'),('purnima'),('purpl3'),('purple'),('purple!'),('purple.'),('purple0'),('purple00');
INSERT INTO `easy_passwords` VALUES ('purple01'),('purple02'),('purple03'),('purple04'),('purple05'),('purple06'),('purple07'),('purple08'),('purple09'),('purple1'),('purple10'),('purple101'),('purple11'),('purple12'),('purple123'),('purple1234'),('purple13'),('purple14'),('purple15'),('purple16'),('purple17'),('purple18'),('purple19'),('purple2'),('purple20'),('purple21'),('purple22'),('purple23'),('purple24'),('purple25'),('purple26'),('purple27'),('purple28'),('purple29'),('purple3'),('purple30'),('purple32'),('purple33'),('purple34'),('purple4'),('purple420'),('purple44'),('purple45'),('purple5'),('purple55'),('purple6'),('purple66'),('purple67'),('purple69'),('purple7'),('purple76'),('purple77'),('purple78'),('purple8'),('purple87'),('purple88'),('purple89'),('purple9'),('purple90'),('purple92'),('purple93'),('purple94'),('purple95'),('purple96'),('purple97'),('purple99'),('purplehaze'),('purplelove'),('purplerain'),('purpose'),('purpose1'),('purzel'),('pus'),('puschel'),('pusher'),('pushkin'),('pushok'),('pushpa'),('pusinka'),('puspita'),('puss'),('pussie'),('pussies'),('pusspuss'),('pusspuss1'),('pusssy'),('pussy'),('pussy!'),('pussy.'),('pussy01'),('pussy07'),('pussy08'),('pussy09'),('pussy1'),('pussy10'),('pussy101'),('pussy11'),('pussy12'),('pussy123'),('pussy1234'),('pussy13'),('pussy14'),('pussy15'),('pussy18'),('pussy2'),('pussy21'),('pussy22'),('pussy23'),('pussy24'),('pussy3'),('pussy4'),('pussy420'),('pussy4me'),('pussy5'),('pussy6'),('pussy666'),('pussy69'),('pussy6969'),('pussy7'),('pussy8'),('pussy9'),('pussycat'),('pussycat1'),('pussycat2'),('pussycat69'),('pussyeater'),('pussylicker'),('pussylips'),('pussylover'),('pussyman'),('pussypussy'),('pussys'),('pussys1'),('pussyy'),('puszek'),('puta'),('puta123'),('puta69'),('putain'),('putamadre'),('putamadre1'),('putangina'),('putanginam'),('putanginamo'),('putaputa'),('putas'),('puteri'),('putita'),('puto'),('puto123'),('puto81'),('putra'),('putri'),('puttana'),('putter'),('putter1'),('puttputt'),('puzzle'),('puzzle1'),('puzzola'),('pw123'),('pw1234'),('PW2012yr'),('Pw898klkaG'),('pwd'),('pwd1234'),('pwisdiwhs'),('pwlamea10'),('pwnage'),('pword'),('pwtest'),('px6gcr51'),('pyanzina_elena'),('pyon'),('pypsik'),('pyramid'),('pyramid1'),('pyramide'),('pyramids'),('python'),('python1'),('q'),('q000000'),('Q0tsrBV488'),('q11111'),('q111111'),('q1111111'),('q112233'),('q121212'),('q123123'),('q123321'),('q12345'),('q123456'),('q1234567'),('q12345678'),('q123456789'),('q1234567890'),('q123456q'),('q12345q'),('q1234q'),('q123q123'),('q12we3'),('q12we34r'),('Q18lG49iq8BhU'),('q1a1z1'),('q1a2z3'),('q1q1q1'),('q1q1q1q1'),('q1q1q1q1q1'),('q1q2q3'),('q1q2q3q4'),('q1q2q3q4q5'),('q1w'),('q1w1e1'),('q1w2e3'),('q1w2e3r'),('q1w2e3r4'),('q1w2e3r4t'),('q1w2e3r4t5'),('q1w2e3r4t5y6'),('q1w2e3r4t5y6u7'),('q1w2e3r4t5y6u7i8'),('q1w2e3r4t5y6u7i8o9'),('q1w2e3r4t5y6u7i8o9p0'),('q1w2q1w2'),('q2345678'),('q2q2q2'),('q2w3e4'),('q2w3e4r'),('q2w3e4r5'),('q2w3e4r5t'),('q2w3e4r5t6'),('q3538004'),('q55555'),('q654321'),('q777777'),('q7w8e9'),('q8a74IppxD'),('q963258741q'),('qa27111985qa'),('qamilek1'),('qaqaqa'),('qarglr123'),('qasdfg'),('qaswed'),('qaVcx411'),('qawsed'),('qawsed1'),('qawsed12'),('qawsed123'),('qawsedr'),('qawsedrf'),('qawsedrf1'),('qawsedrftg'),('qawsedrftgyh'),('qaywsx'),('qaywsx123'),('qaywsxedc'),('qayxsw'),('qaz'),('qaz111'),('qaz123'),('qaz123123'),('qaz1234'),('qaz12345'),('qaz123456'),('qaz123456789'),('qaz123qaz'),('qaz123wsx'),('qaz123wsx456'),('qaz12wsx'),('qaz147'),('qaz1wsx2'),('qaz2wsx'),('qaz321'),('qaz4532'),('qaz741'),('qaz789'),('qazedc'),('qazedctgb'),('qazokm'),('qazpl'),('qazplm'),('qazplm1'),('qazplm123'),('qazqaz'),('qazqaz1'),('qazqaz11'),('qazqaz12'),('qazqaz123'),('qazqazqaz'),('qazqwe'),('qazsedc'),('qazw21123'),('qazwer'),('qazws1'),('qazwsx'),('qazwsx!'),('qazwsx1'),('qazwsx11'),('qazwsx12'),('qazwsx123'),('qazwsx1234'),('qazwsx12345'),('qazwsx123456'),('qazwsx13'),('qazwsx2'),('qazwsx23'),('qazwsx3'),('qazwsx321'),('qazwsx7'),('qazwsx741'),('qazwsxe'),('qazwsxed'),('qazwsxed1'),('qazwsxedc'),('qazwsxedc1'),('qazwsxedc12'),('qazwsxedc123'),('qazwsxedc12345'),('qazwsxedc2'),('qazwsxedcr'),('qazwsxedcrfv'),('qazwsxedcrfvtgb'),('qazwsxqazwsx'),('qazxcdews'),('qazxcv'),('qazxcvb'),('qazxcvbnm'),('qazxdr'),('qazxsw'),('qazxsw1'),('qazxsw111'),('qazxsw12'),('qazxsw123'),('qazxsw2'),('qazxsw21'),('qazxswe'),('qazxswed'),('qazxswedc'),('qazxswedc1'),('qazxswedc123'),('qazxswedcvfr'),('qazzaq'),('qazzaq1'),('qazzaq123'),('qdujvyG5sxa'),('QDxzC43gba'),('qdyE17t1zV'),('qeadzc'),('qebEfcz3yx'),('qecEgdA3zx'),('qeqeqe'),('qetuo'),('qfcFgdA3zx'),('qg9543bh7'),('qH6xl1p9xJ'),('qianqian'),('qICiqdP162'),('qingqing'),('qn4KBWv559'),('qNxE66l7or'),('QOXRzwfr'),('qpalzm'),('qpalzm1'),('qpalzm123'),('qpqpqpqp'),('qpwoei'),('qpwoeiru'),('qpwoeiruty'),('qq'),('qq000000'),('qq111111'),('qq112233'),('qq11qq'),('qq123000'),('qq123123'),('qq1234'),('qq12345'),('qq123456'),('qq123456789'),('qq18ww899'),('qq5201314'),('qqaazz'),('qqq'),('qqq111'),('qqq123'),('qqq123456'),('qqq222'),('qqq333'),('qqqaaa'),('qqqaaazzz'),('qqqq'),('qqqq11'),('qqqq1111'),('qqqq1234'),('qqqqq'),('qqqqq1'),('qqqqq11111'),('qqqqqq'),('qqqqqq1'),('qqqqqq11'),('QQQQQQO'),('qqqqqqq'),('qqqqqqq1'),('qqqqqqqq'),('qqqqqqqq1'),('qqqqqqqqq'),('qqqqqqqqq1'),('qqqqqqqqqq'),('qqqqqqqqqqqq'),('qqqqwwww'),('qqqwww'),('qqqwwweee'),('qqww1122'),('qqwwee'),('qqwweerr'),('qqwwqq'),('qscwdv'),('qsdfgh'),('qsdfghjklm'),('qsefth'),('qsefthuko'),('qti7Zxh18U'),('qtpie1'),('quack'),('quack1'),('quackers'),('quadd'),('quadro'),('quagmire'),('quake'),('quake1'),('quake2'),('quake3'),('quake4'),('quaker'),('quality'),('quality1'),('quality123'),('quan12'),('quan123'),('quantum'),('quantum1'),('quaresma'),('quarter'),('quarter1'),('quartz'),('quasar'),('quasimodo'),('quatre'),('quatro'),('quattro'),('que'),('que-veux-tu'),('quebec'),('queen'),('queen01'),('queen1'),('queen10'),('queen11'),('queen12'),('queen123'),('queen13'),('queen14'),('queen2'),('queen23'),('queen3'),('queen4life'),('queen5'),('queen7'),('queenb'),('queenb1'),('queenbee'),('queenbee1'),('queenie'),('queenie1'),('queens'),('queens1'),('queensland'),('queeny'),('queeny1'),('queer1'),('quentin'),('quentin1'),('quepasa'),('quercus'),('querida'),('quest'),('quest1'),('question'),('question1'),('queteimporta'),('quetzal'),('quGRqFo825'),('quick'),('quick1'),('quicksilve'),('quicksilver'),('quidditch'),('quiero'),('quigley'),('quijote'),('quiksilver'),('quilmes'),('quilter'),('quilting'),('quilts'),('quimica'),('quincy'),('quincy1'),('quinn'),('quinn1'),('quintana'),('quinten'),('quintero'),('quintin'),('quintin1'),('quinto'),('quinton'),('quinton1'),('quique'),('quita1'),('quovadis'),('qureshi'),('qvo78evm'),('qw'),('qw10081973'),('qw1212'),('qw123'),('qw123321'),('qw1234'),('qw12345'),('qw123456'),('qw12er34'),('qw12qw'),('qw12qw12'),('qw1qw2'),('qw3rty'),('qwarty'),('qwas'),('qwas12'),('qwas123'),('qwas1234'),('qwaser'),('qwasqwas'),('qwasyx'),('qwaszx'),('qwaszx1'),('qwaszx11'),('qwaszx12'),('qwaszx123'),('qwaszx1234'),('qwaszxedc'),('qwaszxerdfcv'),('qwaszxqw'),('qwaszxqwaszx'),('qwe'),('qwe058058a'),('qwe098'),('qwe111'),('qwe1122334'),('qwe123'),('qwe123!'),('qwe123123'),('qwe123321'),('qwe1234'),('qwe12345'),('qwe123456'),('qwe123456789'),('qwe123asd'),('qwe123qwe'),('qwe123qwe123'),('qwe123rty'),('qwe123rty456'),('qwe123zxc'),('qwe12qwe'),('qwe1asd'),('qwe223'),('qwe321'),('qwe456'),('qwe789'),('qwe987'),('qweasd'),('qweasd1'),('qweasd11'),('qweasd12'),('qweasd123'),('qweasdqwe'),('qweasdqweasd'),('qweasdyxc'),('qweasdzx'),('qweasdzxc'),('qweasdzxc1'),('qweasdzxc12'),('qweasdzxc123'),('qweasz'),('qwedcxz'),('qwedcxza'),('qwedcxzas'),('qwedsa'),('qwedsa123'),('qwedsazxc'),('qweewq'),('qweewq1'),('qweewq123'),('qwegta13091990'),('qweiop'),('qwepoi'),('qwepoiasdlkj'),('qweqaz'),('qweqwe'),('qweqwe1'),('qweqwe11'),('qweqwe12'),('qweqwe123'),('qweqwe123123'),('qweqweqwe'),('qweqweqwe1'),('qwer'),('qwer0987'),('qwer11'),('qwer12'),('qwer123'),('qwer1234'),('qwer12345'),('qwer123456'),('qwer13'),('qwer4321'),('qwer56'),('qwer5678'),('qwer789'),('qweras'),('qwerasd'),('qwerasdf'),('qwerasdf1'),('qwerasdf1234'),('qwerasdfzxcv'),('qwerewq'),('qwerfdsa'),('qwerfv'),('qwerpoiu'),('qwerqwer'),('qwerqwer1'),('qwerqwer2'),('qwerrewq'),('qwert'),('qwert!'),('qwert.0002'),('qwert1'),('qwert11'),('qwert12'),('qwert123'),('qwert1234'),('qwert12345'),('qwert123456'),('qwert2'),('qwert5'),('qwert54321'),('qwert55'),('qwert6'),('qwert67'),('qwert7'),('qwert789'),('qwerta'),('qwertasd'),('qwertasdf'),('qwertasdfg'),('qwertasdfgzxcvb'),('qwertgfdsa'),('qwertqwert'),('qwerttrewq'),('qwerty'),('qwerty!'),('qwerty.'),('qwerty0'),('qwerty00'),('qwerty000'),('qwerty007'),('qwerty01'),('qwerty02'),('qwerty06'),('qwerty07'),('qwerty08'),('qwerty09'),('qwerty098'),('qwerty0987'),('qwerty1'),('qwerty1!'),('qwerty10'),('qwerty100'),('qwerty101'),('qwerty11'),('qwerty111'),('qwerty112233'),('qwerty12'),('qwerty121'),('qwerty123'),('qwerty1231'),('qwerty123321'),('qwerty1234'),('qwerty12345'),('qwerty123456'),('qwerty1234567'),('qwerty12345678'),('qwerty123456789'),('qwerty1234567890'),('qwerty13'),('qwerty14'),('qwerty15'),('qwerty1517'),('qwerty16'),('qwerty17'),('qwerty18'),('qwerty19'),('qwerty1981'),('qwerty1985'),('qwerty1986'),('qwerty1987'),('qwerty1988'),('qwerty1989'),('qwerty1990'),('qwerty1991'),('qwerty1992'),('qwerty1993'),('qwerty1994'),('qwerty1995'),('qwerty2'),('qwerty20'),('qwerty2009'),('qwerty2010'),('qwerty2011'),('qwerty2012'),('qwerty21'),('qwerty22'),('qwerty23'),('qwerty24'),('qwerty25'),('qwerty26'),('qwerty27'),('qwerty28'),('qwerty3'),('qwerty30'),('qwerty31'),('qwerty32'),('qwerty321'),('qwerty33'),('qwerty333'),('qwerty34'),('qwerty4'),('qwerty4321'),('qwerty44'),('qwerty45'),('qwerty456'),('qwerty5'),('qwerty54321'),('qwerty55'),('qwerty555'),('qwerty56'),('qwerty6'),('qwerty65'),('qwerty654321'),('qwerty66'),('qwerty666'),('qwerty67'),('qwerty69'),('qwerty7'),('qwerty76'),('qwerty765'),('qwerty77'),('qwerty777'),('qwerty777888'),('qwerty78'),('qwerty789'),('qwerty7890'),('qwerty79'),('qwerty8'),('qwerty80'),('qwerty82'),('qwerty83'),('qwerty84'),('qwerty85'),('qwerty86'),('qwerty87'),('qwerty88'),('qwerty888'),('qwerty89'),('qwerty9'),('qwerty90'),('qwerty91'),('qwerty911'),('qwerty92'),('qwerty93'),('qwerty94'),('qwerty95'),('qwerty96'),('qwerty97'),('qwerty98'),('qwerty987'),('qwerty99'),('qwerty999'),('qwertya'),('qwertyas'),('qwertyasd'),('qwertyasdf'),('qwertyasdfg'),('qwertyasdfgh'),('qwertykolakola'),('qwertyq'),('qwertyqaz'),('qwertyqwerty'),('qwertys'),('qwertytrewq'),('qwertyu'),('qwertyu1'),('qwertyu12'),('qwertyu123'),('qwertyu7'),('qwertyu8'),('qwertyui'),('qwertyui1'),('qwertyui12'),('qwertyui2p'),('qwertyui9'),('qwertyuio'),('qwertyuio0'),('qwertyuio1'),('qwertyuio9'),('qwertyuiop'),('qwertyuiop0'),('qwertyuiop1'),('qwertyuiop12'),('qwertyuiop123'),('qwertyuiop1234'),('qwertyuiop12345'),('qwertyuiop123456'),('qwertyuiop123456789'),('qwertyuiop1234567890'),('qwertyuiop789'),('qwertyuiopasdfg'),('qwertyuiopasdfghjkl'),('qwertyuiopasdfghjkl151515'),('qwertyuiopasdfghjklzxcvbnm'),('qwertyuiop[]'),('qwertyy'),('qwertyytrewq'),('qwertyz'),('qwertz'),('qwertz1'),('qwertz12'),('qwertz123'),('qwertz1234'),('qwertzu'),('qwertzu1'),('qwertzui'),('qwertzuiop'),('qwerzxcv'),('qwest123'),('qweszxc'),('qwewq'),('qwezxc'),('qwezxc123'),('qwezxcasd'),('qwqw'),('qwqw12'),('qwqw1212'),('qwqwqw'),('qwqwqw1'),('qwqwqw12'),('qwqwqwqw'),('qwqwqwqwqw'),('qwsazx'),('qwsxza'),('qwsxzas'),('qxVbGfiBuq'),('QxXM93Js'),('Qy5tOgR996'),('qyahzn'),('qzwxec'),('qzwxecrv'),('r'),('r.polinin'),('r00ster'),('r00tb33r'),('r00tbeer'),('r041stcu'),('r0b3rt'),('r0bert'),('r0ckstar'),('r11111'),('r111111'),('r123098'),('r12345'),('r123456'),('r1234567'),('r12345678'),('r123456789'),('r1cd38d'),('r1chard'),('r1r2r3'),('r1r2r3r4'),('r26nnxJx7N'),('r2d2'),('r2d2c3p0'),('r2d2c3po'),('r2d2r2d2'),('r3m3mb3r'),('r4e3w2q1'),('r4evc8d8VS'),('R5GNqyRr'),('r654321'),('r6a50de3ujwtog4'),('r9e8w7q6'),('R9lw4j8khX'),('ra1234'),('ra1ders'),('ra66it'),('rabat1945'),('rabbit'),('rabbit01'),('rabbit1'),('rabbit11'),('rabbit12'),('rabbit123'),('rabbit13'),('rabbit2'),('rabbit3'),('rabbit5'),('rabbit69'),('rabbit7'),('rabbits'),('rabbits1'),('rabota'),('rac'),('raccoon'),('raccoon1'),('race'),('racecar'),('racecar1'),('racecar2'),('racecars'),('racer'),('racer1'),('racers'),('racerx'),('rach123'),('rach86'),('rachael'),('rachael1'),('rachana'),('racheal'),('racheal1'),('rachel'),('rachel!'),('rachel.'),('rachel01'),('rachel07'),('rachel08'),('rachel09'),('rachel1'),('rachel10'),('rachel11'),('rachel12'),('rachel123'),('rachel13'),('rachel14'),('rachel15'),('rachel16'),('rachel17'),('rachel18'),('rachel2'),('rachel21'),('rachel22'),('rachel23'),('rachel24'),('rachel3'),('rachel4'),('rachel5'),('rachel6'),('rachel69'),('rachel7'),('rachel8'),('rachel88'),('rachel9'),('rachel99'),('rachele'),('rachell'),('rachelle'),('rachelle1'),('rachelle289ariyoshi5251987'),('rachid'),('rachida'),('rachna'),('racine'),('racing'),('racing1'),('racoon'),('racquel'),('rad'),('rad123'),('radar'),('radar1'),('radcliffe'),('radek'),('radek1'),('radeon'),('radford'),('radha'),('radhakrishna'),('radharani'),('radhasoami'),('radhaswami'),('radhekrishna'),('radheradhe'),('radhika'),('radiance'),('radiant'),('radiation'),('radiator'),('radical'),('radical1'),('radik070775'),('radio'),('radio1'),('radio123'),('radiohead'),('radiohead1'),('radiology'),('radion-dankov'),('radios'),('radish'),('radius'),('radmila'),('radmila5'),('radmir'),('radost'),('raducu'),('raduga'),('raduga2508'),('raduga388'),('rae123'),('raerae'),('raerae1'),('raf'),('rafa'),('rafa123'),('rafael'),('rafael01'),('rafael1'),('rafael10'),('rafael12'),('rafael123'),('rafael13'),('rafael2'),('rafaela'),('rafaella'),('rafal'),('rafal1'),('rafale'),('raffaele'),('raffaella'),('raffaello'),('rafferty'),('raffles'),('raffy'),('rafiki'),('rafinha'),('rafita'),('rafter'),('ragdoll'),('ragdoll1'),('rage'),('raghav'),('raghavendra'),('ragini'),('ragnar'),('ragnarok'),('ragnarok1'),('rahasia'),('rahasia1'),('rahasia123'),('rahayu'),('raheem'),('raheem1'),('rahima'),('rahman'),('rahmat'),('rahmudinov92'),('rahrah'),('rahrah1'),('rahul'),('rahul1'),('rahul123'),('rai'),('rai-131'),('raiden'),('raiden1'),('raider'),('raider1'),('raider11'),('raider12'),('raider13'),('raider2'),('raiders'),('raiders!'),('raiders#1'),('raiders01'),('raiders07'),('raiders08'),('raiders09'),('raiders1'),('raiders10'),('raiders11'),('raiders12'),('raiders123'),('raiders13'),('raiders14'),('raiders15'),('raiders18'),('raiders2'),('raiders20'),('raiders21'),('raiders22'),('raiders23'),('raiders24'),('raiders3'),('raiders34'),('raiders4'),('raiders5'),('raiders6'),('raiders69'),('raiders7'),('raiders8'),('raiders81'),('raiders9'),('raiders99'),('raiderz1'),('raif.21'),('raihan'),('raikkonen'),('railroad'),('railroad1'),('railway'),('raimundo'),('rain'),('rain12'),('rain123'),('rainb0w'),('rainbow'),('rainbow!'),('rainbow.'),('rainbow01'),('rainbow08'),('rainbow1'),('rainbow10'),('rainbow11'),('rainbow12'),('rainbow123'),('rainbow13'),('rainbow14'),('rainbow15'),('rainbow16'),('rainbow2'),('rainbow21'),('rainbow22'),('rainbow23'),('rainbow24'),('rainbow3'),('rainbow4'),('rainbow5'),('rainbow6'),('rainbow69'),('rainbow7'),('rainbow8'),('rainbow9'),('rainbows'),('rainbows1'),('raindrop'),('raindrop1'),('raindrops'),('raine'),('rainer'),('rainey'),('rainfall'),('rainforest'),('rainier'),('raining'),('rainmaker'),('rainman'),('rainman1'),('rainrain'),('rainyday'),('raisa'),('raisa720290'),('raisa_smelkova'),('raisin'),('raissa'),('raistlin'),('raistlin1'),('raj'),('raj123'),('raj12345'),('raja'),('raja123'),('raja1234'),('rajababu'),('rajan'),('rajani'),('rajaraja'),('rajaram'),('rajarani'),('rajasthan'),('rajawali'),('rajeev'),('rajendra'),('rajesh'),('rajesh123'),('rajeshwari'),('rajeswari'),('rajinder'),('rajini'),('rajkumar'),('rajneesh'),('rajput'),('rajraj'),('raju'),('raju123'),('rakaii'),('rakesh'),('rakesh123'),('raketa'),('rakista'),('rakizta'),('rakker'),('raksha'),('raleigh'),('raleigh1'),('rally'),('rallye'),('ralph'),('ralph1'),('ralph123'),('ralphc8xf'),('ralphie'),('ralphie1'),('ralphy'),('ralphy1'),('raluca'),('ram'),('ram123'),('ram1500'),('ram2500'),('rama'),('ramada'),('ramadan'),('ramadevi'),('ramadhan'),('ramakrishna'),('raman'),('ramana'),('ramani'),('ramarama'),('ramayana'),('ramazan'),('rambler'),('rambler1'),('rambo'),('rambo1'),('rambo12'),('rambo123'),('rambo2'),('rambo3'),('ramboo'),('rambutan'),('ramchandra'),('ramesh'),('ramesh123'),('ramil'),('ramirez'),('ramirez1'),('ramiro'),('ramiro1'),('ramis_bairamov'),('ramjet'),('ramkumar'),('rammstein'),('rammstein1'),('rammstein6'),('ramon'),('ramon1'),('ramon123'),('ramona'),('ramona1'),('ramone'),('ramone1'),('ramones'),('ramones1'),('ramos'),('ramos1'),('rampage'),('rampage1'),('ramram'),('ramramram'),('ramrod'),('ramrod1'),('rams'),('rams28'),('ramsay'),('ramses'),('ramses1'),('ramses2'),('ramsey'),('ramsey1'),('ramsia1986'),('ramstein'),('ramzan'),('ramzes'),('ran'),('rana'),('rana123'),('ranch1'),('rancher'),('ranchero'),('rancho'),('rancho1'),('rancid'),('rancid1'),('RAND'),('rand0m'),('randal'),('randall'),('randall1'),('randi'),('randi1'),('randolph'),('randolph1'),('random'),('random!'),('random1'),('random11'),('random12'),('random123'),('random13'),('random2'),('randomness'),('randy'),('randy1'),('randy12'),('randy123'),('randy2'),('randymoss1'),('randyorton'),('ranetka'),('ranetki'),('rangel'),('ranger'),('ranger00'),('ranger01'),('ranger1'),('ranger10'),('ranger11'),('ranger12'),('ranger123'),('ranger13'),('ranger2'),('ranger21'),('ranger22'),('ranger23'),('ranger3'),('ranger5'),('ranger6'),('ranger69'),('ranger7'),('ranger75'),('ranger88'),('ranger99'),('rangerover'),('rangers'),('rangers01'),('rangers1'),('rangers10'),('rangers11'),('rangers12'),('rangers123'),('rangers1690'),('rangers1873'),('rangers2'),('rangers7'),('rangers9'),('rangers94'),('rangersfc'),('rangersfc1'),('rangga'),('rani'),('ranita'),('ranjan'),('ranjana'),('ranjit'),('ranjith'),('rankin'),('ranking21'),('ranma'),('ranma1'),('ranma12'),('ranran'),('ransom'),('ransom1'),('rantanplan'),('raoUjFL963'),('rap'),('rap123'),('rap4life'),('rapala'),('raphael'),('raphael1'),('rapid'),('rapid123'),('rapido'),('rapper'),('rapper1'),('raprap'),('rapstar1'),('raptor'),('raptor1'),('raptor22'),('raptor350'),('raptor660'),('raptor700'),('raptors'),('raptors1'),('rapture'),('rapture1'),('rapunzel'),('raqdc4ml'),('raquel'),('raquel1'),('rarara'),('ras'),('ras123'),('rasberry'),('rascal'),('rascal01'),('rascal1'),('rascal11'),('rascal12'),('rascal123'),('rascal13'),('rascal2'),('rasengan'),('rasengan1'),('rashad'),('rashad1'),('rashaun966krager1993'),('rashawn1'),('rasheed'),('rasheed1'),('rashid'),('rashida'),('rashmi'),('raskevichtanja'),('rasmus'),('rasmus1'),('raspberry'),('raspberry1'),('rasputin'),('rasputin1'),('rassvet'),('rasta'),('rasta1'),('rasta123'),('rasta420'),('rastafari'),('rastafari1'),('rastaman'),('rastaman1'),('rastas'),('raster'),('rastus'),('rat'),('rat123'),('ratashn67'),('ratata'),('ratatouille'),('ratbag'),('ratboy'),('ratchet'),('ratchet1'),('ratdog'),('ratfink'),('ratman'),('ratona'),('ratrat'),('rats'),('rats12'),('ratten'),('rattle'),('rattler'),('rattlesnake'),('raul'),('raul12'),('raul123'),('raulito'),('Raumschiff'),('rauzawcsiv'),('raven'),('raven01'),('raven1'),('raven11'),('raven12'),('raven123'),('raven13'),('raven2'),('raven3'),('raven5'),('raven6'),('raven666'),('raven69'),('raven7'),('ravenclaw'),('ravenna'),('ravens'),('ravens1'),('ravens52'),('raver1'),('ravi'),('ravi123'),('ravi1234'),('ravich92'),('ravikumar'),('ravinder'),('ravindra'),('ravioli'),('ravipass'),('ravshan'),('ravshan1017'),('raw123'),('rawalpindi'),('rawhide'),('rawiswar'),('rawr'),('rawr11'),('rawr12'),('rawr123'),('rawr1234'),('rawr13'),('rawrrawr'),('ray'),('ray-ray'),('ray123'),('ray1234'),('ray619'),('rayados'),('rayallen'),('rayallen20'),('rayan'),('rayane'),('rayban'),('rayden'),('rayhan'),('raylewis52'),('rayman'),('rayman1'),('raymart'),('raymon'),('raymond'),('raymond1'),('raymond12'),('raymond123'),('raymond2'),('raymond3'),('raymond5'),('raymond7'),('raymonde'),('raymonde336schwegel7331987'),('raymund'),('raymundo'),('rayne1'),('rayquaza'),('rayray'),('rayray1'),('rayray11'),('rayray12'),('rayray123'),('rayray13'),('rayray14'),('rayray2'),('rayray23'),('rayray3'),('rayray7'),('rayyan'),('razdvatri3'),('raziel'),('razjel1'),('razor'),('razor1'),('razor123'),('razorback'),('razorback1'),('razorbacks'),('razorblade'),('razors'),('razvan'),('razvod'),('razzle'),('rb26dett'),('rbcekz'),('rbceyz'),('rbd123'),('rbh.if'),('rbhbkk'),('rbhgbx'),('rbOTmvZ954'),('rbrbvjhf'),('rbtsozeva'),('rc.'),('rc.irf'),('rc.itymrf'),('rc95kzbJ1V'),('rcalgif86'),('rclens'),('rctybz'),('rdfhnbhf'),('rdfhnbhfyy'),('rdfhnfk'),('rdfhnfk1'),('rdfpbvjlj'),('rdukv46x'),('RDxyD43hca'),('re'),('re-enter'),('rea'),('reaction'),('read'),('reader'),('reader1'),('reading'),('reading1'),('readme'),('ready'),('ready1'),('ready123'),('ready2go'),('reagan'),('reagan1'),('real'),('real12'),('real123'),('realbetis'),('realdeal'),('realdeal1'),('realest1'),('realestate'),('realist1'),('reality'),('reality1'),('reallife'),('reallove'),('reallove1'),('really'),('really1'),('realmadrid'),('realmadrid1'),('realmadrid7'),('realman'),('realnigga'),('realnigga1'),('realsim07'),('realtalk1'),('realtek.'),('realtime'),('realtor'),('realtor1'),('realtors'),('realty'),('reanimator'),('reanna'),('reaper'),('reaper1'),('reaper12'),('reaper123'),('reaper13'),('reaper2'),('reaper666'),('reaper69'),('reason'),('reason1'),('reaver'),('reb'),('rebeca'),('rebeca1'),('rebecca'),('rebecca!'),('rebecca01'),('rebecca1'),('rebecca10'),('rebecca11'),('rebecca12'),('rebecca123'),('rebecca13'),('rebecca2'),('rebecca3'),('rebecca4'),('rebecca5'),('rebecca7'),('rebeka'),('rebekah'),('rebekah1'),('rebekka'),('rebel'),('rebel01'),('rebel1'),('rebel10'),('rebel12'),('rebel123'),('rebel13'),('rebel2'),('rebel3'),('rebel4life'),('rebel69'),('rebel9'),('rebelde'),('rebelde1'),('rebelde10'),('rebelde12'),('rebelde123'),('rebelde2'),('rebelde3'),('rebelde6'),('rebell'),('rebelle'),('rebellion'),('rebels'),('rebels1'),('rebenok'),('rebirth'),('rebirth1'),('reboot'),('reborn'),('reborn1'),('rebound'),('rebound1'),('rebus13'),('recall'),('reception'),('recherche'),('recife'),('recipe'),('recipes'),('reckless'),('reckless1'),('recoba'),('recon'),('recon1'),('record'),('record1'),('record10'),('records'),('records1'),('recovery'),('recovery1'),('recruit'),('recruiter'),('recruiter1'),('recruitment'),('recycle'),('recycle1'),('red'),('red007'),('red100'),('red101'),('red111'),('red123'),('red1234'),('red12345'),('red123456'),('red222'),('red234'),('red321'),('red333'),('red456'),('red555'),('red666'),('red777'),('red789'),('red911'),('Redab1993'),('redalert'),('redalert1'),('redalert2'),('redapple'),('redapple1'),('redarmy'),('redbaron'),('redbird'),('redbird1'),('redbirds'),('redblack'),('redblood'),('redblue'),('redblue1'),('redbone'),('redbone1'),('redboy'),('redboy1'),('redbul'),('redbull'),('redbull1'),('redbull12'),('redbull123'),('redbull2'),('redcar'),('redcar1'),('redcat'),('redcross'),('redd'),('redder'),('reddevil'),('reddevil1'),('reddevils'),('reddog'),('reddog1'),('reddog12'),('reddog123'),('reddragon'),('reddragon1'),('reddwarf'),('reddwarf1'),('reddy'),('reddy123'),('redeemed'),('redeemed1'),('redeemer'),('redemption'),('redeye'),('redeye1'),('redeyes'),('redfire'),('redfish'),('redfish1'),('redford'),('redfox'),('redfox1'),('redfred'),('redfred1'),('redgreen'),('redhat'),('redhawk'),('redhead'),('redhead1'),('redhead2'),('redheads'),('redhorse'),('redhot'),('redhot1'),('redhouse'),('redick4'),('rediff'),('rediffmail'),('rediska'),('redko5'),('redlight'),('redlight1'),('redline'),('redline1'),('redlion'),('redman'),('redman1'),('redman123'),('redman2'),('redmond'),('redmoon'),('rednaxela'),('redneck'),('redneck!'),('redneck01'),('redneck08'),('redneck09'),('redneck1'),('redneck101'),('redneck11'),('redneck12'),('redneck123'),('redneck13'),('redneck16'),('redneck2'),('redneck21'),('redneck3'),('redneck5'),('redneck69'),('redneck7'),('rednose'),('redondo'),('redone'),('redouane'),('redred'),('redred1'),('redred12'),('redred123'),('redred2'),('redredred'),('redrider'),('redriver'),('redrobin'),('redrock'),('redrock1'),('redrose'),('redrose1'),('redroses'),('redroses1'),('redrover'),('redrover1'),('redrum'),('redrum1'),('redrum187'),('redrum666'),('reds'),('redsea'),('redshoes'),('redskin'),('redskin1'),('redskins'),('redskins1'),('redskins12'),('redskins2'),('redskins21'),('redskins26'),('redskins89'),('redsky'),('redsox'),('redsox!'),('redsox01'),('redsox04'),('redsox05'),('redsox07'),('redsox08'),('redsox09'),('redsox1'),('redsox10'),('redsox11'),('redsox12'),('redsox123'),('redsox13'),('redsox14'),('redsox15'),('redsox18'),('redsox2'),('redsox2004'),('redsox21'),('redsox22'),('redsox23'),('redsox24'),('redsox3'),('redsox33'),('redsox34'),('redsox4'),('redsox5'),('redsox7'),('redsox8'),('redsox9'),('redsoxs1'),('redstar'),('redstar1'),('redstone'),('redstorm'),('redsun'),('redtruck'),('redtruck1'),('redtube'),('redwall'),('redwall1'),('redwarbike'),('redwin3d'),('redwine'),('redwine1'),('redwing'),('redwing1'),('redwings'),('redwings1'),('redwings19'),('redwolf'),('redwood'),('redwood1'),('redzone'),('redzone1'),('reebok'),('reebok1'),('reece'),('reece1'),('reece123'),('reed'),('reefer'),('reefer1'),('reefer420'),('reena'),('reeree'),('reeree1'),('reese'),('reese1'),('reese123'),('reeses'),('reeses1'),('reeves'),('referee'),('referee1'),('reference'),('refillmotives'),('refinnej'),('reflection'),('reflex'),('refresh'),('refresh1'),('reg'),('regal1'),('regan'),('regan1'),('regawf7ss1dm7rn'),('regenbogen'),('regenboog'),('regency'),('regent'),('reggae'),('reggae1'),('reggaeton'),('reggaeton1'),('reggie'),('reggie01'),('reggie1'),('reggie11'),('reggie12'),('reggie123'),('reggie2'),('reggie25'),('reggie31'),('reggie5'),('reggina'),('regiment'),('regina'),('regina-rebina'),('regina1'),('regina12'),('regina123'),('reginald'),('reginald1'),('regine'),('reginka2393'),('region'),('regional'),('regis'),('register'),('register1'),('registrati'),('registration'),('reglisse'),('regret'),('regulator'),('rehana'),('rehbwf'),('rehjxrf'),('rehman'),('reilly'),('reilly1'),('reina'),('reina1'),('reinaldo'),('reindeer'),('reiner'),('reinhard'),('reject'),('reject1'),('rejoice'),('rekbrjdf'),('rekha'),('reklama'),('relation'),('relationship'),('relax'),('relax1'),('release'),('relentless'),('reliable'),('reliance'),('relientk'),('relientk1'),('religion'),('relisys'),('rellik'),('reload'),('reload1'),('reloaded'),('rem'),('remark'),('rembrandt'),('remedios'),('remedy'),('remember'),('remember!'),('remember1'),('remember12'),('remember2'),('remember7'),('rememberme'),('remi'),('remilekun'),('reminder'),('remington'),('remington1'),('remix1'),('remo1d72a'),('remont'),('remote'),('remote1'),('rempit46'),('remrem'),('remy'),('ren'),('rena.vano1990'),('renae1'),('renaissance'),('renaldo'),('renan123'),('renard'),('renata'),('renata1'),('renate'),('renato'),('renato1'),('renaud'),('renault'),('renault1'),('renault19'),('renault5'),('rencontre'),('rencontres'),('rendakova_sveta'),('render'),('rendezvous'),('rene'),('rene12'),('rene123'),('renee'),('renee01'),('renee08'),('renee09'),('renee1'),('renee11'),('renee12'),('renee123'),('renee13'),('renee14'),('renee15'),('renee16'),('renee2'),('renee21'),('renee22'),('renee23'),('renee3'),('renee5'),('renee7'),('renegade'),('renegade1'),('renesmee'),('renesmeecallen'),('renkanom'),('rennes'),('rennie'),('reno'),('reno911'),('renoir'),('renren'),('renren15'),('rent'),('rental'),('renton'),('renuka'),('renzo'),('reo'),('repair'),('repbyf'),('repeat'),('repent'),('replay'),('repmvbyf'),('repmvf'),('report'),('reporter'),('repsol'),('reptile'),('reptile1'),('reptiles'),('republic'),('republic1'),('republica'),('repytwjd'),('repytwjdf'),('repytxbr'),('requiem'),('requiem1'),('requin'),('rer-tuy'),('rere'),('rere12'),('rere123'),('rerecz'),('rerehepf'),('rereirf'),('rerere'),('rererere'),('rerfhfxf'),('rerfhtre'),('rerghr'),('rerjkrf'),('res'),('rescue'),('rescue1'),('research'),('research1'),('reseau'),('reserve'),('reserved'),('reset'),('reset1'),('reset123'),('reset12345'),('resetme'),('reshma'),('resident'),('resident1'),('resident4'),('residentev'),('residentevil'),('residentevil4'),('resing1965'),('resist'),('resistance'),('resistant50m'),('resource'),('respect'),('respect1'),('respekt'),('response'),('restart'),('restart1'),('restaurant'),('restinpeace'),('restless'),('restore'),('resume'),('retail'),('retamozo'),('retard'),('retard!'),('retard1'),('retard12'),('retard123'),('retard2'),('retarded'),('retarded1'),('retina'),('retire'),('retired'),('retired1'),('retirement'),('retlaw'),('retraite'),('retriever'),('retro'),('retro1'),('retsam'),('return'),('retype'),('reuben'),('reuben1'),('reunion'),('reunion1'),('reunion974'),('reussite'),('revathi'),('revathy'),('reveal'),('revelation'),('revenge'),('revenge!'),('revenge1'),('revenge2'),('reverend'),('reverse'),('reveur'),('review'),('revilo'),('revival'),('revolt'),('revolucion'),('revolution'),('revolver'),('revolver1'),('reward'),('rewind'),('rewq1234'),('rewq4321'),('rex'),('rex123'),('rexocinod'),('rexona'),('rexrex'),('rey'),('rey123'),('rey619'),('reyes'),('reyes1'),('reyes123'),('reyes7'),('reyhan'),('reymark'),('reymisteri'),('reymisterio'),('reymond'),('reymysteri'),('reymysterio'),('reyna'),('reyna1'),('reynald'),('reynaldo'),('reynaldo1'),('reynold'),('reynolds'),('reynolds1'),('reyrey'),('reyrey1'),('reyrey619'),('reyrtutyd'),('rezeda'),('reznor'),('rezo_2010'),('rezvanov_a'),('rf'),('rf:'),('rfcgth'),('rfczgecz11'),('rfgbnfy'),('rfgbnjirf'),('rfgecnf'),('rfghbp'),('rfgtkmrf'),('rfhbyf'),('rfhbyjxrf'),('rfhbyrf'),('rfhectkm'),('rfhfcm'),('rfhfgep'),('rfhfrfnbwf'),('rfhfufylf'),('rfhfvtkm'),('rfhfvtkmrf'),('rfhfylfi'),('rfhjkbyf'),('rfhlbyfk'),('rfhnbyf'),('rfhnjirf'),('rfkbybyf'),('rfkbyf'),('rfkmrekznjh'),('rfktylfhm'),('rfn'),('rfn.'),('rfn.if'),('rfn.irf'),('rfnfcnhjaf'),('rfnhby'),('rfnmrf'),('rfnthbyf'),('rfnthbyrf'),('rfntyjr'),('rfntymrf'),('rfnz'),('rfnz123'),('rfnzrfnz'),('rfpfyjdf'),('rfpfym'),('rfpfynbg'),('rfpzdrf'),('rfrfirf'),('rfrfirf1'),('rfrfitxrf'),('rfrfrf'),('rfrltkf'),('rfrnec'),('rfvbkf'),('rfvbkkf'),('rfvbrflpt'),('rfvfcenhf'),('rfvtgb'),('rfvtgbyhn'),('rfvtym'),('rfvxfnrf'),('rfybreks'),('rhapsody'),('rhbcnb'),('rhbcnbyf'),('rhbcnbyjxrf'),('rhbcnbyrf'),('rhbcnz'),('rhenjq'),('rhfcbdfz'),('rhfcfdbwf'),('rhfcfdxbr'),('rhfcjnf'),('rhfcjnrf'),('rhfcyjlfh'),('rhfcyjzhcr'),('rhfcysq'),('rhfdxtyrj'),('rhianna'),('rhianna1'),('rhiannon'),('rhiannon1'),('rhino'),('rhino1'),('rhino123'),('rhinos'),('Rhinos111'),('rhjirf'),('rhjkbr'),('rhjrjlbk'),('rhodan01'),('rhodes'),('rhodes1'),('rhonda'),('rhonda1'),('rhtdtlrj'),('rhtfnbd'),('rhubarb'),('rhythm'),('rhyzza'),('rianna'),('rianne'),('ribbit'),('ribbon'),('ribeiro'),('ribena'),('ribery'),('ribka227555'),('ric'),('ric123'),('rican1'),('ricard'),('ricardito'),('ricardo'),('ricardo07'),('ricardo1'),('ricardo10'),('ricardo12'),('ricardo123'),('ricardo13'),('ricardo2'),('ricardo22'),('ricardo7'),('riccardo'),('riccardo1'),('riccio'),('rice'),('rice80'),('rich'),('rich12'),('rich123'),('rich1234'),('richa'),('richard'),('richard!'),('richard.'),('richard01'),('richard07'),('richard08'),('richard1'),('richard10'),('richard11'),('richard12'),('richard123'),('richard13'),('richard14'),('richard15'),('richard18'),('richard2'),('richard21'),('richard22'),('richard23'),('richard3'),('richard4'),('richard5'),('richard6'),('richard69'),('richard7'),('richard8'),('richard9'),('richards'),('richards1'),('richardson'),('richbitch1'),('richboy'),('richboy1'),('richelle'),('richelle1'),('riches'),('richgirl'),('richie'),('richie1'),('richie123'),('richierich'),('richman'),('richman1'),('richmond'),('richmond1'),('richter'),('richy1'),('rick'),('rick12'),('rick123'),('rickey'),('rickey1'),('rickie'),('rickjames'),('rickjames1'),('rickross'),('rickross1'),('ricky'),('ricky01'),('ricky1'),('ricky10'),('ricky11'),('ricky12'),('ricky123'),('ricky13'),('ricky2'),('ricky23'),('ricky3'),('ricky4'),('ricky5'),('ricky7'),('rico'),('rico12'),('rico123'),('ricochet'),('ricola'),('ricorico'),('riddhi'),('riddick'),('riddick1'),('riddle'),('riddler'),('ride'),('ride4life'),('ridebmx'),('ridebmx1'),('rideordie'),('rideordie1'),('rider'),('rider1'),('riders'),('riders1'),('riding'),('ridley'),('ridwan'),('riffraff'),('rigger'),('right'),('right1'),('righteous'),('righteous1'),('rightnow'),('righton'),('righton1'),('rigoberto'),('rihana'),('rihanna'),('rihanna1'),('rikardo'),('rikimaru'),('rikki1'),('riley'),('riley01'),('riley06'),('riley07'),('riley08'),('riley1'),('riley11'),('riley12'),('riley123'),('riley13'),('riley2'),('riley3'),('riley5'),('riley7'),('rileydog'),('rimbaud'),('rimini'),('rimmer'),('rina'),('rinat'),('rinat-88'),('rinat.76'),('rincewind'),('rincon'),('ring'),('ringer'),('ringer1'),('ringhio'),('ringo'),('ringo1'),('ringo123'),('ringostar'),('ringring'),('rinoceronte'),('rinrin'),('rintintin'),('rio123'),('rio7777'),('riodejaneiro'),('riogrande'),('riorio'),('rip123'),('rip2pac'),('ripazha'),('ripcurl'),('ripcurl1'),('ripdad1'),('ripken'),('ripken8'),('ripley'),('ripley1'),('ripped'),('ripper'),('ripper1'),('ripper6'),('ripple'),('riptide'),('riquelme'),('risc'),('rishabh'),('rishi'),('rising'),('risingsun'),('rissa1'),('rita'),('rita123'),('rita497'),('ritarita'),('rita_nizhnik_r'),('ritchie'),('ritchie1'),('ritesh'),('ritika'),('ritinha'),('ritter'),('rivaldo'),('rivendell'),('river'),('river1'),('river123'),('rivera'),('rivera1'),('riverdale'),('riverplate'),('riverrat'),('riverrat1'),('rivers'),('rivers1'),('riverside'),('riverside1'),('RiversideC'),('riverview'),('riviera'),('riwr2hky4w3tjgg'),('riyadh'),('rizal'),('rizwan'),('rj'),('rj1234'),('rjcnbr'),('rjcnzy'),('rjcvjc'),('rjdfkmxer'),('rjdfktyrj'),('RJGo7We138'),('rjgtqrf'),('rjhjdf'),('rjhjdf777'),('rjhjkm'),('rjhjkmbien'),('rjhjktdf'),('rjhjnrb1'),('rjhjyf'),('rjitxrf'),('rjktcj'),('rjnjgtc'),('rjntyjr'),('rjntyjxtr'),('rjnzhf'),('rjnzif'),('rjn`yjr'),('rjpkjdf'),('rjpthju'),('rjpzdrf'),('rjrfrjkf'),('rjvgm.nth'),('rjyatnf'),('rjyatnrf'),('rjycnbnewbz'),('rjycnfynby'),('rjyjgkz'),('rjynfrn'),('rkamkin.karoli1988mp'),('rke:'),('rkelly'),('rkfdbfnehf'),('rko123'),('rksk3210'),('rktjgfnhf'),('rmz250'),('roach'),('roach1'),('roadkill'),('roadkill1'),('roadking'),('roadking1'),('roadrunner'),('roadstar'),('roadster'),('roadtrip'),('roanne'),('Roanne42300'),('roar'),('rob'),('rob123'),('robaczek'),('robben'),('robbie'),('robbie01'),('robbie1'),('robbie11'),('robbie12'),('robbie123'),('robbie2'),('robbin'),('robbins'),('robby'),('robby1'),('robby123'),('robert'),('robert!'),('robert.'),('robert0'),('robert00'),('robert01'),('robert02'),('robert03'),('robert04'),('robert05'),('robert06'),('robert07'),('robert08'),('robert09'),('robert1'),('robert10'),('robert101'),('robert11'),('robert12'),('robert123'),('robert1234'),('robert13'),('robert14'),('robert15'),('robert16'),('robert17'),('robert1708'),('robert18'),('robert19'),('robert2'),('robert20'),('robert21'),('robert22'),('robert23'),('robert24'),('robert25'),('robert26'),('robert27'),('robert28'),('robert3'),('robert30'),('robert33'),('robert4'),('robert44'),('robert45'),('robert5'),('robert55'),('robert6'),('robert66'),('robert69'),('robert7'),('robert77'),('robert8'),('robert87'),('robert88'),('robert89'),('robert9'),('robert93'),('robert99'),('roberta'),('roberta1'),('robertina'),('robertino'),('robertito'),('roberto'),('roberto1'),('roberto12'),('roberto123'),('roberto2'),('robertpatt'),('roberts'),('roberts1'),('robertson'),('robertson1'),('robin'),('robin1'),('robin12'),('robin123'),('robin2'),('robina'),('robinho'),('robinho10'),('robinhood'),('robinhood1'),('robins'),('robinson'),('robinson1'),('robles'),('roblox'),('robocop'),('robocop1'),('robot'),('robot1'),('robot123'),('robotech'),('robotics'),('robots'),('robots1'),('robrob'),('robroy'),('robson'),('robvandam'),('roby'),('robyn'),('robyn1'),('roc'),('rocafella'),('rocafella1'),('rocawear'),('rocawear1'),('rocco'),('rocco1'),('rocco123'),('rochdale'),('rochelle'),('rochelle1'),('rochester'),('rochester1'),('rocio'),('rocio1'),('rock'),('rock&roll'),('rock01'),('rock10'),('rock101'),('rock11'),('rock12'),('rock123'),('rock1234'),('rock13'),('rock14'),('rock15'),('rock21'),('rock22'),('rock23'),('rock24'),('rock4ever'),('rock4life'),('rock666'),('rock69'),('rock77'),('rock88'),('rock99'),('rockabilly'),('rockandrol'),('rockandroll'),('rockband'),('rockband1'),('rockband2'),('rockbottom'),('rocker'),('rocker1'),('rocker101'),('rocker12'),('rocker123'),('rocker13'),('rocker2'),('rockers'),('rockers1'),('rockers123'),('rocket'),('rocket01'),('rocket1'),('rocket11'),('rocket12'),('rocket123'),('rocket2'),('rocket21'),('rocket22'),('rocket3'),('rocket69'),('rocket88'),('rocketmail'),('rocketman'),('rocketman1'),('rockets'),('rockets1'),('rockey'),('rockey1'),('rockford'),('rockford1'),('rockhard'),('rockhard1'),('rockhopper'),('rockie'),('rockie1'),('rockies'),('rockies1'),('rockin'),('rockin1'),('rocking'),('rocking1'),('rockit'),('rockland'),('rocklee'),('rocklee1'),('rockman'),('rockman1'),('rockme'),('rocknroll'),('rocknroll!'),('rocknroll1'),('rocknroll2'),('rocknsock1'),('rocko'),('rocko1'),('rockon'),('rockon!'),('rockon1'),('rockon11'),('rockon12'),('rockon123'),('rockon2'),('rockon7'),('rockout'),('rockout1'),('rockport'),('rockrock'),('rockrock1'),('rockroll'),('rocks'),('rocks1'),('rocks123'),('rockstar'),('rockstar!'),('rockstar.'),('rockstar01'),('rockstar08'),('rockstar09'),('rockstar1'),('rockstar10'),('rockstar11'),('rockstar12'),('rockstar123'),('rockstar13'),('rockstar14'),('rockstar15'),('rockstar16'),('rockstar17'),('rockstar18'),('rockstar19'),('rockstar2'),('rockstar21'),('rockstar22'),('rockstar23'),('rockstar24'),('rockstar3'),('rockstar4'),('rockstar5'),('rockstar6'),('rockstar69'),('rockstar7'),('rockstar8'),('rockstar9'),('rocksteady'),('rockwell'),('rockwell1'),('rockwood'),('rocky'),('rocky!'),('rocky007'),('rocky01'),('rocky06'),('rocky07'),('rocky08'),('rocky09'),('rocky1'),('rocky10'),('rocky101'),('rocky11'),('rocky111'),('rocky12'),('rocky123'),('rocky1234'),('rocky12345'),('rocky13'),('rocky14'),('rocky15'),('rocky17'),('rocky2'),('rocky21'),('rocky22'),('rocky23'),('rocky24'),('rocky25'),('rocky3'),('rocky4'),('rocky5'),('rocky6'),('rocky69'),('rocky7'),('rocky77'),('rocky8'),('rocky9'),('rocky99'),('rockybalboa'),('rockyboy'),('rockydog'),('rockydog1'),('rockyou'),('rockyou1'),('rockyroad'),('rockys'),('rod'),('rod123'),('roddick'),('rodel'),('rodent'),('rodeo'),('rodeo1'),('roderick'),('roderick1'),('rodger'),('rodgers'),('rodica'),('rodina'),('rodion'),('rodman'),('rodman91'),('rodney'),('rodney1'),('rodney12'),('rodney123'),('rodney2'),('rodnik'),('rodolfo'),('rodolfo1'),('rodolphe'),('rodrigo'),('rodrigo1'),('rodrigo123'),('rodrigue'),('rodrigues'),('rodriguez'),('rodriguez1'),('rodriguez2'),('rodzina'),('rofl'),('rofl123'),('roflcopter'),('roflmao'),('roflmao1'),('roflmao123'),('roflrofl'),('rogelio'),('rogelio1'),('roger'),('roger01'),('roger1'),('roger12'),('roger123'),('roger2'),('rogerio'),('rogers'),('rogers1'),('rogovivan72'),('rogovsasha123'),('rogue'),('rogue1'),('rohan'),('rohan1'),('rohan123'),('rohini'),('rohit'),('rohit123'),('roisin'),('rojo123'),('roksana'),('rol'),('roland'),('roland1'),('roland123'),('roland7859'),('rolandia42'),('rolando'),('rolando1'),('roldan'),('roleplay1'),('rolex'),('rolex1'),('rolland'),('roller'),('roller1'),('rollercoaster'),('rollie'),('rollie1'),('rollin'),('rollin1'),('rollin20'),('rollin60'),('rolling'),('rolling1'),('rollingstones'),('rollins'),('rollins1'),('rollsroyce'),('rolltide'),('rolltide1'),('rolltide12'),('rolly'),('rolyat'),('rom'),('rom828'),('roma'),('roma12'),('roma123'),('roma1234'),('roma1927'),('roma1996'),('roma2010'),('romain'),('romaine'),('roman'),('roman1'),('roman123'),('romana'),('romance'),('romance!'),('romance1'),('romane'),('romanenko'),('romani'),('romania'),('romania1'),('romanista'),('romano'),('romano1'),('romanov'),('romanova'),('romanova.natalya.96'),('romanroman'),('romans'),('romans1'),('romans116'),('romans12'),('romans8'),('romans828'),('romanson'),('romantic'),('romantic1'),('romantica'),('romantico'),('romantik'),('romantika'),('romario'),('romaroma'),('romashka'),('romawka'),('rome'),('romel'),('romeo'),('romeo01'),('romeo1'),('romeo11'),('romeo12'),('romeo123'),('romeo13'),('romeo2'),('romeo22'),('romeo3'),('romeo7'),('romeos'),('romero'),('romero1'),('romina'),('romina1'),('romka_ya93'),('rommel'),('rommel1'),('romnick'),('romo09'),('romuald'),('romulo'),('romulus'),('romy01'),('ron'),('ron123'),('ronald'),('ronald1'),('ronald12'),('ronald123'),('ronald2'),('ronaldinho'),('ronaldinho10'),('ronaldo'),('ronaldo07'),('ronaldo09'),('ronaldo1'),('ronaldo10'),('ronaldo11'),('ronaldo12'),('ronaldo123'),('ronaldo17'),('ronaldo2'),('ronaldo7'),('ronaldo77'),('ronaldo9'),('ronaldo99'),('ronalyn'),('ronan'),('ronin'),('ronin1'),('ronja'),('ronnel'),('ronnie'),('ronnie01'),('ronnie1'),('ronnie10'),('ronnie11'),('ronnie12'),('ronnie123'),('ronnie2'),('ronnie3'),('ronny'),('ronny1'),('ronron'),('ronron1'),('roofer'),('roofer1'),('roofing'),('roofing1'),('rookie'),('rookie1'),('room101'),('rooney'),('rooney08'),('rooney1'),('rooney10'),('rooney123'),('rooney8'),('rooney9'),('rooroo'),('rooroo1'),('roosevelt'),('roosevelt1'),('roosje'),('rooster'),('rooster1'),('rooster2'),('roosters'),('roosters1'),('root'),('root123'),('rootbeer'),('rootbeer1'),('rootbeer12'),('rootbeer2'),('rooter'),('rootroot'),('roots'),('roper1'),('roro'),('roro1024'),('roro123'),('rororo'),('ros'),('rosa'),('rosa11'),('rosa12'),('rosa123'),('rosa1234'),('rosa13'),('rosado'),('rosalba'),('rosales'),('rosales1'),('rosalia'),('rosalie'),('rosalie1'),('rosalina'),('rosalind'),('rosalinda'),('rosalinda1'),('rosalyn'),('rosamaria'),('rosana'),('rosangela'),('rosanna'),('rosanna1'),('rosaria'),('rosario'),('rosario1'),('rosarosa'),('rosary'),('rosco'),('rosco1'),('roscoe'),('roscoe1'),('roscoe131'),('rose'),('rose01'),('rose07'),('rose08'),('rose09'),('rose10'),('rose101'),('rose11'),('rose12'),('rose123'),('rose1234'),('rose13'),('rose14'),('rose15'),('rose16'),('rose17'),('rose18'),('rose19'),('rose21'),('rose22'),('rose23'),('rose24'),('rose24731'),('rose25'),('rose69'),('rose77'),('rose88'),('rose99'),('roseann'),('roseann1'),('roseanne'),('rosebud'),('rosebud1'),('rosebud12'),('rosebud123'),('rosebud2'),('rosebud7'),('rosebuds'),('rosedale'),('rosegarden'),('roseline'),('rosella'),('roselle'),('roselyn'),('rosemarie'),('rosemarie1'),('rosemary'),('rosemary1'),('rosendo'),('rosenrot'),('rosered'),('roserose'),('roses'),('roses1'),('roses12'),('roses123'),('roses2'),('rosetta'),('rosetta1'),('rosette'),('rosewood'),('rosewood1'),('rosey'),('rosey1'),('roshan'),('roshni'),('rosie'),('rosie01'),('rosie1'),('rosie11'),('rosie12'),('rosie123'),('rosie2'),('rosie3'),('rosiedog'),('rosina'),('rosine'),('rosinha'),('rosita'),('rosita1'),('roslyn'),('ross'),('ross123'),('rossana'),('rossella'),('rossi'),('rossi1'),('rossi46'),('rossia'),('rossia19'),('rossie'),('rossignol'),('rosso'),('rossoneri'),('rossonero'),('rostik'),('rostislav'),('rostov'),('rostov8888'),('roswell'),('roswell1'),('rosy'),('rotary'),('rotciv'),('rothmans'),('rotimi'),('rotten'),('rotten1'),('rotterdam'),('rotterdam1'),('rottie'),('rottweiler'),('roucky'),('roudoudou'),('rouge'),('rouges'),('rough'),('roulette'),('rousseau'),('route66'),('route666'),('router'),('rover'),('rover1'),('rover123'),('rover75'),('rovers'),('rovers1'),('rowan'),('rowan1'),('rowdy'),('rowdy1'),('rowell'),('rowena'),('rowena1'),('rowing'),('rowland'),('rowley'),('roxana'),('roxana1'),('roxane'),('roxanne'),('roxanne1'),('roxas1'),('roxas13'),('roxette'),('roxie'),('roxie1'),('roxie123'),('roxy'),('roxy01'),('roxy07'),('roxy08'),('roxy10'),('roxy101'),('roxy11'),('roxy12'),('roxy123'),('roxy1234'),('roxy13'),('roxy14'),('roxy15'),('roxy18'),('roxy21'),('roxy22'),('roxy23'),('roxy69'),('roxydog'),('roxydog1'),('roxygirl'),('roxygirl1'),('roxyroxy'),('roy'),('roy123'),('royal'),('royal1'),('royal123'),('royale'),('royalflush'),('royals'),('royals1'),('Royals22'),('royalty'),('royalty1'),('royboy'),('roygbiv'),('royroy'),('royston'),('roza'),('rozlori'),('rrr'),('rrr123'),('rrrr'),('rrrrr'),('rrrrr1'),('rrrrrr'),('rrrrrr1'),('rrrrrrr'),('rrrrrrrr'),('rrrrrrrrrr'),('rs11220'),('rs2000'),('rtertuy77ijyhu7i'),('rtrtrt'),('RTW150809'),('rtyfgh'),('rtyfghvbn'),('rtynfdh'),('rtyrty'),('rtyuehe'),('rtyuio'),('rtyuiop'),('ru4real'),('rubber'),('rubber1'),('rubberband'),('rubberduck'),('rubberducky'),('rubbish'),('ruben'),('ruben1'),('ruben123'),('rubens'),('rubicon'),('rubicon1'),('rubies'),('rubina'),('ruby'),('ruby01'),('ruby10'),('ruby11'),('ruby12'),('ruby123'),('ruby1234'),('ruby13'),('ruby22'),('rubydog'),('rubyred'),('rubyred1'),('rubyrose'),('rubyruby'),('rucaxefu'),('ruchika'),('ruckus'),('rudeboy'),('rudeboy1'),('rudenko'),('rudi'),('rudolf'),('rudolph'),('rudolph1'),('rudy'),('rudy102'),('rudy12'),('rudy123'),('ruffles'),('ruffles1'),('ruffryder'),('ruffryders'),('ruffus'),('rufina'),('rufino'),('rufus'),('rufus1'),('rufus123'),('rug'),('rugby'),('rugby1'),('rugby123'),('rugby15'),('rugbyman'),('ruger'),('ruger1'),('rugged'),('rugger'),('rugrat'),('rugrat1'),('rugrats'),('rugrats1'),('rui100'),('ruicosta'),('rukawa'),('rukhsana'),('ruler1991'),('rules'),('rulez'),('rumble'),('run'),('run123'),('run4fun'),('run4life'),('runaway'),('runaway1'),('rundmc'),('runescape'),('runescape!'),('runescape1'),('runescape123'),('runescape2'),('runescape3'),('runescape5'),('runescape9'),('runfast'),('runner'),('runner1'),('runner11'),('runner12'),('runner2'),('running'),('running1'),('runrun'),('rupali'),('rupert'),('rupert1'),('rupesh'),('ruqueb'),('rus'),('rus20dem'),('rusali_1979'),('rusalka'),('rush'),('rush2112'),('rushhour'),('rushmore'),('rushrush'),('rusiphon4'),('ruslan'),('ruslan009'),('ruslan123'),('ruslana'),('russ'),('russel'),('russel1'),('russell'),('russell1'),('russell123'),('russell2'),('russia'),('russia1'),('russia11'),('russia123'),('russian'),('russian1'),('russland'),('rustam'),('rustem'),('rustik'),('rusty'),('rusty01'),('rusty1'),('rusty11'),('rusty12'),('rusty123'),('rusty13'),('rusty2'),('rusty3'),('rusty5'),('rusty7'),('rustydog'),('rustydog1'),('rutgers'),('rutgers1'),('ruth'),('ruth123'),('ruthann'),('rutherford'),('ruthie'),('ruthie1'),('ruthless'),('ruthless1'),('rvd420'),('rwanda'),('ry1dtv'),('ryabec.m'),('ryan'),('ryan01'),('ryan02'),('ryan03'),('ryan04'),('ryan05'),('ryan06'),('ryan07'),('ryan08'),('ryan09'),('ryan1'),('ryan10'),('ryan101'),('ryan11'),('ryan12'),('ryan123'),('ryan1234'),('ryan12345'),('ryan13'),('ryan14'),('ryan15'),('ryan16'),('ryan17'),('ryan18'),('ryan19'),('ryan20'),('ryan2000'),('ryan2005'),('ryan2006'),('ryan2007'),('ryan2008'),('ryan21'),('ryan22'),('ryan23'),('ryan24'),('ryan25'),('ryan69'),('ryan88'),('ryan962052'),('ryan99'),('ryangiggs'),('ryanjames'),('ryanryan'),('ryder'),('ryder1'),('ryjgjxrf'),('ryjgrf'),('rylee1'),('ryleigh'),('ryleigh1'),('ryslan'),('ryu750103'),('rzaev_ilgar'),('r_masick'),('s'),('s-firsova'),('s00000'),('s000000'),('s0cc3r'),('s0ccer'),('s0ftball'),('s0mething'),('s11111'),('s111111'),('s112233'),('s123123'),('s123321'),('s12345'),('s123456'),('s1234567'),('s12345678'),('s123456789'),('s123456s'),('s1lver'),('s1mple'),('s1s1s1'),('s1s2s3'),('s1s2s3s4'),('s1t2o3n4'),('s39jWbw5iA'),('s3cr3t'),('s55555'),('s654321'),('s666666'),('s696969'),('s7777777'),('s8krIl9u4F'),('s8YLPe9jDPvYM'),('s987654321'),('S9QxA9Yn9Cc='),('sa'),('sa1234'),('sa12345'),('sa123456'),('sa2rawybas'),('saab900'),('saab9000'),('saab93'),('saab95'),('saad123'),('saadia'),('saavedra'),('sab'),('sab123'),('saba'),('sabado'),('sabaka'),('sabastian'),('sabato'),('sabbath'),('sabbath1'),('sabedoria'),('saber'),('saber1'),('sabertooth'),('sabian'),('sabian1'),('sabiduria'),('sabiha'),('sabina'),('sabina1'),('sabine'),('sabine1'),('sabine12'),('sabine21'),('sabinka'),('sabino'),('sabita'),('sable'),('sable1'),('sable123'),('sabotage'),('sabre'),('sabre1'),('sabres'),('sabres1'),('sabrina'),('sabrina!'),('sabrina01'),('sabrina1'),('sabrina10'),('sabrina11'),('sabrina12'),('sabrina123'),('sabrina13'),('sabrina2'),('sabrina22'),('sabrina3'),('sabrina5'),('sabrina7'),('sabrina9'),('sabrine'),('sac123'),('sac916'),('sacha'),('sacha1'),('sacha1234'),('sachiko'),('sachin'),('sachin123'),('sacramento'),('sacred'),('sacred1'),('sacrifice'),('sactown916'),('sad'),('sad123'),('sadako'),('saddam'),('saddie'),('saddie1'),('saddle'),('saddle1'),('sadgirl1'),('sadhana'),('sadie'),('sadie!'),('sadie01'),('sadie07'),('sadie1'),('sadie10'),('sadie11'),('sadie12'),('sadie123'),('sadie13'),('sadie2'),('sadie3'),('sadie5'),('sadie7'),('sadiedog'),('sadiedog1'),('sadiegirl'),('sadiegirl1'),('sadiemae'),('sadiemae1'),('sadies'),('sadist'),('sadiya'),('sadman'),('sadness'),('sadness1'),('sadsad'),('safari'),('safari1'),('safe'),('safety'),('safety1'),('safety123'),('safety1st'),('safeway'),('safeway1'),('saffron'),('saffron1'),('safina'),('safira'),('safiya'),('safonova.1967'),('safrane'),('safronov_3112'),('sagalil'),('sagapo'),('sagar'),('sagar123'),('sagara'),('sagarika'),('sage'),('sage123'),('sagesse'),('sagitaire'),('sagitario'),('sagitario1'),('sagitarius'),('sagittario'),('sagittarius'),('sagopa'),('sagopakajmer'),('sahabat'),('sahana'),('sahara'),('sahara1'),('saheed'),('Sahhas1221'),('sahil'),('sai'),('sai123'),('saibaba'),('saibaba1'),('saibaba123'),('saibot'),('said'),('saidov12345'),('saiful'),('saigon'),('sailaja'),('sailboat'),('sailboat1'),('sailfish'),('sailing'),('sailing1'),('sailor'),('sailor1'),('sailormoon'),('saimon'),('sainath'),('saint'),('saint1'),('saints'),('saints01'),('saints09'),('saints1'),('saints10'),('saints11'),('saints12'),('saints123'),('saints2'),('saints25'),('saintseiya'),('saintsrow2'),('saipan670'),('sairam'),('sairam1'),('sairam123'),('saisai'),('saitek'),('saitou'),('saiyan'),('saiyuki'),('sajjad'),('sakamoto'),('sakartvelo'),('sakarya'),('sakarya54'),('sakic19'),('sakina'),('sakoshka_masha'),('sakshi'),('sakthi'),('sakura'),('sakura1'),('sakura11'),('sakura12'),('sakura123'),('sakura13'),('sakura2'),('sakura7'),('sakuragi'),('sal'),('sal123'),('salaam'),('salad'),('salad1'),('salade'),('saladin'),('salado'),('salah'),('salam'),('salam1'),('salam123'),('salama'),('salamanca'),('salamander'),('salamandra'),('salamat'),('salame'),('salami'),('salami1'),('salamon'),('salamsalam'),('salas831'),('salasana'),('salasana1'),('salavat'),('salazar'),('salazar1'),('salcedo'),('saleem'),('saleen'),('saleen1'),('saleens7'),('salem'),('salem1'),('salem123'),('salento'),('salento12'),('salerno'),('sales'),('sales1'),('sales123'),('salesman'),('salford'),('salgado'),('saliha'),('salim'),('salim123'),('salima'),('salimata'),('salina'),('salina1'),('salinas'),('salinas1'),('salinas831'),('salinger'),('salisbury'),('saliva'),('sallad'),('sallie'),('sallie1'),('sally'),('sally1'),('sally12'),('sally123'),('sally2'),('sallyann'),('sallydog'),('salma'),('salma1'),('salma123'),('salman'),('salman1'),('salman123'),('salmankhan'),('salmo23'),('salmo91'),('salmon'),('salmon1'),('salocin'),('saloma'),('salome'),('salome1'),('salomon'),('salomon1'),('salon1'),('saloni'),('salope'),('salsa'),('salsa1'),('salsa123'),('salsabila'),('salsal'),('salsero'),('saltanat'),('saltlake'),('saltwater'),('salty1'),('saltydog'),('salut'),('salut1'),('salut123'),('salute'),('salvacion'),('salvador'),('salvador1'),('salvador12'),('salvador13'),('salvador2'),('salvaje'),('salvation'),('salvation1'),('salvatore'),('salvatore1'),('salvo'),('salzburg'),('sam'),('sam007'),('sam101'),('sam111'),('sam123'),('sam1234'),('sam12345'),('sam123456'),('samadhi'),('samael'),('samana'),('samanta'),('samanta1'),('samantha'),('samantha!'),('samantha.'),('samantha01'),('samantha06'),('samantha07'),('samantha08'),('samantha09'),('samantha1'),('samantha10'),('samantha11'),('samantha12'),('samantha123'),('samantha13'),('samantha14'),('samantha15'),('samantha16'),('samantha17'),('samantha18'),('samantha19'),('samantha2'),('samantha20'),('samantha21'),('samantha22'),('samantha23'),('samantha3'),('samantha4'),('samantha5'),('samantha6'),('samantha69'),('samantha7'),('samantha8'),('samantha9'),('samara'),('samara1'),('samarinda'),('samarkand'),('samarth'),('samatron'),('samaya'),('samba'),('samba1'),('sambo'),('sambo1'),('samboy'),('sambuca'),('sambuca1'),('sambuka'),('samdog'),('samdog1'),('same'),('samedi'),('sameena'),('sameer'),('sameer123'),('sameera'),('samhain'),('sami'),('sami12'),('sami123'),('samia'),('samiam'),('samiam1'),('samiksha'),('samina'),('samir'),('samir1'),('samir123'),('samir21'),('samira'),('samira1'),('samisami'),('samitluiza1'),('samm'),('sammer'),('sammi'),('sammi1'),('sammi123'),('sammie'),('sammie01'),('sammie1'),('sammie11'),('sammie12'),('sammie123'),('sammie13'),('sammie2'),('sammie3'),('sammy'),('sammy!'),('sammy01'),('sammy05'),('sammy06'),('sammy07'),('sammy08'),('sammy09'),('sammy1'),('sammy10'),('sammy101'),('sammy11'),('sammy111'),('sammy12'),('sammy123'),('sammy1234'),('sammy13'),('sammy14'),('sammy15'),('sammy16'),('sammy17'),('sammy18'),('sammy2'),('sammy21'),('sammy22'),('sammy23'),('sammy24'),('sammy3'),('sammy4'),('sammy5'),('sammy6'),('sammy69'),('sammy7'),('sammy77'),('sammy8'),('sammy9'),('sammy99'),('sammyboy'),('sammyboy1'),('sammycat'),('sammyd'),('sammydog'),('sammydog1'),('sammyjo'),('sammyjo1'),('sammys'),('samoa1'),('samoan'),('samoan1'),('samogon'),('samoht'),('samolet'),('samone'),('samone1'),('samosa'),('samourai'),('sampaguita'),('sampath'),('sampdoria'),('sample'),('sample1'),('Sample123'),('Sample1234'),('samples'),('sampoerna'),('sampras'),('sampson'),('sampson1'),('sampson2'),('samrat'),('samreen'),('samsam'),('samsam1'),('samsam12'),('samsam123'),('samsamsam'),('samsara'),('samson'),('samson01'),('samson1'),('samson10'),('samson11'),('samson12'),('samson123'),('samson2'),('samsonite'),('samsuchonok'),('samsun'),('samsun55'),('samsung'),('samsung!'),('samsung.'),('samsung0'),('samsung01'),('samsung09'),('samsung1'),('samsung10'),('samsung11'),('samsung12'),('samsung123'),('samsung13'),('samsung14'),('samsung2'),('samsung21'),('samsung22'),('samsung23'),('samsung3'),('samsung4'),('samsung5'),('samsung6'),('samsung69'),('samsung7'),('samsung8'),('samsung88'),('samsung9'),('samtheman'),('samtron'),('samtron1'),('samual'),('samuel'),('samuel01'),('samuel02'),('samuel07'),('samuel08'),('samuel09'),('samuel1'),('samuel10'),('samuel100'),('samuel11'),('samuel12'),('samuel123'),('samuel1234'),('samuel12345'),('samuel13'),('samuel14'),('samuel15'),('samuel2'),('samuel21'),('samuel22'),('samuel23'),('samuel3'),('samuel4'),('samuel5'),('samuel7'),('samuel99'),('samuele'),('samuelito'),('samurai'),('samurai1'),('samurai7'),('samuraix'),('samuray'),('samvel'),('samwise'),('samy'),('san'),('san123'),('sana'),('sana123'),('sanandreas'),('sanandres'),('sanane'),('sanane1'),('sanane123'),('sananelan'),('sananto210'),('sanantonio'),('sanasana'),('sancarlos'),('sanches'),('sanchez'),('sanchez1'),('sanchez12'),('sanchez123'),('sanchez13'),('sanchez2'),('sanchita'),('sancho'),('sancho1'),('sanctuary'),('sand'),('sandal'),('sandals'),('sandara'),('sandberg'),('Sandberg5'),('sandbox'),('sandee'),('sandeep'),('sandeep1'),('sandeep123'),('sander'),('sander1'),('sanders'),('sanders1'),('sanders20'),('sanders21'),('sanderson'),('sandesh'),('sandgrouse'),('sandhu'),('sandhya'),('sandi'),('sandi1'),('sandia'),('sandie'),('sandie1'),('sandiego'),('sandiego1'),('sandiego13'),('sandiego61'),('sandip'),('sandler'),('sandman'),('sandman1'),('sandman2'),('sandokan'),('sandor'),('sandoval'),('sandoval1'),('sandpiper'),('sandra'),('sandra.'),('sandra01'),('sandra1'),('sandra10'),('sandra11'),('sandra12'),('sandra123'),('sandra13'),('sandra14'),('sandra15'),('sandra18'),('sandra2'),('sandra21'),('sandra22'),('sandra23'),('sandra3'),('sandra5'),('sandra69'),('sandra7'),('sandrina'),('sandrine'),('sandrita'),('sandro'),('sandro1'),('sandrock'),('sandstorm'),('sandwich'),('sandwich1'),('sandy'),('sandy01'),('sandy1'),('sandy10'),('sandy11'),('sandy12'),('sandy123'),('sandy1234'),('sandy13'),('sandy2'),('sandy22'),('sandy3'),('sandy4'),('sandy5'),('sandy7'),('sandydog'),('sandydog1'),('sandys'),('sanek'),('sanford'),('sanford1'),('sanfran'),('sanfran1'),('sanfran49'),('sanfrancisco'),('sangam'),('sangeeta'),('sangeetha'),('sangha'),('sangita'),('sanglier'),('sangohan'),('sangoku'),('sangre'),('sangria'),('sanguine'),('sanibel'),('sanika'),('sanity'),('saniya'),('sanjana'),('sanjar'),('sanjay'),('sanjay1'),('sanjay123'),('sanjeev'),('sanjo408'),('sanjose'),('sanjose1'),('sanjose408'),('sanju'),('sanju123'),('sanjuan'),('sanjuan1'),('sankar'),('sanket'),('sanlorenzo'),('sanluis'),('sanluis1'),('sanmarcos'),('sanmartin'),('sanmiguel'),('sanosuke'),('sanpedro'),('sanpedro1'),('sanrio'),('sans2010'),('sansan'),('sansiro'),('sanson'),('sansone'),('santa'),('santa1'),('santa12'),('santa123'),('santaclara'),('santaclaus'),('santacruz'),('santacruz1'),('santafe'),('santafe1'),('santamaria'),('santana'),('santana1'),('santana2'),('santander'),('santarosa'),('santas'),('santeria'),('santhi'),('santhosh'),('santi'),('santi1'),('santi123'),('santiago'),('santiago1'),('santiago12'),('santiago123'),('santiago2'),('santillan'),('santina'),('santino'),('santino1'),('santo'),('santo1'),('santodomingo'),('santorini'),('santos'),('santos1'),('santos10'),('santos12'),('santos123'),('santos13'),('santos14'),('santosh'),('santosh123'),('santoshi'),('santro'),('sanya'),('sanyika'),('saoirse'),('saopaulo'),('saosin'),('saosin1'),('sapana'),('sapato'),('sapfir'),('saphir'),('saphira'),('saphira1'),('saphire'),('saphire1'),('sapito'),('sapper'),('sapphire'),('sapphire1'),('saprissa'),('saputra'),('saqartvelo'),('sar'),('sara'),('sara01'),('sara10'),('sara11'),('sara12'),('sara123'),('sara1234'),('sara13'),('sara14'),('sara15'),('sara2000'),('sara21'),('sara22'),('sara23'),('sara7272'),('saraba'),('saracen'),('sarada'),('sarafina'),('sarah'),('sarah!'),('sarah.'),('sarah01'),('sarah06'),('sarah07'),('sarah08'),('sarah09'),('sarah1'),('sarah10'),('sarah101'),('sarah11'),('sarah12'),('sarah123'),('sarah1234'),('sarah13'),('sarah14'),('sarah15'),('sarah16'),('sarah17'),('sarah18'),('sarah19'),('sarah2'),('sarah21'),('sarah22'),('sarah23'),('sarah24'),('sarah3'),('sarah4'),('sarah5'),('sarah6'),('sarah69'),('sarah7'),('sarah8'),('sarah88'),('sarah9'),('sarah99'),('saraha'),('sarahann'),('sarahb'),('sarahg'),('sarahh'),('sarahi'),('sarahj'),('sarahjane'),('sarahjane1'),('sarahm'),('sarahs'),('sarajane'),('sarajevo'),('sarajevo1'),('sarala'),('saralee'),('sarang'),('saranghae'),('saranghe'),('saranya'),('sarasa'),('sarasara'),('sarasota'),('sarasota1'),('saraswathi'),('saraswati'),('sarath'),('saratoga'),('saratoga1'),('saratov'),('saravana'),('saravanan'),('saravn'),('sardar'),('sardegna'),('sardine'),('sardor'),('saregama'),('saretta'),('sarge'),('sarge1'),('sargent'),('sargent1'),('sargento'),('sargodha'),('sarika'),('sarina'),('sarina1'),('sarinha'),('sarinka'),('sarita'),('sarita1'),('saritha'),('sarkar'),('sarkar123'),('sarkis'),('sarmat'),('sarmiento'),('saroja'),('sarojini'),('sarrah'),('sarthak'),('saruman'),('sarumi101'),('sarvesh'),('sas'),('sas123'),('sasa'),('sasa12'),('sasa123'),('sasa1234'),('sasanext'),('sasasa'),('sasasa1'),('sasasasa'),('sascha'),('sascha1'),('sasha'),('sasha007'),('sasha01'),('sasha1'),('sasha10'),('sasha11'),('sasha111'),('sasha12'),('sasha123'),('sasha1234'),('sasha12345'),('sasha13'),('sasha14'),('sasha15'),('sasha16'),('sasha17'),('sasha1987'),('sasha1988'),('sasha1989'),('sasha1990'),('sasha1991'),('sasha1992'),('sasha1993'),('sasha1994'),('sasha1995'),('sasha1996'),('sasha1997'),('sasha1998'),('sasha1999'),('sasha2'),('sasha2000'),('sasha2001'),('sasha2002'),('sasha2003'),('sasha2010'),('sasha2011'),('sasha21'),('sasha22'),('sasha23'),('sasha3'),('sasha5'),('sasha7'),('sasha777'),('sasha98'),('sasha99'),('sashaa'),('sashadog'),('sashas'),('sashasasha'),('sasha_007'),('sashenka'),('sashimi'),('sashka'),('sashok'),('sasikala'),('sasin414'),('sasiska'),('saskia'),('saskia1'),('sasori'),('sasquatch'),('sasquatch1'),('sassafras'),('sassari'),('sassas'),('sassi123'),('sassie'),('sassie1'),('sassy'),('sassy01'),('sassy07'),('sassy08'),('sassy09'),('sassy1'),('sassy10'),('sassy101'),('sassy11'),('sassy12'),('sassy123'),('sassy1234'),('sassy13'),('sassy14'),('sassy2'),('sassy21'),('sassy22'),('sassy3'),('sassy4'),('sassy5'),('sassy6'),('sassy69'),('sassy7'),('sassycat'),('sassycat1'),('sassydog'),('sassygirl'),('sassygirl1'),('sasuke'),('sasuke01'),('sasuke1'),('sasuke10'),('sasuke101'),('sasuke11'),('sasuke12'),('sasuke123'),('sasuke1234'),('sasuke13'),('sasuke14'),('sasuke15'),('sasuke2'),('sasuke22'),('sasuke23'),('sasuke3'),('sasuke7'),('sasukeuchiha'),('sasusaku'),('sat'),('sat123'),('sataieva.elinka'),('satan'),('satan1'),('satan123'),('satan6'),('satan666'),('satana'),('satana666'),('satanas'),('satanas666'),('satanic'),('satanic666'),('satchel'),('satchmo'),('satchmo1'),('satelite'),('satellite'),('satellite1'),('satguru'),('satheesh'),('sathish'),('sathya'),('satine'),('satisfaction'),('satish'),('sativa'),('sativa1'),('satnam'),('satori'),('satoshi'),('satria'),('satriani'),('satriani1'),('satsuki'),('satsuma'),('sattorov-q'),('saturday'),('saturday1'),('saturn'),('saturn01'),('saturn1'),('saturn12'),('saturn5'),('saturne'),('saturno'),('saturnus'),('satya'),('satyam'),('saucisse'),('saudade'),('saudades'),('saufen'),('saulito'),('saulute'),('saumya'),('saun'),('saunders'),('saunders1'),('saurabh'),('saurav'),('sauron'),('sausage'),('sausage1'),('sausages'),('sausages1'),('sav'),('savage'),('savage1'),('savage12'),('savage123'),('savage2'),('savage23'),('savage3'),('savana'),('savana1'),('savanah'),('savanah1'),('savanna'),('savanna1'),('savannah'),('savannah01'),('savannah07'),('savannah08'),('savannah1'),('savannah10'),('savannah11'),('savannah12'),('savannah13'),('savannah2'),('savannah3'),('savannah4'),('savannah5'),('savannah7'),('savatage'),('sava_72'),('save'),('saved'),('saved1'),('saveme'),('saveme1'),('savemoney'),('saverio'),('savina'),('saving'),('savings'),('saviola'),('savior'),('savior1'),('saviour'),('saviour1'),('savita'),('savitha'),('savithri'),('savitri'),('saw123'),('saw7139'),('sawdust'),('sawsaw'),('sawsaw1212'),('sawyer'),('sawyer1'),('saxaphone'),('saxena'),('saxman'),('saxofon'),('saxon'),('saxophone'),('saxophone1'),('say'),('saya123'),('sayang'),('sayang1'),('sayang12'),('sayang123'),('sayang2'),('sayang87'),('sayang88'),('sayang89'),('sayang90'),('sayangkamu'),('sayangku'),('sayangku1'),('sayangmama'),('sayank'),('sayonara'),('saysay'),('sayuri'),('saywhat'),('saywhat1'),('sb1234'),('sb123456'),('sbally_64'),('sbc123'),('sc00by'),('sc00byd00'),('sc00ter'),('sc0tland'),('sc1234'),('sca'),('scales'),('scammer'),('scamp'),('scamp1'),('scamper'),('scamper1'),('scampi'),('scampy'),('scandal'),('scania'),('scania1'),('scanner'),('scanner1'),('scarab'),('scarabeo'),('scarecrow'),('scarecrow1'),('scared'),('scareface'),('scareface1'),('scarface'),('scarface1'),('scarface10'),('scarface11'),('scarface12'),('scarface13'),('scarface2'),('scarface21'),('scarface23'),('scarface3'),('scarface5'),('scarface69'),('scarface7'),('scarlet'),('scarlet1'),('scarlett'),('scarlett1'),('scary1'),('scene1'),('scenic'),('sceptre'),('sch'),('sch00l'),('schaap'),('schach'),('schaefer'),('schalke'),('schalke04'),('schastie'),('schatje'),('schatten'),('schatz'),('schatz1'),('schatz123'),('schatzi'),('schatzi1'),('schatzie'),('schecter1'),('scheisse'),('scheisse1'),('schilf02'),('schiller'),('schizzo'),('schlampe'),('schlampe1'),('schlange'),('schlumpf'),('schmetterling'),('schmidt'),('schmidt1'),('schmoo'),('schnauzer'),('schnecke'),('schnecke1'),('schnee'),('schneider'),('schneider1'),('schnitzel'),('schnucki'),('schnuffel'),('schnuffi'),('schnulli'),('schoko'),('schokolade'),('scholar'),('scholes'),('scholes18'),('school'),('school!'),('school.'),('school01'),('school07'),('school08'),('school09'),('school1'),('school10'),('school101'),('school11'),('school12'),('school123'),('school1234'),('school13'),('school14'),('school2'),('school22'),('school23'),('school3'),('school4'),('school5'),('school6'),('school7'),('school8'),('school9'),('schoolboy'),('schoolboy1'),('schoolbus'),('schoolbus1'),('schoolgirl'),('schools'),('schoolsucks'),('schooner'),('schranz'),('schroeder'),('schubert'),('schule'),('schule1'),('schultz'),('schultz1'),('schumacher'),('schumi'),('schuster'),('schuyler'),('schwanz'),('schwartz'),('schwarz'),('schweden'),('schwein'),('schweini'),('schweiz'),('schwimmen'),('science'),('science1'),('scientist'),('scimitar'),('scimmia'),('scipio'),('scirocco'),('scissors'),('scissors1'),('sclub7'),('sco'),('scoala'),('scofield'),('scoobie'),('scoobie1'),('scooby'),('scooby!'),('scooby-doo'),('scooby01'),('scooby08'),('scooby1'),('scooby10'),('scooby11'),('scooby12'),('scooby123'),('scooby13'),('scooby14'),('scooby2'),('scooby21'),('scooby22'),('scooby23'),('scooby3'),('scooby4'),('scooby5'),('scooby6'),('scooby69'),('scooby7'),('scooby8'),('scoobyd00'),('scoobydo'),('scoobydoo'),('scoobydoo1'),('scoobydoo2'),('scoobydoo3'),('scoobydoo7'),('scoop1'),('scoot1'),('scooter'),('scooter!'),('scooter01'),('scooter1'),('scooter10'),('scooter11'),('scooter12'),('scooter123'),('scooter13'),('scooter2'),('scooter22'),('scooter23'),('scooter3'),('scooter4'),('scooter5'),('scooter6'),('scooter69'),('scooter7'),('scooter8'),('scooter9'),('scooters'),('scooty'),('scopare'),('score'),('score1'),('scorpian'),('scorpio'),('scorpio1'),('scorpio11'),('scorpio12'),('scorpio123'),('scorpio13'),('scorpio2'),('scorpio21'),('scorpio3'),('scorpio69'),('scorpio7'),('scorpio8'),('scorpio9'),('scorpion'),('scorpion1'),('scorpion12'),('scorpion13'),('scorpion2'),('scorpion7'),('scorpione'),('scorpions'),('scorpions1'),('scotch'),('scotch1'),('scotia'),('scotland'),('scotland1'),('scott'),('scott01'),('scott1'),('scott10'),('scott11'),('scott12'),('scott123'),('scott13'),('scott2'),('scott22'),('scott23'),('scott3'),('scott5'),('scott69'),('scott7'),('scottie'),('scottie1'),('scottish'),('scotts'),('scotty'),('scotty01'),('scotty1'),('scotty12'),('scotty123'),('scotty2'),('scoubidou'),('scouse'),('scouser'),('scout'),('scout1'),('scout123'),('scout2'),('scouting'),('scouts'),('scrabble'),('scrabble1'),('scranton'),('scrap'),('scrapbook'),('scrapper'),('scrapper1'),('scrappy'),('scrappy1'),('scrappy12'),('scrappy123'),('scrappy13'),('scrappy2'),('scratch'),('scratch1'),('scratchy'),('scraty98'),('scream'),('scream1'),('scream123'),('screamer'),('screamo'),('screamo1'),('screen'),('screen1'),('screwed'),('screwed1'),('screwu'),('screwu2'),('screwyou'),('screwyou1'),('screwyou2'),('script'),('scroll'),('scroll1'),('scrooge'),('scrubs'),('scrubs1'),('scruff'),('scruffy'),('scruffy1'),('scruffy123'),('scruffy2'),('scrumpy'),('scsc78'),('scuba'),('scuba1'),('scubadiver'),('scuderia'),('scully'),('scully1'),('scumbag'),('scumbag1'),('scuola'),('scvMOFAS79'),('sczouvie26'),('sd1234'),('sd123456'),('sd1904'),('sdf'),('sdf123'),('sdf7asdf6asdg8df'),('sdf7asdf6asdg8df1'),('sdfg'),('sdfghj'),('sdfghjkl'),('sdfsdf'),('sdfsdfsd'),('sdfsdfsdf'),('SDream'),('sdsadEE23'),('sdsdsd'),('sdsdsdsd'),('se'),('sea'),('sea123'),('seabass'),('seabass1'),('seabee'),('seabreeze'),('seadog'),('seadoo'),('seafood'),('seafood1'),('seagate'),('seagull'),('seagull1'),('seagulls'),('seahawk'),('seahawk1'),('seahawks'),('seahawks1'),('seahorse'),('Seahorse1'),('sealord'),('sealteam6'),('seaman'),('seamus'),('seamus1'),('sean'),('sean01'),('sean11'),('sean12'),('sean123'),('sean1234'),('sean13'),('sean14'),('sean21'),('sean22'),('sean23'),('seanjohn'),('seanjohn1'),('seanpaul'),('seanpaul1'),('seansean'),('searay'),('search'),('search1'),('search123'),('searcher'),('searching'),('seasea'),('seashell'),('seashell1'),('seashells'),('seashore'),('seaside'),('seaside1'),('season'),('season1'),('seasons'),('seatibiza'),('seatleon'),('seattle'),('seattle1'),('seattle206'),('seaways'),('seaweed'),('seaweed1'),('seawolf'),('seaworld'),('seb'),('seb123'),('seba'),('seba123'),('sebas'),('sebas1'),('sebas123'),('sebast'),('sebastia'),('sebastian'),('sebastian.'),('sebastian0'),('sebastian1'),('sebastian106'),('sebastian12'),('sebastian123'),('sebastian2'),('sebastian3'),('sebastian5'),('sebastian7'),('sebastian8'),('sebastian9'),('sebastiano'),('sebastiao'),('sebastien'),('sebastien1'),('sebring'),('sebring1'),('sec'),('seccion33'),('second'),('second1'),('second2'),('secret'),('secret!'),('secret.'),('secret0'),('secret00'),('secret007'),('secret01'),('secret08'),('secret1'),('secret10'),('secret101'),('secret11'),('secret12'),('secret123'),('secret1234'),('secret13'),('secret2'),('secret21'),('secret22'),('secret23'),('secret24'),('secret3'),('secret4'),('secret5'),('secret6'),('secret666'),('secret69'),('secret7'),('secret77'),('secret99'),('secreta'),('secretaria'),('secretary'),('secreto'),('secreto1'),('secretos'),('secrets'),('secrets1'),('section'),('section1'),('section8'),('sector'),('sector9'),('secure'),('secure1'),('secured'),('securite'),('security'),('security1'),('sedona'),('sedona1'),('seduction'),('seductive'),('see'),('see123'),('seedorf'),('seedsnipe'),('seekbang1'),('seeker'),('seeker1'),('seeking'),('seema'),('seesaw'),('seetha'),('seether'),('seether1'),('seeyou'),('sefa1986'),('segovia'),('segredo'),('segreta'),('segreto'),('segun'),('segun1'),('segundo'),('segura'),('segura88'),('seguridad'),('seguro'),('sehnsucht'),('seifer'),('seigneur'),('seinfeld'),('seinfeld1'),('sekhar'),('sekolah'),('sekret'),('sektor'),('sel'),('selamanya'),('selamat'),('selassie'),('selassie1'),('select'),('select1'),('selena'),('selena1'),('selena11'),('selena12'),('selena123'),('selena13'),('selena2'),('selenagome'),('selenagomez'),('selene'),('selene1'),('selfish'),('selfish1'),('selfmade'),('selfmade1'),('selim2010'),('selina'),('selina1'),('seller'),('selma'),('selma1'),('selmer'),('selvaggia'),('selvam'),('sem'),('semaj'),('semaj1'),('semangat'),('semarang'),('sembarang'),('sembilan'),('semen'),('semenov'),('semenova'),('semeolvido'),('semina-alina'),('seminole'),('seminole1'),('seminoles'),('seminoles1'),('semper'),('semperf1'),('semperfi'),('semperfi1'),('sempre'),('sempron'),('sempurna'),('semsem'),('semsenha'),('sen'),('senate'),('senator'),('senator1'),('senators'),('sender'),('seneca'),('seneca1'),('senegal'),('senegal1'),('senerity'),('senha'),('senha1'),('senha123'),('senhas'),('senhasenha'),('senior'),('senior04'),('senior05'),('senior06'),('senior07'),('senior08'),('senior09'),('senior1'),('senior10'),('senior11'),('senior12'),('senior2008'),('senior2009'),('senior2010'),('senior2011'),('seniors'),('seniors06'),('seniors07'),('seniors08'),('seniors09'),('seniseviyoru'),('seniseviyorum'),('senna'),('senna1'),('senorita'),('sensation'),('sensation1'),('sensei'),('sensei1'),('sensesfail'),('sensitive'),('sensizim'),('sensor'),('sensual'),('senthil'),('sentinel'),('sentnece'),('sentra'),('sentry'),('senveben'),('seo123'),('seo12345'),('seo123456'),('seo21SAAfd23'),('seos1234'),('sep'),('sepatu'),('sephiroth'),('sephiroth1'),('sephiroth7'),('sephora'),('seppel'),('sept10'),('sept11'),('sept12'),('sept13'),('sept14'),('sept15'),('sept16'),('sept17'),('sept18'),('sept19'),('sept20'),('sept21'),('sept22'),('sept23'),('sept24'),('sept25'),('sept26'),('sept27'),('sept28'),('sept29'),('sept30'),('septembe'),('september'),('september0'),('september1'),('september11'),('september12'),('september13'),('september2'),('september21'),('september22'),('september23'),('september3'),('september4'),('september5'),('september6'),('september7'),('september8'),('september9'),('septembre'),('septembrie'),('septiembre'),('sepultura'),('sepultura1'),('sequoia'),('sequoia1'),('ser'),('ser123'),('ser12345'),('ser123456'),('serafim'),('serafima'),('serafin'),('serafina'),('serafina14'),('serafino'),('seraph'),('seraphim'),('serash2240'),('serban24'),('serbia'),('sercan'),('serdar'),('serdce'),('serduszko'),('serebro'),('sereda'),('serega'),('serega-cash'),('serega1'),('serega123'),('serega777'),('seregakalygin'),('serega_torov'),('seregjvich'),('sereja'),('serena'),('serena1'),('serena12'),('serenade'),('serendipit'),('serendipity'),('serene'),('serenella'),('serenity'),('serenity1'),('serenity12'),('serenity2'),('serenity3'),('serenity7'),('sereno'),('serfeliz'),('serg'),('serg-ks.87'),('serg-niki20'),('serg.aleg'),('serg123'),('sergan11'),('sergant'),('sergdock'),('serge'),('sergeant'),('sergeev'),('sergeev2212'),('sergeeva'),('sergeevna'),('sergeevna_10.10.91'),('sergei'),('sergei1986inna'),('sergei_man9'),('sergej'),('sergej_de_sad'),('sergent'),('sergey'),('sergey-ivanov'),('sergey-personal'),('sergey.lushnikoff'),('sergey.melnik-1996'),('sergey1'),('sergey123'),('sergey_brrr24'),('sergik'),('serginho'),('sergio'),('sergio-emperior'),('sergio.b93'),('sergio01'),('sergio1'),('sergio10'),('sergio11'),('sergio12'),('sergio123'),('sergio13'),('sergio2'),('sergiu'),('sergserg'),('serhat'),('serial'),('series'),('serikpaevna_92'),('serina'),('serious'),('serious1'),('seriously'),('serj-gr1966'),('serkan'),('seronoser'),('serova2008'),('serpa7'),('serpent'),('serpent1'),('serpente'),('serpico'),('serpiente'),('serrano'),('serrano1'),('serser'),('serseri'),('serval'),('servant'),('servant1'),('server'),('server1'),('server123'),('service'),('service1'),('service45'),('services'),('servis'),('servus'),('ser_kuzmin'),('sesame'),('sesame1'),('sesamo'),('sesese'),('sesshomaru'),('sesshoumaru'),('session'),('sesso'),('sestra'),('setembro'),('seth'),('seth12'),('seth123'),('setiawan'),('setsuna'),('settembre'),('setter'),('setting'),('settings'),('settle'),('seun20'),('sevastopol'),('seven'),('seven07'),('seven1'),('seven11'),('seven7'),('seven77'),('seven777'),('sevendust'),('sevenfold'),('sevenof9'),('sevens'),('sevens7'),('sevenseven'),('seventeen'),('seventeen1'),('seventeen17'),('seventy'),('seventy7'),('sevenup'),('severin'),('severina'),('severine'),('severino'),('severus'),('sevgeyq9v7kor'),('sevgilim'),('sevilla'),('sevilla1'),('sevillafc'),('seville'),('seviyorum'),('sewewf'),('sewing'),('sex'),('sex101'),('sex111'),('sex123'),('sex1234'),('sex12345'),('sex123456'),('sex247'),('sex4life'),('sex4me'),('sex666'),('sex69'),('sex6969'),('sex777'),('sexbomb'),('sexbomb1'),('sexboy'),('sexe'),('sexesexe'),('sexgod'),('sexgod1'),('sexi'),('sexi101'),('sexi12'),('sexi123'),('sexie1'),('sexiest'),('sexiest1'),('sexii'),('sexii1'),('sexii12'),('sexii123'),('sexisfun'),('sexisgood'),('sexisgood1'),('sexkitten'),('sexkitten1'),('sexlover'),('sexmachine'),('sexman'),('sexme'),('sexme1'),('sexme69'),('sexmeup'),('sexo'),('sexo123'),('sexo69'),('sexonthebeach'),('sexosexo'),('sexpistols'),('sexpot'),('sexsex'),('sexsex1'),('sexsex123'),('sexsex69'),('sexsexsex'),('sexsexsex1'),('sexton'),('sextoy'),('sextrime1'),('sexual'),('sexual1'),('sexual69'),('sexx'),('sexxi1'),('sexxx'),('sexxxx'),('sexxxy'),('sexxxy1'),('sexxy'),('sexxy1'),('sexxy6'),('sexy'),('sexy!!'),('sexy#1'),('sexy00'),('sexy007'),('sexy01'),('sexy02'),('sexy03'),('sexy04'),('sexy05'),('sexy06'),('sexy07'),('sexy08'),('sexy09'),('sexy1'),('sexy10'),('sexy100'),('sexy101'),('sexy11'),('sexy111'),('sexy12'),('sexy123'),('sexy1234'),('sexy12345'),('sexy123456'),('sexy13'),('sexy14'),('sexy15'),('sexy16'),('sexy17'),('sexy18'),('sexy19'),('sexy20'),('sexy2006'),('sexy2007'),('sexy2008'),('sexy2009'),('sexy2010'),('sexy21'),('sexy22'),('sexy23'),('sexy24'),('sexy25'),('sexy26'),('sexy27'),('sexy28'),('sexy29'),('sexy30'),('sexy31'),('sexy32'),('sexy321'),('sexy33'),('sexy34'),('sexy35'),('sexy36'),('sexy40'),('sexy420'),('sexy44'),('sexy45'),('sexy456'),('sexy4ever'),('sexy4life'),('sexy4u'),('sexy55'),('sexy56'),('sexy66'),('sexy666'),('sexy67'),('sexy69'),('sexy6969'),('sexy77'),('sexy777'),('sexy78'),('sexy86'),('sexy87'),('sexy88'),('sexy89'),('sexy90'),('sexy91'),('sexy911'),('sexy92'),('sexy93'),('sexy94'),('sexy95'),('sexy96'),('sexy99'),('sexyako'),('sexyangel'),('sexyangel1'),('sexyass'),('sexyass1'),('sexyb1'),('sexybabe'),('sexybabe1'),('sexybabe12'),('sexybaby'),('sexybaby1'),('sexybaby12'),('sexybaby2'),('sexyback'),('sexyback1'),('sexyback12'),('sexyback2'),('sexybeast'),('sexybeast!'),('sexybeast1'),('sexybeast2'),('sexybitch'),('sexybitch!'),('sexybitch0'),('sexybitch1'),('sexybitch2'),('sexybitch3'),('sexybitch4'),('sexybitch5'),('sexybitch6'),('sexybitch7'),('sexybitch9'),('sexyblack'),('sexyblack1'),('sexyblack2'),('sexyboi1'),('sexyboo1'),('sexyboy'),('sexyboy1'),('sexyboy12'),('sexyboy123'),('sexyboy13'),('sexyboy2'),('sexybum'),('sexycani'),('sexycani1'),('sexychick'),('sexychick1'),('sexydiva'),('sexydiva1'),('sexyeyes'),('sexygal'),('sexygirl'),('sexygirl!'),('sexygirl01'),('sexygirl09'),('sexygirl1'),('sexygirl10'),('sexygirl11'),('sexygirl12'),('sexygirl13'),('sexygirl14'),('sexygirl15'),('sexygirl16'),('sexygirl2'),('sexygirl23'),('sexygirl3'),('sexygirl5'),('sexygirl69'),('sexygirl7'),('sexygirl9'),('sexygirls'),('sexygirls1'),('sexygurl'),('sexygurl1'),('sexygurl12'),('sexygurl2'),('sexyguy'),('sexyguy1'),('sexylady'),('sexylady1'),('sexylady12'),('sexylady2'),('sexylegs'),('sexylexy'),('sexylove'),('sexylove1'),('sexylove12'),('sexylove2'),('sexyma'),('sexyma1'),('sexymama'),('sexymama!'),('sexymama1'),('sexymama10'),('sexymama11'),('sexymama12'),('sexymama13'),('sexymama2'),('sexymama3'),('sexymama69'),('sexymami1'),('sexymamma1'),('sexyman'),('sexyman1'),('sexyman123'),('sexyman2'),('sexyme'),('sexyme1'),('sexyme123'),('sexyme2'),('sexymom'),('sexymom1'),('sexymomma'),('sexymomma1'),('sexyness'),('sexyness1'),('sexyone'),('sexyone1'),('sexyred'),('sexyred1'),('sexysexy'),('sexysexy1'),('sexyt1'),('sexythang'),('sexythang1'),('sexything'),('sexything1'),('sexytime'),('sexytime1'),('sexytime69'),('sexy_julija'),('seychelles'),('seymour'),('seymour1'),('SEyxE44hca'),('seznam'),('sf49ers'),('sfasdfsdfa'),('sfgiants'),('Sfring31'),('sg'),('sgdHhfC4x2'),('sgga'),('sgtrsgh'),('sgydvntep'),('sh'),('sh0pping'),('sh0rty'),('sh1234'),('sh123456'),('sh1thead'),('sha'),('sha123'),('sha22una'),('shaaba'),('shabana'),('shabba'),('shabba1'),('shabbir'),('shabby'),('shabnam'),('shad0w'),('shaddy'),('shade'),('shade1'),('shade45'),('shades'),('shadi'),('shadmoss'),('shadmoss1'),('shadow'),('shadow!'),('shadow.'),('shadow0'),('shadow00'),('shadow007'),('shadow01'),('shadow02'),('shadow0262'),('shadow03'),('shadow04'),('shadow05'),('shadow06'),('shadow07'),('shadow08'),('shadow09'),('shadow1'),('shadow10'),('shadow101'),('shadow11'),('shadow12'),('shadow123'),('shadow1234'),('shadow13'),('shadow14'),('shadow15'),('shadow16'),('shadow17'),('shadow18'),('shadow19'),('shadow2'),('shadow20'),('shadow21'),('shadow22'),('shadow23'),('shadow24'),('shadow25'),('shadow26'),('shadow27'),('shadow28'),('shadow3'),('shadow32'),('shadow33'),('shadow4'),('shadow420'),('shadow44'),('shadow45'),('shadow5'),('shadow55'),('shadow6'),('shadow66'),('shadow666'),('shadow69'),('shadow7'),('shadow77'),('shadow777'),('shadow8'),('shadow87'),('shadow88'),('shadow89'),('shadow9'),('shadow90'),('shadow91'),('shadow92'),('shadow93'),('shadow94'),('shadow95'),('shadow98'),('shadow99'),('shadowcat'),('shadowfax'),('shadowman'),('shadowman1'),('shadows'),('shadows1'),('shadrach'),('shady'),('shady1'),('shady123'),('shafiq'),('shaggy'),('shaggy1'),('shaggy12'),('shaggy123'),('shaggy2'),('shaggy2dop'),('shaggy69'),('shagufta'),('shah'),('shah123'),('shahbaz'),('shaheen'),('shahid'),('shahida'),('shahin'),('shahnaz'),('shahrukh'),('shahrukhkhan'),('shahzad'),('shaikh'),('shaila'),('shailendra'),('shailesh'),('shaina'),('shaina1'),('shaine'),('shaira'),('shaka'),('shaka1'),('shakademous'),('shakal'),('shake'),('shake1'),('shakeel'),('shakeit'),('shakeit1'),('shaker'),('shaker1'),('shakes'),('shakespear'),('shakespeare'),('shakey'),('shakey1'),('shakila'),('shakir'),('shakira'),('shakira1'),('shakira123'),('shakmakovataisiya1992'),('shakthi'),('shakti'),('shakuntala'),('shakur'),('shakur1'),('shalimar'),('shalini'),('shalom'),('shalom1'),('shalom123'),('shalom7'),('sham123'),('sham69'),('shaman'),('shaman1'),('shamanking'),('shamar'),('shamar1'),('shambala'),('shameless'),('shameless1'),('shamil'),('shamim'),('shammi'),('shammy'),('shampoo'),('shampoo1'),('shamrock'),('shamrock1'),('shamus'),('shamus1'),('shan'),('shan123'),('shana'),('shana1'),('shana123'),('shanae'),('shanae1'),('shanda'),('shanda1'),('shandy'),('shandy1'),('shane'),('shane01'),('shane1'),('shane11'),('shane12'),('shane123'),('shane13'),('shane2'),('shane22'),('shane3'),('shane69'),('shane7'),('shanel'),('shanell1'),('shanelle'),('shaner'),('shanes'),('shaney'),('shaney14'),('shanghai'),('shanghai1'),('shangrila'),('shania'),('shania1'),('shanice'),('shanice1'),('shanika'),('shaniqua'),('shaniya1'),('shankar'),('shanker'),('shanks'),('shanky'),('shann0n'),('shanna'),('shanna1'),('shannara'),('shannen'),('shannon'),('shannon!'),('shannon01'),('shannon1'),('shannon10'),('shannon11'),('shannon12'),('shannon123'),('shannon13'),('shannon2'),('shannon21'),('shannon22'),('shannon3'),('shannon4'),('shannon5'),('shannon6'),('shannon69'),('shannon7'),('shannon8'),('shannon9'),('shanny'),('shanny1'),('shanon'),('shanshan'),('shanta'),('shanta1'),('shantanu'),('shante'),('shante1'),('shantel'),('shantel1'),('shantell'),('shantell1'),('shanthi'),('shanti'),('shanti1'),('shanty'),('shaolin'),('shaolin1'),('shaq32'),('shaq34'),('shaquille'),('shaquille1'),('shaquillesecx10'),('shar-vin'),('sharad'),('sharada'),('sharan'),('sharapova'),('sharda'),('share'),('shareaza'),('sharif'),('sharik'),('sharingan'),('sharingan1'),('shark'),('shark1'),('shark123'),('sharkbait'),('sharkboy'),('sharkey'),('sharks'),('sharks1'),('sharky'),('sharky1'),('sharlene'),('sharma'),('sharma123'),('sharmaine'),('sharmaine005foskett6071988'),('sharmila'),('sharon'),('sharon01'),('sharon1'),('sharon11'),('sharon12'),('sharon123'),('sharon2'),('sharona'),('sharp'),('sharp1'),('sharpay'),('sharpe'),('sharpei'),('sharpie'),('sharpie1'),('sharron'),('shasha'),('shasha1'),('shasha123'),('shashank'),('shashi'),('shasta'),('shasta1'),('shaun'),('shaun1'),('shaun123'),('shauna'),('shauna1'),('shaved'),('shavon1'),('shawn'),('shawn01'),('shawn1'),('shawn11'),('shawn12'),('shawn123'),('shawn13'),('shawn2'),('shawn21'),('shawn22'),('shawn23'),('shawn3'),('shawn69'),('shawna'),('shawna1'),('shawnee'),('shawnee1'),('shawshank'),('shawty'),('shawty1'),('shawty10'),('shawty12'),('shawty123'),('shawty13'),('shawty2'),('shay'),('shay11'),('shay12'),('shay123'),('shay13'),('shay14'),('shay15'),('shay16'),('shayan'),('shayla'),('shayla1'),('shaylee'),('shayna'),('shayna1'),('shayne'),('shayne1'),('shayne123'),('shayshay'),('shayshay1'),('shayshay12'),('shazam'),('shazam1'),('shazia'),('she'),('she123'),('shea'),('shea019bernabei1992'),('shearer'),('shearer1'),('shearer9'),('shearwater'),('sheba'),('sheba1'),('sheba123'),('sheba2'),('sheba417yorck1986vxm7'),('sheckler'),('sheckler1'),('shedevil'),('sheeba'),('sheeba1'),('sheela'),('sheena'),('sheena1'),('sheep'),('sheep1'),('sheep123'),('sheepdog'),('sheeps'),('sheepy'),('sheetal'),('sheffield'),('sheffield1'),('sheikh'),('sheila'),('sheila1'),('sheila123'),('shekhar'),('shekinah'),('shelbie'),('shelbie1'),('shelby'),('shelby!'),('shelby01'),('shelby06'),('shelby07'),('shelby08'),('shelby1'),('shelby10'),('shelby11'),('shelby12'),('shelby123'),('shelby13'),('shelby14'),('shelby15'),('shelby2'),('shelby22'),('shelby3'),('shelby4'),('shelby5'),('shelby500'),('shelby67'),('shelby69'),('shelby7'),('shelby8'),('shelby99'),('shelbygt500'),('sheldon'),('sheldon1'),('shelia'),('shelia1'),('shell'),('shell1'),('shell123'),('shella'),('shelley'),('shelley1'),('shellie'),('shellie1'),('shells'),('shelly'),('shelly1'),('shelly12'),('shelly123'),('shelly2'),('shelter'),('shelter1'),('sheltie'),('shelton'),('shelton1'),('shemale'),('shemale1'),('shenlong'),('shenmue'),('shepard'),('shepard1'),('shepherd'),('shepherd1'),('sheppard'),('sheraton'),('sherbert'),('sherbert1'),('sheree'),('sheree1'),('shereen'),('sheridan'),('sheridan1'),('sherif'),('sheriff'),('sheriff1'),('sherin'),('sherlock'),('sherlock1'),('sherly'),('sherlyn'),('sherman'),('sherman1'),('sherpa'),('sherri'),('sherri1'),('sherrie'),('sherrie1'),('sherry'),('sherry1'),('sherry123'),('sherwin'),('sherwin1'),('sherwood'),('sherwood1'),('sheryl'),('sheryl1'),('sherzod'),('sheshe'),('sheshe1'),('shesthe1'),('shetland'),('sheva7'),('shevchenko'),('shevcov_alesha'),('sheyla'),('shi'),('shianne'),('shianne1'),('shibby'),('shibby1'),('shiela'),('shield'),('shields'),('shift'),('shift1'),('shifty'),('shifty1'),('shikamaru'),('shikamaru1'),('shikha'),('shilard'),('shilo1'),('shiloh'),('shiloh1'),('shilpa'),('shilpi'),('shimano'),('shimmer'),('shimmer1'),('shimmy'),('shimmy1'),('shinchan'),('shine'),('shine1'),('shine123'),('shinedown'),('shinedown1'),('shinee'),('shiner'),('shiner1'),('shines'),('shingo'),('shinhwa'),('shinichi'),('shinigami'),('shinigami1'),('shining'),('shiningeagle'),('shinji'),('shinobi'),('shinobi1'),('shinoda'),('shinoda1'),('shinta'),('shipping'),('shippo'),('shippo1'),('shippuden'),('shippuden1'),('shippuuden'),('shipra'),('shirankova42'),('shiraz'),('shireen'),('shirin'),('shirley'),('shirley1'),('shirshov.1968'),('shisha'),('shishi'),('shishmarev76'),('shit'),('shit11'),('shit12'),('shit123'),('shit1234'),('shit13'),('shit22'),('shit666'),('shit69'),('shital'),('shitass'),('shitass1'),('shitbag'),('shitbag1'),('shitface'),('shitface1'),('shitface2'),('shitfuck'),('shitfuck1'),('shithappen'),('shithappens'),('shithead'),('shithead!'),('shithead1'),('shithead12'),('shithead2'),('shithead3'),('shithead69'),('shithole'),('shithole1'),('shitshit'),('shitshit1'),('shitter'),('shitter1'),('shitty'),('shitty1'),('shiva'),('shiva1'),('shiva123'),('shivaji'),('shivam'),('shivan'),('shivangi'),('shivani'),('shivbaba'),('shiver'),('shivers'),('shivji'),('shiznit'),('shiznit1'),('shiznits'),('shizzle'),('shizzle1'),('shkola'),('shmily'),('sho'),('shoaib'),('shobha'),('shock'),('shocker'),('shocker1'),('shockwave'),('shodan'),('shoe'),('shoebox'),('shoelace'),('shoelace1'),('shoes'),('shoes1'),('shoes123'),('shoes2'),('shogun'),('shogun1'),('shokolad'),('shokoladka'),('shona'),('shonda'),('shonda1'),('shoot'),('shoot1'),('shooter'),('shooter1'),('shooters'),('shooting'),('shootingstar'),('shop'),('shop123'),('shopaholic'),('shopgirl'),('shopper'),('shopper1'),('shopping'),('shopping!'),('shopping1'),('shopping12'),('shopping2'),('short'),('short1'),('shortcake'),('shortcake1'),('shortie'),('shortie1'),('shorts'),('shortstop'),('shortstop1'),('shortstuff'),('shorty'),('shorty!'),('shorty#1'),('shorty.'),('shorty01'),('shorty06'),('shorty07'),('shorty08'),('shorty09'),('shorty1'),('shorty10'),('shorty101'),('shorty11'),('shorty12'),('shorty123'),('shorty1234'),('shorty13'),('shorty14'),('shorty15'),('shorty16'),('shorty17'),('shorty18'),('shorty19'),('shorty2'),('shorty20'),('shorty21'),('shorty22'),('shorty23'),('shorty24'),('shorty25'),('shorty3'),('shorty4'),('shorty5'),('shorty6'),('shorty69'),('shorty7'),('shorty77'),('shorty8'),('shorty88'),('shorty9'),('shortys'),('shortys1'),('shosho'),('shotgun'),('shotgun1'),('shotgun12'),('shotgun2'),('shotokan'),('shotokan1'),('shotta'),('shotta1'),('shovel'),('shovelhead'),('show'),('showbiz'),('showdown'),('shower'),('shower1'),('showme'),('showme1'),('showmethemoney'),('showtime'),('showtime1'),('shponka35'),('shraddha'),('shradha'),('shravani'),('shredder'),('shredder1'),('shree'),('shree420'),('shreeganesh'),('shreeji'),('shreeram'),('shrek'),('shrek1'),('shrek123'),('shrek2'),('shrek3'),('shrestha'),('shreya'),('shreyas'),('shriganesh'),('shrikant'),('shrikrishna'),('shrimp'),('shrimp1'),('shrink'),('shriram'),('shroom'),('shrooms'),('shrooms1'),('shruthi'),('shruti'),('shubha'),('shubham'),('shubhangi'),('shuffle'),('shuffle1'),('shuhrat007'),('shukla'),('shukshinasveta'),('shukurova-ismigu'),('shumaher'),('shumaila'),('shunia0505'),('shurik'),('shuriken'),('shushu'),('shutdown'),('shutter'),('shuttle'),('shutup'),('shutup!'),('shutup1'),('shutup12'),('shutup123'),('shutup2'),('shweta'),('shy123'),('shyamala'),('shyann'),('shyann1'),('shyanne'),('shyanne1'),('shygirl'),('shygirl1'),('shyguy'),('shyshy'),('shyshy1'),('sh_o_a_2013'),('sialkot'),('siamese'),('sibelius'),('siberia'),('siberian'),('sibiryak5'),('sicherheit'),('sicilia'),('siciliano'),('sicily'),('sick'),('sickboy'),('sickness'),('sickness1'),('sid'),('sid123'),('siddhant'),('siddharth'),('siddhartha'),('siddhi'),('siddhu'),('siddiqui'),('sidekick'),('sidekick08'),('sidekick1'),('sidekick2'),('sidekick3'),('sideshow'),('sidewalk'),('sideways'),('sidewinder'),('sidharth'),('sidney'),('sidney1'),('sidney12'),('sidonie'),('sidorenko'),('sidorov'),('sidorova'),('sidorow64'),('sidorval'),('sie'),('sieben'),('sieben7'),('siegfried'),('siegheil'),('siegheil88'),('siemens'),('siemens1'),('siemens123'),('siempre'),('siempre1'),('sienna'),('sienna1'),('sierra'),('sierra01'),('sierra1'),('sierra10'),('sierra11'),('sierra117'),('sierra12'),('sierra123'),('sierra13'),('sierra2'),('sierra3'),('sierra5'),('sierra7'),('sierra99'),('siesta'),('siete7'),('sieuwaprd'),('sig53num'),('sigaretta'),('sigma'),('sigma1'),('sigmachi'),('sigmund'),('signal'),('signature'),('signin'),('signup'),('signup1'),('sigora79'),('sigreic'),('sigrid'),('siiifonjiknalivai'),('sikander'),('sil'),('silakova.nadezhda.2012'),('silantyi1987'),('silas'),('silenakriv'),('silence'),('silence1'),('silencer'),('silencio'),('silent'),('silent1'),('silent13'),('silenthill'),('silentium'),('silicon'),('silk'),('silkroad'),('silky1'),('silly'),('silly1'),('silly12'),('silly123'),('silly2'),('sillybilly'),('sillygirl'),('sillygirl1'),('sillygoose'),('sillyme'),('silmaril'),('silva'),('silva1'),('silva123'),('silvana'),('silvana1'),('silvano'),('silver'),('silver!'),('silver00'),('silver01'),('silver1'),('silver10'),('silver11'),('silver12'),('silver123'),('silver13'),('silver14'),('silver16'),('silver17'),('silver18'),('silver2'),('silver21'),('silver22'),('silver23'),('silver24'),('silver25'),('silver3'),('silver33'),('silver4'),('silver5'),('silver6'),('silver69'),('silver7'),('silver77'),('silver8'),('silver88'),('silver9'),('silver99'),('silverado'),('silverado1'),('silverado2'),('silverback'),('silverchair'),('silverfish'),('silverfox'),('silverfox1'),('silverio'),('silverkey3'),('silvermoon'),('silverstar'),('silverstone'),('silversurfer'),('silverwolf'),('silvester'),('silvestre'),('silvestro'),('silvia'),('silvia1'),('silvia123'),('silvietta'),('silvina'),('silvio'),('silviu'),('sim'),('sim123'),('simakov_evg'),('simba'),('simba01'),('simba1'),('simba11'),('simba12'),('simba123'),('simba2'),('simba7'),('simbacat'),('simbad'),('simbas'),('simcity'),('simcity4'),('simens'),('simeon'),('simmons'),('simmons1'),('simo'),('simon'),('simon01'),('simon1'),('simon11'),('simon12'),('simon123'),('simon13'),('simon2'),('simon3'),('simon7'),('simona'),('simona1'),('simone'),('simone01'),('simone1'),('simone11'),('simone12'),('simone123'),('simone2'),('simonetta'),('simonka'),('simonoff-dj'),('simonona'),('simonova5570'),('simonova_lyudmila_73'),('simonovskiy1970'),('simons'),('simonsays'),('simorodok62'),('simple'),('simple01'),('simple1'),('simple11'),('simple12'),('simple123'),('simple2'),('simple23'),('simple7'),('simplegirl'),('simpleman'),('simpleplan'),('simplicity'),('simply'),('simply1'),('simplyme'),('simpson'),('simpson1'),('simpsons'),('simpsons1'),('simpsons12'),('simpsons2'),('simran'),('sims'),('sims123'),('sims2'),('simsalabim'),('simsim'),('simson'),('sin'),('sin-gulya'),('sin1_19'),('sin666'),('sinaloa'),('sinaloa1'),('sinaloa13'),('sinatra'),('sinatra1'),('sinbad'),('sinbad1'),('sincere'),('sincere1'),('sincity'),('sincity1'),('sinclair'),('sinclair1'),('sindhu'),('sinead'),('sinead1'),('sinful'),('sing'),('sing12'),('sing123'),('singapore'),('singapore1'),('singapur'),('singel'),('singer'),('singer1'),('singer12'),('singer123'),('singer2'),('singh'),('singh1'),('singh123'),('singhisking'),('singing'),('singing1'),('single'),('single!'),('single01'),('single07'),('single08'),('single09'),('single1'),('single10'),('single101'),('single11'),('single12'),('single123'),('single13'),('single14'),('single15'),('single16'),('single18'),('single2'),('single2010'),('single21'),('single22'),('single23'),('single3'),('single4'),('single5'),('single69'),('single7'),('singleagain'),('singlelady'),('singlelife'),('singlemom'),('singles'),('singleton'),('singsing'),('singsong'),('sinister'),('sinister1'),('sinned'),('sinner'),('sinner1'),('sinsin'),('sinterklaas'),('siobhan'),('siobhan1'),('siopao'),('siouxsie'),('sipfhair'),('sir'),('siracusa'),('sirazhdinov.shamil'),('sirena'),('sirene'),('sirenita'),('sirik010875'),('sirisha'),('sirius'),('sirius1'),('sirocco'),('sis'),('sisi'),('sisisi'),('sissi'),('sissie'),('sissy'),('sissy1'),('sissy12'),('sissy123'),('sissy2'),('sistem'),('sistema'),('sistemas'),('sister'),('sister1'),('sister11'),('sister12'),('sister123'),('sister2'),('sister3'),('sister4'),('sister5'),('sisters'),('sisters1'),('sisters2'),('sisters3'),('sisters4'),('sitaram'),('sithlord'),('sithlord1'),('siva'),('sivakumar'),('sivas58'),('sivasiva'),('sivenkovklin'),('six666'),('six6six'),('sixela'),('sixers'),('sixers1'),('sixers3'),('sixflags'),('sixflags1'),('sixkids'),('sixpack'),('sixpack1'),('sixsix'),('sixsix1'),('sixsix6'),('sixsixsix'),('sixteen'),('sixteen1'),('sixteen16'),('sixty'),('sixty9'),('sixtynine'),('sixtynine6'),('sizzla'),('sizzle'),('sizzle1'),('sj811212'),('SjiecJ1A9X'),('sk'),('sk1234'),('sk123456'),('sk8123'),('sk84ever'),('sk84life'),('sk8board'),('sk8er'),('sk8er1'),('sk8er4life'),('sk8erboi'),('sk8erboy'),('sk8erdude'),('sk8ergirl'),('sk8ers'),('sk8forlife'),('sk8ing'),('sk8mafia'),('sk8ordie'),('sk8r4life'),('sk8sk8'),('sk8ter'),('sk8ter1'),('sk8terboi'),('sk8terboy'),('sk8tergirl'),('ska'),('ska02ska'),('ska123'),('skadden'),('skank'),('skank1'),('skank123'),('skanky1'),('skaska'),('skate'),('skate!'),('skate.'),('skate01'),('skate08'),('skate1'),('skate10'),('skate101'),('skate11'),('skate12'),('skate123'),('skate1234'),('skate13'),('skate14'),('skate15'),('skate2'),('skate21'),('skate22'),('skate23'),('skate3'),('skate4'),('skate420'),('skate4ever'),('skate4life'),('skate5'),('skate6'),('skate666'),('skate69'),('skate7'),('skate8'),('skate88'),('skate9'),('skateboard'),('skateboard1'),('skateboarding'),('skateordie'),('skater'),('skater!'),('skater.'),('skater01'),('skater09'),('skater1'),('skater10'),('skater101'),('skater11'),('skater12'),('skater123'),('skater1234'),('skater13'),('skater14'),('skater15'),('skater16'),('skater17'),('skater18'),('skater2'),('skater21'),('skater22'),('skater23'),('skater24'),('skater3'),('skater32'),('skater4'),('skater4lif'),('skater5'),('skater6'),('skater69'),('skater7'),('skater8'),('skater88'),('skater9'),('skater99'),('skaterboy'),('skaterboy1'),('skaterboy2'),('skaterdude'),('skaters'),('skaters1'),('skates'),('skates1'),('skating'),('skating1'),('skazka'),('skeet'),('skeet1'),('skeeter'),('skeeter1'),('skeeter2'),('skeleton'),('skeleton1'),('skeletor'),('Skelitor66'),('skeptron'),('sketch'),('sketch1'),('ski'),('ski123'),('skibum'),('skidoo'),('skidoo1'),('skidrow'),('skidrow1'),('SKIFFY'),('skiing'),('skiing1'),('skikda'),('skillet'),('skillet1'),('skills'),('skills1'),('skills12'),('skillz'),('skillz1'),('skin'),('skincare'),('skinhead'),('skinhead1'),('skinhead69'),('skinhead88'),('skinner'),('skinner1'),('skinny'),('skinny1'),('skins1'),('skip'),('skipper'),('skipper1'),('skipper123'),('skipper2'),('skippy'),('skippy01'),('skippy1'),('skippy11'),('skippy12'),('skippy123'),('skippy2'),('skittle'),('skittle1'),('skittles'),('skittles!'),('skittles1'),('skittles10'),('skittles11'),('skittles12'),('skittles13'),('skittles14'),('skittles2'),('skittles3'),('skittles4'),('skittles5'),('skittles69'),('skittles7'),('skittlez1'),('skizzo'),('skoal1'),('skoda'),('skolko'),('skooter'),('skooter1'),('skopje'),('skorpio'),('skorpion'),('skorpion1'),('skorpions23.5'),('skrillex'),('skrip-natalya'),('skripka'),('skull'),('skull1'),('skull123'),('skullcandy'),('skulls'),('skulls1'),('skully'),('skumar'),('skunk'),('skunk1'),('skunk2'),('skunky'),('sky'),('sky123'),('skyblue'),('skyblue1'),('skydive'),('skydive1'),('skydiver'),('skye'),('skyfire'),('skyhawk'),('skyhigh'),('skyking'),('skylar'),('skylar1'),('skylark'),('skylark1'),('skyler'),('skyler1'),('skyler12'),('skyler123'),('skyler2'),('skylight'),('skyline'),('skyline1'),('skyline12'),('skyline123'),('skyline2'),('skyline3'),('skyline34'),('skyline7'),('skylinegtr'),('skyliner'),('skyliner33'),('skyliner34'),('skynet'),('skynyrd'),('skyrim'),('skysky'),('skywalker'),('skywalker1'),('sl1pkn0t'),('sl1pknot'),('sla'),('slacker'),('slacker1'),('sladkaya'),('slainte'),('slalom'),('slam1984'),('slamdunk'),('slamdunk1'),('slammer'),('slammer1'),('slankers'),('slapnuts'),('slapper'),('slappy'),('slappy1'),('slapshock'),('slapshot'),('slapshot1'),('slaptasis'),('slash'),('slash1'),('slash123'),('slasher'),('slasher1'),('slastenka93'),('slater'),('slater1'),('slaughter'),('slaughter1'),('slava'),('slava-45'),('slava.grinco'),('slava1'),('slava123'),('slava_kulbidyuk'),('slave'),('slave1'),('slavia'),('slavik'),('slavik200887'),('slavka'),('slawek'),('slayer'),('slayer!'),('slayer01'),('slayer1'),('slayer11'),('slayer12'),('slayer123'),('slayer13'),('slayer2'),('slayer6'),('slayer66'),('slayer666'),('slayer69'),('slayer7'),('slayers'),('slbenfica'),('sledge'),('sleep'),('sleep1'),('sleeper'),('sleeper1'),('sleeping'),('sleeping1'),('sleepy'),('sleepy1'),('sleepy13'),('slick'),('slick1'),('slick123'),('slick50'),('slickrick'),('slickrick1'),('slider'),('slider1'),('sliders'),('slideshow'),('slifer'),('slim'),('slim12'),('slim123'),('slim1970'),('slime'),('slimer'),('slimjim'),('slimjim1'),('slimshady'),('slimshady1'),('slimthug1'),('slingshot'),('slinky'),('slinky1'),('slipchenko2004'),('slipkn0t'),('slipknot'),('slipknot!'),('slipknot.'),('slipknot0'),('slipknot01'),('slipknot1'),('slipknot10'),('slipknot11'),('slipknot12'),('slipknot123'),('slipknot13'),('slipknot14'),('slipknot2'),('slipknot21'),('slipknot22'),('slipknot3'),('slipknot4'),('slipknot5'),('slipknot6'),('slipknot66'),('slipknot666'),('slipknot69'),('slipknot7'),('slipknot8'),('slipknot9'),('slipper'),('slipper1'),('slippers'),('slippers1'),('slippery'),('slippery1'),('slippy'),('sliver'),('sliver1'),('slk230'),('slniecko'),('sloane'),('sloboda'),('slobodan'),('sloeber'),('slonce'),('sloneczko'),('sloneczko1'),('slonenok1009'),('slonik'),('slonko'),('sloppy'),('slovakia'),('slovan'),('slovenija'),('slovensko'),('slowhand'),('slowpoke'),('slugger'),('slugger1'),('sluggo'),('slunce'),('slunicko'),('slurpee'),('slurpee1'),('slut'),('slut101'),('slut12'),('slut123'),('slut69'),('slutbag1'),('slutface1'),('sluts'),('sluts1'),('slutty'),('slutty1'),('slyfox'),('slytherin'),('sm.karat'),('sm0key'),('sm1234'),('sm123456'),('smack'),('smack1'),('smackdown'),('smackdown1'),('smackdown2'),('smackthat1'),('smail.ru'),('smail2u'),('small'),('small1'),('smallboy'),('smallfry'),('smalll'),('smalls'),('smalls1'),('smallville'),('smart'),('smart1'),('smart123'),('smartass'),('smartass1'),('smartboy'),('smartest1'),('smartgirl'),('smartguy'),('smartie'),('smartie1'),('smarties'),('smarties1'),('smartone'),('smarts'),('smarty'),('smarty1'),('smash'),('smash1'),('smasher'),('smashing'),('smashing1'),('Smb0512bz'),('smeagol'),('smeghead'),('smeghead1'),('smegma'),('smelly'),('smelly1'),('smelly123'),('smellycat'),('smellycat1'),('smetana'),('smi'),('smile'),('smile!'),('smile.'),('smile01'),('smile07'),('smile08'),('smile09'),('smile0_0'),('smile1'),('smile10'),('smile101'),('smile11'),('smile12'),('smile123'),('smile1234'),('smile13'),('smile14'),('smile2'),('smile21'),('smile22'),('smile23'),('smile24'),('smile3'),('smile4'),('smile4ever'),('smile4me'),('smile4u'),('smile5'),('smile6'),('smile69'),('smile7'),('smile8'),('smile9'),('smile99'),('smilee'),('smiler'),('smiles'),('smiles!'),('smiles1'),('smiles12'),('smiles123'),('smiles2'),('smiles4u'),('smilesmile'),('smiley'),('smiley!'),('smiley01'),('smiley1'),('smiley10'),('smiley101'),('smiley11'),('smiley12'),('smiley123'),('smiley13'),('smiley14'),('smiley2'),('smiley22'),('smiley23'),('smiley3'),('smiley5'),('smiley69'),('smiley7'),('smileyface'),('smiling'),('smiling1'),('smilla'),('smirl'),('smirnoff'),('smirnoff1'),('smirnov'),('smirnova'),('smith'),('smith1'),('smith12'),('smith123'),('smith2'),('smith22'),('smith89'),('smitha'),('smithers'),('smiths'),('smithy'),('smiti1'),('smitty'),('smitty1'),('smo'),('smoke'),('smoke1'),('smoke12'),('smoke123'),('smoke14'),('smoke2'),('smoke20'),('smoke420'),('smokepot'),('smoker'),('smoker1'),('smoker420'),('smokes'),('smokes1'),('smokeweed'),('smokeweed1'),('smokeweed4'),('smokey'),('smokey!'),('smokey01'),('smokey07'),('smokey08'),('smokey09'),('smokey1'),('smokey10'),('smokey101'),('smokey11'),('smokey12'),('smokey123'),('smokey13'),('smokey14'),('smokey15'),('smokey16'),('smokey2'),('smokey21'),('smokey22'),('smokey23'),('smokey3'),('smokey4'),('smokey420'),('smokey5'),('smokey6'),('smokey69'),('smokey7'),('smokey77'),('smokey8'),('smokey88'),('smokey99'),('smokeyjoe'),('smokie'),('smokie1'),('smokin'),('smokin1'),('smokin420'),('smoking'),('smoking1'),('smoky'),('smoky1'),('smolensk'),('smooch'),('smooch1'),('smooches'),('smooches1'),('smoochie'),('smoochie1'),('smooth'),('smooth1'),('smoothie'),('smoothie1'),('smoove1'),('smores'),('smother'),('smriti'),('sms123'),('smudge'),('smudge1'),('smudge123'),('smukke'),('smulan'),('smurf'),('smurf1'),('smurfette'),('smurfs'),('smurfy'),('sn00py'),('sn0wball'),('sn0wman'),('sn1ckers'),('snacks'),('snails'),('snaiper'),('snake'),('snake1'),('snake12'),('snake123'),('snake13'),('snake2'),('snake3'),('snake7'),('snakebite'),('snakeeyes'),('snakeman'),('snakes'),('snakes1'),('snapon'),('snapon1'),('snapper'),('snapper1'),('snapple'),('snapple1'),('snappy'),('snappy1'),('snapshot'),('snatch'),('snatch1'),('sneaker'),('sneaker1'),('sneakers'),('sneakers1'),('sneaky'),('sneaky1'),('sneha'),('snehal'),('snicker'),('snicker1'),('snickers'),('snickers!'),('snickers01'),('snickers1'),('snickers11'),('snickers12'),('snickers13'),('snickers2'),('snickers22'),('snickers3'),('snickers4'),('snickers5'),('snickers7'),('snicket'),('sniffer'),('sniffles'),('sniffy'),('snikers'),('sniper'),('sniper01'),('sniper1'),('sniper11'),('sniper12'),('sniper123'),('sniper13'),('sniper2'),('sniper69'),('snipes'),('snipper'),('snitch'),('snitch1'),('snivanie'),('sno'),('snoogans'),('snook1'),('snooker'),('snooker1'),('snooker147'),('snookie'),('snookie1'),('snooks'),('snookums'),('snooky'),('snoop'),('snoop1'),('snoop123'),('snoop2'),('snoopdog'),('snoopdog1'),('snoopdogg'),('snoopdogg1'),('snooper'),('snoops'),('snoopy'),('snoopy!'),('snoopy.'),('snoopy01'),('snoopy07'),('snoopy08'),('snoopy09'),('snoopy1'),('snoopy10'),('snoopy101'),('snoopy11'),('snoopy12'),('snoopy123'),('snoopy13'),('snoopy14'),('snoopy15'),('snoopy16'),('snoopy17'),('snoopy2'),('snoopy21'),('snoopy22'),('snoopy23'),('snoopy24'),('snoopy25'),('snoopy3'),('snoopy4'),('snoopy5'),('snoopy6'),('snoopy69'),('snoopy7'),('snoopy77'),('snoopy8'),('snoopy88'),('snoopy9'),('snoopy99'),('snooze'),('snoppy'),('snoppy1'),('snorre98'),('snow'),('snow11'),('snow12'),('snow123'),('snow1234'),('snow22'),('snowangel'),('snowball'),('snowball1'),('snowball11'),('snowball12'),('snowball2'),('snowball3'),('snowball7'),('snowbell'),('snowbird'),('snowbird1'),('snowboard'),('snowboard1'),('snowboard2'),('snowboarding'),('snowbunny'),('snowbunny1'),('snowdog'),('snowdrop'),('snowey'),('snowfall'),('snowflake'),('snowflake1'),('snowflake2'),('snowflake3'),('snowflakes'),('snowhite'),('snowie'),('snowing'),('snowman'),('snowman1'),('snowman12'),('snowman123'),('snowman2'),('snowman3'),('snowman7'),('snowshoe'),('snowsnow'),('snowstorm'),('snowwhite'),('snowwhite1'),('snowy'),('snowy1'),('snowy123'),('snuffles'),('snuffy'),('snuffy1'),('snuggle'),('snuggle1'),('snuggles'),('snuggles1'),('snuggles2'),('snyder'),('so'),('soap'),('soares'),('sobaka'),('sober1'),('sober3'),('soboleva'),('sobriety'),('soc'),('socal1'),('socc3r'),('soccer'),('soccer!'),('soccer#1'),('soccer.'),('soccer0'),('soccer00'),('soccer01'),('soccer02'),('soccer03'),('soccer04'),('soccer05'),('soccer06'),('soccer07'),('soccer08'),('soccer09'),('soccer1'),('soccer10'),('soccer100'),('soccer101'),('soccer11'),('soccer12'),('soccer123'),('soccer1234'),('soccer13'),('soccer14'),('soccer15'),('soccer16'),('soccer17'),('soccer18'),('soccer19'),('soccer2'),('soccer20'),('soccer2010'),('soccer21'),('soccer22'),('soccer23'),('soccer24'),('soccer25'),('soccer26'),('soccer27'),('soccer28'),('soccer29'),('soccer3'),('soccer30'),('soccer31'),('soccer32'),('soccer33'),('soccer34'),('soccer35'),('soccer4'),('soccer44'),('soccer45'),('soccer4lif'),('soccer5'),('soccer55'),('soccer56'),('soccer6'),('soccer66'),('soccer69'),('soccer7'),('soccer77'),('soccer8'),('soccer87'),('soccer88'),('soccer89'),('soccer9'),('soccer90'),('soccer91'),('soccer92'),('soccer93'),('soccer94'),('soccer95'),('soccer96'),('soccer97'),('soccer98'),('soccer99'),('soccerball'),('soccerboy'),('soccerboy1'),('soccergirl'),('soccerman1'),('soccermom'),('soccermom1'),('soccerstar'),('sochi2014'),('social'),('social1'),('social12'),('social123'),('socialbook'),('socialwork'),('society'),('sociology'),('socks'),('socks1'),('socks123'),('socom'),('socom1'),('socom2'),('socom3'),('socool'),('socool1'),('socorro'),('socorro1'),('socrate'),('socrates'),('socrates1'),('socute'),('soda'),('soda123'),('sodapop'),('sodapop1'),('sodikov.talat'),('sodiq1'),('sodium'),('sodomie'),('soeusei'),('sofia'),('sofia1'),('sofia12'),('sofia123'),('sofiane'),('sofias'),('sofie'),('sofie1'),('sofija'),('sofiya'),('sofly1'),('sofresh1'),('softail'),('softail1'),('softball'),('softball!'),('softball.'),('softball00'),('softball01'),('softball02'),('softball03'),('softball05'),('softball06'),('softball07'),('softball08'),('softball09'),('softball1'),('softball10'),('softball11'),('softball12'),('softball13'),('softball14'),('softball15'),('softball16'),('softball17'),('softball18'),('softball19'),('softball2'),('softball20'),('softball21'),('softball22'),('softball23'),('softball24'),('softball25'),('softball27'),('softball3'),('softball32'),('softball33'),('softball4'),('softball44'),('softball5'),('softball6'),('softball7'),('softball8'),('softball9'),('softball99'),('softtail'),('software'),('software1'),('sofya.kulikova.87'),('sogevigdil1981'),('sohail'),('soinlove'),('Sojdlg123aljg'),('sokol'),('sokolik'),('sokolov'),('sokolova'),('sokrates'),('sol'),('sol123'),('solace'),('solana'),('solange'),('solange1'),('solano'),('solar'),('solar1'),('solara'),('solare'),('solaris'),('solaris1'),('solcito'),('soldado'),('soldat'),('soldier'),('soldier1'),('soldier2'),('soldiers'),('sole'),('solecito'),('soledad'),('soledad1'),('soleil'),('soleil1'),('soleil12'),('soleil123'),('soleil13'),('soleluna'),('solene'),('solid'),('solid1'),('solidsnake'),('solidus'),('solidworks'),('solita'),('solitaire'),('solitaria'),('solitario'),('solitario1'),('solito'),('solitude'),('solnce'),('solnishko'),('solnyshko'),('solnze'),('solo'),('solo123'),('solo7590'),('soloio'),('solomaha-denis'),('soloman'),('soloman1'),('solomon'),('solomon1'),('solomon123'),('solosolo'),('solotime'),('solotu'),('soloveibormalei'),('solovey'),('soloyo'),('soloyo1'),('solrac'),('solsol'),('solstice'),('soltera'),('soltero'),('solution'),('solution1'),('solutions'),('solutions1'),('solveig'),('solyluna'),('som'),('somalia'),('Somanypickles27'),('sombra'),('sombrero'),('somebody'),('somebody1'),('someday'),('someday1'),('someone'),('someone1'),('somerset'),('somerset1'),('something'),('something1'),('something2'),('sometime'),('sometimes'),('sometimes1'),('somewhere'),('somierda'),('sommar'),('sommer'),('sommer07'),('sommer08'),('sommer09'),('sommer1'),('sommer123'),('son'),('son123'),('sona'),('sonali'),('sonata'),('sondra'),('sone4ko'),('sonechka'),('sonechko'),('song'),('songbird'),('songbird1'),('songohan'),('songoku'),('songoku1'),('songs'),('songs1'),('sonia'),('sonia-91'),('sonia1'),('sonia12'),('sonia123'),('sonic'),('sonic1'),('sonic10'),('sonic11'),('sonic12'),('sonic123'),('sonic13'),('sonic2'),('sonic3'),('sonic5'),('sonic7'),('sonicboom'),('sonics'),('sonics1'),('sonicx'),('sonicx1'),('sonika'),('soniya'),('sonja'),('sonja1'),('sonne'),('sonne1'),('sonne123'),('sonnen'),('sonnenblume'),('sonnensche'),('sonnenschein'),('sonnie'),('sonny'),('sonny1'),('sonny12'),('sonny123'),('sonny2'),('sonnyboy'),('sonnyboy1'),('sonofabitch'),('sonofgod'),('sonoio'),('sonoma'),('sonoma1'),('sonora'),('sonora1'),('sonrisa'),('sonshine'),('sonson'),('sonson1'),('sonu'),('sonu123'),('sonu1234'),('sonumonu'),('sonusonu'),('sony'),('sony11'),('sony12'),('sony123'),('sony1234'),('sonya'),('sonya1'),('sonya200102'),('sonyericson'),('sonyericss'),('sonyericsson'),('sonysony'),('sonyvaio'),('sonyvaio1'),('sookie'),('sooner'),('sooner1'),('sooners'),('sooners1'),('sooty'),('sooty1'),('sooty123'),('sop'),('sophia'),('sophia01'),('sophia07'),('sophia08'),('sophia1'),('sophia10'),('sophia11'),('sophia12'),('sophia123'),('sophia13'),('sophia2'),('sophia3'),('sophie'),('sophie!'),('sophie01'),('sophie05'),('sophie06'),('sophie07'),('sophie08'),('sophie09'),('sophie1'),('sophie10'),('sophie11'),('sophie12'),('sophie123'),('sophie13'),('sophie14'),('sophie15'),('sophie2'),('sophie21'),('sophie22'),('sophie23'),('sophie3'),('sophie4'),('sophie5'),('sophie6'),('sophie7'),('sophie99'),('sophieytorf'),('sopli22'),('soprano'),('soprano1'),('sopranos'),('sopranos1'),('sor1989'),('sora12'),('sora123'),('soraya'),('soraya1'),('sorcerer'),('sorciere'),('sorella'),('sorellina'),('sorento'),('soriano'),('sorina'),('soroka'),('sorokin'),('sorokina'),('sorokina-999-01'),('sorokina7778'),('sorpresa'),('sorrento'),('sorriso'),('sorrow'),('sorrow1'),('sorry'),('sorry1'),('sorry123'),('sos'),('sos123'),('sosa21'),('sosexy'),('sosexy1'),('sosiska'),('soso'),('soso123'),('Soso123aljg'),('sosodef'),('sososo'),('sosososo'),('sossina'),('sossos'),('sosweet'),('sou'),('soufeliz'),('soufiane'),('soukaina'),('soukayna'),('soul'),('souleater'),('soulfly'),('soulfly1'),('soulfood'),('soulja'),('soulja1'),('souljaboy'),('souljaboy1'),('souljaboy2'),('soulman'),('soulmate'),('soulmate1'),('soulmates'),('soulreaver'),('soumia'),('soumya'),('sound'),('sound1'),('sounds'),('soundwave'),('soup'),('sourav'),('source'),('source1'),('sourire'),('souris'),('sousou'),('south'),('south1'),('south12'),('south123'),('south13'),('south2'),('south3'),('southafrica'),('southampton'),('southeast'),('southeast1'),('southend'),('southend1'),('southern'),('southern1'),('southgate'),('southpark'),('southpark1'),('southpark2'),('southpaw'),('southpole'),('southpole1'),('southpole2'),('southport'),('southsid3'),('southside'),('southside0'),('southside1'),('southside13'),('southside2'),('southside3'),('southside4'),('southside5'),('southside6'),('southside7'),('southside8'),('southside9'),('southwest'),('southwest1'),('souvenir'),('sov1_86'),('sovereign'),('soviet'),('sovin.sv'),('sowhat'),('sowhat1'),('sowjanya'),('sowmya'),('soyelmejor'),('soyfeliz'),('soylamejor'),('soyma.ivan'),('sp'),('sp.zakaz'),('sp00ky'),('sp0ngeb0b'),('sp1der'),('sp1derman'),('spa'),('space'),('space01'),('space1'),('space11'),('space12'),('space123'),('space1999'),('space2'),('space3'),('space4me'),('space5'),('spaceball1'),('spaceballs'),('spacebar'),('spacejam'),('spaceman'),('spaceman1'),('spacemy1'),('spacer'),('spaces'),('spaces1'),('spaceship'),('spaceship1'),('spacey'),('spacey1'),('spade1'),('spades'),('spades1'),('spagetti'),('spaghetti'),('spaghetti1'),('spagna'),('spain'),('spain1'),('spalding'),('spalding1'),('spam'),('spam123'),('spamar33'),('spammer'),('spamspam'),('spania'),('spaniel'),('spanien'),('spanish'),('spanish1'),('spanish2'),('spank'),('spank1'),('spanking'),('spankme'),('spankme1'),('spanky'),('spanky01'),('spanky1'),('spanky11'),('spanky12'),('spanky123'),('spanky13'),('spanky2'),('spanky69'),('spanky7'),('spanner'),('spanner1'),('sparco'),('sparda'),('sparhawk'),('spark'),('spark1'),('sparkey'),('sparkey1'),('sparkie'),('sparkie1'),('sparkle'),('sparkle1'),('sparkle123'),('sparkle2'),('sparkles'),('sparkles1'),('sparkplug'),('sparks'),('sparks1'),('sparky'),('sparky!'),('sparky01'),('sparky1'),('sparky10'),('sparky101'),('sparky11'),('sparky12'),('sparky123'),('sparky13'),('sparky2'),('sparky22'),('sparky23'),('sparky3'),('sparky5'),('sparky69'),('sparky7'),('sparky99'),('sparrow'),('sparrow1'),('sparrows'),('sparta'),('sparta1'),('spartacus'),('spartacus1'),('spartak'),('spartak1'),('spartak1922'),('spartan'),('spartan1'),('spartan117'),('spartan2'),('spartan300'),('spartan7'),('spartans'),('spartans1'),('sparten117'),('sparticus'),('sparty'),('spawn'),('spawn1'),('spawn123'),('spawn666'),('spe'),('speak2me'),('speaker'),('speaker1'),('speakers'),('speakers1'),('speakes'),('spears'),('spears1'),('special'),('special1'),('special123'),('special2'),('speciala'),('specialist'),('specialized'),('specialk'),('specialk1'),('speckles'),('specnaz'),('spection'),('spectra'),('spectre'),('spectrum'),('spectrum1'),('speech'),('speed'),('speed1'),('speed12'),('speed123'),('speed2'),('speeder'),('speedo'),('speedo1'),('speedracer'),('speeds'),('speedster'),('speedtouch'),('speedway'),('speedway1'),('speedy'),('speedy01'),('speedy1'),('speedy11'),('speedy12'),('speedy123'),('speedy13'),('speedy2'),('speedy3'),('speedy7'),('spellbound'),('spelling'),('spence'),('spence1'),('spencer'),('spencer!'),('spencer01'),('spencer1'),('spencer11'),('spencer12'),('spencer123'),('spencer13'),('spencer2'),('spencer3'),('spencer4'),('spencer5'),('spencer7'),('spenser'),('speranta'),('speranza'),('sperma'),('SPEz3012'),('sphere'),('sphinx'),('spi'),('spice'),('spice1'),('spice333'),('spicegirls'),('spicer'),('spices'),('spicey'),('spicey1'),('spicy'),('spicy1'),('spider'),('spider!'),('spider-man'),('spider01'),('spider1'),('spider10'),('spider11'),('spider12'),('spider123'),('spider13'),('spider2'),('spider21'),('spider22'),('spider23'),('spider3'),('spider4'),('spider5'),('spider6'),('spider69'),('spider7'),('spider8'),('spider99'),('spiderma'),('spiderman'),('spiderman!'),('spiderman.'),('spiderman0'),('spiderman1'),('spiderman12'),('spiderman123'),('spiderman2'),('spiderman3'),('spiderman4'),('spiderman5'),('spiderman6'),('spiderman7'),('spiderman8'),('spiderman9'),('spiderpig'),('spiderpig1'),('spiders'),('spiders1'),('spiderweb'),('spidey'),('spidey1'),('spiegel'),('spierdalaj'),('spiffy'),('spiffy1'),('spike'),('spike01'),('spike1'),('spike10'),('spike11'),('spike12'),('spike123'),('spike1234'),('spike13'),('spike2'),('spike22'),('spike3'),('spike5'),('spike69'),('spike7'),('spiker'),('spiker1'),('spikes'),('spikes1'),('spikey'),('spikey1'),('spillo'),('spinach'),('spinner'),('spinner1'),('spinning'),('spinoza'),('spionin8688'),('spiral'),('spiridonmarkin1982'),('spirit'),('spirit1'),('spirit12'),('spirit123'),('spirit2'),('spirit7'),('spirits'),('spiritual'),('spirou'),('spit'),('spitfire'),('spitfire1'),('spitsy16'),('splash'),('splash1'),('spleen'),('splender'),('splendid'),('splendor'),('spliff'),('spliff1'),('splinter'),('splinter1'),('splintercell'),('splodge'),('spn5'),('spo'),('spock'),('spock1'),('spoiled'),('spoiled1'),('spokane'),('spokane1'),('spolana'),('spongbob'),('spongbob1'),('sponge'),('sponge1'),('sponge12'),('sponge123'),('sponge2'),('spongebob'),('spongebob!'),('spongebob.'),('spongebob0'),('spongebob1'),('spongebob12'),('spongebob123'),('spongebob2'),('spongebob3'),('spongebob4'),('spongebob5'),('spongebob6'),('spongebob7'),('spongebob8'),('spongebob9'),('spongecola'),('spook'),('spook1'),('spookie'),('spookie1'),('spooks'),('spooky'),('spooky1'),('spooky12'),('spooky123'),('spooky13'),('spooky2'),('spoon'),('spoon1'),('spooner'),('spooner1'),('spoons'),('spoons1'),('sport'),('sport1'),('sport123'),('sportage'),('sporting'),('sporting1'),('sports'),('sports1'),('sports10'),('sports101'),('sports11'),('sports12'),('sports123'),('sports13'),('sports2'),('sports21'),('sports22'),('sports23'),('sports3'),('sports5'),('sports7'),('sportsman'),('sportsmen'),('sportster'),('sportster1'),('sporty'),('sporty1'),('sporu-netu'),('spot'),('spot123'),('spotlight'),('spotlight1'),('spots'),('spotty'),('spotty1'),('spread-hop'),('spring'),('spring01'),('spring06'),('spring07'),('spring08'),('spring09'),('spring1'),('spring10'),('spring11'),('spring12'),('spring123'),('spring2'),('spring938burston0001990'),('spring99'),('springbok'),('springer'),('springer1'),('springfield'),('springs'),('springsteen'),('springtime'),('sprinkle'),('sprinkles'),('sprinkles1'),('sprint'),('sprint01'),('sprint1'),('sprinter'),('sprinter1'),('sprite'),('sprite1'),('sprite12'),('sprite123'),('sprite2'),('sprocket'),('sprocket1'),('sprout'),('spruce'),('spud'),('spuddy'),('spunky'),('spunky1'),('spurs'),('spurs1'),('spurs123'),('spurs21'),('sputnik'),('sputnik1'),('spuvd'),('spy123'),('spyder'),('spyder1'),('sQ8Hm7l4'),('sqdwfe'),('squad1'),('squadup1'),('squall'),('squall1'),('squalo'),('square'),('square1'),('squash'),('squash1'),('squeak'),('squeak1'),('squeaker'),('squeaky'),('squeaky1'),('squeek'),('squeeze'),('squid'),('squid1'),('squire'),('squires'),('squirrel'),('squirrel1'),('squirt'),('squirt1'),('squirtle'),('squish'),('squishy'),('squishy1'),('sr20det'),('sraka105'),('sravani'),('sravanthi'),('srbija'),('srbija1'),('srcuqq1_2j1h3rbf'),('sredina-va'),('sreedevi'),('srh420'),('sridevi'),('sridhar'),('sriganesh'),('srikanth'),('srikrishna'),('srilanka'),('srilanka1'),('srilatha'),('srinivas'),('srinivasa'),('srinivasan'),('sriram'),('srirama'),('srisai'),('srisairam'),('srisri'),('srivastava'),('sruthi'),('ss'),('ss1234'),('ss12345'),('ss123456'),('ss23081937'),('ss563563ss'),('sS6z2sw6lU'),('ssj4goku'),('sslazio'),('sslazio1900'),('sss'),('sss-nastya-sss'),('sss111'),('sss123'),('sss333'),('sss777'),('sssaaa'),('ssss'),('sssss'),('sssss1'),('ssssss'),('ssssss1'),('sssssss'),('ssssssss'),('sssssssss'),('ssssssssss'),('ssssssssssss'),('sssuka80'),('ssyu1314'),('ss_1983'),('st'),('st.louis'),('st1234'),('st3v3n'),('Sta'),('sta93'),('stabilo'),('stacey'),('stacey1'),('stacey12'),('stacey123'),('staci'),('stacie'),('stacie1'),('stacks1'),('stacy'),('stacy1'),('stacy123'),('stadium'),('staff'),('Staff123'),('stafford'),('stafford1'),('stage1'),('staind'),('staind1'),('stainless'),('stairway'),('stakan'),('stalin'),('stalin1'),('stalingrad'),('stalker'),('stalker1'),('stalker123'),('stalker2'),('stalker_lemurrr'),('stallion'),('stallion1'),('stallone'),('stamford'),('stampede'),('stamper'),('stamps'),('stampy'),('stan'),('stan021092'),('standard'),('standard1'),('standart'),('standup'),('stanford'),('stanford1'),('stang'),('stang1'),('stanger'),('Stani06'),('stanislas'),('stanislav'),('stank1'),('stanley'),('stanley1'),('stanley123'),('stanley2'),('stanly'),('stanton'),('stanton1'),('staple'),('stapler'),('stapler1'),('staples'),('staples1'),('star'),('star00'),('star01'),('star02'),('star03'),('star05'),('star06'),('star07'),('star08'),('star09'),('star1'),('star10'),('star100'),('star101'),('star11'),('star12'),('star123'),('star1234'),('star12345'),('star13'),('star14'),('star15'),('star16'),('star17'),('star18'),('star19'),('star20'),('star2000'),('star2006'),('star2010'),('star21'),('star22'),('star23'),('star24'),('star25'),('star26'),('star27'),('star28'),('star33'),('star34'),('star44'),('star45'),('star55'),('star56'),('star66'),('star67'),('star69'),('star77'),('star777'),('star7827'),('star87'),('star88'),('star89'),('star92'),('star93'),('star94'),('star95'),('star99'),('starbaby'),('starboy'),('starbright'),('starbuck'),('starbuck1'),('starbucks'),('starbucks1'),('starbucks2'),('starburst'),('starburst1'),('starchild'),('starchild1'),('starcraft'),('starcraft1'),('starcraft2'),('stardoll'),('stardoll1'),('stardust'),('stardust1'),('staredobre'),('starfire'),('starfire1'),('starfish'),('starfish1'),('starfleet'),('starfox'),('starfox1'),('stargate'),('stargate1'),('stargatesg1'),('stargazer'),('stargazer1'),('stargirl'),('stargirl1'),('starkiller'),('starla'),('starla1'),('starlet'),('starlet1'),('starlight'),('starlight1'),('starlight2'),('starling'),('starlite'),('starlite1'),('starman'),('starman1'),('starmoon'),('starpozitiv'),('starr'),('starr1'),('starr123'),('starry'),('starry1'),('stars'),('stars!'),('stars1'),('stars11'),('stars12'),('stars123'),('stars13'),('stars2'),('stars3'),('stars4'),('stars5'),('stars7'),('starscream'),('starshine'),('starshine1'),('starship'),('starship1'),('starsky'),('starsky1'),('starss'),('starstar'),('starstar1'),('starstruck'),('start'),('start1'),('start12'),('start123'),('starter'),('starter1'),('startfinding'),('startrek'),('startrek1'),('starts'),('startup'),('starwar'),('starwar5'),('starwars'),('starwars!'),('starwars01'),('starwars03ja'),('starwars1'),('starwars10'),('starwars11'),('starwars111'),('starwars12'),('starwars123'),('starwars13'),('starwars2'),('starwars22'),('starwars3'),('starwars4'),('starwars5'),('starwars6'),('starwars7'),('starwars77'),('starwars9'),('starwarsfan10'),('starz'),('starz1'),('starz123'),('stas'),('stas.gorodissky'),('stas123'),('stasia'),('stasik'),('stason'),('stason16.92'),('stason729'),('stassenka'),('stasstas'),('stasya'),('stas_kolos'),('stas_the_best.ru'),('state'),('state1'),('states'),('static'),('static1'),('staticx'),('station'),('station1'),('station2'),('station3'),('statistics'),('Status'),('status1'),('stavr75'),('stavros'),('stayaway'),('staycool'),('stayfly1'),('stayoff1'),('stayout'),('stayout!'),('stayout1'),('staystrong'),('ste'),('ste123'),('steak1'),('stealth'),('stealth1'),('steam'),('steamboat'),('steamer'),('steaua'),('steaua1'),('stecova85'),('steel'),('steel1'),('steele'),('steele1'),('steeler'),('steeler1'),('steelers'),('steelers!'),('steelers#1'),('steelers01'),('steelers06'),('steelers07'),('steelers08'),('steelers09'),('steelers1'),('steelers10'),('steelers11'),('steelers12'),('steelers13'),('steelers2'),('steelers3'),('steelers36'),('steelers43'),('steelers5'),('steelers6'),('steelers7'),('steelers86'),('steelhead'),('steelhead1'),('steelman'),('steelseries'),('steeve'),('stef'),('stefan'),('stefan1'),('stefan12'),('stefan123'),('stefancelmare'),('Stefangreil1983'),('stefani'),('stefani1'),('stefania'),('stefania1'),('stefanie'),('stefanie1'),('stefano'),('stefano1'),('stefany'),('steffen'),('steffen1'),('steffi'),('steffi1'),('steffie'),('steffy'),('steflio3123'),('stefy'),('steinbock'),('steiner'),('steinway'),('stella'),('stella!'),('stella01'),('stella1'),('stella10'),('stella11'),('stella12'),('stella123'),('stella13'),('stella2'),('stella22'),('stella354926'),('stellar'),('stellar1'),('stellina'),('step'),('stepa-2009'),('stepan'),('stepanov'),('stepanov.ag'),('stepanova'),('stepanov_georgij'),('stepashka'),('steph'),('steph01'),('steph1'),('steph11'),('steph12'),('steph123'),('steph13'),('steph14'),('steph15'),('steph2'),('steph21'),('steph22'),('steph23'),('steph3'),('steph69'),('stephan'),('stephan1'),('stephane'),('stephane1'),('stephani'),('stephanie'),('stephanie!'),('stephanie.'),('stephanie0'),('stephanie1'),('stephanie2'),('stephanie3'),('stephanie4'),('stephanie5'),('stephanie6'),('stephanie7'),('stephanie8'),('stephanie9'),('stephany'),('stephany1'),('stephen'),('stephen1'),('stephen11'),('stephen12'),('stephen123'),('stephen2'),('stephen3'),('stephen7'),('stephens'),('stephie'),('stephie1'),('stephon'),('stephon1'),('stephy'),('stephy1'),('stepup'),('stepup1'),('stepup2'),('stereo'),('stereo1'),('sterling'),('sterling1'),('stern'),('stern1'),('sternchen'),('sternchen1'),('sterne'),('steroids'),('sterva'),('stetson'),('stetson1'),('steve'),('steve-o'),('steve0'),('steve01'),('steve1'),('steve11'),('steve12'),('steve123'),('steve13'),('steve2'),('steve22'),('steve3'),('steve5'),('steve69'),('steve7'),('steven'),('steven!'),('steven.'),('steven01'),('steven06'),('steven07'),('steven08'),('steven09'),('steven1'),('steven10'),('steven11'),('steven12'),('steven123'),('steven1234'),('steven13'),('steven14'),('steven15'),('steven16'),('steven17'),('steven18'),('steven19'),('steven2'),('steven20'),('steven21'),('steven22'),('steven23'),('steven24'),('steven3'),('steven4'),('steven5'),('steven6'),('steven69'),('steven7'),('steven8'),('steven88'),('steven9'),('stevenash'),('stevenash1'),('stevens'),('stevens1'),('stevenson'),('stevenson1'),('steveo'),('steveo1'),('steves'),('stevevai'),('stevie'),('stevie1'),('stevo1'),('steward'),('stewart'),('stewart1'),('stewart14'),('stewart20'),('stewie'),('stewie1'),('stgeorge'),('stgiles'),('sti'),('sticazzi'),('stick'),('stick1'),('sticker'),('stickers'),('stickman'),('stickman1'),('sticks'),('sticks1'),('sticky'),('sticky1'),('stiffler'),('stiffy'),('stifler'),('stigmata'),('stiletto'),('still'),('stillwater'),('stimpy'),('stimpy1'),('sting'),('sting1'),('stinger'),('stinger1'),('stingray'),('stingray1'),('stink'),('stink1'),('stinker'),('stinker1'),('stinky'),('stinky01'),('stinky1'),('stinky12'),('stinky123'),('stinky2'),('stirling'),('stitch'),('stitch1'),('stitch626'),('stitches'),('stiven'),('stjohn'),('stjoseph'),('stjude'),('stlouis'),('stlouis1'),('stmarys'),('stming4'),('sto'),('stocazzo'),('stockholm'),('stockholm1'),('stocking'),('stockings'),('stocks'),('stockton'),('stockton1'),('stoffel'),('stokecity'),('stokecity1'),('stokes'),('stokrotka'),('stokrotka1'),('stolen'),('stolen1'),('stomatolog'),('stomper'),('stone'),('stone1'),('stone123'),('stone5'),('stonecold'),('stonecold1'),('stonecold3'),('stoned'),('stoned1'),('stoned420'),('stonehenge'),('stoner'),('stoner1'),('stoner420'),('stoner69'),('stones'),('stones1'),('stonewall'),('stonewall1'),('stoney'),('stoney1'),('stone_mitich'),('stooge'),('stooges'),('stoopid'),('stoopid1'),('stop'),('stop12'),('stop123'),('stopit'),('stopit1'),('storage'),('store'),('storm'),('storm1'),('storm11'),('storm12'),('storm123'),('storm2'),('stormdogs'),('stormers'),('stormie'),('stormie1'),('storms'),('stormy'),('stormy1'),('stormy12'),('stormy123'),('stormy2'),('stpaul'),('str'),('str8edge'),('straight'),('straight1'),('strand'),('strange'),('strange.lena'),('strange1'),('stranger'),('stranger1'),('strangle'),('strannik'),('strasbourg'),('strat'),('strat1'),('strategy'),('stratfor'),('stratford'),('strato'),('stratocast'),('stratocaster'),('stratos'),('stratovarius'),('stratton'),('stratus'),('stratus1'),('strauss'),('straw1'),('strawb3rry'),('strawberr1'),('strawberri'),('strawberries'),('strawberry'),('strawberry1'),('stream'),('street'),('street1'),('street12'),('street123'),('street2'),('streetball'),('streetfighter'),('streets'),('streets1'),('strega'),('strekoza'),('strekoza79'),('strela'),('strelec'),('strelka.m'),('strelok'),('strength'),('strength1'),('stress'),('stress1'),('stressed'),('stressed1'),('stretch'),('stretch1'),('strezhetova'),('strider'),('strider1'),('strife'),('strike'),('strike1'),('strike3'),('striker'),('striker1'),('strikers'),('string'),('stringer'),('strings'),('stripe'),('striper'),('striper1'),('stripes'),('stripes1'),('stripped'),('stripper'),('stripper1'),('strobe93'),('stroikarat'),('stroke'),('stroker'),('stroker1'),('strokes'),('strokes1'),('strong'),('strong1'),('strongbad'),('strongbow'),('strongbow1'),('stronger'),('stronger1'),('stronghold'),('strongman'),('stronza'),('stronzo'),('structure'),('struggle'),('strummer'),('struppi'),('stryker'),('stryker1'),('stryper'),('stsnatasha2008'),('stthomas'),('stu'),('stuart'),('stuart1'),('stubbs'),('stubby'),('stubby1'),('stud'),('student'),('student1'),('student12'),('student123'),('student2'),('studentka'),('students'),('studio'),('studio1'),('studio54'),('studioworks'),('studly'),('studly1'),('studman'),('studmuffin'),('study'),('stuff'),('stuff1'),('stuff123'),('stuffy'),('stumpy'),('stumpy1'),('stunna'),('stunna1'),('stunner'),('stunner1'),('stunt101'),('stuntman'),('stup1d'),('stupid'),('stupid!'),('stupid.'),('stupid0'),('stupid01'),('stupid1'),('stupid101'),('stupid11'),('stupid12'),('stupid123'),('stupid13'),('stupid2'),('stupid22'),('stupid3'),('stupid4'),('stupid5'),('stupid6'),('stupid69'),('stupid7'),('stupidass'),('stupidass1'),('stupidbitc'),('stupidgirl'),('stupido'),('stussy'),('stuttgart'),('stuttgart1'),('style'),('style1'),('styles'),('styles1'),('style_style'),('stylin1'),('stylist'),('stylist1'),('stylus'),('su123456'),('su224466'),('su4ik'),('suarez'),('suave1'),('sub'),('sub-zero'),('subaru'),('subaru1'),('subaru29'),('subaru555'),('subhanallah'),('subhash'),('sublime'),('sublime1'),('sublime2'),('sublime420'),('sublime69'),('sublime7'),('submarine'),('submarine1'),('submission'),('submit'),('submit123'),('subprodukty'),('subtitle'),('suburban'),('suburban1'),('subway'),('subway1'),('subwoofer'),('subwoofer1'),('subzero'),('subzero1'),('suc'),('succeed'),('succes'),('success'),('success!'),('success01'),('success08'),('success09'),('success1'),('success11'),('success12'),('success123'),('success2'),('success4me'),('success7'),('success8'),('successful'),('sucess'),('sucesso'),('sucette'),('suchitra'),('suchka'),('suck'),('suck123'),('suck1t'),('sucka1'),('suckadick1'),('suckdick'),('suckdick1'),('sucker'),('sucker1'),('sucker123'),('sucker2'),('suckers'),('suckers1'),('suckit'),('suckit!'),('suckit.'),('suckit1'),('suckit12'),('suckit123'),('suckit2'),('suckit3'),('suckit5'),('suckit69'),('suckme'),('suckme1'),('suckme2'),('suckme69'),('suckmyass69'),('suckmyballs'),('suckmycock'),('suckmydick'),('sucks'),('sucks1'),('sucram'),('sudarshan'),('sudden'),('sudha'),('sudhakar'),('sudhir'),('sudoku'),('sue'),('sue123'),('suerte'),('suesue'),('suffer'),('suffolk'),('suganya'),('sugar'),('sugar01'),('sugar1'),('sugar10'),('sugar11'),('sugar12'),('sugar123'),('sugar13'),('sugar2'),('sugar22'),('sugar3'),('sugar5'),('sugar69'),('sugar7'),('sugarbabe'),('sugarbaby'),('sugarbaby1'),('sugarbear'),('sugarbear1'),('sugarcane'),('sugardaddy'),('sugarfoot'),('sugarfree'),('sugarlips'),('sugarlips1'),('sugarpie'),('sugarpie1'),('sugarplum'),('sugarplum1'),('sugarray'),('sugars'),('sugars1'),('sugarsugar'),('suger1'),('sugipula'),('suhail'),('suhana'),('suhani'),('suhasini'),('suicidal'),('suicidal1'),('suicide'),('suicide1'),('suikoden'),('suisse'),('sujata'),('sujatha'),('suka'),('suka123'),('sukabumi'),('sukanya'),('sukasbliat'),('sukasuka'),('suki'),('sukisuki'),('sukkel'),('sukses'),('sulaiman'),('sulaimon'),('sulamifcherenchikova1979'),('suleiman'),('suleman'),('suleyman'),('sullivan'),('sullivan1'),('sully'),('sully1'),('sulochana'),('sultan'),('sultan1'),('sultana'),('sum'),('sum41'),('suman'),('suman123'),('sumathi'),('sumatra'),('sumeet'),('sumerki'),('sumit'),('sumitra'),('summ3r'),('summer'),('summer!'),('summer.'),('summer.fruit'),('summer00'),('summer01'),('summer02'),('summer03'),('summer04'),('summer05'),('summer06'),('summer07'),('summer08'),('summer09'),('summer1'),('summer10'),('summer101'),('summer11'),('summer12'),('summer123'),('summer1234'),('summer13'),('summer14'),('summer15'),('summer16'),('summer17'),('summer18'),('summer19'),('summer2'),('summer20'),('summer2005'),('summer2006'),('summer2007'),('summer2008'),('summer2009'),('summer2010'),('summer2011'),('summer2012'),('summer21'),('summer22'),('summer23'),('summer24'),('summer25'),('summer3'),('summer33'),('summer4'),('summer44'),('summer45'),('summer5'),('summer55'),('summer6'),('summer66'),('summer67'),('summer69'),('summer7'),('summer77'),('summer78'),('summer8'),('summer88'),('summer89'),('summer9'),('summer96'),('summer98'),('summer99'),('summerfun'),('summerland'),('summerlove'),('summerof69'),('summers'),('summers1'),('summertime'),('summit'),('summit1'),('summoner'),('sumner'),('sumsung'),('sun'),('sun123'),('sun1shine'),('sun2shine'),('sunanda'),('sunbeam'),('sunbird'),('sunburst'),('sundae'),('sundance'),('sundance1'),('sundar'),('sundaram'),('sundari'),('sunday'),('sunday1'),('sunday12'),('sunday123'),('sunday2'),('sunday7'),('sunder'),('sunderland'),('sundevil'),('sundin'),('sundin13'),('sundown'),('sundrop'),('sundrop1'),('sunfire'),('sunfire1'),('sunfish'),('sunflower'),('sunflower1'),('sunflower2'),('sunflower3'),('sunflower4'),('sunflower5'),('sunflower7'),('sunflower8'),('sunflowers'),('sungatullinad'),('sungelika86'),('sunglasses'),('sunil'),('sunil123'),('sunilkumar'),('sunita'),('sunitha'),('sunkanmi'),('sunkist'),('sunkist1'),('sunlight'),('sunlight1'),('sunmoon'),('sunnepa1'),('sunnie'),('sunnny56'),('sunny'),('sunny01'),('sunny1'),('sunny11'),('sunny12'),('sunny123'),('sunny1234'),('sunny13'),('sunny2'),('sunny3'),('sunny36'),('sunny5'),('sunny6'),('sunny7'),('sunnyboy'),('sunnyboy1'),('sunnyd'),('sunnyd1'),('sunnyday'),('sunnyday1'),('sunnydays'),('sunnyest'),('sunnys'),('sunnyside'),('sunnyside1'),('sunray'),('sunrise'),('sunrise1'),('suns13'),('sunset'),('sunset1'),('sunset12'),('sunset123'),('sunset2'),('sunset7'),('sunsh1n3'),('sunsh1ne'),('sunshin3'),('sunshine'),('sunshine!'),('sunshine.'),('sunshine0'),('sunshine00'),('sunshine01'),('sunshine02'),('sunshine05'),('sunshine06'),('sunshine07'),('sunshine08'),('sunshine09'),('sunshine1'),('sunshine10'),('sunshine11'),('sunshine12'),('sunshine123'),('sunshine13'),('sunshine14'),('sunshine15'),('sunshine16'),('sunshine17'),('sunshine18'),('sunshine19'),('sunshine2'),('sunshine20'),('sunshine21'),('sunshine22'),('sunshine23'),('sunshine24'),('sunshine25'),('sunshine26'),('sunshine27'),('sunshine28'),('sunshine29'),('sunshine3'),('sunshine30'),('sunshine32'),('sunshine33'),('sunshine4'),('sunshine44'),('sunshine45'),('sunshine5'),('sunshine55'),('sunshine6'),('sunshine66'),('sunshine69'),('sunshine7'),('sunshine77'),('sunshine8'),('sunshine87'),('sunshine88'),('sunshine89'),('sunshine9'),('sunshine99'),('sunstar'),('sunsun'),('suntan'),('sup'),('sup123'),('sup3rman'),('supa1906'),('super'),('super!'),('super007'),('super01'),('super1'),('super10'),('super100'),('super11'),('super12'),('super123'),('super1231'),('super1234'),('super13'),('super14'),('super15'),('super17'),('super2'),('super21'),('super22'),('super23'),('super3'),('super4'),('super5'),('super6'),('super69'),('super7'),('super8'),('super88'),('super9'),('super99'),('superb'),('superbad'),('superbad1'),('superbee'),('superbike'),('superbowl'),('superbowl1'),('superboy'),('superboy1'),('supercar'),('supercat'),('supercool'),('supercool1'),('supercross'),('superdave'),('superdog'),('superdog1'),('superdude'),('superdude1'),('superduper'),('superduty'),('superfly'),('superfly1'),('superfreak'),('supergirl'),('supergirl1'),('supergirl2'),('superhero'),('superhero1'),('superhuman'),('superior'),('superior1'),('superjunio'),('superjunior'),('superm'),('superman'),('superman!'),('superman.'),('superman0'),('superman00'),('superman01'),('superman06'),('superman07'),('superman08'),('superman09'),('superman1'),('superman10'),('superman11'),('superman12'),('superman123'),('superman13'),('superman14'),('superman15'),('superman16'),('superman17'),('superman18'),('superman19'),('superman2'),('superman20'),('superman21'),('superman22'),('superman23'),('superman24'),('superman25'),('superman26'),('superman27'),('superman28'),('superman3'),('superman30'),('superman32'),('superman33'),('superman34'),('superman4'),('superman45'),('superman5'),('superman55'),('superman6'),('superman69'),('superman7'),('superman77'),('superman78'),('superman8'),('superman87'),('superman88'),('superman89'),('superman9'),('superman99'),('SuperManBoy'),('supermann'),('supermario'),('supermax'),('supermen'),('supermodel'),('supermom'),('supermom1'),('supernatur'),('supernatural'),('supernova'),('supernova1'),('superpippo'),('superpower'),('superpuper'),('supers'),('supersexy'),('supersexy1'),('supersonic'),('supersport'),('superstar'),('superstar!'),('superstar0'),('superstar1'),('superstar2'),('superstar3'),('superstar4'),('superstar5'),('superstar6'),('superstar7'),('superstar8'),('superstar9'),('superstars'),('supersuper'),('supertramp'),('superuser'),('supervisor'),('supervista'),('superwoman'),('suplada'),('suppandi'),('supper'),('supply'),('support'),('support1'),('supported'),('supra'),('supra1'),('supreme'),('supreme1'),('supremo'),('supriya'),('sur'),('sur1313'),('surabaya'),('surabhi'),('surbhi'),('sure'),('sureboy'),('surekha'),('surena13'),('surendra'),('sureno'),('sureno1'),('sureno13'),('surenos13'),('surenox3'),('suresh'),('suresh123'),('sureshot'),('surethang'),('surf'),('surf12'),('surf123'),('surf4life'),('surface'),('surfboard'),('surfboard1'),('surfen'),('surfer'),('surfer1'),('surfer12'),('surfer123'),('surfer2'),('surfer69'),('surfergirl'),('surfin'),('surfing'),('surfing1'),('surfing123'),('surfing2'),('surfsup'),('surfsup1'),('surgeon'),('surgery'),('surgery1'),('suriname'),('surinder'),('surooo777'),('surprise'),('surprise1'),('surrender'),('surrender1'),('surrey'),('surround'),('surside13'),('survey'),('surveyor'),('survival'),('survive'),('survivor'),('survivor1'),('surx13'),('surya'),('sus'),('susan'),('susan1'),('susan123'),('susana'),('susana1'),('susanita'),('susann'),('susanna'),('susanna1'),('susannah'),('susanne'),('susanne1'),('sushant'),('sushi'),('sushi1'),('sushi123'),('sushil'),('sushila'),('sushma'),('sushmita'),('susi'),('susie'),('susie1'),('susie123'),('susieq'),('susieq1'),('suslik'),('susmita'),('suspect'),('SUSPECTS20'),('sussex'),('sutenm123456'),('sutherland'),('sutter'),('sutton'),('sutton1'),('suvarna'),('suzana'),('suzanna'),('suzanne'),('suzanne1'),('suzette'),('suzette1'),('suzie'),('suzie1'),('suzieq'),('suzuki'),('suzuki1'),('suzuki1000'),('suzuki123'),('suzuki125'),('suzuki250'),('suzuki600'),('suzuki750'),('suzy'),('svadba'),('sven'),('svenja'),('sverige'),('sverige1'),('sveta'),('sveta-kisil'),('sveta1'),('sveta123'),('svetasveta'),('svetik'),('svetik_kryuchkov'),('svetka'),('svetlana'),('svetlana-mironova-13'),('svetlana1'),('svetlana26rus'),('svetlana_07'),('svetlanka'),('sveto4ka'),('svetochka'),('svitlana'),('svoboda'),('svoloch'),('svoron1977'),('sw0rdf1sh'),('sw0rdfish'),('sw3434!'),('sw705547'),('swab123'),('swag'),('swag123'),('swagg1'),('swagg123'),('swagga'),('swagga1'),('swagger'),('swagger1'),('swallow'),('swallow1'),('swami'),('swamiji'),('swaminarayan'),('swamisamarth'),('swampfire'),('swamphen'),('swampy'),('swanlake'),('swanny'),('swansea'),('swansea1'),('swanson'),('swapna'),('swapnil'),('swarna'),('swastik'),('swastika'),('swat'),('swatch'),('swathi'),('swati'),('swe'),('swearer'),('sweater'),('swed420'),('sweden'),('sweden1'),('swedru'),('sweeet'),('sweeney'),('sweeney1'),('sweeper'),('sweet'),('sweet!'),('sweet01'),('sweet07'),('sweet08'),('sweet09'),('sweet1'),('sweet10'),('sweet101'),('sweet11'),('sweet12'),('sweet123'),('sweet1234'),('sweet13'),('sweet14'),('sweet15'),('sweet16'),('sweet17'),('sweet18'),('sweet19'),('sweet2'),('sweet20'),('sweet21'),('sweet22'),('sweet23'),('sweet24'),('sweet25'),('sweet3'),('sweet33'),('sweet4'),('sweet5'),('sweet6'),('sweet666'),('sweet69'),('sweet7'),('sweet77'),('sweet8'),('sweet88'),('sweet9'),('sweet90'),('sweet92'),('sweetangel'),('sweetass'),('sweetbaby'),('sweetbaby1'),('sweetboy'),('sweetcandy'),('sweetcheeks'),('sweetdream'),('sweetdreams'),('sweeter'),('sweetest'),('sweetgirl'),('sweetgirl1'),('sweethart'),('sweetheart'),('sweetheart1'),('sweethome'),('sweethoney'),('sweeti'),('sweetie'),('sweetie!'),('sweetie01'),('sweetie1'),('sweetie11'),('sweetie12'),('sweetie123'),('sweetie13'),('sweetie2'),('sweetie22'),('sweetie3'),('sweetie4'),('sweetie5'),('sweetie7'),('sweetie8'),('sweetiepie'),('sweeties'),('sweetlady'),('sweetlips'),('sweetlove'),('sweetlove1'),('sweetlover'),('sweetman'),('sweetmother'),('sweetness'),('sweetness1'),('sweetness2'),('sweetness3'),('sweetone'),('sweetp'),('sweetp1'),('sweetpea'),('sweetpea!'),('sweetpea1'),('sweetpea12'),('sweetpea2'),('sweetpea3'),('sweetpea7'),('sweetpie'),('sweets'),('sweets1'),('sweets12'),('sweets123'),('sweets2'),('sweetstuff'),('sweetsweet'),('sweett'),('sweettea'),('sweetthang'),('sweetthing'),('sweetu'),('sweetwater'),('sweety'),('sweety01'),('sweety1'),('sweety11'),('sweety12'),('sweety123'),('sweety13'),('sweety2'),('sweety22'),('sweety23'),('sweety3'),('sweety7'),('sweetypie'),('sweetypie1'),('swerty'),('swetha'),('swetik'),('swetlana'),('swift'),('swift1'),('swifty'),('swim'),('swim123'),('swimmer'),('swimmer1'),('swimmer2'),('swimming'),('swimming!'),('swimming1'),('swimming12'),('swimming2'),('swindon'),('swing'),('swinger'),('swinger1'),('swingers'),('swisher'),('swisher1'),('swiss'),('swiss1'),('switch'),('switch1'),('switchfoot'),('switzerland'),('swoosh'),('sword'),('sword1'),('sword123'),('swordfis'),('swordfish'),('swordfish1'),('swordfish2'),('swordfish7'),('swords'),('swords1'),('swordsman'),('sxUaIehAtp'),('syafiq'),('sybil'),('sycamore'),('sycamore1'),('sydnee'),('sydney'),('sydney!'),('sydney00'),('sydney01'),('sydney07'),('sydney08'),('sydney1'),('sydney10'),('sydney11'),('sydney12'),('sydney123'),('sydney13'),('sydney2'),('sydney2000'),('sydney22'),('sydney3'),('sydney7'),('sydney99'),('syl'),('sylvain'),('sylvan'),('sylvania'),('sylvester'),('sylvester1'),('sylvia'),('sylvia1'),('sylvie'),('sylwia'),('sylwia1'),('symantec'),('symbol'),('symmetry'),('symone'),('symone1'),('symphony'),('Sym_cskill1'),('synapse'),('syncmaster'),('syndicate'),('synergy'),('synergy1'),('synyster'),('synyster1'),('syracuse'),('syracuse1'),('sys'),('sys64738'),('sysadmin'),('system'),('system1'),('system12'),('system123'),('system2'),('system32'),('systemofadown'),('systems'),('SyyRRqBe70'),('syzygy'),('SZ9kQcCTwY'),('szczurek'),('szerelem'),('szeretlek'),('SZGd4eY287'),('szkola'),('szymon'),('szymon1'),('t'),('t-bone'),('t-mac1'),('t-money'),('t-pain'),('t090571'),('t11111'),('t111111'),('t12345'),('t123456'),('t1234567'),('t12345678'),('t123456789'),('t1ffany'),('t1gg3r'),('t1gger'),('t1nkerbell'),('t326598'),('t36473647'),('t4_Us3r'),('t55555'),('t5E1q9shfD'),('t5r4e3w2q1'),('t654321'),('t666666'),('T7U9Hx'),('t:'),('ta123456'),('tab'),('tab123'),('tabaco'),('tabaluga'),('tabasco'),('tabasco1'),('tabassum'),('tabata'),('tabatha'),('tabatha1'),('tabby'),('tabby1'),('tabby123'),('tabbycat'),('tabbycat1'),('tabitha'),('tabitha1'),('table'),('table1'),('tables'),('taburetka'),('tackle'),('taco'),('taco11'),('taco12'),('taco123'),('taco1234'),('tacobell'),('tacobell1'),('tacobell12'),('tacobell2'),('tacoma'),('tacoma1'),('tacos'),('tacos1'),('tacos123'),('tacotaco'),('tadashi'),('tadpole'),('tadpole1'),('tae123'),('taekwondo'),('taekwondo1'),('taetae'),('taetae1'),('tafadzwa'),('taffy'),('taffy1'),('taffy123'),('tagada'),('tagesgruppe2010'),('tagged'),('tagheuer'),('tahira'),('tahiti'),('tahlia'),('tahoe'),('tahoe1'),('taichi'),('tailor'),('taipan'),('taipei'),('taishan2011'),('taison'),('taitai'),('taiwan'),('tajmahal'),('tajudeen'),('takahiro'),('takamine'),('takamine1'),('takashi'),('takataka'),('takayuki'),('takecare'),('takeda'),('takedown'),('takeiteasy'),('takeme'),('taken1'),('takeover1'),('taker1'),('takeshi'),('takethat'),('takishima'),('takoyaki'),('taktak'),('takumi'),('takuya'),('tal'),('talavera'),('talbot'),('talent'),('talent1'),('talented'),('talented1'),('talgat'),('talia'),('talia1'),('taliban'),('taliesin'),('talisman'),('talita'),('talitha'),('talk2me'),('talking'),('talktome'),('taller'),('talleres'),('tallinn'),('tallman'),('tallulah'),('tallyho'),('talon'),('talon1'),('talula'),('tam'),('tam123'),('tamagotchi'),('tamahome'),('tamale'),('tamanna'),('tamara'),('tamara1'),('tamara12'),('tamara123'),('tamara2'),('tamarindo'),('tamayo'),('tambok'),('tambov'),('tamere'),('tamerlan'),('tami'),('tamia1'),('tamie'),('tamika'),('tamika1'),('tamila'),('tamilan'),('tamilnadu'),('tamiya'),('tammie'),('tammie1'),('tammy'),('tammy1'),('tammy12'),('tammy123'),('tammy2'),('tampa1'),('tampa813'),('tampabay'),('tampabay1'),('tampan'),('tampico'),('tampon'),('tampon1'),('tamriko0942'),('tamtam'),('tamtam1'),('tamuna'),('tan'),('tan123'),('tanaka'),('tandem'),('tane4ka'),('tanechka'),('tanga'),('tanger'),('tangerang'),('tangerine'),('tangerine1'),('tangina'),('tanginamo'),('tangkai'),('tangkay'),('tanglewood'),('tango'),('tango1'),('tango123'),('tango2'),('tangos'),('tangtang'),('tanguy'),('tania'),('tania1'),('tania123'),('tanika'),('tanisha'),('tanisha1'),('tanita'),('taniya'),('tanja'),('tanja1'),('Tanja1993'),('Tanjiang999'),('tank'),('tank12'),('tank123'),('tanker'),('tanker1'),('tankist'),('tanktank'),('tanman'),('tanmay'),('tanner'),('tanner01'),('tanner1'),('tanner10'),('tanner11'),('tanner12'),('tanner123'),('tanner13'),('tanner2'),('tanner22'),('tanner3'),('tanner4'),('tanner5'),('tanner7'),('tanning'),('tanning1'),('tantan'),('tantan1'),('tantra'),('tanuja'),('tanusha'),('tanushka'),('tanveer'),('tanya'),('tanya1'),('tanya12'),('tanya123'),('tanzania'),('tanzen'),('taobao887'),('taotao'),('tape'),('tapioca'),('tapout'),('tapout1'),('tapper'),('tar'),('tara'),('tara11'),('tara12'),('tara123'),('tara1234'),('tarakan'),('tarantado'),('tarantino'),('taranto'),('tarantul'),('tarantula'),('taras'),('tarasenko'),('tarasov'),('tarasova'),('taratara'),('taratata'),('tardis'),('tardis1'),('tarelka'),('target'),('target1'),('target123'),('tarheel'),('tarheel1'),('tarheels'),('tarheels1'),('tarheels23'),('tarifa'),('tarik-66'),('tarkan'),('tarnay1'),('tarpon'),('tarragon'),('tarragona'),('tartan'),('tartar'),('tartaruga'),('tartine'),('taruna'),('taryn1'),('tarzan'),('Tarzan00'),('tarzan1'),('tascha'),('tasha'),('tasha01'),('tasha1'),('tasha12'),('tasha123'),('tasha2'),('tashkent'),('taskaev777'),('tasmania'),('tasneem'),('tasnim'),('tassadar'),('tassie'),('tastatura'),('tastiera'),('tasty1'),('tasya.5'),('tat'),('tata'),('tata11'),('tata12'),('tata123'),('tata1234'),('tata1964'),('tatanka'),('tatarin'),('tatarstan'),('tatata'),('tatatata'),('tatenda'),('tater'),('tater1'),('taterbug'),('taterbug1'),('taters'),('tatertot'),('tatertot1'),('tati'),('tati123'),('tatiana'),('tatiana1'),('tatianna'),('tatina'),('tatita'),('tatjana'),('tattoo'),('tattoo1'),('tattoo13'),('tattoo2'),('tattoo69'),('tattoos'),('tattoos1'),('tatum1'),('tatung'),('tatyana'),('tatyana1'),('tauchen'),('taufik'),('taugamma'),('taugammaph'),('taureau'),('taurus'),('taurus1'),('tavares'),('tavolo'),('tawanda'),('taxi'),('taxidriver'),('taxman'),('tay'),('tay-tay'),('tay123'),('tayl0r'),('tayla1'),('tayler'),('tayler1'),('taylor'),('taylor!'),('taylor.'),('taylor00'),('taylor01'),('taylor02'),('taylor03'),('taylor04'),('taylor05'),('taylor06'),('taylor07'),('taylor08'),('taylor09'),('taylor1'),('taylor10'),('taylor101'),('taylor11'),('taylor12'),('taylor123'),('taylor1234'),('taylor13'),('taylor14'),('taylor15'),('taylor16'),('taylor17'),('taylor18'),('taylor19'),('taylor2'),('taylor20'),('taylor21'),('taylor22'),('taylor23'),('taylor24'),('taylor25'),('taylor26'),('taylor27'),('taylor3'),('taylor33'),('taylor4'),('taylor5'),('taylor56'),('taylor6'),('taylor69'),('taylor7'),('taylor77'),('taylor8'),('taylor88'),('taylor9'),('taylor92'),('taylor93'),('taylor94'),('taylor95'),('taylor96'),('taylor97'),('taylor98'),('taylor99'),('taylorgang'),('taylorlaut'),('taylormade'),('taylorswif'),('taylorswift'),('tayson'),('taytay'),('taytay1'),('taytay11'),('taytay12'),('taytay123'),('taytay13'),('taytay2'),('taytay3'),('tayuya44'),('taz'),('taz123'),('tazdevil'),('tazman'),('tazman1'),('tazmania'),('tazmania1'),('tazmanian'),('taztaz'),('tazz'),('tazz123'),('tazzie'),('tazzy1'),('tbaby1'),('tBFj7No671'),('tbilisi'),('tbird'),('tbird1'),('tbone'),('tbone1'),('tbs13'),('tdubdub05'),('tdutif'),('tdutybq'),('tdutybz'),('tdws011286'),('te'),('tea'),('tea4two'),('teabag'),('teabag1'),('teach'),('teach1'),('teacher'),('teacher1'),('teacher12'),('teacher123'),('teacher2'),('teacher3'),('teacher5'),('teachers'),('teaching'),('teacup'),('teacup1'),('teadoro'),('teagan'),('teagan1'),('team'),('team123'),('teamare'),('teamedward'),('teamjacob'),('teamo'),('teamo!'),('teamo.'),('teamo1'),('teamo10'),('teamo100'),('teamo11'),('teamo12'),('teamo123'),('teamo13'),('teamo14'),('teamo15'),('teamo16'),('teamo17'),('teamo18'),('teamo2'),('teamo22'),('teamo23'),('teamo3'),('teamo5'),('teamo7'),('teamoamor'),('teamobb'),('teamobebe'),('teamodios'),('teamojesus'),('teamomama'),('teamomiamor'),('teamomucho'),('teamomuxo'),('teamoo'),('teamwork'),('teamwork1'),('teapot'),('teapot1'),('teardrop'),('teardrop1'),('tears'),('teaser'),('teatime'),('teatro'),('tebogo'),('tebow15'),('tecate'),('tecate1'),('tech'),('techdeck'),('techdeck1'),('techn9ne'),('technical'),('technician'),('technics'),('technics1'),('technics12'),('techno'),('techno1'),('techno123'),('techno13'),('Techno2009'),('technology'),('tecktonik'),('teclado'),('tecnico'),('tecnologia'),('tecumseh'),('ted'),('ted123'),('teddie'),('teddie1'),('teddy'),('teddy01'),('teddy1'),('teddy10'),('teddy101'),('teddy11'),('teddy12'),('teddy123'),('teddy13'),('teddy14'),('teddy2'),('teddy22'),('teddy23'),('teddy3'),('teddy4'),('teddy5'),('teddy6'),('teddy7'),('teddyb'),('teddybear'),('teddybear!'),('teddybear0'),('teddybear1'),('teddybear2'),('teddybear3'),('teddybear4'),('teddybear5'),('teddybear6'),('teddybear7'),('teddybear8'),('teddybear9'),('teddybears'),('teddyboy'),('teddys'),('tedesco'),('tee'),('tee123'),('teehee'),('teejay'),('teejay1'),('teen'),('teenaa111'),('teenager'),('teenie'),('teens'),('teentitans'),('teepee'),('teetee'),('teetee1'),('teeth'),('teeth1'),('teflon'),('tegan1'),('teh-consul'),('tehran'),('teiubesc'),('teixeira'),('tekiero'),('tekiero1'),('tekila'),('tekken'),('tekken1'),('tekken3'),('tekken5'),('tekken6'),('tel'),('telaviv'),('telecaster'),('Telechargement'),('telecom'),('telecom1'),('telecono'),('telefon'),('telefon1'),('telefone'),('telefonica'),('telefonino'),('telefono'),('telefono1'),('telefoon'),('telegina_65'),('telekom'),('telemark'),('telephone'),('telephone1'),('teleport'),('television'),('televisione'),('televizor'),('telkom'),('teller'),('tellme'),('tellme1'),('tem'),('tema'),('tema-bushelev'),('tema.barabin'),('tema_ku'),('temidayo'),('temitayo'),('temitope'),('temitope1'),('temp'),('temp123'),('temp1234'),('temper'),('tempest'),('tempest1'),('tempesta'),('tempesth1941'),('templar'),('templar1'),('temple'),('temple1'),('tempo'),('tempo1'),('temporal'),('temporary'),('temporary1'),('temppass'),('temppass1'),('TempPassWord'),('temptation'),('temptemp'),('tempus'),('ten'),('tenchi'),('tenchu'),('tendai'),('tender'),('tender1'),('tendresse'),('tendulkar'),('tenerife'),('tenerife1'),('tennessee'),('tennessee1'),('tennis'),('tennis!'),('tennis01'),('tennis07'),('tennis08'),('tennis09'),('tennis1'),('tennis10'),('tennis11'),('tennis12'),('tennis123'),('tennis13'),('tennis14'),('tennis2'),('tennis21'),('tennis22'),('tennis23'),('tennis3'),('tennis4'),('tennis5'),('tennis7'),('tennisball'),('tennyson'),('tenor1'),('tenshi'),('tenshin'),('tension'),('tenten'),('tenten10'),('teodio'),('teodor'),('teodora'),('teodoro'),('Teonamaria1'),('tequiero'),('tequiero1'),('tequiero12'),('tequiero2'),('tequieromu'),('tequieromucho'),('tequila'),('tequila1'),('tequilla'),('ter'),('teremok'),('terenaam'),('terence'),('terence1'),('teresa'),('teresa01'),('teresa1'),('teresa11'),('teresa12'),('teresa123'),('teresa2'),('teresina'),('teresita'),('tereza'),('terezinha'),('terezka'),('terminal'),('terminal1'),('terminator'),('terminator1'),('terminator2'),('termit'),('termite'),('termite1'),('ternopil'),('terorist'),('terra'),('terra1'),('terra123'),('terrace'),('terran'),('terrance'),('terrance1'),('terranova'),('terrapin'),('terrell'),('terrell1'),('terrell2'),('terremoto'),('terrence'),('terrence1'),('terri'),('terri1'),('terrible'),('terrible1'),('terrie'),('terrier'),('terriers'),('terrific'),('terror'),('terror1'),('terrorist'),('terry'),('terry1'),('terry12'),('terry123'),('terry2'),('terry26'),('terrys'),('terserah'),('terter'),('tes'),('tesoro'),('tess'),('tess123'),('tessa'),('tessa1'),('tessa123'),('tessie'),('tessie1'),('test'),('test01'),('test1'),('test11'),('test12'),('test123'),('test1234'),('test12345'),('test123456'),('test2'),('test99'),('testaccount'),('testament'),('teste'),('teste123'),('tester'),('tester!'),('Tester01'),('tester1'),('tester12'),('tester123'),('tester2'),('testes'),('testing'),('testing1'),('testing123'),('testme'),('testpass'),('testqa1'),('testqa12'),('testtest'),('testtest1'),('tete'),('tete123'),('tetete'),('tetley'),('tetris'),('tetsuo'),('teufel'),('Teufel99'),('tevez32'),('tevin1'),('tevion'),('texaco'),('texans'),('texans1'),('texas'),('texas01'),('texas06'),('texas07'),('texas08'),('texas09'),('texas1'),('texas10'),('texas100'),('texas11'),('texas12'),('texas123'),('texas13'),('texas14'),('texas2'),('texas21'),('texas210'),('texas214'),('texas22'),('texas23'),('texas254'),('texas3'),('texas4'),('texas5'),('texas69'),('texas7'),('texas713'),('texas817'),('texasdoor'),('texasmade1'),('texass'),('texastech'),('texastech1'),('texmex'),('textile'),('TFzwF44idb'),('tgbyhn'),('tgPw53j3kG'),('tgtgtg'),('TGzvF55idb'),('th'),('th0mas'),('tha'),('thaddeus'),('thaddeus1'),('thailand'),('thailand1'),('thakur'),('thales'),('thalia'),('thalia1'),('thanatos'),('thando'),('thanh'),('thanh123'),('thanhcong'),('thanhtung'),('thankful'),('thankful1'),('thankgod'),('thankgod1'),('thanks'),('thanks1'),('thanksgod'),('thanku'),('thankyou'),('thankyou1'),('thankyou2'),('thanos'),('that'),('thatbitch1'),('thatcher'),('thatguy'),('thatguy1'),('thatha'),('thatnigga1'),('thatshot'),('thatshot1'),('thatsit'),('thatsme'),('thatsme1'),('thc2000'),('thc420'),('the'),('the123'),('the1andonl'),('the1andonly'),('the1ilove'),('the1man'),('the1nonly'),('the1ring'),('the2ofus'),('the69eyes'),('theanswer'),('theanswer3'),('theater'),('theater1'),('theatre'),('theatre1'),('theband'),('theband1'),('thebeach'),('thebear'),('Thebears12'),('thebeast'),('thebeast1'),('thebeatles'),('thebest'),('thebest1'),('thebest12'),('thebest123'),('thebest2'),('thebest99'),('thebible'),('thebig1'),('thebigboss'),('thebitch'),('thebitch1'),('theblock'),('theblues'),('thebomb'),('thebomb1'),('theboss'),('theboss1'),('theboy'),('theboy1'),('theboys'),('theboys1'),('theboys2'),('theboys3'),('thecat'),('thecat1'),('thechamp'),('thechamp1'),('thechosen1'),('theclash'),('thecool1'),('TheCrazyMaxim'),('thecrew1'),('thecrow'),('thecrow1'),('thecure'),('thecure1'),('thedark1'),('thedevil'),('thedoctor'),('thedog'),('thedog1'),('thedon'),('thedon1'),('thedoors'),('thedoors1'),('thedude'),('thedude1'),('theduke'),('theduke1'),('theedge'),('theend'),('theend1'),('theflash'),('theforce'),('theforce1'),('thegame'),('thegame1'),('thegame12'),('thegame123'),('thegame2'),('theghost'),('thegirls'),('thegr81'),('thegreat'),('thegreat1'),('thegreat12'),('thegreat123'),('thegreatone'),('thehock'),('thehulk'),('thehulk1'),('theIigD4x2'),('theIigE4x2'),('thejoker'),('thejoker1'),('thekid'),('thekid1'),('thekids'),('thekiller'),('thekiller1'),('thekillers'),('theking'),('theking1'),('theking12'),('theking123'),('theking2'),('theking23'),('thelast1'),('thelaw'),('thelegend'),('thelma'),('thelma1'),('thelord'),('thelord1'),('thelordisgood'),('thelove'),('theman'),('theman1'),('theman11'),('theman12'),('theman123'),('theman2'),('theman22'),('theman23'),('theman3'),('theman69'),('themaster'),('themaster1'),('thematrix'),('thematrix1'),('themis'),('themoon'),('thenewme'),('thenewozer'),('thenumber1'),('theo'),('theo123'),('theodor'),('theodora'),('theodore'),('theodore1'),('theone'),('theone01'),('theone1'),('theone11'),('theone12'),('theone123'),('theone2'),('theonly1'),('theonlyone'),('theory'),('thepassword'),('thepimp1'),('thepower'),('thequeen'),('thequeen1'),('therapist'),('therapy'),('therapy1'),('therasmus'),('there'),('thereal1'),('thereds'),('thereisnospoon'),('theresa'),('theresa1'),('theresa2'),('therese'),('therese1'),('theresia'),('thering'),('therion'),('thermo'),('therock'),('therock1'),('therock123'),('therock2'),('theron'),('thesaint'),('thesame'),('thesame1'),('thesecret'),('thesecret1'),('thesexy1'),('theshit'),('theshit1'),('thesimpsons'),('thesims'),('thesims1'),('thesims2'),('thesims3'),('TheSmokin'),('thespian'),('thestrokes'),('thesun'),('thethe'),('thethe1'),('thething'),('thetruth'),('thetruth1'),('thetwins'),('theused'),('theused1'),('theused2'),('thewall'),('thewall1'),('theway'),('thewho'),('thewho1'),('theworld'),('theworld1'),('thi'),('thiago'),('thiago123'),('thibault'),('thibaut'),('thick1'),('thickness'),('thickness1'),('thienthan'),('thieric'),('thierry'),('thierry1'),('thing'),('thing1'),('thing2'),('things'),('things1'),('think'),('think1'),('think123'),('think456'),('thinkbig'),('thinker'),('thinking'),('thinking1'),('thinkpad'),('thinkpink'),('thinkpink1'),('thirdeye'),('thirteen'),('thirteen13'),('thirty'),('thirty3'),('thirty30'),('this'),('thisis'),('thisis1'),('thisisgay'),('thisisgay1'),('thisisit'),('thisisit1'),('thisisme'),('thisisme1'),('thisismine'),('thisismypassword'),('thissucks'),('thissucks1'),('thissucks2'),('thistle'),('thistle1'),('thizz1'),('thizz2'),('tho'),('thomas'),('thomas!'),('thomas.'),('thomas0'),('thomas00'),('thomas01'),('thomas02'),('thomas03'),('thomas04'),('thomas05'),('thomas06'),('thomas07'),('thomas08'),('thomas09'),('thomas1'),('thomas10'),('thomas11'),('thomas12'),('thomas123'),('thomas1234'),('thomas13'),('thomas14'),('thomas15'),('thomas16'),('thomas17'),('thomas18'),('thomas19'),('thomas2'),('thomas20'),('thomas21'),('thomas22'),('thomas23'),('thomas24'),('thomas25'),('thomas26'),('thomas27'),('thomas28'),('thomas3'),('thomas30'),('thomas33'),('thomas4'),('thomas44'),('thomas5'),('thomas55'),('thomas6'),('thomas69'),('thomas7'),('thomas77'),('thomas8'),('thomas87'),('thomas88'),('thomas89'),('thomas9'),('thomas91'),('thomas92'),('thomas94'),('thomas95'),('thomas97'),('thomas98'),('thomas99'),('thommy'),('thompson'),('thompson1'),('thomson'),('thomson1'),('thong'),('thongs'),('thor'),('thor123'),('thornton'),('thornton1'),('thorpe'),('thorsten'),('thought'),('thought1'),('thousand'),('thrash'),('thrash1'),('thrasher'),('thrasher1'),('three'),('three11'),('three3'),('three33'),('three333'),('three6'),('threeboys'),('threegirls'),('threekids'),('threekids3'),('threesome'),('threesome3'),('thrice'),('thrice1'),('thriller'),('thriller1'),('tHTaJehzsp'),('thu'),('thug'),('thug101'),('thug12'),('thug123'),('thug13'),('thug4life'),('thuggin'),('thuggin1'),('thuglife'),('thuglife1'),('thuglife12'),('thuglife13'),('thuglife2'),('thuglife3'),('thuglife7'),('thuglove'),('thuglove1'),('thugstools'),('thug__'),('thumbs'),('thumper'),('thumper1'),('thumper12'),('thumper123'),('thumper2'),('thumper3'),('thunder'),('thunder!'),('thunder01'),('thunder1'),('thunder10'),('thunder11'),('thunder12'),('thunder123'),('thunder13'),('thunder2'),('thunder21'),('thunder22'),('thunder23'),('thunder3'),('thunder4'),('thunder5'),('thunder6'),('thunder69'),('thunder7'),('thunder8'),('thunder9'),('thunderbir'),('thunderbird'),('thunderbolt'),('thundercat'),('thundercats'),('thunders'),('thunderstorm'),('thurman'),('thursday'),('thursday1'),('thurston'),('thuylinh'),('thx1138'),('tia'),('tia123'),('tiago'),('tiago123'),('tiamaria'),('tiamat'),('tiamo'),('tiamotanto'),('tiana'),('tiana1'),('tiancai'),('tianna'),('tianna1'),('tianshi'),('tiantian'),('tianya'),('tiara'),('tiara1'),('tiatia'),('tiberian'),('tiberium'),('tiberius'),('tibia123'),('tiburon'),('tiburon1'),('tichuots'),('ticket'),('ticket1'),('tickets'),('tickle'),('tickle1'),('tickles'),('ticktock'),('ticotico'),('tictac'),('tictac1'),('tidbit'),('tiddles'),('tiddles1'),('Tielandros01'),('tierney'),('tierra'),('tierra1'),('tiesto'),('tiesto1'),('tiff'),('tiff12'),('tiff123'),('tiffani'),('tiffani1'),('tiffanie'),('tiffany'),('tiffany!'),('tiffany.'),('tiffany01'),('tiffany08'),('tiffany09'),('tiffany1'),('tiffany10'),('tiffany11'),('tiffany12'),('tiffany123'),('tiffany13'),('tiffany14'),('tiffany15'),('tiffany16'),('tiffany17'),('tiffany18'),('tiffany2'),('tiffany21'),('tiffany22'),('tiffany23'),('tiffany3'),('tiffany4'),('tiffany5'),('tiffany6'),('tiffany69'),('tiffany7'),('tiffany8'),('tiffany9'),('tiffy'),('tiffy1'),('tig'),('tiger'),('tiger!'),('tiger007'),('tiger01'),('tiger06'),('tiger07'),('tiger08'),('tiger09'),('tiger1'),('tiger10'),('tiger100'),('tiger101'),('tiger11'),('tiger111'),('tiger12'),('tiger123'),('tiger1234'),('tiger13'),('tiger14'),('tiger15'),('tiger16'),('tiger17'),('tiger18'),('tiger2'),('tiger20'),('tiger2000'),('tiger2010'),('tiger21'),('tiger22'),('tiger23'),('tiger24'),('tiger25'),('tiger27'),('tiger3'),('tiger321'),('tiger33'),('tiger34'),('tiger4'),('tiger44'),('tiger45'),('tiger5'),('tiger55'),('tiger6'),('tiger66'),('tiger69'),('tiger7'),('tiger74'),('tiger77'),('tiger777'),('tiger8'),('tiger86'),('tiger88'),('tiger9'),('tiger98'),('tiger99'),('tigerboy'),('tigercat'),('tigercat1'),('tigereye'),('tigerlilly'),('tigerlily'),('tigerlily1'),('tigerman'),('tigers'),('tigers!'),('tigers.'),('tigers01'),('tigers05'),('tigers06'),('tigers07'),('tigers08'),('tigers09'),('tigers1'),('tigers10'),('tigers11'),('tigers12'),('tigers123'),('tigers13'),('tigers14'),('tigers15'),('tigers2'),('tigers21'),('tigers22'),('tigers23'),('tigers24'),('tigers3'),('tigers33'),('tigers4'),('tigers5'),('tigers6'),('tigers69'),('tigers7'),('tigers8'),('tigers84'),('tigers9'),('tigertiger'),('tigerwoods'),('tigger'),('tigger!'),('tigger.'),('tigger00'),('tigger01'),('tigger02'),('tigger03'),('tigger04'),('tigger05'),('tigger06'),('tigger07'),('tigger08'),('tigger09'),('tigger1'),('tigger10'),('tigger101'),('tigger11'),('tigger12'),('tigger123'),('tigger1234'),('tigger13'),('tigger14'),('tigger15'),('tigger16'),('tigger17'),('tigger18'),('tigger19'),('tigger2'),('tigger20'),('tigger21'),('tigger22'),('tigger23'),('tigger24'),('tigger25'),('tigger26'),('tigger27'),('tigger28'),('tigger3'),('tigger33'),('tigger4'),('tigger44'),('tigger45'),('tigger5'),('tigger55'),('tigger6'),('tigger66'),('tigger67'),('tigger68'),('tigger69'),('tigger7'),('tigger77'),('tigger8'),('tigger87'),('tigger88'),('tigger89'),('tigger9'),('tigger99'),('tiggers'),('tiggy1'),('tight'),('tight1'),('tigran'),('tigre'),('tigre1'),('tigrenok'),('tigres'),('tigres1'),('tigress'),('tigresse'),('tigris'),('tigrotto'),('tigrou'),('tijger'),('tijger3417'),('tijgertje'),('tijuana'),('tijuana1'),('tikitiki'),('tiktak'),('tiktok'),('tilley'),('tillie'),('tillie1'),('tilly'),('tilly1'),('tilly123'),('tim'),('tim123'),('tima'),('timati'),('timbaland'),('timber'),('timber1'),('timber2'),('timberlake'),('timberland'),('timberwolf'),('timbuktu'),('time'),('time12'),('time123'),('time2die'),('time2fly'),('time2go'),('time2play'),('time4fun'),('time4me'),('timebomb'),('timeless'),('timeless1'),('timeline'),('timelord'),('timeout'),('timeout1'),('timepass'),('timetime'),('timfranzke'),('timileyin'),('timisoara'),('timmer'),('timmie'),('timmy'),('timmy01'),('timmy1'),('timmy11'),('timmy12'),('timmy123'),('timmy2'),('timmy3'),('timmy5'),('timmy69'),('timmy7'),('timmy9'),('timo'),('timofei'),('timofey'),('timoha'),('timon'),('timon1'),('timosha'),('timoshka'),('timoteo'),('timothy'),('timothy01'),('timothy1'),('timothy12'),('timothy123'),('timothy2'),('timothy3'),('timothy5'),('timothy7'),('timoxa'),('timoxa94'),('timtam'),('timtim'),('timtim1'),('timur'),('timurka'),('tin'),('tina'),('tina01'),('tina10'),('tina11'),('tina12'),('tina123'),('tina1234'),('tina13'),('tina15'),('tina22'),('tina69'),('tinamarie'),('tinashe'),('tinatina'),('tinchen'),('tingting'),('tingtong'),('tinhyeu'),('tink'),('tink01'),('tink07'),('tink08'),('tink09'),('tink10'),('tink101'),('tink11'),('tink12'),('tink123'),('tink1234'),('tink13'),('tink14'),('tink15'),('tink16'),('tink21'),('tink22'),('tink23'),('tink3rb3ll'),('tink69'),('tinka'),('tinka1'),('tinkabell1'),('tinker'),('tinker!'),('tinker01'),('tinker09'),('tinker1'),('tinker10'),('tinker11'),('tinker12'),('tinker123'),('tinker13'),('tinker14'),('tinker15'),('tinker2'),('tinker21'),('tinker22'),('tinker23'),('tinker3'),('tinker4'),('tinker5'),('tinker7'),('tinker8'),('tinker9'),('tinkerbe11'),('tinkerbel1'),('tinkerbell'),('tinkerbell1'),('tinkerbell12'),('tinkerbelle'),('tinkle'),('tinktink'),('tinky1'),('tinman'),('tinman1'),('tino'),('tinotenda'),('tintin'),('tintin1'),('tintin123'),('tiny'),('tiny12'),('tiny123'),('tiny13'),('tinydancer'),('tinytim'),('tinytim1'),('tiphaine'),('tipper'),('tipper1'),('tipperary'),('tippie'),('tippmann'),('tippmann1'),('tippmann98'),('tippy'),('tippy1'),('tippy123'),('tippy2'),('tipsy'),('tipsy1'),('tiptop'),('tiramisu'),('tirana'),('tirupati'),('tiscali'),('tisha'),('tisha1'),('tishenkoff'),('tishka'),('tissot'),('tissue'),('tit'),('titan'),('titan1'),('titan123'),('titania'),('titanic'),('titanic1'),('titanic12'),('titanic123'),('titanic1912'),('titanic2'),('titanik'),('titanium'),('titanium1'),('titans'),('titans1'),('titans10'),('titans12'),('titeuf'),('titi'),('titi123'),('titilayo'),('titimi'),('titina'),('titine'),('tititi'),('titititi'),('titleist'),('titleist1'),('tito'),('tito12'),('tito123'),('tito13'),('titotito'),('titou'),('titouan'),('titoune'),('titova'),('tits'),('tits123'),('tits69'),('titten'),('titti'),('titties'),('titties1'),('titties2'),('titty'),('titty1'),('titus'),('titus1'),('tivogliobene'),('tivoli'),('tiwari'),('tiziana'),('tiziano'),('tj1234'),('tkachenko'),('tkbpfdtnf'),('tkfkdgo'),('tkfkdgo0'),('tkfkdgo1'),('tkfkdgo7'),('tkgsoo083bsr'),('tktyf'),('tl281188t'),('tlc123'),('tmac01'),('tmm'),('tmnet123'),('tmobile'),('tmobile1'),('tmoney'),('tmoney1'),('tmvlzj12'),('Tnk0Mk16VX'),('tnt123'),('to'),('toad'),('toast'),('toast1'),('toast123'),('toaster'),('toaster1'),('toasty'),('toasty1'),('tobacco'),('tobago'),('tobby1'),('tobeornottobe'),('tobi'),('tobi123'),('tobias'),('tobias1'),('tobias12'),('tobias123'),('tobiloba'),('toblerone'),('toby'),('toby01'),('toby10'),('toby11'),('toby12'),('toby123'),('toby1234'),('toby13'),('toby22'),('tobydog'),('tobydog1'),('tobytoby'),('tochukwu'),('tocool'),('toctoc'),('today'),('today1'),('today123'),('todd'),('todd123'),('toejam'),('toenail'),('toenail1'),('toffee'),('toffee1'),('together'),('together1'),('together2'),('toggle'),('toietmoi'),('toilatoi'),('toilet'),('toilet1'),('toiyeuem'),('tokio'),('Tokio1'),('tokiohotel'),('tokunbo'),('tokyo'),('tokyo1'),('tolani'),('toledo'),('toledo1'),('tolentino'),('tolik'),('tolits'),('tolkien'),('tolkien1'),('tolstyh.oxana'),('toluca'),('toluca1'),('tolulope'),('tom'),('tom123'),('tom1234'),('tom12345'),('toma'),('tomahawk'),('tomahawk1'),('tomandjerry'),('tomas'),('tomas1'),('tomas123'),('tomasa'),('tomasek'),('tomasito'),('tomasko'),('tomass'),('tomasz'),('tomasz1'),('tomaszek'),('tomate'),('tomate1'),('tomato'),('tomato1'),('tomatoes'),('tomboy'),('tomboy07'),('tomboy1'),('tombrady'),('tombrady12'),('tombraider'),('tombstone'),('tombstone1'),('tomcat'),('tomcat1'),('tomcat14'),('tomcruise'),('tomdelonge'),('tomek'),('tomek1'),('tomek123'),('tomfelton'),('tomi'),('tomika'),('tomino'),('tomislav'),('tomiwa'),('tomjerry'),('tomjones'),('tomkaulitz'),('tomlinson'),('tommaso'),('tommie'),('tommie1'),('tommy'),('tommy01'),('tommy1'),('tommy10'),('tommy11'),('tommy12'),('tommy123'),('tommy1234'),('tommy13'),('tommy2'),('tommy21'),('tommy22'),('tommy23'),('tommy3'),('tommy4'),('tommy5'),('tommy6'),('tommy69'),('tommy7'),('tommy9'),('tommyboy'),('tommyboy1'),('tommyg'),('tommygirl'),('tommygirl1'),('tommygun'),('tommylee'),('tommys'),('tomodachi'),('tomoko'),('tomorrow'),('tomorrow1'),('tomoyo'),('tomtom'),('tomtom1'),('tomtom11'),('tomtom12'),('tomtom123'),('tomtom2'),('tomtomtom'),('tomwaits'),('tomwelling'),('ton'),('tongtong'),('tongue'),('toni'),('toni12'),('toni123'),('tonight'),('tonight1'),('tonino'),('tonio'),('tonio1'),('tonito'),('tonitoni'),('tonka'),('tonka1'),('tonkpils'),('tonto'),('tonto1'),('tonton'),('tonton1'),('tony'),('tony01'),('tony06'),('tony07'),('tony08'),('tony09'),('tony1'),('tony10'),('tony101'),('tony11'),('tony12'),('tony123'),('tony1234'),('tony13'),('tony14'),('tony15'),('tony16'),('tony17'),('tony18'),('tony19'),('tony20'),('tony21'),('tony22'),('tony23'),('tony24'),('tony25'),('tony69'),('tony77'),('tony88'),('tonya'),('tonya1'),('tonyhawk'),('tonyhawk1'),('tonymontana'),('tonyromo9'),('tonytony'),('too'),('toobad'),('toocool'),('toocool1'),('toocute'),('toocute1'),('toodles'),('toodles1'),('toogood'),('toohot'),('toohot1'),('toohot4u'),('tookie'),('tookie1'),('tool'),('tool123'),('toolbox'),('toolbox1'),('toolman'),('toolman1'),('tools'),('tooltime'),('toomuch'),('toomuch1'),('toonarmy'),('toonarmy1'),('toonces'),('toontown'),('toontown1'),('toosexy'),('toosexy1'),('tooshort'),('tooshort1'),('toosweet'),('toot'),('tootall'),('tooter'),('tooter1'),('tooth1'),('toothbrush'),('toothfairy'),('toothpaste'),('toothpick'),('toothpick1'),('tootie'),('tootie1'),('tootie2'),('tootles'),('tootoo'),('toots'),('toots1'),('tootsie'),('tootsie1'),('tootsie2'),('toottoot'),('top'),('top100'),('top123'),('topaz'),('topaz.null'),('topaz1'),('topaze'),('topbull'),('TOPBUTTON'),('topcat'),('topcat1'),('topdevice'),('topdog'),('topdog1'),('tope123'),('topgear'),('topgear1'),('topgun'),('topgun1'),('tophat'),('tophat1'),('topher'),('topher1'),('topina'),('topino'),('topless'),('topman'),('topmodel'),('topmodel1'),('topmost'),('topnotch'),('topnotch1'),('topogigio'),('topography'),('topolina'),('topolino'),('topper'),('topper1'),('topsecret'),('topsecret1'),('topspin'),('toptop'),('tor'),('tor8585'),('torana'),('toratora'),('torben'),('torchwood'),('torchwood1'),('torcida'),('torero'),('torgsotra'),('tori'),('tori12'),('tori123'),('toriamos'),('toriamos1'),('torino'),('torito'),('torment'),('tormenta'),('tormoz'),('tornade'),('tornado'),('tornado1'),('toro'),('toronto'),('toronto1'),('torpedo'),('torpedo1'),('torque'),('torrance'),('torrent'),('torrente'),('torrents'),('torres'),('torres09'),('torres1'),('torres10'),('torres12'),('torres123'),('torres9'),('torrey'),('torrie'),('torrie1'),('torsten'),('tortilla'),('tortoise'),('tortue'),('tortuga'),('tortuga1'),('tosca'),('toscana'),('toscane'),('tosha1'),('toshiba'),('toshiba1'),('toshiba123'),('toshiba2'),('toshka'),('tosin1'),('tosser'),('tot'),('total'),('total1'),('total12scherz'),('total90'),('totally'),('totally1'),('totalwar'),('totenkopf'),('totito'),('toto'),('toto12'),('toto123'),('toto1234'),('toto22'),('toto90'),('totoche'),('totoro'),('tototo'),('totototo'),('totoy'),('totoybato'),('tottenham'),('tottenham1'),('totti'),('totti10'),('tottigol'),('tou'),('touareg'),('toucan'),('touch'),('touch1'),('touchdown'),('touchdown1'),('touche'),('touchme'),('toughguy'),('toujours'),('toulon'),('toulouse'),('toulouse1'),('toulouse31'),('toupie'),('tourism'),('tournesol'),('toutou'),('toutoune'),('towanda'),('tower'),('tower1'),('towers'),('townsend'),('townsend1'),('towtruck'),('toxic'),('toxic1'),('toxicity'),('toy'),('toy123'),('toybox'),('toyboy'),('toymachine'),('toyosi'),('toyota'),('toyota01'),('toyota1'),('toyota11'),('toyota12'),('toyota123'),('toyota2'),('toyota99'),('toyotamr2'),('toyplanet'),('toystory'),('toystory2'),('toytoy'),('tpain1'),('TPklmQ9668'),('tpxerxjmp'),('tr'),('tr1n1ty'),('tra'),('trabajo'),('trabajo1'),('trabalho'),('trabant'),('trabzon'),('trabzon61'),('trabzonspor'),('trace1'),('tracer'),('tracer1'),('tracey'),('tracey1'),('traci'),('traci1'),('tracie'),('tracie1'),('track'),('track1'),('track12'),('track123'),('track2'),('tracker'),('tracker1'),('tracks'),('trackstar'),('trackstar1'),('tracteur'),('tractor'),('tractor1'),('tractors'),('tracy'),('tracy1'),('tracy123'),('trade'),('trademark'),('trader'),('trader1'),('trading'),('trafalgar'),('traffic'),('traffic1'),('trafford'),('tragedy'),('trailblazer'),('trailer'),('trailer1'),('trails'),('train'),('train1'),('train123'),('trainer'),('trainer1'),('training'),('training1'),('trains'),('trains1'),('traktor'),('tralala'),('tralala1'),('tramonto'),('tramp'),('tramp1'),('trampoline'),('trance'),('trance1'),('trandafir'),('tranmere'),('tranny'),('tranny1'),('tranquil'),('trans'),('trans1'),('transalp'),('transam'),('transam1'),('transcend'),('transfer'),('transform'),('transform1'),('transforme'),('transformer'),('transformers'),('transit'),('transit1'),('transport'),('transport1'),('transporter'),('trapdoor39'),('trapdoor43'),('trapdoor60'),('trapper'),('trapper1'),('trapstar'),('trapstar1'),('trase1990'),('trash'),('trash1'),('trashcan'),('trashcan1'),('trasher'),('tratata'),('trauma'),('travail'),('travel'),('travel1'),('travel123'),('travel2'),('travel88'),('traveler'),('traveler1'),('traveller'),('travelmate'),('TravelmoleOptin'),('travelpack1'),('travian'),('traviesa'),('traviesa1'),('travieso'),('travieso1'),('travis'),('travis!'),('travis.'),('travis01'),('travis07'),('travis08'),('travis09'),('travis1'),('travis10'),('travis11'),('travis12'),('travis123'),('travis13'),('travis14'),('travis15'),('travis16'),('travis199'),('travis2'),('travis21'),('travis22'),('travis23'),('travis3'),('travis4'),('travis5'),('travis69'),('travis7'),('travolta'),('travon1'),('traxdata'),('traxxas'),('traxxas1'),('tre'),('tre123'),('treacle'),('treacle1'),('treasure'),('treasure1'),('treats'),('treats1'),('trebla'),('treble'),('treble99'),('trebor'),('trebor1'),('trece13'),('trecool'),('trecool1'),('tree'),('tree11'),('tree12'),('tree123'),('tree1234'),('treefrog'),('treefrog1'),('treehouse'),('treehouse1'),('treehugger'),('treeman'),('trees'),('trees1'),('trees123'),('treetop'),('treetop1'),('treetops'),('treetree'),('treflip'),('treguier'),('trek'),('trekker'),('trell1'),('trendy'),('trener'),('trent'),('trent1'),('trent123'),('trenton'),('trenton1'),('tresd5'),('tresor'),('tretre'),('tretre1'),('treu14'),('trever'),('trevon'),('trevon1'),('trevor'),('trevor01'),('trevor1'),('trevor10'),('trevor11'),('trevor12'),('trevor123'),('trevor13'),('trevor2'),('trevor3'),('trewq'),('trewq1'),('trey'),('trey12'),('trey123'),('treysongz'),('treysongz1'),('treytrey'),('trezeguet'),('trfnthbyf'),('tri'),('triada'),('trial'),('triana'),('triangle'),('triangle1'),('triathlon'),('tribal'),('tribal1'),('tribe1'),('tribes'),('tribunal'),('tribute'),('tricia'),('tricia1'),('trick'),('trick1'),('tricks'),('trickster'),('trickster1'),('tricky'),('tricky1'),('tricolor'),('trident'),('trident1'),('trieste'),('triforce'),('triforce1'),('trigger'),('trigger1'),('trigger2'),('trigun'),('trigun1'),('trikers21'),('trill1'),('trilli'),('trilly'),('trilogy'),('trina'),('trina1'),('trinacria'),('trindade'),('trini1'),('trinidad'),('trinidad1'),('triniti'),('trinitron'),('trinitron1'),('trinity'),('trinity01'),('trinity05'),('trinity06'),('trinity07'),('trinity08'),('trinity1'),('trinity11'),('trinity12'),('trinity123'),('trinity2'),('trinity3'),('trinity4'),('trinity5'),('trinity6'),('trinity7'),('trinity8'),('trinket'),('triple'),('triple1'),('triple3'),('triple6'),('triple7'),('tripleh'),('tripleh1'),('triplet'),('triplet3'),('triplets'),('triplets3'),('triplex'),('tripod'),('tripod1'),('tripoli'),('tripper'),('tripper1'),('trippin'),('trippy'),('trish'),('trish1'),('trisha'),('trisha1'),('triskelion'),('trista'),('trista1'),('tristan'),('Tristan01'),('tristan1'),('tristan12'),('tristan123'),('tristan2'),('tristan3'),('tristan7'),('tristar'),('triste'),('tristen'),('tristen1'),('tristian'),('tristin'),('tristin1'),('triston'),('triston1'),('tristram'),('triton'),('triton1'),('triumph'),('triumph1'),('trivial'),('trivium'),('trivium1'),('trixie'),('trixie01'),('trixie1'),('trixie12'),('trixie123'),('trixie2'),('tro'),('trofimishe'),('trogdor'),('trogdor1'),('troia'),('troika93'),('trojan'),('trojan1'),('trojans'),('trojans1'),('troll'),('troll0'),('troll1'),('troll123'),('trollface'),('trolls'),('trololo'),('tromba'),('trombone'),('trombone1'),('trompeta'),('trompete'),('trompette'),('tronwell'),('trooper'),('trooper1'),('trooper2'),('troopers'),('trophy'),('tropic'),('tropical'),('tropical1'),('tropicana'),('tropicana1'),('trotter'),('trotter1'),('trouble'),('trouble!'),('trouble1'),('trouble12'),('trouble123'),('trouble13'),('trouble2'),('trouble3'),('trouble69'),('trouble7'),('troubled1'),('troubles'),('troubles1'),('trouducul'),('trousers'),('trout'),('trout1'),('troy'),('troy11'),('troy12'),('troy123'),('troy14'),('troyboy'),('troyboy1'),('trtrtr'),('tru'),('truand'),('truck'),('truck1'),('truck123'),('truckdriver'),('trucker'),('trucker1'),('truckin'),('trucking'),('trucking1'),('trucks'),('trucks1'),('trudy'),('trudy1'),('true'),('trueblood'),('trueblue'),('trueblue1'),('truelove'),('truelove!'),('truelove08'),('truelove1'),('truelove12'),('truelove13'),('truelove2'),('truelove3'),('truelove7'),('trueno'),('truffle'),('truffle1'),('truffles'),('truffles1'),('trujillo'),('trujillo1'),('truman'),('truman1'),('trumpet'),('trumpet1'),('trumpet2'),('trunks'),('trunks1'),('truong'),('trupti'),('truskawka'),('trust'),('trust1'),('trust123'),('trustgod'),('trustgod1'),('trusting'),('trustingod'),('trustme'),('trustme1'),('trustme2'),('trustme_k'),('trustn01'),('trustno'),('trustno1'),('trustno2'),('trustnoone'),('trusty'),('truth'),('truth1'),('trx450r'),('try123'),('tryagain'),('tryagain1'),('trying'),('tryme'),('trystan'),('trythis'),('trythis1'),('trytry'),('tsubasa'),('tsunami'),('tsunami1'),('tsv1860'),('tt1234'),('tt123456'),('tt1234567'),('ttd955AudG'),('ttr125'),('ttt'),('ttt111'),('ttt123'),('tttt'),('ttttt'),('ttttt1'),('tttttt'),('tttttt1'),('ttttttt'),('tttttttt'),('tttttttttt'),('tty'),('tuan123'),('tuananh'),('tuangbi'),('tubby'),('tubby1'),('tubgtn'),('tuborg'),('tucano'),('tucker'),('tucker!'),('tucker01'),('tucker1'),('tucker10'),('tucker11'),('tucker12'),('tucker123'),('tucker13'),('tucker2'),('tucker22'),('tucker3'),('tucker5'),('tucker7'),('tucson'),('tucson1'),('tudelft'),('Tuermchen'),('tuesday'),('tuesday1'),('tuesday2'),('tuffy'),('tuffy1'),('tugboat'),('tugboat1'),('tugger'),('tujheirf'),('tujhjdf'),('tujhrf'),('tuktuk'),('tulane'),('tulip'),('tulip1'),('tulipa'),('tulipan'),('tulipano'),('tulipe'),('tulips'),('tulips1'),('tulpan'),('tumadre'),('tumadre1'),('tumama'),('tumbin'),('tumble'),('tumble1'),('tumbleweed'),('tumelo'),('tumtum'),('tuna'),('tunafish'),('tunafish1'),('tuncay'),('tunde'),('tunde1'),('tunde123'),('tunde12345'),('tunder'),('tundra'),('tundra1'),('tundra_cool2'),('tunes'),('tuning'),('tuning1'),('tunisia'),('tunisie'),('tunnel'),('tuntun'),('tupac'),('tupac1'),('tupac12'),('tupac123'),('tupac2'),('tupac7'),('tupac96'),('tupacshakur'),('tupelo'),('tuppence'),('tuputamadre'),('tur'),('turandot'),('turbine'),('turbo'),('turbo1'),('turbo123'),('turbo2'),('turbos'),('turion64'),('turismo'),('turk182'),('turkey'),('turkey1'),('turkey12'),('turkey123'),('turkey2'),('turkish'),('turkish1'),('turkiye'),('turner'),('turner1'),('turnip'),('turnip1'),('turntable'),('turntable1'),('turquoise'),('turtle'),('turtle!'),('turtle01'),('turtle1'),('turtle10'),('turtle11'),('turtle12'),('turtle123'),('turtle13'),('turtle14'),('turtle2'),('turtle21'),('turtle22'),('turtle23'),('turtle3'),('turtle4'),('turtle5'),('turtle6'),('turtle69'),('turtle7'),('turtle8'),('turtle9'),('turtles'),('turtles1'),('turtles2'),('turtoise'),('tuscany'),('tushar'),('tutifruti'),('tuttle'),('tutu'),('tutu123'),('tututu'),('tuwo4u9'),('tuxedo'),('tuxedo1'),('tvinktvink'),('tvs3108'),('tw'),('tw1l1ght'),('tw33ty'),('twat'),('tweeling'),('tweet1'),('tweeter'),('tweetie'),('tweetie1'),('tweety'),('tweety!'),('tweety01'),('tweety06'),('tweety07'),('tweety08'),('tweety09'),('tweety1'),('tweety10'),('tweety101'),('tweety11'),('tweety12'),('tweety123'),('tweety13'),('tweety14'),('tweety15'),('tweety16'),('tweety17'),('tweety18'),('tweety19'),('tweety2'),('tweety20'),('tweety21'),('tweety22'),('tweety23'),('tweety24'),('tweety25'),('tweety3'),('tweety4'),('tweety5'),('tweety6'),('tweety69'),('tweety7'),('tweety8'),('tweety9'),('tweetybird'),('tweetypie'),('twelve'),('twelve12'),('twenty'),('twenty1'),('twenty2'),('twenty20'),('twenty3'),('twenty4'),('twenty5'),('twenty7'),('twentyfour'),('twentyone'),('twentysix'),('twentytwo'),('twiggy'),('twiggy1'),('twiglet'),('twilight'),('twilight!'),('twilight.'),('twilight01'),('twilight08'),('twilight09'),('twilight1'),('twilight10'),('twilight11'),('twilight12'),('twilight123'),('twilight13'),('twilight14'),('twilight15'),('twilight16'),('twilight17'),('twilight2'),('twilight21'),('twilight22'),('twilight23'),('twilight3'),('twilight4'),('twilight5'),('twilight6'),('twilight7'),('twilight8'),('twilight9'),('twin'),('twin12'),('twinboys'),('twingirls'),('twingo'),('twinkie'),('twinkie1'),('twinkie2'),('twinkies'),('twinkle'),('twinkle1'),('Twinkle15'),('twinkle2'),('twinkles'),('twinkletoes'),('twinky'),('twinky1'),('twins'),('twins02'),('twins06'),('twins07'),('twins08'),('twins1'),('twins12'),('twins123'),('twins2'),('twins22'),('twins3'),('twinss'),('twinturbo'),('twist'),('twista'),('twisted'),('twisted1'),('twisted2'),('twister'),('twister1'),('twister2'),('twitch'),('twitch1'),('twitter'),('twiztid'),('twiztid1'),('two'),('twoboys'),('twoboys2'),('twocats'),('twodogs'),('twogirls'),('twojastara'),('twokids'),('twokids2'),('twostep'),('twotwo'),('tx9Z6ht5eO'),('ty1234'),('ty123456'),('Ty2t1hv3oC'),('tycoon'),('tycoon1'),('tygferrfddss'),('tyghbn'),('tygrys'),('tygrysek'),('tyler'),('tyler!'),('tyler.'),('tyler00'),('tyler01'),('tyler02'),('tyler03'),('tyler04'),('tyler05'),('tyler06'),('tyler07'),('tyler08'),('tyler09'),('tyler1'),('tyler10'),('tyler101'),('tyler11'),('tyler12'),('tyler123'),('tyler1234'),('tyler12345'),('tyler13'),('tyler14'),('tyler15'),('tyler16'),('tyler17'),('tyler18'),('tyler2'),('tyler2000'),('tyler2006'),('tyler2008'),('tyler21'),('tyler22'),('tyler23'),('tyler24'),('tyler25'),('tyler3'),('tyler4'),('tyler5'),('tyler6'),('tyler69'),('tyler7'),('tyler8'),('tyler9'),('tyler95'),('tyler97'),('tyler98'),('tyler99'),('tylerb'),('tylerd'),('tylerj'),('tylerjames'),('tylers'),('tylers1'),('typetogether'),('typewriter'),('typhoon'),('typhoon1'),('tyrael04'),('tyrant'),('tyree1'),('tyrell'),('tyrell1'),('tyrese'),('tyrese1'),('tyrone'),('tyrone1'),('tyrone12'),('tyrone123'),('tyrone2'),('tyrone3'),('tyrone79'),('tyshawn1'),('tyskie'),('tyson'),('tyson01'),('tyson1'),('tyson11'),('tyson12'),('tyson123'),('tyson2'),('tysons'),('tyty'),('tyty12'),('tyty123'),('tytyty'),('tytyty1'),('tyuiop'),('tyumchenko_ok'),('tyutyu'),('tzir25l5KN'),('t_v_belyakova'),('u'),('u.hohlov'),('u0HgtKt617'),('u123456'),('u1v7hHh7eF'),('u23456'),('u2u2u2'),('U38fa39'),('U6e6r9hwiX'),('u6kz2lppto'),('u77789'),('u79999i'),('u83xu3u83'),('u8t6e4'),('u8u8'),('uae_boy'),('uandme'),('ub6ib9'),('ubnfhf'),('ubuntu'),('ubvyfpbz'),('uchenna'),('uchiha'),('uchiha1'),('udacha'),('uekmyfhf'),('uekmyfp'),('ueptkm'),('uf'),('ufhhbgjnnth'),('ufhvjybz'),('ufkbyf'),('ufkfrnbrf'),('ufptkm'),('ufyljy'),('uganda'),('UGAuG55jdb'),('ugly'),('ugly12'),('ugly123'),('uglybitch1'),('ugochukwu'),('uhbujhbq'),('uhbujhmtdf'),('uhf9QDH'),('uhfaabnb'),('uhfybn8888'),('uifKjhF522'),('uiop'),('uIS9Zdgysn'),('uiuiui'),('ujhjljr'),('ujkjdf'),('ujkjdjkjvrf'),('ujnbrf'),('uk7860loans'),('ukflbfnjh'),('ukflbfnjh12'),('ukflbfnjh12345'),('ukflbjkec'),('ukfveh'),('ukraina'),('ukraine'),('ukraine1'),('ukrnet'),('ukulele'),('uliana'),('ulises'),('ulises1'),('ulisse'),('uloveme'),('ulrich'),('ulrike'),('ulster'),('ultima'),('ultima1'),('ultimate'),('ultimate1'),('ultimatum'),('ultimo'),('ultra'),('ultra1'),('ultraman'),('ultras'),('ultraviolet'),('ulyana'),('ulysse'),('ulysse31'),('ulysses'),('umberto'),('umbrella'),('umbrella1'),('umesh'),('umit1406'),('ummagumma'),('umpire'),('un4given'),('unbreakable'),('uncle'),('uncle1'),('unclesam'),('undead'),('undead1'),('undefined'),('under'),('under0ath'),('under1'),('under18'),('undercover'),('underdog'),('underdog1'),('undergroun'),('underground'),('underoath'),('underoath1'),('underoath7'),('underpants'),('underscore'),('understand'),('undertaker'),('undertaker1'),('undertow'),('underwater'),('underwear'),('underwear1'),('underwood'),('underwood1'),('underworld'),('unfaithful'),('unforgiven'),('unhappy'),('unhappy1'),('uni'),('unicorn'),('unicorn1'),('unicorn12'),('unicorn123'),('unicorn2'),('unicorn7'),('unicornio'),('unicorns'),('unicorns1'),('uniden'),('uniden1'),('uniform'),('unilever'),('union'),('union1'),('unique'),('unique1'),('unique123'),('united'),('united01'),('united1'),('united10'),('united11'),('united12'),('united123'),('united2'),('united7'),('united99'),('unitedkingdom'),('unitedstates'),('unity'),('unity1'),('univer'),('univers'),('univers2l'),('universal'),('universal1'),('universe'),('universe1'),('universidad'),('universita'),('universitario'),('university'),('universo'),('universum'),('unknown'),('unknown1'),('unleashed'),('unleashed1'),('unlimited'),('unlimited1'),('unlock'),('unlock1'),('unloved1'),('unlucky'),('unlucky1'),('unlucky13'),('unnamed'),('unodostres'),('unreal'),('unreal1'),('untitled'),('untouchable'),('update'),('upgrade'),('uphill45'),('upiter'),('upload1'),('upperd7'),('uptown'),('uptown1'),('upyachka'),('upyours'),('upyours1'),('upyours2'),('uQA9Ebw445'),('ural'),('uranium'),('uranus'),('uraura'),('urban'),('urban1'),('urbano'),('urchin'),('urdg5psk5'),('urgay1'),('urlacher54'),('urlaub'),('urmila'),('urmine'),('urmom'),('urmom1'),('urmom12'),('urmom123'),('urmom2'),('urmomma1'),('ursula'),('ursula1'),('ursulet'),('urthe1'),('uruguay'),('uruguay1'),('us4ever'),('us7860loans'),('usa'),('usa123'),('usa1234'),('Usa12345'),('usa1776'),('usa777'),('usajobs'),('usarmy'),('usarmy1'),('usasf1234'),('usausa'),('usausa1'),('UsdopaA'),('useless'),('useless1'),('user'),('user123'),('user1234'),('user888'),('username'),('username1'),('useruser'),('usg242'),('usharani'),('usher'),('usher1'),('usher123'),('usher2'),('usher8701'),('usman'),('usman123'),('usmarine'),('usmarines'),('usmc'),('usmc0311'),('usmc1775'),('usnavy'),('usnavy1'),('usuario'),('usuck'),('usuck1'),('usuck123'),('usuck2'),('utahjazz'),('uthvfy'),('uthvfybz'),('util'),('utility'),('utjhubq'),('utjuhfabz'),('utjvtnhbz'),('utn05wWy'),('utopia'),('utopia1'),('utrecht'),('utvols'),('utythfk'),('utyyflbq'),('uuuu'),('uuuuu'),('uuuuuu'),('uuuuuuu'),('uuuuuuuu'),('UvGX8f8232'),('uyjvbr'),('uyqlvip773'),('uytrewq'),('uzbekistan'),('UzBJNEi451'),('uzumaki'),('uzumaki1'),('uzumaki2'),('uzumakinaruto'),('uzumymw'),('v'),('v000001'),('v00d00'),('v123098'),('v12345'),('v123456'),('v1234567'),('v12345678'),('v123456789'),('v12345b'),('v1ct0ry'),('v1ctoria'),('v3URIAh1'),('v3xAfy4k3Y'),('v647947'),('vacaciones'),('vacance'),('vacances'),('vacation'),('vacation1'),('vaches'),('vacuum'),('vader'),('vader1'),('vader123'),('vadim'),('vadim1'),('vadim123'),('vadimka'),('vadyusha.isaev.83'),('vaemai31'),('vaffanculo'),('vagabond'),('vagarsh'),('vagina'),('vagina!'),('vagina.'),('vagina1'),('vagina12'),('vagina123'),('vagina2'),('vagina69'),('vagner'),('vaibhav'),('vainilla'),('vaishali'),('vaishnavi'),('vaishu'),('vakantie'),('val'),('val123'),('vAl353nxhC'),('valami'),('valdemar'),('valdes'),('valdez'),('valdez1'),('valdivia'),('vale'),('vale123'),('vale46'),('valencia'),('valencia1'),('valent'),('valente'),('valentin'),('valentin1'),('valentina'),('valentina.victoria'),('valentina1'),('valentina2'),('valentine'),('valentine1'),('valentine2'),('valentines'),('valentinka'),('valentino'),('valentino1'),('valentino46'),('valentinorossi'),('valenzuela'),('valera'),('valeri'),('valeria'),('valeria1'),('valeria12'),('valeria123'),('valeria2'),('valerian'),('valerie'),('valerie1'),('valerie12'),('valerie123'),('valerie2'),('valerio'),('valeriy'),('valeriya'),('valerka'),('valeron'),('valery'),('valhalla'),('valhalla1'),('valiant'),('valiente'),('valkenhayn'),('valkiria'),('valkyrie'),('valladolid'),('vallarta'),('vallejo'),('vallejo1'),('vallejo707'),('valley'),('valley1'),('valleyforge'),('valmont'),('valparaiso'),('valter'),('valval'),('valverde'),('valya-city'),('valya-garanina'),('valya-lera1'),('valya-sidenko'),('valya-valya-1982'),('valya.2057'),('valya.gorodn'),('valya.ivko'),('valya.klimenko.87'),('valya.korobeynik'),('valya.kryuchkova.1990'),('valya.lantux.83'),('valya.shapoval'),('vampir'),('vampira'),('vampire'),('vampire!'),('vampire1'),('vampire11'),('vampire12'),('vampire123'),('vampire13'),('vampire2'),('vampire3'),('vampire6'),('vampire666'),('vampire69'),('vampire7'),('vampires'),('vampires1'),('vampiro'),('vampiro1'),('vampyre'),('van'),('van123'),('vanbasten'),('vance1'),('vancouver'),('vancouver1'),('vandah'),('vandal'),('vandam'),('vandamme'),('vandana'),('vander'),('vandread'),('vane123'),('vanechka'),('vanesa'),('vanesa1'),('vaness'),('vanessa'),('vanessa!'),('vanessa.'),('vanessa01'),('vanessa06'),('vanessa1'),('vanessa10'),('vanessa11'),('vanessa12'),('vanessa123'),('vanessa13'),('vanessa14'),('Vanessa141175'),('vanessa15'),('vanessa16'),('vanessa17'),('vanessa18'),('vanessa2'),('vanessa21'),('vanessa22'),('vanessa23'),('vanessa3'),('vanessa4'),('vanessa5'),('vanessa6'),('vanessa7'),('vanessa8'),('vanessa9'),('vangelis'),('vangie'),('vangogh'),('vangogh1'),('vanguard'),('vanguard1'),('vanhalen'),('vanhalen1'),('vanhelsing'),('vania'),('vanila'),('vanilla'),('vanilla1'),('vanilla12'),('vanilla123'),('vanilla2'),('vanille'),('vanille1'),('vanina'),('vanish'),('vanita'),('vanitha'),('vanity'),('vanity1'),('vanna1'),('vanness'),('vannessa'),('vanpersie'),('vanquish'),('vans'),('vans12'),('vans123'),('vans13'),('vanshika'),('vantage'),('vanvan'),('vanya'),('vaquero'),('varadero'),('varanasi'),('vardan'),('varduhigohar'),('varela'),('varfeevich'),('varfolomeeva0990'),('varfolomey_72'),('varga43'),('vargas'),('vargas1'),('vargden'),('varghese'),('varich-masha'),('varico'),('varida.alibaeva'),('varika0'),('varitek33'),('varsha'),('varshini'),('varsity'),('varsity1'),('vartk'),('varun'),('varvar'),('varvara'),('vasant'),('vasanth'),('vasantha'),('vasanthi'),('vasara'),('vasco'),('vasco1'),('vascodagama'),('vascorossi'),('vaseline'),('vaseline1'),('vashenko.u.u'),('vasile'),('vasilek'),('vasilenko'),('vasilev'),('vasileva'),('vasili'),('vasilica'),('vasilii'),('vasilina'),('vasilisa'),('vasiliy'),('vasquez'),('vasquez1'),('vasya'),('vatoloco'),('vatoloco1'),('vatoloco13'),('vatoslocos'),('vaughan'),('vaughan1'),('vaughn'),('vaughn1'),('vauxhall'),('vauxhall1'),('vavava'),('vavilon'),('vaz2101'),('vaz2106'),('vaz2107'),('vaz2108'),('vaz2109'),('vaz21093'),('vaz21099'),('vaz2110'),('vaz2112'),('vaz2114'),('vazquez'),('vazquez1'),('vb'),('vball'),('vball1'),('vball10'),('vball11'),('vball12'),('vball13'),('vball14'),('vball2'),('vball3'),('vball7'),('vbhevbh'),('vbhjckfdf'),('vbhjyjdf'),('vbienrf'),('vbif'),('vbifyz'),('vbitkm'),('vbitymrf'),('vbkbwbz'),('vbkfirf'),('vbkfyf'),('vbkkbjy'),('vbkkbjyth'),('vbktyf'),('vbnmrf'),('vbnvbn'),('vbvbvb'),('vbvjpf'),('vb[fbk'),('vc123456'),('ve'),('vecmrf'),('vector'),('vectra'),('vectra1'),('veczhec'),('vedant'),('vedder'),('vedro.ru'),('vEf6g55frZ'),('vega'),('vegas'),('vegas1'),('vegas123'),('vegas2'),('vegas702'),('vegemite'),('vegeta'),('vegeta1'),('vegeta11'),('vegeta12'),('vegeta123'),('vegeta2'),('vegetable'),('veggie'),('vehpbkrf'),('vehpbr'),('vehvfycr'),('velasco'),('velasquez'),('velazquez'),('velcro'),('veleno'),('velocity'),('velocity1'),('velosiped'),('velvet'),('velvet1'),('ven'),('vencedor'),('vendetta'),('vendetta1'),('vendredi'),('vendredi13'),('venecia'),('veneno'),('venera'),('venere'),('venezia'),('venezuela'),('venezuela1'),('venganza'),('vengeance'),('vengeance1'),('venice'),('venice1'),('venise'),('venividivici'),('venkat'),('venkata'),('venkatesh'),('venom'),('venom1'),('venom123'),('venom666'),('venta021'),('ventana'),('ventilador'),('ventura'),('ventura1'),('venture'),('venture1'),('venugopal'),('venus'),('venus1'),('venus123'),('vepsrf'),('ver'),('vera'),('vera123'),('veracruz'),('veracruz1'),('veralipatnikova'),('verano'),('veravera'),('verbal'),('verbatim'),('verbatim1'),('verdade'),('verdao'),('verde'),('verde1'),('verdes'),('verdun'),('verena'),('vergara'),('vergessen'),('vergessen1'),('vergeten'),('vergil'),('vergine'),('veri1234'),('verify'),('veritas'),('veritas1'),('verite'),('verito'),('verity'),('verizon'),('verizon1'),('verizon123'),('verizon2'),('vermelho'),('vermilion'),('vermillion'),('vermont'),('vermont1'),('vernon'),('vernon1'),('vero'),('vero123'),('verochka'),('verona'),('verona1'),('veronica'),('veronica1'),('veronica10'),('veronica12'),('veronica13'),('veronica2'),('veronica3'),('veronica7'),('veronika'),('veronika1'),('veronique'),('versace'),('versace1'),('versailles'),('versatile'),('verseau'),('version'),('version1'),('versus'),('vertex'),('vertical'),('vertigo'),('vertigo1'),('verto00q'),('verunka'),('verygood'),('verynice'),('vesna'),('vespa'),('vesper'),('Vesproongh12'),('veteran'),('veterinaria'),('veterok'),('vette'),('vette1'),('veverka'),('vf'),('vfcmrf'),('vfcnth'),('vfczyz'),('vfhbfyyf'),('vfhbif'),('vfhbirf'),('vfhbjk1801'),('vfhbyf'),('vfhbyf123'),('vfhbyjxrf'),('vfhbyrf'),('vfhbz'),('vfhcbr'),('vfhctkm'),('vfhecmrf'),('vfhecz'),('vfhnby'),('vfhnbyb'),('vfhnsirf'),('vfhrbp'),('vfhrbpf'),('vfhufhbnf'),('vfhufhbnrf'),('vfhujif'),('vfhvtkfl'),('vfhvtkflrf'),('vfibyf'),('vfiekmrf'),('vfiekz'),('vfieyz'),('vfif'),('vfif123'),('vfifvfif'),('vfitymrf'),('vfkbyf'),('vfkbyrf'),('vfkmdbyf'),('vfkmxbr'),('vfksirf'),('vfktymrbq'),('vfktymrfz'),('vfkzdrf'),('vflbyf'),('vflfufcrfh'),('vfnbkmlf'),('vfndtq'),('vfnehsv'),('vfnhbwf'),('vfnhtirf'),('vfntvfnbrf'),('vfpfafrf'),('vfr750'),('vfr800'),('vfrcbr'),('vfrcbv'),('vfrcbv123'),('vfrcbvec'),('vfrcbvjdf'),('vfrcbvrf'),('vfrfhjd'),('vfrfhjdf'),('vfrfhjys'),('vfrfrf'),('vfuflfy'),('vfufpby'),('vfvecz'),('vfvekbxrf'),('vfvekmrf'),('vfvektxrf'),('vfvekz'),('vfvf'),('vfvf12'),('vfvf123'),('vfvfbgfgf'),('vfvfgfgf'),('vfvfgfgfz'),('vfvfif'),('vfvfvbz'),('vfvfvf'),('vfvfvfvf'),('vfvfvskfhfve'),('vfvfxrf'),('VFvihss591'),('vfvjxrf'),('vfy.yz'),('vfylfhby'),('vfylfhbyrf'),('vfyxtcnth'),('vgizetdinov'),('vh5150'),('VHBtH55jec'),('viagra'),('vianney'),('vibi123'),('vic'),('vic123'),('vic685'),('vicecity'),('vicecity1'),('vicekw'),('vicelord5'),('vicente'),('vicente1'),('vicenza'),('viceroy'),('vicious'),('vicious1'),('vick07'),('vick44'),('vickey'),('vicki'),('vicki1'),('vickie'),('vickie1'),('vicky'),('vicky1'),('vicky12'),('vicky123'),('victim'),('victoire'),('victor'),('victor01'),('victor1'),('victor10'),('victor11'),('victor12'),('victor123'),('victor13'),('victor14'),('victor15'),('victor16'),('victor2'),('victor21'),('victor22'),('victor23'),('victor3'),('victor4'),('victor5'),('victor69'),('victor7'),('victorclavier'),('victorfrunz'),('victorhugo'),('victori1967'),('victoria'),('victoria!'),('victoria-berkat-energo'),('victoria-dyatlova'),('victoria.'),('victoria.20000'),('victoria.kl106'),('victoria01'),('victoria07'),('victoria08'),('victoria1'),('victoria10'),('victoria11'),('victoria12'),('victoria123'),('victoria13'),('victoria14'),('victoria14.09'),('victoria15'),('victoria19'),('victoria2'),('victoria20'),('victoria21'),('victoria22'),('victoria23'),('victoria3'),('victoria392eliezrie1992frp'),('victoria4'),('victoria5'),('victoria6'),('victoria7'),('victoria8'),('victoria9'),('victoria989'),('victoriandr01'),('victoria_002'),('victoria_91'),('victoria_shkurco'),('victorious'),('victoriy70'),('victory'),('victory1'),('victory123'),('victory2'),('victory7'),('victor_evdokimov'),('victor_sakhalin1990-20'),('vicusa.tatyana'),('vicvic'),('vida'),('vidaloca'),('vidaloka'),('vidanova'),('vidanueva'),('video'),('video1'),('video123'),('videogame'),('videogame1'),('videogames'),('videos'),('vidhya'),('vieira'),('vienna'),('vienna1'),('vierge'),('viernes'),('viernes13'),('viet12'),('vietnam'),('vietnam1'),('viewsonic'),('viewsonic1'),('vigilante'),('vignesh'),('vihlaeva2012'),('vihotsieva94'),('vihrova1974'),('vijay'),('vijay123'),('vijaya'),('vijaykumar'),('vik'),('vik22535477'),('vika'),('vika-selfish'),('vika.krivonos.1995'),('vika123'),('vika1994'),('vika1995'),('vika1996'),('vika1997'),('vika1998'),('vika2010'),('vikas'),('vikas123'),('vikash'),('vikatc'),('vikavika'),('viki'),('viking'),('viking1'),('viking11'),('viking12'),('viking123'),('vikingo'),('vikings'),('vikings1'),('vikings11'),('vikings12'),('vikings2'),('vikings28'),('vikram'),('viktor'),('viktor1'),('viktori'),('viktoria'),('viktoria1'),('viktorija'),('viktoriy'),('viktoriya'),('viktory'),('vikusya'),('villa'),('villa1'),('villa123'),('village'),('village1'),('villalobos'),('villamor'),('villanova'),('villanueva'),('villareal'),('villarreal'),('villas'),('ville'),('ville1'),('ville666'),('villegas'),('villeneuve'),('villevalo'),('villevalo1'),('vilma'),('vilnius'),('vimala'),('vin'),('vin123'),('vinay'),('vinay123'),('vinayak'),('vinayaka'),('vince'),('vince1'),('vince10'),('vince123'),('vince15'),('vincent'),('vincent01'),('vincent1'),('vincent11'),('vincent12'),('vincent123'),('vincent13'),('vincent2'),('vincent3'),('vincent5'),('vincent7'),('vincenza'),('vincenzo'),('vincenzo1'),('vindiesel'),('vineet'),('vineyard'),('vinicio'),('vinicius'),('vining1'),('vinita'),('vinnie'),('vinnie1'),('vinny'),('vinny1'),('vinny123'),('vinod'),('vinograd'),('vinoth'),('vintage'),('vintage1'),('vinter'),('vinvin'),('viola'),('viola1'),('violator'),('violence'),('violet'),('violet1'),('violet12'),('violet123'),('violeta'),('violeta1'),('violetta'),('violette'),('violin'),('violin1'),('violino'),('violon'),('viorel'),('viorica'),('vip'),('vip123'),('viper'),('viper1'),('viper12'),('viper123'),('viper13'),('viper2'),('viper69'),('viper7'),('vipera'),('vipergts'),('vipers'),('vipers1'),('ViPHV5J736'),('vipvip'),('vip_trading'),('vir'),('virago'),('virendra'),('virgen'),('virgie'),('virgil'),('virgil1'),('virgilio'),('Virgilio12'),('virgin'),('virgin1'),('virginia'),('virginia1'),('virginia12'),('virginia2'),('virginie'),('virgo'),('virgo1'),('virgo123'),('virgola'),('virgos'),('virgule'),('viriato'),('viridiana'),('viridiana1'),('virtual'),('virtual1'),('virtue'),('virtue1234'),('virtus'),('virus'),('virus1'),('virus123'),('viruss'),('visa'),('vishakha'),('vishal'),('vishal123'),('vishenka'),('vishnu'),('vishwa'),('vision'),('vision1'),('vision123'),('visions'),('visitor'),('vissen'),('vista'),('vista1'),('visual'),('vit'),('vita'),('vitali'),('vitalik'),('vitalina'),('vitaliy'),('vitaly'),('vitalya'),('vitamia'),('vitamin'),('vitamin1'),('vitamina'),('vitamine'),('vitaminka88'),('vitara'),('vitesse'),('vitinho'),('vito'),('vitolino10'),('vitor'),('vitor1'),('vitor123'),('vitor1268123'),('vitoria'),('vitoria1'),('vittoria'),('vittorio'),('viv'),('viva'),('vivalabam'),('vivalabam1'),('vivalafica'),('vivalafiga'),('vivalavida'),('vivaldi'),('vivamexico'),('vivayo'),('vivek'),('vivek123'),('vivemoi'),('vivera'),('vivere'),('vivi'),('vivi123'),('vivian'),('vivian1'),('vivian123'),('viviana'),('viviana1'),('viviane'),('vivien'),('vivienne'),('vivitron'),('vivivi'),('vixen'),('vixen1'),('vj'),('vjcrdbx'),('vjcrdf'),('vjfLkiG522'),('vjhjpjd'),('vjhjpjdf'),('vjhrjdrf'),('vjkjltw'),('vjkjrj'),('vjq'),('vjqgfhjkm'),('vJS9Zdgyrn'),('vjybnjh'),('vjz'),('vjzctvmz'),('vjzgjxnf'),('vkontakte'),('vkontakte.ru'),('vkontkate'),('vkoomare88'),('vkorotin'),('vkors'),('vkoryano'),('vkot_2010'),('vkoval87'),('vkovshut_annab1988fg'),('vkpxrnoda'),('vkravchenko'),('vkrbashyan'),('vkryshkin'),('vks1zz9v_7ceu69'),('vktorov'),('vkulak'),('vkundeyai'),('vkuradovetc'),('vk_vk_777'),('vlad'),('vlad123'),('vlad1234'),('vlad12345'),('vlad1994'),('vlad1995'),('vlad1996'),('vlad1997'),('vlad1998'),('vlad1999'),('vlad2000'),('vlad777'),('vlada'),('vlada1206'),('vladcherktecktonik'),('vladik'),('vladimir'),('vladimir1'),('vladimirovna'),('vladislav'),('vladislava'),('vladivostok'),('vladka'),('vladut'),('vladvlad'),('vlasov'),('vlasova'),('vlasta'),('vlinder'),('vm.shlykov'),('vodafone'),('vodafone1'),('vodka'),('vodka1'),('vodka123'),('vodolei'),('vodoley'),('voetbal'),('voetbal1'),('voices'),('voiture'),('voitures'),('vojta'),('vojykGi959'),('vol'),('voland'),('volare'),('volcan'),('volcano'),('volcano1'),('volcom'),('volcom!'),('volcom1'),('volcom11'),('volcom12'),('volcom123'),('volcom13'),('volcom14'),('volcom2'),('volcom21'),('volcom22'),('volcom23'),('volcom3'),('volcom5'),('volcom69'),('volcom7'),('volcom8'),('volcom9'),('voldemar'),('voldemort'),('voldemort1'),('volfram.kozlov123633'),('volfram.kozlov173902'),('volga11955'),('volgirevagv'),('volgograd'),('volgograd.orlovka'),('volhina-73'),('volhsara56'),('voliahim1891'),('volik-yulia'),('volimte'),('volimte1'),('voljanka1976'),('volkan'),('volker'),('volkodav'),('volkorez'),('volkov'),('volkova'),('volkova.67'),('volkova.elena.13'),('volkova.ksyusha.89'),('volkovanata77'),('volkovaolguna'),('volkovoi_net'),('volkslt35'),('volkswagen'),('volkswagon'),('volley'),('volley1'),('volley11'),('volley12'),('volleybal1'),('volleyball'),('volleyball1'),('vollyball1'),('volodia'),('volodina.elena66'),('volodya'),('volodya-ivanov-63'),('vologda'),('volohovich-t'),('volokitina.olga'),('voloshink'),('voltage'),('voltage1'),('voltaire'),('voltron'),('voltron1'),('volume'),('volume1'),('volunteer'),('volunteer1'),('volvic'),('volvo'),('volvo1'),('volvo123'),('volvo240'),('volvo740'),('volvo850'),('volvofh12'),('volvos40'),('volvos60'),('volvos80'),('volvov40'),('volvov70'),('volvoxc90'),('vondutch'),('vonnie'),('vonnie1'),('vonvon'),('voodoo'),('voodoo1'),('voodoo13'),('voodoo2'),('vorobei'),('vorobey'),('vorona'),('voronin'),('voroshilova.liliya'),('vortex'),('vortex1'),('vostok'),('vote4pedro'),('Voting'),('vova'),('vova123'),('vova1997'),('vova1998'),('vova436'),('vovan'),('vovavova'),('vovchik'),('vovochka'),('voyage'),('voyager'),('voyager1'),('VQsaBLPzLa'),('Vqz6QyO294'),('vRbGQnS997'),('vredina'),('vrushali'),('vs-nd'),('vsevolod'),('vsijyjr'),('vSjasnel12'),('vt'),('vthctltc'),('vtkmybr'),('vtkmybrjdf'),('vtkrbq'),('vtldtlm'),('vtuf36jhufpv'),('vtufajy'),('vtufgjkbc'),('vtx1800'),('vuc7neyu0'),('vuitton'),('vulcan'),('vulcan1'),('vulcano'),('vulkan'),('vulture'),('vvv'),('vvv666vvv'),('vvvv'),('vvvvv'),('vvvvvv'),('vvvvvvv'),('vvvvvvvv'),('vvvvvvvvvv'),('vwgolf'),('vwjetta'),('vwpassat'),('vwpolo'),('vyacheslav'),('vyjujnjxbt'),('w'),('w00tw00t'),('w0rdpass'),('w111111'),('w12101957'),('w12345'),('w123456'),('w1234567'),('w12345678'),('w123456789'),('w123456789w'),('w1950a'),('w1952a'),('w1953a'),('w1954a'),('w1955a'),('w1956a'),('w1957a'),('w1958a'),('w1959a'),('w1960a'),('w1961a'),('w1962a'),('w1963a'),('w1964a'),('w1965a'),('w1966a'),('w1967a'),('w1968a'),('w1969a'),('w1970a'),('w1971a'),('w1972a'),('w1973a'),('w1974a'),('w1975a'),('w1976a'),('w1977a'),('w1978a'),('w1979a'),('w1980a'),('w1981a'),('w1982a'),('w1983a'),('w1984a'),('w1985a'),('w1986a'),('w1987a'),('w1988a'),('w1989a'),('w1990a'),('w1991a'),('w1992a'),('W1aUbvOQ'),('w1ll1am'),('w1ll1ams'),('w1lliam'),('w1w1w1'),('w1w2w3'),('w1w2w3w4'),('w2e3r4'),('w2e3r4t5'),('w2w2w2'),('w3lc0m3'),('w3wjnhek'),('W45bj9upkZ'),('W5tn36alfW'),('W5tXn36alfW'),('w66YRyBgRa'),('w8aGc47klA'),('w8woord'),('w9998999'),('wabbit'),('wachtwoord'),('wachtwoord1'),('wacker'),('waco254'),('waddle'),('wade'),('wade03'),('wade123'),('wade23'),('waffenss'),('waffle'),('waffle1'),('waffles'),('waffles1'),('waffles2'),('wagner'),('wagner1'),('wahaha'),('waheed'),('waheguru'),('waheguru1'),('waheguruji'),('wahoo1'),('wahyu'),('waikiki'),('waiting'),('waiting1'),('waiting4u'),('wakacje'),('wakaflocka'),('wakana'),('wakawaka'),('wakeboard'),('wakeboard1'),('wakefield'),('wakeup'),('wakeup1'),('wal'),('wal-mart'),('walalang'),('waldemar'),('walden'),('waldiw82'),('waldo'),('waldo1'),('waldorf'),('wale'),('waleed'),('wales'),('wales1'),('walgreens1'),('walhalla'),('walid'),('walik007'),('walker'),('walker01'),('walker1'),('walker11'),('walker12'),('walker123'),('walker2'),('walkers'),('walking'),('walking1'),('walkitout1'),('walkman'),('walkman1'),('wall.e'),('wallace'),('wallace1'),('wallace2'),('wallace3'),('waller'),('wallet'),('walleye'),('walleye1'),('wallflower'),('wallis'),('wallpaper'),('wallpaper1'),('wallst'),('wallstreet'),('wally'),('wally1'),('wally123'),('walmart'),('walmart1'),('walmart2'),('walnut'),('walnut1'),('walrus'),('walrus1'),('waltdisney'),('walter'),('walter01'),('walter1'),('walter11'),('walter12'),('walter123'),('walter2'),('walter34'),('walters'),('walters1'),('walther'),('walton'),('walton1'),('wambui'),('wan'),('wan0425'),('wan123'),('wanadoo'),('wanda'),('wanda1'),('wanda123'),('wander'),('wanderer'),('wanderers'),('wanderlust'),('wang'),('wang123'),('wang123456'),('wangjian'),('wangjing'),('wanglei'),('wangwang'),('wangwei'),('wangyang'),('wangyut2'),('wanita'),('wanjiku'),('wanjiru'),('wanker'),('wanker1'),('wanker123'),('wankers'),('wankers1'),('wanksta'),('wannabe'),('wannabe1'),('wannadupe'),('wanrltw'),('wanshuai198202'),('wanted'),('wanted1'),('Wanted123'),('wanwan'),('wapiti'),('wapwap'),('waqas123'),('war'),('war123'),('warcraft'),('warcraft1'),('warcraft12'),('warcraft123'),('warcraft2'),('warcraft3'),('warcraft4'),('ward'),('ward86'),('warden'),('wardog'),('wareagle'),('wareagle1'),('warehouse'),('warehouse1'),('warface'),('warfare'),('warfreak'),('wargames'),('warhammer'),('warhammer1'),('warhammer4'),('warhammer40k'),('warhawk'),('warhead'),('warhol'),('warior'),('warlock'),('warlock1'),('warlord'),('warlord1'),('warlords'),('warner'),('warner1'),('warning'),('warning1'),('warped'),('warpten'),('warranty'),('warren'),('warren1'),('warren123'),('warrington'),('warrior'),('warrior1'),('warrior11'),('warrior12'),('warrior123'),('warrior13'),('warrior2'),('warrior3'),('warrior5'),('warrior7'),('warriors'),('warriors1'),('warriors12'),('warriors2'),('warrock'),('warsaw'),('warszawa'),('warszawa1'),('warthog'),('warthog1'),('wartune'),('warwar'),('warwick'),('warwick1'),('warzone'),('was'),('was123'),('wasabi'),('wasabi1'),('wasalak'),('wasd'),('wasd123'),('wasd1234'),('wasdqe'),('wasdwasd'),('waseem'),('washburn'),('washburn1'),('washere'),('washington'),('washington1'),('wass123'),('wassa12345'),('wasser'),('wasser1'),('wasser123'),('wassermann'),('wassila'),('wassim'),('wassup'),('wassup1'),('wasted'),('wasted1'),('wasup1'),('waswas'),('waswas1'),('wat'),('watanabe'),('watashi'),('watch'),('watch1'),('watchdog'),('watcher'),('watchout'),('watchtower'),('water'),('water!'),('water1'),('water10'),('water11'),('water12'),('water123'),('water1234'),('water13'),('water2'),('water21'),('water22'),('water23'),('water3'),('water4'),('water5'),('water7'),('waterart'),('waterboy'),('waterboy1'),('waterfall'),('waterfall1'),('waterfalls'),('waterford'),('watergate'),('waterh20'),('waterh2o'),('waterlily'),('waterloo'),('waterloo1'),('waterman'),('waterman1'),('watermelon'),('watermelon1'),('waterpolo'),('waterpolo1'),('waters'),('waters1'),('waterski'),('waterwater'),('wateva'),('wateva1'),('watever'),('watever1'),('watford'),('watford1'),('watitdo1'),('watkins'),('watkins1'),('watson'),('watson1'),('watson831'),('watsup'),('watsup1'),('watts1'),('watup1'),('wave125'),('waverly'),('wawa'),('wawa123'),('wawawa'),('way2cool'),('way2go'),('waylon'),('waylon1'),('wayne'),('wayne1'),('wayne11'),('wayne12'),('wayne123'),('wayne13'),('wayne2'),('wayne21'),('wayne22'),('wayne23'),('wayne3'),('wayne5'),('waynerooney'),('waynes'),('wazup'),('wazup1'),('wazzup'),('wazzup1'),('wcdd93H9pQ'),('wdtnjr'),('wdtnjxtr'),('we'),('we1234'),('wealth'),('wealthy'),('wealthy1'),('weapon'),('weapons'),('weare1'),('weare138'),('weareone'),('weasel'),('weasel1'),('weasley'),('weather'),('weather1'),('weaver'),('weaver1'),('web'),('web123'),('webber'),('webber1'),('webbie1'),('webcam'),('webcam1'),('webcode1'),('webhompass'),('webkinz'),('webkinz1'),('webkinz12'),('webkinz123'),('webmaster'),('webmaster1'),('webmaster123'),('website'),('website1'),('webster'),('webster1'),('webster7'),('wedding'),('wedding07'),('wedding08'),('wedding09'),('wedding1'),('wedding65'),('weddings'),('wednesday'),('wednesday1'),('wee'),('wee123'),('weed'),('weed01'),('weed101'),('weed11'),('weed12'),('weed123'),('weed1234'),('weed13'),('weed14'),('weed21'),('weed22'),('weed23'),('weed420'),('weed4life'),('weed4me'),('weed666'),('weed69'),('weedhead'),('weedhead1'),('weedman'),('weedman1'),('weedman420'),('weeds1'),('weedweed'),('weedweed1'),('weekend'),('weekend1'),('weeman'),('weeman1'),('weener'),('weener1'),('weenie'),('weenie1'),('weevil'),('weewee'),('weewee1'),('weezer'),('weezer1'),('weezie'),('weezy'),('weezy1'),('weezy12'),('weezy123'),('weezybaby1'),('weezyfbaby'),('weg63TT243'),('wehttam'),('weight'),('weiner'),('weiner1'),('weird'),('weird1'),('weirdo'),('weirdo1'),('weiwei'),('wel'),('welc0me'),('welcom'),('welcome'),('welcome!'),('welcome0'),('welcome01'),('welcome1'),('welcome10'),('welcome11'),('welcome12'),('welcome123'),('welcome1234'),('welcome12345'),('welcome2'),('welcome22'),('welcome3'),('welcome4'),('welcome5'),('welcome6'),('welcome7'),('welcome8'),('welcome9'),('welcome99'),('welcome@123'),('welder'),('welder1'),('welding'),('welding1'),('weldon'),('welkom'),('welkom01'),('welkom1'),('welkom123'),('wellcome'),('wellcome1'),('welldone'),('weller'),('wellington'),('wellness'),('wembley'),('wendel'),('wendell'),('wendell1'),('wendi'),('wendy'),('wendy1'),('wendy12'),('wendy123'),('wendy2'),('wendys'),('wendys1'),('wenef45313'),('wenger'),('wenoob'),('wentworth'),('wentworth1'),('wenwen'),('wenyin12'),('wer'),('wer11111'),('wer123'),('wer123456'),('wer138'),('wer234'),('werder'),('werder1'),('werderbremen'),('werdna'),('werdna1'),('were'),('were12'),('were123'),('werewere'),('werewolf'),('werewolf1'),('werilopert'),('werken'),('werner'),('werner1'),('werock'),('werock!'),('werock1'),('weronika'),('weronika1'),('weronika1992'),('wersdf'),('wert'),('wert12'),('wert123'),('wert1234'),('werter'),('werthrf'),('werthvfy'),('wertwert'),('werty'),('werty1'),('werty12'),('werty123'),('werty12345'),('werty7'),('wertyu'),('wertyu1'),('wertyui'),('wertyuio'),('wertyuiop'),('wertzu'),('werule1'),('werwer'),('werwer1'),('werwerwer'),('werwolf'),('wes'),('wes123'),('wesley'),('wesley01'),('wesley1'),('wesley12'),('wesley123'),('wesley2'),('west'),('west11'),('west12'),('west123'),('west1234'),('west13'),('west14'),('west23'),('west49'),('westbrom'),('westbrom1'),('westbrook'),('westbrook1'),('westcoast'),('westcoast1'),('westend'),('westend1'),('wester'),('western'),('western1'),('westfield'),('westfield1'),('westgate'),('westham'),('westham1'),('westham123'),('westie'),('westlake'),('westlife'),('westlife1'),('westminster'),('weston'),('weston1'),('westpoint'),('westport'),('westside'),('westside!'),('westside1'),('westside10'),('westside11'),('westside12'),('westside13'),('westside14'),('westside18'),('westside2'),('westside21'),('westside23'),('westside3'),('westside4'),('westside5'),('westside6'),('westside69'),('westside7'),('westwest'),('westwind'),('westwood'),('westwood1'),('wet'),('wethebest'),('wethebest1'),('wethepeople'),('wetpussy'),('wetpussy1'),('wetpussy69'),('wetter'),('wetwet'),('wetwet1'),('wetwilly'),('wewe'),('wewe123'),('wewewe'),('wewewe1'),('wewewewe'),('wexford'),('weyersheim'),('weyfvb'),('weymouth'),('wezzy1'),('wg8e3wjf'),('whale'),('whale1'),('whales'),('whales1'),('what'),('what11'),('what12'),('what123'),('what1234'),('what2do'),('what3v3r'),('whateva'),('whateva1'),('whatever'),('whatever!'),('whatever.'),('whatever0'),('whatever01'),('whatever08'),('whatever09'),('whatever1'),('whatever10'),('whatever11'),('whatever12'),('whatever123'),('whatever13'),('whatever14'),('whatever2'),('whatever21'),('whatever22'),('whatever23'),('whatever3'),('whatever4'),('whatever5'),('whatever6'),('whatever69'),('whatever7'),('whatever8'),('whatever9'),('whatif'),('whatisit'),('whatislove'),('whatisthis'),('whatitdo'),('whatitdo1'),('whatnot'),('whatnow'),('whatnow1'),('whatsup'),('whatsup1'),('whatsup123'),('whatsup2'),('whatthe'),('whatthe1'),('whatthefuc'),('whatthefuck'),('whatthehel'),('whatthehell'),('whatthezor'),('whatup'),('whatup1'),('whatwhat'),('whatwhat1'),('wheelchair'),('wheeler'),('wheeler1'),('wheeling'),('wheels'),('wheels1'),('whi'),('whiplash'),('whippet'),('whiskas'),('whiskers'),('whiskers1'),('whiskey'),('whiskey1'),('whisky'),('whisky1'),('whisper'),('whisper1'),('whistle'),('whistler'),('whistler1'),('white'),('white1'),('white12'),('white123'),('white2'),('white23'),('whiteangel'),('whiteboy'),('whiteboy1'),('whitecat'),('whitedog'),('whitefang'),('whitegirl'),('whitegirl1'),('whitehead'),('whitehorse'),('whitehouse'),('whiteman'),('whiteout'),('whitepower'),('whiterabbit'),('whiterose'),('whites'),('whitesnake'),('whitesox'),('whitesox05'),('whitesox1'),('whitetail'),('whitetail1'),('whitetiger'),('whitewater'),('whitewolf'),('whitewolf1'),('whitey'),('whitey1'),('whiting'),('whitley'),('whitley1'),('whitman'),('whitney'),('whitney1'),('whitney12'),('whitney2'),('whitney7'),('whittier'),('who'),('whoami'),('whoami1'),('whoareyou'),('whoareyou1'),('whocares'),('whocares1'),('whodat'),('whodat1'),('whoknows'),('whoknows1'),('wholefoo'),('wholesale'),('whoops'),('whoopwhoop'),('whopper'),('whopper1'),('whore'),('whore!'),('whore.'),('whore1'),('whore12'),('whore123'),('whore2'),('whore69'),('whorebag1'),('whores'),('whores1'),('whosyourdaddy'),('why'),('why123'),('whyme'),('whyme1'),('whyme123'),('whyme2'),('whyme?'),('whynot'),('whynot1'),('whysoserious'),('whywhy'),('wi11iam'),('wibble'),('WIBsH56kec'),('wicca'),('wicca1'),('wiccan'),('wiccan1'),('wichita'),('wicked'),('wicked!'),('wicked1'),('wicked12'),('wicked123'),('wicked13'),('wicked2'),('wicked69'),('wicket'),('widder'),('widescreen'),('widget'),('widzew'),('widzew1910'),('wiener'),('wife'),('wifey'),('wifey1'),('wigger1'),('wiggins'),('wiggle'),('wiggle1'),('wiggles'),('wiggles1'),('wigolf'),('wigwam'),('wii123'),('wijaya'),('wiktor'),('wiktor1'),('wiktoria'),('wiktoria1'),('wil'),('wilber'),('wilbert'),('wilbert1'),('wilbur'),('wilbur1'),('wilcox'),('wild'),('wildbill'),('wildcard'),('wildcat'),('wildcat1'),('wildcat2'),('wildcat7'),('wildcats'),('wildcats!'),('wildcats1'),('wildcats10'),('wildcats11'),('wildcats12'),('wildcats14'),('wildcats2'),('wildcats3'),('wildcats7'),('wildchild'),('wildchild1'),('wilder'),('wilderness'),('wildfire'),('wildfire1'),('wildflower'),('wildhorses'),('wildlife'),('wildlife1'),('wildman'),('wildman1'),('wildone'),('wildone1'),('wildones'),('wildrose'),('wildthing'),('wildthing1'),('wildwest'),('wildwood'),('wildwood1'),('wiley1'),('wilfred'),('wilfred1'),('wilfredo'),('wilfredo1'),('wilfried'),('wilhelm'),('wilhelmina'),('wilkins'),('wilkinson'),('wilkinson1'),('will'),('will11'),('will12'),('will123'),('will1234'),('will22'),('will23'),('willard'),('willard1'),('willem'),('willi'),('willi1'),('william'),('william!'),('william.'),('william0'),('william01'),('william02'),('william03'),('william05'),('william06'),('william07'),('william08'),('william09'),('william1'),('william10'),('william11'),('william12'),('william123'),('william13'),('william14'),('william15'),('william16'),('william17'),('william18'),('william19'),('william2'),('william20'),('william21'),('william22'),('william23'),('william24'),('william25'),('william2631'),('william3'),('william4'),('william5'),('william6'),('william69'),('william7'),('william77'),('william8'),('william88'),('william9'),('william99'),('williams'),('williams1'),('williams11'),('williams12'),('williams2'),('williams3'),('williamson'),('willian'),('willie'),('willie01'),('willie1'),('willie11'),('willie12'),('willie123'),('willie2'),('willie22'),('willie3'),('willis'),('willis1'),('willow'),('willow01'),('willow1'),('willow11'),('willow12'),('willow123'),('willow13'),('willow2'),('willow3'),('willows'),('willpower'),('willsmith'),('willsmith1'),('willwill'),('willy'),('willy1'),('willy12'),('willy123'),('willy2'),('willyou'),('willys'),('willywonka'),('wilma'),('wilma1'),('wilmar'),('wilmer'),('wilmington'),('wilson'),('wilson01'),('wilson1'),('wilson10'),('wilson11'),('wilson12'),('wilson123'),('wilson13'),('wilson2'),('wilson21'),('wilson22'),('wilson23'),('wilson3'),('wilson5'),('wilton'),('wimbledon'),('win'),('win123'),('win2000'),('winamp'),('winchester'),('wind'),('windex'),('windex1'),('windmill'),('windmill1'),('window'),('window1'),('window12'),('window123'),('window2'),('windows'),('windows1'),('windows12'),('windows123'),('windows2'),('windows2000'),('windows7'),('windows8'),('windows95'),('windows98'),('windowsvista'),('windowsxp'),('windowsxp1'),('windsong'),('windsor'),('windsor1'),('windstar'),('windsurf'),('windy'),('windy1'),('wine'),('winfield'),('winfixer'),('wingchun'),('winger'),('wingman'),('wingman1'),('wingnut'),('wingnut1'),('wings'),('wings1'),('wingwing'),('wingzero'),('wingzero1'),('winifred'),('winkie'),('winkle'),('winky1'),('winmx1'),('winner'),('winner01'),('winner1'),('winner11'),('winner12'),('winner123'),('winner2'),('winners'),('winners1'),('winnie'),('winnie01'),('winnie1'),('winnie11'),('winnie12'),('winnie123'),('winnie2'),('winniepooh'),('winniethep'),('winniethepooh'),('winning'),('winnipeg'),('winnipeg2612'),('winona'),('winslow'),('winslow1'),('winston'),('winston01'),('winston1'),('winston12'),('winston123'),('winston2'),('winston3'),('winston7'),('winter'),('winter00'),('winter01'),('winter02'),('winter04'),('winter05'),('winter06'),('winter07'),('winter08'),('winter09'),('winter1'),('winter10'),('winter11'),('winter12'),('winter123'),('winter13'),('winter2'),('winter2008'),('winter2009'),('winter2010'),('winter2011'),('winter21'),('winter22'),('winter23'),('winter3'),('winter5'),('winter7'),('winter77'),('winter98'),('winter99'),('winters'),('winters1'),('winthrop'),('winwin'),('winwinwin'),('winxclub'),('winxp'),('wiosna'),('wipeout'),('wipro'),('wipro@123'),('wireless'),('wireless1'),('wisconsin'),('wisconsin1'),('wisdom'),('wisdom1'),('wisdom12'),('wisdom123'),('wise'),('wiseguy'),('wiseman'),('wiseman1'),('wishbone'),('wishbone1'),('wishes'),('wishing'),('wishmaster'),('wisteria'),('witch'),('witch1'),('witchcraft'),('witcher'),('witches'),('witchy'),('witchy1'),('withgod'),('withlove'),('withoutu'),('withyou'),('witness'),('witspass1234'),('wizard'),('wizard01'),('wizard1'),('wizard101'),('wizard12'),('wizard123'),('wizard13'),('wizards'),('wizards1'),('wizkhalifa'),('wizkid'),('wizzard'),('wjsswj'),('wkgMkjH623'),('wkgMmjH623'),('wladimir'),('wlafica'),('wlafiga'),('wm0001'),('wmilan'),('wmtmufc1'),('wo123456'),('woailaopo'),('woaimama'),('woaini'),('woaini1'),('woaini123'),('woaini1314'),('woaini520'),('woaini521'),('woainia'),('woainima'),('woaiwojia'),('woaiwoziji'),('wobble'),('wobuzhidao'),('wocao5201314'),('wocaonima'),('wodemima'),('WoE45bYzRY'),('wojiushiwo'),('wojtek'),('wojtek1'),('Wokami'),('wol'),('wolf'),('wolf01'),('wolf1'),('wolf11'),('wolf12'),('wolf123'),('wolf1234'),('wolf13'),('wolf22'),('wolf359'),('wolf666'),('wolf69'),('wolfdog'),('wolfen'),('wolfenstein'),('wolfgang'),('wolfgang1'),('wolfie'),('wolfie1'),('wolfman'),('wolfman1'),('wolfpac'),('wolfpack'),('wolfpack1'),('wolfteam'),('wolfwolf'),('wolfy'),('wolfy1'),('wolverin'),('wolverine'),('wolverine1'),('wolverine2'),('wolverine3'),('wolverine7'),('wolverines'),('wolves'),('wolves1'),('wolves11'),('wolves12'),('wolves123'),('wolves2'),('woman'),('woman1'),('womanizer'),('wombat'),('wombat1'),('womble'),('women'),('women1'),('wonder'),('wonder1'),('wonder123'),('wonderboy'),('wonderboy1'),('wonderful'),('wonderful1'),('wonderful2'),('wonderfull'),('wondergirl'),('wonderland'),('wonderman2'),('wonders'),('wonderwall'),('wonderwoma'),('wonderwoman'),('wonka1'),('wonton'),('woo'),('woobie'),('wood'),('wood123'),('woodbine'),('woodbury'),('woodchuck'),('woodduck'),('wooden'),('woodie'),('woodie1'),('woodland'),('woodland1'),('woodlands'),('woodlawn'),('woodman'),('woodman1'),('woodpecker'),('woodrow'),('woodrow1'),('woods'),('woods1'),('woodside'),('woodside1'),('woodson'),('woodstock'),('woodstock1'),('woodward'),('woodward1'),('woodwind'),('woodwork'),('woody'),('woody1'),('woody12'),('woody123'),('woody2'),('woof'),('woofer'),('woofer1'),('woofie'),('woofwoof'),('woofwoof1'),('woogie'),('woogie1'),('woohoo'),('woohoo!'),('woohoo1'),('wookie'),('wookie1'),('woopwoop'),('wooster'),('wootwoot'),('wootwoot1'),('woowoo'),('woowoo1'),('worcester'),('word'),('word12'),('word123'),('wordlife'),('wordlife1'),('wordpass'),('wordpass1'),('wordpass12'),('wordpass2'),('wordup'),('wordup1'),('worinima'),('work'),('work123'),('work1234'),('work4me'),('worker'),('worker1'),('workhard'),('working'),('working1'),('workout'),('workout1'),('workshop'),('worksucks'),('workwork'),('world'),('world1'),('world123'),('worldcup'),('worldofwarcraft'),('worldpeace'),('worlds'),('worldwar'),('worldwar2'),('worldwide'),('worldwide1'),('worm'),('wormix'),('worms'),('wormwood'),('worship'),('worship1'),('worthy'),('woshishei'),('woshishei319'),('woshishen'),('woshishui'),('woshiwo'),('woshiyazi'),('woshizhu'),('wouter'),('wow'),('wow101'),('wow123'),('wow1234'),('wow12345'),('wowowee'),('wowowo'),('wowwow'),('wowwow1'),('wpcAKir264'),('wqer1314'),('wqwqwq'),('wraith'),('wrangler'),('wrangler1'),('wrasloco11'),('wrench'),('wrestle'),('wrestle1'),('wrestlemania'),('wrestler'),('wrestler1'),('wrestling'),('wrestling1'),('wrestling2'),('wrestling3'),('wrestling7'),('wrexham'),('wright'),('wright1'),('wright5'),('wrigley'),('wrigley1'),('wrinkle1'),('wrinkles'),('wrinkles1'),('writer'),('writer1'),('writing'),('wroclaw'),('wrong1'),('wrxsti'),('ws123456'),('wsadwsad'),('wsbe279qSG'),('wsky0o0o0o'),('wsx123'),('wsx123456'),('wsxcde'),('wsxedc'),('wsxqaz'),('wsxwsx'),('wsxzaq'),('WsYDCIG761'),('wtf'),('wtf123'),('wtfwtf'),('wtpfhm'),('wtpmjg'),('wtpmjgda'),('wu-tang'),('wubin007'),('wuchun'),('wulandari'),('wumeiyun123'),('wunderbar'),('wuschel'),('wutang'),('wutang1'),('wutang36'),('wutangclan'),('ww111111'),('ww123456'),('ww651118'),('wwd100'),('wwe'),('wwe.com'),('wwe123'),('wwe1234'),('wwe12345'),('wwe4life'),('wwe619'),('wwefan1'),('wweraw'),('wweraw1'),('wwewwe'),('wwewwe1'),('wwjd'),('www'),('www.com'),('www.ivan-18'),('www111'),('www123'),('www12345'),('www123456'),('www222'),('www333'),('www777'),('WWWAAABBB'),('wwwamador91'),('wwweee'),('wwwksenechkawww'),('wwwooo1234'),('wwww'),('wwwww'),('wwwww1'),('wwwwww'),('wwwwww1'),('wwwwwww'),('wwwwwww1'),('wwwwwwww'),('wwwwwwwww'),('wwwwwwwwww'),('wxcvbn'),('wxcvbn123'),('wy1000000'),('wyatt'),('wyatt1'),('wyatt123'),('wybe4591'),('wyoming'),('wyoming1'),('wysiwyg'),('wyvern'),('wz362308'),('WZF2SmE498'),('wZQ8Xcfxqm'),('wZR8Ycfxrm'),('x'),('x0x0x0'),('x100pre'),('x12345'),('x123456'),('x1234567'),('x123456789'),('x123456x'),('X15piq8snJ'),('x1x1x1'),('x1x2x3'),('x1x2x3x4'),('x2x2x2'),('X3LUym2MMJ'),('x444am'),('x4ivygA51F'),('X60zAY0468'),('x72jHhu3Za'),('x7BktntLEz'),('x7vs8mxg'),('x870624X'),('x8AxspuMEz'),('X8coQx1F1zh'),('X99QOmx561'),('xalitova1988'),('xanadu'),('xanadu1'),('xander'),('xander1'),('xandra'),('xantia'),('Xantria10315'),('xavier'),('xavier01'),('xavier04'),('xavier05'),('xavier06'),('xavier07'),('xavier08'),('xavier09'),('xavier1'),('xavier10'),('xavier11'),('xavier12'),('xavier123'),('xavier13'),('xavier14'),('xavier2'),('xavier21'),('xavier22'),('xavier23'),('xavier3'),('xavier4'),('xavier5'),('xavier7'),('xaxaxa'),('XBLhInTB9w'),('xbonesx'),('xbox'),('xbox123'),('xbox360'),('xbox3600'),('xboxlive'),('xboxlive1'),('xchange'),('xcountry'),('xcvbnm'),('xdf65b6666'),('xdl65b6666'),('xdqwerty'),('xdxdxd'),('xena'),('xenogears'),('xenosaga1234'),('xep624'),('xerxes'),('xexeylhf'),('xfactor'),('xfactor1'),('xfhkbr'),('xfiles'),('xfiles1'),('xfk3bxEZQJ'),('xfqybr'),('xfx3ayFJRK'),('xgx39zGISL'),('xh246AIGUN'),('xh247AHGUM'),('xh248zHHTM'),('Xhh787qpcD'),('xi345BIFVN'),('xi345BJFVP'),('xiang123456'),('xiaobai'),('xiaofeng'),('xiaolong'),('xiaoqiang'),('xiaowei'),('xiaoxiao'),('xiaoxin'),('xiaoyao'),('xiaoyu'),('xiaozhu'),('xige5516726'),('ximena'),('ximena1'),('xingxing'),('xinxin'),('xiomara'),('xiomara1'),('xj453CxDXQ'),('XJCrI66kfd'),('xk45xDxCYR'),('xk55xDxCYR'),('xkhNmkI633'),('xlf65b6666'),('xlsl9963'),('xm55xExBZS'),('xochitl'),('xoxo'),('xoxo12'),('xoxo123'),('xoxoxo'),('xoxoxo1'),('XPEYGeh934'),('xpr4Bf29uX'),('xpress'),('xpressmusic'),('xray'),('xred4654'),('xsdsxs'),('xsplit'),('xsplit123'),('xsw21qaz'),('xsw23edc'),('xsw2zaq1'),('xswqaz'),('xswzaq'),('xt'),('Xt97794xT'),('xt:'),('xterra'),('xthtgfirf'),('xthysq'),('xtkjdtr'),('xtkjdtrgfer'),('xtreme'),('xtreme1'),('xtseo2011TDX'),('xtube'),('xtvgbjy'),('xuanxuan'),('xuliang'),('xup6xup6'),('xx123456'),('xxkk01234'),('xxx'),('xxx000'),('xxx007'),('xxx111'),('xxx123'),('xxx12345'),('xxx123xxx'),('xxx333'),('xxx555'),('xxx666'),('xxx777'),('xxxpass'),('xxxx'),('xxxx1234'),('xxxxx'),('xxxxx1'),('xxxxx6'),('xxxxxx'),('xxxxxx1'),('xxxxxx6'),('xxxxxxx'),('xxxxxxx1'),('xxxxxxxx'),('xxxxxxxxx'),('xxxxxxxxxx'),('xxxxxxxxxxxx'),('xxxyyy'),('xxxzzz'),('xyj44pe3GV'),('xYQ7Xcewqk'),('xyxy159753'),('xyz'),('xyz123'),('xyz12345'),('xyz789'),('xyzxyz'),('xyzzy'),('xzibit'),('xzibit1'),('xzsawq'),('xzsawq21'),('xzxzxz'),('y'),('y0mama'),('y0y0y0'),('y12345'),('y123456'),('y123456789'),('y23456'),('y3llow'),('y3p32FtrqJ'),('y6p67FtrqJ'),('y6p68FtrqJ'),('ya'),('ya623349'),('yaalimadad'),('yaallah'),('yabloko'),('yacine'),('yadira'),('yadira1'),('yagami'),('YAgjecc816'),('YAgjecc826'),('yagmur'),('yahaya'),('yahnox75'),('yahoo'),('yahoo!'),('yahoo.'),('yahoo.com'),('yahoo.com1'),('yahoo0'),('yahoo01'),('yahoo1'),('yahoo10'),('yahoo100'),('yahoo11'),('yahoo12'),('yahoo123'),('yahoo1234'),('yahoo12345'),('yahoo13'),('yahoo2'),('yahoo21'),('yahoo22'),('yahoo23'),('yahoo3'),('yahoo4'),('yahoo5'),('yahoo6'),('yahoo69'),('yahoo7'),('yahoo8'),('yahoo9'),('yahoo99'),('yahoocom'),('yahooid'),('yahoomail'),('yahoomail1'),('yahooo'),('yahooo1'),('yahoos'),('yahoos1'),('yahooyahoo'),('yahweh'),('yahweh1'),('yakamoz'),('yakubu'),('yakumo'),('yakuza'),('yamada'),('yamaha'),('yamaha01'),('yamaha1'),('yamaha11'),('yamaha12'),('yamaha123'),('yamaha125'),('yamaha13'),('yamaha135'),('yamaha2'),('yamaha22'),('yamaha250'),('yamaha450'),('yamaha46'),('yamaha6'),('yamaha69'),('yamaha7'),('yamaha85'),('yamahar1'),('yamahar6'),('yamakasi'),('yamamoto'),('yamato'),('yamazaki'),('yamina'),('yamini'),('yamuna'),('yamyam'),('yan'),('yan123'),('yana'),('yana.kolomoets'),('yana123'),('yanaluch'),('yanayana'),('yancai'),('yanchikchmoki'),('yandel'),('yandel1'),('yandex'),('yandex.ru'),('yandi20080527'),('yang'),('yang123'),('yangyang'),('yanina'),('yanira'),('yanis'),('yankee'),('yankee1'),('yankee11'),('yankee12'),('yankee123'),('yankee13'),('yankee2'),('yankee23'),('yankee3'),('yankee7'),('yankees'),('yankees!'),('yankees01'),('yankees02'),('yankees07'),('yankees08'),('yankees09'),('yankees1'),('yankees10'),('yankees11'),('yankees12'),('yankees123'),('yankees13'),('yankees15'),('yankees2'),('yankees21'),('yankees22'),('yankees23'),('yankees24'),('yankees25'),('yankees26'),('yankees27'),('yankees3'),('yankees4'),('yankees5'),('yankees7'),('yankees8'),('yankees9'),('yanks'),('yanks1'),('yannick'),('yannick1'),('yannis'),('yannou'),('yanochka'),('yansubina'),('yanyan'),('yaoiisgrand'),('Yaorqw12334'),('yaq12wsx'),('yaroslav'),('yaseen'),('yasemin'),('yashar'),('yasin'),('yasmeen'),('yasmeen1'),('yasmin'),('yasmin1'),('yasmin12'),('yasmin123'),('yasmina'),('yasmine'),('yasmine1'),('yasser'),('yassin'),('yassine'),('yatra'),('yay123'),('yaya'),('yaya12'),('yaya123'),('yayang'),('yayaya'),('yayaya1'),('yazmin'),('yazmin1'),('ya_nochka86'),('ybccfy'),('ybhdfyf'),('ybnkoia569'),('ybrbnby'),('ybrbnbyf'),('ybrbnf'),('ybrbnjc'),('ybrbnrf'),('ybrjkfq'),('ybrjkftd'),('ybrjkftdbx'),('ybrjkftdf'),('ybrjkftdyf'),('ybrjkm'),('ybyjxrf'),('yC6AbQSFjo'),('yCEI62p395'),('ye123456'),('yeager'),('yeah'),('yeah12'),('yeah123'),('yeahbaby'),('yeahbaby1'),('yeahboy1'),('yeahright'),('yeahright1'),('yeahyeah'),('yeahyeah1'),('year2000'),('year2007'),('year2008'),('year2009'),('year2010'),('year3000'),('yearbook'),('yeayea'),('yeayea1'),('yecgaa'),('yeehaw'),('YeGbpltw2012LOl'),('yelena'),('yelhsa'),('yell0w'),('yeller'),('yellow'),('yellow!'),('yellow.'),('yellow00'),('yellow01'),('yellow02'),('yellow07'),('yellow08'),('yellow09'),('yellow1'),('yellow10'),('yellow11'),('yellow12'),('yellow123'),('yellow1234'),('yellow13'),('yellow14'),('yellow15'),('yellow16'),('yellow17'),('yellow18'),('yellow19'),('yellow2'),('yellow20'),('yellow21'),('yellow22'),('yellow23'),('yellow24'),('yellow25'),('yellow27'),('yellow3'),('yellow33'),('yellow4'),('yellow44'),('yellow45'),('yellow5'),('yellow55'),('yellow6'),('yellow66'),('yellow69'),('yellow7'),('yellow77'),('yellow8'),('yellow88'),('yellow9'),('yellow99'),('yellowbird'),('yellowcard'),('yellowdog'),('yellowrose'),('yellowstone'),('yemi19900911'),('yemisi'),('yendor'),('yenyen'),('yes'),('yes123'),('yes90125'),('yesenia'),('yesenia1'),('yeshua'),('yeshua1'),('yesiam'),('yesica'),('yesican'),('yesman'),('yessenia'),('yessica'),('yessir'),('yessir1'),('yesterday'),('yesterday1'),('yeswecan'),('yesyes'),('yesyes1'),('yesyesyes'),('yetunde'),('yeuemnhieu'),('yf'),('yfafyz'),('yfcmrf'),('yfcn.'),('yfcn.if'),('yfcn.irf'),('yfcnfcmz'),('yfcntyf'),('yfcntymrf'),('yfcntyrf'),('yfcnz'),('yfcnz1'),('yfcnz123'),('yfcnzyfcnz'),('yfdbufnjh'),('YfDbUfNjH10305070'),('yfdbufnjh63'),('yfdctulf'),('yfgjktjy'),('yfhenj'),('yfl.if'),('yfl.irf'),('yflt'),('yflt:lf'),('yflt;lf'),('yfltymrf'),('yfnecbr'),('yfnecz'),('yfnfif'),('yfnfirf'),('yfnfitymrf'),('yfnfkb'),('yfnfkbz'),('yfnfkmz'),('yfz450'),('yggdrasil'),('Yggdrasil4'),('yh3hnr4869'),('yhj34:'),('yijeong'),('yildiz'),('yilmaz'),('yingyang'),('yingyang1'),('yingying'),('yinyang'),('yinyang1'),('yj2009'),('yjdbrjd'),('yjdbrjdf'),('yjdsq'),('yjdsqgfhjkm'),('yjdsqujl'),('yjwfn73J'),('YKDpJ67mgd'),('ykvpoia569'),('ylenia'),('ylik1911'),('yluy1981'),('ymhPnmJ733'),('yngwie'),('yniQnmK733'),('yo'),('yo1234'),('yo12345'),('yo123456'),('yoda'),('yoda123'),('yodayoda'),('yodude'),('yogesh'),('yogi'),('yogibear'),('yogibear1'),('yogita'),('yogurt'),('yogurt1'),('yogyakarta'),('yohana'),('yohann'),('yojimbo'),('yokohama'),('yolanda'),('yolanda1'),('yolande'),('yolo'),('yomama'),('yomama!'),('yomama1'),('yomama12'),('yomama123'),('yomama2'),('yomama3'),('yomamma'),('yomamma1'),('yomisma'),('yomismo'),('yomom1'),('yomoma1'),('yomomma'),('yomomma!'),('yomomma1'),('yomomma2'),('yondaime'),('yonkers'),('yonkers1'),('yoohoo'),('yoohoo1'),('yOp7s55'),('yorkie'),('yorkie1'),('yorkshire'),('yorkshire1'),('yorktown'),('yoruba'),('yoselin'),('yosemite'),('yosemite1'),('yoshi'),('yoshi1'),('yoshi123'),('yoteamo'),('you'),('you&me'),('you123'),('youaifa569'),('youandi'),('youandme'),('youandme1'),('youandme2'),('youare'),('youare1'),('youaregay1'),('youaremine'),('youbye123'),('youbye1231'),('youcef'),('youknow'),('youknow1'),('youknowit'),('youkofa569'),('youloveme'),('younes'),('youness'),('young'),('young1'),('young10'),('young12'),('young123'),('young2'),('young23'),('young3'),('young5'),('youngblood'),('youngbuck'),('youngbuck1'),('younger'),('younglove1'),('youngluwe'),('youngman'),('youngmoney'),('youporn'),('your'),('yourface'),('yourface1'),('yourgay'),('yourgay!'),('yourgay1'),('yourgay2'),('yourlove'),('yourm0m'),('yourmama'),('yourmama1'),('yourmom'),('yourmom!'),('yourmom.'),('yourmom1'),('yourmom11'),('yourmom12'),('yourmom123'),('yourmom13'),('yourmom2'),('yourmom22'),('yourmom3'),('yourmom4'),('yourmom5'),('yourmom6'),('yourmom69'),('yourmom7'),('yourmom8'),('yourmomma'),('yourmomma1'),('yourmother'),('yourmum'),('yourmum1'),('yourname'),('yourname1'),('yourock'),('yourock1'),('yourself'),('yourspace1'),('yousef'),('yousmell'),('youssef'),('yousuck'),('yousuck!'),('yousuck.'),('yousuck1'),('yousuck12'),('yousuck123'),('yousuck2'),('yousuck3'),('yousuck69'),('yousuf'),('youth'),('youth1'),('youtube'),('youtube1'),('youtube12'),('youtube123'),('youtube2'),('youwish'),('youwish1'),('youyou'),('youyou1'),('youyouyou'),('yoville'),('yoville1'),('yoyo'),('yoyo11'),('yoyo12'),('yoyo123'),('yoyo1234'),('yoyo22'),('yoyoma'),('yoyoyo'),('yoyoyo!'),('yoyoyo1'),('yoyoyo12'),('yoyoyo123'),('yoyoyo2'),('yoyoyo3'),('yoyoyoyo'),('yoyoyoyo1'),('yozgat66'),('ypfu2vl856'),('ypt123'),('ysabel'),('yt'),('ytgfhjkm'),('ytngfhjkz'),('ytpyf.'),('YtQ9bkR'),('ytrewq'),('ytrewq1'),('ytrewq123'),('ytrewq321'),('ytreza'),('ytrhjvfyn'),('ytyfdb'),('ytyfdb:e'),('ytyfdb;e'),('ytyfdbcnm'),('yu-gi-oh'),('yU5L97wK8Q'),('yuantuo2012'),('yuanyuan'),('yugioh'),('yugioh1'),('yugioh12'),('yugioh123'),('yuiop'),('yuiyui'),('yuki'),('yukiko'),('yukiyuki'),('yukon'),('yukon1'),('yulia'),('yulia-dubrovina'),('yuliana'),('yulianaz85'),('yuliasha87'),('yulia_yulia_13'),('yuliya'),('yulya'),('yulyasik2002'),('yumiko'),('yummie'),('yummy'),('yummy!'),('yummy1'),('yummy12'),('yummy123'),('yummy2'),('yummy69'),('yumyum'),('yumyum1'),('yungmoney1'),('yunita'),('yunusemre'),('yupyup'),('yupyup1'),('yura'),('yuri'),('yuriko'),('yuriy'),('yushinazena2009'),('yusuf'),('yusuf1'),('yusuf123'),('yusuke'),('yuvraj'),('yuyuyu'),('yv3bcdaq'),('yvette'),('yvette1'),('yvonne'),('yvonne1'),('yvonne12'),('yvonne123'),('yvonne90'),('yx12345678'),('yxcvbn'),('yxcvbnm'),('yxcvbnm1'),('yxcvbnm123'),('yxelik'),('yXP7Wbewpk'),('yy.tt.67'),('yy123456'),('yygjmy1984'),('yygjmy333'),('yYxTHH8J9k'),('yyy'),('yyyy'),('yyyyy'),('yyyyy6'),('yyyyyy'),('yyyyyy1'),('yyyyyyy'),('yyyyyyyy'),('yyyyyyyyyy'),('YYZ59gtP100'),('yz250f'),('yz450f'),('yzerman'),('yzerman19'),('z'),('z00000'),('z000000'),('z00sk'),('z010203'),('z0102030405'),('z11111'),('z111111'),('z1122334455'),('z123123'),('z123321'),('z12345'),('z123456'),('z1234567'),('z12345678'),('z123456789'),('z123456z'),('z19721226'),('z1x1c1v1'),('z1x2c3'),('z1x2c3v4'),('z1x2c3v4b5'),('z1x2c3v4b5n6'),('z1x2c3v4b5n6m7'),('z1z1z1'),('z1z1z1z1'),('z1z2z3'),('z1z2z3z4'),('z1z2z3z4z5'),('z223856'),('z23456'),('z28camaro'),('z7777777'),('z7895123'),('z:'),('zabava'),('zabelina12391'),('zabelinaalena'),('zabihullin99'),('zabirov2'),('zabivay'),('zablo'),('zabloczkaya2012'),('zabludshaya'),('zabolotneva_ira'),('zabolotniy.a'),('zabolotnov1968'),('zabolotnova31337'),('zabor.hut2'),('zaborov_t'),('zaborskiy80'),('zabotin_sasha'),('zabuza'),('zac'),('zac123'),('zacarias'),('zacatecas'),('zacatecas1'),('zacefron'),('zacefron1'),('zacefron12'),('zacefron14'),('zach'),('zach11'),('zach12'),('zach123'),('zach1234'),('zach13'),('zachariah'),('zachary'),('zachary!'),('zachary01'),('zachary1'),('zachary10'),('zachary11'),('zachary12'),('zachary123'),('zachary13'),('zachary2'),('zachary3'),('zachary4'),('zachary5'),('zachary6'),('zachary7'),('zachary8'),('zachary9'),('zachery'),('zachery1'),('zachodnio'),('zack'),('zack11'),('zack12'),('zack123'),('zack1234'),('zack13'),('zackary'),('zackary1'),('zackery'),('zackery1'),('zacky1'),('zadnica'),('zadrot'),('zaebali'),('zafira'),('zafiro'),('zag12wsx'),('zagadka'),('zagreb'),('zahara'),('zaharov'),('zaharova'),('zaheer'),('zahira'),('zahra'),('zainab'),('zaira'),('zaizai'),('zak'),('zak123'),('zakaria'),('zakopane'),('zakzak'),('zalina'),('zalupa'),('zamalek'),('zambia'),('zamboni'),('zamira'),('zamora'),('zamora1'),('zamorano'),('zamzam'),('zander'),('zander1'),('zandra'),('zane'),('zanessa'),('zanessa1'),('zaneta'),('zanetti'),('zangetsu'),('zanoza'),('zanzibar'),('zanzibar1'),('zap'),('zapata'),('zapata1'),('zapatero'),('zapato'),('zaphod'),('zappa'),('zappa1'),('zapper'),('zaq'),('zaq!2wsx'),('zaq1'),('zaq11qaz'),('zaq123'),('zaq1234'),('zaq12345'),('zaq123456'),('zaq123edc'),('zaq123wsx'),('zaq12wsx'),('zaq12wsxcde3'),('zaq147'),('zaq1@WSX'),('zaq1qaz'),('zaq1xsw2'),('zaq1xsw2cde3'),('zaq1zaq1'),('zaqqaz'),('zaqwer'),('zaqwert'),('zaqwerty'),('zaqwsx'),('zaqwsx1'),('zaqwsx12'),('zaqwsx123'),('zaqwsxcde'),('zaqwsxcderfv'),('zaqxsw'),('zaqxsw1'),('zaqxsw12'),('zaqxsw123'),('zaqxswcde'),('zaqxswcde123'),('zaqxswcdevfr'),('zaqzaq'),('zaqzaqzaq'),('zara'),('zara123'),('zaragoza'),('zarate'),('zaratustra'),('zaraza'),('zarazara'),('zardoz'),('zarema'),('zarina'),('zarinaismailova'),('zarinalin87'),('zarina_loves'),('zarina_sabirova'),('zarina_zhasan'),('zarinka1111'),('zarinochka_b'),('zarygalina'),('zasada'),('zasranec'),('zavala'),('zavilov'),('zaxarov-1976'),('zaxscd'),('zaxscdvf'),('zaxscdvfbg'),('zaynmalik'),('zayzay'),('zayzay1'),('zaza'),('zaza123'),('zazaza'),('zazaza1'),('zazazaza'),('ZbychLas'),('zbyszek'),('zcegth'),('zcfvfzkexifz'),('zcfvfzrhfcbdfz'),('zcxfcnkbdf'),('zdenek'),('zdenka'),('zealot'),('zebedee'),('zebra'),('zebra1'),('zebra12'),('zebra123'),('zebra2'),('zebra3'),('zebras'),('zebras1'),('zebulon'),('zeenat'),('zeeshan'),('zeke'),('zelda'),('zelda1'),('zelda123'),('zelda2'),('zelda64'),('zemfira'),('zenaida'),('zenit'),('zenit-talnah'),('zenith'),('zenith1'),('zenobia'),('zenzen'),('zephyr'),('zephyr1'),('zeppelin'),('zeppelin1'),('zepplin'),('zepplin1'),('zeratul'),('zerkalo'),('zermatt'),('zero'),('zero00'),('zero000'),('zero0000'),('zero01'),('zero11'),('zero12'),('zero123'),('zero1234'),('zero13'),('zero666'),('zerocool'),('zerocool1'),('zerozero'),('Zesh1412'),('zeus'),('zeus123'),('zevs_ev'),('zeynep'),('zezette'),('zezina80'),('zgmfx10a'),('zgmfx20a'),('zH8o9ly3gI'),('zhang'),('zhang123'),('zhanghao'),('zhangjian'),('zhangjie'),('zhanglei'),('zhangqiang'),('zhangwei'),('zhangyan'),('zhangyu'),('zhanna'),('zhd741220'),('zhenya'),('zhenyu2012'),('zhimakaimen'),('zhjckfd'),('zhjckfdf'),('zhongguo'),('zhou1980'),('zhuzhu'),('zidane'),('zidane1'),('zidane10'),('zidane5'),('zif1313'),('zigazaga'),('ziggy'),('ziggy1'),('ziggy12'),('ziggy123'),('ziggy2'),('zigzag'),('zigzag1'),('zildjian'),('zildjian1'),('zimbabwe'),('zimbabwe1'),('zimmer'),('zimmer483'),('zimmerman'),('zimmerman1'),('zimmermann33'),('zinaida'),('zindagi'),('zinedine'),('zinger'),('zinnia'),('zinzin'),('ziom82'),('ziomal'),('ziomek'),('ziomek1'),('ziomek123'),('zion'),('zipper'),('zipper1'),('zippo'),('zippo1'),('zippy'),('zippy1'),('zippy123'),('zipzip'),('zitrone'),('zizou'),('zizou10'),('zk.'),('zk.,k.nt,z'),('zk.:'),('zkexifz'),('zkl858'),('zkmxbrbcbkf'),('zlatan'),('ZLEnK77nge'),('zmf1704c'),('zmodem'),('Zmx870919123'),('zmxncbv'),('zniQpnK733'),('zniRpnL744'),('znt'),('znt,zk.,k.'),('znt:'),('zoccola'),('zodiac'),('zodiac1'),('zodiak'),('zodnat'),('zoe'),('zoe101'),('zoe123'),('zoedog'),('zoegirl'),('zoey'),('zoey101'),('zoey11'),('zoey12'),('zoey123'),('zoey1234'),('zoezoe'),('zoezoe1'),('zoidberg'),('zola25'),('zolika'),('zolotarev08'),('zoloto'),('zoltan'),('zolushka'),('zombie'),('zombie1'),('zombie12'),('zombie123'),('zombie13'),('zombie2'),('zombie666'),('zombie69'),('zombies'),('zombies1'),('zonnebloem'),('zoo123'),('zoolander'),('zoolander1'),('zoology'),('zoom'),('zoom123'),('zoom1234'),('zoomer'),('zoomzoom'),('zoomzoom1'),('zooropa'),('zoosk'),('zoosk.com'),('zoosk1'),('zoosk123'),('zoosk2010'),('zooyork'),('zooyork1'),('zoozoo'),('zorglub'),('zorro'),('zorro1'),('zorro123'),('zoubida'),('zoulou'),('zouyong'),('zouzou'),('zozozo'),('zpaqrt2963'),('zrjdktdf'),('ZRSzd9p238'),('zsazsa'),('zsazsa1'),('zse45rdx'),('zse4rfv'),('zse4xdr5'),('zsexdr'),('zsolti'),('zsxdcf'),('zsxdcfv'),('zsxdcfvg'),('zubair'),('zucchero'),('zucker'),('zuewamarija'),('zujlrf'),('zukunft'),('zul123'),('zulu'),('zumzum'),('zurich'),('zuzana'),('zuzanka'),('zuzanna'),('zuzia'),('zuzia1'),('zverev'),('zvezda'),('ZV_!80lo'),('zw5A1u5eVw'),('zwickau'),('zwilling'),('zwinky1'),('ZwJBVHy184'),('zWN6Vbdvpj'),('zx1234'),('zx123456'),('zx12cv34'),('zxasqw'),('zxasqw1'),('zxasqw12'),('zxasqw123'),('zxc'),('zxc098'),('zxc123'),('zxc123123'),('zxc1234'),('zxc12345'),('zxc123456'),('zxc123456789'),('zxc123zxc'),('zxc321'),('zxc456'),('zxc5555'),('zxc789'),('zxc841219'),('zxcasd'),('zxcasd1'),('zxcasd123'),('zxcasdqwe'),('zxcasdqwe1'),('zxcasdqwe123'),('zxccxz'),('zxcdsa'),('zxcdsaqwe'),('zxcqwe'),('zxcqwe123'),('zxcv'),('zxcv0987'),('zxcv12'),('zxcv123'),('zxcv1234'),('zxcv12345'),('zxcv123456'),('zxcv4321'),('zxcvasdf'),('zxcvb'),('zxcvb1'),('zxcvb12'),('zxcvb123'),('zxcvb1234'),('zxcvb12345'),('zxcvb6'),('zxcvbasdfg'),('zxcvbbvcxz'),('zxcvbn'),('zxcvbn1'),('zxcvbn12'),('zxcvbn123'),('zxcvbn123456'),('zxcvbn2m'),('zxcvbn7'),('zxcvbnm'),('zxcvbnm,'),('zxcvbnm,.'),('zxcvbnm,./'),('zxcvbnm.'),('zxcvbnm0'),('zxcvbnm1'),('zxcvbnm11'),('zxcvbnm12'),('zxcvbnm123'),('zxcvbnm1234'),('zxcvbnm12345'),('zxcvbnm123456'),('zxcvbnm1234567'),('zxcvbnm123456789'),('zxcvbnm2'),('zxcvbnm3'),('zxcvbnm5'),('zxcvbnm7'),('zxcvbnm8'),('zxcvbnm9'),('zxcvbnm:'),('zxcvbnma'),('zxcvbnmasd'),('zxcvbnmasdfghjkl'),('zxcvbnmm'),('zxcvbnmmnbvcxz'),('zxcvbnmzxcvbnm'),('zxcvfdsa'),('zxcvvcxz'),('zxcvzxcv'),('zxcxz'),('zxczxc'),('zxczxc1'),('zxczxc123'),('zxczxczxc'),('zxzxzx'),('zxzxzx1'),('zxzxzxzx'),('zy19791201'),('zydfhm'),('zyjxrf'),('zyltrc'),('zz'),('zz1234'),('zz123456'),('ZZ8807zpl'),('zzaaqq11'),('zzr1100'),('zzs000000'),('zztop'),('zzxxcc'),('zzxxccvv'),('zzz'),('zzz000'),('zzz111'),('zzz123'),('zzz333'),('zzz777'),('zzzaaa'),('zzzxxx'),('zzzxxxccc'),('zzzz'),('zzzz1111'),('zzzzxxxx'),('zzzzz'),('zzzzz1'),('zzzzzz'),('zzzzzz1'),('zzzzzzz'),('zzzzzzz1'),('zzzzzzzz'),('zzzzzzzzz'),('zzzzzzzzzx'),('zzzzzzzzzz'),('_'),('______'),('`1234'),('`12345'),('``````'),('александр'),('алексей'),('анастасия'),('андрей'),('вероника'),('виктория'),('вконтакте'),('дмитрий'),('екатерина'),('иришка'),('йфяцыч'),('йфяцычувс'),('йцукен'),('йцукенг'),('йцукенгшщз'),('йцукенгшщзхъ'),('какашка'),('карина'),('катюша'),('кирилл'),('контакт'),('котенок'),('красотка'),('кристина'),('леночка'),('любимая'),('любимый'),('люблю'),('люблютебя'),('любовь'),('максим'),('максимка'),('малышка'),('мамочка'),('мамуля'),('марина'),('маруся'),('надежда'),('наташа'),('не'),('ненавижу'),('никита'),('оксана'),('пїЅпїЅпїЅ'),('пїЅпїЅпїЅпїЅ'),('пїЅпїЅпїЅпїЅпїЅ'),('пїЅпїЅпїЅпїЅпїЅпїЅ'),('пїЅпїЅпїЅпїЅпїЅпїЅ@mail.ru'),('пїЅпїЅпїЅпїЅпїЅпїЅпїЅ'),('пїЅпїЅпїЅпїЅпїЅпїЅпїЅпїЅ'),('пїЅпїЅпїЅпїЅпїЅпїЅпїЅпїЅпїЅ'),('пїЅпїЅпїЅпїЅпїЅпїЅпїЅпїЅпїЅпїЅ'),('пїЅпїЅпїЅпїЅпїЅпїЅпїЅпїЅпїЅпїЅпї'),('пароль'),('полина'),('привет'),('приветик'),('просто'),('Р»СЋР±РѕРІСЊ'),('РЅР°С‚Р°С€Р°'),('РїР°СЂРѕР»СЊ'),('РїСЂРёРІРµС‚'),('РјР°РєСЃРёРј'),('РјР°СЂРёРЅР°'),('ранетки'),('ромашка'),('руслан'),('Р№С†СѓРєРµРЅ'),('СЏ'),('сашенька'),('светлана'),('сергей'),('солнце'),('солнышко'),('счастье'),('татьяна'),('телефон'),('я'),('ялюблютебя'),('ятебялюблю'),('ячсмит'),('ячсмить'),('�'),('�+��+��+��+�'),('�+��+���'),('�+��+���+��'),('�+��+�����'),('�+��+������'),('�+���+����'),('�+����+��'),('�+����+��+�'),('�+����+������'),('�+����+���������'),('�+�����+��'),('�+�����+���'),('�+�����+�����+����'),('�+�����+�����+�����+����'),('�+�����+�����+�����+�����+����'),('�+�����+�����+�����+�����+�����+'),('�+������'),('�+������+'),('�+������+��'),('�+�������'),('�+��������'),('�+���������'),('�+����������'),('��'),('��+����'),('��+����+���'),('��+������'),('��+�������'),('��+��������'),('��+����������'),('��+�����������'),('���'),('���+�+���'),('���+���'),('���+����+���������'),('���+�����'),('���+�������'),('����'),('����+�����'),('����+�������'),('�����'),('�����+��'),('�����+������'),('�����123'),('������'),('������+�+'),('������+��'),('������+���'),('������+����'),('������-�����������-+����'),('�������'),('�������+��'),('�������+���'),('�������+����+�����'),('�������+�����'),('�������+��������'),('�������+��������.'),('��������'),('��������+���'),('���������'),('����������'),('����������+����+��'),('�����������'),('������������'),('�������������'),('����������������'),('�����������������+�+�����������+'),('��������������������'),('��������������������-�����');
/*!40000 ALTER TABLE `easy_passwords` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ecommerce_tracking`
--

DROP TABLE IF EXISTS `ecommerce_tracking`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ecommerce_tracking` (
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `services` varchar(63) NOT NULL DEFAULT '',
  `message_type` varchar(63) NOT NULL DEFAULT '',
  `via` varchar(127) NOT NULL DEFAULT '',
  `date_added` datetime DEFAULT NULL,
  `extra_info` text NOT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `verified` datetime DEFAULT NULL,
  `verified_amount` decimal(9,2) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `idx_orders_id` (`orders_id`,`services`,`message_type`),
  KEY `idx_services` (`services`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ecommerce_tracking`
--

LOCK TABLES `ecommerce_tracking` WRITE;
/*!40000 ALTER TABLE `ecommerce_tracking` DISABLE KEYS */;
/*!40000 ALTER TABLE `ecommerce_tracking` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `email_template_types`
--

DROP TABLE IF EXISTS `email_template_types`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `email_template_types` (
  `type_id` int(11) NOT NULL AUTO_INCREMENT,
  `language_id` int(11) NOT NULL DEFAULT '1',
  `type_name` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`type_id`,`language_id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `email_template_types`
--

LOCK TABLES `email_template_types` WRITE;
/*!40000 ALTER TABLE `email_template_types` DISABLE KEYS */;
INSERT INTO `email_template_types` VALUES (1,1,'Admin Template'),(1,3,'Admin Template'),(1,10,'Admin Template'),(1,11,'Admin Template'),(1,12,'Admin Template'),(1,13,'Admin Template'),(1,15,'Admin Template'),(1,17,'Admin Template'),(1,26,'Admin Template'),(1,28,'Admin Template'),(1,29,'Admin Template'),(2,1,'User related template from admin'),(2,3,'User related template from admin'),(2,10,'User related template from admin'),(2,11,'User related template from admin'),(2,12,'User related template from admin'),(2,13,'User related template from admin'),(2,15,'User related template from admin'),(2,17,'User related template from admin'),(2,26,'User related template from admin'),(2,28,'User related template from admin'),(2,29,'User related template from admin'),(3,1,'User related from user'),(3,3,'User related from user'),(3,10,'User related from user'),(3,11,'User related from user'),(3,12,'User related from user'),(3,13,'User related from user'),(3,15,'User related from user'),(3,17,'User related from user'),(3,26,'User related from user'),(3,28,'User related from user'),(3,29,'User related from user');
/*!40000 ALTER TABLE `email_template_types` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `email_templates`
--

DROP TABLE IF EXISTS `email_templates`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `email_templates` (
  `email_templates_id` int(11) NOT NULL AUTO_INCREMENT,
  `email_templates_key` varchar(255) NOT NULL DEFAULT '',
  `email_template_type` varchar(20) NOT NULL DEFAULT 'plaintext',
  `type_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`email_templates_id`),
  UNIQUE KEY `MailKey` (`email_templates_key`,`email_template_type`)
) ENGINE=InnoDB AUTO_INCREMENT=129 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `email_templates`
--

LOCK TABLES `email_templates` WRITE;
/*!40000 ALTER TABLE `email_templates` DISABLE KEYS */;
INSERT INTO `email_templates` VALUES (1,'New Customer Confirmation','plaintext',3),(3,'Order Confirmation','plaintext',2),(4,'Password Forgotten','plaintext',3),(9,'New Customer Confirmation','html',3),(11,'Order Confirmation','html',2),(12,'Password Forgotten','html',3),(15,'Order Update','plaintext',0),(16,'Order Update','html',2),(19,'Send coupon','plaintext',0),(20,'Send coupon','html',2),(25,'Recovery Cart','html',2),(26,'Recovery Cart','plaintext',2),(27,'Request for quote','plaintext',0),(28,'Request for quote','html',2),(29,'Request for payment','plaintext',0),(30,'Request for payment','html',2),(31,'Loyalty programme','plaintext',0),(32,'Loyalty programme','html',3),(33,'Refer friend','plaintext',0),(34,'Refer friend','html',3),(35,'Reference program','plaintext',0),(36,'Reference program','html',3),(37,'Testimonial posting','plaintext',0),(38,'Testimonial posting','html',2),(39,'Send voucher','plaintext',0),(40,'Send voucher','html',2),(41,'Notify Back in Stock','html',2),(42,'Notify Back in Stock','plaintext',0),(48,'New Subscribe Confirmation','plaintext',0),(49,'New Subscribe Confirmation','html',3),(50,'Successful Subscription','plaintext',0),(51,'Successful Subscription','html',3),(53,'Unsubscribe Confirmation','html',3),(54,'Successful Unubscription','plaintext',0),(55,'Successful Unubscription','html',3),(56,'Sample Confirmation','html',2),(57,'Sample Confirmation','plaintext',0),(60,'Recovery Cart first letter','html',3),(61,'Recovery Cart first letter','plaintext',3),(62,'Recovery Cart second letter','html',3),(63,'Recovery Cart second letter','plaintext',0),(64,'Recovery Cart third letter','html',3),(65,'Recovery Cart third letter','plaintext',0),(66,'Cross-selling and up-selling products','html',3),(67,'Cross-selling and up-selling products','plaintext',0),(68,'Wedding invitation','html',3),(69,'Wedding invitation','plaintext',0),(70,'Deleting an account','html',3),(71,'Deleting an account','plaintext',0),(72,'GDPR update request','html',3),(73,'GDPR update request','plaintext',0),(74,'GDPR guest request','html',3),(75,'GDPR guest request','plaintext',0),(76,'GDPR regular offers request','html',3),(77,'GDPR regular offers request','plaintext',0),(78,'Wedding partner invitation','plaintext',0),(79,'Wedding partner invitation','html',3),(80,'Gift Card','html',2),(81,'Add Tracking Number','plaintext',0),(82,'Add Tracking Number','html',3),(85,'Credit amount notification','html',3),(86,'Bonus points notification','html',3),(87,'Reminder 12 months','plaintext',0),(88,'Reminder 12 months','html',3),(89,'Account update','html',2),(90,'Admin update','html',1),(92,'New Customer Query','html',3),(93,'Admin create','html',1),(94,'Admin Login Security Key','html',1),(95,'Admin Login Security Key','plaintext',1),(96,'Admin New Device Login','html',1),(97,'Admin New Device Login','plaintext',1),(98,'Admin Login Security Key SMS','html',1),(99,'Admin Login Security Key SMS','plaintext',1),(100,'Admin create','plaintext',1),(101,'Admin update','plaintext',1),(102,'Gift Card','plaintext',0),(103,'Unsubscribe Confirmation','plaintext',0),(104,'Credit amount notification','plaintext',0),(105,'Bonus points notification','plaintext',0),(106,'Account update','plaintext',0),(107,'New Customer Query','plaintext',0),(108,'Affiliate Signup','html',0),(109,'Affiliate Activation','html',0),(110,'Affiliate Payment Notify','html',0),(111,'Order Status Update','html',0),(112,'Order Status Update','plaintext',0),(113,'Warehouse notification','html',0),(114,'Warehouse notification','plaintext',0),(115,'Abandoned Cart Notification','plaintext',0),(116,'Abandoned Cart Notification','html',0),(117,'Communication extension new email','plaintext',0),(118,'Communication extension new email','html',0),(119,'Admin Login Password Error','html',0),(120,'Admin Login Password Error','plaintext',0),(121,'Admin Login Security Key Error','html',0),(122,'Admin Login Security Key Error','plaintext',0),(123,'RMA new email','html',0),(124,'RMA new email','plaintext',0),(125,'Admin Password Forgotten','html',0),(126,'Admin Password Forgotten','plaintext',0),(127,'Contact Us Enquiry','html',0),(128,'Contact Us Enquiry','plaintext',0);
/*!40000 ALTER TABLE `email_templates` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `email_templates_texts`
--

DROP TABLE IF EXISTS `email_templates_texts`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `email_templates_texts` (
  `email_templates_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `affiliate_id` int(11) NOT NULL DEFAULT '0',
  `email_templates_subject` varchar(255) DEFAULT NULL,
  `email_templates_body` text,
  PRIMARY KEY (`email_templates_id`,`platform_id`,`language_id`,`affiliate_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `email_templates_texts`
--

LOCK TABLES `email_templates_texts` WRITE;
/*!40000 ALTER TABLE `email_templates_texts` DISABLE KEYS */;
INSERT INTO `email_templates_texts` VALUES (1,1,1,0,'Welcome to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for opening an account at ##STORE_NAME##.\r\n\r\nYou can now access various services we have to offer. Some of these services include:\r\n\r\nPermanent Cart - Any products added to your online cart remain there until you remove them, or check them out.\r\nAddress Book - We can now deliver your products to addresses other than your own! This is perfect to send birthday gifts direct to the birthday-person themselves.\r\nOrder History - View your history of purchases that you have made with us.\r\nProduct Reviews - Share your opinions on products with our other customers.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(1,7,1,0,'Welcome to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for opening an account at ##STORE_NAME##.\r\n\r\nYou can now access various services we have to offer. Some of these services include:\r\n\r\nPermanent Cart - Any products added to your online cart remain there until you remove them, or check them out.\r\nAddress Book - We can now deliver your products to addresses other than your own! This is perfect to send birthday gifts direct to the birthday-person themselves.\r\nOrder History - View your history of purchases that you have made with us.\r\nProduct Reviews - Share your opinions on products with our other customers.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(1,8,1,0,'Welcome to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for opening an account at ##STORE_NAME##.\r\n\r\nYou can now access various services we have to offer. Some of these services include:\r\n\r\nPermanent Cart - Any products added to your online cart remain there until you remove them, or check them out.\r\nAddress Book - We can now deliver your products to addresses other than your own! This is perfect to send birthday gifts direct to the birthday-person themselves.\r\nOrder History - View your history of purchases that you have made with us.\r\nProduct Reviews - Share your opinions on products with our other customers.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(1,9,1,0,'Welcome to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for opening an account at ##STORE_NAME##.\r\n\r\nYou can now access various services we have to offer. Some of these services include:\r\n\r\nPermanent Cart - Any products added to your online cart remain there until you remove them, or check them out.\r\nAddress Book - We can now deliver your products to addresses other than your own! This is perfect to send birthday gifts direct to the birthday-person themselves.\r\nOrder History - View your history of purchases that you have made with us.\r\nProduct Reviews - Share your opinions on products with our other customers.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(1,10,1,0,'Welcome to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for opening an account at ##STORE_NAME##.\r\n\r\nYou can now access various services we have to offer. Some of these services include:\r\n\r\nPermanent Cart - Any products added to your online cart remain there until you remove them, or check them out.\r\nAddress Book - We can now deliver your products to addresses other than your own! This is perfect to send birthday gifts direct to the birthday-person themselves.\r\nOrder History - View your history of purchases that you have made with us.\r\nProduct Reviews - Share your opinions on products with our other customers.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(3,1,1,0,'##STORE_NAME## - thank you for your order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing an order with ##STORE_NAME##!\r\n\r\nHere are some order details for your reference:\r\n\r\nOrder Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of products on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(3,7,1,0,'##STORE_NAME## - thank you for your order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing an order with ##STORE_NAME##!\r\n\r\nHere are some order details for your reference:\r\n\r\nOrder Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of products on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(3,8,1,0,'##STORE_NAME## - thank you for your order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing an order with ##STORE_NAME##!\r\n\r\nHere are some order details for your reference:\r\n\r\nOrder Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of products on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(3,9,1,0,'##STORE_NAME## - thank you for your order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing an order with ##STORE_NAME##!\r\n\r\nHere are some order details for your reference:\r\n\r\nOrder Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of products on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(3,10,1,0,'##STORE_NAME## - thank you for your order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing an order with ##STORE_NAME##!\r\n\r\nHere are some order details for your reference:\r\n\r\nOrder Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of products on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(4,1,1,0,'##STORE_NAME## - your new password','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYour personal data has been adjusted. If this has occurred without your involvement or consent, please contact us as soon as possible!\r\n\r\nWebsite: ##HTTP_HOST##\r\nUsername: ##CUSTOMER_EMAIL##\r\nPassword: ##NEW_PASSWORD##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(4,7,1,0,'##STORE_NAME## - your new password','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYour personal data has been adjusted. If this has occurred without your involvement or consent, please contact us as soon as possible!\r\n\r\nWebsite: ##HTTP_HOST##\r\nUsername: ##CUSTOMER_EMAIL##\r\nPassword: ##NEW_PASSWORD##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(4,8,1,0,'##STORE_NAME## - your new password','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYour personal data has been adjusted. If this has occurred without your involvement or consent, please contact us as soon as possible!\r\n\r\nWebsite: ##HTTP_HOST##\r\nUsername: ##CUSTOMER_EMAIL##\r\nPassword: ##NEW_PASSWORD##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(4,9,1,0,'##STORE_NAME## - your new password','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYour personal data has been adjusted. If this has occurred without your involvement or consent, please contact us as soon as possible!\r\n\r\nWebsite: ##HTTP_HOST##\r\nUsername: ##CUSTOMER_EMAIL##\r\nPassword: ##NEW_PASSWORD##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(4,10,1,0,'##STORE_NAME## - your new password','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYour personal data has been adjusted. If this has occurred without your involvement or consent, please contact us as soon as possible!\r\n\r\nWebsite: ##HTTP_HOST##\r\nUsername: ##CUSTOMER_EMAIL##\r\nPassword: ##NEW_PASSWORD##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(9,1,1,0,'Welcome to ##STORE_NAME##','<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Dear ##CUSTOMER_FIRSTNAME##</span><span style=\"font-family:verdana,geneva,sans-serif\">,<br />\r\n<br />\r\nThank you for opening an account at ##STORE_NAME##.<br />\r\n<br />\r\nYou can now access various services we have to offer. Some of these services include:<br />\r\n<br />\r\nPermanent Cart - Any products added to your online cart remain there until you remove them, or check them out.<br />\r\nAddress Book - We can now deliver your products to addresses other than your own! This is perfect to send birthday gifts direct to the birthday-person themselves.<br />\r\nOrder History - View your history of purchases that you have made with us.<br />\r\nProduct&nbsp;Reviews - Share your opinions on products with our other customers.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(9,7,1,0,'Welcome to ##STORE_NAME##','<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Dear ##CUSTOMER_FIRSTNAME##</span><span style=\"font-family:verdana,geneva,sans-serif\">,<br />\r\n<br />\r\nThank you for opening an account at ##STORE_NAME##.<br />\r\n<br />\r\nYou can now access various services we have to offer. Some of these services include:<br />\r\n<br />\r\nPermanent Cart - Any products added to your online cart remain there until you remove them, or check them out.<br />\r\nAddress Book - We can now deliver your products to addresses other than your own! This is perfect to send birthday gifts direct to the birthday-person themselves.<br />\r\nOrder History - View your history of purchases that you have made with us.<br />\r\nProduct&nbsp;Reviews - Share your opinions on products with our other customers.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(9,8,1,0,'Welcome to ##STORE_NAME##','<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Dear ##CUSTOMER_FIRSTNAME##</span><span style=\"font-family:verdana,geneva,sans-serif\">,<br />\r\n<br />\r\nThank you for opening an account at ##STORE_NAME##.<br />\r\n<br />\r\nYou can now access various services we have to offer. Some of these services include:<br />\r\n<br />\r\nPermanent Cart - Any products added to your online cart remain there until you remove them, or check them out.<br />\r\nAddress Book - We can now deliver your products to addresses other than your own! This is perfect to send birthday gifts direct to the birthday-person themselves.<br />\r\nOrder History - View your history of purchases that you have made with us.<br />\r\nProduct&nbsp;Reviews - Share your opinions on products with our other customers.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(9,9,1,0,'Welcome to ##STORE_NAME##','<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Dear ##CUSTOMER_FIRSTNAME##</span><span style=\"font-family:verdana,geneva,sans-serif\">,<br />\r\n<br />\r\nThank you for opening an account at ##STORE_NAME##.<br />\r\n<br />\r\nYou can now access various services we have to offer. Some of these services include:<br />\r\n<br />\r\nPermanent Cart - Any products added to your online cart remain there until you remove them, or check them out.<br />\r\nAddress Book - We can now deliver your products to addresses other than your own! This is perfect to send birthday gifts direct to the birthday-person themselves.<br />\r\nOrder History - View your history of purchases that you have made with us.<br />\r\nProduct&nbsp;Reviews - Share your opinions on products with our other customers.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(9,10,1,0,'Welcome to ##STORE_NAME##','<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Dear ##CUSTOMER_FIRSTNAME##</span><span style=\"font-family:verdana,geneva,sans-serif\">,<br />\r\n<br />\r\nThank you for opening an account at ##STORE_NAME##.<br />\r\n<br />\r\nYou can now access various services we have to offer. Some of these services include:<br />\r\n<br />\r\nPermanent Cart - Any products added to your online cart remain there until you remove them, or check them out.<br />\r\nAddress Book - We can now deliver your products to addresses other than your own! This is perfect to send birthday gifts direct to the birthday-person themselves.<br />\r\nOrder History - View your history of purchases that you have made with us.<br />\r\nProduct&nbsp;Reviews - Share your opinions on products with our other customers.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(11,1,1,0,'##STORE_NAME## - thank you for your order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','<p><span style=\"font-size:12px;\">Dear&nbsp;</span>##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you very much for placing an order with&nbsp;<span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">##STORE_NAME##!</span></span></p>\r\n\r\n<p>Here are some order details for your reference:</p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Here is the list of products on your order:<br />\r\n##PRODUCTS_ORDERED##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">This is the summary of your order with us:<br />\r\n##ORDER_TOTALS##<br />\r\n<br />\r\nAs per your instructions we will delivery your order to the following address:<br />\r\n##DELIVERY_ADDRESS##<br />\r\n<br />\r\nThis billing address will be used for the invoice:</span></span><br />\r\n<span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">##BILLING_ADDRESS##<br />\r\n<br />\r\nYou have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</span></span></p>\r\n\r\n<p>Once again, thanks a lot for your order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(11,7,1,0,'##STORE_NAME## - thank you for your order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','<p><span style=\"font-size:12px;\">Dear&nbsp;</span>##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you very much for placing an order with&nbsp;<span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">##STORE_NAME##!</span></span></p>\r\n\r\n<p>Here are some order details for your reference:</p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Here is the list of products on your order:<br />\r\n##PRODUCTS_ORDERED##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">This is the summary of your order with us:<br />\r\n##ORDER_TOTALS##<br />\r\n<br />\r\nAs per your instructions we will delivery your order to the following address:<br />\r\n##DELIVERY_ADDRESS##<br />\r\n<br />\r\nThis billing address will be used for the invoice:</span></span><br />\r\n<span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">##BILLING_ADDRESS##<br />\r\n<br />\r\nYou have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</span></span></p>\r\n\r\n<p>Once again, thanks a lot for your order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(11,8,1,0,'##STORE_NAME## - thank you for your order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','<p><span style=\"font-size:12px;\">Dear&nbsp;</span>##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you very much for placing an order with&nbsp;<span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">##STORE_NAME##!</span></span></p>\r\n\r\n<p>Here are some order details for your reference:</p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Here is the list of products on your order:<br />\r\n##PRODUCTS_ORDERED##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">This is the summary of your order with us:<br />\r\n##ORDER_TOTALS##<br />\r\n<br />\r\nAs per your instructions we will delivery your order to the following address:<br />\r\n##DELIVERY_ADDRESS##<br />\r\n<br />\r\nThis billing address will be used for the invoice:</span></span><br />\r\n<span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">##BILLING_ADDRESS##<br />\r\n<br />\r\nYou have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</span></span></p>\r\n\r\n<p>Once again, thanks a lot for your order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(11,9,1,0,'##STORE_NAME## - thank you for your order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','<p><span style=\"font-size:12px;\">Dear&nbsp;</span>##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you very much for placing an order with&nbsp;<span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">##STORE_NAME##!</span></span></p>\r\n\r\n<p>Here are some order details for your reference:</p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Here is the list of products on your order:<br />\r\n##PRODUCTS_ORDERED##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">This is the summary of your order with us:<br />\r\n##ORDER_TOTALS##<br />\r\n<br />\r\nAs per your instructions we will delivery your order to the following address:<br />\r\n##DELIVERY_ADDRESS##<br />\r\n<br />\r\nThis billing address will be used for the invoice:</span></span><br />\r\n<span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">##BILLING_ADDRESS##<br />\r\n<br />\r\nYou have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</span></span></p>\r\n\r\n<p>Once again, thanks a lot for your order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(11,10,1,0,'##STORE_NAME## - thank you for your order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','<p><span style=\"font-size:12px;\">Dear&nbsp;</span>##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you very much for placing an order with&nbsp;<span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">##STORE_NAME##!</span></span></p>\r\n\r\n<p>Here are some order details for your reference:</p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Here is the list of products on your order:<br />\r\n##PRODUCTS_ORDERED##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">This is the summary of your order with us:<br />\r\n##ORDER_TOTALS##<br />\r\n<br />\r\nAs per your instructions we will delivery your order to the following address:<br />\r\n##DELIVERY_ADDRESS##<br />\r\n<br />\r\nThis billing address will be used for the invoice:</span></span><br />\r\n<span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">##BILLING_ADDRESS##<br />\r\n<br />\r\nYou have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:verdana,geneva,sans-serif;\">Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</span></span></p>\r\n\r\n<p>Once again, thanks a lot for your order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(12,1,1,0,'##STORE_NAME## - your new password','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your personal data has&nbsp;been adjusted. If this has occurred without your involvement or consent,&nbsp;please contact us as soon as possible!</p>\r\n\r\n<p>Website:&nbsp;##HTTP_HOST##<br />\r\nUsername: ##CUSTOMER_EMAIL##<br />\r\nPassword:&nbsp;##NEW_PASSWORD##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(12,7,1,0,'##STORE_NAME## - your new password','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your personal data has&nbsp;been adjusted. If this has occurred without your involvement or consent,&nbsp;please contact us as soon as possible!</p>\r\n\r\n<p>Website:&nbsp;##HTTP_HOST##<br />\r\nUsername: ##CUSTOMER_EMAIL##<br />\r\nPassword:&nbsp;##NEW_PASSWORD##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(12,8,1,0,'##STORE_NAME## - your new password','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your personal data has&nbsp;been adjusted. If this has occurred without your involvement or consent,&nbsp;please contact us as soon as possible!</p>\r\n\r\n<p>Website:&nbsp;##HTTP_HOST##<br />\r\nUsername: ##CUSTOMER_EMAIL##<br />\r\nPassword:&nbsp;##NEW_PASSWORD##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(12,9,1,0,'##STORE_NAME## - your new password','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your personal data has&nbsp;been adjusted. If this has occurred without your involvement or consent,&nbsp;please contact us as soon as possible!</p>\r\n\r\n<p>Website:&nbsp;##HTTP_HOST##<br />\r\nUsername: ##CUSTOMER_EMAIL##<br />\r\nPassword:&nbsp;##NEW_PASSWORD##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(12,10,1,0,'##STORE_NAME## - your new password','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your personal data has&nbsp;been adjusted. If this has occurred without your involvement or consent,&nbsp;please contact us as soon as possible!</p>\r\n\r\n<p>Website:&nbsp;##HTTP_HOST##<br />\r\nUsername: ##CUSTOMER_EMAIL##<br />\r\nPassword:&nbsp;##NEW_PASSWORD##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(15,1,1,0,'##STORE_NAME## - your Order ##ORDER_NUMBER## From ##ORDER_DATE_SHORT## - Updated','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing an order with ##STORE_NAME##!\r\n\r\nIt has just been updated. Please find the most up to date details below:\r\n\r\nOrder Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of products on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(15,7,1,0,'##STORE_NAME## - your Order ##ORDER_NUMBER## From ##ORDER_DATE_SHORT## - Updated','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing an order with ##STORE_NAME##!\r\n\r\nIt has just been updated. Please find the most up to date details below:\r\n\r\nOrder Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of products on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(15,8,1,0,'##STORE_NAME## - your Order ##ORDER_NUMBER## From ##ORDER_DATE_SHORT## - Updated','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing an order with ##STORE_NAME##!\r\n\r\nIt has just been updated. Please find the most up to date details below:\r\n\r\nOrder Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of products on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(15,9,1,0,'##STORE_NAME## - your Order ##ORDER_NUMBER## From ##ORDER_DATE_SHORT## - Updated','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing an order with ##STORE_NAME##!\r\n\r\nIt has just been updated. Please find the most up to date details below:\r\n\r\nOrder Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of products on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(15,10,1,0,'##STORE_NAME## - your Order ##ORDER_NUMBER## From ##ORDER_DATE_SHORT## - Updated','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing an order with ##STORE_NAME##!\r\n\r\nIt has just been updated. Please find the most up to date details below:\r\n\r\nOrder Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of products on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(16,1,1,0,'##STORE_NAME## - your Order ##ORDER_NUMBER## From ##ORDER_DATE_SHORT## - Updated','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you very much for placing an order with&nbsp;##STORE_NAME##!</p>\r\n\r\n<p>It has just been updated. Please find the most up to date details below:</p>\r\n\r\n<p>Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##</p>\r\n\r\n<p>Here is the list of products on your order:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>This is the summary of your order with us:<br />\r\n##ORDER_TOTALS##<br />\r\n<br />\r\nAs per your instructions we will delivery your order to the following address:<br />\r\n##DELIVERY_ADDRESS##<br />\r\n<br />\r\nThis billing address will be used for the invoice:<br />\r\n##BILLING_ADDRESS##<br />\r\n<br />\r\nYou have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</p>\r\n\r\n<p>Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>Once again, thanks a lot for your order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(16,7,1,0,'##STORE_NAME## - your Order ##ORDER_NUMBER## From ##ORDER_DATE_SHORT## - Updated','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you very much for placing an order with&nbsp;##STORE_NAME##!</p>\r\n\r\n<p>It has just been updated. Please find the most up to date details below:</p>\r\n\r\n<p>Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##</p>\r\n\r\n<p>Here is the list of products on your order:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>This is the summary of your order with us:<br />\r\n##ORDER_TOTALS##<br />\r\n<br />\r\nAs per your instructions we will delivery your order to the following address:<br />\r\n##DELIVERY_ADDRESS##<br />\r\n<br />\r\nThis billing address will be used for the invoice:<br />\r\n##BILLING_ADDRESS##<br />\r\n<br />\r\nYou have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</p>\r\n\r\n<p>Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>Once again, thanks a lot for your order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(16,8,1,0,'##STORE_NAME## - your Order ##ORDER_NUMBER## From ##ORDER_DATE_SHORT## - Updated','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you very much for placing an order with&nbsp;##STORE_NAME##!</p>\r\n\r\n<p>It has just been updated. Please find the most up to date details below:</p>\r\n\r\n<p>Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##</p>\r\n\r\n<p>Here is the list of products on your order:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>This is the summary of your order with us:<br />\r\n##ORDER_TOTALS##<br />\r\n<br />\r\nAs per your instructions we will delivery your order to the following address:<br />\r\n##DELIVERY_ADDRESS##<br />\r\n<br />\r\nThis billing address will be used for the invoice:<br />\r\n##BILLING_ADDRESS##<br />\r\n<br />\r\nYou have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</p>\r\n\r\n<p>Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>Once again, thanks a lot for your order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(16,9,1,0,'##STORE_NAME## - your Order ##ORDER_NUMBER## From ##ORDER_DATE_SHORT## - Updated','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you very much for placing an order with&nbsp;##STORE_NAME##!</p>\r\n\r\n<p>It has just been updated. Please find the most up to date details below:</p>\r\n\r\n<p>Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##</p>\r\n\r\n<p>Here is the list of products on your order:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>This is the summary of your order with us:<br />\r\n##ORDER_TOTALS##<br />\r\n<br />\r\nAs per your instructions we will delivery your order to the following address:<br />\r\n##DELIVERY_ADDRESS##<br />\r\n<br />\r\nThis billing address will be used for the invoice:<br />\r\n##BILLING_ADDRESS##<br />\r\n<br />\r\nYou have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</p>\r\n\r\n<p>Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>Once again, thanks a lot for your order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(16,10,1,0,'##STORE_NAME## - your Order ##ORDER_NUMBER## From ##ORDER_DATE_SHORT## - Updated','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you very much for placing an order with&nbsp;##STORE_NAME##!</p>\r\n\r\n<p>It has just been updated. Please find the most up to date details below:</p>\r\n\r\n<p>Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##</p>\r\n\r\n<p>Here is the list of products on your order:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>This is the summary of your order with us:<br />\r\n##ORDER_TOTALS##<br />\r\n<br />\r\nAs per your instructions we will delivery your order to the following address:<br />\r\n##DELIVERY_ADDRESS##<br />\r\n<br />\r\nThis billing address will be used for the invoice:<br />\r\n##BILLING_ADDRESS##<br />\r\n<br />\r\nYou have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</p>\r\n\r\n<p>Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>Once again, thanks a lot for your order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(19,1,1,0,'##STORE_NAME## - discount coupon','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYou have been sent a discount coupon ##COUPON_NAME##!\r\n\r\nCoupon amount: ##COUPON_AMOUNT##\r\nDesciption: \r\n##COUPON_DESCRIPTION##\r\n\r\nYou can now redeem this coupon during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.\r\nThe coupon code is ##COUPON_CODE##\r\n\r\nPlease keep the code safe so you can benefit from this unique special offer.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(19,7,1,0,'##STORE_NAME## - discount coupon','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYou have been sent a discount coupon ##COUPON_NAME##!\r\n\r\nCoupon amount: ##COUPON_AMOUNT##\r\nDesciption: \r\n##COUPON_DESCRIPTION##\r\n\r\nYou can now redeem this coupon during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.\r\nThe coupon code is ##COUPON_CODE##\r\n\r\nPlease keep the code safe so you can benefit from this unique special offer.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(19,8,1,0,'##STORE_NAME## - discount coupon','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYou have been sent a discount coupon ##COUPON_NAME##!\r\n\r\nCoupon amount: ##COUPON_AMOUNT##\r\nDesciption: \r\n##COUPON_DESCRIPTION##\r\n\r\nYou can now redeem this coupon during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.\r\nThe coupon code is ##COUPON_CODE##\r\n\r\nPlease keep the code safe so you can benefit from this unique special offer.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(19,9,1,0,'##STORE_NAME## - discount coupon','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYou have been sent a discount coupon ##COUPON_NAME##!\r\n\r\nCoupon amount: ##COUPON_AMOUNT##\r\nDesciption: \r\n##COUPON_DESCRIPTION##\r\n\r\nYou can now redeem this coupon during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.\r\nThe coupon code is ##COUPON_CODE##\r\n\r\nPlease keep the code safe so you can benefit from this unique special offer.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(19,10,1,0,'##STORE_NAME## - discount coupon','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYou have been sent a discount coupon ##COUPON_NAME##!\r\n\r\nCoupon amount: ##COUPON_AMOUNT##\r\nDesciption: \r\n##COUPON_DESCRIPTION##\r\n\r\nYou can now redeem this coupon during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.\r\nThe coupon code is ##COUPON_CODE##\r\n\r\nPlease keep the code safe so you can benefit from this unique special offer.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(20,1,1,0,'##STORE_NAME## - discount coupon','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>You have been sent a discount coupon&nbsp;##COUPON_NAME##!</p>\r\n\r\n<p>Coupon amount:&nbsp;<strong>##COUPON_AMOUNT##</strong><br />\r\nDesciption:&nbsp;<br />\r\n##COUPON_DESCRIPTION##</p>\r\n\r\n<p>You can now redeem this coupon during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.<br />\r\nThe coupon code is <strong>##COUPON_CODE##</strong></p>\r\n\r\n<p>Please keep the code safe so you can benefit from this unique special offer.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(20,7,1,0,'##STORE_NAME## - discount coupon','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>You have been sent a discount coupon&nbsp;##COUPON_NAME##!</p>\r\n\r\n<p>Coupon amount:&nbsp;<strong>##COUPON_AMOUNT##</strong><br />\r\nDesciption:&nbsp;<br />\r\n##COUPON_DESCRIPTION##</p>\r\n\r\n<p>You can now redeem this coupon during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.<br />\r\nThe coupon code is <strong>##COUPON_CODE##</strong></p>\r\n\r\n<p>Please keep the code safe so you can benefit from this unique special offer.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(20,8,1,0,'##STORE_NAME## - discount coupon','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>You have been sent a discount coupon&nbsp;##COUPON_NAME##!</p>\r\n\r\n<p>Coupon amount:&nbsp;<strong>##COUPON_AMOUNT##</strong><br />\r\nDesciption:&nbsp;<br />\r\n##COUPON_DESCRIPTION##</p>\r\n\r\n<p>You can now redeem this coupon during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.<br />\r\nThe coupon code is <strong>##COUPON_CODE##</strong></p>\r\n\r\n<p>Please keep the code safe so you can benefit from this unique special offer.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(20,9,1,0,'##STORE_NAME## - discount coupon','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>You have been sent a discount coupon&nbsp;##COUPON_NAME##!</p>\r\n\r\n<p>Coupon amount:&nbsp;<strong>##COUPON_AMOUNT##</strong><br />\r\nDesciption:&nbsp;<br />\r\n##COUPON_DESCRIPTION##</p>\r\n\r\n<p>You can now redeem this coupon during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.<br />\r\nThe coupon code is <strong>##COUPON_CODE##</strong></p>\r\n\r\n<p>Please keep the code safe so you can benefit from this unique special offer.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(20,10,1,0,'##STORE_NAME## - discount coupon','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>You have been sent a discount coupon&nbsp;##COUPON_NAME##!</p>\r\n\r\n<p>Coupon amount:&nbsp;<strong>##COUPON_AMOUNT##</strong><br />\r\nDesciption:&nbsp;<br />\r\n##COUPON_DESCRIPTION##</p>\r\n\r\n<p>You can now redeem this coupon during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.<br />\r\nThe coupon code is <strong>##COUPON_CODE##</strong></p>\r\n\r\n<p>Please keep the code safe so you can benefit from this unique special offer.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(25,1,1,0,'##STORE_NAME## - items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##<br />\r\n<br />\r\n##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(25,7,1,0,'##STORE_NAME## - items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##<br />\r\n<br />\r\n##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(25,8,1,0,'##STORE_NAME## - items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##<br />\r\n<br />\r\n##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(25,9,1,0,'##STORE_NAME## - items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##<br />\r\n<br />\r\n##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(25,10,1,0,'##STORE_NAME## - items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##<br />\r\n<br />\r\n##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(26,1,1,0,'##STORE_NAME## - items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(26,7,1,0,'##STORE_NAME## - items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(26,8,1,0,'##STORE_NAME## - items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(26,9,1,0,'##STORE_NAME## - items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(26,10,1,0,'##STORE_NAME## - items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(27,1,1,0,'##STORE_NAME## - request for quote','Customer name ##USER_GREETING##\r\n\r\nCustomer Email ##CUSTOMER_EMAIL##\r\n\r\nProduct ##PRODUCT_NAME##\r\n\r\nRequest message\r\n##REQUEST_MESSAGE##'),(27,7,1,0,'##STORE_NAME## - request for quote','Customer name ##USER_GREETING##\r\n\r\nCustomer Email ##CUSTOMER_EMAIL##\r\n\r\nProduct ##PRODUCT_NAME##\r\n\r\nRequest message\r\n##REQUEST_MESSAGE##'),(27,8,1,0,'##STORE_NAME## - request for quote','Customer name ##USER_GREETING##\r\n\r\nCustomer Email ##CUSTOMER_EMAIL##\r\n\r\nProduct ##PRODUCT_NAME##\r\n\r\nRequest message\r\n##REQUEST_MESSAGE##'),(27,9,1,0,'##STORE_NAME## - request for quote','Customer name ##USER_GREETING##\r\n\r\nCustomer Email ##CUSTOMER_EMAIL##\r\n\r\nProduct ##PRODUCT_NAME##\r\n\r\nRequest message\r\n##REQUEST_MESSAGE##'),(27,10,1,0,'##STORE_NAME## - request for quote','Customer name ##USER_GREETING##\r\n\r\nCustomer Email ##CUSTOMER_EMAIL##\r\n\r\nProduct ##PRODUCT_NAME##\r\n\r\nRequest message\r\n##REQUEST_MESSAGE##'),(28,1,1,0,'##STORE_NAME## - request for quote','<p>Customer name ##USER_GREETING##</p>\r\n\r\n<p>Customer Email ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Product <a href=\"##PRODUCT_URL##\">##PRODUCT_NAME##</a></p>\r\n\r\n<p>Request message<br />\r\n##REQUEST_MESSAGE##</p>\r\n\r\n<p>&nbsp;</p>'),(28,7,1,0,'##STORE_NAME## - request for quote','<p>Customer name ##USER_GREETING##</p>\r\n\r\n<p>Customer Email ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Product <a href=\"##PRODUCT_URL##\">##PRODUCT_NAME##</a></p>\r\n\r\n<p>Request message<br />\r\n##REQUEST_MESSAGE##</p>\r\n\r\n<p>&nbsp;</p>'),(28,8,1,0,'##STORE_NAME## - request for quote','<p>Customer name ##USER_GREETING##</p>\r\n\r\n<p>Customer Email ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Product <a href=\"##PRODUCT_URL##\">##PRODUCT_NAME##</a></p>\r\n\r\n<p>Request message<br />\r\n##REQUEST_MESSAGE##</p>\r\n\r\n<p>&nbsp;</p>'),(28,9,1,0,'##STORE_NAME## - request for quote','<p>Customer name ##USER_GREETING##</p>\r\n\r\n<p>Customer Email ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Product <a href=\"##PRODUCT_URL##\">##PRODUCT_NAME##</a></p>\r\n\r\n<p>Request message<br />\r\n##REQUEST_MESSAGE##</p>\r\n\r\n<p>&nbsp;</p>'),(28,10,1,0,'##STORE_NAME## - request for quote','<p>Customer name ##USER_GREETING##</p>\r\n\r\n<p>Customer Email ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Product <a href=\"##PRODUCT_URL##\">##PRODUCT_NAME##</a></p>\r\n\r\n<p>Request message<br />\r\n##REQUEST_MESSAGE##</p>\r\n\r\n<p>&nbsp;</p>'),(29,1,1,0,'##STORE_NAME## - request for secure payment','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAs per your conversation with our staff, please find request for payment enclosed below: \r\n##REQUEST_MESSAGE##\r\n\r\nPlease follow this secure link to make a payment:\r\n##REQUEST_URL##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(29,7,1,0,'##STORE_NAME## - request for secure payment','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAs per your conversation with our staff, please find request for payment enclosed below: \r\n##REQUEST_MESSAGE##\r\n\r\nPlease follow this secure link to make a payment:\r\n##REQUEST_URL##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(29,8,1,0,'##STORE_NAME## - request for secure payment','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAs per your conversation with our staff, please find request for payment enclosed below: \r\n##REQUEST_MESSAGE##\r\n\r\nPlease follow this secure link to make a payment:\r\n##REQUEST_URL##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(29,9,1,0,'##STORE_NAME## - request for secure payment','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAs per your conversation with our staff, please find request for payment enclosed below: \r\n##REQUEST_MESSAGE##\r\n\r\nPlease follow this secure link to make a payment:\r\n##REQUEST_URL##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(29,10,1,0,'##STORE_NAME## - request for secure payment','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAs per your conversation with our staff, please find request for payment enclosed below: \r\n##REQUEST_MESSAGE##\r\n\r\nPlease follow this secure link to make a payment:\r\n##REQUEST_URL##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(30,1,1,0,'##STORE_NAME## - request for secure payment','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>As per your conversation with our staff, please find request for payment enclosed below:<br />\r\n##REQUEST_MESSAGE##</p>\r\n\r\n<p>Please follow this secure link to make a payment:<br />\r\n<a href=\"##REQUEST_URL##\">##REQUEST_URL##</a></p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(30,7,1,0,'##STORE_NAME## - request for secure payment','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>As per your conversation with our staff, please find request for payment enclosed below:<br />\r\n##REQUEST_MESSAGE##</p>\r\n\r\n<p>Please follow this secure link to make a payment:<br />\r\n<a href=\"##REQUEST_URL##\">##REQUEST_URL##</a></p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(30,8,1,0,'##STORE_NAME## - request for secure payment','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>As per your conversation with our staff, please find request for payment enclosed below:<br />\r\n##REQUEST_MESSAGE##</p>\r\n\r\n<p>Please follow this secure link to make a payment:<br />\r\n<a href=\"##REQUEST_URL##\">##REQUEST_URL##</a></p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(30,9,1,0,'##STORE_NAME## - request for secure payment','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>As per your conversation with our staff, please find request for payment enclosed below:<br />\r\n##REQUEST_MESSAGE##</p>\r\n\r\n<p>Please follow this secure link to make a payment:<br />\r\n<a href=\"##REQUEST_URL##\">##REQUEST_URL##</a></p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(30,10,1,0,'##STORE_NAME## - request for secure payment','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>As per your conversation with our staff, please find request for payment enclosed below:<br />\r\n##REQUEST_MESSAGE##</p>\r\n\r\n<p>Please follow this secure link to make a payment:<br />\r\n<a href=\"##REQUEST_URL##\">##REQUEST_URL##</a></p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(31,1,1,0,'Loyalty programme from ##STORE_NAME## - new discount code','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nWe appreciate your participation in our loyalty programme. Please find your discount code below.\r\n\r\n##COUPON_CODE## [code automatically generated].\r\n\r\nUse it during the checkout procedure and get ##COUPON_AMOUNT## off your order.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(31,7,1,0,'Loyalty programme from ##STORE_NAME## - new discount code','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nWe appreciate your participation in our loyalty programme. Please find your discount code below.\r\n\r\n##COUPON_CODE## [code automatically generated].\r\n\r\nUse it during the checkout procedure and get ##COUPON_AMOUNT## off your order.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(31,8,1,0,'Loyalty programme from ##STORE_NAME## - new discount code','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nWe appreciate your participation in our loyalty programme. Please find your discount code below.\r\n\r\n##COUPON_CODE## [code automatically generated].\r\n\r\nUse it during the checkout procedure and get ##COUPON_AMOUNT## off your order.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(31,9,1,0,'Loyalty programme from ##STORE_NAME## - new discount code','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nWe appreciate your participation in our loyalty programme. Please find your discount code below.\r\n\r\n##COUPON_CODE## [code automatically generated].\r\n\r\nUse it during the checkout procedure and get ##COUPON_AMOUNT## off your order.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(31,10,1,0,'Loyalty programme from ##STORE_NAME## - new discount code','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nWe appreciate your participation in our loyalty programme. Please find your discount code below.\r\n\r\n##COUPON_CODE## [code automatically generated].\r\n\r\nUse it during the checkout procedure and get ##COUPON_AMOUNT## off your order.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(32,1,1,0,'Loyalty programme from ##STORE_NAME## - new discount code','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">We appreciate your participation in our loyalty programme. Please find your discount code below.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><strong>##COUPON_CODE##</strong> [code automatically generated].</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Use it during the checkout procedure and get <strong>##COUPON_AMOUNT##</strong> off your order.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(32,7,1,0,'Loyalty programme from ##STORE_NAME## - new discount code','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">We appreciate your participation in our loyalty programme. Please find your discount code below.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><strong>##COUPON_CODE##</strong> [code automatically generated].</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Use it during the checkout procedure and get <strong>##COUPON_AMOUNT##</strong> off your order.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(32,8,1,0,'Loyalty programme from ##STORE_NAME## - new discount code','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">We appreciate your participation in our loyalty programme. Please find your discount code below.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><strong>##COUPON_CODE##</strong> [code automatically generated].</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Use it during the checkout procedure and get <strong>##COUPON_AMOUNT##</strong> off your order.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(32,9,1,0,'Loyalty programme from ##STORE_NAME## - new discount code','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">We appreciate your participation in our loyalty programme. Please find your discount code below.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><strong>##COUPON_CODE##</strong> [code automatically generated].</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Use it during the checkout procedure and get <strong>##COUPON_AMOUNT##</strong> off your order.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(32,10,1,0,'Loyalty programme from ##STORE_NAME## - new discount code','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">We appreciate your participation in our loyalty programme. Please find your discount code below.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><strong>##COUPON_CODE##</strong> [code automatically generated].</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Use it during the checkout procedure and get <strong>##COUPON_AMOUNT##</strong> off your order.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(33,1,1,0,'Your friend ##CUSTOMER_NAME## has recommend ##STORE_NAME##','Dear ##FRIEND_FIRSTNAME##,\r\n\r\n##CUSTOMER_NAME## thought you might like our online store ##STORE_NAME## and had this to write to you:\r\n\r\n##MESSAGE##\r\n\r\nIf you do decide to give us a try by clicking through the link below, you can receive ##COUPON_AMOUNT## off your first order with no minimum spend, and ##CUSTOMER_NAME## will also receive ##GIFT_AMOUNT## for recommending us too!\r\n\r\nPlease visit ##STORE_NAME## and take a look. The code you can use to receive ##COUPON_AMOUNT## off your first order is:\r\n##COUPON_CODE## [code automatically generated]\r\n\r\nPlease be rest assured you have not been added to any mailing list and, if you decide not to join us, we will not email you again.\r\n\r\nWe hope to serve you soon!\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(33,7,1,0,'Your friend ##CUSTOMER_NAME## has recommend ##STORE_NAME##','Dear ##FRIEND_FIRSTNAME##,\r\n\r\n##CUSTOMER_NAME## thought you might like our online store ##STORE_NAME## and had this to write to you:\r\n\r\n##MESSAGE##\r\n\r\nIf you do decide to give us a try by clicking through the link below, you can receive ##COUPON_AMOUNT## off your first order with no minimum spend, and ##CUSTOMER_NAME## will also receive ##GIFT_AMOUNT## for recommending us too!\r\n\r\nPlease visit ##STORE_NAME## and take a look. The code you can use to receive ##COUPON_AMOUNT## off your first order is:\r\n##COUPON_CODE## [code automatically generated]\r\n\r\nPlease be rest assured you have not been added to any mailing list and, if you decide not to join us, we will not email you again.\r\n\r\nWe hope to serve you soon!\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(33,8,1,0,'Your friend ##CUSTOMER_NAME## has recommend ##STORE_NAME##','Dear ##FRIEND_FIRSTNAME##,\r\n\r\n##CUSTOMER_NAME## thought you might like our online store ##STORE_NAME## and had this to write to you:\r\n\r\n##MESSAGE##\r\n\r\nIf you do decide to give us a try by clicking through the link below, you can receive ##COUPON_AMOUNT## off your first order with no minimum spend, and ##CUSTOMER_NAME## will also receive ##GIFT_AMOUNT## for recommending us too!\r\n\r\nPlease visit ##STORE_NAME## and take a look. The code you can use to receive ##COUPON_AMOUNT## off your first order is:\r\n##COUPON_CODE## [code automatically generated]\r\n\r\nPlease be rest assured you have not been added to any mailing list and, if you decide not to join us, we will not email you again.\r\n\r\nWe hope to serve you soon!\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(33,9,1,0,'Your friend ##CUSTOMER_NAME## has recommend ##STORE_NAME##','Dear ##FRIEND_FIRSTNAME##,\r\n\r\n##CUSTOMER_NAME## thought you might like our online store ##STORE_NAME## and had this to write to you:\r\n\r\n##MESSAGE##\r\n\r\nIf you do decide to give us a try by clicking through the link below, you can receive ##COUPON_AMOUNT## off your first order with no minimum spend, and ##CUSTOMER_NAME## will also receive ##GIFT_AMOUNT## for recommending us too!\r\n\r\nPlease visit ##STORE_NAME## and take a look. The code you can use to receive ##COUPON_AMOUNT## off your first order is:\r\n##COUPON_CODE## [code automatically generated]\r\n\r\nPlease be rest assured you have not been added to any mailing list and, if you decide not to join us, we will not email you again.\r\n\r\nWe hope to serve you soon!\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(33,10,1,0,'Your friend ##CUSTOMER_NAME## has recommend ##STORE_NAME##','Dear ##FRIEND_FIRSTNAME##,\r\n\r\n##CUSTOMER_NAME## thought you might like our online store ##STORE_NAME## and had this to write to you:\r\n\r\n##MESSAGE##\r\n\r\nIf you do decide to give us a try by clicking through the link below, you can receive ##COUPON_AMOUNT## off your first order with no minimum spend, and ##CUSTOMER_NAME## will also receive ##GIFT_AMOUNT## for recommending us too!\r\n\r\nPlease visit ##STORE_NAME## and take a look. The code you can use to receive ##COUPON_AMOUNT## off your first order is:\r\n##COUPON_CODE## [code automatically generated]\r\n\r\nPlease be rest assured you have not been added to any mailing list and, if you decide not to join us, we will not email you again.\r\n\r\nWe hope to serve you soon!\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(34,1,1,0,'Your friend ##CUSTOMER_NAME## has recommend ##STORE_NAME##','<p>Dear ##FRIEND_FIRSTNAME##,</p>\r\n\r\n<p>##CUSTOMER_NAME## thought you might like our online store&nbsp;##STORE_NAME## and had this to write to you:</p>\r\n\r\n<p>##MESSAGE##</p>\r\n\r\n<p>If you do decide to give us a try by clicking through the link below, you can receive ##COUPON_AMOUNT## off your first order with no minimum spend, and ##CUSTOMER_NAME## will also receive ##GIFT_AMOUNT## for recommending us too!</p>\r\n\r\n<p>Please visit <a href=\"##REFER_LINK##\">##STORE_NAME##</a> and take a look. The code you can use to receive ##COUPON_AMOUNT## off your first order is:<br />\r\n##COUPON_CODE## [code automatically generated]</p>\r\n\r\n<p>Please be rest assured you have not been added to any mailing list and, if you decide not to join us, we will not email you again.</p>\r\n\r\n<p>We hope to serve you soon!</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(34,7,1,0,'Your friend ##CUSTOMER_NAME## has recommend ##STORE_NAME##','<p>Dear ##FRIEND_FIRSTNAME##,</p>\r\n\r\n<p>##CUSTOMER_NAME## thought you might like our online store&nbsp;##STORE_NAME## and had this to write to you:</p>\r\n\r\n<p>##MESSAGE##</p>\r\n\r\n<p>If you do decide to give us a try by clicking through the link below, you can receive ##COUPON_AMOUNT## off your first order with no minimum spend, and ##CUSTOMER_NAME## will also receive ##GIFT_AMOUNT## for recommending us too!</p>\r\n\r\n<p>Please visit <a href=\"##REFER_LINK##\">##STORE_NAME##</a> and take a look. The code you can use to receive ##COUPON_AMOUNT## off your first order is:<br />\r\n##COUPON_CODE## [code automatically generated]</p>\r\n\r\n<p>Please be rest assured you have not been added to any mailing list and, if you decide not to join us, we will not email you again.</p>\r\n\r\n<p>We hope to serve you soon!</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(34,8,1,0,'Your friend ##CUSTOMER_NAME## has recommend ##STORE_NAME##','<p>Dear ##FRIEND_FIRSTNAME##,</p>\r\n\r\n<p>##CUSTOMER_NAME## thought you might like our online store&nbsp;##STORE_NAME## and had this to write to you:</p>\r\n\r\n<p>##MESSAGE##</p>\r\n\r\n<p>If you do decide to give us a try by clicking through the link below, you can receive ##COUPON_AMOUNT## off your first order with no minimum spend, and ##CUSTOMER_NAME## will also receive ##GIFT_AMOUNT## for recommending us too!</p>\r\n\r\n<p>Please visit <a href=\"##REFER_LINK##\">##STORE_NAME##</a> and take a look. The code you can use to receive ##COUPON_AMOUNT## off your first order is:<br />\r\n##COUPON_CODE## [code automatically generated]</p>\r\n\r\n<p>Please be rest assured you have not been added to any mailing list and, if you decide not to join us, we will not email you again.</p>\r\n\r\n<p>We hope to serve you soon!</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(34,9,1,0,'Your friend ##CUSTOMER_NAME## has recommend ##STORE_NAME##','<p>Dear ##FRIEND_FIRSTNAME##,</p>\r\n\r\n<p>##CUSTOMER_NAME## thought you might like our online store&nbsp;##STORE_NAME## and had this to write to you:</p>\r\n\r\n<p>##MESSAGE##</p>\r\n\r\n<p>If you do decide to give us a try by clicking through the link below, you can receive ##COUPON_AMOUNT## off your first order with no minimum spend, and ##CUSTOMER_NAME## will also receive ##GIFT_AMOUNT## for recommending us too!</p>\r\n\r\n<p>Please visit <a href=\"##REFER_LINK##\">##STORE_NAME##</a> and take a look. The code you can use to receive ##COUPON_AMOUNT## off your first order is:<br />\r\n##COUPON_CODE## [code automatically generated]</p>\r\n\r\n<p>Please be rest assured you have not been added to any mailing list and, if you decide not to join us, we will not email you again.</p>\r\n\r\n<p>We hope to serve you soon!</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(34,10,1,0,'Your friend ##CUSTOMER_NAME## has recommend ##STORE_NAME##','<p>Dear ##FRIEND_FIRSTNAME##,</p>\r\n\r\n<p>##CUSTOMER_NAME## thought you might like our online store&nbsp;##STORE_NAME## and had this to write to you:</p>\r\n\r\n<p>##MESSAGE##</p>\r\n\r\n<p>If you do decide to give us a try by clicking through the link below, you can receive ##COUPON_AMOUNT## off your first order with no minimum spend, and ##CUSTOMER_NAME## will also receive ##GIFT_AMOUNT## for recommending us too!</p>\r\n\r\n<p>Please visit <a href=\"##REFER_LINK##\">##STORE_NAME##</a> and take a look. The code you can use to receive ##COUPON_AMOUNT## off your first order is:<br />\r\n##COUPON_CODE## [code automatically generated]</p>\r\n\r\n<p>Please be rest assured you have not been added to any mailing list and, if you decide not to join us, we will not email you again.</p>\r\n\r\n<p>We hope to serve you soon!</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(35,1,1,0,'##STORE_NAME## - reference programme update','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYour friend ##FRIEND_NAME## has placed their first order with us! \r\n\r\nWe appreciate your participation in our customer reference program. Please find your discount code below.\r\n\r\n##COUPON_CODE## [code automatically generated]\r\n\r\nUse it during the checkout procedure and get ##GIFT_AMOUNT## off your order.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(35,7,1,0,'##STORE_NAME## - reference programme update','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYour friend ##FRIEND_NAME## has placed their first order with us! \r\n\r\nWe appreciate your participation in our customer reference program. Please find your discount code below.\r\n\r\n##COUPON_CODE## [code automatically generated]\r\n\r\nUse it during the checkout procedure and get ##GIFT_AMOUNT## off your order.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(35,8,1,0,'##STORE_NAME## - reference programme update','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYour friend ##FRIEND_NAME## has placed their first order with us! \r\n\r\nWe appreciate your participation in our customer reference program. Please find your discount code below.\r\n\r\n##COUPON_CODE## [code automatically generated]\r\n\r\nUse it during the checkout procedure and get ##GIFT_AMOUNT## off your order.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(35,9,1,0,'##STORE_NAME## - reference programme update','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYour friend ##FRIEND_NAME## has placed their first order with us! \r\n\r\nWe appreciate your participation in our customer reference program. Please find your discount code below.\r\n\r\n##COUPON_CODE## [code automatically generated]\r\n\r\nUse it during the checkout procedure and get ##GIFT_AMOUNT## off your order.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(35,10,1,0,'##STORE_NAME## - reference programme update','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYour friend ##FRIEND_NAME## has placed their first order with us! \r\n\r\nWe appreciate your participation in our customer reference program. Please find your discount code below.\r\n\r\n##COUPON_CODE## [code automatically generated]\r\n\r\nUse it during the checkout procedure and get ##GIFT_AMOUNT## off your order.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(36,1,1,0,'##STORE_NAME## - reference programme update','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your friend ##FRIEND_NAME## has placed their first order with us!&nbsp;</p>\r\n\r\n<p>We appreciate your participation in our customer reference program. Please find your discount code below.</p>\r\n\r\n<p>##COUPON_CODE## [code automatically generated]</p>\r\n\r\n<p>Use it during the checkout procedure and get ##GIFT_AMOUNT## off your order.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(36,7,1,0,'##STORE_NAME## - reference programme update','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your friend ##FRIEND_NAME## has placed their first order with us!&nbsp;</p>\r\n\r\n<p>We appreciate your participation in our customer reference program. Please find your discount code below.</p>\r\n\r\n<p>##COUPON_CODE## [code automatically generated]</p>\r\n\r\n<p>Use it during the checkout procedure and get ##GIFT_AMOUNT## off your order.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(36,8,1,0,'##STORE_NAME## - reference programme update','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your friend ##FRIEND_NAME## has placed their first order with us!&nbsp;</p>\r\n\r\n<p>We appreciate your participation in our customer reference program. Please find your discount code below.</p>\r\n\r\n<p>##COUPON_CODE## [code automatically generated]</p>\r\n\r\n<p>Use it during the checkout procedure and get ##GIFT_AMOUNT## off your order.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(36,9,1,0,'##STORE_NAME## - reference programme update','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your friend ##FRIEND_NAME## has placed their first order with us!&nbsp;</p>\r\n\r\n<p>We appreciate your participation in our customer reference program. Please find your discount code below.</p>\r\n\r\n<p>##COUPON_CODE## [code automatically generated]</p>\r\n\r\n<p>Use it during the checkout procedure and get ##GIFT_AMOUNT## off your order.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(36,10,1,0,'##STORE_NAME## - reference programme update','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your friend ##FRIEND_NAME## has placed their first order with us!&nbsp;</p>\r\n\r\n<p>We appreciate your participation in our customer reference program. Please find your discount code below.</p>\r\n\r\n<p>##COUPON_CODE## [code automatically generated]</p>\r\n\r\n<p>Use it during the checkout procedure and get ##GIFT_AMOUNT## off your order.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(37,1,1,0,'##STORE_NAME## - new customer testimonial','Dear ##STORE_OWNER##,\r\n\r\nHere is the most recent customer comment about your online store.\r\n\r\nIt goes like this:\r\n##MESSAGE##\r\n\r\nTo edit this go to : ##REFER_LINK##'),(37,7,1,0,'##STORE_NAME## - new customer testimonial','Dear ##STORE_OWNER##,\r\n\r\nHere is the most recent customer comment about your online store.\r\n\r\nIt goes like this:\r\n##MESSAGE##\r\n\r\nTo edit this go to : ##REFER_LINK##'),(37,8,1,0,'##STORE_NAME## - new customer testimonial','Dear ##STORE_OWNER##,\r\n\r\nHere is the most recent customer comment about your online store.\r\n\r\nIt goes like this:\r\n##MESSAGE##\r\n\r\nTo edit this go to : ##REFER_LINK##'),(37,9,1,0,'##STORE_NAME## - new customer testimonial','Dear ##STORE_OWNER##,\r\n\r\nHere is the most recent customer comment about your online store.\r\n\r\nIt goes like this:\r\n##MESSAGE##\r\n\r\nTo edit this go to : ##REFER_LINK##'),(37,10,1,0,'##STORE_NAME## - new customer testimonial','Dear ##STORE_OWNER##,\r\n\r\nHere is the most recent customer comment about your online store.\r\n\r\nIt goes like this:\r\n##MESSAGE##\r\n\r\nTo edit this go to : ##REFER_LINK##'),(38,1,1,0,'##STORE_NAME## - new customer testimonial','Dear ##STORE_OWNER##,\r\n<p>Here is the most recent customer comment about your online store.</p>\r\n\r\n<p>It goes like this:</p>\r\n\r\n<p>##MESSAGE##</p>\r\n\r\n<p>To edit this go to : <a href=\"##REFER_LINK##\">this link</a></p>'),(38,7,1,0,'##STORE_NAME## - new customer testimonial','Dear ##STORE_OWNER##,\r\n<p>Here is the most recent customer comment about your online store.</p>\r\n\r\n<p>It goes like this:</p>\r\n\r\n<p>##MESSAGE##</p>\r\n\r\n<p>To edit this go to : <a href=\"##REFER_LINK##\">this link</a></p>'),(38,8,1,0,'##STORE_NAME## - new customer testimonial','Dear ##STORE_OWNER##,\r\n<p>Here is the most recent customer comment about your online store.</p>\r\n\r\n<p>It goes like this:</p>\r\n\r\n<p>##MESSAGE##</p>\r\n\r\n<p>To edit this go to : <a href=\"##REFER_LINK##\">this link</a></p>'),(38,9,1,0,'##STORE_NAME## - new customer testimonial','Dear ##STORE_OWNER##,\r\n<p>Here is the most recent customer comment about your online store.</p>\r\n\r\n<p>It goes like this:</p>\r\n\r\n<p>##MESSAGE##</p>\r\n\r\n<p>To edit this go to : <a href=\"##REFER_LINK##\">this link</a></p>'),(38,10,1,0,'##STORE_NAME## - new customer testimonial','Dear ##STORE_OWNER##,\r\n<p>Here is the most recent customer comment about your online store.</p>\r\n\r\n<p>It goes like this:</p>\r\n\r\n<p>##MESSAGE##</p>\r\n\r\n<p>To edit this go to : <a href=\"##REFER_LINK##\">this link</a></p>'),(39,1,1,0,'##STORE_NAME## - gift voucher','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYou have been sent a gift voucher ##COUPON_NAME##!\r\n\r\nGift voucher amount: ##COUPON_AMOUNT##\r\nDesciption: \r\n##COUPON_DESCRIPTION##\r\n\r\nYou can now redeem this gift voucher during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.\r\nThe gift voucher code is ##COUPON_CODE##\r\n\r\nPlease keep the code safe so you can benefit from this unique special offer.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(39,7,1,0,'##STORE_NAME## - gift voucher','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYou have been sent a gift voucher ##COUPON_NAME##!\r\n\r\nGift voucher amount: ##COUPON_AMOUNT##\r\nDesciption: \r\n##COUPON_DESCRIPTION##\r\n\r\nYou can now redeem this gift voucher during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.\r\nThe gift voucher code is ##COUPON_CODE##\r\n\r\nPlease keep the code safe so you can benefit from this unique special offer.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(39,8,1,0,'##STORE_NAME## - gift voucher','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYou have been sent a gift voucher ##COUPON_NAME##!\r\n\r\nGift voucher amount: ##COUPON_AMOUNT##\r\nDesciption: \r\n##COUPON_DESCRIPTION##\r\n\r\nYou can now redeem this gift voucher during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.\r\nThe gift voucher code is ##COUPON_CODE##\r\n\r\nPlease keep the code safe so you can benefit from this unique special offer.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(39,9,1,0,'##STORE_NAME## - gift voucher','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYou have been sent a gift voucher ##COUPON_NAME##!\r\n\r\nGift voucher amount: ##COUPON_AMOUNT##\r\nDesciption: \r\n##COUPON_DESCRIPTION##\r\n\r\nYou can now redeem this gift voucher during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.\r\nThe gift voucher code is ##COUPON_CODE##\r\n\r\nPlease keep the code safe so you can benefit from this unique special offer.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(39,10,1,0,'##STORE_NAME## - gift voucher','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nYou have been sent a gift voucher ##COUPON_NAME##!\r\n\r\nGift voucher amount: ##COUPON_AMOUNT##\r\nDesciption: \r\n##COUPON_DESCRIPTION##\r\n\r\nYou can now redeem this gift voucher during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.\r\nThe gift voucher code is ##COUPON_CODE##\r\n\r\nPlease keep the code safe so you can benefit from this unique special offer.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(40,1,1,0,'##STORE_NAME## - gift voucher','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>You have been sent a gift voucher ##COUPON_NAME##!</p>\r\n\r\n<p>Gift voucher amount:&nbsp;<strong>##COUPON_AMOUNT##</strong><br />\r\nDesciption:&nbsp;<br />\r\n##COUPON_DESCRIPTION##</p>\r\n\r\n<p>You can now redeem this gift voucher during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.<br />\r\nThe gift voucher code is <strong>##COUPON_CODE##</strong></p>\r\n\r\n<p>Please keep the code safe so you can benefit from this unique special offer.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(40,7,1,0,'##STORE_NAME## - gift voucher','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>You have been sent a gift voucher ##COUPON_NAME##!</p>\r\n\r\n<p>Gift voucher amount:&nbsp;<strong>##COUPON_AMOUNT##</strong><br />\r\nDesciption:&nbsp;<br />\r\n##COUPON_DESCRIPTION##</p>\r\n\r\n<p>You can now redeem this gift voucher during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.<br />\r\nThe gift voucher code is <strong>##COUPON_CODE##</strong></p>\r\n\r\n<p>Please keep the code safe so you can benefit from this unique special offer.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(40,8,1,0,'##STORE_NAME## - gift voucher','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>You have been sent a gift voucher ##COUPON_NAME##!</p>\r\n\r\n<p>Gift voucher amount:&nbsp;<strong>##COUPON_AMOUNT##</strong><br />\r\nDesciption:&nbsp;<br />\r\n##COUPON_DESCRIPTION##</p>\r\n\r\n<p>You can now redeem this gift voucher during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.<br />\r\nThe gift voucher code is <strong>##COUPON_CODE##</strong></p>\r\n\r\n<p>Please keep the code safe so you can benefit from this unique special offer.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(40,9,1,0,'##STORE_NAME## - gift voucher','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>You have been sent a gift voucher ##COUPON_NAME##!</p>\r\n\r\n<p>Gift voucher amount:&nbsp;<strong>##COUPON_AMOUNT##</strong><br />\r\nDesciption:&nbsp;<br />\r\n##COUPON_DESCRIPTION##</p>\r\n\r\n<p>You can now redeem this gift voucher during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.<br />\r\nThe gift voucher code is <strong>##COUPON_CODE##</strong></p>\r\n\r\n<p>Please keep the code safe so you can benefit from this unique special offer.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(40,10,1,0,'##STORE_NAME## - gift voucher','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>You have been sent a gift voucher ##COUPON_NAME##!</p>\r\n\r\n<p>Gift voucher amount:&nbsp;<strong>##COUPON_AMOUNT##</strong><br />\r\nDesciption:&nbsp;<br />\r\n##COUPON_DESCRIPTION##</p>\r\n\r\n<p>You can now redeem this gift voucher during the checkout on our website ##HTTP_HOST##. Just enter the code in the box provided, and press the Redeem button.<br />\r\nThe gift voucher code is <strong>##COUPON_CODE##</strong></p>\r\n\r\n<p>Please keep the code safe so you can benefit from this unique special offer.</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(41,1,1,0,'Notification from ##STORE_NAME##','<p><span style=\"font-size:12px;\">Dear </span>##CUSTOMER_FIRSTNAME##<span style=\"font-size:12px;\">,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Exciting news - product ##PRODUCT_NAME## is back in stock!</span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><a href=\"##PRODUCT_URL##\"><img alt=\"##PRODUCT_NAME##\" src=\"##PRODUCT_IMAGE##\" /></a></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">You&#39;re receiving this communication because you filled in a corresponding form on our website.&nbsp;</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(41,7,1,0,'Notification from ##STORE_NAME##','<p><span style=\"font-size:12px;\">Dear </span>##CUSTOMER_FIRSTNAME##<span style=\"font-size:12px;\">,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Exciting news - product ##PRODUCT_NAME## is back in stock!</span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><a href=\"##PRODUCT_URL##\"><img alt=\"##PRODUCT_NAME##\" src=\"##PRODUCT_IMAGE##\" /></a></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">You&#39;re receiving this communication because you filled in a corresponding form on our website.&nbsp;</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(41,8,1,0,'Notification from ##STORE_NAME##','<p><span style=\"font-size:12px;\">Dear </span>##CUSTOMER_FIRSTNAME##<span style=\"font-size:12px;\">,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Exciting news - product ##PRODUCT_NAME## is back in stock!</span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><a href=\"##PRODUCT_URL##\"><img alt=\"##PRODUCT_NAME##\" src=\"##PRODUCT_IMAGE##\" /></a></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">You&#39;re receiving this communication because you filled in a corresponding form on our website.&nbsp;</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(41,9,1,0,'Notification from ##STORE_NAME##','<p><span style=\"font-size:12px;\">Dear </span>##CUSTOMER_FIRSTNAME##<span style=\"font-size:12px;\">,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Exciting news - product ##PRODUCT_NAME## is back in stock!</span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><a href=\"##PRODUCT_URL##\"><img alt=\"##PRODUCT_NAME##\" src=\"##PRODUCT_IMAGE##\" /></a></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">You&#39;re receiving this communication because you filled in a corresponding form on our website.&nbsp;</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(41,10,1,0,'Notification from ##STORE_NAME##','<p><span style=\"font-size:12px;\">Dear </span>##CUSTOMER_FIRSTNAME##<span style=\"font-size:12px;\">,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Exciting news - product ##PRODUCT_NAME## is back in stock!</span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><a href=\"##PRODUCT_URL##\"><img alt=\"##PRODUCT_NAME##\" src=\"##PRODUCT_IMAGE##\" /></a></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">You&#39;re receiving this communication because you filled in a corresponding form on our website.&nbsp;</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(42,1,1,0,'','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nExciting news - product ##PRODUCT_NAME## is back in stock!\r\n\r\nYou\'re receiving this communication because you filled in a corresponding form on our website. \r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(42,7,1,0,'','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nExciting news - product ##PRODUCT_NAME## is back in stock!\r\n\r\nYou\'re receiving this communication because you filled in a corresponding form on our website. \r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(42,8,1,0,'','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nExciting news - product ##PRODUCT_NAME## is back in stock!\r\n\r\nYou\'re receiving this communication because you filled in a corresponding form on our website. \r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(42,9,1,0,'','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nExciting news - product ##PRODUCT_NAME## is back in stock!\r\n\r\nYou\'re receiving this communication because you filled in a corresponding form on our website. \r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(42,10,1,0,'','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nExciting news - product ##PRODUCT_NAME## is back in stock!\r\n\r\nYou\'re receiving this communication because you filled in a corresponding form on our website. \r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(48,1,1,0,'Subscribe to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nWe have received a subscription request from your email address. \r\n\r\nPlease confirm your subscrition status by clicking the following link:\r\n##SUBSCRIBE_LINK##\r\n\r\nIn case you have had a change of heart - not a problem at all, please simple ignore this email.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(48,7,1,0,'Subscribe to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nWe have received a subscription request from your email address. \r\n\r\nPlease confirm your subscrition status by clicking the following link:\r\n##SUBSCRIBE_LINK##\r\n\r\nIn case you have had a change of heart - not a problem at all, please simple ignore this email.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(48,8,1,0,'Subscribe to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nWe have received a subscription request from your email address. \r\n\r\nPlease confirm your subscrition status by clicking the following link:\r\n##SUBSCRIBE_LINK##\r\n\r\nIn case you have had a change of heart - not a problem at all, please simple ignore this email.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(48,9,1,0,'Subscribe to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nWe have received a subscription request from your email address. \r\n\r\nPlease confirm your subscrition status by clicking the following link:\r\n##SUBSCRIBE_LINK##\r\n\r\nIn case you have had a change of heart - not a problem at all, please simple ignore this email.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(48,10,1,0,'Subscribe to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nWe have received a subscription request from your email address. \r\n\r\nPlease confirm your subscrition status by clicking the following link:\r\n##SUBSCRIBE_LINK##\r\n\r\nIn case you have had a change of heart - not a problem at all, please simple ignore this email.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(49,1,1,0,'Subscribe to ##STORE_NAME## news','<p><span style=\"font-size:12px;\">Dear&nbsp;##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">We have received a subscription request from your email address.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please confirm your subscrition status by clicking the following link:<br />\r\n<a href=\"##SUBSCRIBE_LINK##\">##SUBSCRIBE_LINK##</a></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">In case you have had a change of heart - not a problem at all, please simple ignore this email.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(49,7,1,0,'Subscribe to ##STORE_NAME## news','<p><span style=\"font-size:12px;\">Dear&nbsp;##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">We have received a subscription request from your email address.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please confirm your subscrition status by clicking the following link:<br />\r\n<a href=\"##SUBSCRIBE_LINK##\">##SUBSCRIBE_LINK##</a></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">In case you have had a change of heart - not a problem at all, please simple ignore this email.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(49,8,1,0,'Subscribe to ##STORE_NAME## news','<p><span style=\"font-size:12px;\">Dear&nbsp;##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">We have received a subscription request from your email address.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please confirm your subscrition status by clicking the following link:<br />\r\n<a href=\"##SUBSCRIBE_LINK##\">##SUBSCRIBE_LINK##</a></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">In case you have had a change of heart - not a problem at all, please simple ignore this email.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(49,9,1,0,'Subscribe to ##STORE_NAME## news','<p><span style=\"font-size:12px;\">Dear&nbsp;##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">We have received a subscription request from your email address.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please confirm your subscrition status by clicking the following link:<br />\r\n<a href=\"##SUBSCRIBE_LINK##\">##SUBSCRIBE_LINK##</a></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">In case you have had a change of heart - not a problem at all, please simple ignore this email.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(49,10,1,0,'Subscribe to ##STORE_NAME## news','<p><span style=\"font-size:12px;\">Dear&nbsp;##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">We have received a subscription request from your email address.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please confirm your subscrition status by clicking the following link:<br />\r\n<a href=\"##SUBSCRIBE_LINK##\">##SUBSCRIBE_LINK##</a></span></p>\r\n\r\n<p><span style=\"font-size:12px;\">In case you have had a change of heart - not a problem at all, please simple ignore this email.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(50,1,1,0,'Subscribtion to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for subscribing to our newsletter!\r\n\r\nYou can always unsubscribe by using this link: ##UNSUBSCRIBE_LINK##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(50,7,1,0,'Subscribtion to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for subscribing to our newsletter!\r\n\r\nYou can always unsubscribe by using this link: ##UNSUBSCRIBE_LINK##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(50,8,1,0,'Subscribtion to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for subscribing to our newsletter!\r\n\r\nYou can always unsubscribe by using this link: ##UNSUBSCRIBE_LINK##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(50,9,1,0,'Subscribtion to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for subscribing to our newsletter!\r\n\r\nYou can always unsubscribe by using this link: ##UNSUBSCRIBE_LINK##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(50,10,1,0,'Subscribtion to ##STORE_NAME##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for subscribing to our newsletter!\r\n\r\nYou can always unsubscribe by using this link: ##UNSUBSCRIBE_LINK##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(51,1,1,0,'##STORE_NAME## - subscription','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for subscribing to our newsletter!</p>\r\n\r\n<p>You can always unsubscribe by using this link:&nbsp;##UNSUBSCRIBE_LINK##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(51,7,1,0,'##STORE_NAME## - subscription','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for subscribing to our newsletter!</p>\r\n\r\n<p>You can always unsubscribe by using this link:&nbsp;##UNSUBSCRIBE_LINK##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(51,8,1,0,'##STORE_NAME## - subscription','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for subscribing to our newsletter!</p>\r\n\r\n<p>You can always unsubscribe by using this link:&nbsp;##UNSUBSCRIBE_LINK##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(51,9,1,0,'##STORE_NAME## - subscription','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for subscribing to our newsletter!</p>\r\n\r\n<p>You can always unsubscribe by using this link:&nbsp;##UNSUBSCRIBE_LINK##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(51,10,1,0,'##STORE_NAME## - subscription','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for subscribing to our newsletter!</p>\r\n\r\n<p>You can always unsubscribe by using this link:&nbsp;##UNSUBSCRIBE_LINK##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(53,1,1,0,'Unubscribe from ##STORE_NAME##','<a href=\"##UNSUBSCRIBE_LINK##\">Unsubsribe Link</a>'),(53,7,1,0,'Unubscribe from ##STORE_NAME##','<a href=\"##UNSUBSCRIBE_LINK##\">Unsubsribe Link</a>'),(53,8,1,0,'Unubscribe from ##STORE_NAME##','<a href=\"##UNSUBSCRIBE_LINK##\">Unsubsribe Link</a>'),(53,9,1,0,'Unubscribe from ##STORE_NAME##','<a href=\"##UNSUBSCRIBE_LINK##\">Unsubsribe Link</a>'),(53,10,1,0,'Unubscribe from ##STORE_NAME##','<a href=\"##UNSUBSCRIBE_LINK##\">Unsubsribe Link</a>'),(54,1,1,0,'Unsubscribtion from ##STORE_NAME##','You was successfully unsubscribed from ##STORE_NAME##'),(54,7,1,0,'Unsubscribtion from ##STORE_NAME##','You was successfully unsubscribed from ##STORE_NAME##'),(54,8,1,0,'Unsubscribtion from ##STORE_NAME##','You was successfully unsubscribed from ##STORE_NAME##'),(54,9,1,0,'Unsubscribtion from ##STORE_NAME##','You was successfully unsubscribed from ##STORE_NAME##'),(54,10,1,0,'Unsubscribtion from ##STORE_NAME##','You was successfully unsubscribed from ##STORE_NAME##'),(55,1,1,0,'Unsubscribtion from ##STORE_NAME##','You have been successfully unsubscribed from ##STORE_NAME##'),(55,7,1,0,'Unsubscribtion from ##STORE_NAME##','You have been successfully unsubscribed from ##STORE_NAME##'),(55,8,1,0,'Unsubscribtion from ##STORE_NAME##','You have been successfully unsubscribed from ##STORE_NAME##'),(55,9,1,0,'Unsubscribtion from ##STORE_NAME##','You have been successfully unsubscribed from ##STORE_NAME##'),(55,10,1,0,'Unsubscribtion from ##STORE_NAME##','You have been successfully unsubscribed from ##STORE_NAME##'),(56,1,1,0,'##STORE_NAME## - thank you for your sample order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Dear&nbsp;##CUSTOMER_FIRSTNAME##,</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Thank you very much for placing a sample&nbsp;order with&nbsp;##STORE_NAME##!</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Here are some sample order details for your reference:</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Sample Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Sample Ordered: ##ORDER_DATE_LONG##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Here is the list of samples on your order:<br />\r\n##PRODUCTS_ORDERED##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">This is the summary of your sample order with us:<br />\r\n##ORDER_TOTALS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">As per your instructions we will delivery your sample order to the following address:<br />\r\n##DELIVERY_ADDRESS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">This billing address will be used for the invoice:<br />\r\n##BILLING_ADDRESS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">You have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Once again, thanks a lot for your sample order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></span></p>'),(56,7,1,0,'##STORE_NAME## - thank you for your sample order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Dear&nbsp;##CUSTOMER_FIRSTNAME##,</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Thank you very much for placing a sample&nbsp;order with&nbsp;##STORE_NAME##!</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Here are some sample order details for your reference:</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Sample Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Sample Ordered: ##ORDER_DATE_LONG##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Here is the list of samples on your order:<br />\r\n##PRODUCTS_ORDERED##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">This is the summary of your sample order with us:<br />\r\n##ORDER_TOTALS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">As per your instructions we will delivery your sample order to the following address:<br />\r\n##DELIVERY_ADDRESS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">This billing address will be used for the invoice:<br />\r\n##BILLING_ADDRESS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">You have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Once again, thanks a lot for your sample order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></span></p>'),(56,8,1,0,'##STORE_NAME## - thank you for your sample order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Dear&nbsp;##CUSTOMER_FIRSTNAME##,</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Thank you very much for placing a sample&nbsp;order with&nbsp;##STORE_NAME##!</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Here are some sample order details for your reference:</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Sample Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Sample Ordered: ##ORDER_DATE_LONG##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Here is the list of samples on your order:<br />\r\n##PRODUCTS_ORDERED##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">This is the summary of your sample order with us:<br />\r\n##ORDER_TOTALS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">As per your instructions we will delivery your sample order to the following address:<br />\r\n##DELIVERY_ADDRESS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">This billing address will be used for the invoice:<br />\r\n##BILLING_ADDRESS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">You have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Once again, thanks a lot for your sample order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></span></p>'),(56,9,1,0,'##STORE_NAME## - thank you for your sample order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Dear&nbsp;##CUSTOMER_FIRSTNAME##,</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Thank you very much for placing a sample&nbsp;order with&nbsp;##STORE_NAME##!</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Here are some sample order details for your reference:</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Sample Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Sample Ordered: ##ORDER_DATE_LONG##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Here is the list of samples on your order:<br />\r\n##PRODUCTS_ORDERED##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">This is the summary of your sample order with us:<br />\r\n##ORDER_TOTALS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">As per your instructions we will delivery your sample order to the following address:<br />\r\n##DELIVERY_ADDRESS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">This billing address will be used for the invoice:<br />\r\n##BILLING_ADDRESS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">You have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Once again, thanks a lot for your sample order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></span></p>'),(56,10,1,0,'##STORE_NAME## - thank you for your sample order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Dear&nbsp;##CUSTOMER_FIRSTNAME##,</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Thank you very much for placing a sample&nbsp;order with&nbsp;##STORE_NAME##!</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Here are some sample order details for your reference:</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Sample Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice:<br />\r\n##ORDER_INVOICE_URL##<br />\r\nDate Sample Ordered: ##ORDER_DATE_LONG##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Here is the list of samples on your order:<br />\r\n##PRODUCTS_ORDERED##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">This is the summary of your sample order with us:<br />\r\n##ORDER_TOTALS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">As per your instructions we will delivery your sample order to the following address:<br />\r\n##DELIVERY_ADDRESS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">This billing address will be used for the invoice:<br />\r\n##BILLING_ADDRESS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">You have chosen the following payment method:<br />\r\n##PAYMENT_METHOD##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Your special instructions or comments were as follows:<br />\r\n##ORDER_COMMENTS##</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Once again, thanks a lot for your sample order with us! We will be in touch in due&nbsp;course to update you on our progress with it.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></span></p>\r\n\r\n<p><span style=\"font-size:12px;\"><span style=\"font-family:Arial,Helvetica,sans-serif;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></span></p>'),(57,1,1,0,'##STORE_NAME## - thank you for your sample order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing a sample order with ##STORE_NAME##!\r\n\r\nHere are some sample order details for your reference:\r\n\r\nSample Order Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Sample Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of samples on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your sample order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your sample order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your sample order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(57,7,1,0,'##STORE_NAME## - thank you for your sample order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing a sample order with ##STORE_NAME##!\r\n\r\nHere are some sample order details for your reference:\r\n\r\nSample Order Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Sample Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of samples on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your sample order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your sample order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your sample order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(57,8,1,0,'##STORE_NAME## - thank you for your sample order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing a sample order with ##STORE_NAME##!\r\n\r\nHere are some sample order details for your reference:\r\n\r\nSample Order Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Sample Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of samples on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your sample order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your sample order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your sample order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(57,9,1,0,'##STORE_NAME## - thank you for your sample order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing a sample order with ##STORE_NAME##!\r\n\r\nHere are some sample order details for your reference:\r\n\r\nSample Order Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Sample Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of samples on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your sample order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your sample order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your sample order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(57,10,1,0,'##STORE_NAME## - thank you for your sample order ##ORDER_NUMBER## from ##ORDER_DATE_SHORT##','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you very much for placing a sample order with ##STORE_NAME##!\r\n\r\nHere are some sample order details for your reference:\r\n\r\nSample Order Number: ##ORDER_NUMBER##\r\nDetailed Invoice:\r\n##ORDER_INVOICE_URL##\r\nDate Sample Ordered: ##ORDER_DATE_LONG##\r\n\r\nHere is the list of samples on your order:\r\n##PRODUCTS_ORDERED##\r\n\r\nThis is the summary of your sample order with us:\r\n##ORDER_TOTALS##\r\n\r\nAs per your instructions we will delivery your sample order to the following address:\r\n##DELIVERY_ADDRESS##\r\n\r\nThis billing address will be used for the invoice:\r\n##BILLING_ADDRESS##\r\n\r\nYou have chosen the following payment method:\r\n##PAYMENT_METHOD##\r\n\r\nYour special instructions or comments were as follows:\r\n##ORDER_COMMENTS##\r\n\r\nOnce again, thanks a lot for your sample order with us! We will be in touch in due course to update you on our progress with it.\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(60,1,1,0,'##STORE_NAME## - items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##<br />\r\n<br />\r\n##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(60,7,1,0,'##STORE_NAME## - items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##<br />\r\n<br />\r\n##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(60,8,1,0,'##STORE_NAME## - items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##<br />\r\n<br />\r\n##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(60,9,1,0,'##STORE_NAME## - items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##<br />\r\n<br />\r\n##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(60,10,1,0,'##STORE_NAME## - items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##<br />\r\n<br />\r\n##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(61,1,1,0,'##STORE_NAME## - items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(61,7,1,0,'##STORE_NAME## - items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(61,8,1,0,'##STORE_NAME## - items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(61,9,1,0,'##STORE_NAME## - items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(61,10,1,0,'##STORE_NAME## - items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(62,1,1,0,'##STORE_NAME## - items are still in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(62,7,1,0,'##STORE_NAME## - items are still in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(62,8,1,0,'##STORE_NAME## - items are still in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(62,9,1,0,'##STORE_NAME## - items are still in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(62,10,1,0,'##STORE_NAME## - items are still in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(63,1,1,0,'##STORE_NAME## - items are still in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(63,7,1,0,'##STORE_NAME## - items are still in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(63,8,1,0,'##STORE_NAME## - items are still in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(63,9,1,0,'##STORE_NAME## - items are still in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(63,10,1,0,'##STORE_NAME## - items are still in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(64,1,1,0,'##STORE_NAME## - reminder about items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(64,7,1,0,'##STORE_NAME## - reminder about items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(64,8,1,0,'##STORE_NAME## - reminder about items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(64,9,1,0,'##STORE_NAME## - reminder about items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(64,10,1,0,'##STORE_NAME## - reminder about items in your shopping cart','<p>Dear&nbsp;##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Thank you for choosing to visit ##STORE_NAME##!</p>\r\n\r\n<p>We noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.</p>\r\n\r\n<p>Items currently in your card are as follows:<br />\r\n##PRODUCTS_ORDERED##</p>\r\n\r\n<p>The following comments have been made about your order:<br />\r\n##ORDER_COMMENTS##</p>\r\n\r\n<p>##COUPON_CODE##</p>\r\n\r\n<p>Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</p>\r\n\r\n<p>Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</p>'),(65,1,1,0,'##STORE_NAME## - reminder about items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(65,7,1,0,'##STORE_NAME## - reminder about items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(65,8,1,0,'##STORE_NAME## - reminder about items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(65,9,1,0,'##STORE_NAME## - reminder about items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(65,10,1,0,'##STORE_NAME## - reminder about items in your shopping cart','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nWe noticed you had selected some items and placed them into your shopping cart, however you did not complete your order at that time.\r\n\r\nItems currently in your card are as follows:\r\n##PRODUCTS_ORDERED##\r\n\r\nThe following comments have been made about your order:\r\n##ORDER_COMMENTS##\r\n\r\n##COUPON_CODE##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(66,1,1,0,'','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Thank you for choosing to visit ##STORE_NAME##!</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Our Customer assistance team thought you might be interested in the following products:</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">##PRODUCTS_ORDERED##</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(66,7,1,0,'','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Thank you for choosing to visit ##STORE_NAME##!</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Our Customer assistance team thought you might be interested in the following products:</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">##PRODUCTS_ORDERED##</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(66,8,1,0,'','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Thank you for choosing to visit ##STORE_NAME##!</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Our Customer assistance team thought you might be interested in the following products:</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">##PRODUCTS_ORDERED##</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(66,9,1,0,'','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Thank you for choosing to visit ##STORE_NAME##!</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Our Customer assistance team thought you might be interested in the following products:</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">##PRODUCTS_ORDERED##</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(66,10,1,0,'','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Thank you for choosing to visit ##STORE_NAME##!</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Our Customer assistance team thought you might be interested in the following products:</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">##PRODUCTS_ORDERED##</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\r\n\r\n<p><span style=\"font-size:12px;\">Kind regards,<br />\r\nThe team of&nbsp;##STORE_NAME##</span></p>'),(67,1,1,0,'','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nOur Customer assistance team thought you might be interested in the following products:\r\n\r\n##PRODUCTS_ORDERED##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(67,7,1,0,'','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nOur Customer assistance team thought you might be interested in the following products:\r\n\r\n##PRODUCTS_ORDERED##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(67,8,1,0,'','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nOur Customer assistance team thought you might be interested in the following products:\r\n\r\n##PRODUCTS_ORDERED##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(67,9,1,0,'','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nOur Customer assistance team thought you might be interested in the following products:\r\n\r\n##PRODUCTS_ORDERED##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(67,10,1,0,'','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nThank you for choosing to visit ##STORE_NAME##!\r\n\r\nOur Customer assistance team thought you might be interested in the following products:\r\n\r\n##PRODUCTS_ORDERED##\r\n\r\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\r\n\r\nKind regards,\r\nThe team of ##STORE_NAME##'),(68,1,1,0,'Wedding invitation','Hello&nbsp;##INVITED_NAME##,<br />\r\n<a href=\"##SHARE_LINK##\">##SHARE_LINK##</a>'),(68,7,1,0,'Wedding invitation','Hello&nbsp;##INVITED_NAME##,<br />\r\n<a href=\"##SHARE_LINK##\">##SHARE_LINK##</a>'),(68,8,1,0,'Wedding invitation','Hello&nbsp;##INVITED_NAME##,<br />\r\n<a href=\"##SHARE_LINK##\">##SHARE_LINK##</a>'),(68,9,1,0,'Wedding invitation','Hello&nbsp;##INVITED_NAME##,<br />\r\n<a href=\"##SHARE_LINK##\">##SHARE_LINK##</a>'),(68,10,1,0,'Wedding invitation','Hello&nbsp;##INVITED_NAME##,<br />\r\n<a href=\"##SHARE_LINK##\">##SHARE_LINK##</a>'),(69,1,1,0,'',''),(69,7,1,0,'',''),(69,8,1,0,'',''),(69,9,1,0,'',''),(69,10,1,0,'',''),(70,1,1,0,'Notify from ##STORE_NAME##','<p><span style=\"font-size:14px\"><span style=\"font-family:verdana,geneva,sans-serif\">##USER_GREETING##,</span></span><br />\r\n<br />\r\nYour data has been completely deleted from<span style=\"font-size:14px\"><span style=\"font-family:verdana,geneva,sans-serif\"> ##STORE_NAME##.<br />\r\n<br />\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></span></p>'),(70,7,1,0,'Notify from ##STORE_NAME##','<p><span style=\"font-size:14px\"><span style=\"font-family:verdana,geneva,sans-serif\">##USER_GREETING##,</span></span><br />\r\n<br />\r\nYour data has been completely deleted from<span style=\"font-size:14px\"><span style=\"font-family:verdana,geneva,sans-serif\"> ##STORE_NAME##.<br />\r\n<br />\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></span></p>'),(70,8,1,0,'Notify from ##STORE_NAME##','<p><span style=\"font-size:14px\"><span style=\"font-family:verdana,geneva,sans-serif\">##USER_GREETING##,</span></span><br />\r\n<br />\r\nYour data has been completely deleted from<span style=\"font-size:14px\"><span style=\"font-family:verdana,geneva,sans-serif\"> ##STORE_NAME##.<br />\r\n<br />\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></span></p>'),(70,9,1,0,'Notify from ##STORE_NAME##','<p><span style=\"font-size:14px\"><span style=\"font-family:verdana,geneva,sans-serif\">##USER_GREETING##,</span></span><br />\r\n<br />\r\nYour data has been completely deleted from<span style=\"font-size:14px\"><span style=\"font-family:verdana,geneva,sans-serif\"> ##STORE_NAME##.<br />\r\n<br />\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></span></p>'),(70,10,1,0,'Notify from ##STORE_NAME##','<p><span style=\"font-size:14px\"><span style=\"font-family:verdana,geneva,sans-serif\">##USER_GREETING##,</span></span><br />\r\n<br />\r\nYour data has been completely deleted from<span style=\"font-size:14px\"><span style=\"font-family:verdana,geneva,sans-serif\"> ##STORE_NAME##.<br />\r\n<br />\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></span></p>'),(71,1,1,0,'Notify from ##STORE_NAME##','##USER_GREETING##,\r\n\r\nYour data has been completely deleted from ##STORE_NAME##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(71,7,1,0,'Notify from ##STORE_NAME##','##USER_GREETING##,\r\n\r\nYour data has been completely deleted from ##STORE_NAME##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(71,8,1,0,'Notify from ##STORE_NAME##','##USER_GREETING##,\r\n\r\nYour data has been completely deleted from ##STORE_NAME##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(71,9,1,0,'Notify from ##STORE_NAME##','##USER_GREETING##,\r\n\r\nYour data has been completely deleted from ##STORE_NAME##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(71,10,1,0,'Notify from ##STORE_NAME##','##USER_GREETING##,\r\n\r\nYour data has been completely deleted from ##STORE_NAME##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(72,1,1,0,'##STORE_NAME## GDPR update request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Please provide Your date of birthday by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(72,7,1,0,'##STORE_NAME## GDPR update request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Please provide Your date of birthday by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(72,8,1,0,'##STORE_NAME## GDPR update request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Please provide Your date of birthday by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(72,9,1,0,'##STORE_NAME## GDPR update request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Please provide Your date of birthday by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(72,10,1,0,'##STORE_NAME## GDPR update request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Please provide Your date of birthday by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(73,1,1,0,'##STORE_NAME## GDPR update request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nPlease provide Your date of birthday by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(73,7,1,0,'##STORE_NAME## GDPR update request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nPlease provide Your date of birthday by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(73,8,1,0,'##STORE_NAME## GDPR update request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nPlease provide Your date of birthday by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(73,9,1,0,'##STORE_NAME## GDPR update request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nPlease provide Your date of birthday by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(73,10,1,0,'##STORE_NAME## GDPR update request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nPlease provide Your date of birthday by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(74,1,1,0,'##STORE_NAME## guest request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>After ##BEFORE## Your guest account will be deleted. If You wish save design and order details for ease of re-ordering please create an account by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(74,7,1,0,'##STORE_NAME## guest request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>After ##BEFORE## Your guest account will be deleted. If You wish save design and order details for ease of re-ordering please create an account by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(74,8,1,0,'##STORE_NAME## guest request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>After ##BEFORE## Your guest account will be deleted. If You wish save design and order details for ease of re-ordering please create an account by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(74,9,1,0,'##STORE_NAME## guest request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>After ##BEFORE## Your guest account will be deleted. If You wish save design and order details for ease of re-ordering please create an account by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(74,10,1,0,'##STORE_NAME## guest request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>After ##BEFORE## Your guest account will be deleted. If You wish save design and order details for ease of re-ordering please create an account by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(75,1,1,0,'##STORE_NAME## guest request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAfter ##BEFORE## Your guest account will be deleted. If You wish save design and order details for ease of re-ordering please create an account by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(75,7,1,0,'##STORE_NAME## guest request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAfter ##BEFORE## Your guest account will be deleted. If You wish save design and order details for ease of re-ordering please create an account by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(75,8,1,0,'##STORE_NAME## guest request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAfter ##BEFORE## Your guest account will be deleted. If You wish save design and order details for ease of re-ordering please create an account by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(75,9,1,0,'##STORE_NAME## guest request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAfter ##BEFORE## Your guest account will be deleted. If You wish save design and order details for ease of re-ordering please create an account by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(75,10,1,0,'##STORE_NAME## guest request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAfter ##BEFORE## Your guest account will be deleted. If You wish save design and order details for ease of re-ordering please create an account by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(76,1,1,0,'##STORE_NAME## regular offers request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>After ##BEFORE## Your regular offers will expire. If You wish continue receive discount code offers from time to time please extend by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(76,7,1,0,'##STORE_NAME## regular offers request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>After ##BEFORE## Your regular offers will expire. If You wish continue receive discount code offers from time to time please extend by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(76,8,1,0,'##STORE_NAME## regular offers request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>After ##BEFORE## Your regular offers will expire. If You wish continue receive discount code offers from time to time please extend by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(76,9,1,0,'##STORE_NAME## regular offers request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>After ##BEFORE## Your regular offers will expire. If You wish continue receive discount code offers from time to time please extend by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(76,10,1,0,'##STORE_NAME## regular offers request','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>After ##BEFORE## Your regular offers will expire. If You wish continue receive discount code offers from time to time please extend by visiting our website ##HTTP_HOST##<span style=\"font-family:verdana,geneva,sans-serif\">.</span><br />\r\n&nbsp;</p>\r\n\r\n<p><span style=\"font-family:verdana,geneva,sans-serif\">If you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at <a href=\"mailto:##STORE_OWNER_EMAIL_ADDRESS##\">##STORE_OWNER_EMAIL_ADDRESS##</a></span></p>'),(77,1,1,0,'##STORE_NAME## regular offers request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAfter ##BEFORE## Your regular offers will expire. You wish continue receive discount code offers from time to time please extend by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(77,7,1,0,'##STORE_NAME## regular offers request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAfter ##BEFORE## Your regular offers will expire. You wish continue receive discount code offers from time to time please extend by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(77,8,1,0,'##STORE_NAME## regular offers request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAfter ##BEFORE## Your regular offers will expire. You wish continue receive discount code offers from time to time please extend by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(77,9,1,0,'##STORE_NAME## regular offers request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAfter ##BEFORE## Your regular offers will expire. You wish continue receive discount code offers from time to time please extend by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(77,10,1,0,'##STORE_NAME## regular offers request','Dear ##CUSTOMER_FIRSTNAME##,\r\n\r\nAfter ##BEFORE## Your regular offers will expire. You wish continue receive discount code offers from time to time please extend by visiting our website ##HTTP_HOST##.\r\n\r\nIf you have any questions or require assistance please contact our Customer Support Team who will be happy to help you. Please email us at ##STORE_OWNER_EMAIL_ADDRESS##'),(78,1,1,0,'Wedding invitation from ##FROM_FIRSTNAME## ##FROM_LASTNAME##','Dear ##INVITED_NAME##\r\n##FROM_FIRSTNAME## invite you to get participation with your wedding on ##STORE_NAME##, please visit us ##SHARE_LINK##'),(78,7,1,0,'Wedding invitation from ##FROM_FIRSTNAME## ##FROM_LASTNAME##','Dear ##INVITED_NAME##\r\n##FROM_FIRSTNAME## invite you to get participation with your wedding on ##STORE_NAME##, please visit us ##SHARE_LINK##'),(78,8,1,0,'Wedding invitation from ##FROM_FIRSTNAME## ##FROM_LASTNAME##','Dear ##INVITED_NAME##\r\n##FROM_FIRSTNAME## invite you to get participation with your wedding on ##STORE_NAME##, please visit us ##SHARE_LINK##'),(78,9,1,0,'Wedding invitation from ##FROM_FIRSTNAME## ##FROM_LASTNAME##','Dear ##INVITED_NAME##\r\n##FROM_FIRSTNAME## invite you to get participation with your wedding on ##STORE_NAME##, please visit us ##SHARE_LINK##'),(78,10,1,0,'Wedding invitation from ##FROM_FIRSTNAME## ##FROM_LASTNAME##','Dear ##INVITED_NAME##\r\n##FROM_FIRSTNAME## invite you to get participation with your wedding on ##STORE_NAME##, please visit us ##SHARE_LINK##'),(79,1,1,0,'Wedding invitation from ##FROM_FIRSTNAME## ##FROM_LASTNAME##','<p>Dear ##INVITED_NAME##</p>\r\n\r\n<p>##FROM_FIRSTNAME## invite you to get participation with your wedding on ##STORE_NAME##,</p>\r\n\r\n<p>please visit us <a href=\"##SHARE_LINK##\">##SHARE_LINK##</a></p>'),(79,7,1,0,'Wedding invitation from ##FROM_FIRSTNAME## ##FROM_LASTNAME##','<p>Dear ##INVITED_NAME##</p>\r\n\r\n<p>##FROM_FIRSTNAME## invite you to get participation with your wedding on ##STORE_NAME##,</p>\r\n\r\n<p>please visit us <a href=\"##SHARE_LINK##\">##SHARE_LINK##</a></p>'),(79,8,1,0,'Wedding invitation from ##FROM_FIRSTNAME## ##FROM_LASTNAME##','<p>Dear ##INVITED_NAME##</p>\r\n\r\n<p>##FROM_FIRSTNAME## invite you to get participation with your wedding on ##STORE_NAME##,</p>\r\n\r\n<p>please visit us <a href=\"##SHARE_LINK##\">##SHARE_LINK##</a></p>'),(79,9,1,0,'Wedding invitation from ##FROM_FIRSTNAME## ##FROM_LASTNAME##','<p>Dear ##INVITED_NAME##</p>\r\n\r\n<p>##FROM_FIRSTNAME## invite you to get participation with your wedding on ##STORE_NAME##,</p>\r\n\r\n<p>please visit us <a href=\"##SHARE_LINK##\">##SHARE_LINK##</a></p>'),(79,10,1,0,'Wedding invitation from ##FROM_FIRSTNAME## ##FROM_LASTNAME##','<p>Dear ##INVITED_NAME##</p>\r\n\r\n<p>##FROM_FIRSTNAME## invite you to get participation with your wedding on ##STORE_NAME##,</p>\r\n\r\n<p>please visit us <a href=\"##SHARE_LINK##\">##SHARE_LINK##</a></p>'),(80,1,1,0,'Gift Card','##CARD##'),(80,4,1,0,'Gift Card','##CARD##'),(80,5,1,0,'Gift Card','##CARD##'),(80,6,1,0,'Gift Card','##CARD##'),(80,7,1,0,'Gift Card','##CARD##'),(80,8,1,0,'Gift Card','##CARD##'),(80,9,1,0,'Gift Card','##CARD##'),(80,10,1,0,'Gift Card','##CARD##'),(81,1,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\r\nDetailed Invoice: ##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nTracking number: ##TRACKING_NUMBER##\r\n\r\n##TRACKING_NUMBER_URL##'),(81,4,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\nDetailed Invoice: ##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\nTracking number: ##TRACKING_NUMBER##\n\n##TRACKING_NUMBER_URL##'),(81,5,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\nDetailed Invoice: ##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\nTracking number: ##TRACKING_NUMBER##\n\n##TRACKING_NUMBER_URL##'),(81,6,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\nDetailed Invoice: ##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\nTracking number: ##TRACKING_NUMBER##\n\n##TRACKING_NUMBER_URL##'),(81,7,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\r\nDetailed Invoice: ##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nTracking number: ##TRACKING_NUMBER##\r\n\r\n##TRACKING_NUMBER_URL##'),(81,8,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\r\nDetailed Invoice: ##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nTracking number: ##TRACKING_NUMBER##\r\n\r\n##TRACKING_NUMBER_URL##'),(81,9,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\r\nDetailed Invoice: ##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nTracking number: ##TRACKING_NUMBER##\r\n\r\n##TRACKING_NUMBER_URL##'),(81,10,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\r\nDetailed Invoice: ##ORDER_INVOICE_URL##\r\nDate Ordered: ##ORDER_DATE_LONG##\r\n\r\nTracking number: ##TRACKING_NUMBER##\r\n\r\n##TRACKING_NUMBER_URL##'),(82,1,1,0,'Order Update','<p>Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice: ##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##<br />\r\n<br />\r\nTracking number: ##TRACKING_NUMBER##</p>\r\n\r\n<p>##TRACKING_NUMBER_URL##</p>'),(82,4,1,0,'Order Update','<p>Order Number: ##ORDER_NUMBER##<br />\nDetailed Invoice: ##ORDER_INVOICE_URL##<br />\nDate Ordered: ##ORDER_DATE_LONG##<br />\n<br />\nTracking number: ##TRACKING_NUMBER##</p>\n\n<p>##TRACKING_NUMBER_URL##</p>'),(82,5,1,0,'Order Update','<p>Order Number: ##ORDER_NUMBER##<br />\nDetailed Invoice: ##ORDER_INVOICE_URL##<br />\nDate Ordered: ##ORDER_DATE_LONG##<br />\n<br />\nTracking number: ##TRACKING_NUMBER##</p>\n\n<p>##TRACKING_NUMBER_URL##</p>'),(82,6,1,0,'Order Update','<p>Order Number: ##ORDER_NUMBER##<br />\nDetailed Invoice: ##ORDER_INVOICE_URL##<br />\nDate Ordered: ##ORDER_DATE_LONG##<br />\n<br />\nTracking number: ##TRACKING_NUMBER##</p>\n\n<p>##TRACKING_NUMBER_URL##</p>'),(82,7,1,0,'Order Update','<p>Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice: ##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##<br />\r\n<br />\r\nTracking number: ##TRACKING_NUMBER##</p>\r\n\r\n<p>##TRACKING_NUMBER_URL##</p>'),(82,8,1,0,'Order Update','<p>Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice: ##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##<br />\r\n<br />\r\nTracking number: ##TRACKING_NUMBER##</p>\r\n\r\n<p>##TRACKING_NUMBER_URL##</p>'),(82,9,1,0,'Order Update','<p>Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice: ##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##<br />\r\n<br />\r\nTracking number: ##TRACKING_NUMBER##</p>\r\n\r\n<p>##TRACKING_NUMBER_URL##</p>'),(82,10,1,0,'Order Update','<p>Order Number: ##ORDER_NUMBER##<br />\r\nDetailed Invoice: ##ORDER_INVOICE_URL##<br />\r\nDate Ordered: ##ORDER_DATE_LONG##<br />\r\n<br />\r\nTracking number: ##TRACKING_NUMBER##</p>\r\n\r\n<p>##TRACKING_NUMBER_URL##</p>'),(85,1,1,0,'Credit amount notification','<p>Your credit amount has been changed on: ##CREDIT_AMOUNT##</p>\r\n\r\n<p>{{The comments for your order are ##CREDIT_AMOUNT_COMMENTS##}}</p>'),(85,4,1,0,'Credit amount notification','<p>Your credit amount has been changed on: ##CREDIT_AMOUNT##</p><p>{{The comments for your order are ##CREDIT_AMOUNT_COMMENTS##}}</p>'),(85,5,1,0,'Credit amount notification','<p>Your credit amount has been changed on: ##CREDIT_AMOUNT##</p><p>{{The comments for your order are ##CREDIT_AMOUNT_COMMENTS##}}</p>'),(85,6,1,0,'Credit amount notification','<p>Your credit amount has been changed on: ##CREDIT_AMOUNT##</p><p>{{The comments for your order are ##CREDIT_AMOUNT_COMMENTS##}}</p>'),(85,7,1,0,'Credit amount notification','<p>Your credit amount has been changed on: ##CREDIT_AMOUNT##</p>\r\n\r\n<p>{{The comments for your order are ##CREDIT_AMOUNT_COMMENTS##}}</p>'),(85,8,1,0,'Credit amount notification','<p>Your credit amount has been changed on: ##CREDIT_AMOUNT##</p>\r\n\r\n<p>{{The comments for your order are ##CREDIT_AMOUNT_COMMENTS##}}</p>'),(85,9,1,0,'Credit amount notification','<p>Your credit amount has been changed on: ##CREDIT_AMOUNT##</p>\r\n\r\n<p>{{The comments for your order are ##CREDIT_AMOUNT_COMMENTS##}}</p>'),(85,10,1,0,'Credit amount notification','<p>Your credit amount has been changed on: ##CREDIT_AMOUNT##</p>\r\n\r\n<p>{{The comments for your order are ##CREDIT_AMOUNT_COMMENTS##}}</p>'),(86,1,1,0,'Bonus points notification','<p>Your bonus amount has been changed on: ##BONUS_POINTS##</p>\r\n\r\n<p>{{The comments for your order are ##BONUS_POINTS_COMMENTS##}}</p>'),(86,4,1,0,'Bonus points notification','<p>Your bonus amount has been changed on: ##BONUS_POINTS##</p><p>{{The comments for your order are ##BONUS_POINTS_COMMENTS##}}</p>'),(86,5,1,0,'Bonus points notification','<p>Your bonus amount has been changed on: ##BONUS_POINTS##</p><p>{{The comments for your order are ##BONUS_POINTS_COMMENTS##}}</p>'),(86,6,1,0,'Bonus points notification','<p>Your bonus amount has been changed on: ##BONUS_POINTS##</p><p>{{The comments for your order are ##BONUS_POINTS_COMMENTS##}}</p>'),(86,7,1,0,'Bonus points notification','<p>Your bonus amount has been changed on: ##BONUS_POINTS##</p>\r\n\r\n<p>{{The comments for your order are ##BONUS_POINTS_COMMENTS##}}</p>'),(86,8,1,0,'Bonus points notification','<p>Your bonus amount has been changed on: ##BONUS_POINTS##</p>\r\n\r\n<p>{{The comments for your order are ##BONUS_POINTS_COMMENTS##}}</p>'),(86,9,1,0,'Bonus points notification','<p>Your bonus amount has been changed on: ##BONUS_POINTS##</p>\r\n\r\n<p>{{The comments for your order are ##BONUS_POINTS_COMMENTS##}}</p>'),(86,10,1,0,'Bonus points notification','<p>Your bonus amount has been changed on: ##BONUS_POINTS##</p>\r\n\r\n<p>{{The comments for your order are ##BONUS_POINTS_COMMENTS##}}</p>'),(87,1,1,0,'',''),(87,7,1,0,'',''),(87,8,1,0,'',''),(87,9,1,0,'',''),(87,10,1,0,'',''),(88,1,1,0,'',''),(88,7,1,0,'',''),(88,8,1,0,'',''),(88,9,1,0,'',''),(88,10,1,0,'',''),(89,1,1,0,'Your ##STORE_NAME## account has been updated','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Please be advised that your access to ##STORE_NAME## has been updated.</p>\r\n\r\n<p>Your username is your E-mail address and your new password is: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>\r\n\r\n<p>Once logged in we recommend you visit My Account and change your password to one you will easily remember.</p>'),(89,4,1,0,'Your ##STORE_NAME## account has been updated','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\n<p>Please be advised that your access to ##STORE_NAME## has been updated.</p>\n<p>Your username is your E-mail address and your new password is: <input value=\"##NEW_PASSWORD##\" style=\"border: none;background: none\"></p>\n<p>Once logged in we recommend you visit My Account and change your password to one you will easily remember.</p>'),(89,5,1,0,'Your ##STORE_NAME## account has been updated','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\n<p>Please be advised that your access to ##STORE_NAME## has been updated.</p>\n<p>Your username is your E-mail address and your new password is: <input value=\"##NEW_PASSWORD##\" style=\"border: none;background: none\"></p>\n<p>Once logged in we recommend you visit My Account and change your password to one you will easily remember.</p>'),(89,6,1,0,'Your ##STORE_NAME## account has been updated','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\n<p>Please be advised that your access to ##STORE_NAME## has been updated.</p>\n<p>Your username is your E-mail address and your new password is: <input value=\"##NEW_PASSWORD##\" style=\"border: none;background: none\"></p>\n<p>Once logged in we recommend you visit My Account and change your password to one you will easily remember.</p>'),(89,7,1,0,'Your ##STORE_NAME## account has been updated','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Please be advised that your access to ##STORE_NAME## has been updated.</p>\r\n\r\n<p>Your username is your E-mail address and your new password is: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>\r\n\r\n<p>Once logged in we recommend you visit My Account and change your password to one you will easily remember.</p>'),(89,8,1,0,'Your ##STORE_NAME## account has been updated','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Please be advised that your access to ##STORE_NAME## has been updated.</p>\r\n\r\n<p>Your username is your E-mail address and your new password is: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>\r\n\r\n<p>Once logged in we recommend you visit My Account and change your password to one you will easily remember.</p>'),(89,9,1,0,'Your ##STORE_NAME## account has been updated','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Please be advised that your access to ##STORE_NAME## has been updated.</p>\r\n\r\n<p>Your username is your E-mail address and your new password is: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>\r\n\r\n<p>Once logged in we recommend you visit My Account and change your password to one you will easily remember.</p>'),(89,10,1,0,'Your ##STORE_NAME## account has been updated','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Please be advised that your access to ##STORE_NAME## has been updated.</p>\r\n\r\n<p>Your username is your E-mail address and your new password is: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>\r\n\r\n<p>Once logged in we recommend you visit My Account and change your password to one you will easily remember.</p>'),(90,1,1,0,'Personal Information Change','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your personal information, perhaps including your password, has been changed. If this was done without your knowledge or consent please contact the administrator immediatly!</p>\r\n\r\n<p>Website : ##STORE_URL##</p>\r\n\r\n<p>Username: ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(90,4,1,0,'Personal Information Change','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\n<p>Your personal information, perhaps including your password, has been changed. If this was done without your knowledge or consent please contact the administrator immediatly!</p>\n<p>Website : ##STORE_URL##</p>\n<p>Username: ##CUSTOMER_EMAIL##</p>\n<p>Password: <input value=\"##NEW_PASSWORD##\" style=\"border: none;background: none\"></p>'),(90,5,1,0,'Personal Information Change','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\n<p>Your personal information, perhaps including your password, has been changed. If this was done without your knowledge or consent please contact the administrator immediatly!</p>\n<p>Website : ##STORE_URL##</p>\n<p>Username: ##CUSTOMER_EMAIL##</p>\n<p>Password: <input value=\"##NEW_PASSWORD##\" style=\"border: none;background: none\"></p>'),(90,6,1,0,'Personal Information Change','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\n<p>Your personal information, perhaps including your password, has been changed. If this was done without your knowledge or consent please contact the administrator immediatly!</p>\n<p>Website : ##STORE_URL##</p>\n<p>Username: ##CUSTOMER_EMAIL##</p>\n<p>Password: <input value=\"##NEW_PASSWORD##\" style=\"border: none;background: none\"></p>'),(90,7,1,0,'Personal Information Change','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your personal information, perhaps including your password, has been changed. If this was done without your knowledge or consent please contact the administrator immediatly!</p>\r\n\r\n<p>Website : ##STORE_URL##</p>\r\n\r\n<p>Username: ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(90,8,1,0,'Personal Information Change','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your personal information, perhaps including your password, has been changed. If this was done without your knowledge or consent please contact the administrator immediatly!</p>\r\n\r\n<p>Website : ##STORE_URL##</p>\r\n\r\n<p>Username: ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(90,9,1,0,'Personal Information Change','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your personal information, perhaps including your password, has been changed. If this was done without your knowledge or consent please contact the administrator immediatly!</p>\r\n\r\n<p>Website : ##STORE_URL##</p>\r\n\r\n<p>Username: ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(90,10,1,0,'Personal Information Change','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your personal information, perhaps including your password, has been changed. If this was done without your knowledge or consent please contact the administrator immediatly!</p>\r\n\r\n<p>Website : ##STORE_URL##</p>\r\n\r\n<p>Username: ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(92,1,1,0,'New Customer','New Customer: ##CUSTOMER_FIRSTNAME## ##CUSTOMER_LASTNAME##, ##CUSTOMER_EMAIL##'),(92,4,1,0,'New Customer','New Customer: ##CUSTOMER_FIRSTNAME## ##CUSTOMER_LASTNAME##, ##CUSTOMER_EMAIL##'),(92,5,1,0,'New Customer','New Customer: ##CUSTOMER_FIRSTNAME## ##CUSTOMER_LASTNAME##, ##CUSTOMER_EMAIL##'),(92,6,1,0,'New Customer','New Customer: ##CUSTOMER_FIRSTNAME## ##CUSTOMER_LASTNAME##, ##CUSTOMER_EMAIL##'),(92,7,1,0,'New Customer','New Customer: ##CUSTOMER_FIRSTNAME## ##CUSTOMER_LASTNAME##, ##CUSTOMER_EMAIL##'),(92,8,1,0,'New Customer','New Customer: ##CUSTOMER_FIRSTNAME## ##CUSTOMER_LASTNAME##, ##CUSTOMER_EMAIL##'),(92,9,1,0,'New Customer','New Customer: ##CUSTOMER_FIRSTNAME## ##CUSTOMER_LASTNAME##, ##CUSTOMER_EMAIL##'),(92,10,1,0,'New Customer','New Customer: ##CUSTOMER_FIRSTNAME## ##CUSTOMER_LASTNAME##, ##CUSTOMER_EMAIL##'),(93,1,1,0,'New Administrator','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your account has been created</p>\r\n\r\n<p>Website : ##STORE_URL##</p>\r\n\r\n<p>Username: ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(93,4,1,0,'New Administrator','<p>Hello ##CUSTOMER_FIRSTNAME##,</p><p>Your account has created</p><p>Website : ##STORE_URL##</p><p>Username: ##CUSTOMER_EMAIL##</p><p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(93,5,1,0,'New Administrator','<p>Hello ##CUSTOMER_FIRSTNAME##,</p><p>Your account has created</p><p>Website : ##STORE_URL##</p><p>Username: ##CUSTOMER_EMAIL##</p><p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(93,6,1,0,'New Administrator','<p>Hello ##CUSTOMER_FIRSTNAME##,</p><p>Your account has created</p><p>Website : ##STORE_URL##</p><p>Username: ##CUSTOMER_EMAIL##</p><p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(93,7,1,0,'New Administrator','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your account has been created</p>\r\n\r\n<p>Website : ##STORE_URL##</p>\r\n\r\n<p>Username: ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(93,8,1,0,'New Administrator','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your account has been&nbsp;created</p>\r\n\r\n<p>Website : ##STORE_URL##</p>\r\n\r\n<p>Username: ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(93,9,1,0,'New Administrator','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your account has been created</p>\r\n\r\n<p>Website : ##STORE_URL##</p>\r\n\r\n<p>Username: ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(93,10,1,0,'New Administrator','<p>Hello ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Your account has been created</p>\r\n\r\n<p>Website : ##STORE_URL##</p>\r\n\r\n<p>Username: ##CUSTOMER_EMAIL##</p>\r\n\r\n<p>Password: <input style=\"border: none;background: none\" value=\"##NEW_PASSWORD##\" /></p>'),(94,1,1,0,'Admin Login Security Key','<p>Your login security key is: ##SECURITY_KEY##</p>\r\n\r\n<p>If it is not you is trying to login into website, please contact with website administrators immediately!</p>'),(94,7,1,0,'Admin Login Security Key','<p>Your login security key is: ##SECURITY_KEY##</p>\r\n\r\n<p>If it is not you is trying to login into website, please contact with website administrators immediately!</p>'),(94,8,1,0,'Admin Login Security Key','<p>Your login security key is: ##SECURITY_KEY##</p>\r\n\r\n<p>If it is not you is trying to login into website, please contact with website administrators immediately!</p>'),(94,9,1,0,'Admin Login Security Key','<p>Your login security key is: ##SECURITY_KEY##</p>\r\n\r\n<p>If it is not you is trying to login into website, please contact with website administrators immediately!</p>'),(94,10,1,0,'Admin Login Security Key','<p>Your login security key is: ##SECURITY_KEY##</p>\r\n\r\n<p>If it is not you is trying to login into website, please contact with website administrators immediately!</p>'),(95,1,1,0,'',''),(95,7,1,0,'',''),(95,8,1,0,'',''),(95,9,1,0,'',''),(95,10,1,0,'',''),(96,1,1,0,'Admin New Device Login','<p>Someone has logged in with your credentials on new device.</p>\r\n\r\n<p><br />\r\nDate and time: ##AD_DEVICE_DATE##<br />\r\n<br />\r\nDevice: ##AD_DEVICE_ID##<br />\r\n<br />\r\nIP address (location): ##AD_DEVICE_IP##<br />\r\n<br />\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.</p>'),(96,7,1,0,'Admin New Device Login','<p>Someone has logged in with your credentials on new device.</p>\r\n\r\n<p><br />\r\nDate and time: ##AD_DEVICE_DATE##<br />\r\n<br />\r\nDevice: ##AD_DEVICE_ID##<br />\r\n<br />\r\nIP address (location): ##AD_DEVICE_IP##<br />\r\n<br />\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.</p>'),(96,8,1,0,'Admin New Device Login','<p>Someone has logged in with your credentials on new device.</p>\r\n\r\n<p><br />\r\nDate and time: ##AD_DEVICE_DATE##<br />\r\n<br />\r\nDevice: ##AD_DEVICE_ID##<br />\r\n<br />\r\nIP address (location): ##AD_DEVICE_IP##<br />\r\n<br />\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.</p>'),(96,9,1,0,'Admin New Device Login','<p>Someone has logged in with your credentials on new device.</p>\r\n\r\n<p><br />\r\nDate and time: ##AD_DEVICE_DATE##<br />\r\n<br />\r\nDevice: ##AD_DEVICE_ID##<br />\r\n<br />\r\nIP address (location): ##AD_DEVICE_IP##<br />\r\n<br />\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.</p>'),(96,10,1,0,'Admin New Device Login','<p>Someone has logged in with your credentials on new device.</p>\r\n\r\n<p><br />\r\nDate and time: ##AD_DEVICE_DATE##<br />\r\n<br />\r\nDevice: ##AD_DEVICE_ID##<br />\r\n<br />\r\nIP address (location): ##AD_DEVICE_IP##<br />\r\n<br />\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.</p>'),(97,1,1,0,'Admin New Device Login','Someone has logged in with your credentials on new device from ##AD_DEVICE_IP##.\r\n\r\nDevice id: ##AD_DEVICE_ID##.'),(97,7,1,0,'Admin New Device Login','Someone has logged in with your credentials on new device from ##AD_DEVICE_IP##.\r\n\r\nDevice id: ##AD_DEVICE_ID##.'),(97,8,1,0,'Admin New Device Login','Someone has logged in with your credentials on new device from ##AD_DEVICE_IP##.\r\n\r\nDevice id: ##AD_DEVICE_ID##.'),(97,9,1,0,'Admin New Device Login','Someone has logged in with your credentials on new device from ##AD_DEVICE_IP##.\r\n\r\nDevice id: ##AD_DEVICE_ID##.'),(97,10,1,0,'Admin New Device Login','Someone has logged in with your credentials on new device from ##AD_DEVICE_IP##.\r\n\r\nDevice id: ##AD_DEVICE_ID##.'),(98,1,1,0,'Admin Login Security Key SMS','Your login security key is: ##SECURITY_KEY##'),(98,7,1,0,'Admin Login Security Key SMS','Your login security key is: ##SECURITY_KEY##'),(98,8,1,0,'Admin Login Security Key SMS','Your login security key is: ##SECURITY_KEY##'),(98,9,1,0,'Admin Login Security Key SMS','Your login security key is: ##SECURITY_KEY##'),(98,10,1,0,'Admin Login Security Key SMS','Your login security key is: ##SECURITY_KEY##'),(99,1,1,0,'Admin Login Security Key SMS','Your login security key is: ##SECURITY_KEY##'),(99,7,1,0,'Admin Login Security Key SMS','Your login security key is: ##SECURITY_KEY##'),(99,8,1,0,'Admin Login Security Key SMS','Your login security key is: ##SECURITY_KEY##'),(99,9,1,0,'Admin Login Security Key SMS','Your login security key is: ##SECURITY_KEY##'),(99,10,1,0,'Admin Login Security Key SMS','Your login security key is: ##SECURITY_KEY##'),(100,1,1,0,'',''),(100,7,1,0,'',''),(100,8,1,0,'',''),(100,9,1,0,'',''),(100,10,1,0,'',''),(101,1,1,0,'',''),(101,7,1,0,'',''),(101,8,1,0,'',''),(101,9,1,0,'',''),(101,10,1,0,'',''),(102,1,1,0,'',''),(102,7,1,0,'',''),(102,8,1,0,'',''),(102,9,1,0,'',''),(102,10,1,0,'',''),(103,1,1,0,'',''),(103,7,1,0,'',''),(103,8,1,0,'',''),(103,9,1,0,'',''),(103,10,1,0,'',''),(104,1,1,0,'',''),(104,7,1,0,'',''),(104,8,1,0,'',''),(104,9,1,0,'',''),(104,10,1,0,'',''),(105,1,1,0,'',''),(105,7,1,0,'',''),(105,8,1,0,'',''),(105,9,1,0,'',''),(105,10,1,0,'',''),(106,1,1,0,'',''),(106,7,1,0,'',''),(106,8,1,0,'',''),(106,9,1,0,'',''),(106,10,1,0,'',''),(107,1,1,0,'',''),(107,7,1,0,'',''),(107,8,1,0,'',''),(107,9,1,0,'',''),(107,10,1,0,'',''),(108,1,1,0,'Welcome to the Affiliate Program','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>thank you for joining the Affiliate Program.</p>\r\n\r\n<p>Your Account Information:</p>\r\n\r\n<p>Your Affiliate ID is: ##AFFILIATE_ID##</p>\r\n\r\n<p>Your Affiliate Username is: ##AFFILIATE_USERNAME##</p>\r\n\r\n<p>Your Password is:&nbsp;##AFFILIATE_PASSWORD##</p>\r\n\r\n<p>Link to your account here: ##AFFILIATE_LINK##</p>\r\n\r\n<p><strong>Your account will be activated after verification.</strong></p>\r\n\r\n<p>Have fun earning referal fees!</p>\r\n\r\n<p>Your Affiliate Team</p>'),(108,7,1,0,'Welcome to the Affiliate Program','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>thank you for joining the Affiliate Program.</p>\r\n\r\n<p>Your Account Information:</p>\r\n\r\n<p>Your Affiliate ID is: ##AFFILIATE_ID##</p>\r\n\r\n<p>Your Affiliate Username is: ##AFFILIATE_USERNAME##</p>\r\n\r\n<p>Your Password is:&nbsp;##AFFILIATE_PASSWORD##</p>\r\n\r\n<p>Link to your account here: ##AFFILIATE_LINK##</p>\r\n\r\n<p><strong>Your account will be activated after verification.</strong></p>\r\n\r\n<p>Have fun earning referal fees!</p>\r\n\r\n<p>Your Affiliate Team</p>'),(108,8,1,0,'Welcome to the Affiliate Program','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>thank you for joining the Affiliate Program.</p>\r\n\r\n<p>Your Account Information:</p>\r\n\r\n<p>Your Affiliate ID is: ##AFFILIATE_ID##</p>\r\n\r\n<p>Your Affiliate Username is: ##AFFILIATE_USERNAME##</p>\r\n\r\n<p>Your Password is:&nbsp;##AFFILIATE_PASSWORD##</p>\r\n\r\n<p>Link to your account here: ##AFFILIATE_LINK##</p>\r\n\r\n<p><strong>Your account will be activated after verification.</strong></p>\r\n\r\n<p>Have fun earning referal fees!</p>\r\n\r\n<p>Your Affiliate Team</p>'),(108,9,1,0,'Welcome to the Affiliate Program','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>thank you for joining the Affiliate Program.</p>\r\n\r\n<p>Your Account Information:</p>\r\n\r\n<p>Your Affiliate ID is: ##AFFILIATE_ID##</p>\r\n\r\n<p>Your Affiliate Username is: ##AFFILIATE_USERNAME##</p>\r\n\r\n<p>Your Password is:&nbsp;##AFFILIATE_PASSWORD##</p>\r\n\r\n<p>Link to your account here: ##AFFILIATE_LINK##</p>\r\n\r\n<p><strong>Your account will be activated after verification.</strong></p>\r\n\r\n<p>Have fun earning referal fees!</p>\r\n\r\n<p>Your Affiliate Team</p>'),(108,10,1,0,'Welcome to the Affiliate Program','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>thank you for joining the Affiliate Program.</p>\r\n\r\n<p>Your Account Information:</p>\r\n\r\n<p>Your Affiliate ID is: ##AFFILIATE_ID##</p>\r\n\r\n<p>Your Affiliate Username is: ##AFFILIATE_USERNAME##</p>\r\n\r\n<p>Your Password is:&nbsp;##AFFILIATE_PASSWORD##</p>\r\n\r\n<p>Link to your account here: ##AFFILIATE_LINK##</p>\r\n\r\n<p><strong>Your account will be activated after verification.</strong></p>\r\n\r\n<p>Have fun earning referal fees!</p>\r\n\r\n<p>Your Affiliate Team</p>'),(109,1,1,0,'Your Affiliate Program has been activated','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>your account has been activated.</p>\r\nLink to your account here: ##AFFILIATE_LINK##\r\n\r\n<p>Have fun earning referal fees!</p>\r\n\r\n<p>Your Affiliate Team</p>'),(109,7,1,0,'Your Affiliate Program has been activated','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>your account has been activated.</p>\r\nLink to your account here: ##AFFILIATE_LINK##\r\n\r\n<p>Have fun earning referal fees!</p>\r\n\r\n<p>Your Affiliate Team</p>'),(109,8,1,0,'Your Affiliate Program has been activated','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>your account has been activated.</p>\r\nLink to your account here: ##AFFILIATE_LINK##\r\n\r\n<p>Have fun earning referal fees!</p>\r\n\r\n<p>Your Affiliate Team</p>'),(109,9,1,0,'Your Affiliate Program has been activated','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>your account has been activated.</p>\r\nLink to your account here: ##AFFILIATE_LINK##\r\n\r\n<p>Have fun earning referal fees!</p>\r\n\r\n<p>Your Affiliate Team</p>'),(109,10,1,0,'Your Affiliate Program has been activated','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>your account has been activated.</p>\r\nLink to your account here: ##AFFILIATE_LINK##\r\n\r\n<p>Have fun earning referal fees!</p>\r\n\r\n<p>Your Affiliate Team</p>'),(110,1,1,0,'Affiliate Payment Update','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Payment Number: ##PAYMENT_ID##</p>\r\n\r\n<p>Date billed: ##PAYMENT_DATE##</p>\r\n\r\n<p>Your payment has been updated to the following status.</p>\r\n\r\n<p>New status: ##PAYMENT_STATUS##</p>\r\n\r\n<p>Please reply to this email if you have any questions.</p>'),(110,7,1,0,'Affiliate Payment Update','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Payment Number: ##PAYMENT_ID##</p>\r\n\r\n<p>Date billed: ##PAYMENT_DATE##</p>\r\n\r\n<p>Your payment has been updated to the following status.</p>\r\n\r\n<p>New status: ##PAYMENT_STATUS##</p>\r\n\r\n<p>Please reply to this email if you have any questions.</p>'),(110,8,1,0,'Affiliate Payment Update','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Payment Number: ##PAYMENT_ID##</p>\r\n\r\n<p>Date billed: ##PAYMENT_DATE##</p>\r\n\r\n<p>Your payment has been updated to the following status.</p>\r\n\r\n<p>New status: ##PAYMENT_STATUS##</p>\r\n\r\n<p>Please reply to this email if you have any questions.</p>'),(110,9,1,0,'Affiliate Payment Update','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Payment Number: ##PAYMENT_ID##</p>\r\n\r\n<p>Date billed: ##PAYMENT_DATE##</p>\r\n\r\n<p>Your payment has been updated to the following status.</p>\r\n\r\n<p>New status: ##PAYMENT_STATUS##</p>\r\n\r\n<p>Please reply to this email if you have any questions.</p>'),(110,10,1,0,'Affiliate Payment Update','<p>Dear ##CUSTOMER_FIRSTNAME##,</p>\r\n\r\n<p>Payment Number: ##PAYMENT_ID##</p>\r\n\r\n<p>Date billed: ##PAYMENT_DATE##</p>\r\n\r\n<p>Your payment has been updated to the following status.</p>\r\n\r\n<p>New status: ##PAYMENT_STATUS##</p>\r\n\r\n<p>Please reply to this email if you have any questions.</p>'),(111,1,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','<p>Dear&nbsp; ##CUSTOMER_FIRSTNAME##,<br />\nyour order has been updated.</p>\n\n<p><strong>New status: </strong>##NEW_ORDER_STATUS##</p>\n\n<p><strong>Detailed Invoice</strong>:<br />\n##ORDER_INVOICE_URL##</p>\n\n<p>Order&nbsp;Number: ##ORDER_NUMBER## (placed on ##ORDER_DATE_LONG##)</p>\n\n<p>&nbsp;</p>\n##ORDER_COMMENTS##\n\n<p>&nbsp;</p>\n<p>Please reply to this email if you have any questions.</p>\n\n<p>Best wishes.</p>'),(111,4,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','<p>Dear&nbsp; ##CUSTOMER_FIRSTNAME##,<br />\nyour order has been updated.</p>\n\n<p><strong>New status: </strong>##NEW_ORDER_STATUS##</p>\n\n<p><strong>Detailed Invoice</strong>:<br />\n##ORDER_INVOICE_URL##</p>\n\n<p>Order&nbsp;Number: ##ORDER_NUMBER## (placed on ##ORDER_DATE_LONG##)</p>\n\n<p>&nbsp;</p>\n##ORDER_COMMENTS##\n\n<p>&nbsp;</p>\n<p>Please reply to this email if you have any questions.</p>\n\n<p>Best wishes.</p>'),(111,5,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','<p>Dear&nbsp; ##CUSTOMER_FIRSTNAME##,<br />\nyour order has been updated.</p>\n\n<p><strong>New status: </strong>##NEW_ORDER_STATUS##</p>\n\n<p><strong>Detailed Invoice</strong>:<br />\n##ORDER_INVOICE_URL##</p>\n\n<p>Order&nbsp;Number: ##ORDER_NUMBER## (placed on ##ORDER_DATE_LONG##)</p>\n\n<p>&nbsp;</p>\n##ORDER_COMMENTS##\n\n<p>&nbsp;</p>\n<p>Please reply to this email if you have any questions.</p>\n\n<p>Best wishes.</p>'),(111,6,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','<p>Dear&nbsp; ##CUSTOMER_FIRSTNAME##,<br />\nyour order has been updated.</p>\n\n<p><strong>New status: </strong>##NEW_ORDER_STATUS##</p>\n\n<p><strong>Detailed Invoice</strong>:<br />\n##ORDER_INVOICE_URL##</p>\n\n<p>Order&nbsp;Number: ##ORDER_NUMBER## (placed on ##ORDER_DATE_LONG##)</p>\n\n<p>&nbsp;</p>\n##ORDER_COMMENTS##\n\n<p>&nbsp;</p>\n<p>Please reply to this email if you have any questions.</p>\n\n<p>Best wishes.</p>'),(111,7,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','<p>Dear&nbsp; ##CUSTOMER_FIRSTNAME##,<br />\nyour order has been updated.</p>\n\n<p><strong>New status: </strong>##NEW_ORDER_STATUS##</p>\n\n<p><strong>Detailed Invoice</strong>:<br />\n##ORDER_INVOICE_URL##</p>\n\n<p>Order&nbsp;Number: ##ORDER_NUMBER## (placed on ##ORDER_DATE_LONG##)</p>\n\n<p>&nbsp;</p>\n##ORDER_COMMENTS##\n\n<p>&nbsp;</p>\n<p>Please reply to this email if you have any questions.</p>\n\n<p>Best wishes.</p>'),(111,8,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','<p>Dear&nbsp; ##CUSTOMER_FIRSTNAME##,<br />\nyour order has been updated.</p>\n\n<p><strong>New status: </strong>##NEW_ORDER_STATUS##</p>\n\n<p><strong>Detailed Invoice</strong>:<br />\n##ORDER_INVOICE_URL##</p>\n\n<p>Order&nbsp;Number: ##ORDER_NUMBER## (placed on ##ORDER_DATE_LONG##)</p>\n\n<p>&nbsp;</p>\n##ORDER_COMMENTS##\n\n<p>&nbsp;</p>\n<p>Please reply to this email if you have any questions.</p>\n\n<p>Best wishes.</p>'),(111,9,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','<p>Dear&nbsp; ##CUSTOMER_FIRSTNAME##,<br />\nyour order has been updated.</p>\n\n<p><strong>New status: </strong>##NEW_ORDER_STATUS##</p>\n\n<p><strong>Detailed Invoice</strong>:<br />\n##ORDER_INVOICE_URL##</p>\n\n<p>Order&nbsp;Number: ##ORDER_NUMBER## (placed on ##ORDER_DATE_LONG##)</p>\n\n<p>&nbsp;</p>\n##ORDER_COMMENTS##\n\n<p>&nbsp;</p>\n<p>Please reply to this email if you have any questions.</p>\n\n<p>Best wishes.</p>'),(111,10,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','<p>Dear&nbsp; ##CUSTOMER_FIRSTNAME##,<br />\nyour order has been updated.</p>\n\n<p><strong>New status: </strong>##NEW_ORDER_STATUS##</p>\n\n<p><strong>Detailed Invoice</strong>:<br />\n##ORDER_INVOICE_URL##</p>\n\n<p>Order&nbsp;Number: ##ORDER_NUMBER## (placed on ##ORDER_DATE_LONG##)</p>\n\n<p>&nbsp;</p>\n##ORDER_COMMENTS##\n\n<p>&nbsp;</p>\n<p>Please reply to this email if you have any questions.</p>\n\n<p>Best wishes.</p>'),(112,1,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','##STORE_NAME##\n------------------------------------------------------\nOrder Number: ##ORDER_NUMBER##\nDetailed Invoice:\n##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\n##ORDER_COMMENTS##\n\nYour order has been updated to the following status.\n\nNew status: ##NEW_ORDER_STATUS##\n\nPlease reply to this email if you have any questions.'),(112,4,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','##STORE_NAME##\n------------------------------------------------------\nOrder Number: ##ORDER_NUMBER##\nDetailed Invoice:\n##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\n##ORDER_COMMENTS##\n\nYour order has been updated to the following status.\n\nNew status: ##NEW_ORDER_STATUS##\n\nPlease reply to this email if you have any questions.'),(112,5,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','##STORE_NAME##\n------------------------------------------------------\nOrder Number: ##ORDER_NUMBER##\nDetailed Invoice:\n##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\n##ORDER_COMMENTS##\n\nYour order has been updated to the following status.\n\nNew status: ##NEW_ORDER_STATUS##\n\nPlease reply to this email if you have any questions.'),(112,6,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','##STORE_NAME##\n------------------------------------------------------\nOrder Number: ##ORDER_NUMBER##\nDetailed Invoice:\n##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\n##ORDER_COMMENTS##\n\nYour order has been updated to the following status.\n\nNew status: ##NEW_ORDER_STATUS##\n\nPlease reply to this email if you have any questions.'),(112,7,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','##STORE_NAME##\n------------------------------------------------------\nOrder Number: ##ORDER_NUMBER##\nDetailed Invoice:\n##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\n##ORDER_COMMENTS##\n\nYour order has been updated to the following status.\n\nNew status: ##NEW_ORDER_STATUS##\n\nPlease reply to this email if you have any questions.'),(112,8,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','##STORE_NAME##\n------------------------------------------------------\nOrder Number: ##ORDER_NUMBER##\nDetailed Invoice:\n##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\n##ORDER_COMMENTS##\n\nYour order has been updated to the following status.\n\nNew status: ##NEW_ORDER_STATUS##\n\nPlease reply to this email if you have any questions.'),(112,9,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','##STORE_NAME##\n------------------------------------------------------\nOrder Number: ##ORDER_NUMBER##\nDetailed Invoice:\n##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\n##ORDER_COMMENTS##\n\nYour order has been updated to the following status.\n\nNew status: ##NEW_ORDER_STATUS##\n\nPlease reply to this email if you have any questions.'),(112,10,1,0,'Your Order Nr. ##ORDER_NUMBER## Status Updated','##STORE_NAME##\n------------------------------------------------------\nOrder Number: ##ORDER_NUMBER##\nDetailed Invoice:\n##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\n##ORDER_COMMENTS##\n\nYour order has been updated to the following status.\n\nNew status: ##NEW_ORDER_STATUS##\n\nPlease reply to this email if you have any questions.'),(113,1,1,0,'##STORE_NAME## - warehouse notification','<p>Order &nbsp;##ORDER_NUMBER## for collection:</p>\n<p>##PRODUCTS_ORDERED##</p>\n'),(113,4,1,0,'##STORE_NAME## - warehouse notification','<p>Order &nbsp;##ORDER_NUMBER## for collection:</p>\n<p>##PRODUCTS_ORDERED##</p>\n'),(113,5,1,0,'##STORE_NAME## - warehouse notification','<p>Order &nbsp;##ORDER_NUMBER## for collection:</p>\n<p>##PRODUCTS_ORDERED##</p>\n'),(113,6,1,0,'##STORE_NAME## - warehouse notification','<p>Order &nbsp;##ORDER_NUMBER## for collection:</p>\n<p>##PRODUCTS_ORDERED##</p>\n'),(113,7,1,0,'##STORE_NAME## - warehouse notification','<p>Order &nbsp;##ORDER_NUMBER## for collection:</p>\n<p>##PRODUCTS_ORDERED##</p>\n'),(113,8,1,0,'##STORE_NAME## - warehouse notification','<p>Order &nbsp;##ORDER_NUMBER## for collection:</p>\n<p>##PRODUCTS_ORDERED##</p>\n'),(113,9,1,0,'##STORE_NAME## - warehouse notification','<p>Order &nbsp;##ORDER_NUMBER## for collection:</p>\n<p>##PRODUCTS_ORDERED##</p>\n'),(113,10,1,0,'##STORE_NAME## - warehouse notification','<p>Order &nbsp;##ORDER_NUMBER## for collection:</p>\n<p>##PRODUCTS_ORDERED##</p>\n'),(114,1,1,0,'##STORE_NAME## - warehouse notification','Order ##ORDER_NUMBER## for collection:\n##PRODUCTS_ORDERED##\n'),(114,4,1,0,'##STORE_NAME## - warehouse notification','Order ##ORDER_NUMBER## for collection:\n##PRODUCTS_ORDERED##\n'),(114,5,1,0,'##STORE_NAME## - warehouse notification','Order ##ORDER_NUMBER## for collection:\n##PRODUCTS_ORDERED##\n'),(114,6,1,0,'##STORE_NAME## - warehouse notification','Order ##ORDER_NUMBER## for collection:\n##PRODUCTS_ORDERED##\n'),(114,7,1,0,'##STORE_NAME## - warehouse notification','Order ##ORDER_NUMBER## for collection:\n##PRODUCTS_ORDERED##\n'),(114,8,1,0,'##STORE_NAME## - warehouse notification','Order ##ORDER_NUMBER## for collection:\n##PRODUCTS_ORDERED##\n'),(114,9,1,0,'##STORE_NAME## - warehouse notification','Order ##ORDER_NUMBER## for collection:\n##PRODUCTS_ORDERED##\n'),(114,10,1,0,'##STORE_NAME## - warehouse notification','Order ##ORDER_NUMBER## for collection:\n##PRODUCTS_ORDERED##\n'),(115,1,1,0,'Abandoned Cart Notification ##STORE_NAME##','Customer contact: ##CUSTOMER_DETAILS##\n ##PRODUCTS_ORDERED##'),(115,4,1,0,'Abandoned Cart Notification ##STORE_NAME##','Customer contact: ##CUSTOMER_DETAILS##\n ##PRODUCTS_ORDERED##'),(115,5,1,0,'Abandoned Cart Notification ##STORE_NAME##','Customer contact: ##CUSTOMER_DETAILS##\n ##PRODUCTS_ORDERED##'),(115,6,1,0,'Abandoned Cart Notification ##STORE_NAME##','Customer contact: ##CUSTOMER_DETAILS##\n ##PRODUCTS_ORDERED##'),(115,7,1,0,'Abandoned Cart Notification ##STORE_NAME##','Customer contact: ##CUSTOMER_DETAILS##\n ##PRODUCTS_ORDERED##'),(115,8,1,0,'Abandoned Cart Notification ##STORE_NAME##','Customer contact: ##CUSTOMER_DETAILS##\n ##PRODUCTS_ORDERED##'),(115,9,1,0,'Abandoned Cart Notification ##STORE_NAME##','Customer contact: ##CUSTOMER_DETAILS##\n ##PRODUCTS_ORDERED##'),(115,10,1,0,'Abandoned Cart Notification ##STORE_NAME##','Customer contact: ##CUSTOMER_DETAILS##\n ##PRODUCTS_ORDERED##'),(116,1,1,0,'Abandoned Cart Notification ##STORE_NAME##','<p>Customer contact: ##CUSTOMER_DETAILS##</p>\r\n\r\n<br>##PRODUCTS_ORDERED##'),(116,4,1,0,'Abandoned Cart Notification ##STORE_NAME##','<p>Customer contact: ##CUSTOMER_DETAILS##</p>\r\n\r\n<br>##PRODUCTS_ORDERED##'),(116,5,1,0,'Abandoned Cart Notification ##STORE_NAME##','<p>Customer contact: ##CUSTOMER_DETAILS##</p>\r\n\r\n<br>##PRODUCTS_ORDERED##'),(116,6,1,0,'Abandoned Cart Notification ##STORE_NAME##','<p>Customer contact: ##CUSTOMER_DETAILS##</p>\r\n\r\n<br>##PRODUCTS_ORDERED##'),(116,7,1,0,'Abandoned Cart Notification ##STORE_NAME##','<p>Customer contact: ##CUSTOMER_DETAILS##</p>\r\n\r\n<br>##PRODUCTS_ORDERED##'),(116,8,1,0,'Abandoned Cart Notification ##STORE_NAME##','<p>Customer contact: ##CUSTOMER_DETAILS##</p>\r\n\r\n<br>##PRODUCTS_ORDERED##'),(116,9,1,0,'Abandoned Cart Notification ##STORE_NAME##','<p>Customer contact: ##CUSTOMER_DETAILS##</p>\r\n\r\n<br>##PRODUCTS_ORDERED##'),(116,10,1,0,'Abandoned Cart Notification ##STORE_NAME##','<p>Customer contact: ##CUSTOMER_DETAILS##</p>\r\n\r\n<br>##PRODUCTS_ORDERED##'),(117,1,1,0,'You\'ve received new communication email','Please, visit ##COMMUNICATION_URL## to read more!'),(117,7,1,0,'You\'ve received new communication email','Please, visit ##COMMUNICATION_URL## to read more!'),(117,8,1,0,'You\'ve received new communication email','Please, visit ##COMMUNICATION_URL## to read more!'),(117,9,1,0,'You\'ve received new communication email','Please, visit ##COMMUNICATION_URL## to read more!'),(117,10,1,0,'You\'ve received new communication email','Please, visit ##COMMUNICATION_URL## to read more!'),(118,1,1,0,'You\'ve received new communication email','Please, visit <a target=\"_blank\" href=\"##COMMUNICATION_URL##\">this URL</a> to read more!'),(118,7,1,0,'You\'ve received new communication email','Please, visit <a target=\"_blank\" href=\"##COMMUNICATION_URL##\">this URL</a> to read more!'),(118,8,1,0,'You\'ve received new communication email','Please, visit <a target=\"_blank\" href=\"##COMMUNICATION_URL##\">this URL</a> to read more!'),(118,9,1,0,'You\'ve received new communication email','Please, visit <a target=\"_blank\" href=\"##COMMUNICATION_URL##\">this URL</a> to read more!'),(118,10,1,0,'You\'ve received new communication email','Please, visit <a target=\"_blank\" href=\"##COMMUNICATION_URL##\">this URL</a> to read more!'),(119,1,1,0,'Invalid attempt to login with your email!','<p>Someone has tried to login with your email.</p>\r\n\r\n<p><br />\r\nDate and time: ##DEVICE_DATE##<br />\r\n<br />\r\nDevice agent: ##DEVICE_AGENT##<br />\r\n<br />\r\nIP address (location): ##DEVICE_IP##<br />\r\n<br />\r\nUsed password: ##PASSWORD_INVALID##<br />\r\n&nbsp;</p>\r\n\r\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\r\n\r\n<p>&nbsp;</p>'),(119,4,1,0,'Invalid attempt to login with your email!','<p>Someone has tried to login with your email.</p>\n<p><br />\nDate and time: ##DEVICE_DATE##<br />\n<br />\nDevice agent: ##DEVICE_AGENT##<br />\n<br />\nIP address (location): ##DEVICE_IP##<br />\n&nbsp;</p>\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n<p>&nbsp;</p>\n'),(119,5,1,0,'Invalid attempt to login with your email!','<p>Someone has tried to login with your email.</p>\n<p><br />\nDate and time: ##DEVICE_DATE##<br />\n<br />\nDevice agent: ##DEVICE_AGENT##<br />\n<br />\nIP address (location): ##DEVICE_IP##<br />\n&nbsp;</p>\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n<p>&nbsp;</p>\n'),(119,6,1,0,'Invalid attempt to login with your email!','<p>Someone has tried to login with your email.</p>\n<p><br />\nDate and time: ##DEVICE_DATE##<br />\n<br />\nDevice agent: ##DEVICE_AGENT##<br />\n<br />\nIP address (location): ##DEVICE_IP##<br />\n&nbsp;</p>\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n<p>&nbsp;</p>\n'),(119,7,1,0,'Invalid attempt to login with your email!','<p>Someone has tried to login with your email.</p>\r\n\r\n<p><br />\r\nDate and time: ##DEVICE_DATE##<br />\r\n<br />\r\nDevice agent: ##DEVICE_AGENT##<br />\r\n<br />\r\nIP address (location): ##DEVICE_IP##<br />\r\n<br />\r\nUsed password: ##PASSWORD_INVALID##<br />\r\n&nbsp;</p>\r\n\r\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\r\n\r\n<p>&nbsp;</p>'),(119,8,1,0,'Invalid attempt to login with your email!','<p>Someone has tried to login with your email.</p>\r\n\r\n<p><br />\r\nDate and time: ##DEVICE_DATE##<br />\r\n<br />\r\nDevice agent: ##DEVICE_AGENT##<br />\r\n<br />\r\nIP address (location): ##DEVICE_IP##<br />\r\n<br />\r\nUsed password: ##PASSWORD_INVALID##<br />\r\n&nbsp;</p>\r\n\r\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\r\n\r\n<p>&nbsp;</p>'),(119,9,1,0,'Invalid attempt to login with your email!','<p>Someone has tried to login with your email.</p>\r\n\r\n<p><br />\r\nDate and time: ##DEVICE_DATE##<br />\r\n<br />\r\nDevice agent: ##DEVICE_AGENT##<br />\r\n<br />\r\nIP address (location): ##DEVICE_IP##<br />\r\n<br />\r\nUsed password: ##PASSWORD_INVALID##<br />\r\n&nbsp;</p>\r\n\r\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\r\n\r\n<p>&nbsp;</p>'),(119,10,1,0,'Invalid attempt to login with your email!','<p>Someone has tried to login with your email.</p>\r\n\r\n<p><br />\r\nDate and time: ##DEVICE_DATE##<br />\r\n<br />\r\nDevice agent: ##DEVICE_AGENT##<br />\r\n<br />\r\nIP address (location): ##DEVICE_IP##<br />\r\n<br />\r\nUsed password: ##PASSWORD_INVALID##<br />\r\n&nbsp;</p>\r\n\r\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\r\n\r\n<p>&nbsp;</p>'),(120,1,1,0,'Invalid attempt to login with your email!','Someone has tried to login with your email.\r\nDate and time: ##DEVICE_DATE##\r\nDevice agent: ##DEVICE_AGENT##\r\nIP address (location): ##DEVICE_IP##\r\nUsed password: ##PASSWORD_INVALID##\r\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.'),(120,4,1,0,'Invalid attempt to login with your email!','Someone has tried to login with your email.\nDate and time: ##DEVICE_DATE##\nDevice agent: ##DEVICE_AGENT##\nIP address (location): ##DEVICE_IP##\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n'),(120,5,1,0,'Invalid attempt to login with your email!','Someone has tried to login with your email.\nDate and time: ##DEVICE_DATE##\nDevice agent: ##DEVICE_AGENT##\nIP address (location): ##DEVICE_IP##\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n'),(120,6,1,0,'Invalid attempt to login with your email!','Someone has tried to login with your email.\nDate and time: ##DEVICE_DATE##\nDevice agent: ##DEVICE_AGENT##\nIP address (location): ##DEVICE_IP##\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n'),(120,7,1,0,'Invalid attempt to login with your email!','Someone has tried to login with your email.\r\nDate and time: ##DEVICE_DATE##\r\nDevice agent: ##DEVICE_AGENT##\r\nIP address (location): ##DEVICE_IP##\r\nUsed password: ##PASSWORD_INVALID##\r\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.'),(120,8,1,0,'Invalid attempt to login with your email!','Someone has tried to login with your email.\r\nDate and time: ##DEVICE_DATE##\r\nDevice agent: ##DEVICE_AGENT##\r\nIP address (location): ##DEVICE_IP##\r\nUsed password: ##PASSWORD_INVALID##\r\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.'),(120,9,1,0,'Invalid attempt to login with your email!','Someone has tried to login with your email.\r\nDate and time: ##DEVICE_DATE##\r\nDevice agent: ##DEVICE_AGENT##\r\nIP address (location): ##DEVICE_IP##\r\nUsed password: ##PASSWORD_INVALID##\r\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.'),(120,10,1,0,'Invalid attempt to login with your email!','Someone has tried to login with your email.\r\nDate and time: ##DEVICE_DATE##\r\nDevice agent: ##DEVICE_AGENT##\r\nIP address (location): ##DEVICE_IP##\r\nUsed password: ##PASSWORD_INVALID##\r\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\r\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.'),(121,1,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','<p>Someone has tried to login and pass 2-step authorization with your credentials.</p>\n<p><br />\nDate and time: ##DEVICE_DATE##<br />\n<br />\nDevice agent: ##DEVICE_AGENT##<br />\n<br />\nIP address (location): ##DEVICE_IP##<br />\n&nbsp;</p>\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n<p>&nbsp;</p>\n'),(121,4,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','<p>Someone has tried to login and pass 2-step authorization with your credentials.</p>\n<p><br />\nDate and time: ##DEVICE_DATE##<br />\n<br />\nDevice agent: ##DEVICE_AGENT##<br />\n<br />\nIP address (location): ##DEVICE_IP##<br />\n&nbsp;</p>\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n<p>&nbsp;</p>\n'),(121,5,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','<p>Someone has tried to login and pass 2-step authorization with your credentials.</p>\n<p><br />\nDate and time: ##DEVICE_DATE##<br />\n<br />\nDevice agent: ##DEVICE_AGENT##<br />\n<br />\nIP address (location): ##DEVICE_IP##<br />\n&nbsp;</p>\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n<p>&nbsp;</p>\n'),(121,6,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','<p>Someone has tried to login and pass 2-step authorization with your credentials.</p>\n<p><br />\nDate and time: ##DEVICE_DATE##<br />\n<br />\nDevice agent: ##DEVICE_AGENT##<br />\n<br />\nIP address (location): ##DEVICE_IP##<br />\n&nbsp;</p>\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n<p>&nbsp;</p>\n'),(121,7,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','<p>Someone has tried to login and pass 2-step authorization with your credentials.</p>\n<p><br />\nDate and time: ##DEVICE_DATE##<br />\n<br />\nDevice agent: ##DEVICE_AGENT##<br />\n<br />\nIP address (location): ##DEVICE_IP##<br />\n&nbsp;</p>\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n<p>&nbsp;</p>\n'),(121,8,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','<p>Someone has tried to login and pass 2-step authorization with your credentials.</p>\n<p><br />\nDate and time: ##DEVICE_DATE##<br />\n<br />\nDevice agent: ##DEVICE_AGENT##<br />\n<br />\nIP address (location): ##DEVICE_IP##<br />\n&nbsp;</p>\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n<p>&nbsp;</p>\n'),(121,9,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','<p>Someone has tried to login and pass 2-step authorization with your credentials.</p>\n<p><br />\nDate and time: ##DEVICE_DATE##<br />\n<br />\nDevice agent: ##DEVICE_AGENT##<br />\n<br />\nIP address (location): ##DEVICE_IP##<br />\n&nbsp;</p>\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n<p>&nbsp;</p>\n'),(121,10,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','<p>Someone has tried to login and pass 2-step authorization with your credentials.</p>\n<p><br />\nDate and time: ##DEVICE_DATE##<br />\n<br />\nDevice agent: ##DEVICE_AGENT##<br />\n<br />\nIP address (location): ##DEVICE_IP##<br />\n&nbsp;</p>\n<p>If it&#39;s weren&#39;t you who was trying to login, please log in into the system <a href=\"##LOGIN_URL##\" target=\"_blank\">using this link</a> immediately!</p>\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n<p>&nbsp;</p>\n'),(122,1,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','Someone has tried to login and pass 2-step authorization with your credentials.\nDate and time: ##DEVICE_DATE##\nDevice agent: ##DEVICE_AGENT##\nIP address (location): ##DEVICE_IP##\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n'),(122,4,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','Someone has tried to login and pass 2-step authorization with your credentials.\nDate and time: ##DEVICE_DATE##\nDevice agent: ##DEVICE_AGENT##\nIP address (location): ##DEVICE_IP##\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n'),(122,5,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','Someone has tried to login and pass 2-step authorization with your credentials.\nDate and time: ##DEVICE_DATE##\nDevice agent: ##DEVICE_AGENT##\nIP address (location): ##DEVICE_IP##\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n'),(122,6,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','Someone has tried to login and pass 2-step authorization with your credentials.\nDate and time: ##DEVICE_DATE##\nDevice agent: ##DEVICE_AGENT##\nIP address (location): ##DEVICE_IP##\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n'),(122,7,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','Someone has tried to login and pass 2-step authorization with your credentials.\nDate and time: ##DEVICE_DATE##\nDevice agent: ##DEVICE_AGENT##\nIP address (location): ##DEVICE_IP##\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n'),(122,8,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','Someone has tried to login and pass 2-step authorization with your credentials.\nDate and time: ##DEVICE_DATE##\nDevice agent: ##DEVICE_AGENT##\nIP address (location): ##DEVICE_IP##\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n'),(122,9,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','Someone has tried to login and pass 2-step authorization with your credentials.\nDate and time: ##DEVICE_DATE##\nDevice agent: ##DEVICE_AGENT##\nIP address (location): ##DEVICE_IP##\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n'),(122,10,1,0,'Invalid attempt to pass 2-step authorization with your credentials!','Someone has tried to login and pass 2-step authorization with your credentials.\nDate and time: ##DEVICE_DATE##\nDevice agent: ##DEVICE_AGENT##\nIP address (location): ##DEVICE_IP##\nIf it\'s weren\'t you who was trying to login, please log in into the system using ##LOGIN_URL## link immediately!\nIf you have not logged into your account for a long time, and you think that you can get another person, change your password as soon as possible.\n'),(123,1,1,0,'RMA has been issued ##TOPIC_SUBJECT##','<p>Please, visit <a href=\"##COMMUNICATION_URL##\" target=\"_blank\">this URL</a> to see details</p>\n<p>&nbsp;</p>\n<p>##TOPIC_SUBJECT##</p>\n##TOPIC_STATUS##<br>\n##MESSAGE##\n\n<p>&nbsp;</p>\n\n<p>RMA automated instruction to customer:</p>\n\n<p>We have raised a return for your item, please mark your parcel with the RMA reference below and return it to:</p>\n\n<p>##RMA_STATUS##<br />\n##RMA_NUMBER##<br />\n\n<p>The RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.</p>\n\n<p>We recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than &pound;50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over &pound;50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.</p>\n\n<p>Please note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.</p>\n\n<p>Please note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.&nbsp;</p>\n\n<p>If your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.</p>\n'),(123,4,1,0,'RMA has been issued ##TOPIC_SUBJECT##','<p>Please, visit <a href=\"##COMMUNICATION_URL##\" target=\"_blank\">this URL</a> to see details</p>\n<p>&nbsp;</p>\n<p>##TOPIC_SUBJECT##</p>\n##TOPIC_STATUS##<br>\n##MESSAGE##\n\n<p>&nbsp;</p>\n\n<p>RMA automated instruction to customer:</p>\n\n<p>We have raised a return for your item, please mark your parcel with the RMA reference below and return it to:</p>\n\n<p>##RMA_STATUS##<br />\n##RMA_NUMBER##<br />\n\n<p>The RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.</p>\n\n<p>We recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than &pound;50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over &pound;50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.</p>\n\n<p>Please note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.</p>\n\n<p>Please note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.&nbsp;</p>\n\n<p>If your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.</p>\n'),(123,5,1,0,'RMA has been issued ##TOPIC_SUBJECT##','<p>Please, visit <a href=\"##COMMUNICATION_URL##\" target=\"_blank\">this URL</a> to see details</p>\n<p>&nbsp;</p>\n<p>##TOPIC_SUBJECT##</p>\n##TOPIC_STATUS##<br>\n##MESSAGE##\n\n<p>&nbsp;</p>\n\n<p>RMA automated instruction to customer:</p>\n\n<p>We have raised a return for your item, please mark your parcel with the RMA reference below and return it to:</p>\n\n<p>##RMA_STATUS##<br />\n##RMA_NUMBER##<br />\n\n<p>The RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.</p>\n\n<p>We recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than &pound;50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over &pound;50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.</p>\n\n<p>Please note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.</p>\n\n<p>Please note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.&nbsp;</p>\n\n<p>If your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.</p>\n'),(123,6,1,0,'RMA has been issued ##TOPIC_SUBJECT##','<p>Please, visit <a href=\"##COMMUNICATION_URL##\" target=\"_blank\">this URL</a> to see details</p>\n<p>&nbsp;</p>\n<p>##TOPIC_SUBJECT##</p>\n##TOPIC_STATUS##<br>\n##MESSAGE##\n\n<p>&nbsp;</p>\n\n<p>RMA automated instruction to customer:</p>\n\n<p>We have raised a return for your item, please mark your parcel with the RMA reference below and return it to:</p>\n\n<p>##RMA_STATUS##<br />\n##RMA_NUMBER##<br />\n\n<p>The RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.</p>\n\n<p>We recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than &pound;50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over &pound;50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.</p>\n\n<p>Please note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.</p>\n\n<p>Please note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.&nbsp;</p>\n\n<p>If your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.</p>\n'),(123,7,1,0,'RMA has been issued ##TOPIC_SUBJECT##','<p>Please, visit <a href=\"##COMMUNICATION_URL##\" target=\"_blank\">this URL</a> to see details</p>\n<p>&nbsp;</p>\n<p>##TOPIC_SUBJECT##</p>\n##TOPIC_STATUS##<br>\n##MESSAGE##\n\n<p>&nbsp;</p>\n\n<p>RMA automated instruction to customer:</p>\n\n<p>We have raised a return for your item, please mark your parcel with the RMA reference below and return it to:</p>\n\n<p>##RMA_STATUS##<br />\n##RMA_NUMBER##<br />\n\n<p>The RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.</p>\n\n<p>We recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than &pound;50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over &pound;50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.</p>\n\n<p>Please note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.</p>\n\n<p>Please note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.&nbsp;</p>\n\n<p>If your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.</p>\n'),(123,8,1,0,'RMA has been issued ##TOPIC_SUBJECT##','<p>Please, visit <a href=\"##COMMUNICATION_URL##\" target=\"_blank\">this URL</a> to see details</p>\n<p>&nbsp;</p>\n<p>##TOPIC_SUBJECT##</p>\n##TOPIC_STATUS##<br>\n##MESSAGE##\n\n<p>&nbsp;</p>\n\n<p>RMA automated instruction to customer:</p>\n\n<p>We have raised a return for your item, please mark your parcel with the RMA reference below and return it to:</p>\n\n<p>##RMA_STATUS##<br />\n##RMA_NUMBER##<br />\n\n<p>The RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.</p>\n\n<p>We recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than &pound;50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over &pound;50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.</p>\n\n<p>Please note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.</p>\n\n<p>Please note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.&nbsp;</p>\n\n<p>If your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.</p>\n'),(123,9,1,0,'RMA has been issued ##TOPIC_SUBJECT##','<p>Please, visit <a href=\"##COMMUNICATION_URL##\" target=\"_blank\">this URL</a> to see details</p>\n<p>&nbsp;</p>\n<p>##TOPIC_SUBJECT##</p>\n##TOPIC_STATUS##<br>\n##MESSAGE##\n\n<p>&nbsp;</p>\n\n<p>RMA automated instruction to customer:</p>\n\n<p>We have raised a return for your item, please mark your parcel with the RMA reference below and return it to:</p>\n\n<p>##RMA_STATUS##<br />\n##RMA_NUMBER##<br />\n\n<p>The RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.</p>\n\n<p>We recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than &pound;50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over &pound;50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.</p>\n\n<p>Please note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.</p>\n\n<p>Please note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.&nbsp;</p>\n\n<p>If your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.</p>\n'),(123,10,1,0,'RMA has been issued ##TOPIC_SUBJECT##','<p>Please, visit <a href=\"##COMMUNICATION_URL##\" target=\"_blank\">this URL</a> to see details</p>\n<p>&nbsp;</p>\n<p>##TOPIC_SUBJECT##</p>\n##TOPIC_STATUS##<br>\n##MESSAGE##\n\n<p>&nbsp;</p>\n\n<p>RMA automated instruction to customer:</p>\n\n<p>We have raised a return for your item, please mark your parcel with the RMA reference below and return it to:</p>\n\n<p>##RMA_STATUS##<br />\n##RMA_NUMBER##<br />\n\n<p>The RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.</p>\n\n<p>We recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than &pound;50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over &pound;50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.</p>\n\n<p>Please note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.</p>\n\n<p>Please note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.&nbsp;</p>\n\n<p>If your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.</p>\n'),(124,1,1,0,'RMA has been issued','Please, visit this URL ##COMMUNICATION_URL## to see details\n\n\nRMA automated instruction to customer:\n\nWe have raised a return for your item, please mark your parcel with the RMA reference below and return it to:\n\n##RMA_NUMBER##\n\nThe RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.\n\nWe recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than £50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over £50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.\n\nPlease note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.\n\nPlease note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.\n\nIf your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.'),(124,4,1,0,'RMA has been issued','Please, visit this URL ##COMMUNICATION_URL## to see details\n\n\nRMA automated instruction to customer:\n\nWe have raised a return for your item, please mark your parcel with the RMA reference below and return it to:\n\n##RMA_NUMBER##\n\nThe RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.\n\nWe recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than £50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over £50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.\n\nPlease note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.\n\nPlease note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.\n\nIf your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.'),(124,5,1,0,'RMA has been issued','Please, visit this URL ##COMMUNICATION_URL## to see details\n\n\nRMA automated instruction to customer:\n\nWe have raised a return for your item, please mark your parcel with the RMA reference below and return it to:\n\n##RMA_NUMBER##\n\nThe RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.\n\nWe recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than £50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over £50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.\n\nPlease note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.\n\nPlease note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.\n\nIf your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.'),(124,6,1,0,'RMA has been issued','Please, visit this URL ##COMMUNICATION_URL## to see details\n\n\nRMA automated instruction to customer:\n\nWe have raised a return for your item, please mark your parcel with the RMA reference below and return it to:\n\n##RMA_NUMBER##\n\nThe RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.\n\nWe recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than £50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over £50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.\n\nPlease note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.\n\nPlease note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.\n\nIf your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.'),(124,7,1,0,'RMA has been issued','Please, visit this URL ##COMMUNICATION_URL## to see details\n\n\nRMA automated instruction to customer:\n\nWe have raised a return for your item, please mark your parcel with the RMA reference below and return it to:\n\n##RMA_NUMBER##\n\nThe RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.\n\nWe recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than £50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over £50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.\n\nPlease note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.\n\nPlease note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.\n\nIf your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.'),(124,8,1,0,'RMA has been issued','Please, visit this URL ##COMMUNICATION_URL## to see details\n\n\nRMA automated instruction to customer:\n\nWe have raised a return for your item, please mark your parcel with the RMA reference below and return it to:\n\n##RMA_NUMBER##\n\nThe RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.\n\nWe recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than £50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over £50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.\n\nPlease note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.\n\nPlease note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.\n\nIf your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.'),(124,9,1,0,'RMA has been issued','Please, visit this URL ##COMMUNICATION_URL## to see details\n\n\nRMA automated instruction to customer:\n\nWe have raised a return for your item, please mark your parcel with the RMA reference below and return it to:\n\n##RMA_NUMBER##\n\nThe RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.\n\nWe recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than £50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over £50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.\n\nPlease note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.\n\nPlease note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.\n\nIf your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.'),(124,10,1,0,'RMA has been issued','Please, visit this URL ##COMMUNICATION_URL## to see details\n\n\nRMA automated instruction to customer:\n\nWe have raised a return for your item, please mark your parcel with the RMA reference below and return it to:\n\n##RMA_NUMBER##\n\nThe RMA number (starting RT) should be clearly visible on the outside of the package, as the first line of the address as indicated above. Failure to have the RMA number on the outside of the parcel may lead to delays with the return being processed. This RMA number is valid for 10 working days from the date of issue.\n\nWe recommend that returned items are sent via an insured postal service to ensure they are insured for their value and arrive with us safely. Please also ensure that returned items are adequately packaged for protection in transit. If the value of the item is lower than £50.00 then this would be covered by Royal Mail Recorded Delivery or if the item is over £50.00 in value Royal Mail Special Delivery would give a higher level of insurance to cover the full cost. We are not liable for items that are damaged during transit.\n\nPlease note this address is for our main distribution warehouse. We are unable to accept any returns in person at this premise.\n\nPlease note we can only reimburse the cost of returning the goods if the item has arrived with you in a faulty state, or has failed due to a manufacturing fault within the first two weeks. If your return is applicable for postal reimbursement please provide an electronic copy of the postal receipt (.JPEG or .PDF) in reply to this message as this information is required to issue the reimbursement.\n\nIf your address has changed from the original shipping address, please update us via email and include a note of your new address with the returned item.'),(125,1,1,0,'##STORE_NAME## - New Password','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\n\n<p><span style=\"font-size:12px;\">New password to access the back end of&nbsp;&#39;##STORE_NAME##&#39; has just been requested.</span></p>\n\n<p><span style=\"font-size:12px;\">##NEW_PASSWORD_SENTENCE##</span></p>\n\n<p><span style=\"font-size:12px;\"><strong>##NEW_PASSWORD##</strong></span></p>\n\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\n\n<p><span style=\"font-size:12px;\">Kind regards,<br />\nThe team of&nbsp;##STORE_NAME##</span></p>\n'),(125,4,1,0,'##STORE_NAME## - New Password','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\n\n<p><span style=\"font-size:12px;\">New password to access the back end of&nbsp;&#39;##STORE_NAME##&#39; has just been requested.</span></p>\n\n<p><span style=\"font-size:12px;\">##NEW_PASSWORD_SENTENCE##</span></p>\n\n<p><span style=\"font-size:12px;\"><strong>##NEW_PASSWORD##</strong></span></p>\n\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\n\n<p><span style=\"font-size:12px;\">Kind regards,<br />\nThe team of&nbsp;##STORE_NAME##</span></p>\n'),(125,5,1,0,'##STORE_NAME## - New Password','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\n\n<p><span style=\"font-size:12px;\">New password to access the back end of&nbsp;&#39;##STORE_NAME##&#39; has just been requested.</span></p>\n\n<p><span style=\"font-size:12px;\">##NEW_PASSWORD_SENTENCE##</span></p>\n\n<p><span style=\"font-size:12px;\"><strong>##NEW_PASSWORD##</strong></span></p>\n\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\n\n<p><span style=\"font-size:12px;\">Kind regards,<br />\nThe team of&nbsp;##STORE_NAME##</span></p>\n'),(125,6,1,0,'##STORE_NAME## - New Password','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\n\n<p><span style=\"font-size:12px;\">New password to access the back end of&nbsp;&#39;##STORE_NAME##&#39; has just been requested.</span></p>\n\n<p><span style=\"font-size:12px;\">##NEW_PASSWORD_SENTENCE##</span></p>\n\n<p><span style=\"font-size:12px;\"><strong>##NEW_PASSWORD##</strong></span></p>\n\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\n\n<p><span style=\"font-size:12px;\">Kind regards,<br />\nThe team of&nbsp;##STORE_NAME##</span></p>\n'),(125,7,1,0,'##STORE_NAME## - New Password','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\n\n<p><span style=\"font-size:12px;\">New password to access the back end of&nbsp;&#39;##STORE_NAME##&#39; has just been requested.</span></p>\n\n<p><span style=\"font-size:12px;\">##NEW_PASSWORD_SENTENCE##</span></p>\n\n<p><span style=\"font-size:12px;\"><strong>##NEW_PASSWORD##</strong></span></p>\n\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\n\n<p><span style=\"font-size:12px;\">Kind regards,<br />\nThe team of&nbsp;##STORE_NAME##</span></p>\n'),(125,8,1,0,'##STORE_NAME## - New Password','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\n\n<p><span style=\"font-size:12px;\">New password to access the back end of&nbsp;&#39;##STORE_NAME##&#39; has just been requested.</span></p>\n\n<p><span style=\"font-size:12px;\">##NEW_PASSWORD_SENTENCE##</span></p>\n\n<p><span style=\"font-size:12px;\"><strong>##NEW_PASSWORD##</strong></span></p>\n\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\n\n<p><span style=\"font-size:12px;\">Kind regards,<br />\nThe team of&nbsp;##STORE_NAME##</span></p>\n'),(125,9,1,0,'##STORE_NAME## - New Password','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\n\n<p><span style=\"font-size:12px;\">New password to access the back end of&nbsp;&#39;##STORE_NAME##&#39; has just been requested.</span></p>\n\n<p><span style=\"font-size:12px;\">##NEW_PASSWORD_SENTENCE##</span></p>\n\n<p><span style=\"font-size:12px;\"><strong>##NEW_PASSWORD##</strong></span></p>\n\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\n\n<p><span style=\"font-size:12px;\">Kind regards,<br />\nThe team of&nbsp;##STORE_NAME##</span></p>\n'),(125,10,1,0,'##STORE_NAME## - New Password','<p><span style=\"font-size:12px;\">Dear ##CUSTOMER_FIRSTNAME##,</span></p>\n\n<p><span style=\"font-size:12px;\">New password to access the back end of&nbsp;&#39;##STORE_NAME##&#39; has just been requested.</span></p>\n\n<p><span style=\"font-size:12px;\">##NEW_PASSWORD_SENTENCE##</span></p>\n\n<p><span style=\"font-size:12px;\"><strong>##NEW_PASSWORD##</strong></span></p>\n\n<p><span style=\"font-size:12px;\">Please don&#39;t hesitate to contact us at&nbsp;##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.</span></p>\n\n<p><span style=\"font-size:12px;\">Kind regards,<br />\nThe team of&nbsp;##STORE_NAME##</span></p>\n'),(126,1,1,0,'##STORE_NAME## - New Password','Dear ##CUSTOMER_FIRSTNAME##,\n\nNew password to access the back end of \'##STORE_NAME##\' has just been requested.\n\n##NEW_PASSWORD_SENTENCE##\n##NEW_PASSWORD##\n\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\n\nKind regards,\nThe team of ##STORE_NAME##\n'),(126,4,1,0,'##STORE_NAME## - New Password','Dear ##CUSTOMER_FIRSTNAME##,\n\nNew password to access the back end of \'##STORE_NAME##\' has just been requested.\n\n##NEW_PASSWORD_SENTENCE##\n##NEW_PASSWORD##\n\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\n\nKind regards,\nThe team of ##STORE_NAME##\n'),(126,5,1,0,'##STORE_NAME## - New Password','Dear ##CUSTOMER_FIRSTNAME##,\n\nNew password to access the back end of \'##STORE_NAME##\' has just been requested.\n\n##NEW_PASSWORD_SENTENCE##\n##NEW_PASSWORD##\n\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\n\nKind regards,\nThe team of ##STORE_NAME##\n'),(126,6,1,0,'##STORE_NAME## - New Password','Dear ##CUSTOMER_FIRSTNAME##,\n\nNew password to access the back end of \'##STORE_NAME##\' has just been requested.\n\n##NEW_PASSWORD_SENTENCE##\n##NEW_PASSWORD##\n\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\n\nKind regards,\nThe team of ##STORE_NAME##\n'),(126,7,1,0,'##STORE_NAME## - New Password','Dear ##CUSTOMER_FIRSTNAME##,\n\nNew password to access the back end of \'##STORE_NAME##\' has just been requested.\n\n##NEW_PASSWORD_SENTENCE##\n##NEW_PASSWORD##\n\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\n\nKind regards,\nThe team of ##STORE_NAME##\n'),(126,8,1,0,'##STORE_NAME## - New Password','Dear ##CUSTOMER_FIRSTNAME##,\n\nNew password to access the back end of \'##STORE_NAME##\' has just been requested.\n\n##NEW_PASSWORD_SENTENCE##\n##NEW_PASSWORD##\n\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\n\nKind regards,\nThe team of ##STORE_NAME##\n'),(126,9,1,0,'##STORE_NAME## - New Password','Dear ##CUSTOMER_FIRSTNAME##,\n\nNew password to access the back end of \'##STORE_NAME##\' has just been requested.\n\n##NEW_PASSWORD_SENTENCE##\n##NEW_PASSWORD##\n\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\n\nKind regards,\nThe team of ##STORE_NAME##\n'),(126,10,1,0,'##STORE_NAME## - New Password','Dear ##CUSTOMER_FIRSTNAME##,\n\nNew password to access the back end of \'##STORE_NAME##\' has just been requested.\n\n##NEW_PASSWORD_SENTENCE##\n##NEW_PASSWORD##\n\nPlease don\'t hesitate to contact us at ##STORE_OWNER_EMAIL_ADDRESS## should you have any questions.\n\nKind regards,\nThe team of ##STORE_NAME##\n'),(127,1,1,0,'Message from site visitor','<p>##ENQUIRY_CONTENT##</p>\n<p>-------------------------</p>\n<p>Name: ##CUSTOMER_NAME##<br>\nEmail: ##CUSTOMER_EMAIL##</p>'),(127,4,1,0,'Message from site visitor','<p>##ENQUIRY_CONTENT##</p>\n<p>-------------------------</p>\n<p>Name: ##CUSTOMER_NAME##<br>\nEmail: ##CUSTOMER_EMAIL##</p>'),(127,5,1,0,'Message from site visitor','<p>##ENQUIRY_CONTENT##</p>\n<p>-------------------------</p>\n<p>Name: ##CUSTOMER_NAME##<br>\nEmail: ##CUSTOMER_EMAIL##</p>'),(127,6,1,0,'Message from site visitor','<p>##ENQUIRY_CONTENT##</p>\n<p>-------------------------</p>\n<p>Name: ##CUSTOMER_NAME##<br>\nEmail: ##CUSTOMER_EMAIL##</p>'),(127,7,1,0,'Message from site visitor','<p>##ENQUIRY_CONTENT##</p>\n<p>-------------------------</p>\n<p>Name: ##CUSTOMER_NAME##<br>\nEmail: ##CUSTOMER_EMAIL##</p>'),(127,8,1,0,'Message from site visitor','<p>##ENQUIRY_CONTENT##</p>\n<p>-------------------------</p>\n<p>Name: ##CUSTOMER_NAME##<br>\nEmail: ##CUSTOMER_EMAIL##</p>'),(127,9,1,0,'Message from site visitor','<p>##ENQUIRY_CONTENT##</p>\n<p>-------------------------</p>\n<p>Name: ##CUSTOMER_NAME##<br>\nEmail: ##CUSTOMER_EMAIL##</p>'),(127,10,1,0,'Message from site visitor','<p>##ENQUIRY_CONTENT##</p>\n<p>-------------------------</p>\n<p>Name: ##CUSTOMER_NAME##<br>\nEmail: ##CUSTOMER_EMAIL##</p>'),(128,1,1,0,'Message from site visitor','##ENQUIRY_CONTENT##\n\n-------------------------\n\nName: ##CUSTOMER_NAME##\nEmail: ##CUSTOMER_EMAIL##'),(128,4,1,0,'Message from site visitor','##ENQUIRY_CONTENT##\n\n-------------------------\n\nName: ##CUSTOMER_NAME##\nEmail: ##CUSTOMER_EMAIL##'),(128,5,1,0,'Message from site visitor','##ENQUIRY_CONTENT##\n\n-------------------------\n\nName: ##CUSTOMER_NAME##\nEmail: ##CUSTOMER_EMAIL##'),(128,6,1,0,'Message from site visitor','##ENQUIRY_CONTENT##\n\n-------------------------\n\nName: ##CUSTOMER_NAME##\nEmail: ##CUSTOMER_EMAIL##'),(128,7,1,0,'Message from site visitor','##ENQUIRY_CONTENT##\n\n-------------------------\n\nName: ##CUSTOMER_NAME##\nEmail: ##CUSTOMER_EMAIL##'),(128,8,1,0,'Message from site visitor','##ENQUIRY_CONTENT##\n\n-------------------------\n\nName: ##CUSTOMER_NAME##\nEmail: ##CUSTOMER_EMAIL##'),(128,9,1,0,'Message from site visitor','##ENQUIRY_CONTENT##\n\n-------------------------\n\nName: ##CUSTOMER_NAME##\nEmail: ##CUSTOMER_EMAIL##'),(128,10,1,0,'Message from site visitor','##ENQUIRY_CONTENT##\n\n-------------------------\n\nName: ##CUSTOMER_NAME##\nEmail: ##CUSTOMER_EMAIL##'),(4519,1,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\nDetailed Invoice: ##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\nTracking number: ##TRACKING_NUMBER##\n\n##TRACKING_NUMBER_URL##'),(4519,4,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\nDetailed Invoice: ##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\nTracking number: ##TRACKING_NUMBER##\n\n##TRACKING_NUMBER_URL##'),(4519,5,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\nDetailed Invoice: ##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\nTracking number: ##TRACKING_NUMBER##\n\n##TRACKING_NUMBER_URL##'),(4519,6,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\nDetailed Invoice: ##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\nTracking number: ##TRACKING_NUMBER##\n\n##TRACKING_NUMBER_URL##'),(4519,7,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\nDetailed Invoice: ##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\nTracking number: ##TRACKING_NUMBER##\n\n##TRACKING_NUMBER_URL##'),(4519,8,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\nDetailed Invoice: ##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\nTracking number: ##TRACKING_NUMBER##\n\n##TRACKING_NUMBER_URL##'),(4519,9,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\nDetailed Invoice: ##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\nTracking number: ##TRACKING_NUMBER##\n\n##TRACKING_NUMBER_URL##'),(4519,10,1,0,'Order Update','Order Number: ##ORDER_NUMBER##\nDetailed Invoice: ##ORDER_INVOICE_URL##\nDate Ordered: ##ORDER_DATE_LONG##\n\nTracking number: ##TRACKING_NUMBER##\n\n##TRACKING_NUMBER_URL##');
/*!40000 ALTER TABLE `email_templates_texts` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `email_templates_to_design_template`
--

DROP TABLE IF EXISTS `email_templates_to_design_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `email_templates_to_design_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `email_templates_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `theme_id` varchar(256) NOT NULL DEFAULT '',
  `email_design_template` varchar(256) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `email_templates_to_design_template`
--

LOCK TABLES `email_templates_to_design_template` WRITE;
/*!40000 ALTER TABLE `email_templates_to_design_template` DISABLE KEYS */;
/*!40000 ALTER TABLE `email_templates_to_design_template` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `emails`
--

DROP TABLE IF EXISTS `emails`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `emails` (
  `emails_id` int(11) NOT NULL AUTO_INCREMENT,
  `subject` varchar(256) NOT NULL DEFAULT '',
  `theme_name` varchar(256) NOT NULL DEFAULT '',
  `template` varchar(256) NOT NULL DEFAULT '',
  `html` text,
  `data` text,
  `date_added` datetime DEFAULT NULL,
  `date_modified` datetime DEFAULT NULL,
  PRIMARY KEY (`emails_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `emails`
--

LOCK TABLES `emails` WRITE;
/*!40000 ALTER TABLE `emails` DISABLE KEYS */;
/*!40000 ALTER TABLE `emails` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_custom_providers`
--

DROP TABLE IF EXISTS `ep_custom_providers`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_custom_providers` (
  `custom_provider_id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(32) NOT NULL DEFAULT '',
  `parent_provider` varchar(255) NOT NULL DEFAULT '',
  `direction` enum('import','export') NOT NULL DEFAULT 'import',
  `provider_configure` text,
  PRIMARY KEY (`custom_provider_id`),
  KEY `direction` (`direction`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_custom_providers`
--

LOCK TABLES `ep_custom_providers` WRITE;
/*!40000 ALTER TABLE `ep_custom_providers` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_custom_providers` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_datasources`
--

DROP TABLE IF EXISTS `ep_datasources`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_datasources` (
  `code` varchar(32) NOT NULL DEFAULT '',
  `class` varchar(32) DEFAULT NULL,
  `settings` text,
  UNIQUE KEY `code` (`code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_datasources`
--

LOCK TABLES `ep_datasources` WRITE;
/*!40000 ALTER TABLE `ep_datasources` DISABLE KEYS */;
INSERT INTO `ep_datasources` VALUES ('Import from osCommerce 2x','OSCommerce',NULL);
/*!40000 ALTER TABLE `ep_datasources` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_directories`
--

DROP TABLE IF EXISTS `ep_directories`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_directories` (
  `directory_id` int(11) NOT NULL AUTO_INCREMENT,
  `removable` tinyint(1) NOT NULL DEFAULT '1',
  `cron_enabled` tinyint(1) NOT NULL DEFAULT '0',
  `parent_id` int(11) NOT NULL DEFAULT '0',
  `name` varchar(32) NOT NULL DEFAULT '',
  `directory_type` varchar(16) NOT NULL DEFAULT 'export',
  `directory` varchar(255) NOT NULL DEFAULT '',
  `directory_config` text NOT NULL,
  PRIMARY KEY (`directory_id`)
) ENGINE=InnoDB AUTO_INCREMENT=26 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_directories`
--

LOCK TABLES `ep_directories` WRITE;
/*!40000 ALTER TABLE `ep_directories` DISABLE KEYS */;
INSERT INTO `ep_directories` VALUES (1,0,0,0,'TEXT_MANUAL_EXPORT','export','manual_export',''),(2,0,0,0,'TEXT_MANUAL_IMPORT','import','manual_import',''),(3,0,1,0,'TEXT_AUTOMATIC_EXPORT','export','auto_export',''),(4,0,1,0,'TEXT_AUTOMATIC_IMPORT','import','auto_import',''),(5,0,1,0,'TEXT_DATASOURCE','datasource','datasource',''),(20,1,1,5,'--','datasource','Import from osCommerce 2x','[{\"file_format\":\"OSCommerce\",\"job_provider\":\"OSCommerce\\\\ImportBrands\",\"run_frequency\":\"-1\",\"filename_pattern\":\"OSCommerce_ImportBrands_4084\",\"run_time\":\"00:00\"},{\"file_format\":\"OSCommerce\",\"job_provider\":\"OSCommerce\\\\ImportCategories\",\"run_frequency\":\"-1\",\"filename_pattern\":\"OSCommerce_ImportCategories_8261\",\"run_time\":\"00:00\"},{\"file_format\":\"OSCommerce\",\"job_provider\":\"OSCommerce\\\\ImportProductsOptions\",\"run_frequency\":\"-1\",\"filename_pattern\":\"OSCommerce_ImportProductsOptions_3439\",\"run_time\":\"00:00\"},{\"file_format\":\"OSCommerce\",\"job_provider\":\"OSCommerce\\\\ImportProducts\",\"run_frequency\":\"-1\",\"filename_pattern\":\"OSCommerce_ImportProducts_2558\",\"run_time\":\"00:00\"},{\"file_format\":\"OSCommerce\",\"job_provider\":\"OSCommerce\\\\ImportCustomers\",\"run_frequency\":\"-1\",\"filename_pattern\":\"OSCommerce_ImportCustomers_5841\",\"run_time\":\"00:00\"},{\"file_format\":\"OSCommerce\",\"job_provider\":\"OSCommerce\\\\ImportOrdersStatuses\",\"run_frequency\":\"-1\",\"filename_pattern\":\"OSCommerce_ImportOrdersStatuses_8904\",\"run_time\":\"00:00\"},{\"file_format\":\"OSCommerce\",\"job_provider\":\"OSCommerce\\\\ImportOrders\",\"run_frequency\":\"-1\",\"filename_pattern\":\"OSCommerce_ImportOrders_1836\",\"run_time\":\"00:00\"},{\"file_format\":\"OSCommerce\",\"job_provider\":\"OSCommerce\\\\ImportTaxZones\",\"run_frequency\":\"-1\",\"filename_pattern\":\"OSCommerce_ImportTaxZones_5446\",\"run_time\":\"00:00\"},{\"file_format\":\"OSCommerce\",\"job_provider\":\"OSCommerce\\\\ImportTax\",\"run_frequency\":\"-1\",\"filename_pattern\":\"OSCommerce_ImportTax_7512\",\"run_time\":\"00:00\"}]'),(21,1,1,20,'--','processed','processed','');
/*!40000 ALTER TABLE `ep_directories` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_holbi_soap_category_products_flags`
--

DROP TABLE IF EXISTS `ep_holbi_soap_category_products_flags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_holbi_soap_category_products_flags` (
  `ep_directory_id` int(11) NOT NULL,
  `categories_id` int(11) NOT NULL,
  `flag_name` varchar(32) NOT NULL,
  `flag_value` varchar(16) NOT NULL DEFAULT '-1',
  PRIMARY KEY (`ep_directory_id`,`categories_id`,`flag_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_holbi_soap_category_products_flags`
--

LOCK TABLES `ep_holbi_soap_category_products_flags` WRITE;
/*!40000 ALTER TABLE `ep_holbi_soap_category_products_flags` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_holbi_soap_category_products_flags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_holbi_soap_kv_storage`
--

DROP TABLE IF EXISTS `ep_holbi_soap_kv_storage`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_holbi_soap_kv_storage` (
  `ep_directory_id` int(11) NOT NULL,
  `key_name` varchar(64) NOT NULL,
  `key_value` varchar(1024) NOT NULL DEFAULT '',
  PRIMARY KEY (`ep_directory_id`,`key_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_holbi_soap_kv_storage`
--

LOCK TABLES `ep_holbi_soap_kv_storage` WRITE;
/*!40000 ALTER TABLE `ep_holbi_soap_kv_storage` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_holbi_soap_kv_storage` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_holbi_soap_kw_id_storage`
--

DROP TABLE IF EXISTS `ep_holbi_soap_kw_id_storage`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_holbi_soap_kw_id_storage` (
  `ep_directory_id` int(11) NOT NULL,
  `mapping_type` varchar(64) NOT NULL,
  `kw` varchar(64) NOT NULL,
  `description` varchar(255) NOT NULL DEFAULT '',
  `id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`ep_directory_id`,`mapping_type`,`kw`),
  KEY `id` (`id`),
  KEY `kw` (`kw`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_holbi_soap_kw_id_storage`
--

LOCK TABLES `ep_holbi_soap_kw_id_storage` WRITE;
/*!40000 ALTER TABLE `ep_holbi_soap_kw_id_storage` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_holbi_soap_kw_id_storage` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_holbi_soap_link_categories`
--

DROP TABLE IF EXISTS `ep_holbi_soap_link_categories`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_holbi_soap_link_categories` (
  `ep_directory_id` int(11) NOT NULL,
  `remote_category_id` int(11) NOT NULL,
  `local_category_id` int(11) NOT NULL DEFAULT '0',
  `server_last_modified` datetime DEFAULT NULL,
  `client_processed_last_modified` datetime DEFAULT NULL,
  PRIMARY KEY (`ep_directory_id`,`remote_category_id`),
  KEY `local_category_id` (`local_category_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_holbi_soap_link_categories`
--

LOCK TABLES `ep_holbi_soap_link_categories` WRITE;
/*!40000 ALTER TABLE `ep_holbi_soap_link_categories` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_holbi_soap_link_categories` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_holbi_soap_link_customers`
--

DROP TABLE IF EXISTS `ep_holbi_soap_link_customers`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_holbi_soap_link_customers` (
  `ep_directory_id` int(11) NOT NULL DEFAULT '0',
  `remote_customers_id` int(11) NOT NULL DEFAULT '0',
  `local_customers_id` int(11) NOT NULL DEFAULT '0',
  `local_time_processed` timestamp NULL DEFAULT NULL,
  `server_modify_time` timestamp NULL DEFAULT NULL,
  UNIQUE KEY `local_customers_id` (`local_customers_id`),
  KEY `ep_directory_id` (`ep_directory_id`,`remote_customers_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_holbi_soap_link_customers`
--

LOCK TABLES `ep_holbi_soap_link_customers` WRITE;
/*!40000 ALTER TABLE `ep_holbi_soap_link_customers` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_holbi_soap_link_customers` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_holbi_soap_link_inventory`
--

DROP TABLE IF EXISTS `ep_holbi_soap_link_inventory`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_holbi_soap_link_inventory` (
  `ep_directory_id` int(11) NOT NULL DEFAULT '0',
  `remote_products_id` int(11) NOT NULL DEFAULT '0',
  `local_uprid` varchar(256) NOT NULL DEFAULT '',
  `server_last_modified` datetime DEFAULT NULL,
  `client_processed_last_modified` datetime DEFAULT NULL,
  KEY `ep_directory_id` (`ep_directory_id`,`local_uprid`(255)),
  KEY `remote_products_id` (`remote_products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_holbi_soap_link_inventory`
--

LOCK TABLES `ep_holbi_soap_link_inventory` WRITE;
/*!40000 ALTER TABLE `ep_holbi_soap_link_inventory` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_holbi_soap_link_inventory` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_holbi_soap_link_orders`
--

DROP TABLE IF EXISTS `ep_holbi_soap_link_orders`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_holbi_soap_link_orders` (
  `ep_directory_id` int(11) NOT NULL DEFAULT '0',
  `remote_orders_id` int(11) NOT NULL DEFAULT '0',
  `local_orders_id` int(11) NOT NULL DEFAULT '0',
  `track_remote_order` tinyint(1) NOT NULL DEFAULT '0',
  `local_order_last_modified` datetime DEFAULT NULL,
  `local_order_last_modified_hash` varchar(32) NOT NULL DEFAULT '',
  `cfg_export_as` varchar(16) NOT NULL DEFAULT 'order',
  `date_exported` datetime DEFAULT NULL,
  `remote_guid` varchar(255) NOT NULL DEFAULT '',
  `remote_order_number` varchar(100) NOT NULL DEFAULT '',
  UNIQUE KEY `idx_PRIMARY` (`ep_directory_id`,`local_orders_id`,`remote_orders_id`,`cfg_export_as`),
  KEY `local_orders_id` (`local_orders_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_holbi_soap_link_orders`
--

LOCK TABLES `ep_holbi_soap_link_orders` WRITE;
/*!40000 ALTER TABLE `ep_holbi_soap_link_orders` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_holbi_soap_link_orders` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_holbi_soap_link_products`
--

DROP TABLE IF EXISTS `ep_holbi_soap_link_products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_holbi_soap_link_products` (
  `ep_directory_id` int(11) NOT NULL DEFAULT '0',
  `remote_products_id` int(11) NOT NULL DEFAULT '0',
  `local_products_id` int(11) NOT NULL DEFAULT '0',
  `server_last_modified` datetime DEFAULT NULL,
  `client_processed_last_modified` datetime DEFAULT NULL,
  `is_own_product` tinyint(1) DEFAULT NULL,
  UNIQUE KEY `local_products_id` (`local_products_id`,`ep_directory_id`),
  KEY `ep_directory_id` (`ep_directory_id`,`remote_products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_holbi_soap_link_products`
--

LOCK TABLES `ep_holbi_soap_link_products` WRITE;
/*!40000 ALTER TABLE `ep_holbi_soap_link_products` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_holbi_soap_link_products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_holbi_soap_mapping`
--

DROP TABLE IF EXISTS `ep_holbi_soap_mapping`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_holbi_soap_mapping` (
  `ep_directory_id` int(11) NOT NULL,
  `mapping_type` varchar(64) NOT NULL,
  `remote_id` int(11) NOT NULL,
  `local_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`ep_directory_id`,`mapping_type`,`remote_id`),
  KEY `local_id` (`local_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_holbi_soap_mapping`
--

LOCK TABLES `ep_holbi_soap_mapping` WRITE;
/*!40000 ALTER TABLE `ep_holbi_soap_mapping` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_holbi_soap_mapping` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_holbi_soap_products_flags`
--

DROP TABLE IF EXISTS `ep_holbi_soap_products_flags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_holbi_soap_products_flags` (
  `ep_directory_id` int(11) NOT NULL,
  `products_id` int(11) NOT NULL,
  `flag_name` varchar(32) NOT NULL,
  `flag_value` varchar(16) NOT NULL DEFAULT '-1',
  PRIMARY KEY (`ep_directory_id`,`products_id`,`flag_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_holbi_soap_products_flags`
--

LOCK TABLES `ep_holbi_soap_products_flags` WRITE;
/*!40000 ALTER TABLE `ep_holbi_soap_products_flags` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_holbi_soap_products_flags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_holbi_soap_remote_products_queue`
--

DROP TABLE IF EXISTS `ep_holbi_soap_remote_products_queue`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_holbi_soap_remote_products_queue` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `ep_directory_id` int(11) NOT NULL DEFAULT '0',
  `job_id` int(11) NOT NULL DEFAULT '0',
  `remote_id` int(11) NOT NULL DEFAULT '0',
  `date_added` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `class_name` varchar(255) NOT NULL DEFAULT '',
  `info` text NOT NULL,
  PRIMARY KEY (`id`),
  KEY `idx_ep_directory_id` (`ep_directory_id`),
  KEY `idx_remote_id` (`remote_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_holbi_soap_remote_products_queue`
--

LOCK TABLES `ep_holbi_soap_remote_products_queue` WRITE;
/*!40000 ALTER TABLE `ep_holbi_soap_remote_products_queue` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_holbi_soap_remote_products_queue` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_holbi_soap_server_kv_storage`
--

DROP TABLE IF EXISTS `ep_holbi_soap_server_kv_storage`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_holbi_soap_server_kv_storage` (
  `departments_id` int(11) NOT NULL,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `key_name` varchar(64) NOT NULL,
  `key_value` text,
  PRIMARY KEY (`departments_id`,`platform_id`,`key_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_holbi_soap_server_kv_storage`
--

LOCK TABLES `ep_holbi_soap_server_kv_storage` WRITE;
/*!40000 ALTER TABLE `ep_holbi_soap_server_kv_storage` DISABLE KEYS */;
INSERT INTO `ep_holbi_soap_server_kv_storage` VALUES (0,1,'product/UpdateDataFlag','[]'),(0,7,'product/UpdateDataFlag','[]'),(0,8,'product/UpdateDataFlag','[]');
/*!40000 ALTER TABLE `ep_holbi_soap_server_kv_storage` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_job`
--

DROP TABLE IF EXISTS `ep_job`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_job` (
  `job_id` int(11) NOT NULL AUTO_INCREMENT,
  `directory_id` int(11) NOT NULL DEFAULT '0',
  `file_name` varchar(255) NOT NULL DEFAULT '',
  `file_name_internal` varchar(32) NOT NULL DEFAULT '',
  `file_time` int(11) NOT NULL DEFAULT '0',
  `file_size` int(11) unsigned NOT NULL DEFAULT '0',
  `direction` enum('import','export','datasource','import_zip','import_sheets') NOT NULL DEFAULT 'import',
  `run_frequency` int(11) NOT NULL DEFAULT '-1',
  `run_time` char(5) NOT NULL DEFAULT '00:00',
  `last_cron_run` datetime DEFAULT NULL,
  `process_progress` tinyint(1) NOT NULL DEFAULT '0',
  `job_provider` varchar(128) NOT NULL DEFAULT 'auto',
  `job_state` varchar(16) NOT NULL DEFAULT 'not_configured',
  `job_configure` longtext,
  PRIMARY KEY (`job_id`),
  KEY `directory_id` (`directory_id`,`file_time`),
  KEY `idx_direction_file` (`direction`,`job_state`,`file_name`,`job_id`,`run_frequency`)
) ENGINE=InnoDB AUTO_INCREMENT=136 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_job`
--

LOCK TABLES `ep_job` WRITE;
/*!40000 ALTER TABLE `ep_job` DISABLE KEYS */;
INSERT INTO `ep_job` VALUES (22,20,'OSCommerce_ImportBrands_4084','',0,0,'datasource',-1,'00:00',NULL,0,'OSCommerce\\ImportBrands','configured',NULL),(23,20,'OSCommerce_ImportCategories_8261','',0,0,'datasource',-1,'00:00',NULL,0,'OSCommerce\\ImportCategories','configured',NULL),(24,20,'OSCommerce_ImportProductsOptions_3439','',0,0,'datasource',-1,'00:00',NULL,0,'OSCommerce\\ImportProductsOptions','configured',NULL),(25,20,'OSCommerce_ImportProducts_2558','',0,0,'datasource',-1,'00:00',NULL,0,'OSCommerce\\ImportProducts','configured',NULL),(26,20,'OSCommerce_ImportCustomers_5841','',0,0,'datasource',-1,'00:00',NULL,0,'OSCommerce\\ImportCustomers','configured',NULL),(27,20,'OSCommerce_ImportOrdersStatuses_8904','',0,0,'datasource',-1,'00:00',NULL,0,'OSCommerce\\ImportOrdersStatuses','configured',NULL),(28,20,'OSCommerce_ImportOrders_1836','',0,0,'datasource',-1,'00:00',NULL,0,'OSCommerce\\ImportOrders','configured',NULL),(29,20,'OSCommerce_ImportTaxZones_5446','',0,0,'datasource',-1,'00:00',NULL,0,'OSCommerce\\ImportTaxZones','configured',NULL),(83,20,'OSCommerce_ImportTax_7512','',0,0,'datasource',-1,'00:00',NULL,0,'OSCommerce\\ImportTax','configured',NULL);
/*!40000 ALTER TABLE `ep_job` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_log_messages`
--

DROP TABLE IF EXISTS `ep_log_messages`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_log_messages` (
  `ep_log_message_id` int(11) NOT NULL AUTO_INCREMENT,
  `job_id` int(11) NOT NULL DEFAULT '0',
  `message_time` datetime DEFAULT NULL,
  `message_text` varchar(1024) NOT NULL DEFAULT '',
  PRIMARY KEY (`ep_log_message_id`),
  KEY `job_id` (`job_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1445 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_log_messages`
--

LOCK TABLES `ep_log_messages` WRITE;
/*!40000 ALTER TABLE `ep_log_messages` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_log_messages` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_order_issues`
--

DROP TABLE IF EXISTS `ep_order_issues`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_order_issues` (
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `status` int(11) NOT NULL DEFAULT '0',
  `ep_directory_id` int(11) NOT NULL DEFAULT '0',
  `date_added` datetime DEFAULT NULL,
  `issue_text` varchar(1024) NOT NULL DEFAULT '',
  UNIQUE KEY `orders_id` (`orders_id`,`ep_directory_id`,`date_added`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_order_issues`
--

LOCK TABLES `ep_order_issues` WRITE;
/*!40000 ALTER TABLE `ep_order_issues` DISABLE KEYS */;
/*!40000 ALTER TABLE `ep_order_issues` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ep_profiles`
--

DROP TABLE IF EXISTS `ep_profiles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ep_profiles` (
  `ep_direction` enum('import','export') DEFAULT NULL,
  `ep_type` varchar(32) NOT NULL DEFAULT '',
  `shop_field` varchar(64) NOT NULL DEFAULT '',
  `file_field` varchar(64) NOT NULL DEFAULT '',
  KEY `ep_direction` (`ep_direction`,`ep_type`(4))
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ep_profiles`
--

LOCK TABLES `ep_profiles` WRITE;
/*!40000 ALTER TABLE `ep_profiles` DISABLE KEYS */;
INSERT INTO `ep_profiles` VALUES ('export','products','products_model',''),('export','categories','key_field',''),('export','categories','categories_old_seo_page_name',''),('export','categories','categories_name_en_0',''),('export','categories','categories_seo_page_name_en_0',''),('export','images','products_model',''),('export','images','products_name',''),('export','images','default_image',''),('export','images','image_status',''),('export','images','sort_order',''),('export','images','image_title_main',''),('export','images','image_alt_main',''),('export','images','orig_file_name_main',''),('export','images','alt_file_name_main',''),('export','images','image_title_en',''),('export','images','image_alt_en',''),('export','images','orig_file_name_en',''),('export','images','alt_file_name_en',''),('export','images','image_title_nl',''),('export','images','image_alt_nl',''),('export','images','orig_file_name_nl',''),('export','images','alt_file_name_nl',''),('export','images','products_ean',''),('export','images','products_asin',''),('export','images','products_isbn',''),('export','products_to_categories','',''),('export','inventory','products_id',''),('export','inventory','products_name',''),('export','inventory','products_quantity',''),('export','inventory','products_model',''),('export','inventory','products_ean',''),('export','inventory','products_upc',''),('export','inventory','products_asin',''),('export','inventory','products_isbn',''),('export','inventory','non_existent',''),('export','inventory','inventory_price_0',''),('export','inventory','inventory_group_price_2',''),('export','inventory','inventory_group_price_1',''),('export','properties','',''),('export','attributes','products_model',''),('export','attributes','products_attributes_weight',''),('export','catalog_properties','key_field',''),('export','catalog_properties','properties_name_en',''),('export','catalog_properties','value_en',''),('export','catalog_properties','properties_type',''),('export','catalog_properties','sort_order',''),('export','catalog_properties','multi_choice',''),('export','catalog_properties','multi_line',''),('export','catalog_properties','decimals',''),('export','catalog_properties','display_product',''),('export','catalog_properties','display_listing',''),('export','catalog_properties','display_filter',''),('export','catalog_properties','display_search',''),('export','catalog_properties','display_compare',''),('export','catalog_properties','properties_description_en_0',''),('export','catalog_properties','properties_units_id_en_0',''),('export','products','products_tax_class_id',''),('export','products','products_quantity',''),('export','products','products_weight',''),('export','products','sort_order',''),('export','products','products_date_available',''),('export','products','products_ean',''),('export','products','products_asin',''),('export','products','products_isbn',''),('export','products','order_quantity_minimal',''),('export','products','order_quantity_step',''),('export','products','products_status',''),('export','products','manufacturers_id',''),('export','products','products_price_0',''),('export','products','products_price_discount_0',''),('export','products','products_price_2',''),('export','products','products_price_discount_2',''),('export','products','products_price_1',''),('export','products','products_price_discount_1',''),('export','products','products_name_en_0',''),('export','products','products_description_short_en_0',''),('export','products','products_description_en_0',''),('export','products','products_url_en_0',''),('export','products','products_head_title_tag_en_0',''),('export','products','products_head_desc_tag_en_0',''),('export','products','products_head_keywords_tag_en_0',''),('export','products','products_self_service_en_0',''),('export','products','products_seo_page_name_en_0',''),('export','products','products_name_nl_0',''),('export','products','products_description_short_nl_0',''),('export','products','products_description_nl_0',''),('export','products','products_url_nl_0',''),('export','products','products_head_title_tag_nl_0',''),('export','products','products_head_desc_tag_nl_0',''),('export','products','products_head_keywords_tag_nl_0',''),('export','products','products_self_service_nl_0',''),('export','products','products_seo_page_name_nl_0',''),('export','products','products_name_de_0',''),('export','products','products_description_short_de_0',''),('export','products','products_description_de_0',''),('export','products','products_url_de_0',''),('export','products','products_head_title_tag_de_0',''),('export','products','products_head_desc_tag_de_0',''),('export','products','products_head_keywords_tag_de_0',''),('export','products','products_self_service_de_0',''),('export','products','products_seo_page_name_de_0',''),('export','products','products_name_fr_0',''),('export','products','products_description_short_fr_0',''),('export','products','products_description_fr_0',''),('export','products','products_url_fr_0',''),('export','products','products_head_title_tag_fr_0',''),('export','products','products_head_desc_tag_fr_0',''),('export','products','products_head_keywords_tag_fr_0',''),('export','products','products_self_service_fr_0',''),('export','products','products_seo_page_name_fr_0',''),('export','products','products_name_no_0',''),('export','products','products_description_short_no_0',''),('export','products','products_description_no_0',''),('export','products','products_url_no_0',''),('export','products','products_head_title_tag_no_0',''),('export','products','products_head_desc_tag_no_0',''),('export','products','products_head_keywords_tag_no_0',''),('export','products','products_self_service_no_0',''),('export','products','products_seo_page_name_no_0',''),('export','products','products_name_it_0',''),('export','products','products_description_short_it_0',''),('export','products','products_description_it_0',''),('export','products','products_url_it_0',''),('export','products','products_head_title_tag_it_0',''),('export','products','products_head_desc_tag_it_0',''),('export','products','products_head_keywords_tag_it_0',''),('export','products','products_self_service_it_0',''),('export','products','products_seo_page_name_it_0',''),('export','products','products_name_ua_0',''),('export','products','products_description_short_ua_0',''),('export','products','products_description_ua_0',''),('export','products','products_url_ua_0',''),('export','products','products_head_title_tag_ua_0',''),('export','products','products_head_desc_tag_ua_0',''),('export','products','products_head_keywords_tag_ua_0',''),('export','products','products_self_service_ua_0',''),('export','products','products_seo_page_name_ua_0',''),('export','products','products_name_ru_0',''),('export','products','products_description_short_ru_0',''),('export','products','products_description_ru_0',''),('export','products','products_url_ru_0',''),('export','products','products_head_title_tag_ru_0',''),('export','products','products_head_desc_tag_ru_0',''),('export','products','products_head_keywords_tag_ru_0',''),('export','products','products_self_service_ru_0',''),('export','products','products_seo_page_name_ru_0',''),('export','products','_categories_0',''),('export','products','_categories_1',''),('export','products','_categories_2',''),('export','products','_categories_3',''),('export','products','_categories_4',''),('export','products','_categories_5',''),('export','products','_categories_6',''),('export','categories','categories_image',''),('export','categories','sort_order',''),('export','categories','categories_status',''),('export','categories','categories_description_en_0',''),('export','categories','categories_head_title_tag_en_0',''),('export','categories','categories_head_keywords_tag_en_0',''),('export','categories','categories_head_desc_tag_en_0',''),('export','categories','categories_name_nl_0',''),('export','categories','categories_seo_page_name_nl_0',''),('export','categories','categories_description_nl_0',''),('export','categories','categories_head_title_tag_nl_0',''),('export','categories','categories_head_keywords_tag_nl_0',''),('export','categories','categories_head_desc_tag_nl_0',''),('export','categories','categories_name_de_0',''),('export','categories','categories_seo_page_name_de_0',''),('export','categories','categories_description_de_0',''),('export','categories','categories_head_title_tag_de_0',''),('export','categories','categories_head_keywords_tag_de_0',''),('export','categories','categories_head_desc_tag_de_0',''),('export','categories','categories_name_fr_0',''),('export','categories','categories_seo_page_name_fr_0',''),('export','categories','categories_description_fr_0',''),('export','categories','categories_head_title_tag_fr_0',''),('export','categories','categories_head_keywords_tag_fr_0',''),('export','categories','categories_head_desc_tag_fr_0',''),('export','categories','categories_name_no_0',''),('export','categories','categories_seo_page_name_no_0',''),('export','categories','categories_description_no_0',''),('export','categories','categories_head_title_tag_no_0',''),('export','categories','categories_head_keywords_tag_no_0',''),('export','categories','categories_head_desc_tag_no_0',''),('export','categories','categories_name_it_0',''),('export','categories','categories_seo_page_name_it_0',''),('export','categories','categories_description_it_0',''),('export','categories','categories_head_title_tag_it_0',''),('export','categories','categories_head_keywords_tag_it_0',''),('export','categories','categories_head_desc_tag_it_0',''),('export','categories','categories_name_ua_0',''),('export','categories','categories_seo_page_name_ua_0',''),('export','categories','categories_description_ua_0',''),('export','categories','categories_head_title_tag_ua_0',''),('export','categories','categories_head_keywords_tag_ua_0',''),('export','categories','categories_head_desc_tag_ua_0',''),('export','categories','categories_name_ru_0',''),('export','categories','categories_seo_page_name_ru_0',''),('export','categories','categories_description_ru_0',''),('export','categories','categories_head_title_tag_ru_0',''),('export','categories','categories_head_keywords_tag_ru_0',''),('export','categories','categories_head_desc_tag_ru_0',''),('export','attributes','products_options_name_en',''),('export','attributes','products_options_values_name_en',''),('export','attributes','products_options_name_nl',''),('export','attributes','products_options_values_name_nl',''),('export','attributes','products_options_name_de',''),('export','attributes','products_options_values_name_de',''),('export','attributes','products_options_name_fr',''),('export','attributes','products_options_values_name_fr',''),('export','attributes','products_options_name_no',''),('export','attributes','products_options_values_name_no',''),('export','attributes','products_options_name_it',''),('export','attributes','products_options_values_name_it',''),('export','attributes','products_options_name_ua',''),('export','attributes','products_options_values_name_ua',''),('export','attributes','products_options_name_ru',''),('export','attributes','products_options_values_name_ru',''),('export','attributes','price_prefix',''),('export','attributes','options_values_price_0',''),('export','attributes','attributes_group_price_0_2',''),('export','attributes','attributes_group_price_0_1',''),('export','attributes','products_attributes_weight_prefix',''),('export','images','image_title_de',''),('export','images','image_alt_de',''),('export','images','orig_file_name_de',''),('export','images','alt_file_name_de',''),('export','images','image_title_fr',''),('export','images','image_alt_fr',''),('export','images','orig_file_name_fr',''),('export','images','alt_file_name_fr',''),('export','images','image_title_no',''),('export','images','image_alt_no',''),('export','images','orig_file_name_no',''),('export','images','alt_file_name_no',''),('export','images','image_title_it',''),('export','images','image_alt_it',''),('export','images','orig_file_name_it',''),('export','images','alt_file_name_it',''),('export','images','image_title_ua',''),('export','images','image_alt_ua',''),('export','images','orig_file_name_ua',''),('export','images','alt_file_name_ua',''),('export','images','image_title_ru',''),('export','images','image_alt_ru',''),('export','images','orig_file_name_ru',''),('export','images','alt_file_name_ru',''),('export','catalog_properties','properties_name_nl',''),('export','catalog_properties','value_nl',''),('export','catalog_properties','properties_name_de',''),('export','catalog_properties','value_de',''),('export','catalog_properties','properties_name_fr',''),('export','catalog_properties','value_fr',''),('export','catalog_properties','properties_name_no',''),('export','catalog_properties','value_no',''),('export','catalog_properties','properties_name_it',''),('export','catalog_properties','value_it',''),('export','catalog_properties','properties_name_ua',''),('export','catalog_properties','value_ua',''),('export','catalog_properties','properties_name_ru',''),('export','catalog_properties','value_ru',''),('export','catalog_properties','properties_description_nl_0',''),('export','catalog_properties','properties_units_id_nl_0',''),('export','catalog_properties','properties_description_de_0',''),('export','catalog_properties','properties_units_id_de_0',''),('export','catalog_properties','properties_description_fr_0',''),('export','catalog_properties','properties_units_id_fr_0',''),('export','catalog_properties','properties_description_no_0',''),('export','catalog_properties','properties_units_id_no_0',''),('export','catalog_properties','properties_description_it_0',''),('export','catalog_properties','properties_units_id_it_0',''),('export','catalog_properties','properties_description_ua_0',''),('export','catalog_properties','properties_units_id_ua_0',''),('export','catalog_properties','properties_description_ru_0',''),('export','catalog_properties','properties_units_id_ru_0','');
/*!40000 ALTER TABLE `ep_profiles` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `exclusion_devices`
--

DROP TABLE IF EXISTS `exclusion_devices`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `exclusion_devices` (
  `device_id` varchar(40) NOT NULL,
  `date_add` datetime DEFAULT NULL,
  PRIMARY KEY (`device_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `exclusion_devices`
--

LOCK TABLES `exclusion_devices` WRITE;
/*!40000 ALTER TABLE `exclusion_devices` DISABLE KEYS */;
/*!40000 ALTER TABLE `exclusion_devices` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `featured`
--

DROP TABLE IF EXISTS `featured`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `featured` (
  `featured_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` int(11) NOT NULL DEFAULT '0',
  `featured_date_added` datetime DEFAULT NULL,
  `featured_last_modified` datetime DEFAULT NULL,
  `expires_date` datetime DEFAULT NULL,
  `date_status_change` datetime DEFAULT NULL,
  `status` int(1) DEFAULT '1',
  `affiliate_id` int(11) NOT NULL DEFAULT '0',
  `featured_type_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `start_date` datetime DEFAULT NULL,
  PRIMARY KEY (`featured_id`),
  KEY `expires_date` (`expires_date`),
  KEY `idx_status_expire` (`status`,`expires_date`),
  KEY `idx_featured_type_id` (`featured_type_id`),
  KEY `idx_start_date` (`start_date`),
  KEY `idx_status_start_date` (`status`,`start_date`)
) ENGINE=InnoDB AUTO_INCREMENT=24 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `featured`
--

LOCK TABLES `featured` WRITE;
/*!40000 ALTER TABLE `featured` DISABLE KEYS */;
INSERT INTO `featured` VALUES (1,40,'2022-07-23 14:24:53','2022-07-25 11:16:14','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(2,52,'2022-07-23 14:25:18',NULL,'0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(3,54,'2022-07-23 14:43:56',NULL,'0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(4,68,'2022-07-23 14:44:33',NULL,'0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(5,69,'2022-07-23 14:44:48',NULL,'0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(6,59,'2022-07-23 14:45:08',NULL,'0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(7,56,'2022-07-23 14:45:27','2022-07-23 14:45:53','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(8,9,'2022-07-23 15:19:45',NULL,'0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(9,13,'2022-07-23 15:20:26','2022-07-25 12:08:47','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(10,16,'2022-07-23 15:20:39','2022-07-25 12:22:36','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(11,18,'2022-07-23 15:20:51',NULL,'0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(12,2,'2022-07-23 15:21:48',NULL,'0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(13,21,'2022-07-23 15:22:06','2022-07-25 12:17:51','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(14,33,'2022-07-23 15:23:42','2022-07-25 12:36:32','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(15,32,'2022-07-23 15:25:02','2022-07-25 12:45:27','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(16,35,'2022-07-23 15:25:13','2022-07-25 13:02:21','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(17,37,'2022-07-23 15:26:23','2022-07-25 12:53:54','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(18,36,'2022-07-23 15:26:48','2022-07-25 12:58:38','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(19,39,'2022-07-23 15:30:29','2022-07-25 11:20:19','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(20,42,'2022-07-23 15:31:26','2022-07-25 10:56:54','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(21,44,'2022-07-23 15:31:35','2022-07-25 10:50:13','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(22,48,'2022-07-23 15:32:36','2022-07-25 11:31:29','0000-00-00 00:00:00',NULL,1,0,0,0,NULL),(23,46,'2022-07-23 15:32:46','2022-07-25 11:37:40','0000-00-00 00:00:00',NULL,1,0,0,0,NULL);
/*!40000 ALTER TABLE `featured` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `featured_types`
--

DROP TABLE IF EXISTS `featured_types`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `featured_types` (
  `featured_type_id` int(11) NOT NULL,
  `language_id` int(11) NOT NULL,
  `featured_type_name` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`featured_type_id`,`language_id`),
  KEY `featured_type_name` (`featured_type_name`(8))
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `featured_types`
--

LOCK TABLES `featured_types` WRITE;
/*!40000 ALTER TABLE `featured_types` DISABLE KEYS */;
/*!40000 ALTER TABLE `featured_types` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `filters`
--

DROP TABLE IF EXISTS `filters`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `filters` (
  `filters_id` int(11) NOT NULL AUTO_INCREMENT,
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `manufacturers_id` int(11) NOT NULL DEFAULT '0',
  `filters_type` enum('keywords','price','category','brand','attribute','property') NOT NULL DEFAULT 'keywords',
  `options_id` int(11) NOT NULL DEFAULT '0',
  `properties_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) DEFAULT '0',
  `status` tinyint(1) DEFAULT '0',
  `filters_of` enum('category','brand') NOT NULL DEFAULT 'category',
  PRIMARY KEY (`filters_id`),
  KEY `idx_categories_id` (`categories_id`),
  KEY `idx_manufacturers_id` (`manufacturers_id`),
  KEY `idx_filters_of` (`filters_of`),
  KEY `idx_status` (`status`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `filters`
--

LOCK TABLES `filters` WRITE;
/*!40000 ALTER TABLE `filters` DISABLE KEYS */;
/*!40000 ALTER TABLE `filters` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `forbidden`
--

DROP TABLE IF EXISTS `forbidden`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `forbidden` (
  `forbidden_id` int(11) NOT NULL AUTO_INCREMENT,
  `forbidden_address` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`forbidden_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `forbidden`
--

LOCK TABLES `forbidden` WRITE;
/*!40000 ALTER TABLE `forbidden` DISABLE KEYS */;
/*!40000 ALTER TABLE `forbidden` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `fraud`
--

DROP TABLE IF EXISTS `fraud`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `fraud` (
  `fraud_address` varchar(64) NOT NULL,
  `fraud_date` datetime DEFAULT NULL,
  `fraud_counter` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`fraud_address`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `fraud`
--

LOCK TABLES `fraud` WRITE;
/*!40000 ALTER TABLE `fraud` DISABLE KEYS */;
/*!40000 ALTER TABLE `fraud` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ga`
--

DROP TABLE IF EXISTS `ga`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ga` (
  `ga_id` int(11) NOT NULL AUTO_INCREMENT,
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `utmgclid` varchar(100) NOT NULL DEFAULT '',
  `utmccn` varchar(255) NOT NULL DEFAULT '',
  `utmcmd` varchar(255) NOT NULL DEFAULT '',
  `utmctr` varchar(255) NOT NULL DEFAULT '',
  `utmcsr` varchar(100) NOT NULL DEFAULT '',
  `ip_address` varchar(15) NOT NULL DEFAULT '',
  `last_page_url` varchar(64) NOT NULL DEFAULT '',
  `http_referer` varchar(255) NOT NULL DEFAULT '',
  `user_agent` varchar(255) NOT NULL DEFAULT '',
  `resolution` varchar(15) NOT NULL DEFAULT '',
  `basket_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`ga_id`),
  KEY `orders_id` (`orders_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ga`
--

LOCK TABLES `ga` WRITE;
/*!40000 ALTER TABLE `ga` DISABLE KEYS */;
/*!40000 ALTER TABLE `ga` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `gdpr_check`
--

DROP TABLE IF EXISTS `gdpr_check`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `gdpr_check` (
  `customers_id` int(11) NOT NULL,
  `email` varchar(64) NOT NULL DEFAULT '',
  `date_send` date DEFAULT NULL,
  `token` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`customers_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `gdpr_check`
--

LOCK TABLES `gdpr_check` WRITE;
/*!40000 ALTER TABLE `gdpr_check` DISABLE KEYS */;
/*!40000 ALTER TABLE `gdpr_check` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `geo_zones`
--

DROP TABLE IF EXISTS `geo_zones`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `geo_zones` (
  `geo_zone_id` int(11) NOT NULL AUTO_INCREMENT,
  `geo_zone_name` varchar(32) NOT NULL DEFAULT '',
  `geo_zone_description` varchar(255) NOT NULL DEFAULT '',
  `last_modified` datetime DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  `billing_status` int(1) NOT NULL DEFAULT '1',
  `shipping_status` int(1) NOT NULL DEFAULT '1',
  `taxable` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`geo_zone_id`),
  KEY `idx_taxable_gz_id` (`taxable`,`geo_zone_id`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `geo_zones`
--

LOCK TABLES `geo_zones` WRITE;
/*!40000 ALTER TABLE `geo_zones` DISABLE KEYS */;
INSERT INTO `geo_zones` VALUES (1,'USA','USA','2005-01-10 21:39:04','2003-07-17 10:29:23',0,0,0),(4,'EU','EU','2017-01-23 09:25:50','2006-03-18 16:29:55',0,0,0),(5,'All World','',NULL,'2017-05-10 14:41:18',1,1,0);
/*!40000 ALTER TABLE `geo_zones` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `gift_wrap_products`
--

DROP TABLE IF EXISTS `gift_wrap_products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `gift_wrap_products` (
  `gw_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` int(11) NOT NULL DEFAULT '0',
  `groups_id` int(11) NOT NULL DEFAULT '0',
  `currencies_id` int(11) NOT NULL DEFAULT '0',
  `gift_wrap_price` decimal(15,2) NOT NULL DEFAULT '0.00',
  PRIMARY KEY (`gw_id`),
  UNIQUE KEY `products_id` (`products_id`,`groups_id`,`currencies_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `gift_wrap_products`
--

LOCK TABLES `gift_wrap_products` WRITE;
/*!40000 ALTER TABLE `gift_wrap_products` DISABLE KEYS */;
/*!40000 ALTER TABLE `gift_wrap_products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `give_away_products`
--

DROP TABLE IF EXISTS `give_away_products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `give_away_products` (
  `gap_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` int(11) NOT NULL DEFAULT '0',
  `groups_id` int(11) NOT NULL DEFAULT '0',
  `shopping_cart_price` decimal(15,2) NOT NULL DEFAULT '0.00',
  `begin_date` date NOT NULL DEFAULT '0000-00-00',
  `end_date` date NOT NULL DEFAULT '0000-00-00',
  `products_qty` int(11) NOT NULL DEFAULT '0',
  `buy_qty` int(11) NOT NULL DEFAULT '0',
  `use_in_qty_discount` tinyint(1) NOT NULL DEFAULT '0',
  `currencies_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`gap_id`),
  KEY `products_id` (`products_id`,`groups_id`),
  KEY `groups_id` (`groups_id`),
  KEY `buy_qty` (`buy_qty`),
  KEY `currencies_id` (`currencies_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `give_away_products`
--

LOCK TABLES `give_away_products` WRITE;
/*!40000 ALTER TABLE `give_away_products` DISABLE KEYS */;
/*!40000 ALTER TABLE `give_away_products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `global_payments_transactions`
--

DROP TABLE IF EXISTS `global_payments_transactions`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `global_payments_transactions` (
  `transaction_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `srd` varchar(255) NOT NULL DEFAULT '',
  `store` varchar(50) NOT NULL DEFAULT '',
  `order_id` int(11) NOT NULL DEFAULT '0',
  `gp_order_id` varchar(255) NOT NULL DEFAULT '',
  `customer_id` int(11) NOT NULL DEFAULT '0',
  `amount` int(11) NOT NULL DEFAULT '0',
  `customer_name` varchar(255) NOT NULL DEFAULT '',
  `card_holder_name` varchar(255) NOT NULL DEFAULT '',
  `card_details` varchar(255) NOT NULL DEFAULT '',
  `card_type` varchar(50) NOT NULL DEFAULT '',
  `exp_date` varchar(10) NOT NULL DEFAULT '',
  `customer_ref` varchar(255) NOT NULL DEFAULT '',
  `card_ref` varchar(255) NOT NULL DEFAULT '',
  `code` varchar(2) NOT NULL DEFAULT '',
  `raw` text NOT NULL,
  PRIMARY KEY (`transaction_id`),
  KEY `customer_id_idx` (`customer_id`),
  KEY `order_id_idx` (`order_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `global_payments_transactions`
--

LOCK TABLES `global_payments_transactions` WRITE;
/*!40000 ALTER TABLE `global_payments_transactions` DISABLE KEYS */;
/*!40000 ALTER TABLE `global_payments_transactions` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `google_settings`
--

DROP TABLE IF EXISTS `google_settings`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `google_settings` (
  `google_settings_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `module` varchar(64) NOT NULL DEFAULT '',
  `status` tinyint(1) NOT NULL DEFAULT '0',
  `info` text,
  `module_name` varchar(128) NOT NULL DEFAULT '',
  PRIMARY KEY (`google_settings_id`),
  KEY `idx_platform_status_module` (`platform_id`,`status`,`module`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `google_settings`
--

LOCK TABLES `google_settings` WRITE;
/*!40000 ALTER TABLE `google_settings` DISABLE KEYS */;
/*!40000 ALTER TABLE `google_settings` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `groups`
--

DROP TABLE IF EXISTS `groups`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `groups` (
  `groups_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `groups_name` varchar(255) NOT NULL DEFAULT '',
  `groups_discount` decimal(12,2) NOT NULL DEFAULT '0.00',
  `groups_is_tax_applicable` smallint(1) NOT NULL DEFAULT '1',
  `groups_is_reseller` smallint(1) NOT NULL DEFAULT '0',
  `groups_disable_checkout` smallint(1) NOT NULL DEFAULT '0',
  `date_added` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `groups_is_show_price` tinyint(1) NOT NULL DEFAULT '1',
  `new_approve` tinyint(1) NOT NULL DEFAULT '0',
  `image_active` varchar(255) NOT NULL DEFAULT '',
  `image_inactive` varchar(255) NOT NULL DEFAULT '',
  `apply_groups_discount_to_specials` tinyint(1) NOT NULL DEFAULT '0',
  `disable_watermark` tinyint(1) NOT NULL DEFAULT '0',
  `groups_use_more_discount` tinyint(4) NOT NULL DEFAULT '0',
  `superdiscount_summ` decimal(15,2) NOT NULL DEFAULT '0.00',
  `bonus_points_currency_rate` decimal(8,5) NOT NULL DEFAULT '0.00000',
  `groups_disable_cart` int(1) NOT NULL DEFAULT '0',
  `groups_price_as_special` int(4) NOT NULL DEFAULT '0',
  `groups_commission` decimal(6,2) NOT NULL DEFAULT '0.00',
  `per_product_price` int(1) NOT NULL DEFAULT '1',
  `default_landing_page` varchar(255) NOT NULL DEFAULT '',
  `cart_for_logged_only` int(1) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`groups_id`),
  KEY `idx_per_product_price` (`per_product_price`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `groups`
--

LOCK TABLES `groups` WRITE;
/*!40000 ALTER TABLE `groups` DISABLE KEYS */;
INSERT INTO `groups` VALUES (1,'Basic',0.00,1,0,0,'2016-02-09 15:47:47','2018-01-24 13:12:19',1,0,'','',0,0,0,1000.00,0.00000,0,0,0.00,0,'',0,0),(2,'Advanced',10.00,1,1,0,'2016-02-10 12:49:29','2018-11-13 14:27:26',1,1,'','',0,0,0,0.00,0.00000,0,0,0.00,0,'',0,0);
/*!40000 ALTER TABLE `groups` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `groups_categories`
--

DROP TABLE IF EXISTS `groups_categories`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `groups_categories` (
  `groups_id` int(11) NOT NULL,
  `categories_id` int(11) NOT NULL,
  PRIMARY KEY (`groups_id`,`categories_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `groups_categories`
--

LOCK TABLES `groups_categories` WRITE;
/*!40000 ALTER TABLE `groups_categories` DISABLE KEYS */;
/*!40000 ALTER TABLE `groups_categories` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `groups_discounts`
--

DROP TABLE IF EXISTS `groups_discounts`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `groups_discounts` (
  `groups_discounts_id` int(11) NOT NULL AUTO_INCREMENT,
  `groups_id` int(11) NOT NULL DEFAULT '0',
  `groups_discounts_amount` decimal(15,2) NOT NULL DEFAULT '0.00',
  `groups_discounts_value` tinyint(4) NOT NULL DEFAULT '0',
  `check_supersum` tinyint(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`groups_discounts_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `groups_discounts`
--

LOCK TABLES `groups_discounts` WRITE;
/*!40000 ALTER TABLE `groups_discounts` DISABLE KEYS */;
/*!40000 ALTER TABLE `groups_discounts` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `guest_check`
--

DROP TABLE IF EXISTS `guest_check`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `guest_check` (
  `customers_id` int(11) NOT NULL,
  `email` varchar(64) NOT NULL DEFAULT '',
  `date_send` date DEFAULT NULL,
  `token` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`customers_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `guest_check`
--

LOCK TABLES `guest_check` WRITE;
/*!40000 ALTER TABLE `guest_check` DISABLE KEYS */;
/*!40000 ALTER TABLE `guest_check` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hooks`
--

DROP TABLE IF EXISTS `hooks`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hooks` (
  `hook_id` int(11) NOT NULL AUTO_INCREMENT,
  `page_name` varchar(64) NOT NULL DEFAULT '',
  `page_area` varchar(64) NOT NULL DEFAULT '',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `extension_name` varchar(64) NOT NULL DEFAULT '',
  `extension_file` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`hook_id`),
  UNIQUE KEY `idx_uniq` (`page_name`,`page_area`,`sort_order`,`extension_name`)
) ENGINE=InnoDB AUTO_INCREMENT=11 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hooks`
--

LOCK TABLES `hooks` WRITE;
/*!40000 ALTER TABLE `hooks` DISABLE KEYS */;
INSERT INTO `hooks` VALUES (1,'banner_manager/banneredit','',100,'UserGroups','[[softpath]]/lib/common/extensions/UserGroups/hooks/banner_manager.banneredit.php'),(2,'banner_manager/banneredit','platform-table-heading-cell',100,'UserGroups','[[softpath]]/lib/common/extensions/UserGroups/hooks/banner_manager.banneredit.platform-table-heading-cell.tpl'),(3,'banner_manager/banneredit','platform-table-cell',100,'UserGroups','[[softpath]]/lib/common/extensions/UserGroups/hooks/banner_manager.banneredit.platform-table-cell.tpl'),(4,'banner_manager/submit','',100,'UserGroups','[[softpath]]/lib/common/extensions/UserGroups/hooks/banner_manager.submit.php'),(5,'box/banner','',100,'UserGroups','[[softpath]]/lib/common/extensions/UserGroups/hooks/box.banner.php'),(6,'box/block/hide-widget','',100,'UserGroups','[[softpath]]/lib/common/extensions/UserGroups/hooks/box.block.hide-widget.php'),(7,'design/box-edit','hide-widget',100,'UserGroups','[[softpath]]/lib/common/extensions/UserGroups/hooks/design.box-edit.hide-widget.tpl'),(8,'categories/productedit','',100,'ProductTemplates','[[softpath]]/lib/common/extensions/ProductTemplates/hooks/categories.productedit.php'),(9,'categories/productedit','details-right-column',100,'ProductTemplates','[[softpath]]/lib/common/extensions/ProductTemplates/hooks/categories.productedit.details-right-column.tpl'),(10,'categories/productedit-beforesave','',100,'StockControl','[[softpath]]/lib/common/extensions/StockControl/hooks/categories.productedit-beforesave.php');
/*!40000 ALTER TABLE `hooks` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `image_cache_keys`
--

DROP TABLE IF EXISTS `image_cache_keys`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `image_cache_keys` (
  `external_key` char(16) NOT NULL DEFAULT '',
  `internal_key` char(32) NOT NULL DEFAULT '',
  `is_valid` tinyint(1) NOT NULL DEFAULT '1',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `image_size` varchar(16) NOT NULL DEFAULT '',
  `watermark_image` text,
  `watermark_mtime` int(11) unsigned NOT NULL DEFAULT '0',
  `extra_params` varchar(255) NOT NULL DEFAULT '',
  UNIQUE KEY `external_key` (`external_key`),
  KEY `internal_key` (`internal_key`,`is_valid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `image_cache_keys`
--

LOCK TABLES `image_cache_keys` WRITE;
/*!40000 ALTER TABLE `image_cache_keys` DISABLE KEYS */;
/*!40000 ALTER TABLE `image_cache_keys` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `image_copy_reference`
--

DROP TABLE IF EXISTS `image_copy_reference`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `image_copy_reference` (
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `products_id` int(11) NOT NULL DEFAULT '0',
  `products_image_id` int(11) NOT NULL DEFAULT '0',
  `filename` varchar(2048) NOT NULL DEFAULT '',
  `date_added` datetime DEFAULT NULL,
  `clean_flag` tinyint(1) NOT NULL DEFAULT '0',
  KEY `platform_id` (`platform_id`),
  KEY `products_id` (`products_id`),
  KEY `clean_flag` (`clean_flag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `image_copy_reference`
--

LOCK TABLES `image_copy_reference` WRITE;
/*!40000 ALTER TABLE `image_copy_reference` DISABLE KEYS */;
/*!40000 ALTER TABLE `image_copy_reference` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `image_types`
--

DROP TABLE IF EXISTS `image_types`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `image_types` (
  `image_types_id` int(11) NOT NULL AUTO_INCREMENT,
  `image_types_name` varchar(32) NOT NULL DEFAULT '',
  `image_types_x` int(11) NOT NULL DEFAULT '0',
  `image_types_y` int(11) NOT NULL DEFAULT '0',
  `width_from` int(11) NOT NULL DEFAULT '0',
  `width_to` int(11) NOT NULL DEFAULT '0',
  `parent_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`image_types_id`)
) ENGINE=InnoDB AUTO_INCREMENT=12 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `image_types`
--

LOCK TABLES `image_types` WRITE;
/*!40000 ALTER TABLE `image_types` DISABLE KEYS */;
INSERT INTO `image_types` VALUES (1,'Thumbnail',50,50,0,0,0),(2,'Small',210,210,0,0,0),(3,'Medium',600,600,0,0,0),(4,'Large',800,800,0,0,0),(5,'Category gallery',300,300,0,0,0),(6,'Category hero',1250,500,0,0,0),(7,'Category homepage',300,300,0,0,0),(8,'Brand gallery',300,300,0,0,0),(9,'Brand hero',1250,500,0,0,0),(10,'Category gallery add',250,250,0,0,0),(11,'Category menu',300,300,1,0,0);
/*!40000 ALTER TABLE `image_types` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `index_cache`
--

DROP TABLE IF EXISTS `index_cache`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `index_cache` (
  `icTable` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `icKey` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `icColumn` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `icLength` int(10) NOT NULL,
  `icOrder` int(10) NOT NULL,
  `icUnique` tinyint(1) NOT NULL,
  `icDateInsert` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`icTable`,`icKey`,`icColumn`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `index_cache`
--

LOCK TABLES `index_cache` WRITE;
/*!40000 ALTER TABLE `index_cache` DISABLE KEYS */;
/*!40000 ALTER TABLE `index_cache` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `information`
--

DROP TABLE IF EXISTS `information`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `information` (
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `information_id` int(11) NOT NULL AUTO_INCREMENT,
  `visible` enum('1','0') NOT NULL DEFAULT '1',
  `v_order` tinyint(3) unsigned NOT NULL DEFAULT '0',
  `info_title` varchar(255) NOT NULL DEFAULT '',
  `description` text NOT NULL,
  `languages_id` int(11) NOT NULL DEFAULT '0',
  `page_title` varchar(255) NOT NULL DEFAULT '',
  `meta_title` varchar(255) NOT NULL DEFAULT '',
  `page` varchar(255) NOT NULL DEFAULT '',
  `scope` set('header','infobox','footer') NOT NULL DEFAULT 'header',
  `affiliate_id` int(11) NOT NULL DEFAULT '0',
  `page_type` varchar(6) NOT NULL DEFAULT 'NONSSL',
  `meta_description` tinytext,
  `meta_key` tinytext,
  `seo_page_name` varchar(128) NOT NULL DEFAULT '',
  `old_seo_page_name` varchar(128) NOT NULL DEFAULT '',
  `date_added` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `no_logged` tinyint(1) NOT NULL DEFAULT '0',
  `hide` tinyint(1) NOT NULL DEFAULT '0',
  `template_name` varchar(256) NOT NULL DEFAULT '',
  `noindex_option` int(11) NOT NULL DEFAULT '0',
  `nofollow_option` int(11) NOT NULL DEFAULT '0',
  `rel_canonical` varchar(128) NOT NULL DEFAULT '',
  `information_h1_tag` varchar(255) NOT NULL DEFAULT '',
  `information_h2_tag` text NOT NULL,
  `information_h3_tag` text NOT NULL,
  `description_short` text NOT NULL,
  `type` tinyint(3) unsigned NOT NULL DEFAULT '0',
  `image` varchar(255) NOT NULL DEFAULT '',
  `maps_id` int(11) NOT NULL DEFAULT '0',
  `hide_on_xml` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`information_id`,`platform_id`,`languages_id`,`affiliate_id`)
) ENGINE=InnoDB AUTO_INCREMENT=45 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `information`
--

LOCK TABLES `information` WRITE;
/*!40000 ALTER TABLE `information` DISABLE KEYS */;
INSERT INTO `information` VALUES (1,9,'1',6,'Terms & Conditions','<p>Unless a special agreement is signed between Holbi and its client, these terms and conditions are applicable to and work and communications that we carry out for our client. All occurrences of words &ldquo;we&rdquo;, &ldquo;us&rdquo;, &ldquo;our&rdquo; mean Holbi, when all occurrences of &ldquo;you&rdquo;, &ldquo;your&rdquo; mean you, our client.</p>\r\n\r\n<p>1 ACCEPTANCE OF TERMS</p>\r\n\r\n<p>1.1 Your access to and use of&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;(&ldquo;the Website&rdquo;) and any Services referred to in Clause 2, is subject exclusively to these Terms and Conditions. You will not use the Website/Services for any purpose that is unlawful or prohibited by these Terms and Conditions. By using the Website/Services you are fully accepting the terms, conditions and disclaimers contained in this notice. If you do not accept these Terms and Conditions you must immediately stop using the Website/Services.</p>\r\n\r\n<p>1.2 We reserve the right to update or amend these Terms and Conditions at any time and your continued use of the Website/Services following any changes shall be deemed to be your acceptance of such change. It is therefore your responsibility to check the Terms and Conditions regularly for any changes.</p>\r\n\r\n<p>2 THE SERVICES</p>\r\n\r\n<p>The Website provides music and video download and streaming services (&ldquo;the Services&rdquo;) designed to enable you to purchase legal online music with others. Unless stated otherwise the Services are for your personal and non-commercial use only. You hereby accept that your computer meets the minimum technical requirements for the Services as stated clearly on the Website. The Services are for your own personal use and you are not authorised to make any copies of any downloads other than for personal use.</p>\r\n\r\n<p>3 CHILD SUPERVISION</p>\r\n\r\n<p>We are concerned about the safety and privacy of our users, particularly children. Parents who wish to allow their children access to and use of the Website/Services should supervise such access and use. By allowing your child access to the Services you are allowing your child access to all of the Services. It is therefore your responsibility to determine which Services are appropriate for your child. Always use caution when revealing personally identifiable information about yourself or your children via any of the Services.</p>\r\n\r\n<p>4 PRIVACY POLICY</p>\r\n\r\n<p>4.1 We are committed to responsible data management and subscribe to the principals of the data protection legislation in the United Kingdom. We are committed to maintaining the privacy of our users and maintaining the security of any personal information received from you. If you register for any of the Services you will be asked to provide basic personal information. The information provided by you is not available for sale or use by third parties. The information is used solely for notifying you of changes or updates to the Website/Services.</p>\r\n\r\n<p>4.2 We may use a technology called &ldquo;cookies&rdquo; as part of our normal business procedure to track patterns of behaviour of visitors to the Website. A cookie is an element of data that the Website sends to your browser that is then stored on your system. You can set your browser to prevent this happening. Any information collected in this way can be used to identify you unless you change your browser settings.</p>\r\n\r\n<p>5 USER ACCOUNT, PASSWORD AND SECURITY</p>\r\n\r\n<p>If a particular Service requires you to open an account you will be required to complete the registration process by providing certain information and registering a username and password for use with that Service. You are responsible for maintaining the confidentiality of the username and password and also for all activities which take place under your account. You agree to immediately notify us of any unauthorised use of your password or account or any other breach of security. In no event will&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;be liable for any indirect or consequential loss or damage whatsoever resulting from the disclosure of your username and/or password. You may not use another person&rsquo;s account at any time, without the express permission of the account holder.</p>\r\n\r\n<p>6 ACCEPTABLE USE</p>\r\n\r\n<p>6.1 You acknowledge that all information, text, graphics, logos, photographs, images, moving images, sound, illustrations and other materials (&ldquo;the Content&rdquo;), whether posted publicly or transmitted privately, are the sole responsibility of the person from whom such Content originated. We do not control or endorse the Content and cannot guarantee the accuracy, integrity or quality of such Content and you acknowledge that by using the Services you may be exposed to Content that is offensive and/or indecent.&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;will not be liable in any way for any Content or for any loss or damage of any kind resulting from the use of any Content transmitted via the Services and you agree to bear all risks associated with the use of any Content, including any reliance on the accuracy or completeness of such Content.</p>\r\n\r\n<p>6.2 In using the Website/Services you agree not to:</p>\r\n\r\n<p>6.2.1 use the Services to send junk email, spam, chain letters, pyramid schemes or any other unsolicited messages, commercial or otherwise;</p>\r\n\r\n<p>6.2.2 post, publish, distribute or disseminate material or information that is defamatory, infringing, obscene, indecent, threatening, abusive, harassing or unlawful;</p>\r\n\r\n<p>6.2.3 post, publish, distribute or disseminate material or information that incites discrimination, hate or violence towards any person or group on account of their race, religion, disability, nationality or otherwise;</p>\r\n\r\n<p>6.2.4 threaten, abuse, disrupt, stalk or otherwise violate the legal rights (including rights of privacy and publicity) of others;</p>\r\n\r\n<p>6.2.5 use any information or material in any manner that infringes any copyright, trademark, patent or other proprietary right of any party;</p>\r\n\r\n<p>6.2.6 make available or upload files that contain a virus, worm, trojan or corrupt data that may damage the operation of the computer or property of another;</p>\r\n\r\n<p>6.2.7 collect or store personal information about others, including email addresses;</p>\r\n\r\n<p>6.2.8 advertise or offer to buy or sell goods or services for any commercial purpose, unless such communication facility specifically allows such messages;</p>\r\n\r\n<p>6.2.9 impersonate any person or entity for the purpose of misleading others;</p>\r\n\r\n<p>6.2.10 violate any applicable laws or regulations;</p>\r\n\r\n<p>6.2.11 use the Website/Services in any manner that could damage, disable, overburden or impair the Website/Services or interfere with any other party&rsquo;s use and enjoyment of the Website/Services;</p>\r\n\r\n<p>6.2.12 post, publish, distribute or disseminate material or information that you do not have a right to transmit under any law or under contractual or fiduciary relationships (such as inside information or confidential information disclosed in the course of employment or under a confidentiality agreement);</p>\r\n\r\n<p>6.2.13 attempt to gain unauthorised access to any of the Services, other accounts, computer systems or networks connected to the Website/Services through hacking, password mining or any other means.</p>\r\n\r\n<p>6.3 We have no obligation to monitor the Services but shall be entitled to review materials posted to a communications facility and, at our sole discretion, to remove any material that breaches these Terms and Conditions or is otherwise objectionable.</p>\r\n\r\n<p>7 TERMINATION</p>\r\n\r\n<p>We have the right to terminate your access to any or all of the Services at any time, without notice, for any reason, including without limitation, breach of these Terms and Conditions. We may also at any time, at our sole discretion, discontinue the Website/Services or any part thereof without prior notice and you agree that we shall not be liable to you or any third party for any termination of your access to the Website/Services.</p>\r\n\r\n<p>In case you are using any of our SaaS (software as a service) solutions and wish to terminate the use of such service we will be unable to refund any set up fees you might have paid to have your account(s) set up and configured.</p>\r\n\r\n<p>8 LINKS TO THIRD PARTY WEBSITES</p>\r\n\r\n<p>The Website/Services may include links to third party websites that are controlled and maintained by others. Any link to other websites is not an endorsement of such websites and you acknowledge and agree that&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;is not responsible for the content or availability of any such sites.</p>\r\n\r\n<p>9 INTERNATIONAL USE</p>\r\n\r\n<p>You agree to comply with all applicable laws regarding the transmission of technical data exported from the United Kingdom or the country in which you reside (if different) and with all local laws and rules regarding acceptable use of and conduct on the Internet.</p>\r\n\r\n<p>10 INTELLECTUAL PROPERTY RIGHTS</p>\r\n\r\n<p>10.1 The Website and its content (including without limitation the Website design, text, graphics and all software and source codes connected with the Website and the Services) are protected by copyright, trade marks, patents and other intellectual property rights and laws. In accessing the Website you agree that you will access the contents solely for your personal, non-commercial use. None of the content may be downloaded, copied, reproduced, transmitted, stored, sold or distributed without the prior written consent of the copyright holder. This excludes the downloading, copying and/or printing of pages of the Website for personal, non-commercial or home use only.</p>\r\n\r\n<p>10.2&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;does not claim ownership of any materials you post, upload or submit to any publicly accessible area of the Services. However, by doing so you are granting us a world-wide, royalty free, non-exclusive licence to copy, distribute, transmit, reproduce, publicly display, edit, translate or publish such Content for as long as you elect to display such Content via the Services. The licence shall be terminated when such Content is deleted from the Services.</p>\r\n\r\n<p>11 INDEMNITY</p>\r\n\r\n<p>You agree to indemnify and hold&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;harmless from and against any breach by you of these Terms and Conditions and any claim or demand brought against&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;by any third party arising out of your use of the Services and/or any Content submitted, posted or transmitted through the Services, including without limitation, all claims, actions, proceedings, losses, liabilities, damages, costs, expenses (including reasonable legal costs and expenses) howsoever suffered or incurred by&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;in consequence of your breach of these Terms and Conditions.</p>\r\n\r\n<p>12 DISCLAIMERS AND LIMITATION OF LIABILITY</p>\r\n\r\n<p>12.1 Use of the Website/Services is at your own risk. The Website/Services are provided on an &ldquo;AS IS&rdquo; and &ldquo;AS AVAILABLE&rdquo; basis without any representation or endorsement made and without warranty of any kind whether express or implied, including but not limited to the implied warranties of satisfactory quality, fitness for a particular purpose, non-infringement, compatibility, security and accuracy.</p>\r\n\r\n<p>12.2 To the extent permitted by law,&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;will not be liable for any indirect or consequential loss or damage whatsoever (including without limitation loss of business, opportunity, data, profits) arising out of or in connection with the use of the Website/Services.</p>\r\n\r\n<p>12.3&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;makes no warranty that the Website/Services will meet your requirements, that Content will be accurate or reliable, that the functionality of the Website/Services will be uninterrupted or error free, that defects will be corrected or that the Website/Services or the server that makes them available are free of viruses or anything else which may be harmful or destructive.</p>\r\n\r\n<p>12.4 Nothing in these Terms and Conditions shall be construed so as to exclude or limit the liability of&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;for death or personal injury as a result of the negligence of&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>.</p>\r\n\r\n<p>12.5 Nothing in these Terms and Conditions shall affect your statutory rights as a consumer.</p>\r\n\r\n<p>13 PUBLIC OFFER OF HOLBI</p>\r\n\r\n<p>In case you as a Customer place an order with us&nbsp;<a href=\"https://www.holbi.co.uk/disclaimer/\" target=\"_self\">Our Public offer</a>&nbsp;terms and conditions apply.</p>\r\n\r\n<p>13.1 Paying for solutions and services online.</p>\r\n\r\n<p>We accept payments online via SagePay &ndash; a secure fully PCI DSS certified solution. Visa, Master Card and American Express are accepted. We accept payments in GBP, EUR and USD.</p>\r\n\r\n<p>Solutions and services are provided strictly to customers over 18 years of age.</p>\r\n\r\n<p>Delivery of solutions and services is performed via electronic means of communication. Web sites are uploaded to the designated web hosting accounts (or servers), configured and launched. Software solutions are provided as executable files and are configured and launched. No physical delivery option is available.</p>\r\n\r\n<p>No returns can be offered as no physical delivery takes place. Solutions and services are considered to be delivered once they have been uploaded to the designated web hosting accounts or servers.</p>\r\n\r\n<p>No refunds can be offered for completed and delivered solutions and services. No refunds can be offered once work commences on the whole project or one of its parts.</p>\r\n\r\n<p>Full cancellation can be offered as soon as the work has not commenced on the whole project or one of its parts.</p>\r\n\r\n<p>14 SEVERANCE</p>\r\n\r\n<p>If any of these Terms and Conditions should be determined to be invalid, illegal or unenforceable for any reason by any court of competent jurisdiction then such Term or Condition shall be severed and the remaining Terms and Conditions shall survive and remain in full force and effect and continue to be binding and enforceable.</p>\r\n\r\n<p>15 GOVERNING LAW</p>\r\n\r\n<p>These Terms and Conditions shall be governed by and construed in accordance with English law and you hereby submit to the exclusive jurisdiction of English courts.</p>',1,'Terms & Conditions','Terms and conditions','','header,infobox',0,'NONSSL','Write your terms and conditions for user&amp;#039;s trust using Ecommerce Platform: osCommerce by Holbi','','terms-conditions','','2015-02-10 00:00:00','2021-11-03 16:18:16',0,0,'',0,0,'','Terms and conditions osCommerce by Holbi','','','',0,'0',0,0),(1,9,'1',2,'Terms & conditions','',2,'Terms & conditions','','','header,infobox,footer',0,'NONSSL',NULL,NULL,'terms-conditions','','2015-02-10 00:00:00',NULL,0,0,'',0,0,'','','','','',0,'0',0,0),(7,9,'1',6,'Terms & Conditions','<p>Unless a special agreement is signed between Holbi and its client, these terms and conditions are applicable to and work and communications that we carry out for our client. All occurrences of words &ldquo;we&rdquo;, &ldquo;us&rdquo;, &ldquo;our&rdquo; mean Holbi, when all occurrences of &ldquo;you&rdquo;, &ldquo;your&rdquo; mean you, our client.</p>\r\n\r\n<p>1 ACCEPTANCE OF TERMS</p>\r\n\r\n<p>1.1 Your access to and use of&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;(&ldquo;the Website&rdquo;) and any Services referred to in Clause 2, is subject exclusively to these Terms and Conditions. You will not use the Website/Services for any purpose that is unlawful or prohibited by these Terms and Conditions. By using the Website/Services you are fully accepting the terms, conditions and disclaimers contained in this notice. If you do not accept these Terms and Conditions you must immediately stop using the Website/Services.</p>\r\n\r\n<p>1.2 We reserve the right to update or amend these Terms and Conditions at any time and your continued use of the Website/Services following any changes shall be deemed to be your acceptance of such change. It is therefore your responsibility to check the Terms and Conditions regularly for any changes.</p>\r\n\r\n<p>2 THE SERVICES</p>\r\n\r\n<p>The Website provides music and video download and streaming services (&ldquo;the Services&rdquo;) designed to enable you to purchase legal online music with others. Unless stated otherwise the Services are for your personal and non-commercial use only. You hereby accept that your computer meets the minimum technical requirements for the Services as stated clearly on the Website. The Services are for your own personal use and you are not authorised to make any copies of any downloads other than for personal use.</p>\r\n\r\n<p>3 CHILD SUPERVISION</p>\r\n\r\n<p>We are concerned about the safety and privacy of our users, particularly children. Parents who wish to allow their children access to and use of the Website/Services should supervise such access and use. By allowing your child access to the Services you are allowing your child access to all of the Services. It is therefore your responsibility to determine which Services are appropriate for your child. Always use caution when revealing personally identifiable information about yourself or your children via any of the Services.</p>\r\n\r\n<p>4 PRIVACY POLICY</p>\r\n\r\n<p>4.1 We are committed to responsible data management and subscribe to the principals of the data protection legislation in the United Kingdom. We are committed to maintaining the privacy of our users and maintaining the security of any personal information received from you. If you register for any of the Services you will be asked to provide basic personal information. The information provided by you is not available for sale or use by third parties. The information is used solely for notifying you of changes or updates to the Website/Services.</p>\r\n\r\n<p>4.2 We may use a technology called &ldquo;cookies&rdquo; as part of our normal business procedure to track patterns of behaviour of visitors to the Website. A cookie is an element of data that the Website sends to your browser that is then stored on your system. You can set your browser to prevent this happening. Any information collected in this way can be used to identify you unless you change your browser settings.</p>\r\n\r\n<p>5 USER ACCOUNT, PASSWORD AND SECURITY</p>\r\n\r\n<p>If a particular Service requires you to open an account you will be required to complete the registration process by providing certain information and registering a username and password for use with that Service. You are responsible for maintaining the confidentiality of the username and password and also for all activities which take place under your account. You agree to immediately notify us of any unauthorised use of your password or account or any other breach of security. In no event will&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;be liable for any indirect or consequential loss or damage whatsoever resulting from the disclosure of your username and/or password. You may not use another person&rsquo;s account at any time, without the express permission of the account holder.</p>\r\n\r\n<p>6 ACCEPTABLE USE</p>\r\n\r\n<p>6.1 You acknowledge that all information, text, graphics, logos, photographs, images, moving images, sound, illustrations and other materials (&ldquo;the Content&rdquo;), whether posted publicly or transmitted privately, are the sole responsibility of the person from whom such Content originated. We do not control or endorse the Content and cannot guarantee the accuracy, integrity or quality of such Content and you acknowledge that by using the Services you may be exposed to Content that is offensive and/or indecent.&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;will not be liable in any way for any Content or for any loss or damage of any kind resulting from the use of any Content transmitted via the Services and you agree to bear all risks associated with the use of any Content, including any reliance on the accuracy or completeness of such Content.</p>\r\n\r\n<p>6.2 In using the Website/Services you agree not to:</p>\r\n\r\n<p>6.2.1 use the Services to send junk email, spam, chain letters, pyramid schemes or any other unsolicited messages, commercial or otherwise;</p>\r\n\r\n<p>6.2.2 post, publish, distribute or disseminate material or information that is defamatory, infringing, obscene, indecent, threatening, abusive, harassing or unlawful;</p>\r\n\r\n<p>6.2.3 post, publish, distribute or disseminate material or information that incites discrimination, hate or violence towards any person or group on account of their race, religion, disability, nationality or otherwise;</p>\r\n\r\n<p>6.2.4 threaten, abuse, disrupt, stalk or otherwise violate the legal rights (including rights of privacy and publicity) of others;</p>\r\n\r\n<p>6.2.5 use any information or material in any manner that infringes any copyright, trademark, patent or other proprietary right of any party;</p>\r\n\r\n<p>6.2.6 make available or upload files that contain a virus, worm, trojan or corrupt data that may damage the operation of the computer or property of another;</p>\r\n\r\n<p>6.2.7 collect or store personal information about others, including email addresses;</p>\r\n\r\n<p>6.2.8 advertise or offer to buy or sell goods or services for any commercial purpose, unless such communication facility specifically allows such messages;</p>\r\n\r\n<p>6.2.9 impersonate any person or entity for the purpose of misleading others;</p>\r\n\r\n<p>6.2.10 violate any applicable laws or regulations;</p>\r\n\r\n<p>6.2.11 use the Website/Services in any manner that could damage, disable, overburden or impair the Website/Services or interfere with any other party&rsquo;s use and enjoyment of the Website/Services;</p>\r\n\r\n<p>6.2.12 post, publish, distribute or disseminate material or information that you do not have a right to transmit under any law or under contractual or fiduciary relationships (such as inside information or confidential information disclosed in the course of employment or under a confidentiality agreement);</p>\r\n\r\n<p>6.2.13 attempt to gain unauthorised access to any of the Services, other accounts, computer systems or networks connected to the Website/Services through hacking, password mining or any other means.</p>\r\n\r\n<p>6.3 We have no obligation to monitor the Services but shall be entitled to review materials posted to a communications facility and, at our sole discretion, to remove any material that breaches these Terms and Conditions or is otherwise objectionable.</p>\r\n\r\n<p>7 TERMINATION</p>\r\n\r\n<p>We have the right to terminate your access to any or all of the Services at any time, without notice, for any reason, including without limitation, breach of these Terms and Conditions. We may also at any time, at our sole discretion, discontinue the Website/Services or any part thereof without prior notice and you agree that we shall not be liable to you or any third party for any termination of your access to the Website/Services.</p>\r\n\r\n<p>In case you are using any of our SaaS (software as a service) solutions and wish to terminate the use of such service we will be unable to refund any set up fees you might have paid to have your account(s) set up and configured.</p>\r\n\r\n<p>8 LINKS TO THIRD PARTY WEBSITES</p>\r\n\r\n<p>The Website/Services may include links to third party websites that are controlled and maintained by others. Any link to other websites is not an endorsement of such websites and you acknowledge and agree that&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;is not responsible for the content or availability of any such sites.</p>\r\n\r\n<p>9 INTERNATIONAL USE</p>\r\n\r\n<p>You agree to comply with all applicable laws regarding the transmission of technical data exported from the United Kingdom or the country in which you reside (if different) and with all local laws and rules regarding acceptable use of and conduct on the Internet.</p>\r\n\r\n<p>10 INTELLECTUAL PROPERTY RIGHTS</p>\r\n\r\n<p>10.1 The Website and its content (including without limitation the Website design, text, graphics and all software and source codes connected with the Website and the Services) are protected by copyright, trade marks, patents and other intellectual property rights and laws. In accessing the Website you agree that you will access the contents solely for your personal, non-commercial use. None of the content may be downloaded, copied, reproduced, transmitted, stored, sold or distributed without the prior written consent of the copyright holder. This excludes the downloading, copying and/or printing of pages of the Website for personal, non-commercial or home use only.</p>\r\n\r\n<p>10.2&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;does not claim ownership of any materials you post, upload or submit to any publicly accessible area of the Services. However, by doing so you are granting us a world-wide, royalty free, non-exclusive licence to copy, distribute, transmit, reproduce, publicly display, edit, translate or publish such Content for as long as you elect to display such Content via the Services. The licence shall be terminated when such Content is deleted from the Services.</p>\r\n\r\n<p>11 INDEMNITY</p>\r\n\r\n<p>You agree to indemnify and hold&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;harmless from and against any breach by you of these Terms and Conditions and any claim or demand brought against&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;by any third party arising out of your use of the Services and/or any Content submitted, posted or transmitted through the Services, including without limitation, all claims, actions, proceedings, losses, liabilities, damages, costs, expenses (including reasonable legal costs and expenses) howsoever suffered or incurred by&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;in consequence of your breach of these Terms and Conditions.</p>\r\n\r\n<p>12 DISCLAIMERS AND LIMITATION OF LIABILITY</p>\r\n\r\n<p>12.1 Use of the Website/Services is at your own risk. The Website/Services are provided on an &ldquo;AS IS&rdquo; and &ldquo;AS AVAILABLE&rdquo; basis without any representation or endorsement made and without warranty of any kind whether express or implied, including but not limited to the implied warranties of satisfactory quality, fitness for a particular purpose, non-infringement, compatibility, security and accuracy.</p>\r\n\r\n<p>12.2 To the extent permitted by law,&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;will not be liable for any indirect or consequential loss or damage whatsoever (including without limitation loss of business, opportunity, data, profits) arising out of or in connection with the use of the Website/Services.</p>\r\n\r\n<p>12.3&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;makes no warranty that the Website/Services will meet your requirements, that Content will be accurate or reliable, that the functionality of the Website/Services will be uninterrupted or error free, that defects will be corrected or that the Website/Services or the server that makes them available are free of viruses or anything else which may be harmful or destructive.</p>\r\n\r\n<p>12.4 Nothing in these Terms and Conditions shall be construed so as to exclude or limit the liability of&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;for death or personal injury as a result of the negligence of&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>.</p>\r\n\r\n<p>12.5 Nothing in these Terms and Conditions shall affect your statutory rights as a consumer.</p>\r\n\r\n<p>13 PUBLIC OFFER OF HOLBI</p>\r\n\r\n<p>In case you as a Customer place an order with us&nbsp;<a href=\"https://www.holbi.co.uk/disclaimer/\" target=\"_self\">Our Public offer</a>&nbsp;terms and conditions apply.</p>\r\n\r\n<p>13.1 Paying for solutions and services online.</p>\r\n\r\n<p>We accept payments online via SagePay &ndash; a secure fully PCI DSS certified solution. Visa, Master Card and American Express are accepted. We accept payments in GBP, EUR and USD.</p>\r\n\r\n<p>Solutions and services are provided strictly to customers over 18 years of age.</p>\r\n\r\n<p>Delivery of solutions and services is performed via electronic means of communication. Web sites are uploaded to the designated web hosting accounts (or servers), configured and launched. Software solutions are provided as executable files and are configured and launched. No physical delivery option is available.</p>\r\n\r\n<p>No returns can be offered as no physical delivery takes place. Solutions and services are considered to be delivered once they have been uploaded to the designated web hosting accounts or servers.</p>\r\n\r\n<p>No refunds can be offered for completed and delivered solutions and services. No refunds can be offered once work commences on the whole project or one of its parts.</p>\r\n\r\n<p>Full cancellation can be offered as soon as the work has not commenced on the whole project or one of its parts.</p>\r\n\r\n<p>14 SEVERANCE</p>\r\n\r\n<p>If any of these Terms and Conditions should be determined to be invalid, illegal or unenforceable for any reason by any court of competent jurisdiction then such Term or Condition shall be severed and the remaining Terms and Conditions shall survive and remain in full force and effect and continue to be binding and enforceable.</p>\r\n\r\n<p>15 GOVERNING LAW</p>\r\n\r\n<p>These Terms and Conditions shall be governed by and construed in accordance with English law and you hereby submit to the exclusive jurisdiction of English courts.</p>',1,'Terms & Conditions','Terms and conditions','','header,infobox',0,'NONSSL','Write your terms and conditions for user&amp;#039;s trust using Ecommerce Platform: osCommerce by Holbi','','terms-conditions','','2015-02-10 00:00:00','2021-11-03 16:18:16',0,0,'',0,0,'','Terms and conditions osCommerce by Holbi','','','',0,'0',0,0),(7,9,'1',2,'Terms & conditions','',2,'Terms & conditions','','','header,infobox,footer',0,'NONSSL','','','terms-conditions','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'0',0,0),(8,9,'1',6,'Terms & Conditions','<p>Unless a special agreement is signed between Holbi and its client, these terms and conditions are applicable to and work and communications that we carry out for our client. All occurrences of words &ldquo;we&rdquo;, &ldquo;us&rdquo;, &ldquo;our&rdquo; mean Holbi, when all occurrences of &ldquo;you&rdquo;, &ldquo;your&rdquo; mean you, our client.</p>\r\n\r\n<p>1 ACCEPTANCE OF TERMS</p>\r\n\r\n<p>1.1 Your access to and use of&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;(&ldquo;the Website&rdquo;) and any Services referred to in Clause 2, is subject exclusively to these Terms and Conditions. You will not use the Website/Services for any purpose that is unlawful or prohibited by these Terms and Conditions. By using the Website/Services you are fully accepting the terms, conditions and disclaimers contained in this notice. If you do not accept these Terms and Conditions you must immediately stop using the Website/Services.</p>\r\n\r\n<p>1.2 We reserve the right to update or amend these Terms and Conditions at any time and your continued use of the Website/Services following any changes shall be deemed to be your acceptance of such change. It is therefore your responsibility to check the Terms and Conditions regularly for any changes.</p>\r\n\r\n<p>2 THE SERVICES</p>\r\n\r\n<p>The Website provides music and video download and streaming services (&ldquo;the Services&rdquo;) designed to enable you to purchase legal online music with others. Unless stated otherwise the Services are for your personal and non-commercial use only. You hereby accept that your computer meets the minimum technical requirements for the Services as stated clearly on the Website. The Services are for your own personal use and you are not authorised to make any copies of any downloads other than for personal use.</p>\r\n\r\n<p>3 CHILD SUPERVISION</p>\r\n\r\n<p>We are concerned about the safety and privacy of our users, particularly children. Parents who wish to allow their children access to and use of the Website/Services should supervise such access and use. By allowing your child access to the Services you are allowing your child access to all of the Services. It is therefore your responsibility to determine which Services are appropriate for your child. Always use caution when revealing personally identifiable information about yourself or your children via any of the Services.</p>\r\n\r\n<p>4 PRIVACY POLICY</p>\r\n\r\n<p>4.1 We are committed to responsible data management and subscribe to the principals of the data protection legislation in the United Kingdom. We are committed to maintaining the privacy of our users and maintaining the security of any personal information received from you. If you register for any of the Services you will be asked to provide basic personal information. The information provided by you is not available for sale or use by third parties. The information is used solely for notifying you of changes or updates to the Website/Services.</p>\r\n\r\n<p>4.2 We may use a technology called &ldquo;cookies&rdquo; as part of our normal business procedure to track patterns of behaviour of visitors to the Website. A cookie is an element of data that the Website sends to your browser that is then stored on your system. You can set your browser to prevent this happening. Any information collected in this way can be used to identify you unless you change your browser settings.</p>\r\n\r\n<p>5 USER ACCOUNT, PASSWORD AND SECURITY</p>\r\n\r\n<p>If a particular Service requires you to open an account you will be required to complete the registration process by providing certain information and registering a username and password for use with that Service. You are responsible for maintaining the confidentiality of the username and password and also for all activities which take place under your account. You agree to immediately notify us of any unauthorised use of your password or account or any other breach of security. In no event will&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;be liable for any indirect or consequential loss or damage whatsoever resulting from the disclosure of your username and/or password. You may not use another person&rsquo;s account at any time, without the express permission of the account holder.</p>\r\n\r\n<p>6 ACCEPTABLE USE</p>\r\n\r\n<p>6.1 You acknowledge that all information, text, graphics, logos, photographs, images, moving images, sound, illustrations and other materials (&ldquo;the Content&rdquo;), whether posted publicly or transmitted privately, are the sole responsibility of the person from whom such Content originated. We do not control or endorse the Content and cannot guarantee the accuracy, integrity or quality of such Content and you acknowledge that by using the Services you may be exposed to Content that is offensive and/or indecent.&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;will not be liable in any way for any Content or for any loss or damage of any kind resulting from the use of any Content transmitted via the Services and you agree to bear all risks associated with the use of any Content, including any reliance on the accuracy or completeness of such Content.</p>\r\n\r\n<p>6.2 In using the Website/Services you agree not to:</p>\r\n\r\n<p>6.2.1 use the Services to send junk email, spam, chain letters, pyramid schemes or any other unsolicited messages, commercial or otherwise;</p>\r\n\r\n<p>6.2.2 post, publish, distribute or disseminate material or information that is defamatory, infringing, obscene, indecent, threatening, abusive, harassing or unlawful;</p>\r\n\r\n<p>6.2.3 post, publish, distribute or disseminate material or information that incites discrimination, hate or violence towards any person or group on account of their race, religion, disability, nationality or otherwise;</p>\r\n\r\n<p>6.2.4 threaten, abuse, disrupt, stalk or otherwise violate the legal rights (including rights of privacy and publicity) of others;</p>\r\n\r\n<p>6.2.5 use any information or material in any manner that infringes any copyright, trademark, patent or other proprietary right of any party;</p>\r\n\r\n<p>6.2.6 make available or upload files that contain a virus, worm, trojan or corrupt data that may damage the operation of the computer or property of another;</p>\r\n\r\n<p>6.2.7 collect or store personal information about others, including email addresses;</p>\r\n\r\n<p>6.2.8 advertise or offer to buy or sell goods or services for any commercial purpose, unless such communication facility specifically allows such messages;</p>\r\n\r\n<p>6.2.9 impersonate any person or entity for the purpose of misleading others;</p>\r\n\r\n<p>6.2.10 violate any applicable laws or regulations;</p>\r\n\r\n<p>6.2.11 use the Website/Services in any manner that could damage, disable, overburden or impair the Website/Services or interfere with any other party&rsquo;s use and enjoyment of the Website/Services;</p>\r\n\r\n<p>6.2.12 post, publish, distribute or disseminate material or information that you do not have a right to transmit under any law or under contractual or fiduciary relationships (such as inside information or confidential information disclosed in the course of employment or under a confidentiality agreement);</p>\r\n\r\n<p>6.2.13 attempt to gain unauthorised access to any of the Services, other accounts, computer systems or networks connected to the Website/Services through hacking, password mining or any other means.</p>\r\n\r\n<p>6.3 We have no obligation to monitor the Services but shall be entitled to review materials posted to a communications facility and, at our sole discretion, to remove any material that breaches these Terms and Conditions or is otherwise objectionable.</p>\r\n\r\n<p>7 TERMINATION</p>\r\n\r\n<p>We have the right to terminate your access to any or all of the Services at any time, without notice, for any reason, including without limitation, breach of these Terms and Conditions. We may also at any time, at our sole discretion, discontinue the Website/Services or any part thereof without prior notice and you agree that we shall not be liable to you or any third party for any termination of your access to the Website/Services.</p>\r\n\r\n<p>In case you are using any of our SaaS (software as a service) solutions and wish to terminate the use of such service we will be unable to refund any set up fees you might have paid to have your account(s) set up and configured.</p>\r\n\r\n<p>8 LINKS TO THIRD PARTY WEBSITES</p>\r\n\r\n<p>The Website/Services may include links to third party websites that are controlled and maintained by others. Any link to other websites is not an endorsement of such websites and you acknowledge and agree that&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;is not responsible for the content or availability of any such sites.</p>\r\n\r\n<p>9 INTERNATIONAL USE</p>\r\n\r\n<p>You agree to comply with all applicable laws regarding the transmission of technical data exported from the United Kingdom or the country in which you reside (if different) and with all local laws and rules regarding acceptable use of and conduct on the Internet.</p>\r\n\r\n<p>10 INTELLECTUAL PROPERTY RIGHTS</p>\r\n\r\n<p>10.1 The Website and its content (including without limitation the Website design, text, graphics and all software and source codes connected with the Website and the Services) are protected by copyright, trade marks, patents and other intellectual property rights and laws. In accessing the Website you agree that you will access the contents solely for your personal, non-commercial use. None of the content may be downloaded, copied, reproduced, transmitted, stored, sold or distributed without the prior written consent of the copyright holder. This excludes the downloading, copying and/or printing of pages of the Website for personal, non-commercial or home use only.</p>\r\n\r\n<p>10.2&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;does not claim ownership of any materials you post, upload or submit to any publicly accessible area of the Services. However, by doing so you are granting us a world-wide, royalty free, non-exclusive licence to copy, distribute, transmit, reproduce, publicly display, edit, translate or publish such Content for as long as you elect to display such Content via the Services. The licence shall be terminated when such Content is deleted from the Services.</p>\r\n\r\n<p>11 INDEMNITY</p>\r\n\r\n<p>You agree to indemnify and hold&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;harmless from and against any breach by you of these Terms and Conditions and any claim or demand brought against&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;by any third party arising out of your use of the Services and/or any Content submitted, posted or transmitted through the Services, including without limitation, all claims, actions, proceedings, losses, liabilities, damages, costs, expenses (including reasonable legal costs and expenses) howsoever suffered or incurred by&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;in consequence of your breach of these Terms and Conditions.</p>\r\n\r\n<p>12 DISCLAIMERS AND LIMITATION OF LIABILITY</p>\r\n\r\n<p>12.1 Use of the Website/Services is at your own risk. The Website/Services are provided on an &ldquo;AS IS&rdquo; and &ldquo;AS AVAILABLE&rdquo; basis without any representation or endorsement made and without warranty of any kind whether express or implied, including but not limited to the implied warranties of satisfactory quality, fitness for a particular purpose, non-infringement, compatibility, security and accuracy.</p>\r\n\r\n<p>12.2 To the extent permitted by law,&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;will not be liable for any indirect or consequential loss or damage whatsoever (including without limitation loss of business, opportunity, data, profits) arising out of or in connection with the use of the Website/Services.</p>\r\n\r\n<p>12.3&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;makes no warranty that the Website/Services will meet your requirements, that Content will be accurate or reliable, that the functionality of the Website/Services will be uninterrupted or error free, that defects will be corrected or that the Website/Services or the server that makes them available are free of viruses or anything else which may be harmful or destructive.</p>\r\n\r\n<p>12.4 Nothing in these Terms and Conditions shall be construed so as to exclude or limit the liability of&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>&nbsp;for death or personal injury as a result of the negligence of&nbsp;<a href=\"http://holbi.co.uk/\" target=\"_blank\">holbi.co.uk</a>.</p>\r\n\r\n<p>12.5 Nothing in these Terms and Conditions shall affect your statutory rights as a consumer.</p>\r\n\r\n<p>13 PUBLIC OFFER OF HOLBI</p>\r\n\r\n<p>In case you as a Customer place an order with us&nbsp;<a href=\"https://www.holbi.co.uk/disclaimer/\" target=\"_self\">Our Public offer</a>&nbsp;terms and conditions apply.</p>\r\n\r\n<p>13.1 Paying for solutions and services online.</p>\r\n\r\n<p>We accept payments online via SagePay &ndash; a secure fully PCI DSS certified solution. Visa, Master Card and American Express are accepted. We accept payments in GBP, EUR and USD.</p>\r\n\r\n<p>Solutions and services are provided strictly to customers over 18 years of age.</p>\r\n\r\n<p>Delivery of solutions and services is performed via electronic means of communication. Web sites are uploaded to the designated web hosting accounts (or servers), configured and launched. Software solutions are provided as executable files and are configured and launched. No physical delivery option is available.</p>\r\n\r\n<p>No returns can be offered as no physical delivery takes place. Solutions and services are considered to be delivered once they have been uploaded to the designated web hosting accounts or servers.</p>\r\n\r\n<p>No refunds can be offered for completed and delivered solutions and services. No refunds can be offered once work commences on the whole project or one of its parts.</p>\r\n\r\n<p>Full cancellation can be offered as soon as the work has not commenced on the whole project or one of its parts.</p>\r\n\r\n<p>14 SEVERANCE</p>\r\n\r\n<p>If any of these Terms and Conditions should be determined to be invalid, illegal or unenforceable for any reason by any court of competent jurisdiction then such Term or Condition shall be severed and the remaining Terms and Conditions shall survive and remain in full force and effect and continue to be binding and enforceable.</p>\r\n\r\n<p>15 GOVERNING LAW</p>\r\n\r\n<p>These Terms and Conditions shall be governed by and construed in accordance with English law and you hereby submit to the exclusive jurisdiction of English courts.</p>',1,'Terms & Conditions','Terms and conditions','','header,infobox',0,'NONSSL','Write your terms and conditions for user&amp;#039;s trust using Ecommerce Platform: osCommerce by Holbi','','terms-conditions','','2015-02-10 00:00:00','2021-11-03 16:18:16',0,0,'',0,0,'','Terms and conditions osCommerce by Holbi','','','',0,'0',0,0),(8,9,'1',2,'Terms & conditions','',2,'Terms & conditions','','','header,infobox,footer',0,'NONSSL','','','terms-conditions','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'0',0,0),(1,12,'1',5,'User Guide','<p>As the user on this website you can create the account and use your profile from your social network accounts. Once you create your account you will be able to shop faster, be up to date on an orders status and keep track of the orders you have previously made.</p>\r\n\r\n<p>You can find an item on the website using search tool, sort the items by date, name, weight, price, model, manufacturer, brand and category. You can also set up how many items you want to show.</p>\r\n\r\n<p>You can choose different currencies and languages on the website.</p>\r\n\r\n<p>Purchasing process is simple and straight forward. While purchasing an item you can add it to &ldquo;My wish list&rdquo;, add an item to cart, proceed to checkout, fill in the required details there and choose different payment methods (PayPal (including Credit and Debit Cards), Credit Card or Bank Card (Processed by Sage Pay), Cash on Delivery or LiqPay).</p>\r\n\r\n<p>After placing the order you will be notified about it via email. Each time the status of your order is changed you will be notified about it via email as well.</p>\r\n\r\n<p>Finally we take your security on this website very seriously. All your personal information will be securely stored and under no circumstances will be shared with anyone.</p>\r\n\r\n<p>&nbsp;</p>',1,'User Guide','User guide of ecommerce platform osCommerce','','header,infobox',0,'NONSSL','Give your clients description of how to use your website with ecommerce osCommerce','','user-guide','','2015-02-10 00:00:00','2021-11-03 16:11:52',0,0,'',0,0,'','User guide ecommerce osCommerce','','','',0,'0',0,0),(1,12,'1',5,'','lkjljljljj',2,'','','','header,infobox,footer',0,'NONSSL','','','','','2015-02-10 00:00:00','2016-04-11 11:35:00',0,0,'',0,0,'','','','','',0,'0',0,0),(7,12,'1',5,'User Guide','<p>As the user on this website you can create the account and use your profile from your social network accounts. Once you create your account you will be able to shop faster, be up to date on an orders status and keep track of the orders you have previously made.</p>\r\n\r\n<p>You can find an item on the website using search tool, sort the items by date, name, weight, price, model, manufacturer, brand and category. You can also set up how many items you want to show.</p>\r\n\r\n<p>You can choose different currencies and languages on the website.</p>\r\n\r\n<p>Purchasing process is simple and straight forward. While purchasing an item you can add it to &ldquo;My wish list&rdquo;, add an item to cart, proceed to checkout, fill in the required details there and choose different payment methods (PayPal (including Credit and Debit Cards), Credit Card or Bank Card (Processed by Sage Pay), Cash on Delivery or LiqPay).</p>\r\n\r\n<p>After placing the order you will be notified about it via email. Each time the status of your order is changed you will be notified about it via email as well.</p>\r\n\r\n<p>Finally we take your security on this website very seriously. All your personal information will be securely stored and under no circumstances will be shared with anyone.</p>\r\n\r\n<p>&nbsp;</p>',1,'User Guide','User guide of ecommerce platform osCommerce','','header,infobox',0,'NONSSL','Give your clients description of how to use your website with ecommerce osCommerce','','user-guide','','2015-02-10 00:00:00','2021-11-03 16:11:52',0,0,'',0,0,'','User guide ecommerce osCommerce','','','',0,'0',0,0),(7,12,'1',5,'','lkjljljljj',2,'','','','header,infobox,footer',0,'NONSSL','','','','','2015-02-10 00:00:00','2016-04-11 11:35:00',0,0,'',0,0,'','','','','',0,'0',0,0),(8,12,'1',5,'User Guide','<p>As the user on this website you can create the account and use your profile from your social network accounts. Once you create your account you will be able to shop faster, be up to date on an orders status and keep track of the orders you have previously made.</p>\r\n\r\n<p>You can find an item on the website using search tool, sort the items by date, name, weight, price, model, manufacturer, brand and category. You can also set up how many items you want to show.</p>\r\n\r\n<p>You can choose different currencies and languages on the website.</p>\r\n\r\n<p>Purchasing process is simple and straight forward. While purchasing an item you can add it to &ldquo;My wish list&rdquo;, add an item to cart, proceed to checkout, fill in the required details there and choose different payment methods (PayPal (including Credit and Debit Cards), Credit Card or Bank Card (Processed by Sage Pay), Cash on Delivery or LiqPay).</p>\r\n\r\n<p>After placing the order you will be notified about it via email. Each time the status of your order is changed you will be notified about it via email as well.</p>\r\n\r\n<p>Finally we take your security on this website very seriously. All your personal information will be securely stored and under no circumstances will be shared with anyone.</p>\r\n\r\n<p>&nbsp;</p>',1,'User Guide','User guide of ecommerce platform osCommerce','','header,infobox',0,'NONSSL','Give your clients description of how to use your website with ecommerce osCommerce','','user-guide','','2015-02-10 00:00:00','2021-11-03 16:11:52',0,0,'',0,0,'','User guide ecommerce osCommerce','','','',0,'0',0,0),(8,12,'1',5,'','lkjljljljj',2,'','','','header,infobox,footer',0,'NONSSL','','','','','2015-02-10 00:00:00','2016-04-11 11:35:00',0,0,'',0,0,'','','','','',0,'0',0,0),(1,13,'1',4,'Privacy Policy','<p>1. This osCommerce web site (the &quot;Web site&quot;) is provided by Holbi.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>The Web site is committed to protecting your privacy and maintaining the security of any personal information received from you. We strictly adhere to the requirements of the data protection legislation in the United Kingdom.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>2. When you join the Holbi mailing list by completing the form on the Web site we ask for your contact details to comprise our media database. We do not collect credit/debit card information.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>3. We use your personal information to compile demographic information, distribute our press releases and newsletter.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>4. We do not sell, rent or exchange your personal information with any third party for commercial reasons. Your subscription information will be kept private and is not publicly accessible. Your email address and other information will never be given out or sold to a third party. This includes those who wish to contact Holbi for any general purpose as well</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>5. We follow strict security procedures in the storage and disclosure of information which you have given us, to prevent unauthorized access in accordance with the United Kingdom data protection legislation.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>We do not collect sensitive information about you except when you specifically knowingly provide it. In order to maintain the accuracy of our database, you can check, update, correct or remove your personal details by <a href=\"/contact\">contacting us</a>. You are, upon request, entitled to receive information regarding our use of your personal data free of charge once a year.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>We may use a technology called &quot;cookies&quot; as part of a normal business procedure to track patterns of behavior of visitors to our site. A cookie is an element of data that our Web site sends to your browser, which is then stored on your system. You can set your browser to prevent this happening. Any information collected in this way can be used to identify you unless you change your browser settings.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>Of the information we learn about you from your visit to Holbi Web sites, we store only the following: the IP address from which you access the Internet, the date and time, the Internet address of the Web site from which you linked directly to our site, the name of the file or the words you searched, and the browser used to access our site. This information is used to measure the number of visitors to the various sections of our site and identify system performance or problem areas. We also use this information to help us expand the coverage of the sites and to make the site more useful. Holbi periodically deletes its Web logs. On occasion, Holbi may provide this information to third party entities it contracts with for the purposes of research analysis.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>6. We will not transfer your information outside the EEA (European Economic Area) without first obtaining your consent.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>7. If you have any further questions, please <a href=\"##URL##contact/index\">contact us</a>.</p>',1,'Privacy Policy','Privacy policy of osCommerce by Holbi Group','','header,infobox',0,'NONSSL','Give your client full company information for better trust using ecommerce site: osCommerce by Holbi','','privacy-policy','','2015-02-10 00:00:00','2021-11-03 16:11:13',0,0,'',0,0,'','Privacy policy','','','',0,'0',0,0),(1,13,'1',4,'Privacy Policy','',2,'Privacy Policy','','','header,infobox,footer',0,'NONSSL',NULL,NULL,'privacy-policy','','2015-02-10 00:00:00',NULL,0,0,'',0,0,'','','','','',0,'0',0,0),(7,13,'1',4,'Privacy Policy','<p>1. This osCommerce web site (the &quot;Web site&quot;) is provided by Holbi.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>The Web site is committed to protecting your privacy and maintaining the security of any personal information received from you. We strictly adhere to the requirements of the data protection legislation in the United Kingdom.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>2. When you join the Holbi mailing list by completing the form on the Web site we ask for your contact details to comprise our media database. We do not collect credit/debit card information.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>3. We use your personal information to compile demographic information, distribute our press releases and newsletter.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>4. We do not sell, rent or exchange your personal information with any third party for commercial reasons. Your subscription information will be kept private and is not publicly accessible. Your email address and other information will never be given out or sold to a third party. This includes those who wish to contact Holbi for any general purpose as well</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>5. We follow strict security procedures in the storage and disclosure of information which you have given us, to prevent unauthorized access in accordance with the United Kingdom data protection legislation.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>We do not collect sensitive information about you except when you specifically knowingly provide it. In order to maintain the accuracy of our database, you can check, update, correct or remove your personal details by <a href=\"/contact\">contacting us</a>. You are, upon request, entitled to receive information regarding our use of your personal data free of charge once a year.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>We may use a technology called &quot;cookies&quot; as part of a normal business procedure to track patterns of behavior of visitors to our site. A cookie is an element of data that our Web site sends to your browser, which is then stored on your system. You can set your browser to prevent this happening. Any information collected in this way can be used to identify you unless you change your browser settings.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>Of the information we learn about you from your visit to Holbi Web sites, we store only the following: the IP address from which you access the Internet, the date and time, the Internet address of the Web site from which you linked directly to our site, the name of the file or the words you searched, and the browser used to access our site. This information is used to measure the number of visitors to the various sections of our site and identify system performance or problem areas. We also use this information to help us expand the coverage of the sites and to make the site more useful. Holbi periodically deletes its Web logs. On occasion, Holbi may provide this information to third party entities it contracts with for the purposes of research analysis.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>6. We will not transfer your information outside the EEA (European Economic Area) without first obtaining your consent.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>7. If you have any further questions, please <a href=\"##URL##contact/index\">contact us</a>.</p>',1,'Privacy Policy','Privacy policy of osCommerce by Holbi Group','','header,infobox',0,'NONSSL','Give your client full company information for better trust using ecommerce site: osCommerce by Holbi','','privacy-policy','','2015-02-10 00:00:00','2021-11-03 16:11:13',0,0,'',0,0,'','Privacy policy','','','',0,'0',0,0),(7,13,'1',4,'Privacy Policy','',2,'Privacy Policy','','','header,infobox,footer',0,'NONSSL','','','privacy-policy','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'0',0,0),(8,13,'1',4,'Privacy Policy','<p>1. This osCommerce web site (the &quot;Web site&quot;) is provided by Holbi.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>The Web site is committed to protecting your privacy and maintaining the security of any personal information received from you. We strictly adhere to the requirements of the data protection legislation in the United Kingdom.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>2. When you join the Holbi mailing list by completing the form on the Web site we ask for your contact details to comprise our media database. We do not collect credit/debit card information.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>3. We use your personal information to compile demographic information, distribute our press releases and newsletter.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>4. We do not sell, rent or exchange your personal information with any third party for commercial reasons. Your subscription information will be kept private and is not publicly accessible. Your email address and other information will never be given out or sold to a third party. This includes those who wish to contact Holbi for any general purpose as well</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>5. We follow strict security procedures in the storage and disclosure of information which you have given us, to prevent unauthorized access in accordance with the United Kingdom data protection legislation.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>We do not collect sensitive information about you except when you specifically knowingly provide it. In order to maintain the accuracy of our database, you can check, update, correct or remove your personal details by <a href=\"/contact\">contacting us</a>. You are, upon request, entitled to receive information regarding our use of your personal data free of charge once a year.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>We may use a technology called &quot;cookies&quot; as part of a normal business procedure to track patterns of behavior of visitors to our site. A cookie is an element of data that our Web site sends to your browser, which is then stored on your system. You can set your browser to prevent this happening. Any information collected in this way can be used to identify you unless you change your browser settings.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>Of the information we learn about you from your visit to Holbi Web sites, we store only the following: the IP address from which you access the Internet, the date and time, the Internet address of the Web site from which you linked directly to our site, the name of the file or the words you searched, and the browser used to access our site. This information is used to measure the number of visitors to the various sections of our site and identify system performance or problem areas. We also use this information to help us expand the coverage of the sites and to make the site more useful. Holbi periodically deletes its Web logs. On occasion, Holbi may provide this information to third party entities it contracts with for the purposes of research analysis.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>6. We will not transfer your information outside the EEA (European Economic Area) without first obtaining your consent.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>7. If you have any further questions, please <a href=\"##URL##contact/index\">contact us</a>.</p>',1,'Privacy Policy','Privacy policy of osCommerce by Holbi Group','','header,infobox',0,'NONSSL','Give your client full company information for better trust using ecommerce site: osCommerce by Holbi','','privacy-policy','','2015-02-10 00:00:00','2021-11-03 16:11:13',0,0,'',0,0,'','Privacy policy','','','',0,'0',0,0),(8,13,'1',4,'Privacy Policy','',2,'Privacy Policy','','','header,infobox,footer',0,'NONSSL','','','privacy-policy','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'0',0,0),(1,17,'0',0,'Home','',1,'','','index.php','header,infobox,footer',0,'NONSSL','','','home','','2015-02-10 00:00:00','2018-01-11 14:39:31',0,0,'',0,0,'','','','','',0,'',0,0),(1,17,'0',1,'','',1,'','','index.php','footer',16,'NONSSL',NULL,NULL,'','','2015-02-10 00:00:00',NULL,0,0,'',0,0,'','','','','',0,'',0,0),(1,17,'0',1,'','',1,'','','index.php','footer',18,'NONSSL',NULL,NULL,'','','2015-02-10 00:00:00',NULL,0,0,'',0,0,'','','','','',0,'',0,0),(1,17,'0',1,'Home','',2,'','','index.php','header,infobox,footer',0,'NONSSL',NULL,NULL,'home','','2015-02-10 00:00:00',NULL,0,0,'',0,0,'','','','','',0,'',0,0),(1,17,'0',1,'','',2,'','','index.php','footer',16,'NONSSL',NULL,NULL,'','','2015-02-10 00:00:00',NULL,0,0,'',0,0,'','','','','',0,'',0,0),(1,17,'0',1,'','',2,'','','index.php','footer',18,'NONSSL',NULL,NULL,'','','2015-02-10 00:00:00',NULL,0,0,'',0,0,'','','','','',0,'',0,0),(7,17,'0',0,'Home','',1,'','','index.php','header,infobox,footer',0,'NONSSL','','','home','','2015-02-10 00:00:00','2018-01-11 14:39:31',0,0,'',0,0,'','','','','',0,'',0,0),(7,17,'0',1,'','',1,'','','index.php','footer',16,'NONSSL','','','','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(7,17,'0',1,'','',1,'','','index.php','footer',18,'NONSSL','','','','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(7,17,'0',1,'Home','',2,'','','index.php','header,infobox,footer',0,'NONSSL','','','home','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(7,17,'0',1,'','',2,'','','index.php','footer',16,'NONSSL','','','','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(7,17,'0',1,'','',2,'','','index.php','footer',18,'NONSSL','','','','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(8,17,'0',0,'Home','',1,'','','index.php','header,infobox,footer',0,'NONSSL','','','home','','2015-02-10 00:00:00','2018-01-11 14:39:31',0,0,'',0,0,'','','','','',0,'',0,0),(8,17,'0',1,'','',1,'','','index.php','footer',16,'NONSSL','','','','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(8,17,'0',1,'','',1,'','','index.php','footer',18,'NONSSL','','','','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(8,17,'0',1,'Home','',2,'','','index.php','header,infobox,footer',0,'NONSSL','','','home','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(8,17,'0',1,'','',2,'','','index.php','footer',16,'NONSSL','','','','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(8,17,'0',1,'','',2,'','','index.php','footer',18,'NONSSL','','','','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(1,19,'',0,'','',2,'','','','',0,'',NULL,NULL,'','','2015-02-10 00:00:00',NULL,0,0,'',0,0,'','','','','',0,'',0,0),(7,19,'',0,'','',2,'','','','',0,'','','','','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(8,19,'',0,'','',2,'','','','',0,'','','','','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(1,21,'',0,'','',2,'','','','',0,'',NULL,NULL,'','','2015-02-10 00:00:00',NULL,0,0,'',0,0,'','','','','',0,'',0,0),(7,21,'',0,'','',2,'','','','',0,'','','','','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(8,21,'',0,'','',2,'','','','',0,'','','','','','2015-02-10 00:00:00','0000-00-00 00:00:00',0,0,'',0,0,'','','','','',0,'',0,0),(1,22,'1',0,'About Us','Pellentesque in ipsum id orci porta dapibus. Donec sollicitudin molestie malesuada. Cras ultricies ligula sed magna dictum porta. Nulla porttitor accumsan tincidunt. Nulla porttitor accumsan tincidunt. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Donec velit neque, auctor sit amet aliquam vel, ullamcorper sit amet ligula. Cras ultricies ligula sed magna dictum porta. Curabitur aliquet quam id dui posuere blandit. Curabitur aliquet quam id dui posuere blandit. Curabitur arcu erat, accumsan id imperdiet et, porttitor at sem.',1,'About Us','About us','','header',0,'NONSSL','Allow your clients check about your web site using Ecommerce website : osCommerce by Holbi','','about-us','','2017-02-01 00:00:00','2022-02-18 17:16:15',0,0,'',0,0,'','About us feature','','','',0,'0',0,0),(7,22,'1',0,'About Us','Pellentesque in ipsum id orci porta dapibus. Donec sollicitudin molestie malesuada. Cras ultricies ligula sed magna dictum porta. Nulla porttitor accumsan tincidunt. Nulla porttitor accumsan tincidunt. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Donec velit neque, auctor sit amet aliquam vel, ullamcorper sit amet ligula. Cras ultricies ligula sed magna dictum porta. Curabitur aliquet quam id dui posuere blandit. Curabitur aliquet quam id dui posuere blandit. Curabitur arcu erat, accumsan id imperdiet et, porttitor at sem.',1,'About Us','About us','','header',0,'NONSSL','Allow your clients check about your web site using Ecommerce website : osCommerce by Holbi','','about-us','','2017-02-01 00:00:00','2022-02-18 17:16:15',0,0,'',0,0,'','About us feature','','','',0,'0',0,0),(8,22,'1',0,'About Us','Pellentesque in ipsum id orci porta dapibus. Donec sollicitudin molestie malesuada. Cras ultricies ligula sed magna dictum porta. Nulla porttitor accumsan tincidunt. Nulla porttitor accumsan tincidunt. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Donec velit neque, auctor sit amet aliquam vel, ullamcorper sit amet ligula. Cras ultricies ligula sed magna dictum porta. Curabitur aliquet quam id dui posuere blandit. Curabitur aliquet quam id dui posuere blandit. Curabitur arcu erat, accumsan id imperdiet et, porttitor at sem.',1,'About Us','About us','','header',0,'NONSSL','Allow your clients check about your web site using Ecommerce website : osCommerce by Holbi','','about-us','','2017-02-01 00:00:00','2022-02-18 17:16:15',0,0,'',0,0,'','About us feature','','','',0,'0',0,0),(9,22,'1',0,'About Us','Pellentesque in ipsum id orci porta dapibus. Donec sollicitudin molestie malesuada. Cras ultricies ligula sed magna dictum porta. Nulla porttitor accumsan tincidunt. Nulla porttitor accumsan tincidunt. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Donec velit neque, auctor sit amet aliquam vel, ullamcorper sit amet ligula. Cras ultricies ligula sed magna dictum porta. Curabitur aliquet quam id dui posuere blandit. Curabitur aliquet quam id dui posuere blandit. Curabitur arcu erat, accumsan id imperdiet et, porttitor at sem.',1,'About Us','','','header',0,'NONSSL','','','about-us','','2017-02-01 00:00:00',NULL,0,0,'',0,0,'','','','','',0,'0',0,0),(10,22,'1',0,'','',1,'','','','header',0,'NONSSL','','','','','2017-02-01 00:00:00',NULL,0,0,'',0,0,'','','','','',0,'0',0,0),(1,28,'1',0,'Holbi','<p style=\"text-align: justify;\"><a href=\"https://www.holbi.co.uk/\">Holbi Group</a>&nbsp;is a leading provider of Ecommerce solutions for SMEs and global corporations.</p>\r\n\r\n<p style=\"text-align: justify;\">A &nbsp;60+ &nbsp;<a href=\"https://www.holbi.co.uk/our-team\">strong team</a>, we have industry&#39;s best Ecommerce web developers, designers, &nbsp;QA engineers, and project managers available to create new solutions and improve existing ones.</p>\r\n\r\n<p style=\"text-align: justify;\">More than&nbsp;half &nbsp;of &nbsp;our &nbsp;business &nbsp;is &nbsp;about &nbsp;Ecommerce &nbsp;development. &nbsp;We manufacture our own Ecommerce open source platform osCommerce and also create &nbsp;Ecommerce websites for our clients from all over the world. At Holbi &nbsp;we &nbsp;enjoy &nbsp;working &nbsp;on &nbsp;challenging &nbsp;projects &nbsp;with complicated specifications, &nbsp;multiple integrations with 3rd parties, websites that trade in different international markets.</p>\r\n\r\n<p style=\"text-align: justify;\">Besides &nbsp;Ecommerce &nbsp;development we have departments that specialise in Customer &nbsp;support &nbsp;solutions &nbsp;(mostly based on Kayako), Accounting and ERP integrations (software that integrates Ecommerce with the likes of Sage, &nbsp;QuickBooks, &nbsp;Exact, &nbsp;MYOB), &nbsp;online marketing (SEO, PPC, social marketing), and special Ecommerce hosting.</p>\r\n\r\n<p style=\"text-align: justify;\">Holbi &nbsp;is &nbsp;always &nbsp;happy &nbsp;to &nbsp;offer &nbsp;a &nbsp;full range of services to your business!</p>',1,'Holbi','HOLBI Group Contact page','','header',0,'NONSSL','Holbi Group is a leading provider of Ecommerce solutions for SMEs and global corporations. A  60+  strong team, we have industry&#039;s best Ecommerce web developers, designers,  QA engineers, and project managers.','','holbi','','2017-07-25 00:00:00','2022-07-25 11:02:50',0,1,'',0,0,'','HOLBI','','','',0,'0',0,0),(7,28,'1',0,'Holbi','<p style=\"text-align: justify;\"><a href=\"https://www.holbi.co.uk/\">Holbi Group</a>&nbsp;is a leading provider of Ecommerce solutions for SMEs and global corporations.</p>\r\n\r\n<p style=\"text-align: justify;\">A &nbsp;60+ &nbsp;<a href=\"https://www.holbi.co.uk/our-team\">strong team</a>, we have industry&#39;s best Ecommerce web developers, designers, &nbsp;QA engineers, and project managers available to create new solutions and improve existing ones.</p>\r\n\r\n<p style=\"text-align: justify;\">More than&nbsp;half &nbsp;of &nbsp;our &nbsp;business &nbsp;is &nbsp;about &nbsp;Ecommerce &nbsp;development. &nbsp;We manufacture our own Ecommerce open source platform osCommerce and also create &nbsp;Ecommerce websites for our clients from all over the world. At Holbi &nbsp;we &nbsp;enjoy &nbsp;working &nbsp;on &nbsp;challenging &nbsp;projects &nbsp;with complicated specifications, &nbsp;multiple integrations with 3rd parties, websites that trade in different international markets.</p>\r\n\r\n<p style=\"text-align: justify;\">Besides &nbsp;Ecommerce &nbsp;development we have departments that specialise in Customer &nbsp;support &nbsp;solutions &nbsp;(mostly based on Kayako), Accounting and ERP integrations (software that integrates Ecommerce with the likes of Sage, &nbsp;QuickBooks, &nbsp;Exact, &nbsp;MYOB), &nbsp;online marketing (SEO, PPC, social marketing), and special Ecommerce hosting.</p>\r\n\r\n<p style=\"text-align: justify;\">Holbi &nbsp;is &nbsp;always &nbsp;happy &nbsp;to &nbsp;offer &nbsp;a &nbsp;full range of services to your business!</p>',1,'Holbi','HOLBI Group Contact page','','header',0,'NONSSL','Holbi Group is a leading provider of Ecommerce solutions for SMEs and global corporations. A  60+  strong team, we have industry&#039;s best Ecommerce web developers, designers,  QA engineers, and project managers.','','holbi','','2017-07-25 00:00:00','2022-07-25 11:02:50',0,1,'',0,0,'','HOLBI','','','',0,'0',0,0),(8,28,'1',0,'Holbi','<p style=\"text-align: justify;\"><a href=\"https://www.holbi.co.uk/\">Holbi Group</a>&nbsp;is a leading provider of Ecommerce solutions for SMEs and global corporations.</p>\r\n\r\n<p style=\"text-align: justify;\">A &nbsp;60+ &nbsp;<a href=\"https://www.holbi.co.uk/our-team\">strong team</a>, we have industry&#39;s best Ecommerce web developers, designers, &nbsp;QA engineers, and project managers available to create new solutions and improve existing ones.</p>\r\n\r\n<p style=\"text-align: justify;\">More than&nbsp;half &nbsp;of &nbsp;our &nbsp;business &nbsp;is &nbsp;about &nbsp;Ecommerce &nbsp;development. &nbsp;We manufacture our own Ecommerce open source platform osCommerce and also create &nbsp;Ecommerce websites for our clients from all over the world. At Holbi &nbsp;we &nbsp;enjoy &nbsp;working &nbsp;on &nbsp;challenging &nbsp;projects &nbsp;with complicated specifications, &nbsp;multiple integrations with 3rd parties, websites that trade in different international markets.</p>\r\n\r\n<p style=\"text-align: justify;\">Besides &nbsp;Ecommerce &nbsp;development we have departments that specialise in Customer &nbsp;support &nbsp;solutions &nbsp;(mostly based on Kayako), Accounting and ERP integrations (software that integrates Ecommerce with the likes of Sage, &nbsp;QuickBooks, &nbsp;Exact, &nbsp;MYOB), &nbsp;online marketing (SEO, PPC, social marketing), and special Ecommerce hosting.</p>\r\n\r\n<p style=\"text-align: justify;\">Holbi &nbsp;is &nbsp;always &nbsp;happy &nbsp;to &nbsp;offer &nbsp;a &nbsp;full range of services to your business!</p>',1,'Holbi','HOLBI Group Contact page','','header',0,'NONSSL','Holbi Group is a leading provider of Ecommerce solutions for SMEs and global corporations. A  60+  strong team, we have industry&#039;s best Ecommerce web developers, designers,  QA engineers, and project managers.','','holbi','','2017-07-25 00:00:00','2022-07-25 11:02:50',0,1,'',0,0,'','HOLBI','','','',0,'0',0,0),(9,28,'1',0,'Holbi','<p style=\"text-align: justify;\"><a href=\"https://www.holbi.co.uk/\">Holbi Group</a>&nbsp;is a leading provider of Ecommerce solutions for SMEs and global corporations.</p>\r\n\r\n<p style=\"text-align: justify;\">A &nbsp;60+ &nbsp;<a href=\"https://www.holbi.co.uk/our-team\">strong team</a>, we have industry&#39;s best Ecommerce web developers, designers, &nbsp;QA engineers, and project managers available to create new solutions and improve existing ones.</p>\r\n\r\n<p style=\"text-align: justify;\">More than&nbsp;half &nbsp;of &nbsp;our &nbsp;business &nbsp;is &nbsp;about &nbsp;Ecommerce &nbsp;development. &nbsp;We manufacture our own Ecommerce open source platform osCommerce and also create &nbsp;Ecommerce websites for our clients from all over the world. At Holbi &nbsp;we &nbsp;enjoy &nbsp;working &nbsp;on &nbsp;challenging &nbsp;projects &nbsp;with complicated specifications, &nbsp;multiple integrations with 3rd parties, websites that trade in different international markets.</p>\r\n\r\n<p style=\"text-align: justify;\">Besides &nbsp;Ecommerce &nbsp;development we have departments that specialise in Customer &nbsp;support &nbsp;solutions &nbsp;(mostly based on Kayako), Accounting and ERP integrations (software that integrates Ecommerce with the likes of Sage, &nbsp;QuickBooks, &nbsp;Exact, &nbsp;MYOB), &nbsp;online marketing (SEO, PPC, social marketing), and special Ecommerce hosting.</p>\r\n\r\n<p style=\"text-align: justify;\">Holbi &nbsp;is &nbsp;always &nbsp;happy &nbsp;to &nbsp;offer &nbsp;a &nbsp;full range of services to your business!</p>',1,'Holbi','HOLBI Group Contact page','','header',0,'NONSSL','Holbi Group is a leading provider of Ecommerce solutions for SMEs and global corporations. A  60+  strong team, we have industry&#039;s best Ecommerce web developers, designers,  QA engineers, and project managers.','','holbi','','2017-07-25 00:00:00','2022-07-25 11:02:50',0,1,'',0,0,'','HOLBI','','','',0,'0',0,0),(10,28,'1',0,'Holbi','<p style=\"text-align: justify;\"><a href=\"https://www.holbi.co.uk/\">Holbi Group</a>&nbsp;is a leading provider of Ecommerce solutions for SMEs and global corporations.</p>\r\n\r\n<p style=\"text-align: justify;\">A &nbsp;60+ &nbsp;<a href=\"https://www.holbi.co.uk/our-team\">strong team</a>, we have industry&#39;s best Ecommerce web developers, designers, &nbsp;QA engineers, and project managers available to create new solutions and improve existing ones.</p>\r\n\r\n<p style=\"text-align: justify;\">More than&nbsp;half &nbsp;of &nbsp;our &nbsp;business &nbsp;is &nbsp;about &nbsp;Ecommerce &nbsp;development. &nbsp;We manufacture our own Ecommerce open source platform osCommerce and also create &nbsp;Ecommerce websites for our clients from all over the world. At Holbi &nbsp;we &nbsp;enjoy &nbsp;working &nbsp;on &nbsp;challenging &nbsp;projects &nbsp;with complicated specifications, &nbsp;multiple integrations with 3rd parties, websites that trade in different international markets.</p>\r\n\r\n<p style=\"text-align: justify;\">Besides &nbsp;Ecommerce &nbsp;development we have departments that specialise in Customer &nbsp;support &nbsp;solutions &nbsp;(mostly based on Kayako), Accounting and ERP integrations (software that integrates Ecommerce with the likes of Sage, &nbsp;QuickBooks, &nbsp;Exact, &nbsp;MYOB), &nbsp;online marketing (SEO, PPC, social marketing), and special Ecommerce hosting.</p>\r\n\r\n<p style=\"text-align: justify;\">Holbi &nbsp;is &nbsp;always &nbsp;happy &nbsp;to &nbsp;offer &nbsp;a &nbsp;full range of services to your business!</p>',1,'Holbi','HOLBI Group Contact page','','header',0,'NONSSL','Holbi Group is a leading provider of Ecommerce solutions for SMEs and global corporations. A  60+  strong team, we have industry&#039;s best Ecommerce web developers, designers,  QA engineers, and project managers.','','holbi','','2017-07-25 00:00:00','2022-07-25 11:02:50',0,1,'',0,0,'','HOLBI','','','',0,'0',0,0),(1,29,'1',0,'eCommerce development','<p><a href=\"https://holbi.co.uk\">Holbi</a> &nbsp;has been involved into <a href=\"https://www.oscommerce.com\">Ecommerce development</a> since 2002 when we created and successfully launched the first several Ecommerce websites of &nbsp;our &nbsp;customers &nbsp;in &nbsp;the &nbsp;UK &nbsp;and &nbsp;USA. Since then we developed and launched over 2,000 online shops in multiple countries.</p>\r\n\r\n<p><a href=\"https://www.oscommerce.com\">Ecommerce &nbsp;development</a> is not just about development. First of all, we interview &nbsp; our &nbsp;client &nbsp;and &nbsp;assess &nbsp;their &nbsp;business, &nbsp;their &nbsp;current website(s), &nbsp; websites &nbsp; of &nbsp; their &nbsp;competitors. We aim to understand strategic &nbsp;goals &nbsp; of &nbsp; our &nbsp; client &nbsp;so &nbsp;that &nbsp;the &nbsp;Ecommerce website would &nbsp;not &nbsp;just address current needs but provide a reliable platform<br />\r\nfor growth and flexibility in the future.</p>\r\n\r\n<p>Then we create a map of business processes and see how the new website will fit into it.</p>\r\n\r\n<p>The &nbsp;next &nbsp;step &nbsp;includes &nbsp;creating &nbsp;of &nbsp;a &nbsp;wireframe &nbsp;model that will describe &nbsp;the &nbsp;architecture &nbsp;of &nbsp;the &nbsp;new website and explain the main interactions, involving users of different roles.</p>\r\n\r\n<p>After &nbsp;that &nbsp;we &nbsp;create unique graphic design or use existing graphics and integrate it with the Ecommerce engine - osCommerce.</p>\r\n\r\n<p>Finally, &nbsp;we &nbsp;add &nbsp;various &nbsp;features, &nbsp;run &nbsp;tests &nbsp;before &nbsp;the site is presented to the client for acceptance testing.</p>\r\n\r\n<p><a href=\"https://www.oscommerce.com\">Ecommerce &nbsp;development</a> from <a href=\"https://holbi.co.uk\">Holbi</a> also involves site launch. We have a special &nbsp; Ecommerce &nbsp; Hosting &nbsp;department &nbsp;that &nbsp;deals &nbsp;with &nbsp;servers, configurations and maintenance.</p>\r\n\r\n<p>The &nbsp; work &nbsp;doesn&#39;t &nbsp;stop at the site launch. As our client&#39;s business develops &nbsp;we &nbsp;are often asked to support and maintain the website, add more features, or create additional Ecommerce front ends.</p>\r\n\r\n<p>&nbsp;</p>',1,'eCommerce development','Ecommerce development','','header',0,'NONSSL','Holbi has been involved into Ecommerce development since 2002 when we created and successfully launched the first several Ecommerce websites of  our  customers  in  the  UK  and  USA. Since then we developed and launched over 2,000 online shops.','','ecommerce-development','','2017-08-02 00:00:00','2022-07-25 11:16:29',0,1,'',0,0,'','Holbi Ecommerce development','','','',0,'0',0,0),(7,29,'1',0,'eCommerce development','<p><a href=\"https://holbi.co.uk\">Holbi</a> &nbsp;has been involved into <a href=\"https://www.oscommerce.com\">Ecommerce development</a> since 2002 when we created and successfully launched the first several Ecommerce websites of &nbsp;our &nbsp;customers &nbsp;in &nbsp;the &nbsp;UK &nbsp;and &nbsp;USA. Since then we developed and launched over 2,000 online shops in multiple countries.</p>\r\n\r\n<p><a href=\"https://www.oscommerce.com\">Ecommerce &nbsp;development</a> is not just about development. First of all, we interview &nbsp; our &nbsp;client &nbsp;and &nbsp;assess &nbsp;their &nbsp;business, &nbsp;their &nbsp;current website(s), &nbsp; websites &nbsp; of &nbsp; their &nbsp;competitors. We aim to understand strategic &nbsp;goals &nbsp; of &nbsp; our &nbsp; client &nbsp;so &nbsp;that &nbsp;the &nbsp;Ecommerce website would &nbsp;not &nbsp;just address current needs but provide a reliable platform<br />\r\nfor growth and flexibility in the future.</p>\r\n\r\n<p>Then we create a map of business processes and see how the new website will fit into it.</p>\r\n\r\n<p>The &nbsp;next &nbsp;step &nbsp;includes &nbsp;creating &nbsp;of &nbsp;a &nbsp;wireframe &nbsp;model that will describe &nbsp;the &nbsp;architecture &nbsp;of &nbsp;the &nbsp;new website and explain the main interactions, involving users of different roles.</p>\r\n\r\n<p>After &nbsp;that &nbsp;we &nbsp;create unique graphic design or use existing graphics and integrate it with the Ecommerce engine - osCommerce.</p>\r\n\r\n<p>Finally, &nbsp;we &nbsp;add &nbsp;various &nbsp;features, &nbsp;run &nbsp;tests &nbsp;before &nbsp;the site is presented to the client for acceptance testing.</p>\r\n\r\n<p><a href=\"https://oscommerce.com\">Ecommerce &nbsp;development</a> from <a href=\"https://holbi.co.uk\">Holbi</a> also involves site launch. We have a special &nbsp; Ecommerce &nbsp; Hosting &nbsp;department &nbsp;that &nbsp;deals &nbsp;with &nbsp;servers, configurations and maintenance.</p>\r\n\r\n<p>The &nbsp; work &nbsp;doesn&#39;t &nbsp;stop at the site launch. As our client&#39;s business develops &nbsp;we &nbsp;are often asked to support and maintain the website, add more features, or create additional Ecommerce front ends.</p>',1,'eCommerce development','Ecommerce development','','header',0,'NONSSL','Holbi has been involved into Ecommerce development since 2002 when we created and successfully launched the first several Ecommerce websites of  our  customers  in  the  UK  and  USA. Since then we developed and launched over 2,000 online shops.','','ecommerce-development','','2017-08-02 00:00:00','2022-07-25 11:16:29',0,1,'',0,0,'','Holbi Ecommerce development','','','',0,'0',0,0),(8,29,'1',0,'eCommerce development','<p><a href=\"https://holbi.co.uk\">Holbi</a> &nbsp;has been involved into <a href=\"https://www.oscommerce.com\">Ecommerce development</a> since 2002 when we created and successfully launched the first several Ecommerce websites of &nbsp;our &nbsp;customers &nbsp;in &nbsp;the &nbsp;UK &nbsp;and &nbsp;USA. Since then we developed and launched over 2,000 online shops in multiple countries.</p>\r\n\r\n<p><a href=\"https://www.oscommerce.com\">Ecommerce &nbsp;development</a> is not just about development. First of all, we interview &nbsp; our &nbsp;client &nbsp;and &nbsp;assess &nbsp;their &nbsp;business, &nbsp;their &nbsp;current website(s), &nbsp; websites &nbsp; of &nbsp; their &nbsp;competitors. We aim to understand strategic &nbsp;goals &nbsp; of &nbsp; our &nbsp; client &nbsp;so &nbsp;that &nbsp;the &nbsp;Ecommerce website would &nbsp;not &nbsp;just address current needs but provide a reliable platform<br />\r\nfor growth and flexibility in the future.</p>\r\n\r\n<p>Then we create a map of business processes and see how the new website will fit into it.</p>\r\n\r\n<p>The &nbsp;next &nbsp;step &nbsp;includes &nbsp;creating &nbsp;of &nbsp;a &nbsp;wireframe &nbsp;model that will describe &nbsp;the &nbsp;architecture &nbsp;of &nbsp;the &nbsp;new website and explain the main interactions, involving users of different roles.</p>\r\n\r\n<p>After &nbsp;that &nbsp;we &nbsp;create unique graphic design or use existing graphics and integrate it with the Ecommerce engine - osCommerce.</p>\r\n\r\n<p>Finally, &nbsp;we &nbsp;add &nbsp;various &nbsp;features, &nbsp;run &nbsp;tests &nbsp;before &nbsp;the site is presented to the client for acceptance testing.</p>\r\n\r\n<p><a href=\"https://oscommerce.com\">Ecommerce &nbsp;development</a> from <a href=\"https://holbi.co.uk\">Holbi</a> also involves site launch. We have a special &nbsp; Ecommerce &nbsp; Hosting &nbsp;department &nbsp;that &nbsp;deals &nbsp;with &nbsp;servers, configurations and maintenance.</p>\r\n\r\n<p>The &nbsp; work &nbsp;doesn&#39;t &nbsp;stop at the site launch. As our client&#39;s business develops &nbsp;we &nbsp;are often asked to support and maintain the website, add more features, or create additional Ecommerce front ends.</p>',1,'eCommerce development','Ecommerce development','','header',0,'NONSSL','Holbi has been involved into Ecommerce development since 2002 when we created and successfully launched the first several Ecommerce websites of  our  customers  in  the  UK  and  USA. Since then we developed and launched over 2,000 online shops.','','ecommerce-development','','2017-08-02 00:00:00','2022-07-25 11:16:29',0,1,'',0,0,'','Holbi Ecommerce development','','','',0,'0',0,0),(9,29,'1',0,'eCommerce development','<p><a href=\"https://holbi.co.uk\">Holbi</a> &nbsp;has been involved into <a href=\"https://www.oscommerce.com\">Ecommerce development</a> since 2002 when we created and successfully launched the first several Ecommerce websites of &nbsp;our &nbsp;customers &nbsp;in &nbsp;the &nbsp;UK &nbsp;and &nbsp;USA. Since then we developed and launched over 2,000 online shops in multiple countries.</p>\r\n\r\n<p><a href=\"https://www.oscommerce.com\">Ecommerce &nbsp;development</a> is not just about development. First of all, we interview &nbsp; our &nbsp;client &nbsp;and &nbsp;assess &nbsp;their &nbsp;business, &nbsp;their &nbsp;current website(s), &nbsp; websites &nbsp; of &nbsp; their &nbsp;competitors. We aim to understand strategic &nbsp;goals &nbsp; of &nbsp; our &nbsp; client &nbsp;so &nbsp;that &nbsp;the &nbsp;Ecommerce website would &nbsp;not &nbsp;just address current needs but provide a reliable platform<br />\r\nfor growth and flexibility in the future.</p>\r\n\r\n<p>Then we create a map of business processes and see how the new website will fit into it.</p>\r\n\r\n<p>The &nbsp;next &nbsp;step &nbsp;includes &nbsp;creating &nbsp;of &nbsp;a &nbsp;wireframe &nbsp;model that will describe &nbsp;the &nbsp;architecture &nbsp;of &nbsp;the &nbsp;new website and explain the main interactions, involving users of different roles.</p>\r\n\r\n<p>After &nbsp;that &nbsp;we &nbsp;create unique graphic design or use existing graphics and integrate it with the Ecommerce engine - osCommerce.</p>\r\n\r\n<p>Finally, &nbsp;we &nbsp;add &nbsp;various &nbsp;features, &nbsp;run &nbsp;tests &nbsp;before &nbsp;the site is presented to the client for acceptance testing.</p>\r\n\r\n<p><a href=\"https://oscommerce.com\">Ecommerce &nbsp;development</a> from <a href=\"https://holbi.co.uk\">Holbi</a> also involves site launch. We have a special &nbsp; Ecommerce &nbsp; Hosting &nbsp;department &nbsp;that &nbsp;deals &nbsp;with &nbsp;servers, configurations and maintenance.</p>\r\n\r\n<p>The &nbsp; work &nbsp;doesn&#39;t &nbsp;stop at the site launch. As our client&#39;s business develops &nbsp;we &nbsp;are often asked to support and maintain the website, add more features, or create additional Ecommerce front ends.</p>',1,'eCommerce development','Ecommerce development','','header',0,'NONSSL','Holbi has been involved into Ecommerce development since 2002 when we created and successfully launched the first several Ecommerce websites of  our  customers  in  the  UK  and  USA. Since then we developed and launched over 2,000 online shops.','','ecommerce-development','','2017-08-02 00:00:00','2022-07-25 11:16:29',0,1,'',0,0,'','Holbi Ecommerce development','','','',0,'0',0,0),(10,29,'1',0,'eCommerce development','<p><a href=\"https://holbi.co.uk\">Holbi</a> &nbsp;has been involved into <a href=\"https://www.oscommerce.com\">Ecommerce development</a> since 2002 when we created and successfully launched the first several Ecommerce websites of &nbsp;our &nbsp;customers &nbsp;in &nbsp;the &nbsp;UK &nbsp;and &nbsp;USA. Since then we developed and launched over 2,000 online shops in multiple countries.</p>\r\n\r\n<p><a href=\"https://www.oscommerce.com\">Ecommerce &nbsp;development</a> is not just about development. First of all, we interview &nbsp; our &nbsp;client &nbsp;and &nbsp;assess &nbsp;their &nbsp;business, &nbsp;their &nbsp;current website(s), &nbsp; websites &nbsp; of &nbsp; their &nbsp;competitors. We aim to understand strategic &nbsp;goals &nbsp; of &nbsp; our &nbsp; client &nbsp;so &nbsp;that &nbsp;the &nbsp;Ecommerce website would &nbsp;not &nbsp;just address current needs but provide a reliable platform<br />\r\nfor growth and flexibility in the future.</p>\r\n\r\n<p>Then we create a map of business processes and see how the new website will fit into it.</p>\r\n\r\n<p>The &nbsp;next &nbsp;step &nbsp;includes &nbsp;creating &nbsp;of &nbsp;a &nbsp;wireframe &nbsp;model that will describe &nbsp;the &nbsp;architecture &nbsp;of &nbsp;the &nbsp;new website and explain the main interactions, involving users of different roles.</p>\r\n\r\n<p>After &nbsp;that &nbsp;we &nbsp;create unique graphic design or use existing graphics and integrate it with the Ecommerce engine - osCommerce.</p>\r\n\r\n<p>Finally, &nbsp;we &nbsp;add &nbsp;various &nbsp;features, &nbsp;run &nbsp;tests &nbsp;before &nbsp;the site is presented to the client for acceptance testing.</p>\r\n\r\n<p><a href=\"https://oscommerce.com\">Ecommerce &nbsp;development</a> from <a href=\"https://holbi.co.uk\">Holbi</a> also involves site launch. We have a special &nbsp; Ecommerce &nbsp; Hosting &nbsp;department &nbsp;that &nbsp;deals &nbsp;with &nbsp;servers, configurations and maintenance.</p>\r\n\r\n<p>The &nbsp; work &nbsp;doesn&#39;t &nbsp;stop at the site launch. As our client&#39;s business develops &nbsp;we &nbsp;are often asked to support and maintain the website, add more features, or create additional Ecommerce front ends.</p>',1,'eCommerce development','Ecommerce development','','header',0,'NONSSL','Holbi has been involved into Ecommerce development since 2002 when we created and successfully launched the first several Ecommerce websites of  our  customers  in  the  UK  and  USA. Since then we developed and launched over 2,000 online shops.','','ecommerce-development','','2017-08-02 00:00:00','2022-07-25 11:16:29',0,1,'',0,0,'','Holbi Ecommerce development','','','',0,'0',0,0),(1,30,'1',0,'Powered by osCommerce','<p>Powered by <a href=\"https://www.oscommerce.com\">osCommerce</a></p>\r\n\r\n<p>osCommerce &nbsp;is &nbsp;an &nbsp;open &nbsp;source &nbsp;Ecommerce platform produced by Holbi Group in the UK and designed for global market.</p>\r\n\r\n<p>Based &nbsp;on &nbsp;the &nbsp;latest &nbsp;versions &nbsp;of &nbsp;PHP &nbsp;and mySQL, it is one of the fastest &nbsp;shopping &nbsp;cart &nbsp;solutions &nbsp;on &nbsp;the market. However it is also compatible &nbsp; with &nbsp;some &nbsp;previous versions of PHP and mySQL to make it widely available.</p>\r\n\r\n<p>osCommerce &nbsp;can &nbsp;be &nbsp;used &nbsp;by &nbsp;SMEs and global corporations, as it has features and simplicity to satisfy all users.</p>\r\n\r\n<p>It &nbsp;comes &nbsp;full &nbsp;of built in features, and a number of additional plugins.</p>\r\n\r\n<p>USPs include:</p>\r\n\r\n<p>- multiple front ends</p>\r\n\r\n<p>- themes</p>\r\n\r\n<p>- visual theme designer</p>\r\n\r\n<p>- responsive design</p>\r\n\r\n<p>- full site control via the CMS</p>\r\n\r\n<p>- SEO friendly</p>\r\n\r\n<p>- support for configurable products</p>\r\n\r\n<p>- advanced product management and pricing</p>\r\n\r\n<p><br />\r\nAdditional plugins are available:</p>\r\n\r\n<p>- Amazon and eBay integration</p>\r\n\r\n<p>- accounting software integration (Sage, QuickBooks, Exact, MYOB)</p>\r\n\r\n<p>- visual product designer&nbsp;<br />\r\n&nbsp;</p>',1,'Powered by osCommerce','What is osCommerce by holbi group','','header',0,'NONSSL','osCommerce is an open source Ecommerce platform produced by Holbi Group in the UK and designed for global market.','','oscommerce','','2017-08-02 00:00:00','2022-07-25 11:14:25',0,1,'',0,0,'','What is osCommerce','','','',0,'0',0,0),(7,30,'1',0,'Powered by osCommerce','<p>Powered by <a href=\"https://www.oscommerce.com\">osCommerce</a></p>\r\n\r\n<p>osCommerce &nbsp;is &nbsp;an &nbsp;open &nbsp;source &nbsp;Ecommerce platform produced by Holbi Group in the UK and designed for global market.</p>\r\n\r\n<p>Based &nbsp;on &nbsp;the &nbsp;latest &nbsp;versions &nbsp;of &nbsp;PHP &nbsp;and mySQL, it is one of the fastest &nbsp;shopping &nbsp;cart &nbsp;solutions &nbsp;on &nbsp;the market. However it is also compatible &nbsp; with &nbsp;some &nbsp;previous versions of PHP and mySQL to make it widely available.</p>\r\n\r\n<p>osCommerce &nbsp;can &nbsp;be &nbsp;used &nbsp;by &nbsp;SMEs and global corporations, as it has features and simplicity to satisfy all users.</p>\r\n\r\n<p>It &nbsp;comes &nbsp;full &nbsp;of built in features, and a number of additional plugins.</p>\r\n\r\n<p>USPs include:</p>\r\n\r\n<p>- multiple front ends</p>\r\n\r\n<p>- themes</p>\r\n\r\n<p>- visual theme designer</p>\r\n\r\n<p>- responsive design</p>\r\n\r\n<p>- full site control via the CMS</p>\r\n\r\n<p>- SEO friendly</p>\r\n\r\n<p>- support for configurable products</p>\r\n\r\n<p>- advanced product management and pricing</p>\r\n\r\n<p><br />\r\nAdditional plugins are available:</p>\r\n\r\n<p>- Amazon and eBay integration</p>\r\n\r\n<p>- accounting software integration (Sage, QuickBooks, Exact, MYOB)</p>\r\n\r\n<p>- visual product designer&nbsp;</p>',1,'Powered by osCommerce','What is osCommerce by holbi group','','header',0,'NONSSL','osCommerce is an open source Ecommerce platform produced by Holbi Group in the UK and designed for global market.','','oscommerce','','2017-08-02 00:00:00','2022-07-25 11:14:25',0,1,'',0,0,'','What is osCommerce','','','',0,'0',0,0),(8,30,'1',0,'Powered by osCommerce','<p>Powered by <a href=\"https://www.oscommerce.com\">osCommerce</a></p>\r\n\r\n<p>osCommerce &nbsp;is &nbsp;an &nbsp;open &nbsp;source &nbsp;Ecommerce platform produced by Holbi Group in the UK and designed for global market.</p>\r\n\r\n<p>Based &nbsp;on &nbsp;the &nbsp;latest &nbsp;versions &nbsp;of &nbsp;PHP &nbsp;and mySQL, it is one of the fastest &nbsp;shopping &nbsp;cart &nbsp;solutions &nbsp;on &nbsp;the market. However it is also compatible &nbsp; with &nbsp;some &nbsp;previous versions of PHP and mySQL to make it widely available.</p>\r\n\r\n<p>osCommerce &nbsp;can &nbsp;be &nbsp;used &nbsp;by &nbsp;SMEs and global corporations, as it has features and simplicity to satisfy all users.</p>\r\n\r\n<p>It &nbsp;comes &nbsp;full &nbsp;of built in features, and a number of additional plugins.</p>\r\n\r\n<p>USPs include:</p>\r\n\r\n<p>- multiple front ends</p>\r\n\r\n<p>- themes</p>\r\n\r\n<p>- visual theme designer</p>\r\n\r\n<p>- responsive design</p>\r\n\r\n<p>- full site control via the CMS</p>\r\n\r\n<p>- SEO friendly</p>\r\n\r\n<p>- support for configurable products</p>\r\n\r\n<p>- advanced product management and pricing</p>\r\n\r\n<p><br />\r\nAdditional plugins are available:</p>\r\n\r\n<p>- Amazon and eBay integration</p>\r\n\r\n<p>- accounting software integration (Sage, QuickBooks, Exact, MYOB)</p>\r\n\r\n<p>- visual product designer&nbsp;</p>',1,'Powered by osCommerce','What is osCommerce by holbi group','','header',0,'NONSSL','osCommerce is an open source Ecommerce platform produced by Holbi Group in the UK and designed for global market.','','oscommerce','','2017-08-02 00:00:00','2022-07-25 11:14:25',0,1,'',0,0,'','What is osCommerce','','','',0,'0',0,0),(9,30,'1',0,'Powered by osCommerce','<p>Powered by <a href=\"https://www.oscommerce.com\">osCommerce</a></p>\r\n\r\n<p>osCommerce &nbsp;is &nbsp;an &nbsp;open &nbsp;source &nbsp;Ecommerce platform produced by Holbi Group in the UK and designed for global market.</p>\r\n\r\n<p>Based &nbsp;on &nbsp;the &nbsp;latest &nbsp;versions &nbsp;of &nbsp;PHP &nbsp;and mySQL, it is one of the fastest &nbsp;shopping &nbsp;cart &nbsp;solutions &nbsp;on &nbsp;the market. However it is also compatible &nbsp; with &nbsp;some &nbsp;previous versions of PHP and mySQL to make it widely available.</p>\r\n\r\n<p>osCommerce &nbsp;can &nbsp;be &nbsp;used &nbsp;by &nbsp;SMEs and global corporations, as it has features and simplicity to satisfy all users.</p>\r\n\r\n<p>It &nbsp;comes &nbsp;full &nbsp;of built in features, and a number of additional plugins.</p>\r\n\r\n<p>USPs include:</p>\r\n\r\n<p>- multiple front ends</p>\r\n\r\n<p>- themes</p>\r\n\r\n<p>- visual theme designer</p>\r\n\r\n<p>- responsive design</p>\r\n\r\n<p>- full site control via the CMS</p>\r\n\r\n<p>- SEO friendly</p>\r\n\r\n<p>- support for configurable products</p>\r\n\r\n<p>- advanced product management and pricing</p>\r\n\r\n<p><br />\r\nAdditional plugins are available:</p>\r\n\r\n<p>- Amazon and eBay integration</p>\r\n\r\n<p>- accounting software integration (Sage, QuickBooks, Exact, MYOB)</p>\r\n\r\n<p>- visual product designer&nbsp;</p>',1,'Powered by osCommerce','What is osCommerce by holbi group','','header',0,'NONSSL','osCommerce is an open source Ecommerce platform produced by Holbi Group in the UK and designed for global market.','','oscommerce','','2017-08-02 00:00:00','2022-07-25 11:14:25',0,1,'',0,0,'','What is osCommerce','','','',0,'0',0,0),(10,30,'1',0,'Powered by osCommerce','<p>Powered by <a href=\"https://www.oscommerce.com\">osCommerce</a></p>\r\n\r\n<p>osCommerce &nbsp;is &nbsp;an &nbsp;open &nbsp;source &nbsp;Ecommerce platform produced by Holbi Group in the UK and designed for global market.</p>\r\n\r\n<p>Based &nbsp;on &nbsp;the &nbsp;latest &nbsp;versions &nbsp;of &nbsp;PHP &nbsp;and mySQL, it is one of the fastest &nbsp;shopping &nbsp;cart &nbsp;solutions &nbsp;on &nbsp;the market. However it is also compatible &nbsp; with &nbsp;some &nbsp;previous versions of PHP and mySQL to make it widely available.</p>\r\n\r\n<p>osCommerce &nbsp;can &nbsp;be &nbsp;used &nbsp;by &nbsp;SMEs and global corporations, as it has features and simplicity to satisfy all users.</p>\r\n\r\n<p>It &nbsp;comes &nbsp;full &nbsp;of built in features, and a number of additional plugins.</p>\r\n\r\n<p>USPs include:</p>\r\n\r\n<p>- multiple front ends</p>\r\n\r\n<p>- themes</p>\r\n\r\n<p>- visual theme designer</p>\r\n\r\n<p>- responsive design</p>\r\n\r\n<p>- full site control via the CMS</p>\r\n\r\n<p>- SEO friendly</p>\r\n\r\n<p>- support for configurable products</p>\r\n\r\n<p>- advanced product management and pricing</p>\r\n\r\n<p><br />\r\nAdditional plugins are available:</p>\r\n\r\n<p>- Amazon and eBay integration</p>\r\n\r\n<p>- accounting software integration (Sage, QuickBooks, Exact, MYOB)</p>\r\n\r\n<p>- visual product designer&nbsp;</p>',1,'Powered by osCommerce','What is osCommerce by holbi group','','header',0,'NONSSL','osCommerce is an open source Ecommerce platform produced by Holbi Group in the UK and designed for global market.','','oscommerce','','2017-08-02 00:00:00','2022-07-25 11:14:25',0,1,'',0,0,'','What is osCommerce','','','',0,'0',0,0),(1,36,'1',0,'Testimonials','',1,'Testimonials','Site testimonials section','','header',0,'NONSSL','Allow your cliets to write testimonials with Ecommerce platform : osCommerce by Holbi','','testimonials','','2018-03-06 00:00:00','2021-11-03 16:10:27',0,0,'Testimonials',0,0,'','Testimonials feature','','','',0,'0',0,0),(7,36,'1',0,'Testimonials','',1,'Testimonials','Site testimonials section','','header',0,'NONSSL','Allow your cliets to write testimonials with Ecommerce platform : osCommerce by Holbi','','testimonials','','2018-03-06 00:00:00','2021-11-03 16:10:27',0,0,'Testimonials',0,0,'','Testimonials feature','','','',0,'0',0,0),(8,36,'1',0,'Testimonials','',1,'Testimonials','Site testimonials section','','header',0,'NONSSL','Allow your cliets to write testimonials with Ecommerce platform : osCommerce by Holbi','','testimonials','','2018-03-06 00:00:00','2021-11-03 16:10:27',0,0,'Testimonials',0,0,'','Testimonials feature','','','',0,'0',0,0),(1,37,'1',0,'Personal data and its handling','<p><strong>1. Personal data is data about an individual who can be identified from that data</strong></p>\r\n\r\n<p>Data Collector is a person or entity that collects personal data. Holbi is a Data Collector of personal data of our customers. We require to know who we communicate with in order to conduct business with you. Communication can be performed via email, telephone, various messengers, virtual meeting solutions, etc.</p>\r\n\r\n<p>Data Processor is a person or entity that processes personal data. Holbi is a Data Processor of personal data of consumers of some of our customers. Holbi doesn&rsquo;t require your consumer data as such, however may occasionally require to access it in order to run tests of various solutions requested by you.</p>\r\n\r\n<p>In case you have your website(s) hosted with Holbi, Holbi automatically holds personal data of your consumers, however still doesn&rsquo;t access it without your explicit request.</p>\r\n\r\n<p>Personal data may include name, address, email address, social profile information. However it will never include credit card data.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>2. Your rights to access, edit, and remove Personal data</strong></p>\r\n\r\n<p>As customer of Holbi you have the right to request information about which data is held by Holbi about you. To do it, please .</p>\r\n\r\n<p>You can always request to have your personal data updated to keep it up to date. Please contact us to do it.</p>\r\n\r\n<p>You can ask to have your personal data removed from our systems. Please note this will stop us from being able to conduct business with you, and will result into immediate cancellation of any and all works being performed for you by Holbi, unless you nominate new contact instead of yourself.</p>\r\n\r\n<p>As our customers you have full access to the personal data of your consumers. You can access it, edit where necessary, or remove it. Your decision to remove all personal data from our servers will result into cessation of hosting services if such were provided.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>3. Personal data storage</strong></p>\r\n\r\n<p>Holbi stores personal information to be access by relevant authorised personnel only, and only when required to perform services as per your instructions. Personal information is held for an unlimited amount of time, securely, distributed amongst relevant authorised personnel, as, due to the nature of business, it may be required in the future to contact you in regards to a change in technology, security update, etc. related to your systems developed or provided by Holbi.</p>\r\n\r\n<p>In case you host your websites with Holbi, personal data of your customers is stored on secure Holbi servers located in secure data centres. Access to such servers by Holbi personnel is only possible following a request from you to perform certain development or maintenance activities. No data is copied to storage or saved locally in Holbi offices. No data leaves Holbi offices.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>4. Security and confidentiality</strong></p>\r\n\r\n<p>Physical access to Holbi offices is limited to authorised personnel only.</p>\r\n\r\n<p>All computers are password protected. All computers have the latest anti-virus software installed, and operation systems are most up to date at all times.</p>\r\n\r\n<p>Networks are protected by intrusion detection and prevention systems, no access to Holbi&rsquo;s internal networks is possible from the outside without authorization. Network access logs are reviewed daily.</p>\r\n\r\n<p>All Holbi personnel has confidentiality clause in their contracts.</p>\r\n\r\n<p>We have a very low turnover of staff at Holbi, however when someone leaves our company their accounts get terminated and all relevant passwords are immediately changed.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>5. Breaches and notifications</strong></p>\r\n\r\n<p>In case our systems get breached, we will immediately notify all parties affected via email, telephone, or other means of communication and inform them on the particulars of the issue and on our intended method to solve it.</p>',1,'Personal data and its handling','','','header',0,'NONSSL','','','personal-data-and-its-handling','','2021-11-03 00:00:00','2021-11-03 17:15:09',0,0,'',0,0,'','','','','',0,'0',0,0),(7,37,'1',0,'Personal data and its handling','<p><strong>1. Personal data is data about an individual who can be identified from that data</strong></p>\r\n\r\n<p>Data Collector is a person or entity that collects personal data. Holbi is a Data Collector of personal data of our customers. We require to know who we communicate with in order to conduct business with you. Communication can be performed via email, telephone, various messengers, virtual meeting solutions, etc.</p>\r\n\r\n<p>Data Processor is a person or entity that processes personal data. Holbi is a Data Processor of personal data of consumers of some of our customers. Holbi doesn&rsquo;t require your consumer data as such, however may occasionally require to access it in order to run tests of various solutions requested by you.</p>\r\n\r\n<p>In case you have your website(s) hosted with Holbi, Holbi automatically holds personal data of your consumers, however still doesn&rsquo;t access it without your explicit request.</p>\r\n\r\n<p>Personal data may include name, address, email address, social profile information. However it will never include credit card data.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>2. Your rights to access, edit, and remove Personal data</strong></p>\r\n\r\n<p>As customer of Holbi you have the right to request information about which data is held by Holbi about you. To do it, please .</p>\r\n\r\n<p>You can always request to have your personal data updated to keep it up to date. Please contact us to do it.</p>\r\n\r\n<p>You can ask to have your personal data removed from our systems. Please note this will stop us from being able to conduct business with you, and will result into immediate cancellation of any and all works being performed for you by Holbi, unless you nominate new contact instead of yourself.</p>\r\n\r\n<p>As our customers you have full access to the personal data of your consumers. You can access it, edit where necessary, or remove it. Your decision to remove all personal data from our servers will result into cessation of hosting services if such were provided.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>3. Personal data storage</strong></p>\r\n\r\n<p>Holbi stores personal information to be access by relevant authorised personnel only, and only when required to perform services as per your instructions. Personal information is held for an unlimited amount of time, securely, distributed amongst relevant authorised personnel, as, due to the nature of business, it may be required in the future to contact you in regards to a change in technology, security update, etc. related to your systems developed or provided by Holbi.</p>\r\n\r\n<p>In case you host your websites with Holbi, personal data of your customers is stored on secure Holbi servers located in secure data centres. Access to such servers by Holbi personnel is only possible following a request from you to perform certain development or maintenance activities. No data is copied to storage or saved locally in Holbi offices. No data leaves Holbi offices.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>4. Security and confidentiality</strong></p>\r\n\r\n<p>Physical access to Holbi offices is limited to authorised personnel only.</p>\r\n\r\n<p>All computers are password protected. All computers have the latest anti-virus software installed, and operation systems are most up to date at all times.</p>\r\n\r\n<p>Networks are protected by intrusion detection and prevention systems, no access to Holbi&rsquo;s internal networks is possible from the outside without authorization. Network access logs are reviewed daily.</p>\r\n\r\n<p>All Holbi personnel has confidentiality clause in their contracts.</p>\r\n\r\n<p>We have a very low turnover of staff at Holbi, however when someone leaves our company their accounts get terminated and all relevant passwords are immediately changed.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>5. Breaches and notifications</strong></p>\r\n\r\n<p>In case our systems get breached, we will immediately notify all parties affected via email, telephone, or other means of communication and inform them on the particulars of the issue and on our intended method to solve it.</p>',1,'Personal data and its handling','','','header',0,'NONSSL','','','personal-data-and-its-handling','','2021-11-03 00:00:00','2021-11-03 17:15:09',0,0,'',0,0,'','','','','',0,'0',0,0),(8,37,'1',0,'Personal data and its handling','<p><strong>1. Personal data is data about an individual who can be identified from that data</strong></p>\r\n\r\n<p>Data Collector is a person or entity that collects personal data. Holbi is a Data Collector of personal data of our customers. We require to know who we communicate with in order to conduct business with you. Communication can be performed via email, telephone, various messengers, virtual meeting solutions, etc.</p>\r\n\r\n<p>Data Processor is a person or entity that processes personal data. Holbi is a Data Processor of personal data of consumers of some of our customers. Holbi doesn&rsquo;t require your consumer data as such, however may occasionally require to access it in order to run tests of various solutions requested by you.</p>\r\n\r\n<p>In case you have your website(s) hosted with Holbi, Holbi automatically holds personal data of your consumers, however still doesn&rsquo;t access it without your explicit request.</p>\r\n\r\n<p>Personal data may include name, address, email address, social profile information. However it will never include credit card data.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>2. Your rights to access, edit, and remove Personal data</strong></p>\r\n\r\n<p>As customer of Holbi you have the right to request information about which data is held by Holbi about you. To do it, please .</p>\r\n\r\n<p>You can always request to have your personal data updated to keep it up to date. Please contact us to do it.</p>\r\n\r\n<p>You can ask to have your personal data removed from our systems. Please note this will stop us from being able to conduct business with you, and will result into immediate cancellation of any and all works being performed for you by Holbi, unless you nominate new contact instead of yourself.</p>\r\n\r\n<p>As our customers you have full access to the personal data of your consumers. You can access it, edit where necessary, or remove it. Your decision to remove all personal data from our servers will result into cessation of hosting services if such were provided.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>3. Personal data storage</strong></p>\r\n\r\n<p>Holbi stores personal information to be access by relevant authorised personnel only, and only when required to perform services as per your instructions. Personal information is held for an unlimited amount of time, securely, distributed amongst relevant authorised personnel, as, due to the nature of business, it may be required in the future to contact you in regards to a change in technology, security update, etc. related to your systems developed or provided by Holbi.</p>\r\n\r\n<p>In case you host your websites with Holbi, personal data of your customers is stored on secure Holbi servers located in secure data centres. Access to such servers by Holbi personnel is only possible following a request from you to perform certain development or maintenance activities. No data is copied to storage or saved locally in Holbi offices. No data leaves Holbi offices.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>4. Security and confidentiality</strong></p>\r\n\r\n<p>Physical access to Holbi offices is limited to authorised personnel only.</p>\r\n\r\n<p>All computers are password protected. All computers have the latest anti-virus software installed, and operation systems are most up to date at all times.</p>\r\n\r\n<p>Networks are protected by intrusion detection and prevention systems, no access to Holbi&rsquo;s internal networks is possible from the outside without authorization. Network access logs are reviewed daily.</p>\r\n\r\n<p>All Holbi personnel has confidentiality clause in their contracts.</p>\r\n\r\n<p>We have a very low turnover of staff at Holbi, however when someone leaves our company their accounts get terminated and all relevant passwords are immediately changed.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>5. Breaches and notifications</strong></p>\r\n\r\n<p>In case our systems get breached, we will immediately notify all parties affected via email, telephone, or other means of communication and inform them on the particulars of the issue and on our intended method to solve it.</p>',1,'Personal data and its handling','','','header',0,'NONSSL','','','personal-data-and-its-handling','','2021-11-03 00:00:00','2021-11-03 17:15:09',0,0,'',0,0,'','','','','',0,'0',0,0),(1,38,'0',0,'Warranty','Warranty',1,'Warranty','','','header',0,'NONSSL','','','warranty','','2022-01-18 00:00:00','2022-01-19 10:39:46',0,0,'',0,0,'','','','','',0,'0',0,0),(7,38,'1',0,'Warranty','Warranty',1,'Warranty','','','header',0,'NONSSL','','','warranty','','2022-01-18 00:00:00','2022-01-19 10:39:46',0,0,'',0,0,'','','','','',0,'0',0,0),(8,38,'0',0,'Warranty','Warranty',1,'Warranty','','','header',0,'NONSSL','','','warranty','','2022-01-18 00:00:00','2022-01-19 10:39:46',0,0,'',0,0,'','','','','',0,'0',0,0),(1,39,'0',0,'Shipping','',1,'Shipping','','','header',0,'NONSSL','','','shipping','','2022-01-18 00:00:00','2022-01-19 09:28:43',0,0,'',0,0,'','','','','',0,'0',0,0),(7,39,'1',0,'Shipping','Shipping',1,'Shipping','','','header',0,'NONSSL','','','shipping','','2022-01-18 00:00:00','2022-01-19 09:28:43',0,0,'',0,0,'','','','','',0,'0',0,0),(8,39,'0',0,'Shipping','',1,'Shipping','','','header',0,'NONSSL','','','shipping','','2022-01-18 00:00:00','2022-01-19 09:28:43',0,0,'',0,0,'','','','','',0,'0',0,0),(1,40,'0',0,'This is exmaple','<p>This is exmaple of how your b2b supermarket can look like.</p>\r\n&nbsp;\r\n\r\n<p>Text bellow can describes your future shop.</p>\r\n&nbsp;\r\n\r\n<p>&quot;We spend our days leaving no stone unturned in our hunt for the best products at the best prices, so you don&rsquo;t have to.</p>\r\n&nbsp;\r\n\r\n<p>So far we&rsquo;ve found 1000&rsquo;s of products, and in the process gained a thorough understanding of the needs of our customers. We know you&rsquo;re busy, so we want to make things as simple as possible for you with our huge stocks at your fingertips along with lots more products available from our specially selected partners.</p>\r\n&nbsp;\r\n\r\n<p>We&rsquo;ve spent a lot of time making sure our website brings ease of ordering to a whole new level. It&rsquo;s open 24/7 and packed with all the information you need, and you can buy with absolute confidence in the knowledge that our easy and free returns process means that you can return your order to us for a replacement or refund with no questions asked.&quot;</p>',1,'This is exmaple','','','header',0,'NONSSL','','','the-brainchild','','2022-02-18 00:00:00','2022-02-21 07:14:37',0,0,'',0,0,'','','','','',0,'0',0,0),(7,40,'0',0,'','',1,'','','','header',0,'NONSSL','','','','','2022-02-18 00:00:00','2022-02-21 07:14:37',0,0,'',0,0,'','','','','',0,'0',0,0),(8,40,'0',0,'','',1,'','','','header',0,'NONSSL','','','','','2022-02-18 00:00:00','2022-02-21 07:14:37',0,0,'',0,0,'','','','','',0,'0',0,0),(9,40,'1',0,'This is exmaple','<p>This is exmaple of how your b2b supermarket can look like.</p>\r\n&nbsp;\r\n\r\n<p>Text bellow can describes your future shop.</p>\r\n&nbsp;\r\n\r\n<p>&quot;We spend our days leaving no stone unturned in our hunt for the best products at the best prices, so you don&rsquo;t have to.</p>\r\n&nbsp;\r\n\r\n<p>So far we&rsquo;ve found 1000&rsquo;s of products, and in the process gained a thorough understanding of the needs of our customers. We know you&rsquo;re busy, so we want to make things as simple as possible for you with our huge stocks at your fingertips along with lots more products available from our specially selected partners.</p>\r\n&nbsp;\r\n\r\n<p>We&rsquo;ve spent a lot of time making sure our website brings ease of ordering to a whole new level. It&rsquo;s open 24/7 and packed with all the information you need, and you can buy with absolute confidence in the knowledge that our easy and free returns process means that you can return your order to us for a replacement or refund with no questions asked.&quot;</p>\r\nand free returns process means that you can return your order to us for a replacement or refund with no questions asked.',1,'This is exmaple','','','header',0,'NONSSL','','','the-brainchild','','2022-02-18 00:00:00','2022-02-21 07:14:37',0,0,'',0,0,'','','','','',0,'0',0,0),(10,40,'0',0,'','',1,'','','','header',0,'NONSSL','','','','','2022-02-18 00:00:00','2022-02-21 07:14:37',0,0,'',0,0,'','','','','',0,'0',0,0),(1,41,'1',0,'Contact Us','',1,'Contact Us','Contact us about ecommerce site creating','','header',0,'NONSSL','If you have any questions - contact us. Ecommerce Platform: osCommerce by Holbi','','contact','','2022-05-16 13:20:18',NULL,0,0,'contact',0,0,'','','Any questions? contact us\nosCommerce by Holbi','Paradise Farm, High street\nOpening hours\nMo - Fr (9:00-18:00)\nKempsford\nUnited Kingdom\nGL7 4EU','',0,'',0,0),(7,41,'1',0,'Contact Us','',1,'Contact Us','Contact us about ecommerce site creating','','header',0,'NONSSL','If you have any questions - contact us. Ecommerce Platform: osCommerce by Holbi','','contact','','2022-05-16 13:20:18',NULL,0,0,'contact',0,0,'','','Any questions? contact us\nosCommerce by Holbi','Paradise Farm, High street\nOpening hours\nMo - Fr (9:00-18:00)\nKempsford\nUnited Kingdom\nGL7 4EU','',0,'',0,0),(8,41,'1',0,'Contact Us','',1,'Contact Us','Contact us about ecommerce site creating','','header',0,'NONSSL','If you have any questions - contact us. Ecommerce Platform: osCommerce by Holbi','','contact','','2022-05-16 13:20:18',NULL,0,0,'contact',0,0,'','','Any questions? contact us\nosCommerce by Holbi','Paradise Farm, High street\nOpening hours\nMo - Fr (9:00-18:00)\nKempsford\nUnited Kingdom\nGL7 4EU','',0,'',0,0),(9,41,'1',0,'Contact Us','',1,'Contact Us','','','header',0,'NONSSL','','','contact','','2022-05-16 13:20:18',NULL,0,0,'contact',0,0,'','','','','',0,'',0,0),(10,41,'1',0,'Contact Us','',1,'Contact Us','','','header',0,'NONSSL','','','contact','','2022-05-16 13:20:18',NULL,0,0,'contact',0,0,'','','','','',0,'',0,0),(1,42,'0',0,'Delivery & Returns','',1,'Delivery & Returns','','','header',0,'NONSSL','','','delivery-returns','','2022-05-18 00:00:00','2022-07-25 09:54:56',0,0,'',0,0,'','','','','',0,'0',0,0),(7,42,'1',0,'Delivery & Returns','<h3>Delivery</h3>\r\n\r\n<p>Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<h3>Returns</h3>\r\n\r\n<p>At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti quos dolores et quas molestias excepturi sint occaecati cupiditate non provident, similique sunt in culpa qui officia deserunt mollitia animi, id est laborum et dolorum fuga.</p>\r\n\r\n<p>Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus. Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repellat.</p>',1,'Delivery & Returns','','','header',0,'NONSSL','','','delivery-returns','','2022-05-18 00:00:00','2022-07-25 09:54:56',0,0,'',0,0,'','','','','',0,'0',0,0),(8,42,'1',0,'Delivery & Returns','<h3>Delivery</h3>\r\n\r\n<p>Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<h3>Returns</h3>\r\n\r\n<p>At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti quos dolores et quas molestias excepturi sint occaecati cupiditate non provident, similique sunt in culpa qui officia deserunt mollitia animi, id est laborum et dolorum fuga.</p>\r\n\r\n<p>Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus. Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repellat.</p>',1,'Delivery & Returns','','','header',0,'NONSSL','','','delivery-returns','','2022-05-18 00:00:00','2022-07-25 09:54:56',0,0,'',0,0,'','','','','',0,'0',0,0),(9,42,'1',0,'Delivery & Returns','<h3>Delivery</h3>\r\n\r\n<p>Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<h3>Returns</h3>\r\n\r\n<p>At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti quos dolores et quas molestias excepturi sint occaecati cupiditate non provident, similique sunt in culpa qui officia deserunt mollitia animi, id est laborum et dolorum fuga.</p>\r\n\r\n<p>Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus. Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repellat.</p>',1,'Delivery & Returns','','','header',0,'NONSSL','','','delivery-returns','','2022-05-18 00:00:00','2022-07-25 09:54:56',0,0,'',0,0,'','','','','',0,'0',0,0),(10,42,'1',0,'Delivery & Returns','<h3>Delivery</h3>\r\n\r\n<p>Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<h3>Returns</h3>\r\n\r\n<p>At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti quos dolores et quas molestias excepturi sint occaecati cupiditate non provident, similique sunt in culpa qui officia deserunt mollitia animi, id est laborum et dolorum fuga.</p>\r\n\r\n<p>Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus. Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repellat.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p>&nbsp;</p>',1,'Delivery & Returns','','','header',0,'NONSSL','','','delivery-returns','','2022-05-18 00:00:00','2022-07-25 09:54:56',0,0,'',0,0,'','','','','',0,'0',0,0),(1,43,'0',0,'','',1,'Returns & Exchanges','','','header',0,'NONSSL','','','returns-exchanges','','2022-07-25 00:00:00','2022-07-25 09:58:26',0,0,'',0,0,'','','','','',0,'0',0,0),(7,43,'0',0,'','',1,'','','','header',0,'NONSSL','','','','','2022-07-25 00:00:00','2022-07-25 09:58:26',0,0,'',0,0,'','','','','',0,'0',0,0),(8,43,'0',0,'','',1,'','','','header',0,'NONSSL','','','','','2022-07-25 00:00:00','2022-07-25 09:58:26',0,0,'',0,0,'','','','','',0,'0',0,0),(9,43,'0',0,'','',1,'','','','header',0,'NONSSL','','','','','2022-07-25 00:00:00','2022-07-25 09:58:26',0,0,'',0,0,'','','','','',0,'0',0,0),(10,43,'1',0,'','<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</p>\r\n\r\n<p>&nbsp;</p>',1,'Returns & Exchanges','','','header',0,'NONSSL','','','returns-exchanges','','2022-07-25 00:00:00','2022-07-25 09:58:26',0,0,'',0,0,'','','','','',0,'0',0,0),(1,44,'0',0,'','',1,'Next business day','','','header',0,'NONSSL','','','next-business-day','','2022-07-25 00:00:00','2022-07-25 10:00:17',0,0,'',0,0,'','','','','',0,'0',0,0),(7,44,'0',0,'','',1,'','','','header',0,'NONSSL','','','','','2022-07-25 00:00:00','2022-07-25 10:00:17',0,0,'',0,0,'','','','','',0,'0',0,0),(8,44,'0',0,'','',1,'','','','header',0,'NONSSL','','','','','2022-07-25 00:00:00','2022-07-25 10:00:17',0,0,'',0,0,'','','','','',0,'0',0,0),(9,44,'0',0,'','',1,'','','','header',0,'NONSSL','','','','','2022-07-25 00:00:00','2022-07-25 10:00:17',0,0,'',0,0,'','','','','',0,'0',0,0),(10,44,'1',0,'','<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</p>\r\n\r\n<p>&nbsp;</p>',1,'Next business day','','','header',0,'NONSSL','','','next-business-day','','2022-07-25 00:00:00','2022-07-25 10:00:17',0,0,'',0,0,'','','','','',0,'0',0,0);
/*!40000 ALTER TABLE `information` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `install_ignore_list`
--

DROP TABLE IF EXISTS `install_ignore_list`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `install_ignore_list` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `path` varchar(255) DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `install_ignore_list`
--

LOCK TABLES `install_ignore_list` WRITE;
/*!40000 ALTER TABLE `install_ignore_list` DISABLE KEYS */;
/*!40000 ALTER TABLE `install_ignore_list` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `install_list_cache`
--

DROP TABLE IF EXISTS `install_list_cache`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `install_list_cache` (
  `admin_id` int(11) DEFAULT '0',
  `offset` varchar(32) DEFAULT '',
  `limit` varchar(32) DEFAULT '',
  `type` varchar(32) DEFAULT '',
  `search` varchar(255) DEFAULT '',
  `sort` varchar(32) DEFAULT '',
  `return` text,
  `date_added` datetime DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `install_list_cache`
--

LOCK TABLES `install_list_cache` WRITE;
/*!40000 ALTER TABLE `install_list_cache` DISABLE KEYS */;
/*!40000 ALTER TABLE `install_list_cache` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `installer`
--

DROP TABLE IF EXISTS `installer`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `installer` (
  `installer_id` int(11) NOT NULL AUTO_INCREMENT,
  `filename` varchar(128) DEFAULT NULL,
  `data` text,
  `date_added` datetime NOT NULL,
  `archive_type` varchar(32) NOT NULL DEFAULT '',
  `archive_class` varchar(128) NOT NULL DEFAULT '',
  `archive_version` decimal(15,4) NOT NULL DEFAULT '0.0000',
  PRIMARY KEY (`installer_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `installer`
--

LOCK TABLES `installer` WRITE;
/*!40000 ALTER TABLE `installer` DISABLE KEYS */;
/*!40000 ALTER TABLE `installer` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `inventory`
--

DROP TABLE IF EXISTS `inventory`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `inventory` (
  `inventory_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` varchar(255) NOT NULL DEFAULT '',
  `prid` int(11) NOT NULL DEFAULT '0',
  `products_name` varchar(255) NOT NULL DEFAULT '',
  `products_model` varchar(40) NOT NULL DEFAULT '',
  `products_quantity` int(11) NOT NULL DEFAULT '0',
  `allocated_stock_quantity` int(11) NOT NULL DEFAULT '0',
  `temporary_stock_quantity` int(11) NOT NULL DEFAULT '0',
  `warehouse_stock_quantity` int(11) NOT NULL DEFAULT '0',
  `suppliers_stock_quantity` int(11) NOT NULL DEFAULT '0',
  `ordered_stock_quantity` int(11) NOT NULL DEFAULT '0',
  `send_notification` int(1) NOT NULL DEFAULT '1',
  `products_ean` varchar(13) NOT NULL DEFAULT '',
  `products_asin` varchar(10) NOT NULL DEFAULT '',
  `products_isbn` varchar(13) NOT NULL DEFAULT '',
  `non_existent` tinyint(1) NOT NULL DEFAULT '0',
  `inventory_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `inventory_discount_price` varchar(255) NOT NULL DEFAULT '',
  `price_prefix` char(3) NOT NULL DEFAULT '+',
  `inventory_full_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `inventory_discount_full_price` varchar(255) NOT NULL DEFAULT '',
  `products_upc` varchar(13) NOT NULL DEFAULT '',
  `inventory_weight` decimal(6,3) NOT NULL DEFAULT '0.000',
  `stock_indication_id` int(11) NOT NULL DEFAULT '0',
  `stock_delivery_terms_id` int(11) NOT NULL DEFAULT '0',
  `supplier_price_manual` tinyint(1) DEFAULT NULL,
  `inventory_tax_class_id` int(4) DEFAULT NULL,
  `stock_control` int(4) NOT NULL DEFAULT '0',
  `allow_backorder` int(2) NOT NULL DEFAULT '0',
  `products_date_available` datetime DEFAULT NULL,
  PRIMARY KEY (`inventory_id`),
  UNIQUE KEY `products_id` (`products_id`),
  KEY `prid` (`prid`),
  KEY `inventory_model_IDX` (`products_model`(16)),
  KEY `inventory_ean_IDX` (`products_ean`),
  KEY `inventory_upc_IDX` (`products_upc`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `inventory`
--

LOCK TABLES `inventory` WRITE;
/*!40000 ALTER TABLE `inventory` DISABLE KEYS */;
/*!40000 ALTER TABLE `inventory` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `inventory_prices`
--

DROP TABLE IF EXISTS `inventory_prices`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `inventory_prices` (
  `inventory_id` int(11) NOT NULL,
  `products_id` varchar(255) NOT NULL DEFAULT '',
  `prid` int(11) NOT NULL DEFAULT '0',
  `groups_id` int(11) NOT NULL,
  `currencies_id` int(11) NOT NULL,
  `price_prefix` char(3) NOT NULL DEFAULT '+',
  `inventory_group_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `inventory_group_discount_price` varchar(255) NOT NULL DEFAULT '',
  `inventory_full_price` decimal(15,6) NOT NULL DEFAULT '-2.000000',
  `inventory_discount_full_price` varchar(255) NOT NULL DEFAULT '',
  `supplier_price_manual` tinyint(1) DEFAULT NULL,
  PRIMARY KEY (`inventory_id`,`groups_id`,`currencies_id`),
  UNIQUE KEY `unique_products_id` (`products_id`,`groups_id`,`currencies_id`),
  KEY `idx_products_id` (`products_id`),
  KEY `idx_prid` (`prid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `inventory_prices`
--

LOCK TABLES `inventory_prices` WRITE;
/*!40000 ALTER TABLE `inventory_prices` DISABLE KEYS */;
/*!40000 ALTER TABLE `inventory_prices` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `io_entity`
--

DROP TABLE IF EXISTS `io_entity`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `io_entity` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `project_id` int(11) NOT NULL,
  `entity_name` varchar(128) NOT NULL,
  PRIMARY KEY (`id`),
  KEY `project_id` (`project_id`),
  KEY `entity_name` (`entity_name`(24))
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `io_entity`
--

LOCK TABLES `io_entity` WRITE;
/*!40000 ALTER TABLE `io_entity` DISABLE KEYS */;
/*!40000 ALTER TABLE `io_entity` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `io_entity_mapping`
--

DROP TABLE IF EXISTS `io_entity_mapping`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `io_entity_mapping` (
  `entity_id` int(11) NOT NULL,
  `external_id` int(11) NOT NULL,
  `internal_id` int(11) NOT NULL,
  UNIQUE KEY `entity_id` (`entity_id`,`external_id`,`internal_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `io_entity_mapping`
--

LOCK TABLES `io_entity_mapping` WRITE;
/*!40000 ALTER TABLE `io_entity_mapping` DISABLE KEYS */;
/*!40000 ALTER TABLE `io_entity_mapping` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `io_project`
--

DROP TABLE IF EXISTS `io_project`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `io_project` (
  `project_id` int(11) NOT NULL AUTO_INCREMENT,
  `project_code` varchar(32) NOT NULL,
  `is_local` tinyint(1) NOT NULL DEFAULT '0',
  `department_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `description` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`project_id`),
  UNIQUE KEY `project_code` (`project_code`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `io_project`
--

LOCK TABLES `io_project` WRITE;
/*!40000 ALTER TABLE `io_project` DISABLE KEYS */;
INSERT INTO `io_project` VALUES (1,'MYAPPLICATI_61C1B2DE000003220113',1,0,0,'');
/*!40000 ALTER TABLE `io_project` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `klarna_order_reference`
--

DROP TABLE IF EXISTS `klarna_order_reference`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `klarna_order_reference` (
  `klarna_id` varchar(255) NOT NULL,
  `order_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`klarna_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `klarna_order_reference`
--

LOCK TABLES `klarna_order_reference` WRITE;
/*!40000 ALTER TABLE `klarna_order_reference` DISABLE KEYS */;
/*!40000 ALTER TABLE `klarna_order_reference` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `languages`
--

DROP TABLE IF EXISTS `languages`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `languages` (
  `languages_id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(32) NOT NULL DEFAULT '',
  `code` char(2) NOT NULL DEFAULT '',
  `image` varchar(64) DEFAULT NULL,
  `image_svg` varchar(64) DEFAULT NULL,
  `directory` varchar(32) DEFAULT NULL,
  `sort_order` int(3) DEFAULT NULL,
  `languages_status` int(1) NOT NULL DEFAULT '1',
  `locale` varchar(10) NOT NULL DEFAULT 'en_US',
  `shown_language` tinyint(4) NOT NULL DEFAULT '1',
  `searchable_language` tinyint(4) NOT NULL DEFAULT '1',
  `hide_in_admin` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`languages_id`),
  KEY `IDX_LANGUAGES_NAME` (`name`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `languages`
--

LOCK TABLES `languages` WRITE;
/*!40000 ALTER TABLE `languages` DISABLE KEYS */;
INSERT INTO `languages` VALUES (1,'English','en','','en.svg','',1,1,'en_GB',1,1,0);
/*!40000 ALTER TABLE `languages` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `languages_data`
--

DROP TABLE IF EXISTS `languages_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `languages_data` (
  `language_data_id` int(11) NOT NULL AUTO_INCREMENT,
  `language_code` varchar(5) NOT NULL DEFAULT '',
  `icon` varchar(64) NOT NULL DEFAULT '',
  `language_iso` varchar(15) NOT NULL DEFAULT '',
  `language_name` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`language_data_id`)
) ENGINE=InnoDB AUTO_INCREMENT=29 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `languages_data`
--

LOCK TABLES `languages_data` WRITE;
/*!40000 ALTER TABLE `languages_data` DISABLE KEYS */;
INSERT INTO `languages_data` VALUES (1,'en','en.svg','eng','English'),(2,'nl','nl.svg','dut','Nederlands'),(3,'it','it.svg','ita','Italiano'),(4,'de','de.svg','deu','Deutsch'),(5,'fr','fr.svg','fra','Français'),(6,'no','no.svg','nor','Norsk'),(7,'ru','ru.svg','rus','Русский'),(8,'ua','ua.svg','ukr','Українська'),(9,'tr','TR.svg','tur','Türkçe'),(10,'el','GR.svg','ell','Ελληνικά'),(11,'es','ES.svg','spa','Español'),(12,'lv','LV.svg','lav','Latviešu'),(13,'lt','LT.svg','lit','Lietuvių'),(14,'pt','PT.svg','por','Português'),(15,'pl','PL.svg','pol','Polski'),(16,'bg','BG.svg','bul','Български'),(17,'sk','SK.svg','slk','Slovenčina'),(18,'sl','SL.svg','slv','Slovenščina'),(19,'ro','RO.svg','ron','Română'),(20,'fi','FI.svg','fin','Suomi'),(21,'cs','CS.svg','ces','Čeština'),(22,'et','EE.svg','est','Eesti'),(23,'da','DA.svg','dan','Dansk'),(24,'ga','GA.svg','gle','Gaeilge'),(25,'tw','tw.svg','twn','繁中'),(26,'ja','jp.svg','jpn','日本語'),(27,'zh','cn.svg','zho','簡中'),(28,'vi','vn.svg','vie','越南話');
/*!40000 ALTER TABLE `languages_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `languages_formats`
--

DROP TABLE IF EXISTS `languages_formats`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `languages_formats` (
  `languages_formats_id` int(11) NOT NULL AUTO_INCREMENT,
  `configuration_key` varchar(64) NOT NULL DEFAULT '',
  `configuration_value` varchar(255) NOT NULL DEFAULT '',
  `language_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`languages_formats_id`),
  KEY `language_id` (`language_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1533 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `languages_formats`
--

LOCK TABLES `languages_formats` WRITE;
/*!40000 ALTER TABLE `languages_formats` DISABLE KEYS */;
INSERT INTO `languages_formats` VALUES (1381,'DATE_FORMAT_SHORT','%d %b %Y',1),(1382,'DATE_FORMAT_LONG','%A %d %B, %Y',1),(1383,'DATE_TIME_FORMAT_LONG','%A %d %B, %Y %H:%M:%S',1),(1384,'DATE_FORMAT','d M Y',1),(1385,'PHP_DATE_TIME_FORMAT','d/m/Y H:i:s',1),(1386,'DATE_TIME_FORMAT','%d %b %Y %H:%M:%S',1),(1387,'DATE_FORMAT_DATEPICKER','dd M yy',1),(1388,'DATE_FORMAT_DATEPICKER_PHP','d M Y',1),(1389,'DOB_FORMAT_STRING','dd/mm/yyyy',1),(1390,'HTML_PARAMS','dir=\"ltr\" lang=\"en\"',1),(1391,'CHARSET','utf-8',1),(1392,'LANGUAGE_CURRENCY','USD',1),(1532,'DATE_FORMAT_DATEPTIMEICKER_PHP','d M Y H:i',1);
/*!40000 ALTER TABLE `languages_formats` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `location_blocks`
--

DROP TABLE IF EXISTS `location_blocks`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `location_blocks` (
  `block_id` int(11) NOT NULL AUTO_INCREMENT,
  `block_name` varchar(32) DEFAULT NULL,
  PRIMARY KEY (`block_id`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `location_blocks`
--

LOCK TABLES `location_blocks` WRITE;
/*!40000 ALTER TABLE `location_blocks` DISABLE KEYS */;
INSERT INTO `location_blocks` VALUES (1,'Floor'),(2,'Room'),(3,'Rack'),(4,'Shelf'),(5,'Section');
/*!40000 ALTER TABLE `location_blocks` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `locations`
--

DROP TABLE IF EXISTS `locations`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `locations` (
  `location_id` int(11) NOT NULL AUTO_INCREMENT,
  `block_id` int(11) NOT NULL DEFAULT '0',
  `location_name` varchar(32) DEFAULT NULL,
  `parrent_id` int(11) NOT NULL DEFAULT '0',
  `is_final` tinyint(1) NOT NULL DEFAULT '0',
  `warehouse_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`location_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `locations`
--

LOCK TABLES `locations` WRITE;
/*!40000 ALTER TABLE `locations` DISABLE KEYS */;
/*!40000 ALTER TABLE `locations` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `manufacturers`
--

DROP TABLE IF EXISTS `manufacturers`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `manufacturers` (
  `manufacturers_id` int(11) NOT NULL AUTO_INCREMENT,
  `manufacturers_name` varchar(32) NOT NULL DEFAULT '',
  `manufacturers_image` varchar(256) DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `manufacturers_old_seo_page_name` varchar(128) NOT NULL DEFAULT '',
  `maps_id` int(11) NOT NULL DEFAULT '0',
  `manufacturers_image_2` varchar(256) NOT NULL DEFAULT '',
  `stock_limit` int(11) NOT NULL DEFAULT '-1',
  PRIMARY KEY (`manufacturers_id`),
  KEY `IDX_MANUFACTURERS_NAME` (`manufacturers_name`)
) ENGINE=InnoDB AUTO_INCREMENT=24 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `manufacturers`
--

LOCK TABLES `manufacturers` WRITE;
/*!40000 ALTER TABLE `manufacturers` DISABLE KEYS */;
INSERT INTO `manufacturers` VALUES (1,'DKNY',NULL,'2022-07-22 21:06:46',NULL,0,'',0,'',-1),(2,'Puma',NULL,'2022-07-22 21:06:46',NULL,0,'',0,'',-1),(3,'Gucci',NULL,'2022-07-22 21:06:47',NULL,0,'',0,'',-1),(4,'Casio',NULL,'2022-07-22 21:06:48',NULL,0,'',0,'',-1),(5,'Nemesis',NULL,'2022-07-22 21:06:49',NULL,0,'',0,'',-1),(6,'Edox',NULL,'2022-07-22 21:06:49',NULL,0,'',0,'',-1),(7,'Citizen',NULL,'2022-07-22 21:06:50',NULL,0,'',0,'',-1),(8,'COZY SLEEP',NULL,'2022-07-22 21:07:00',NULL,0,'',0,'',-1),(9,'COUNTRY',NULL,'2022-07-22 21:07:00',NULL,0,'',0,'',-1),(10,'JACK',NULL,'2022-07-22 21:07:01',NULL,0,'',0,'',-1),(11,'HAMPTONS',NULL,'2022-07-22 21:07:01',NULL,0,'',0,'',-1),(12,'BROLLY',NULL,'2022-07-22 21:07:01',NULL,0,'',0,'',-1),(13,'FURTEX',NULL,'2022-07-22 21:07:01',NULL,0,'',0,'',-1),(14,'OLIVIA',NULL,'2022-07-22 21:07:01',NULL,0,'',0,'',-1),(15,'CLAYTON',NULL,'2022-07-22 21:07:02',NULL,0,'',0,'',-1),(16,'VERONICA',NULL,'2022-07-22 21:07:02',NULL,0,'',0,'',-1),(17,'MONA',NULL,'2022-07-22 21:07:02',NULL,0,'',0,'',-1),(18,'MICHAEL',NULL,'2022-07-22 21:07:02',NULL,0,'',0,'',-1),(19,'CASPER',NULL,'2022-07-22 21:07:02',NULL,0,'',0,'',-1),(20,'JONAS',NULL,'2022-07-22 21:07:02',NULL,0,'',0,'',-1),(21,'ERIN',NULL,'2022-07-22 21:07:03',NULL,0,'',0,'',-1),(22,'BERRY',NULL,'2022-07-22 21:07:03',NULL,0,'',0,'',-1),(23,'ZEDS QUASAR',NULL,'2022-07-22 21:07:03',NULL,0,'',0,'',-1);
/*!40000 ALTER TABLE `manufacturers` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `manufacturers_info`
--

DROP TABLE IF EXISTS `manufacturers_info`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `manufacturers_info` (
  `manufacturers_id` int(11) NOT NULL DEFAULT '0',
  `languages_id` int(11) NOT NULL DEFAULT '0',
  `manufacturers_url` varchar(255) NOT NULL DEFAULT '',
  `url_clicked` int(5) NOT NULL DEFAULT '0',
  `date_last_click` datetime DEFAULT NULL,
  `manufacturers_meta_description` tinytext NOT NULL,
  `manufacturers_meta_key` tinytext NOT NULL,
  `manufacturers_meta_title` tinytext NOT NULL,
  `manufacturers_seo_name` varchar(255) NOT NULL DEFAULT '',
  `manufacturers_description` text NOT NULL,
  `manufacturers_h1_tag` varchar(255) NOT NULL DEFAULT '',
  `manufacturers_h2_tag` text NOT NULL,
  `manufacturers_h3_tag` text NOT NULL,
  PRIMARY KEY (`manufacturers_id`,`languages_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `manufacturers_info`
--

LOCK TABLES `manufacturers_info` WRITE;
/*!40000 ALTER TABLE `manufacturers_info` DISABLE KEYS */;
INSERT INTO `manufacturers_info` VALUES (1,1,'',0,NULL,'','','','','','','',''),(2,1,'',0,NULL,'','','','','','','',''),(3,1,'',0,NULL,'','','','','','','',''),(4,1,'',0,NULL,'','','','','','','',''),(5,1,'',0,NULL,'','','','','','','',''),(6,1,'',0,NULL,'','','','','','','',''),(7,1,'',0,NULL,'','','','','','','',''),(8,1,'',0,NULL,'','','','','','','',''),(9,1,'',0,NULL,'','','','','','','',''),(10,1,'',0,NULL,'','','','','','','',''),(11,1,'',0,NULL,'','','','','','','',''),(12,1,'',0,NULL,'','','','','','','',''),(13,1,'',0,NULL,'','','','','','','',''),(14,1,'',0,NULL,'','','','','','','',''),(15,1,'',0,NULL,'','','','','','','',''),(16,1,'',0,NULL,'','','','','','','',''),(17,1,'',0,NULL,'','','','','','','',''),(18,1,'',0,NULL,'','','','','','','',''),(19,1,'',0,NULL,'','','','','','','',''),(20,1,'',0,NULL,'','','','','','','',''),(21,1,'',0,NULL,'','','','','','','',''),(22,1,'',0,NULL,'','','','','','','',''),(23,1,'',0,NULL,'','','','','','','','');
/*!40000 ALTER TABLE `manufacturers_info` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_items`
--

DROP TABLE IF EXISTS `menu_items`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `menu_items` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `menu_id` int(11) DEFAULT NULL,
  `parent_id` int(11) DEFAULT NULL,
  `link` text,
  `link_id` int(11) DEFAULT NULL,
  `link_type` varchar(255) DEFAULT NULL,
  `target_blank` int(1) DEFAULT NULL,
  `sub_categories` int(1) DEFAULT NULL,
  `custom_categories` text,
  `class` varchar(64) NOT NULL DEFAULT '',
  `sort_order` int(11) DEFAULT NULL,
  `no_logged` tinyint(1) NOT NULL DEFAULT '0',
  `theme_page_id` int(11) NOT NULL DEFAULT '0',
  `nofollow` int(1) NOT NULL DEFAULT '0',
  `user_groups` varchar(255) NOT NULL DEFAULT '#0#',
  `settings` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `id` (`id`),
  KEY `menu_id` (`menu_id`,`platform_id`),
  KEY `link_type` (`link_type`)
) ENGINE=InnoDB AUTO_INCREMENT=1212 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_items`
--

LOCK TABLES `menu_items` WRITE;
/*!40000 ALTER TABLE `menu_items` DISABLE KEYS */;
INSERT INTO `menu_items` VALUES (204,1,9,0,'',45,'info',0,0,NULL,'',0,0,0,0,'#0#',NULL),(205,1,9,0,'',13,'info',0,0,NULL,'',1,0,0,0,'#0#',NULL),(225,2,4,0,'shopping-cart',906805,'custom',0,0,NULL,'cart-link',0,0,0,0,'#0#',NULL),(229,3,3,0,'',41,'info',0,0,NULL,'',1,0,0,0,'#0#',NULL),(302,2,3,0,'',8888886,'default',0,0,NULL,'',0,0,0,0,'#0#',NULL),(303,2,3,0,'',41,'info',0,0,NULL,'',1,0,0,0,'#0#',NULL),(404,1,4,0,'',8888883,'default',0,0,NULL,'',0,0,0,0,'#0#',NULL),(464,2,2,0,'',8888878,'default',0,0,NULL,'',5,0,0,0,'#0#',NULL),(465,3,2,0,'',999999999,'categories',0,0,NULL,'',0,0,0,0,'#0#',NULL),(466,3,2,465,'',207,'categories',0,1,NULL,'',1,0,0,0,'#0#',NULL),(467,3,2,465,'',199,'categories',0,1,NULL,'',2,0,0,0,'#0#',NULL),(468,3,2,465,'',123,'categories',0,1,NULL,'',3,0,0,0,'#0#',NULL),(469,3,2,465,'',202,'categories',0,1,NULL,'',4,0,0,0,'#0#',NULL),(470,3,2,465,'',122,'categories',0,1,NULL,'',5,0,0,0,'#0#',NULL),(471,3,2,0,'',8888878,'default',0,0,NULL,'',6,0,0,0,'#0#',NULL),(473,3,3,0,'',8888886,'default',0,0,NULL,'',0,0,0,0,'#0#',NULL),(478,7,3,0,'',8888886,'default',0,0,'','',0,0,0,0,'#0#',NULL),(482,7,3,0,'',41,'info',0,0,'','',1,0,0,0,'#0#',NULL),(483,7,3,0,'',8888888,'default',0,0,'','',2,0,0,0,'#0#',NULL),(541,2,2,0,'',999999999,'categories',0,0,NULL,'',0,0,0,0,'#0#',NULL),(542,2,2,541,'',198,'categories',0,1,NULL,'',1,0,0,0,'#0#',NULL),(543,2,2,541,'',203,'categories',0,1,NULL,'',2,0,0,0,'#0#',NULL),(544,2,2,541,'',209,'categories',0,1,NULL,'',3,0,0,0,'#0#',NULL),(545,2,2,541,'',205,'categories',0,1,NULL,'',4,0,0,0,'#0#',NULL),(546,2,3,0,'testimonials',899892,'custom',0,0,NULL,'',2,0,1883,0,'#0#',NULL),(547,2,3,0,'/blog',755133,'custom',0,0,NULL,'',3,0,0,0,'#0#',NULL),(548,2,9,0,'',13,'info',0,0,NULL,'',0,0,0,0,'#0#',NULL),(573,3,9,0,'',13,'info',0,0,NULL,'',0,0,0,0,'#0#',NULL),(574,3,4,0,'',8888883,'default',0,0,NULL,'',0,0,0,0,'#0#',NULL),(575,3,3,0,'testimonials',360060,'custom',0,0,NULL,'',2,0,1914,0,'#0#',NULL),(576,3,3,0,'/blog',598982,'custom',0,0,NULL,'',3,0,0,0,'#0#',NULL),(598,1,27,0,'',8888880,'default',0,0,NULL,'',0,0,0,0,'#0#',NULL),(599,1,27,0,'',8888881,'default',0,0,NULL,'',1,0,0,0,'#0#',NULL),(600,1,27,0,'',8888882,'default',0,0,NULL,'',2,0,0,0,'#0#',NULL),(601,1,27,0,'',8888878,'default',0,0,NULL,'',3,0,0,0,'#0#',NULL),(606,1,28,0,'',13,'info',0,0,NULL,'',0,0,0,0,'#0#',NULL),(607,1,28,0,'',12,'info',0,0,NULL,'',1,0,0,0,'#0#',NULL),(608,1,28,0,'',9,'info',0,0,NULL,'',2,0,0,0,'#0#',NULL),(609,1,28,0,'',41,'info',0,0,NULL,'',3,0,0,0,'#0#',NULL),(610,1,29,0,'',8888888,'default',0,0,NULL,'',0,0,0,0,'#0#',NULL),(611,1,29,0,'',8888887,'default',0,0,NULL,'',1,0,0,0,'#0#',NULL),(612,1,29,0,'',8888883,'default',0,0,NULL,'',2,0,0,0,'#0#',NULL),(613,1,29,0,'',8888884,'default',0,0,NULL,'',3,0,0,0,'#0#',NULL),(634,1,35,0,'',8888888,'default',0,0,NULL,'',0,0,0,0,'#0#',NULL),(635,1,35,0,'',8888887,'default',0,0,NULL,'',5,0,0,0,'#0#',NULL),(636,1,35,0,'',69216220,'account',0,0,NULL,'',1,0,0,0,'#0#',NULL),(637,1,35,0,'',104932685,'account',0,0,NULL,'',2,0,0,0,'#0#',NULL),(638,1,35,0,'',195237054,'account',0,0,NULL,'',3,0,0,0,'#0#',NULL),(639,1,35,0,'',199136074,'account',0,0,NULL,'',4,0,0,0,'#0#',NULL),(685,8,2,0,'',8888882,'default',0,0,'','',3,0,0,0,'#0#',NULL),(686,8,2,0,'',8888881,'default',0,0,'','',4,0,0,0,'#0#',NULL),(687,8,2,0,'',8888878,'default',0,0,'','',5,0,0,0,'#0#',NULL),(688,1,36,0,'',782768,'custom',0,0,'','',0,0,0,0,'#0#',NULL),(689,1,36,688,'',8888880,'default',0,0,'','',1,0,0,0,'#0#',NULL),(690,1,36,688,'',8888881,'default',0,0,'','',2,0,0,0,'#0#',NULL),(691,1,36,688,'',8888882,'default',0,0,'','',3,0,0,0,'#0#',NULL),(692,1,36,688,'',8888878,'default',0,0,'','',4,0,0,0,'#0#',NULL),(693,1,36,0,'',182457,'custom',0,0,'','',5,0,0,0,'#0#',NULL),(694,1,36,693,'',13,'info',0,0,'','',6,0,0,0,'#0#',NULL),(695,1,36,693,'',12,'info',0,0,'','',7,0,0,0,'#0#',NULL),(696,1,36,693,'',9,'info',0,0,'','',8,0,0,0,'#0#',NULL),(697,1,36,693,'',41,'info',0,0,'','',9,0,0,0,'#0#',NULL),(698,1,36,693,'Customer care',0,'component',0,0,'','',10,0,0,0,'#0#',NULL),(699,1,36,0,'',290742,'custom',0,0,'','',11,0,0,0,'#0#',NULL),(700,1,36,699,'',8888888,'default',0,0,'','',12,0,0,0,'#0#',NULL),(701,1,36,699,'',8888883,'default',0,0,'','',13,0,0,0,'#0#',NULL),(702,1,36,699,'Social',0,'component',0,0,'','',14,0,0,0,'#0#',NULL),(703,1,37,0,'',999999999,'categories',0,0,'','',0,0,0,0,'#0#',NULL),(704,1,37,703,'',0,'custom',0,0,'','',5,0,0,0,'#0#',NULL),(705,1,37,704,'',2,'categories',0,1,'','',6,0,0,0,'#0#',NULL),(706,1,37,704,'',3,'categories',0,1,'','',7,0,0,0,'#0#',NULL),(707,1,37,704,'',4,'categories',0,1,'','',8,0,0,0,'#0#',NULL),(708,7,36,0,'',782768,'custom',0,0,'','',0,0,0,0,'#0#',NULL),(709,7,36,708,'',8888880,'default',0,0,'','',1,0,0,0,'#0#',NULL),(710,7,36,708,'',8888881,'default',0,0,'','',2,0,0,0,'#0#',NULL),(711,7,36,708,'',8888882,'default',0,0,'','',3,0,0,0,'#0#',NULL),(712,7,36,708,'',8888878,'default',0,0,'','',4,0,0,0,'#0#',NULL),(713,7,36,0,'',182457,'custom',0,0,'','',5,0,0,0,'#0#',NULL),(714,7,36,713,'',13,'info',0,0,'','',6,0,0,0,'#0#',NULL),(715,7,36,713,'',12,'info',0,0,'','',7,0,0,0,'#0#',NULL),(716,7,36,713,'',9,'info',0,0,'','',8,0,0,0,'#0#',NULL),(717,7,36,713,'',41,'info',0,0,'','',9,0,0,0,'#0#',NULL),(718,7,36,713,'Customer care',0,'component',0,0,'','',10,0,0,0,'#0#',NULL),(719,7,36,0,'',290742,'custom',0,0,'','',11,0,0,0,'#0#',NULL),(720,7,36,719,'',8888888,'default',0,0,'','',12,0,0,0,'#0#',NULL),(721,7,36,719,'',8888883,'default',0,0,'','',13,0,0,0,'#0#',NULL),(722,7,36,719,'Social',0,'component',0,0,'','',14,0,0,0,'#0#',NULL),(729,8,27,0,'',8888881,'default',0,0,'','',2,0,0,0,'#0#',NULL),(732,8,27,0,'',8888882,'default',0,0,'','',0,0,0,0,'#0#',NULL),(733,8,27,0,'',8888880,'default',0,0,'','',1,0,0,0,'#0#',NULL),(736,8,28,0,'',22,'info',0,0,'','',0,0,0,0,'#0#',NULL),(737,8,28,0,'',12,'info',0,0,'','',1,0,0,0,'#0#',NULL),(738,8,28,0,'',9,'info',0,0,'','',2,0,0,0,'#0#',NULL),(739,8,29,0,'',8888887,'default',0,0,'','',0,0,0,0,'#0#',NULL),(740,8,29,0,'',8888888,'default',0,0,'','',1,0,0,0,'#0#',NULL),(741,8,29,0,'',8888884,'default',0,0,'','',2,0,0,0,'#0#',NULL),(742,7,35,0,'',8888888,'default',0,0,NULL,'',0,0,0,0,'#0#',NULL),(743,7,35,0,'',8888887,'default',0,0,NULL,'',5,0,0,0,'#0#',NULL),(744,7,35,0,'',69216220,'account',0,0,NULL,'',1,0,0,0,'#0#',NULL),(745,7,35,0,'',104932685,'account',0,0,NULL,'',2,0,0,0,'#0#',NULL),(746,7,35,0,'',195237054,'account',0,0,NULL,'',3,0,0,0,'#0#',NULL),(747,7,35,0,'',199136074,'account',0,0,NULL,'',4,0,0,0,'#0#',NULL),(753,8,35,0,'',8888888,'default',0,0,NULL,'',0,0,0,0,'#0#',NULL),(754,8,35,0,'',8888887,'default',0,0,NULL,'',5,0,0,0,'#0#',NULL),(755,8,35,0,'',69216220,'account',0,0,NULL,'',1,0,0,0,'#0#',NULL),(756,8,35,0,'',104932685,'account',0,0,NULL,'',2,0,0,0,'#0#',NULL),(757,8,35,0,'',195237054,'account',0,0,NULL,'',3,0,0,0,'#0#',NULL),(758,8,35,0,'',199136074,'account',0,0,NULL,'',4,0,0,0,'#0#',NULL),(764,10,35,0,'',8888888,'default',0,0,'','',0,0,0,0,'#0#',NULL),(765,10,35,0,'',69216220,'account',0,0,'','',1,0,0,0,'#0#',NULL),(766,10,35,0,'',195237054,'account',0,0,'','',2,0,0,0,'#0#',NULL),(767,10,35,0,'',248110350,'account',0,0,'','',3,0,0,0,'#0#',NULL),(768,10,35,0,'',8888887,'default',0,0,'','',4,0,0,0,'#0#',NULL),(769,10,27,0,'',8888878,'default',0,0,'','',0,0,0,0,'#0#',NULL),(770,10,28,0,'',41,'info',0,0,'','',0,0,0,0,'#0#',NULL),(771,10,29,0,'',8888888,'default',0,0,'','',0,0,0,0,'#0#',NULL),(772,10,29,0,'',8888887,'default',0,0,'','',1,0,0,0,'#0#',NULL),(773,10,29,0,'',8888883,'default',0,0,'','',2,0,0,0,'#0#',NULL),(774,10,29,0,'',8888884,'default',0,0,'','',3,0,0,0,'#0#',NULL),(775,10,36,0,'',954024,'custom',0,0,'','',4,0,0,0,'#0#',NULL),(776,10,36,775,'',8888888,'default',0,0,'','',5,0,0,0,'#0#',NULL),(777,10,36,775,'',8888887,'default',0,0,'','',6,0,0,0,'#0#',NULL),(778,10,36,775,'',8888883,'default',0,0,'','',7,0,0,0,'#0#',NULL),(779,10,36,775,'',8888884,'default',0,0,'','',8,0,0,0,'#0#',NULL),(780,10,36,0,'',255645,'custom',0,0,'','',0,0,0,0,'#0#',NULL),(781,10,36,780,'',8888878,'default',0,0,'','',1,0,0,0,'#0#',NULL),(782,10,36,0,'',452687,'custom',0,0,'','',2,0,0,0,'#0#',NULL),(783,10,36,782,'',41,'info',0,0,'','',3,0,0,0,'#0#',NULL),(800,9,36,0,'',70588,'custom',0,0,'','',0,0,0,0,'#0#',NULL),(801,9,36,800,'',22,'info',0,0,'','',1,0,0,0,'#0#',NULL),(802,9,36,0,'',936341,'custom',0,0,'','',2,0,0,0,'#0#',NULL),(803,9,36,802,'/',169801,'custom',0,0,'','',3,0,0,0,'#0#',NULL),(804,9,36,0,'',562139,'custom',0,0,'','',4,0,0,0,'#0#',NULL),(805,9,36,804,'',41,'info',0,0,'','',5,0,0,0,'#0#',NULL),(821,9,35,0,'',195237054,'account',0,0,'','',1,0,0,0,'#0#',NULL),(822,9,35,0,'',157236866,'account',0,0,'','',0,0,0,0,'#0#',NULL),(848,1,37,703,'',1,'categories',0,0,'','',1,0,0,0,'#0#',NULL),(849,1,37,703,'',7,'categories',0,0,'','',2,0,0,0,'#0#',NULL),(850,1,37,703,'',11,'categories',0,0,'','',3,0,0,0,'#0#',NULL),(851,1,37,703,'',17,'categories',0,0,'','',4,0,0,0,'#0#',NULL),(913,10,3,0,'',279902,'custom',0,0,'','',0,0,0,0,'#0#',NULL),(914,10,3,910,'',999999999,'categories',0,0,'','',1,0,0,0,'#0#',NULL),(916,10,3,914,'',5,'categories',0,1,'','',2,0,0,0,'#0#',NULL),(917,10,3,916,'',6,'categories',0,1,'','',3,0,0,0,'#0#',NULL),(918,10,3,916,'',7,'categories',0,1,'','',4,0,0,0,'#0#',NULL),(919,10,3,916,'',8,'categories',0,1,'','',5,0,0,0,'#0#',NULL),(920,10,3,913,'',999999999,'categories',0,0,'','',1,0,0,0,'#0#',NULL),(921,10,3,920,'',5,'categories',0,1,'','',2,0,0,0,'#0#',NULL),(922,10,3,921,'',6,'categories',0,1,'','',3,0,0,0,'#0#',NULL),(923,10,3,921,'',7,'categories',0,1,'','',4,0,0,0,'#0#',NULL),(924,10,3,921,'',8,'categories',0,1,'','',5,0,0,0,'#0#',NULL),(997,9,3,0,'',279902,'custom',0,0,'','',0,0,0,0,'#0#',NULL),(998,9,3,997,'',999999999,'categories',0,0,'','',1,0,0,0,'#0#',NULL),(1022,9,3,998,'',5,'categories',0,1,'','',2,0,0,0,'#0#',NULL),(1023,9,3,1022,'',8,'categories',0,1,'','',6,0,0,0,'#0#',NULL),(1024,9,3,1022,'',6,'categories',0,1,'','',3,0,0,0,'#0#',NULL),(1025,9,3,1022,'',7,'categories',0,1,'','',4,0,0,0,'#0#',NULL),(1026,9,3,1022,'',8,'categories',0,1,'','',5,0,0,0,'#0#',NULL),(1042,9,3,998,'',6,'categories',0,1,'','',7,0,0,0,'#0#',NULL),(1043,9,3,998,'',8,'categories',0,1,'','',8,0,0,0,'#0#',NULL),(1044,9,3,998,'',7,'categories',0,1,'','',9,0,0,0,'#0#',NULL),(1099,7,2,0,'',999999999,'categories',0,0,'','',0,0,0,0,'#0#',NULL),(1134,7,2,1099,'',13,'categories',0,1,'','',1,0,0,0,'#0#',NULL),(1135,7,2,1134,'',14,'categories',0,1,'','',2,0,0,0,'#0#',NULL),(1136,7,2,1134,'',15,'categories',0,1,'','',3,0,0,0,'#0#',NULL),(1137,7,2,1134,'',16,'categories',0,1,'','',4,0,0,0,'#0#',NULL),(1138,7,2,1134,'',17,'categories',0,1,'','',5,0,0,0,'#0#',NULL),(1139,7,2,1134,'',18,'categories',0,1,'','',6,0,0,0,'#0#',NULL),(1140,7,2,0,'',8888880,'default',0,0,'','',7,0,0,0,'#0#',NULL),(1141,7,2,0,'',8888881,'default',0,0,'','',8,0,0,0,'#0#',NULL),(1142,7,2,0,'',8888882,'default',0,0,'','',9,0,0,0,'#0#',NULL),(1147,8,3,0,'',8888886,'default',0,0,'','',0,0,0,0,'#0#',NULL),(1148,8,3,0,'',41,'info',0,0,'','',1,0,0,0,'#0#',NULL),(1150,1,3,998,'',8888880,'default',0,0,'','',10,0,0,0,'#0#',NULL),(1151,9,3,998,'',8888880,'default',0,0,'','',10,0,0,0,'#0#',NULL),(1155,9,2,0,'',8888880,'default',0,0,'','',3,0,0,0,'#0#',NULL),(1160,1,2,0,'',10,'categories',0,1,'','',0,0,0,0,'#0#',NULL),(1161,1,2,0,'',11,'categories',0,1,'','',1,0,0,0,'#0#',NULL),(1162,1,2,0,'',12,'categories',0,1,'','',2,0,0,0,'#0#',NULL),(1202,10,2,0,'',10,'categories',0,1,'','',0,0,0,0,'#0#',NULL),(1203,10,2,0,'',11,'categories',0,1,'','',1,0,0,0,'#0#',NULL),(1204,10,2,0,'',12,'categories',0,1,'','',2,0,0,0,'#0#',NULL),(1205,9,2,0,'',10,'categories',0,1,'','',0,0,0,0,'#0#',NULL),(1206,9,2,0,'',11,'categories',0,1,'','',1,0,0,0,'#0#',NULL),(1207,9,2,0,'',12,'categories',0,1,'','',2,0,0,0,'#0#',NULL),(1208,10,2,0,'',8888880,'default',0,0,'','',3,0,0,0,'#0#',NULL),(1209,8,2,0,'',2,'categories',0,1,'','',0,0,0,0,'#0#',NULL),(1210,8,2,0,'',4,'categories',0,1,'','',1,0,0,0,'#0#',NULL),(1211,8,2,0,'',3,'categories',0,1,'','',2,0,0,0,'#0#',NULL);
/*!40000 ALTER TABLE `menu_items` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_source`
--

DROP TABLE IF EXISTS `menu_source`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `menu_source` (
  `id` int(255) NOT NULL DEFAULT '0',
  `platform_id` int(255) NOT NULL DEFAULT '0',
  `source_platform_id` int(255) DEFAULT '0',
  PRIMARY KEY (`id`,`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_source`
--

LOCK TABLES `menu_source` WRITE;
/*!40000 ALTER TABLE `menu_source` DISABLE KEYS */;
/*!40000 ALTER TABLE `menu_source` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_titles`
--

DROP TABLE IF EXISTS `menu_titles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `menu_titles` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `language_id` int(11) NOT NULL DEFAULT '1',
  `item_id` int(11) DEFAULT NULL,
  `title` text,
  `link` text,
  PRIMARY KEY (`id`),
  UNIQUE KEY `language_item` (`language_id`,`item_id`),
  KEY `id` (`id`),
  KEY `item_id` (`item_id`),
  KEY `language_id` (`language_id`)
) ENGINE=InnoDB AUTO_INCREMENT=388 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_titles`
--

LOCK TABLES `menu_titles` WRITE;
/*!40000 ALTER TABLE `menu_titles` DISABLE KEYS */;
INSERT INTO `menu_titles` VALUES (30,1,225,'Shopping Cart',NULL),(265,1,302,'Home',NULL),(266,1,473,'Home',NULL),(282,1,546,'Testimonials',NULL),(283,1,547,'Blog',NULL),(284,1,575,'Testimonials',NULL),(285,1,576,'Blog',NULL),(353,1,688,'Products',NULL),(354,1,693,'Customer care',NULL),(355,1,699,'Account',NULL),(356,1,708,'Products',NULL),(357,1,713,'Customer care',NULL),(358,1,719,'Account',NULL),(359,1,775,'Account',NULL),(360,1,780,'Company',NULL),(361,1,782,'Customers',NULL),(363,1,800,'Information',NULL),(364,1,802,'Shopping',NULL),(365,1,803,'Delivery information',NULL),(366,1,804,'Contact Details',NULL),(371,1,913,'Products',NULL),(384,1,997,'Products',NULL),(385,1,1208,'Sales',NULL),(386,1,1151,'Sales',NULL),(387,1,1140,'Sales',NULL);
/*!40000 ALTER TABLE `menu_titles` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menus`
--

DROP TABLE IF EXISTS `menus`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `menus` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `menu_name` text,
  `last_modified` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `id` (`id`),
  KEY `menu_name` (`menu_name`(32))
) ENGINE=InnoDB AUTO_INCREMENT=38 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menus`
--

LOCK TABLES `menus` WRITE;
/*!40000 ALTER TABLE `menus` DISABLE KEYS */;
INSERT INTO `menus` VALUES (2,'Categories','[[regtime]]'),(3,'Header menu','[[regtime]]'),(4,'Account','[[regtime]]'),(9,'FAQ','[[regtime]]'),(27,'footer1','[[regtime]]'),(28,'footer2','[[regtime]]'),(29,'footer3','[[regtime]]'),(35,'Account box','[[regtime]]'),(36,'Footer','[[regtime]]'),(37,'LeftCategories','[[regtime]]');
/*!40000 ALTER TABLE `menus` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `meta_tags`
--

DROP TABLE IF EXISTS `meta_tags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `meta_tags` (
  `meta_tags_key` varchar(100) NOT NULL DEFAULT '',
  `meta_tags_value` text,
  `language_id` tinyint(4) NOT NULL DEFAULT '0',
  `affiliate_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  KEY `platform_id` (`platform_id`,`language_id`,`affiliate_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `meta_tags`
--

LOCK TABLES `meta_tags` WRITE;
/*!40000 ALTER TABLE `meta_tags` DISABLE KEYS */;
INSERT INTO `meta_tags` VALUES ('HEAD_TITLE_TAG_ALL','',1,0,1),('HEAD_TITLE_TAG_ALL','',2,0,1),('HEAD_KEY_TAG_ALL','trueloaded, ecommerce, holbi,holbi group,graphic designer, online designer, self made design, templates',1,0,1),('HEAD_KEY_TAG_ALL','',2,0,1),('HEAD_DESC_TAG_ALL','',1,0,1),('HEAD_DESC_TAG_ALL','',2,0,1),('HEAD_TITLE_TAG_DEFAULT','Ecommerce platform - osCommerce by Holbi Group',1,0,1),('HEAD_TITLE_TAG_DEFAULT','',2,0,1),('HEAD_KEY_TAG_DEFAULT','',1,0,1),('HEAD_KEY_TAG_DEFAULT','',2,0,1),('HEAD_DESC_TAG_DEFAULT','osCommerce Ecommerce platform from Holbi Group. eCommerce Shopping Cart solution. Ecommerce site. osCommerce by Holbi',1,0,1),('HEAD_DESC_TAG_DEFAULT','',2,0,1),('HEAD_TITLE_TAG_PRODUCT_INFO','Ecommerce platform - ##PRODUCT_NAME## - ##BRAND_NAME##',1,0,1),('HEAD_TITLE_TAG_PRODUCT_INFO','',2,0,1),('HEAD_KEY_TAG_PRODUCT_INFO','',1,0,1),('HEAD_KEY_TAG_PRODUCT_INFO','',2,0,1),('HEAD_DESC_TAG_PRODUCT_INFO','Sell your products with ecommerce site: osCommerce by Holbi. This is ##PRODUCT_NAME## from ##CATEGORY_NAME## produced by ##BRAND_NAME##',1,0,1),('HEAD_DESC_TAG_PRODUCT_INFO','',2,0,1),('HEAD_TITLE_TAG_WHATS_NEW','Listing of laterst products',1,0,1),('HEAD_TITLE_TAG_WHATS_NEW','',2,0,1),('HEAD_KEY_TAG_WHATS_NEW','',1,0,1),('HEAD_KEY_TAG_WHATS_NEW','',2,0,1),('HEAD_DESC_TAG_WHATS_NEW','You may find latest product here with ecommerce website: osCommerce by Holbi',1,0,1),('HEAD_DESC_TAG_WHATS_NEW','',2,0,1),('HEAD_TITLE_TAG_SPECIALS','Listing of specials - sales - products',1,0,1),('HEAD_TITLE_TAG_SPECIALS','',2,0,1),('HEAD_KEY_TAG_SPECIALS','',1,0,1),('HEAD_KEY_TAG_SPECIALS','',2,0,1),('HEAD_DESC_TAG_SPECIALS','Your clients will see all sales on your web site powered by ecommerce site: osCommerce by Holbi',1,0,1),('HEAD_DESC_TAG_SPECIALS','',2,0,1),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Read what others are saying',1,0,1),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',2,0,1),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',1,0,1),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',2,0,1),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Products reviews: Read what others are saying about Ecommerce platform : osCommerce by Holbi',1,0,1),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',2,0,1),('HEAD_TITLE_TAG_ALL','',3,0,1),('HEAD_KEY_TAG_ALL','',3,0,1),('HEAD_DESC_TAG_ALL','',3,0,1),('HEAD_TITLE_TAG_DEFAULT','E-commerceplatform - TrueLoaded door Holbi Group',3,0,1),('HEAD_KEY_TAG_DEFAULT','',3,0,1),('HEAD_DESC_TAG_DEFAULT','TrueLoaded E-commerceplatform van Holbi Group. eCommerce winkelwagen oplossing. E-commerce site. TrueLoaded door Holbi',3,0,1),('HEAD_TITLE_TAG_PRODUCT_INFO','E-commerce oplossing - ##PRODUCT_NAME## - ##BRAND_NAME##',3,0,1),('HEAD_KEY_TAG_PRODUCT_INFO','',3,0,1),('HEAD_DESC_TAG_PRODUCT_INFO','Verkoop uw producten met e-commerce site: TrueLoaded door Holbi. Dit is ##PRODUCT_NAME## from ##CATEGORY_NAME## geproduceerd door ##BRAND_NAME##',3,0,1),('HEAD_TITLE_TAG_WHATS_NEW','Lijst met de nieuwste producten',3,0,1),('HEAD_KEY_TAG_WHATS_NEW','',3,0,1),('HEAD_DESC_TAG_WHATS_NEW','U vindt het nieuwste product hier met e-commerce website: TrueLoaded door Holbi',3,0,1),('HEAD_TITLE_TAG_SPECIALS','Lijst met specials - verkoop - producten',3,0,1),('HEAD_KEY_TAG_SPECIALS','',3,0,1),('HEAD_DESC_TAG_SPECIALS','Uw klanten zien alle verkopen op uw website mogelijk gemaakt door e-commercesites: TrueLoaded door Holbi',3,0,1),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Lees wat anderen zeggen',3,0,1),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',3,0,1),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Productrecensies: Lees wat anderen over Ecommerce-platform zeggen: TrueLoaded door Holbi',3,0,1),('HEAD_TITLE_TAG_ALL','',1,0,5),('HEAD_TITLE_TAG_ALL','',3,0,5),('HEAD_KEY_TAG_ALL','',1,0,5),('HEAD_KEY_TAG_ALL','',3,0,5),('HEAD_DESC_TAG_ALL','',1,0,5),('HEAD_DESC_TAG_ALL','',3,0,5),('HEAD_TITLE_TAG_DEFAULT','',1,0,5),('HEAD_TITLE_TAG_DEFAULT','',3,0,5),('HEAD_KEY_TAG_DEFAULT','',1,0,5),('HEAD_KEY_TAG_DEFAULT','',3,0,5),('HEAD_DESC_TAG_DEFAULT','',1,0,5),('HEAD_DESC_TAG_DEFAULT','',3,0,5),('HEAD_TITLE_TAG_PRODUCT_INFO','',1,0,5),('HEAD_TITLE_TAG_PRODUCT_INFO','',3,0,5),('HEAD_KEY_TAG_PRODUCT_INFO','',1,0,5),('HEAD_KEY_TAG_PRODUCT_INFO','',3,0,5),('HEAD_DESC_TAG_PRODUCT_INFO','',1,0,5),('HEAD_DESC_TAG_PRODUCT_INFO','',3,0,5),('HEAD_TITLE_TAG_WHATS_NEW','',1,0,5),('HEAD_TITLE_TAG_WHATS_NEW','',3,0,5),('HEAD_KEY_TAG_WHATS_NEW','',1,0,5),('HEAD_KEY_TAG_WHATS_NEW','',3,0,5),('HEAD_DESC_TAG_WHATS_NEW','',1,0,5),('HEAD_DESC_TAG_WHATS_NEW','',3,0,5),('HEAD_TITLE_TAG_SPECIALS','',1,0,5),('HEAD_TITLE_TAG_SPECIALS','',3,0,5),('HEAD_KEY_TAG_SPECIALS','',1,0,5),('HEAD_KEY_TAG_SPECIALS','',3,0,5),('HEAD_DESC_TAG_SPECIALS','',1,0,5),('HEAD_DESC_TAG_SPECIALS','',3,0,5),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',1,0,5),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',3,0,5),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',1,0,5),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',3,0,5),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',1,0,5),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',3,0,5),('HEAD_TITLE_TAG_ALL','',1,0,4),('HEAD_TITLE_TAG_ALL','',1,0,6),('HEAD_TITLE_TAG_ALL','',3,0,4),('HEAD_TITLE_TAG_ALL','',3,0,6),('HEAD_TITLE_TAG_ALL','',10,0,1),('HEAD_TITLE_TAG_ALL','',10,0,4),('HEAD_TITLE_TAG_ALL','',10,0,5),('HEAD_TITLE_TAG_ALL','',10,0,6),('HEAD_TITLE_TAG_ALL','',11,0,1),('HEAD_TITLE_TAG_ALL','',11,0,4),('HEAD_TITLE_TAG_ALL','',11,0,5),('HEAD_TITLE_TAG_ALL','',11,0,6),('HEAD_TITLE_TAG_ALL','',12,0,1),('HEAD_TITLE_TAG_ALL','',12,0,4),('HEAD_TITLE_TAG_ALL','',12,0,5),('HEAD_TITLE_TAG_ALL','',12,0,6),('HEAD_TITLE_TAG_ALL','',13,0,1),('HEAD_TITLE_TAG_ALL','',13,0,4),('HEAD_TITLE_TAG_ALL','',13,0,5),('HEAD_TITLE_TAG_ALL','',13,0,6),('HEAD_TITLE_TAG_ALL','',15,0,1),('HEAD_TITLE_TAG_ALL','',15,0,4),('HEAD_TITLE_TAG_ALL','',15,0,5),('HEAD_TITLE_TAG_ALL','',15,0,6),('HEAD_TITLE_TAG_ALL','',17,0,1),('HEAD_TITLE_TAG_ALL','',17,0,4),('HEAD_TITLE_TAG_ALL','',17,0,5),('HEAD_TITLE_TAG_ALL','',17,0,6),('HEAD_KEY_TAG_ALL','',1,0,4),('HEAD_KEY_TAG_ALL','',1,0,6),('HEAD_KEY_TAG_ALL','',3,0,4),('HEAD_KEY_TAG_ALL','',3,0,6),('HEAD_KEY_TAG_ALL','',10,0,1),('HEAD_KEY_TAG_ALL','',10,0,4),('HEAD_KEY_TAG_ALL','',10,0,5),('HEAD_KEY_TAG_ALL','',10,0,6),('HEAD_KEY_TAG_ALL','',11,0,1),('HEAD_KEY_TAG_ALL','',11,0,4),('HEAD_KEY_TAG_ALL','',11,0,5),('HEAD_KEY_TAG_ALL','',11,0,6),('HEAD_KEY_TAG_ALL','',12,0,1),('HEAD_KEY_TAG_ALL','',12,0,4),('HEAD_KEY_TAG_ALL','',12,0,5),('HEAD_KEY_TAG_ALL','',12,0,6),('HEAD_KEY_TAG_ALL','',13,0,1),('HEAD_KEY_TAG_ALL','',13,0,4),('HEAD_KEY_TAG_ALL','',13,0,5),('HEAD_KEY_TAG_ALL','',13,0,6),('HEAD_KEY_TAG_ALL','',15,0,1),('HEAD_KEY_TAG_ALL','',15,0,4),('HEAD_KEY_TAG_ALL','',15,0,5),('HEAD_KEY_TAG_ALL','',15,0,6),('HEAD_KEY_TAG_ALL','',17,0,1),('HEAD_KEY_TAG_ALL','',17,0,4),('HEAD_KEY_TAG_ALL','',17,0,5),('HEAD_KEY_TAG_ALL','',17,0,6),('HEAD_DESC_TAG_ALL','',1,0,4),('HEAD_DESC_TAG_ALL','',1,0,6),('HEAD_DESC_TAG_ALL','',3,0,4),('HEAD_DESC_TAG_ALL','',3,0,6),('HEAD_DESC_TAG_ALL','',10,0,1),('HEAD_DESC_TAG_ALL','',10,0,4),('HEAD_DESC_TAG_ALL','',10,0,5),('HEAD_DESC_TAG_ALL','',10,0,6),('HEAD_DESC_TAG_ALL','',11,0,1),('HEAD_DESC_TAG_ALL','',11,0,4),('HEAD_DESC_TAG_ALL','',11,0,5),('HEAD_DESC_TAG_ALL','',11,0,6),('HEAD_DESC_TAG_ALL','',12,0,1),('HEAD_DESC_TAG_ALL','',12,0,4),('HEAD_DESC_TAG_ALL','',12,0,5),('HEAD_DESC_TAG_ALL','',12,0,6),('HEAD_DESC_TAG_ALL','',13,0,1),('HEAD_DESC_TAG_ALL','',13,0,4),('HEAD_DESC_TAG_ALL','',13,0,5),('HEAD_DESC_TAG_ALL','',13,0,6),('HEAD_DESC_TAG_ALL','',15,0,1),('HEAD_DESC_TAG_ALL','',15,0,4),('HEAD_DESC_TAG_ALL','',15,0,5),('HEAD_DESC_TAG_ALL','',15,0,6),('HEAD_DESC_TAG_ALL','',17,0,1),('HEAD_DESC_TAG_ALL','',17,0,4),('HEAD_DESC_TAG_ALL','',17,0,5),('HEAD_DESC_TAG_ALL','',17,0,6),('HEAD_TITLE_TAG_DEFAULT','',1,0,4),('HEAD_TITLE_TAG_DEFAULT','',1,0,6),('HEAD_TITLE_TAG_DEFAULT','',3,0,4),('HEAD_TITLE_TAG_DEFAULT','',3,0,6),('HEAD_TITLE_TAG_DEFAULT','E-Commerce Plattform - TrueLoaded von Holbi Group',10,0,1),('HEAD_TITLE_TAG_DEFAULT','',10,0,4),('HEAD_TITLE_TAG_DEFAULT','',10,0,5),('HEAD_TITLE_TAG_DEFAULT','',10,0,6),('HEAD_TITLE_TAG_DEFAULT','Plateforme de commerce électronique - TrueLoaded par Holbi Group',11,0,1),('HEAD_TITLE_TAG_DEFAULT','',11,0,4),('HEAD_TITLE_TAG_DEFAULT','',11,0,5),('HEAD_TITLE_TAG_DEFAULT','',11,0,6),('HEAD_TITLE_TAG_DEFAULT','E-handel plattform - TrueLoaded av Holbi Group',12,0,1),('HEAD_TITLE_TAG_DEFAULT','',12,0,4),('HEAD_TITLE_TAG_DEFAULT','',12,0,5),('HEAD_TITLE_TAG_DEFAULT','',12,0,6),('HEAD_TITLE_TAG_DEFAULT','Piattaforma di e-commerce - TrueLoaded di Holbi Group',13,0,1),('HEAD_TITLE_TAG_DEFAULT','',13,0,4),('HEAD_TITLE_TAG_DEFAULT','',13,0,5),('HEAD_TITLE_TAG_DEFAULT','',13,0,6),('HEAD_TITLE_TAG_DEFAULT','Електронна комерційна платформа - TrueLoaded від Holbi Group',15,0,1),('HEAD_TITLE_TAG_DEFAULT','',15,0,4),('HEAD_TITLE_TAG_DEFAULT','',15,0,5),('HEAD_TITLE_TAG_DEFAULT','',15,0,6),('HEAD_TITLE_TAG_DEFAULT','Электронная коммерция - TrueLoaded от Holbi Group',17,0,1),('HEAD_TITLE_TAG_DEFAULT','',17,0,4),('HEAD_TITLE_TAG_DEFAULT','',17,0,5),('HEAD_TITLE_TAG_DEFAULT','',17,0,6),('HEAD_KEY_TAG_DEFAULT','',1,0,4),('HEAD_KEY_TAG_DEFAULT','',1,0,6),('HEAD_KEY_TAG_DEFAULT','',3,0,4),('HEAD_KEY_TAG_DEFAULT','',3,0,6),('HEAD_KEY_TAG_DEFAULT','',10,0,1),('HEAD_KEY_TAG_DEFAULT','',10,0,4),('HEAD_KEY_TAG_DEFAULT','',10,0,5),('HEAD_KEY_TAG_DEFAULT','',10,0,6),('HEAD_KEY_TAG_DEFAULT','',11,0,1),('HEAD_KEY_TAG_DEFAULT','',11,0,4),('HEAD_KEY_TAG_DEFAULT','',11,0,5),('HEAD_KEY_TAG_DEFAULT','',11,0,6),('HEAD_KEY_TAG_DEFAULT','',12,0,1),('HEAD_KEY_TAG_DEFAULT','',12,0,4),('HEAD_KEY_TAG_DEFAULT','',12,0,5),('HEAD_KEY_TAG_DEFAULT','',12,0,6),('HEAD_KEY_TAG_DEFAULT','',13,0,1),('HEAD_KEY_TAG_DEFAULT','',13,0,4),('HEAD_KEY_TAG_DEFAULT','',13,0,5),('HEAD_KEY_TAG_DEFAULT','',13,0,6),('HEAD_KEY_TAG_DEFAULT','',15,0,1),('HEAD_KEY_TAG_DEFAULT','',15,0,4),('HEAD_KEY_TAG_DEFAULT','',15,0,5),('HEAD_KEY_TAG_DEFAULT','',15,0,6),('HEAD_KEY_TAG_DEFAULT','',17,0,1),('HEAD_KEY_TAG_DEFAULT','',17,0,4),('HEAD_KEY_TAG_DEFAULT','',17,0,5),('HEAD_KEY_TAG_DEFAULT','',17,0,6),('HEAD_DESC_TAG_DEFAULT','',1,0,4),('HEAD_DESC_TAG_DEFAULT','',1,0,6),('HEAD_DESC_TAG_DEFAULT','',3,0,4),('HEAD_DESC_TAG_DEFAULT','',3,0,6),('HEAD_DESC_TAG_DEFAULT','TrueLoaded E-Commerce Plattform von Holbi Group. eCommerce Warenkorb Lösung. E-Commerce Website. TrueLoaded von Holbi',10,0,1),('HEAD_DESC_TAG_DEFAULT','',10,0,4),('HEAD_DESC_TAG_DEFAULT','',10,0,5),('HEAD_DESC_TAG_DEFAULT','',10,0,6),('HEAD_DESC_TAG_DEFAULT','Plateforme de commerce électronique TrueLoaded du groupe Holbi. Solution de panier eCommerce. Site de commerce électronique. TrueLoaded par Holbi',11,0,1),('HEAD_DESC_TAG_DEFAULT','',11,0,4),('HEAD_DESC_TAG_DEFAULT','',11,0,5),('HEAD_DESC_TAG_DEFAULT','',11,0,6),('HEAD_DESC_TAG_DEFAULT','TrueLoaded E-handelsplattform fra Holbi Group. e-handel handlekurv løsning. E-handel nettsted. TrueLoaded av Holbi',12,0,1),('HEAD_DESC_TAG_DEFAULT','',12,0,4),('HEAD_DESC_TAG_DEFAULT','',12,0,5),('HEAD_DESC_TAG_DEFAULT','',12,0,6),('HEAD_DESC_TAG_DEFAULT','Piattaforma di e-commerce TrueLoaded di Holbi Group. soluzione di eCommerce Shopping Cart. Sito e-commerce TrueLoaded di Holbi',13,0,1),('HEAD_DESC_TAG_DEFAULT','',13,0,4),('HEAD_DESC_TAG_DEFAULT','',13,0,5),('HEAD_DESC_TAG_DEFAULT','',13,0,6),('HEAD_DESC_TAG_DEFAULT','TrueLoaded Електронна комерційна платформа від Holbi Group. Рішення для кошика для електронної комерції. Сайт електронної комерції. TrueLoaded від Holbi',15,0,1),('HEAD_DESC_TAG_DEFAULT','',15,0,4),('HEAD_DESC_TAG_DEFAULT','',15,0,5),('HEAD_DESC_TAG_DEFAULT','',15,0,6),('HEAD_DESC_TAG_DEFAULT','Платформа TrueLoaded для электронной коммерции от Holbi Group. Решение для покупок электронной коммерции. Сайт электронной торговли. TrueLoaded от Holbi',17,0,1),('HEAD_DESC_TAG_DEFAULT','',17,0,4),('HEAD_DESC_TAG_DEFAULT','',17,0,5),('HEAD_DESC_TAG_DEFAULT','',17,0,6),('HEAD_TITLE_TAG_PRODUCT_INFO','',1,0,4),('HEAD_TITLE_TAG_PRODUCT_INFO','',1,0,6),('HEAD_TITLE_TAG_PRODUCT_INFO','',3,0,4),('HEAD_TITLE_TAG_PRODUCT_INFO','',3,0,6),('HEAD_TITLE_TAG_PRODUCT_INFO','E-Commerce-Plattform - ##PRODUCT_NAME## - ##BRAND_NAME##',10,0,1),('HEAD_TITLE_TAG_PRODUCT_INFO','',10,0,4),('HEAD_TITLE_TAG_PRODUCT_INFO','',10,0,5),('HEAD_TITLE_TAG_PRODUCT_INFO','',10,0,6),('HEAD_TITLE_TAG_PRODUCT_INFO','',11,0,1),('HEAD_TITLE_TAG_PRODUCT_INFO','',11,0,4),('HEAD_TITLE_TAG_PRODUCT_INFO','',11,0,5),('HEAD_TITLE_TAG_PRODUCT_INFO','',11,0,6),('HEAD_TITLE_TAG_PRODUCT_INFO','',12,0,1),('HEAD_TITLE_TAG_PRODUCT_INFO','',12,0,4),('HEAD_TITLE_TAG_PRODUCT_INFO','',12,0,5),('HEAD_TITLE_TAG_PRODUCT_INFO','',12,0,6),('HEAD_TITLE_TAG_PRODUCT_INFO','',13,0,1),('HEAD_TITLE_TAG_PRODUCT_INFO','',13,0,4),('HEAD_TITLE_TAG_PRODUCT_INFO','',13,0,5),('HEAD_TITLE_TAG_PRODUCT_INFO','',13,0,6),('HEAD_TITLE_TAG_PRODUCT_INFO','',15,0,1),('HEAD_TITLE_TAG_PRODUCT_INFO','',15,0,4),('HEAD_TITLE_TAG_PRODUCT_INFO','',15,0,5),('HEAD_TITLE_TAG_PRODUCT_INFO','',15,0,6),('HEAD_TITLE_TAG_PRODUCT_INFO','',17,0,1),('HEAD_TITLE_TAG_PRODUCT_INFO','',17,0,4),('HEAD_TITLE_TAG_PRODUCT_INFO','',17,0,5),('HEAD_TITLE_TAG_PRODUCT_INFO','',17,0,6),('HEAD_KEY_TAG_PRODUCT_INFO','',1,0,4),('HEAD_KEY_TAG_PRODUCT_INFO','',1,0,6),('HEAD_KEY_TAG_PRODUCT_INFO','',3,0,4),('HEAD_KEY_TAG_PRODUCT_INFO','',3,0,6),('HEAD_KEY_TAG_PRODUCT_INFO','',10,0,1),('HEAD_KEY_TAG_PRODUCT_INFO','',10,0,4),('HEAD_KEY_TAG_PRODUCT_INFO','',10,0,5),('HEAD_KEY_TAG_PRODUCT_INFO','',10,0,6),('HEAD_KEY_TAG_PRODUCT_INFO','',11,0,1),('HEAD_KEY_TAG_PRODUCT_INFO','',11,0,4),('HEAD_KEY_TAG_PRODUCT_INFO','',11,0,5),('HEAD_KEY_TAG_PRODUCT_INFO','',11,0,6),('HEAD_KEY_TAG_PRODUCT_INFO','',12,0,1),('HEAD_KEY_TAG_PRODUCT_INFO','',12,0,4),('HEAD_KEY_TAG_PRODUCT_INFO','',12,0,5),('HEAD_KEY_TAG_PRODUCT_INFO','',12,0,6),('HEAD_KEY_TAG_PRODUCT_INFO','',13,0,1),('HEAD_KEY_TAG_PRODUCT_INFO','',13,0,4),('HEAD_KEY_TAG_PRODUCT_INFO','',13,0,5),('HEAD_KEY_TAG_PRODUCT_INFO','',13,0,6),('HEAD_KEY_TAG_PRODUCT_INFO','',15,0,1),('HEAD_KEY_TAG_PRODUCT_INFO','',15,0,4),('HEAD_KEY_TAG_PRODUCT_INFO','',15,0,5),('HEAD_KEY_TAG_PRODUCT_INFO','',15,0,6),('HEAD_KEY_TAG_PRODUCT_INFO','',17,0,1),('HEAD_KEY_TAG_PRODUCT_INFO','',17,0,4),('HEAD_KEY_TAG_PRODUCT_INFO','',17,0,5),('HEAD_KEY_TAG_PRODUCT_INFO','',17,0,6),('HEAD_DESC_TAG_PRODUCT_INFO','',1,0,4),('HEAD_DESC_TAG_PRODUCT_INFO','',1,0,6),('HEAD_DESC_TAG_PRODUCT_INFO','',3,0,4),('HEAD_DESC_TAG_PRODUCT_INFO','',3,0,6),('HEAD_DESC_TAG_PRODUCT_INFO','Verkaufen Sie Ihre Produkte mit E-Commerce-Site: TrueLoaded von Holbi. Dies ist ##PRODUCT_NAME## von ##CATEGORY_NAME##, produziert von ##BRAND_NAME##',10,0,1),('HEAD_DESC_TAG_PRODUCT_INFO','',10,0,4),('HEAD_DESC_TAG_PRODUCT_INFO','',10,0,5),('HEAD_DESC_TAG_PRODUCT_INFO','',10,0,6),('HEAD_DESC_TAG_PRODUCT_INFO','',11,0,1),('HEAD_DESC_TAG_PRODUCT_INFO','',11,0,4),('HEAD_DESC_TAG_PRODUCT_INFO','',11,0,5),('HEAD_DESC_TAG_PRODUCT_INFO','',11,0,6),('HEAD_DESC_TAG_PRODUCT_INFO','',12,0,1),('HEAD_DESC_TAG_PRODUCT_INFO','',12,0,4),('HEAD_DESC_TAG_PRODUCT_INFO','',12,0,5),('HEAD_DESC_TAG_PRODUCT_INFO','',12,0,6),('HEAD_DESC_TAG_PRODUCT_INFO','',13,0,1),('HEAD_DESC_TAG_PRODUCT_INFO','',13,0,4),('HEAD_DESC_TAG_PRODUCT_INFO','',13,0,5),('HEAD_DESC_TAG_PRODUCT_INFO','',13,0,6),('HEAD_DESC_TAG_PRODUCT_INFO','',15,0,1),('HEAD_DESC_TAG_PRODUCT_INFO','',15,0,4),('HEAD_DESC_TAG_PRODUCT_INFO','',15,0,5),('HEAD_DESC_TAG_PRODUCT_INFO','',15,0,6),('HEAD_DESC_TAG_PRODUCT_INFO','',17,0,1),('HEAD_DESC_TAG_PRODUCT_INFO','',17,0,4),('HEAD_DESC_TAG_PRODUCT_INFO','',17,0,5),('HEAD_DESC_TAG_PRODUCT_INFO','',17,0,6),('HEAD_TITLE_TAG_WHATS_NEW','',1,0,4),('HEAD_TITLE_TAG_WHATS_NEW','',1,0,6),('HEAD_TITLE_TAG_WHATS_NEW','',3,0,4),('HEAD_TITLE_TAG_WHATS_NEW','',3,0,6),('HEAD_TITLE_TAG_WHATS_NEW','Auflistung der neuesten Produkte',10,0,1),('HEAD_TITLE_TAG_WHATS_NEW','',10,0,4),('HEAD_TITLE_TAG_WHATS_NEW','',10,0,5),('HEAD_TITLE_TAG_WHATS_NEW','',10,0,6),('HEAD_TITLE_TAG_WHATS_NEW','Liste des derniers produits',11,0,1),('HEAD_TITLE_TAG_WHATS_NEW','',11,0,4),('HEAD_TITLE_TAG_WHATS_NEW','',11,0,5),('HEAD_TITLE_TAG_WHATS_NEW','',11,0,6),('HEAD_TITLE_TAG_WHATS_NEW','Oppføring av nyeste produkter',12,0,1),('HEAD_TITLE_TAG_WHATS_NEW','',12,0,4),('HEAD_TITLE_TAG_WHATS_NEW','',12,0,5),('HEAD_TITLE_TAG_WHATS_NEW','',12,0,6),('HEAD_TITLE_TAG_WHATS_NEW','Elenco degli ultimi prodotti',13,0,1),('HEAD_TITLE_TAG_WHATS_NEW','',13,0,4),('HEAD_TITLE_TAG_WHATS_NEW','',13,0,5),('HEAD_TITLE_TAG_WHATS_NEW','',13,0,6),('HEAD_TITLE_TAG_WHATS_NEW','Перелік останніх продуктів',15,0,1),('HEAD_TITLE_TAG_WHATS_NEW','',15,0,4),('HEAD_TITLE_TAG_WHATS_NEW','',15,0,5),('HEAD_TITLE_TAG_WHATS_NEW','',15,0,6),('HEAD_TITLE_TAG_WHATS_NEW','Список последних продуктов',17,0,1),('HEAD_TITLE_TAG_WHATS_NEW','',17,0,4),('HEAD_TITLE_TAG_WHATS_NEW','',17,0,5),('HEAD_TITLE_TAG_WHATS_NEW','',17,0,6),('HEAD_KEY_TAG_WHATS_NEW','',1,0,4),('HEAD_KEY_TAG_WHATS_NEW','',1,0,6),('HEAD_KEY_TAG_WHATS_NEW','',3,0,4),('HEAD_KEY_TAG_WHATS_NEW','',3,0,6),('HEAD_KEY_TAG_WHATS_NEW','',10,0,1),('HEAD_KEY_TAG_WHATS_NEW','',10,0,4),('HEAD_KEY_TAG_WHATS_NEW','',10,0,5),('HEAD_KEY_TAG_WHATS_NEW','',10,0,6),('HEAD_KEY_TAG_WHATS_NEW','',11,0,1),('HEAD_KEY_TAG_WHATS_NEW','',11,0,4),('HEAD_KEY_TAG_WHATS_NEW','',11,0,5),('HEAD_KEY_TAG_WHATS_NEW','',11,0,6),('HEAD_KEY_TAG_WHATS_NEW','',12,0,1),('HEAD_KEY_TAG_WHATS_NEW','',12,0,4),('HEAD_KEY_TAG_WHATS_NEW','',12,0,5),('HEAD_KEY_TAG_WHATS_NEW','',12,0,6),('HEAD_KEY_TAG_WHATS_NEW','',13,0,1),('HEAD_KEY_TAG_WHATS_NEW','',13,0,4),('HEAD_KEY_TAG_WHATS_NEW','',13,0,5),('HEAD_KEY_TAG_WHATS_NEW','',13,0,6),('HEAD_KEY_TAG_WHATS_NEW','',15,0,1),('HEAD_KEY_TAG_WHATS_NEW','',15,0,4),('HEAD_KEY_TAG_WHATS_NEW','',15,0,5),('HEAD_KEY_TAG_WHATS_NEW','',15,0,6),('HEAD_KEY_TAG_WHATS_NEW','',17,0,1),('HEAD_KEY_TAG_WHATS_NEW','',17,0,4),('HEAD_KEY_TAG_WHATS_NEW','',17,0,5),('HEAD_KEY_TAG_WHATS_NEW','',17,0,6),('HEAD_DESC_TAG_WHATS_NEW','',1,0,4),('HEAD_DESC_TAG_WHATS_NEW','',1,0,6),('HEAD_DESC_TAG_WHATS_NEW','',3,0,4),('HEAD_DESC_TAG_WHATS_NEW','',3,0,6),('HEAD_DESC_TAG_WHATS_NEW','Sie können das neueste Produkt hier mit E-Commerce-Website finden: TrueLoaded von Holbi',10,0,1),('HEAD_DESC_TAG_WHATS_NEW','',10,0,4),('HEAD_DESC_TAG_WHATS_NEW','',10,0,5),('HEAD_DESC_TAG_WHATS_NEW','',10,0,6),('HEAD_DESC_TAG_WHATS_NEW','Vous pouvez trouver le dernier produit ici avec le site de commerce électronique: TrueLoaded by Holbi',11,0,1),('HEAD_DESC_TAG_WHATS_NEW','',11,0,4),('HEAD_DESC_TAG_WHATS_NEW','',11,0,5),('HEAD_DESC_TAG_WHATS_NEW','',11,0,6),('HEAD_DESC_TAG_WHATS_NEW','Du kan finne det nyeste produktet her med e-handel nettsted: TrueLoaded av Holbi',12,0,1),('HEAD_DESC_TAG_WHATS_NEW','',12,0,4),('HEAD_DESC_TAG_WHATS_NEW','',12,0,5),('HEAD_DESC_TAG_WHATS_NEW','',12,0,6),('HEAD_DESC_TAG_WHATS_NEW','Puoi trovare l\'ultimo prodotto qui con il sito web di e-commerce: TrueLoaded di Holbi',13,0,1),('HEAD_DESC_TAG_WHATS_NEW','',13,0,4),('HEAD_DESC_TAG_WHATS_NEW','',13,0,5),('HEAD_DESC_TAG_WHATS_NEW','',13,0,6),('HEAD_DESC_TAG_WHATS_NEW','Ви можете знайти новітній продукт на сайті електронної комерції: TrueLoaded by Holbi',15,0,1),('HEAD_DESC_TAG_WHATS_NEW','',15,0,4),('HEAD_DESC_TAG_WHATS_NEW','',15,0,5),('HEAD_DESC_TAG_WHATS_NEW','',15,0,6),('HEAD_DESC_TAG_WHATS_NEW','Вы можете найти новейший продукт на сайте электронной коммерции: TrueLoaded by Holbi',17,0,1),('HEAD_DESC_TAG_WHATS_NEW','',17,0,4),('HEAD_DESC_TAG_WHATS_NEW','',17,0,5),('HEAD_DESC_TAG_WHATS_NEW','',17,0,6),('HEAD_TITLE_TAG_SPECIALS','',1,0,4),('HEAD_TITLE_TAG_SPECIALS','',1,0,6),('HEAD_TITLE_TAG_SPECIALS','',3,0,4),('HEAD_TITLE_TAG_SPECIALS','',3,0,6),('HEAD_TITLE_TAG_SPECIALS','Auflistung von Specials - Verkauf - Produkte',10,0,1),('HEAD_TITLE_TAG_SPECIALS','',10,0,4),('HEAD_TITLE_TAG_SPECIALS','',10,0,5),('HEAD_TITLE_TAG_SPECIALS','',10,0,6),('HEAD_TITLE_TAG_SPECIALS','Liste des promotions - ventes - produits',11,0,1),('HEAD_TITLE_TAG_SPECIALS','',11,0,4),('HEAD_TITLE_TAG_SPECIALS','',11,0,5),('HEAD_TITLE_TAG_SPECIALS','',11,0,6),('HEAD_TITLE_TAG_SPECIALS','Oppføring av tilbud - salgsprodukter',12,0,1),('HEAD_TITLE_TAG_SPECIALS','',12,0,4),('HEAD_TITLE_TAG_SPECIALS','',12,0,5),('HEAD_TITLE_TAG_SPECIALS','',12,0,6),('HEAD_TITLE_TAG_SPECIALS','Elenco di offerte speciali - vendite - prodotti',13,0,1),('HEAD_TITLE_TAG_SPECIALS','',13,0,4),('HEAD_TITLE_TAG_SPECIALS','',13,0,5),('HEAD_TITLE_TAG_SPECIALS','',13,0,6),('HEAD_TITLE_TAG_SPECIALS','Перелік спеціальних продуктів- продаж - продуки',15,0,1),('HEAD_TITLE_TAG_SPECIALS','',15,0,4),('HEAD_TITLE_TAG_SPECIALS','',15,0,5),('HEAD_TITLE_TAG_SPECIALS','',15,0,6),('HEAD_TITLE_TAG_SPECIALS','Список специальных продуктов - продажа - продукты',17,0,1),('HEAD_TITLE_TAG_SPECIALS','',17,0,4),('HEAD_TITLE_TAG_SPECIALS','',17,0,5),('HEAD_TITLE_TAG_SPECIALS','',17,0,6),('HEAD_KEY_TAG_SPECIALS','',1,0,4),('HEAD_KEY_TAG_SPECIALS','',1,0,6),('HEAD_KEY_TAG_SPECIALS','',3,0,4),('HEAD_KEY_TAG_SPECIALS','',3,0,6),('HEAD_KEY_TAG_SPECIALS','',10,0,1),('HEAD_KEY_TAG_SPECIALS','',10,0,4),('HEAD_KEY_TAG_SPECIALS','',10,0,5),('HEAD_KEY_TAG_SPECIALS','',10,0,6),('HEAD_KEY_TAG_SPECIALS','',11,0,1),('HEAD_KEY_TAG_SPECIALS','',11,0,4),('HEAD_KEY_TAG_SPECIALS','',11,0,5),('HEAD_KEY_TAG_SPECIALS','',11,0,6),('HEAD_KEY_TAG_SPECIALS','',12,0,1),('HEAD_KEY_TAG_SPECIALS','',12,0,4),('HEAD_KEY_TAG_SPECIALS','',12,0,5),('HEAD_KEY_TAG_SPECIALS','',12,0,6),('HEAD_KEY_TAG_SPECIALS','',13,0,1),('HEAD_KEY_TAG_SPECIALS','',13,0,4),('HEAD_KEY_TAG_SPECIALS','',13,0,5),('HEAD_KEY_TAG_SPECIALS','',13,0,6),('HEAD_KEY_TAG_SPECIALS','',15,0,1),('HEAD_KEY_TAG_SPECIALS','',15,0,4),('HEAD_KEY_TAG_SPECIALS','',15,0,5),('HEAD_KEY_TAG_SPECIALS','',15,0,6),('HEAD_KEY_TAG_SPECIALS','',17,0,1),('HEAD_KEY_TAG_SPECIALS','',17,0,4),('HEAD_KEY_TAG_SPECIALS','',17,0,5),('HEAD_KEY_TAG_SPECIALS','',17,0,6),('HEAD_DESC_TAG_SPECIALS','',1,0,4),('HEAD_DESC_TAG_SPECIALS','',1,0,6),('HEAD_DESC_TAG_SPECIALS','',3,0,4),('HEAD_DESC_TAG_SPECIALS','',3,0,6),('HEAD_DESC_TAG_SPECIALS','Ihre Kunden werden alle Verkäufe auf Ihrer Website sehen, die auf der E-Commerce-Website basieren: TrueLoaded by Holbi',10,0,1),('HEAD_DESC_TAG_SPECIALS','',10,0,4),('HEAD_DESC_TAG_SPECIALS','',10,0,5),('HEAD_DESC_TAG_SPECIALS','',10,0,6),('HEAD_DESC_TAG_SPECIALS','Vos clients verront toutes les ventes sur votre site web alimenté par le site de commerce électronique: TrueLoaded par Holbi',11,0,1),('HEAD_DESC_TAG_SPECIALS','',11,0,4),('HEAD_DESC_TAG_SPECIALS','',11,0,5),('HEAD_DESC_TAG_SPECIALS','',11,0,6),('HEAD_DESC_TAG_SPECIALS','Dine kunder vil se alt salg på nettstedet ditt drevet av e-handelsnettsted: TrueLoaded av Holbi',12,0,1),('HEAD_DESC_TAG_SPECIALS','',12,0,4),('HEAD_DESC_TAG_SPECIALS','',12,0,5),('HEAD_DESC_TAG_SPECIALS','',12,0,6),('HEAD_DESC_TAG_SPECIALS','I tuoi clienti vedranno tutte le vendite sul tuo sito web supportate dal sito di e-commerce: TrueLoaded by Holbi',13,0,1),('HEAD_DESC_TAG_SPECIALS','',13,0,4),('HEAD_DESC_TAG_SPECIALS','',13,0,5),('HEAD_DESC_TAG_SPECIALS','',13,0,6),('HEAD_DESC_TAG_SPECIALS','Ваші клієнти будуть бачити всі розпродажі вашого сайту на сайті електронної комерції: TrueLoaded by Holbi',15,0,1),('HEAD_DESC_TAG_SPECIALS','',15,0,4),('HEAD_DESC_TAG_SPECIALS','',15,0,5),('HEAD_DESC_TAG_SPECIALS','',15,0,6),('HEAD_DESC_TAG_SPECIALS','Ваши клиенты будут видеть все распродажи вашего сайта на сайте электронной коммерции: TrueLoaded by Holbi',17,0,1),('HEAD_DESC_TAG_SPECIALS','',17,0,4),('HEAD_DESC_TAG_SPECIALS','',17,0,5),('HEAD_DESC_TAG_SPECIALS','',17,0,6),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',1,0,4),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',1,0,6),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',3,0,4),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',3,0,6),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Lesen Sie, was andere sagen',10,0,1),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',10,0,4),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',10,0,5),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',10,0,6),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Lisez ce que les autres disent',11,0,1),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',11,0,4),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',11,0,5),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',11,0,6),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Les hva andre sier',12,0,1),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',12,0,4),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',12,0,5),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',12,0,6),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Leggi cosa dicono gli altri',13,0,1),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',13,0,4),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',13,0,5),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',13,0,6),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Прочитайте, що говорять інші',15,0,1),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',15,0,4),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',15,0,5),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',15,0,6),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Читайте, что говорят другие',17,0,1),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',17,0,4),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',17,0,5),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',17,0,6),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',1,0,4),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',1,0,6),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',3,0,4),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',3,0,6),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',10,0,1),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',10,0,4),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',10,0,5),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',10,0,6),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',11,0,1),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',11,0,4),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',11,0,5),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',11,0,6),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',12,0,1),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',12,0,4),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',12,0,5),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',12,0,6),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',13,0,1),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',13,0,4),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',13,0,5),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',13,0,6),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',15,0,1),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',15,0,4),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',15,0,5),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',15,0,6),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',17,0,1),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',17,0,4),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',17,0,5),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',17,0,6),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',1,0,4),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',1,0,6),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',3,0,4),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',3,0,6),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Produktbewertungen: Lesen Sie, was andere über die Ecommerce-Plattform sagen: TrueLoaded by Holbi',10,0,1),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',10,0,4),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',10,0,5),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',10,0,6),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Avis sur les produits: Lisez ce que les autres disent à propos de la plate-forme de commerce électronique: TrueLoaded by Holbi',11,0,1),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',11,0,4),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',11,0,5),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',11,0,6),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Produktanmeldelser: Les hva andre sier om E-handel plattform: TrueLoaded av Holbi',12,0,1),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',12,0,4),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',12,0,5),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',12,0,6),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Recensioni dei prodotti: leggi cosa dicono gli altri sulla piattaforma di e-commerce: TrueLoaded by Holbi',13,0,1),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',13,0,4),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',13,0,5),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',13,0,6),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Огляд продуктів: прочитайте, що говорять інші про платформу платформі електронної комерції: TrueLoaded by Holbi',15,0,1),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',15,0,4),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',15,0,5),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',15,0,6),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Обзор продуктов: прочитайте, что говорят другие о платформе платформе электронной коммерции: TrueLoaded by Holbi',17,0,1),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',17,0,4),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',17,0,5),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',17,0,6),('HEAD_H3_TAG_ALL','',13,0,1),('HEAD_H2_TAG_ALL','',15,0,1),('HEAD_H1_TAG_ALL','',10,0,6),('HEAD_H3_TAG_ALL','',12,0,6),('HEAD_H2_TAG_ALL','',13,0,6),('HEAD_H1_TAG_ALL','',15,0,1),('HEAD_H1_TAG_ALL','',13,0,6),('HEAD_H3_TAG_ALL','',17,0,6),('HEAD_H3_TAG_ALL','',3,0,1),('HEAD_H2_TAG_ALL','',10,0,1),('HEAD_H2_TAG_ALL','',1,0,6),('HEAD_H2_TAG_ALL','',3,0,6),('HEAD_H1_TAG_ALL','',10,0,1),('HEAD_H1_TAG_DEFAULT','E-Commerce Plattform TrueLoaded von Holbi Group',10,0,1),('HEAD_H3_TAG_ALL','',12,0,1),('HEAD_H2_TAG_ALL','',13,0,1),('HEAD_H1_TAG_ALL','',3,0,6),('HEAD_H1_TAG_DEFAULT','',3,0,6),('HEAD_H3_TAG_ALL','',11,0,6),('HEAD_H2_TAG_ALL','',12,0,6),('HEAD_H1_TAG_ALL','',13,0,1),('HEAD_H3_TAG_ALL','',17,0,1),('HEAD_H1_TAG_ALL','',12,0,6),('HEAD_H3_TAG_ALL','',15,0,6),('HEAD_H2_TAG_ALL','',17,0,6),('HEAD_H2_TAG_ALL','',3,0,1),('HEAD_H1_TAG_ALL','',17,0,6),('HEAD_H1_TAG_ALL','',3,0,1),('HEAD_H1_TAG_DEFAULT','E-commerceplatform TrueLoaded door Holbi Group',3,0,1),('HEAD_H3_TAG_ALL','',11,0,1),('HEAD_H2_TAG_ALL','',12,0,1),('HEAD_H1_TAG_ALL','',1,0,6),('HEAD_H1_TAG_DEFAULT','',1,0,6),('HEAD_H3_TAG_ALL','',10,0,6),('HEAD_H2_TAG_ALL','',11,0,6),('HEAD_H1_TAG_ALL','',12,0,1),('HEAD_H3_TAG_ALL','',15,0,1),('HEAD_H2_TAG_ALL','',17,0,1),('HEAD_H1_TAG_ALL','',11,0,6),('HEAD_H3_TAG_ALL','',13,0,6),('HEAD_H2_TAG_ALL','',15,0,6),('HEAD_H1_TAG_ALL','',17,0,1),('HEAD_H1_TAG_ALL','',15,0,6),('HEAD_H1_TAG_ALL','',1,0,1),('HEAD_H1_TAG_DEFAULT','Ecommerce platform osCommerce by Holbi Group',1,0,1),('HEAD_H3_TAG_ALL','',10,0,1),('HEAD_H2_TAG_ALL','',11,0,1),('HEAD_H3_TAG_ALL','',1,0,6),('HEAD_H3_TAG_ALL','',3,0,6),('HEAD_H2_TAG_ALL','',10,0,6),('HEAD_H1_TAG_ALL','',11,0,1),('HEAD_H3_TAG_ALL','',1,0,1),('HEAD_H2_TAG_ALL','',1,0,1),('HEAD_H1_TAG_DEFAULT','',10,0,6),('HEAD_H1_TAG_DEFAULT','Plateforme de commerce électronique TrueLoaded par Holbi Group',11,0,1),('HEAD_H1_TAG_DEFAULT','',11,0,6),('HEAD_H1_TAG_DEFAULT','E-handel plattform TrueLoaded av Holbi Group',12,0,1),('HEAD_H1_TAG_DEFAULT','',12,0,6),('HEAD_H1_TAG_DEFAULT','Piattaforma di e-commerce TrueLoaded di Holbi Group',13,0,1),('HEAD_H1_TAG_DEFAULT','',13,0,6),('HEAD_H1_TAG_DEFAULT','Електронна комерційна платформа TrueLoaded від Holbi Group',15,0,1),('HEAD_H1_TAG_DEFAULT','',15,0,6),('HEAD_H1_TAG_DEFAULT','Электронная коммерция TrueLoaded от Holbi Group',17,0,1),('HEAD_H1_TAG_DEFAULT','',17,0,6),('HEAD_H2_TAG_DEFAULT','',1,0,1),('HEAD_H2_TAG_DEFAULT','',1,0,6),('HEAD_H2_TAG_DEFAULT','',3,0,1),('HEAD_H2_TAG_DEFAULT','',3,0,6),('HEAD_H2_TAG_DEFAULT','',10,0,1),('HEAD_H2_TAG_DEFAULT','',10,0,6),('HEAD_H2_TAG_DEFAULT','',11,0,1),('HEAD_H2_TAG_DEFAULT','',11,0,6),('HEAD_H2_TAG_DEFAULT','',12,0,1),('HEAD_H2_TAG_DEFAULT','',12,0,6),('HEAD_H2_TAG_DEFAULT','',13,0,1),('HEAD_H2_TAG_DEFAULT','',13,0,6),('HEAD_H2_TAG_DEFAULT','',15,0,1),('HEAD_H2_TAG_DEFAULT','',15,0,6),('HEAD_H2_TAG_DEFAULT','',17,0,1),('HEAD_H2_TAG_DEFAULT','',17,0,6),('HEAD_H3_TAG_DEFAULT','',1,0,1),('HEAD_H3_TAG_DEFAULT','',1,0,6),('HEAD_H3_TAG_DEFAULT','',3,0,1),('HEAD_H3_TAG_DEFAULT','',3,0,6),('HEAD_H3_TAG_DEFAULT','',10,0,1),('HEAD_H3_TAG_DEFAULT','',10,0,6),('HEAD_H3_TAG_DEFAULT','',11,0,1),('HEAD_H3_TAG_DEFAULT','',11,0,6),('HEAD_H3_TAG_DEFAULT','',12,0,1),('HEAD_H3_TAG_DEFAULT','',12,0,6),('HEAD_H3_TAG_DEFAULT','',13,0,1),('HEAD_H3_TAG_DEFAULT','',13,0,6),('HEAD_H3_TAG_DEFAULT','',15,0,1),('HEAD_H3_TAG_DEFAULT','',15,0,6),('HEAD_H3_TAG_DEFAULT','',17,0,1),('HEAD_H3_TAG_DEFAULT','',17,0,6),('HEAD_H1_TAG_PRODUCT_INFO','',1,0,1),('HEAD_H1_TAG_PRODUCT_INFO','',1,0,6),('HEAD_H1_TAG_PRODUCT_INFO','',3,0,1),('HEAD_H1_TAG_PRODUCT_INFO','',3,0,6),('HEAD_H1_TAG_PRODUCT_INFO','',10,0,1),('HEAD_H1_TAG_PRODUCT_INFO','',10,0,6),('HEAD_H1_TAG_PRODUCT_INFO','',11,0,1),('HEAD_H1_TAG_PRODUCT_INFO','',11,0,6),('HEAD_H1_TAG_PRODUCT_INFO','',12,0,1),('HEAD_H1_TAG_PRODUCT_INFO','',12,0,6),('HEAD_H1_TAG_PRODUCT_INFO','',13,0,1),('HEAD_H1_TAG_PRODUCT_INFO','',13,0,6),('HEAD_H1_TAG_PRODUCT_INFO','',15,0,1),('HEAD_H1_TAG_PRODUCT_INFO','',15,0,6),('HEAD_H1_TAG_PRODUCT_INFO','',17,0,1),('HEAD_H1_TAG_PRODUCT_INFO','',17,0,6),('HEAD_H2_TAG_PRODUCT_INFO','',1,0,1),('HEAD_H2_TAG_PRODUCT_INFO','',1,0,6),('HEAD_H2_TAG_PRODUCT_INFO','',3,0,1),('HEAD_H2_TAG_PRODUCT_INFO','',3,0,6),('HEAD_H2_TAG_PRODUCT_INFO','',10,0,1),('HEAD_H2_TAG_PRODUCT_INFO','',10,0,6),('HEAD_H2_TAG_PRODUCT_INFO','',11,0,1),('HEAD_H2_TAG_PRODUCT_INFO','',11,0,6),('HEAD_H2_TAG_PRODUCT_INFO','',12,0,1),('HEAD_H2_TAG_PRODUCT_INFO','',12,0,6),('HEAD_H2_TAG_PRODUCT_INFO','',13,0,1),('HEAD_H2_TAG_PRODUCT_INFO','',13,0,6),('HEAD_H2_TAG_PRODUCT_INFO','',15,0,1),('HEAD_H2_TAG_PRODUCT_INFO','',15,0,6),('HEAD_H2_TAG_PRODUCT_INFO','',17,0,1),('HEAD_H2_TAG_PRODUCT_INFO','',17,0,6),('HEAD_H3_TAG_PRODUCT_INFO','',1,0,1),('HEAD_H3_TAG_PRODUCT_INFO','',1,0,6),('HEAD_H3_TAG_PRODUCT_INFO','',3,0,1),('HEAD_H3_TAG_PRODUCT_INFO','',3,0,6),('HEAD_H3_TAG_PRODUCT_INFO','',10,0,1),('HEAD_H3_TAG_PRODUCT_INFO','',10,0,6),('HEAD_H3_TAG_PRODUCT_INFO','',11,0,1),('HEAD_H3_TAG_PRODUCT_INFO','',11,0,6),('HEAD_H3_TAG_PRODUCT_INFO','',12,0,1),('HEAD_H3_TAG_PRODUCT_INFO','',12,0,6),('HEAD_H3_TAG_PRODUCT_INFO','',13,0,1),('HEAD_H3_TAG_PRODUCT_INFO','',13,0,6),('HEAD_H3_TAG_PRODUCT_INFO','',15,0,1),('HEAD_H3_TAG_PRODUCT_INFO','',15,0,6),('HEAD_H3_TAG_PRODUCT_INFO','',17,0,1),('HEAD_H3_TAG_PRODUCT_INFO','',17,0,6),('HEAD_H1_TAG_WHATS_NEW','latest products feature',1,0,1),('HEAD_H1_TAG_WHATS_NEW','',1,0,6),('HEAD_H1_TAG_WHATS_NEW','nieuwste producten functie',3,0,1),('HEAD_H1_TAG_WHATS_NEW','',3,0,6),('HEAD_H1_TAG_WHATS_NEW','neueste Produkteigenschaft',10,0,1),('HEAD_H1_TAG_WHATS_NEW','',10,0,6),('HEAD_H1_TAG_WHATS_NEW','dernière caractéristique des produits',11,0,1),('HEAD_H1_TAG_WHATS_NEW','',11,0,6),('HEAD_H1_TAG_WHATS_NEW','nyeste produktfunksjonen',12,0,1),('HEAD_H1_TAG_WHATS_NEW','',12,0,6),('HEAD_H1_TAG_WHATS_NEW','ultima funzionalità dei prodotti',13,0,1),('HEAD_H1_TAG_WHATS_NEW','',13,0,6),('HEAD_H1_TAG_WHATS_NEW','найновіші продукти',15,0,1),('HEAD_H1_TAG_WHATS_NEW','',15,0,6),('HEAD_H1_TAG_WHATS_NEW','новейшие продукты',17,0,1),('HEAD_H1_TAG_WHATS_NEW','',17,0,6),('HEAD_H2_TAG_WHATS_NEW','',1,0,1),('HEAD_H2_TAG_WHATS_NEW','',1,0,6),('HEAD_H2_TAG_WHATS_NEW','',3,0,1),('HEAD_H2_TAG_WHATS_NEW','',3,0,6),('HEAD_H2_TAG_WHATS_NEW','',10,0,1),('HEAD_H2_TAG_WHATS_NEW','',10,0,6),('HEAD_H2_TAG_WHATS_NEW','',11,0,1),('HEAD_H2_TAG_WHATS_NEW','',11,0,6),('HEAD_H2_TAG_WHATS_NEW','',12,0,1),('HEAD_H2_TAG_WHATS_NEW','',12,0,6),('HEAD_H2_TAG_WHATS_NEW','',13,0,1),('HEAD_H2_TAG_WHATS_NEW','',13,0,6),('HEAD_H2_TAG_WHATS_NEW','',15,0,1),('HEAD_H2_TAG_WHATS_NEW','',15,0,6),('HEAD_H2_TAG_WHATS_NEW','',17,0,1),('HEAD_H2_TAG_WHATS_NEW','',17,0,6),('HEAD_H3_TAG_WHATS_NEW','',1,0,1),('HEAD_H3_TAG_WHATS_NEW','',1,0,6),('HEAD_H3_TAG_WHATS_NEW','',3,0,1),('HEAD_H3_TAG_WHATS_NEW','',3,0,6),('HEAD_H3_TAG_WHATS_NEW','',10,0,1),('HEAD_H3_TAG_WHATS_NEW','',10,0,6),('HEAD_H3_TAG_WHATS_NEW','',11,0,1),('HEAD_H3_TAG_WHATS_NEW','',11,0,6),('HEAD_H3_TAG_WHATS_NEW','',12,0,1),('HEAD_H3_TAG_WHATS_NEW','',12,0,6),('HEAD_H3_TAG_WHATS_NEW','',13,0,1),('HEAD_H3_TAG_WHATS_NEW','',13,0,6),('HEAD_H3_TAG_WHATS_NEW','',15,0,1),('HEAD_H3_TAG_WHATS_NEW','',15,0,6),('HEAD_H3_TAG_WHATS_NEW','',17,0,1),('HEAD_H3_TAG_WHATS_NEW','',17,0,6),('HEAD_H1_TAG_SPECIALS','Sales feature',1,0,1),('HEAD_H1_TAG_SPECIALS','',1,0,6),('HEAD_H1_TAG_SPECIALS','Verkoop functie',3,0,1),('HEAD_H1_TAG_SPECIALS','',3,0,6),('HEAD_H1_TAG_SPECIALS','Verkaufsfunktion',10,0,1),('HEAD_H1_TAG_SPECIALS','',10,0,6),('HEAD_H1_TAG_SPECIALS','Fonction de vente',11,0,1),('HEAD_H1_TAG_SPECIALS','',11,0,6),('HEAD_H1_TAG_SPECIALS','Salgsfunksjon',12,0,1),('HEAD_H1_TAG_SPECIALS','',12,0,6),('HEAD_H1_TAG_SPECIALS','Caratteristica di vendita',13,0,1),('HEAD_H1_TAG_SPECIALS','',13,0,6),('HEAD_H1_TAG_SPECIALS','Розпродажі',15,0,1),('HEAD_H1_TAG_SPECIALS','',15,0,6),('HEAD_H1_TAG_SPECIALS','Распродажи',17,0,1),('HEAD_H1_TAG_SPECIALS','',17,0,6),('HEAD_H2_TAG_SPECIALS','',1,0,1),('HEAD_H2_TAG_SPECIALS','',1,0,6),('HEAD_H2_TAG_SPECIALS','',3,0,1),('HEAD_H2_TAG_SPECIALS','',3,0,6),('HEAD_H2_TAG_SPECIALS','',10,0,1),('HEAD_H2_TAG_SPECIALS','',10,0,6),('HEAD_H2_TAG_SPECIALS','',11,0,1),('HEAD_H2_TAG_SPECIALS','',11,0,6),('HEAD_H2_TAG_SPECIALS','',12,0,1),('HEAD_H2_TAG_SPECIALS','',12,0,6),('HEAD_H2_TAG_SPECIALS','',13,0,1),('HEAD_H2_TAG_SPECIALS','',13,0,6),('HEAD_H2_TAG_SPECIALS','',15,0,1),('HEAD_H2_TAG_SPECIALS','',15,0,6),('HEAD_H2_TAG_SPECIALS','',17,0,1),('HEAD_H2_TAG_SPECIALS','',17,0,6),('HEAD_H3_TAG_SPECIALS','',1,0,1),('HEAD_H3_TAG_SPECIALS','',1,0,6),('HEAD_H3_TAG_SPECIALS','',3,0,1),('HEAD_H3_TAG_SPECIALS','',3,0,6),('HEAD_H3_TAG_SPECIALS','',10,0,1),('HEAD_H3_TAG_SPECIALS','',10,0,6),('HEAD_H3_TAG_SPECIALS','',11,0,1),('HEAD_H3_TAG_SPECIALS','',11,0,6),('HEAD_H3_TAG_SPECIALS','',12,0,1),('HEAD_H3_TAG_SPECIALS','',12,0,6),('HEAD_H3_TAG_SPECIALS','',13,0,1),('HEAD_H3_TAG_SPECIALS','',13,0,6),('HEAD_H3_TAG_SPECIALS','',15,0,1),('HEAD_H3_TAG_SPECIALS','',15,0,6),('HEAD_H3_TAG_SPECIALS','',17,0,1),('HEAD_H3_TAG_SPECIALS','',17,0,6),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Products reviews functionality',1,0,1),('HEAD_TITLE_TAG_PRODUCTS_ALL','Listing of all products on the site',1,0,1),('HEAD_TITLE_TAG_PRODUCTS_ALL','',1,0,6),('HEAD_TITLE_TAG_PRODUCTS_ALL','Lijst van alle producten op de site',3,0,1),('HEAD_TITLE_TAG_PRODUCTS_ALL','',3,0,6),('HEAD_TITLE_TAG_PRODUCTS_ALL','Auflistung aller Produkte auf der Website',10,0,1),('HEAD_TITLE_TAG_PRODUCTS_ALL','',10,0,6),('HEAD_TITLE_TAG_PRODUCTS_ALL','Liste de tous les produits sur le site',11,0,1),('HEAD_TITLE_TAG_PRODUCTS_ALL','',11,0,6),('HEAD_TITLE_TAG_PRODUCTS_ALL','Oppføring av alle produkter på nettstedet',12,0,1),('HEAD_TITLE_TAG_PRODUCTS_ALL','',12,0,6),('HEAD_TITLE_TAG_PRODUCTS_ALL','Elenco di tutti i prodotti sul sito',13,0,1),('HEAD_TITLE_TAG_PRODUCTS_ALL','',13,0,6),('HEAD_TITLE_TAG_PRODUCTS_ALL','Перелік усіх продуктів на сайті',15,0,1),('HEAD_TITLE_TAG_PRODUCTS_ALL','',15,0,6),('HEAD_TITLE_TAG_PRODUCTS_ALL','Список всех продуктов на сайте',17,0,1),('HEAD_TITLE_TAG_PRODUCTS_ALL','',17,0,6),('HEAD_DESC_TAG_PRODUCTS_ALL','Listing of all your product with filters availble here. Powered by ecommerce platform: osCommerce by Holbi',1,0,1),('HEAD_DESC_TAG_PRODUCTS_ALL','',1,0,6),('HEAD_DESC_TAG_PRODUCTS_ALL','Lijst van al uw producten met filters hier beschikbaar. Mogelijk gemaakt door e-commerce platform: TrueLoaded door Holbi',3,0,1),('HEAD_DESC_TAG_PRODUCTS_ALL','',3,0,6),('HEAD_DESC_TAG_PRODUCTS_ALL','Hier finden Sie eine Auflistung aller Produkte mit Filtern. Powered by E-Commerce-Plattform: TrueLoaded von Holbi',10,0,1),('HEAD_DESC_TAG_PRODUCTS_ALL','',10,0,6),('HEAD_DESC_TAG_PRODUCTS_ALL','Liste de tous vos produits avec des filtres disponibles ici. Propulsé par une plate-forme de commerce électronique: TrueLoaded par Holbi',11,0,1),('HEAD_DESC_TAG_PRODUCTS_ALL','',11,0,6),('HEAD_DESC_TAG_PRODUCTS_ALL','Oppføring av alt ditt produkt med filtre tilgjengelig her. Drevet av e-handelsplattform: TrueLoaded av Holbi',12,0,1),('HEAD_DESC_TAG_PRODUCTS_ALL','',12,0,6),('HEAD_DESC_TAG_PRODUCTS_ALL','Elenco di tutti i tuoi prodotti con filtri disponibili qui. Basato sulla piattaforma di e-commerce: TrueLoaded di Holbi',13,0,1),('HEAD_DESC_TAG_PRODUCTS_ALL','',13,0,6),('HEAD_DESC_TAG_PRODUCTS_ALL','Перелік усіх ваших продуктів із фільтрами доступний тут. Працює на платформі електронної комерції: TrueLoaded by Holbi',15,0,1),('HEAD_DESC_TAG_PRODUCTS_ALL','',15,0,6),('HEAD_DESC_TAG_PRODUCTS_ALL','Здесь представлен список всех ваших продуктов с фильтрами. Работает на платформе электронной коммерции: TrueLoaded by Holbi',17,0,1),('HEAD_DESC_TAG_PRODUCTS_ALL','',17,0,6),('HEAD_H1_TAG_PRODUCTS_ALL','Full product range with filters module',1,0,1),('HEAD_H1_TAG_PRODUCTS_ALL','',1,0,6),('HEAD_H1_TAG_PRODUCTS_ALL','Volledig assortiment met filtermodule',3,0,1),('HEAD_H1_TAG_PRODUCTS_ALL','',3,0,6),('HEAD_H1_TAG_PRODUCTS_ALL','Komplette Produktpalette mit Filtermodul',10,0,1),('HEAD_H1_TAG_PRODUCTS_ALL','',10,0,6),('HEAD_H1_TAG_PRODUCTS_ALL','Gamme complète de produits avec module de filtres',11,0,1),('HEAD_H1_TAG_PRODUCTS_ALL','',11,0,6),('HEAD_H1_TAG_PRODUCTS_ALL','Fullt produktsortiment med filtermodul',12,0,1),('HEAD_H1_TAG_PRODUCTS_ALL','',12,0,6),('HEAD_H1_TAG_PRODUCTS_ALL','Gamma completa di prodotti con modulo filtri',13,0,1),('HEAD_H1_TAG_PRODUCTS_ALL','',13,0,6),('HEAD_H1_TAG_PRODUCTS_ALL','Повний асортимент продукції з модулем фільтрів',15,0,1),('HEAD_H1_TAG_PRODUCTS_ALL','',15,0,6),('HEAD_H1_TAG_PRODUCTS_ALL','Полный ассортимент продукции с модулем фильтров',17,0,1),('HEAD_H1_TAG_PRODUCTS_ALL','',17,0,6),('HEAD_H2_TAG_PRODUCTS_ALL','',1,0,1),('HEAD_H2_TAG_PRODUCTS_ALL','',1,0,6),('HEAD_H2_TAG_PRODUCTS_ALL','',3,0,1),('HEAD_H2_TAG_PRODUCTS_ALL','',3,0,6),('HEAD_H2_TAG_PRODUCTS_ALL','',10,0,1),('HEAD_H2_TAG_PRODUCTS_ALL','',10,0,6),('HEAD_H2_TAG_PRODUCTS_ALL','',11,0,1),('HEAD_H2_TAG_PRODUCTS_ALL','',11,0,6),('HEAD_H2_TAG_PRODUCTS_ALL','',12,0,1),('HEAD_H2_TAG_PRODUCTS_ALL','',12,0,6),('HEAD_H2_TAG_PRODUCTS_ALL','',13,0,1),('HEAD_H2_TAG_PRODUCTS_ALL','',13,0,6),('HEAD_H2_TAG_PRODUCTS_ALL','',15,0,1),('HEAD_H2_TAG_PRODUCTS_ALL','',15,0,6),('HEAD_H2_TAG_PRODUCTS_ALL','',17,0,1),('HEAD_H2_TAG_PRODUCTS_ALL','',17,0,6),('HEAD_H3_TAG_PRODUCTS_ALL','',1,0,1),('HEAD_H3_TAG_PRODUCTS_ALL','',1,0,6),('HEAD_H3_TAG_PRODUCTS_ALL','',3,0,1),('HEAD_H3_TAG_PRODUCTS_ALL','',3,0,6),('HEAD_H3_TAG_PRODUCTS_ALL','',10,0,1),('HEAD_H3_TAG_PRODUCTS_ALL','',10,0,6),('HEAD_H3_TAG_PRODUCTS_ALL','',11,0,1),('HEAD_H3_TAG_PRODUCTS_ALL','',11,0,6),('HEAD_H3_TAG_PRODUCTS_ALL','',12,0,1),('HEAD_H3_TAG_PRODUCTS_ALL','',12,0,6),('HEAD_H3_TAG_PRODUCTS_ALL','',13,0,1),('HEAD_H3_TAG_PRODUCTS_ALL','',13,0,6),('HEAD_H3_TAG_PRODUCTS_ALL','',15,0,1),('HEAD_H3_TAG_PRODUCTS_ALL','',15,0,6),('HEAD_H3_TAG_PRODUCTS_ALL','',17,0,1),('HEAD_H3_TAG_PRODUCTS_ALL','',17,0,6),('HEAD_TITLE_TAG_FEATURED','Select product\'s range',1,0,1),('HEAD_TITLE_TAG_FEATURED','',1,0,6),('HEAD_TITLE_TAG_FEATURED','Selecteer het assortiment van het product',3,0,1),('HEAD_TITLE_TAG_FEATURED','',3,0,6),('HEAD_TITLE_TAG_FEATURED','Wählen Sie den Produktbereich aus',10,0,1),('HEAD_TITLE_TAG_FEATURED','',10,0,6),('HEAD_TITLE_TAG_FEATURED','Sélectionnez la gamme de produits',11,0,1),('HEAD_TITLE_TAG_FEATURED','',11,0,6),('HEAD_TITLE_TAG_FEATURED','Velg produktets utvalg',12,0,1),('HEAD_TITLE_TAG_FEATURED','',12,0,6),('HEAD_TITLE_TAG_FEATURED','Seleziona la gamma del prodotto',13,0,1),('HEAD_TITLE_TAG_FEATURED','',13,0,6),('HEAD_TITLE_TAG_FEATURED','Виберіть діапазон продукту',15,0,1),('HEAD_TITLE_TAG_FEATURED','',15,0,6),('HEAD_TITLE_TAG_FEATURED','Выберите диапазон продукта',17,0,1),('HEAD_TITLE_TAG_FEATURED','',17,0,6),('HEAD_DESC_TAG_FEATURED','We have powerful feature - selected best products for your clients - ecommerce site: osCommerce by Holbi',1,0,1),('HEAD_DESC_TAG_FEATURED','',1,0,6),('HEAD_DESC_TAG_FEATURED','We hebben krachtige functies - geselecteerde beste producten voor uw klanten - ecommerce-site: TrueLoaded door Holbi',3,0,1),('HEAD_DESC_TAG_FEATURED','',3,0,6),('HEAD_DESC_TAG_FEATURED','Wir haben eine leistungsstarke Funktion - ausgewählte beste Produkte für Ihre Kunden - E-Commerce-Website: TrueLoaded von Holbi',10,0,1),('HEAD_DESC_TAG_FEATURED','',10,0,6),('HEAD_DESC_TAG_FEATURED','Nous avons une fonctionnalité puissante - meilleurs produits sélectionnés pour vos clients - site de commerce électronique: TrueLoaded par Holbi',11,0,1),('HEAD_DESC_TAG_FEATURED','',11,0,6),('HEAD_DESC_TAG_FEATURED','Vi har en kraftig funksjon - utvalgte beste produkter for kundene dine - e-handelsside: TrueLoaded av Holbi',12,0,1),('HEAD_DESC_TAG_FEATURED','',12,0,6),('HEAD_DESC_TAG_FEATURED','Abbiamo una potente funzionalità: i migliori prodotti selezionati per i tuoi clienti: sito di e-commerce: TrueLoaded by Holbi',13,0,1),('HEAD_DESC_TAG_FEATURED','',13,0,6),('HEAD_DESC_TAG_FEATURED','У нас є просунуті функції - вибрані кращі продукти для ваших клієнтів - сайт електронної комерції: TrueLoaded by Holbi',15,0,1),('HEAD_DESC_TAG_FEATURED','',15,0,6),('HEAD_DESC_TAG_FEATURED','У нас есть продвинутые функции - выбранные лучшие продукты для ваших клиентов - сайт электронной коммерции: TrueLoaded by Holbi',17,0,1),('HEAD_DESC_TAG_FEATURED','',17,0,6),('HEAD_H1_TAG_FEATURED','selected best products module',1,0,1),('HEAD_H1_TAG_FEATURED','',1,0,6),('HEAD_H1_TAG_FEATURED','geselecteerde module met de beste producten',3,0,1),('HEAD_H1_TAG_FEATURED','',3,0,6),('HEAD_H1_TAG_FEATURED','ausgewähltes bestes Produktmodul',10,0,1),('HEAD_H1_TAG_FEATURED','',10,0,6),('HEAD_H1_TAG_FEATURED','sélection des meilleurs produits',11,0,1),('HEAD_H1_TAG_FEATURED','',11,0,6),('HEAD_H1_TAG_FEATURED','valgt beste produktmodul',12,0,1),('HEAD_H1_TAG_FEATURED','',12,0,6),('HEAD_H1_TAG_FEATURED','selezionato il miglior prodotto modulo',13,0,1),('HEAD_H1_TAG_FEATURED','',13,0,6),('HEAD_H1_TAG_FEATURED','модуль для вибору кращих продуктів',15,0,1),('HEAD_H1_TAG_FEATURED','',15,0,6),('HEAD_H1_TAG_FEATURED','модуль для выбора лучших продуктов',17,0,1),('HEAD_H1_TAG_FEATURED','',17,0,6),('HEAD_H2_TAG_FEATURED','',1,0,1),('HEAD_H2_TAG_FEATURED','',1,0,6),('HEAD_H2_TAG_FEATURED','',3,0,1),('HEAD_H2_TAG_FEATURED','',3,0,6),('HEAD_H2_TAG_FEATURED','',10,0,1),('HEAD_H2_TAG_FEATURED','',10,0,6),('HEAD_H2_TAG_FEATURED','',11,0,1),('HEAD_H2_TAG_FEATURED','',11,0,6),('HEAD_H2_TAG_FEATURED','',12,0,1),('HEAD_H2_TAG_FEATURED','',12,0,6),('HEAD_H2_TAG_FEATURED','',13,0,1),('HEAD_H2_TAG_FEATURED','',13,0,6),('HEAD_H2_TAG_FEATURED','',15,0,1),('HEAD_H2_TAG_FEATURED','',15,0,6),('HEAD_H2_TAG_FEATURED','',17,0,1),('HEAD_H3_TAG_FEATURED','',1,0,1),('HEAD_H3_TAG_FEATURED','',1,0,6),('HEAD_H3_TAG_FEATURED','',3,0,1),('HEAD_H3_TAG_FEATURED','',3,0,6),('HEAD_H3_TAG_FEATURED','',10,0,1),('HEAD_H3_TAG_FEATURED','',10,0,6),('HEAD_H3_TAG_FEATURED','',11,0,1),('HEAD_H3_TAG_FEATURED','',11,0,6),('HEAD_H3_TAG_FEATURED','',12,0,1),('HEAD_H3_TAG_FEATURED','',12,0,6),('HEAD_H3_TAG_FEATURED','',13,0,1),('HEAD_H3_TAG_FEATURED','',13,0,6),('HEAD_H3_TAG_FEATURED','',15,0,1),('HEAD_H3_TAG_FEATURED','',15,0,6),('HEAD_H3_TAG_FEATURED','',17,0,1),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Functionaliteit van productreviews',3,0,1),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Produkte prüfen Funktionalität',10,0,1),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Produits critiques fonctionnalité',11,0,1),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Produktomtaler funksjonalitet',12,0,1),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Funzionalità di recensioni di prodotti',13,0,1),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Функціональність огляду продуктів',15,0,1),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Функциональность обзора продуктов',17,0,1),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',1,0,1),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',3,0,1),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',10,0,1),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',11,0,1),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',12,0,1),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',13,0,1),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',15,0,1),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',17,0,1),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',1,0,1),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',3,0,1),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',10,0,1),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',11,0,1),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',12,0,1),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',13,0,1),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',15,0,1),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',17,0,1),('HEAD_TITLE_TAG_CONTACT_US','Contact us about ecommerce site creating',1,0,1),('HEAD_TITLE_TAG_CONTACT_US','Neem contact met ons op over het maken van e-commercesites',3,0,1),('HEAD_TITLE_TAG_CONTACT_US','Kontaktieren Sie uns für die Erstellung von E-Commerce-Websites',10,0,1),('HEAD_TITLE_TAG_CONTACT_US','',11,0,1),('HEAD_TITLE_TAG_CONTACT_US','',12,0,1),('HEAD_TITLE_TAG_CONTACT_US','',13,0,1),('HEAD_TITLE_TAG_CONTACT_US','',15,0,1),('HEAD_TITLE_TAG_CONTACT_US','',17,0,1),('HEAD_DESC_TAG_CONTACT_US','If you have any questions - contact us. Ecommerce Platform: osCommerce by Holbi',1,0,1),('HEAD_DESC_TAG_CONTACT_US','Als u vragen heeft, neem dan contact met ons op. E-commerceplatform: TrueLoaded door Holbi',3,0,1),('HEAD_DESC_TAG_CONTACT_US','Wenn Sie Fragen haben - kontaktieren Sie uns. E-Commerce-Plattform: TrueLoaded von Holbi',10,0,1),('HEAD_DESC_TAG_CONTACT_US','',11,0,1),('HEAD_DESC_TAG_CONTACT_US','',12,0,1),('HEAD_DESC_TAG_CONTACT_US','',13,0,1),('HEAD_DESC_TAG_CONTACT_US','',15,0,1),('HEAD_DESC_TAG_CONTACT_US','',17,0,1),('HEAD_H1_TAG_CONTACT_US','HOLBI GROUP LTD',1,0,1),('HEAD_H1_TAG_CONTACT_US','Holbi Europe NL',3,0,1),('HEAD_H1_TAG_CONTACT_US','HOLBI GROUP LTD DE',10,0,1),('HEAD_H1_TAG_CONTACT_US','',11,0,1),('HEAD_H1_TAG_CONTACT_US','',12,0,1),('HEAD_H1_TAG_CONTACT_US','',13,0,1),('HEAD_H1_TAG_CONTACT_US','',15,0,1),('HEAD_H1_TAG_CONTACT_US','',17,0,1),('HEAD_H2_TAG_CONTACT_US','Any questions? contact us\nosCommerce by Holbi',1,0,1),('HEAD_H2_TAG_CONTACT_US','Nog vragen? Neem contact met ons op\nTrueLoaded door Holbi',3,0,1),('HEAD_H2_TAG_CONTACT_US','Irgendwelche Fragen? kontaktiere uns\nTrueLoaded door Holbi',10,0,1),('HEAD_H2_TAG_CONTACT_US','',11,0,1),('HEAD_H2_TAG_CONTACT_US','',12,0,1),('HEAD_H2_TAG_CONTACT_US','',13,0,1),('HEAD_H2_TAG_CONTACT_US','',15,0,1),('HEAD_H2_TAG_CONTACT_US','',17,0,1),('HEAD_H3_TAG_CONTACT_US','Paradise Farm, High street\nOpening hours\nMo - Fr (9:00-18:00)\nKempsford\nUnited Kingdom\nGL7 4EU',1,0,1),('HEAD_H3_TAG_CONTACT_US','GL7 4EU\nUnited Kingdom\nKempsford\nMo - Fr (9:00-18:00)\nOpening hours\nParadise Farm, High street',3,0,1),('HEAD_H3_TAG_CONTACT_US','GL7 4EU\nParadise Farm, High street\nOpening hours\nMo - Fr (9:00-18:00)\nKempsford\nUnited Kingdom',10,0,1),('HEAD_H3_TAG_CONTACT_US','',11,0,1),('HEAD_H3_TAG_CONTACT_US','',12,0,1),('HEAD_H3_TAG_CONTACT_US','',13,0,1),('HEAD_H3_TAG_CONTACT_US','',15,0,1),('HEAD_H3_TAG_CONTACT_US','',17,0,1),('HEAD_TITLE_TAG_GIFT_CARD','Buy gift card',1,0,1),('HEAD_TITLE_TAG_GIFT_CARD','Cadeaubon kopen',3,0,1),('HEAD_TITLE_TAG_GIFT_CARD','Geschenkkarte kaufen',10,0,1),('HEAD_TITLE_TAG_GIFT_CARD','',11,0,1),('HEAD_TITLE_TAG_GIFT_CARD','',12,0,1),('HEAD_TITLE_TAG_GIFT_CARD','',13,0,1),('HEAD_TITLE_TAG_GIFT_CARD','',15,0,1),('HEAD_TITLE_TAG_GIFT_CARD','',17,0,1),('HEAD_DESC_TAG_GIFT_CARD','Sell gift card to your clients with ecommerce site: osCommerce by Holbi',1,0,1),('HEAD_DESC_TAG_GIFT_CARD','Verkoop een cadeaubon aan uw klanten met een ecommerce-site: TrueLoaded door Holbi',3,0,1),('HEAD_DESC_TAG_GIFT_CARD','Verkaufen Sie eine Geschenkkarte an Ihre Kunden mit der E-Commerce-Seite: TrueLoaded by Holbi',10,0,1),('HEAD_DESC_TAG_GIFT_CARD','',11,0,1),('HEAD_DESC_TAG_GIFT_CARD','',12,0,1),('HEAD_DESC_TAG_GIFT_CARD','',13,0,1),('HEAD_DESC_TAG_GIFT_CARD','',15,0,1),('HEAD_DESC_TAG_GIFT_CARD','',17,0,1),('HEAD_H1_TAG_GIFT_CARD','gift card functionality',1,0,1),('HEAD_H1_TAG_GIFT_CARD','geschenkkaartfunctionaliteit',3,0,1),('HEAD_H1_TAG_GIFT_CARD','Geschenkkartenfunktionalität',10,0,1),('HEAD_H1_TAG_GIFT_CARD','',11,0,1),('HEAD_H1_TAG_GIFT_CARD','',12,0,1),('HEAD_H1_TAG_GIFT_CARD','',13,0,1),('HEAD_H1_TAG_GIFT_CARD','',15,0,1),('HEAD_H1_TAG_GIFT_CARD','',17,0,1),('HEAD_H2_TAG_GIFT_CARD','',1,0,1),('HEAD_H2_TAG_GIFT_CARD','',3,0,1),('HEAD_H2_TAG_GIFT_CARD','',10,0,1),('HEAD_H2_TAG_GIFT_CARD','',11,0,1),('HEAD_H2_TAG_GIFT_CARD','',12,0,1),('HEAD_H2_TAG_GIFT_CARD','',13,0,1),('HEAD_H2_TAG_GIFT_CARD','',15,0,1),('HEAD_H2_TAG_GIFT_CARD','',17,0,1),('HEAD_H3_TAG_GIFT_CARD','',1,0,1),('HEAD_H3_TAG_GIFT_CARD','',3,0,1),('HEAD_H3_TAG_GIFT_CARD','',10,0,1),('HEAD_H3_TAG_GIFT_CARD','',11,0,1),('HEAD_H3_TAG_GIFT_CARD','',12,0,1),('HEAD_H3_TAG_GIFT_CARD','',13,0,1),('HEAD_H3_TAG_GIFT_CARD','',15,0,1),('HEAD_H3_TAG_GIFT_CARD','',17,0,1),('HEAD_TITLE_TAG_WEDDING_REGISTRY','Wedding registry',1,0,1),('HEAD_TITLE_TAG_WEDDING_REGISTRY','Trouwregister',3,0,1),('HEAD_TITLE_TAG_WEDDING_REGISTRY','Hochzeitsliste',10,0,1),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',11,0,1),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',12,0,1),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',13,0,1),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',15,0,1),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',17,0,1),('HEAD_DESC_TAG_WEDDING_REGISTRY','Set up wedding registry module for your clients with Ecommerce platform : osCommerce by Holbi',1,0,1),('HEAD_DESC_TAG_WEDDING_REGISTRY','Bruiloftregistratiemodule instellen voor uw klanten met e-commerceplatform: TrueLoaded door Holbi',3,0,1),('HEAD_DESC_TAG_WEDDING_REGISTRY','Richten Sie für Ihre Kunden ein Hochzeitsregistrierungsmodul mit der Ecommerce-Plattform ein: TrueLoaded by Holbi',10,0,1),('HEAD_DESC_TAG_WEDDING_REGISTRY','',11,0,1),('HEAD_DESC_TAG_WEDDING_REGISTRY','',12,0,1),('HEAD_DESC_TAG_WEDDING_REGISTRY','',13,0,1),('HEAD_DESC_TAG_WEDDING_REGISTRY','',15,0,1),('HEAD_DESC_TAG_WEDDING_REGISTRY','',17,0,1),('HEAD_H1_TAG_WEDDING_REGISTRY','Wedding registry module',1,0,1),('HEAD_H1_TAG_WEDDING_REGISTRY','Huwelijksregistratiemodule',3,0,1),('HEAD_H1_TAG_WEDDING_REGISTRY','Hochzeitsregistrierungsmodul',10,0,1),('HEAD_H1_TAG_WEDDING_REGISTRY','',11,0,1),('HEAD_H1_TAG_WEDDING_REGISTRY','',12,0,1),('HEAD_H1_TAG_WEDDING_REGISTRY','',13,0,1),('HEAD_H1_TAG_WEDDING_REGISTRY','',15,0,1),('HEAD_H1_TAG_WEDDING_REGISTRY','',17,0,1),('HEAD_H2_TAG_WEDDING_REGISTRY','',1,0,1),('HEAD_H2_TAG_WEDDING_REGISTRY','',3,0,1),('HEAD_H2_TAG_WEDDING_REGISTRY','',10,0,1),('HEAD_H2_TAG_WEDDING_REGISTRY','',11,0,1),('HEAD_H2_TAG_WEDDING_REGISTRY','',12,0,1),('HEAD_H2_TAG_WEDDING_REGISTRY','',13,0,1),('HEAD_H2_TAG_WEDDING_REGISTRY','',15,0,1),('HEAD_H2_TAG_WEDDING_REGISTRY','',17,0,1),('HEAD_H3_TAG_WEDDING_REGISTRY','',1,0,1),('HEAD_H3_TAG_WEDDING_REGISTRY','',3,0,1),('HEAD_H3_TAG_WEDDING_REGISTRY','',10,0,1),('HEAD_H3_TAG_WEDDING_REGISTRY','',11,0,1),('HEAD_H3_TAG_WEDDING_REGISTRY','',12,0,1),('HEAD_H3_TAG_WEDDING_REGISTRY','',13,0,1),('HEAD_H3_TAG_WEDDING_REGISTRY','',15,0,1),('HEAD_H3_TAG_WEDDING_REGISTRY','',17,0,1),('HEAD_TITLE_TAG_CATEGORY','Ecommerce website osCommerce - ##CATEGORY_NAME##',1,0,1),('HEAD_TITLE_TAG_CATEGORY','E-commerce oplossing TrueLoaded - ##CATEGORY_NAME##',3,0,1),('HEAD_TITLE_TAG_CATEGORY','E-Commerce-Lösung TrueLoaded - ##CATEGORY_NAME##',10,0,1),('HEAD_TITLE_TAG_CATEGORY','',11,0,1),('HEAD_TITLE_TAG_CATEGORY','',12,0,1),('HEAD_TITLE_TAG_CATEGORY','',13,0,1),('HEAD_TITLE_TAG_CATEGORY','',15,0,1),('HEAD_TITLE_TAG_CATEGORY','',17,0,1),('HEAD_DESC_TAG_CATEGORY','Use powerfull catalog system with ecommerce platform : osCommerce by Holbi. This is ##CATEGORY_NAME##.',1,0,1),('HEAD_DESC_TAG_CATEGORY','Gebruik krachtig catalogussysteem met e-commerceplatform: TrueLoaded door Holbi. Dit is ##CATEGORY_NAME##.',3,0,1),('HEAD_DESC_TAG_CATEGORY','Verwenden Sie ein leistungsfähiges Katalogsystem mit E-Commerce-Plattform: TrueLoaded von Holbi. Das ist ##CATEGORY_NAME##.',10,0,1),('HEAD_DESC_TAG_CATEGORY','',11,0,1),('HEAD_DESC_TAG_CATEGORY','',12,0,1),('HEAD_DESC_TAG_CATEGORY','',13,0,1),('HEAD_DESC_TAG_CATEGORY','',15,0,1),('HEAD_DESC_TAG_CATEGORY','',17,0,1),('HEAD_H1_TAG_CATEGORY','',1,0,1),('HEAD_H1_TAG_CATEGORY','',3,0,1),('HEAD_H1_TAG_CATEGORY','',10,0,1),('HEAD_H1_TAG_CATEGORY','',11,0,1),('HEAD_H1_TAG_CATEGORY','',12,0,1),('HEAD_H1_TAG_CATEGORY','',13,0,1),('HEAD_H1_TAG_CATEGORY','',15,0,1),('HEAD_H1_TAG_CATEGORY','',17,0,1),('HEAD_H2_TAG_CATEGORY','',1,0,1),('HEAD_H2_TAG_CATEGORY','',3,0,1),('HEAD_H2_TAG_CATEGORY','',10,0,1),('HEAD_H2_TAG_CATEGORY','',11,0,1),('HEAD_H2_TAG_CATEGORY','',12,0,1),('HEAD_H2_TAG_CATEGORY','',13,0,1),('HEAD_H2_TAG_CATEGORY','',15,0,1),('HEAD_H2_TAG_CATEGORY','',17,0,1),('HEAD_H3_TAG_CATEGORY','',1,0,1),('HEAD_H3_TAG_CATEGORY','',3,0,1),('HEAD_H3_TAG_CATEGORY','',10,0,1),('HEAD_H3_TAG_CATEGORY','',11,0,1),('HEAD_H3_TAG_CATEGORY','',12,0,1),('HEAD_H3_TAG_CATEGORY','',13,0,1),('HEAD_H3_TAG_CATEGORY','',15,0,1),('HEAD_H3_TAG_CATEGORY','',17,0,1),('HEAD_TITLE_TAG_BRAND','##BRAND_NAME## powered by osCommerce',1,0,1),('HEAD_TITLE_TAG_BRAND','##BRAND_NAME## mogelijk gemaakt door TrueLoaded',3,0,1),('HEAD_TITLE_TAG_BRAND','##BRAND_NAME## unterstützt von TrueLoaded',10,0,1),('HEAD_TITLE_TAG_BRAND','',11,0,1),('HEAD_TITLE_TAG_BRAND','',12,0,1),('HEAD_TITLE_TAG_BRAND','',13,0,1),('HEAD_TITLE_TAG_BRAND','',15,0,1),('HEAD_TITLE_TAG_BRAND','',17,0,1),('HEAD_DESC_TAG_BRAND','Sell your your brands like: ##BRAND_NAME## to your clients using ecommerce site: osCommerce by Holbi',1,0,1),('HEAD_DESC_TAG_BRAND','Verkoop je eigen merken zoals: ##BRAND_NAME## aan je klanten via de e-commercesite: TrueLoaded by Holbi',3,0,1),('HEAD_DESC_TAG_BRAND','Verkaufen Sie Ihre Marken wie: ##BRAND_NAME## an Ihre Kunden über die E-Commerce-Seite: TrueLoaded by Holbi',10,0,1),('HEAD_DESC_TAG_BRAND','',11,0,1),('HEAD_DESC_TAG_BRAND','',12,0,1),('HEAD_DESC_TAG_BRAND','',13,0,1),('HEAD_DESC_TAG_BRAND','',15,0,1),('HEAD_DESC_TAG_BRAND','',17,0,1),('HEAD_H1_TAG_BRAND','',1,0,1),('HEAD_H1_TAG_BRAND','',3,0,1),('HEAD_H1_TAG_BRAND','',10,0,1),('HEAD_H1_TAG_BRAND','',11,0,1),('HEAD_H1_TAG_BRAND','',12,0,1),('HEAD_H1_TAG_BRAND','',13,0,1),('HEAD_H1_TAG_BRAND','',15,0,1),('HEAD_H1_TAG_BRAND','',17,0,1),('HEAD_H2_TAG_BRAND','',1,0,1),('HEAD_H2_TAG_BRAND','',3,0,1),('HEAD_H2_TAG_BRAND','',10,0,1),('HEAD_H2_TAG_BRAND','',11,0,1),('HEAD_H2_TAG_BRAND','',12,0,1),('HEAD_H2_TAG_BRAND','',13,0,1),('HEAD_H2_TAG_BRAND','',15,0,1),('HEAD_H2_TAG_BRAND','',17,0,1),('HEAD_H3_TAG_BRAND','',1,0,1),('HEAD_H3_TAG_BRAND','',3,0,1),('HEAD_H3_TAG_BRAND','',10,0,1),('HEAD_H3_TAG_BRAND','',11,0,1),('HEAD_H3_TAG_BRAND','',12,0,1),('HEAD_H3_TAG_BRAND','',13,0,1),('HEAD_H3_TAG_BRAND','',15,0,1),('HEAD_H3_TAG_BRAND','',17,0,1),('HEAD_TITLE_TAG_DEFAULT','Platforma e-commerce - TrueLoaded firmy Holbi Group',26,0,1),('HEAD_DESC_TAG_DEFAULT','Platforma TrueLoaded Ecommerce od Holbi Group. Rozwiązanie koszyka e-commerce. Witryna e-commerce. TrueLoaded przez Holbi',26,0,1),('HEAD_H1_TAG_DEFAULT','Platforma e-commerce TrueLoaded firmy Holbi Group',26,0,1),('HEAD_H2_TAG_DEFAULT','',26,0,1),('HEAD_H3_TAG_DEFAULT','',26,0,1),('HEAD_TITLE_TAG_PRODUCTS_ALL','Lista wszystkich produktów na stronie',26,0,1),('HEAD_DESC_TAG_PRODUCTS_ALL','Lista wszystkich produktów z filtrami dostępna tutaj. Obsługiwane przez platformę e-commerce: TrueLoaded by Holbi',26,0,1),('HEAD_H1_TAG_PRODUCTS_ALL','Pełny asortyment produktów z modułem filtrów',26,0,1),('HEAD_H2_TAG_PRODUCTS_ALL','',26,0,1),('HEAD_H3_TAG_PRODUCTS_ALL','',26,0,1),('HEAD_TITLE_TAG_WHATS_NEW','Lista najnowszych produktów',26,0,1),('HEAD_DESC_TAG_WHATS_NEW','Możesz znaleźć najnowszy produkt tutaj ze stroną e-commerce: TrueLoaded by Holbi',26,0,1),('HEAD_H1_TAG_WHATS_NEW','najnowsze funkcje produktów',26,0,1),('HEAD_H2_TAG_WHATS_NEW','',26,0,1),('HEAD_H3_TAG_WHATS_NEW','',26,0,1),('HEAD_TITLE_TAG_SPECIALS','Lista ofert specjalnych - sprzedaż - produkty',26,0,1),('HEAD_DESC_TAG_SPECIALS','Twoi klienci zobaczą całą sprzedaż Twojej witryny internetowej opartą na witrynie e-commerce: TrueLoaded firmy Holbi',26,0,1),('HEAD_H1_TAG_SPECIALS','Funkcja sprzedaży',26,0,1),('HEAD_H2_TAG_SPECIALS','',26,0,1),('HEAD_H3_TAG_SPECIALS','',26,0,1),('HEAD_TITLE_TAG_FEATURED','Wybierz zakres produktu',26,0,1),('HEAD_DESC_TAG_FEATURED','Mamy potężną funkcję - wybrane najlepsze produkty dla Twoich klientów - witrynę e-commerce: TrueLoaded firmy Holbi',26,0,1),('HEAD_H1_TAG_FEATURED','wybrany moduł najlepszych produktów',26,0,1),('HEAD_H2_TAG_FEATURED','',26,0,1),('HEAD_H3_TAG_FEATURED','',26,0,1),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Przeczytaj, co mówią inni',26,0,1),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Recenzje produktów: Przeczytaj, co inni mówią o platformie e-commerce: TrueLoaded by Holbi',26,0,1),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Funkcjonalność recenzji produktów',26,0,1),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',26,0,1),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',26,0,1),('HEAD_TITLE_TAG_CONTACT_US','',26,0,1),('HEAD_DESC_TAG_CONTACT_US','',26,0,1),('HEAD_H1_TAG_CONTACT_US','',26,0,1),('HEAD_H2_TAG_CONTACT_US','',26,0,1),('HEAD_H3_TAG_CONTACT_US','',26,0,1),('HEAD_TITLE_TAG_GIFT_CARD','',26,0,1),('HEAD_DESC_TAG_GIFT_CARD','',26,0,1),('HEAD_H1_TAG_GIFT_CARD','',26,0,1),('HEAD_H2_TAG_GIFT_CARD','',26,0,1),('HEAD_H3_TAG_GIFT_CARD','',26,0,1),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',26,0,1),('HEAD_DESC_TAG_WEDDING_REGISTRY','',26,0,1),('HEAD_H1_TAG_WEDDING_REGISTRY','',26,0,1),('HEAD_H2_TAG_WEDDING_REGISTRY','',26,0,1),('HEAD_H3_TAG_WEDDING_REGISTRY','',26,0,1),('HEAD_TITLE_TAG_PRODUCT_INFO','',26,0,1),('HEAD_DESC_TAG_PRODUCT_INFO','',26,0,1),('HEAD_H1_TAG_PRODUCT_INFO','',26,0,1),('HEAD_H2_TAG_PRODUCT_INFO','',26,0,1),('HEAD_H3_TAG_PRODUCT_INFO','',26,0,1),('HEAD_TITLE_TAG_CATEGORY','',26,0,1),('HEAD_DESC_TAG_CATEGORY','',26,0,1),('HEAD_H1_TAG_CATEGORY','',26,0,1),('HEAD_H2_TAG_CATEGORY','',26,0,1),('HEAD_H3_TAG_CATEGORY','',26,0,1),('HEAD_TITLE_TAG_BRAND','',26,0,1),('HEAD_DESC_TAG_BRAND','',26,0,1),('HEAD_H1_TAG_BRAND','',26,0,1),('HEAD_H2_TAG_BRAND','',26,0,1),('HEAD_H3_TAG_BRAND','',26,0,1),('HEAD_TITLE_TAG_FREE_SAMPLES','Listing of free samples on the site',1,0,1),('HEAD_TITLE_TAG_FREE_SAMPLES','Lijst van gratis monsters op de site',3,0,1),('HEAD_TITLE_TAG_FREE_SAMPLES','Auflistung von kostenlosen Proben auf der Website',10,0,1),('HEAD_TITLE_TAG_FREE_SAMPLES','',11,0,1),('HEAD_TITLE_TAG_FREE_SAMPLES','',12,0,1),('HEAD_TITLE_TAG_FREE_SAMPLES','',13,0,1),('HEAD_TITLE_TAG_FREE_SAMPLES','',15,0,1),('HEAD_TITLE_TAG_FREE_SAMPLES','',17,0,1),('HEAD_TITLE_TAG_FREE_SAMPLES','',26,0,1),('HEAD_DESC_TAG_FREE_SAMPLES','Listing of all your free samples with filters availble here. Powered by ecommerce platform: osCommerce by Holbi',1,0,1),('HEAD_DESC_TAG_FREE_SAMPLES','Lijst van al uw gratis monsters met filters hier beschikbaar. Mogelijk gemaakt door e-commerce platform: True Loaded by Holbi',3,0,1),('HEAD_DESC_TAG_FREE_SAMPLES','Auflistung aller kostenlosen Beispiele mit Filtern hier verfügbar. Powered by E-Commerce-Plattform: True Loaded von Holbi',10,0,1),('HEAD_DESC_TAG_FREE_SAMPLES','',11,0,1),('HEAD_DESC_TAG_FREE_SAMPLES','',12,0,1),('HEAD_DESC_TAG_FREE_SAMPLES','',13,0,1),('HEAD_DESC_TAG_FREE_SAMPLES','',15,0,1),('HEAD_DESC_TAG_FREE_SAMPLES','',17,0,1),('HEAD_DESC_TAG_FREE_SAMPLES','',26,0,1),('HEAD_H1_TAG_FREE_SAMPLES','Full samples range with filters module',1,0,1),('HEAD_H1_TAG_FREE_SAMPLES','Volledig monstersbereik met filtermodule',3,0,1),('HEAD_H1_TAG_FREE_SAMPLES','Voller Probenbereich mit Filtermodul',10,0,1),('HEAD_H1_TAG_FREE_SAMPLES','',11,0,1),('HEAD_H1_TAG_FREE_SAMPLES','',12,0,1),('HEAD_H1_TAG_FREE_SAMPLES','',13,0,1),('HEAD_H1_TAG_FREE_SAMPLES','',15,0,1),('HEAD_H1_TAG_FREE_SAMPLES','',17,0,1),('HEAD_H1_TAG_FREE_SAMPLES','',26,0,1),('HEAD_H2_TAG_FREE_SAMPLES','',1,0,1),('HEAD_H2_TAG_FREE_SAMPLES','',3,0,1),('HEAD_H2_TAG_FREE_SAMPLES','',10,0,1),('HEAD_H2_TAG_FREE_SAMPLES','',11,0,1),('HEAD_H2_TAG_FREE_SAMPLES','',12,0,1),('HEAD_H2_TAG_FREE_SAMPLES','',13,0,1),('HEAD_H2_TAG_FREE_SAMPLES','',15,0,1),('HEAD_H2_TAG_FREE_SAMPLES','',17,0,1),('HEAD_H2_TAG_FREE_SAMPLES','',26,0,1),('HEAD_H3_TAG_FREE_SAMPLES','',1,0,1),('HEAD_H3_TAG_FREE_SAMPLES','',3,0,1),('HEAD_H3_TAG_FREE_SAMPLES','',10,0,1),('HEAD_H3_TAG_FREE_SAMPLES','',11,0,1),('HEAD_H3_TAG_FREE_SAMPLES','',12,0,1),('HEAD_H3_TAG_FREE_SAMPLES','',13,0,1),('HEAD_H3_TAG_FREE_SAMPLES','',15,0,1),('HEAD_H3_TAG_FREE_SAMPLES','',17,0,1),('HEAD_H3_TAG_FREE_SAMPLES','',26,0,1),('HEAD_TITLE_TAG_ALL','',26,0,1),('HEAD_DESC_TAG_ALL','',26,0,1),('HEAD_H1_TAG_ALL','',26,0,1),('HEAD_H2_TAG_ALL','',26,0,1),('HEAD_H3_TAG_ALL','',26,0,1),('DEFAULT_BREADCRUMB_CATALOG_INDEX','',1,0,1),('IMAGE_ALT_TAG_MASK_CATEGORY','',1,0,1),('IMAGE_TITLE_TAG_MASK_CATEGORY','',1,0,1),('DEFAULT_BREADCRUMB_CATALOG_PRODUCT','',1,0,1),('IMAGE_ALT_TAG_MASK_PRODUCT_INFO','',1,0,1),('IMAGE_TITLE_TAG_MASK_PRODUCT_INFO','',1,0,1),('HEAD_TITLE_TAG_BLOG_INDEX','',1,0,1),('HEAD_DESC_TAG_BLOG_INDEX','',1,0,1),('HEAD_TITLE_TAG_BLOG_POST','',1,0,1),('HEAD_DESC_TAG_BLOG_POST','',1,0,1),('HEAD_H1_TAG_BLOG_POST','',1,0,1),('HEAD_H2_TAG_BLOG_POST','',1,0,1),('HEAD_H3_TAG_BLOG_POST','',1,0,1),('HEAD_TITLE_TAG_BLOG_TAG','',1,0,1),('HEAD_DESC_TAG_BLOG_TAG','',1,0,1),('HEAD_H1_TAG_BLOG_TAG','',1,0,1),('HEAD_H2_TAG_BLOG_TAG','',1,0,1),('HEAD_H3_TAG_BLOG_TAG','',1,0,1),('HEAD_TITLE_TAG_BLOG_CATEGORY','',1,0,1),('HEAD_DESC_TAG_BLOG_CATEGORY','',1,0,1),('HEAD_H1_TAG_BLOG_CATEGORY','',1,0,1),('HEAD_H2_TAG_BLOG_CATEGORY','',1,0,1),('HEAD_H3_TAG_BLOG_CATEGORY','',1,0,1),('HEAD_TITLE_TAG_ALL','',1,0,7),('HEAD_KEY_TAG_ALL','trueloaded, ecommerce, holbi,holbi group,graphic designer, online designer, self made design, templates',1,0,7),('HEAD_DESC_TAG_ALL','',1,0,7),('HEAD_TITLE_TAG_DEFAULT','Ecommerce platform - osCommerce by Holbi Group',1,0,7),('HEAD_KEY_TAG_DEFAULT','',1,0,7),('HEAD_DESC_TAG_DEFAULT','osCommerce Ecommerce platform from Holbi Group. eCommerce Shopping Cart solution. Ecommerce site. osCommerce by Holbi',1,0,7),('HEAD_TITLE_TAG_PRODUCT_INFO','Ecommerce platform - ##PRODUCT_NAME## - ##BRAND_NAME##',1,0,7),('HEAD_KEY_TAG_PRODUCT_INFO','',1,0,7),('HEAD_DESC_TAG_PRODUCT_INFO','Sell your products with ecommerce site: osCommerce by Holbi. This is ##PRODUCT_NAME## from ##CATEGORY_NAME## produced by ##BRAND_NAME##',1,0,7),('HEAD_TITLE_TAG_WHATS_NEW','Listing of laterst products',1,0,7),('HEAD_KEY_TAG_WHATS_NEW','',1,0,7),('HEAD_DESC_TAG_WHATS_NEW','You may find latest product here with ecommerce website: osCommerce by Holbi',1,0,7),('HEAD_TITLE_TAG_SPECIALS','Listing of specials - sales - products',1,0,7),('HEAD_KEY_TAG_SPECIALS','',1,0,7),('HEAD_DESC_TAG_SPECIALS','Your clients will see all sales on your web site powered by ecommerce site: osCommerce by Holbi',1,0,7),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Read what others are saying',1,0,7),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',1,0,7),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Products reviews: Read what others are saying about Ecommerce platform : osCommerce by Holbi',1,0,7),('HEAD_H1_TAG_ALL','',1,0,7),('HEAD_H1_TAG_DEFAULT','Ecommerce platform osCommerce by Holbi Group',1,0,7),('HEAD_H3_TAG_ALL','',1,0,7),('HEAD_H2_TAG_ALL','',1,0,7),('HEAD_H2_TAG_DEFAULT','',1,0,7),('HEAD_H3_TAG_DEFAULT','',1,0,7),('HEAD_H1_TAG_PRODUCT_INFO','',1,0,7),('HEAD_H2_TAG_PRODUCT_INFO','',1,0,7),('HEAD_H3_TAG_PRODUCT_INFO','',1,0,7),('HEAD_H1_TAG_WHATS_NEW','latest products feature',1,0,7),('HEAD_H2_TAG_WHATS_NEW','',1,0,7),('HEAD_H3_TAG_WHATS_NEW','',1,0,7),('HEAD_H1_TAG_SPECIALS','Sales feature',1,0,7),('HEAD_H2_TAG_SPECIALS','',1,0,7),('HEAD_H3_TAG_SPECIALS','',1,0,7),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Products reviews functionality',1,0,7),('HEAD_TITLE_TAG_PRODUCTS_ALL','Listing of all products on the site',1,0,7),('HEAD_DESC_TAG_PRODUCTS_ALL','Listing of all your product with filters availble here. Powered by ecommerce platform: osCommerce by Holbi',1,0,7),('HEAD_H1_TAG_PRODUCTS_ALL','Full product range with filters module',1,0,7),('HEAD_H2_TAG_PRODUCTS_ALL','',1,0,7),('HEAD_H3_TAG_PRODUCTS_ALL','',1,0,7),('HEAD_TITLE_TAG_FEATURED','Select product\'s range',1,0,7),('HEAD_DESC_TAG_FEATURED','We have powerful feature - selected best products for your clients - ecommerce site: osCommerce by Holbi',1,0,7),('HEAD_H1_TAG_FEATURED','selected best products module',1,0,7),('HEAD_H2_TAG_FEATURED','',1,0,7),('HEAD_H3_TAG_FEATURED','',1,0,7),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',1,0,7),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',1,0,7),('HEAD_TITLE_TAG_CONTACT_US','Contact us about ecommerce site creating',1,0,7),('HEAD_DESC_TAG_CONTACT_US','If you have any questions - contact us. Ecommerce Platform: osCommerce by Holbi',1,0,7),('HEAD_H1_TAG_CONTACT_US','HOLBI GROUP LTD',1,0,7),('HEAD_H2_TAG_CONTACT_US','Any questions? contact us\nosCommerce by Holbi',1,0,7),('HEAD_H3_TAG_CONTACT_US','Paradise Farm, High street\nOpening hours\nMo - Fr (9:00-18:00)\nKempsford\nUnited Kingdom\nGL7 4EU',1,0,7),('HEAD_TITLE_TAG_GIFT_CARD','Buy gift card',1,0,7),('HEAD_DESC_TAG_GIFT_CARD','Sell gift card to your clients with ecommerce site: osCommerce by Holbi',1,0,7),('HEAD_H1_TAG_GIFT_CARD','gift card functionality',1,0,7),('HEAD_H2_TAG_GIFT_CARD','',1,0,7),('HEAD_H3_TAG_GIFT_CARD','',1,0,7),('HEAD_TITLE_TAG_WEDDING_REGISTRY','Wedding registry',1,0,7),('HEAD_DESC_TAG_WEDDING_REGISTRY','Set up wedding registry module for your clients with Ecommerce platform : osCommerce by Holbi',1,0,7),('HEAD_H1_TAG_WEDDING_REGISTRY','Wedding registry module',1,0,7),('HEAD_H2_TAG_WEDDING_REGISTRY','',1,0,7),('HEAD_H3_TAG_WEDDING_REGISTRY','',1,0,7),('HEAD_TITLE_TAG_CATEGORY','Ecommerce website osCommerce - ##CATEGORY_NAME##',1,0,7),('HEAD_DESC_TAG_CATEGORY','Use powerfull catalog system with ecommerce platform : osCommerce by Holbi. This is ##CATEGORY_NAME##.',1,0,7),('HEAD_H1_TAG_CATEGORY','',1,0,7),('HEAD_H2_TAG_CATEGORY','',1,0,7),('HEAD_H3_TAG_CATEGORY','',1,0,7),('HEAD_TITLE_TAG_BRAND','##BRAND_NAME## powered by osCommerce',1,0,7),('HEAD_DESC_TAG_BRAND','Sell your your brands like: ##BRAND_NAME## to your clients using ecommerce site: osCommerce by Holbi',1,0,7),('HEAD_H1_TAG_BRAND','',1,0,7),('HEAD_H2_TAG_BRAND','',1,0,7),('HEAD_H3_TAG_BRAND','',1,0,7),('HEAD_TITLE_TAG_FREE_SAMPLES','Listing of free samples on the site',1,0,7),('HEAD_DESC_TAG_FREE_SAMPLES','Listing of all your free samples with filters availble here. Powered by ecommerce platform: osCommerce by Holbi',1,0,7),('HEAD_H1_TAG_FREE_SAMPLES','Full samples range with filters module',1,0,7),('HEAD_H2_TAG_FREE_SAMPLES','',1,0,7),('HEAD_H3_TAG_FREE_SAMPLES','',1,0,7),('DEFAULT_BREADCRUMB_CATALOG_INDEX','',1,0,7),('IMAGE_ALT_TAG_MASK_CATEGORY','',1,0,7),('IMAGE_TITLE_TAG_MASK_CATEGORY','',1,0,7),('DEFAULT_BREADCRUMB_CATALOG_PRODUCT','',1,0,7),('IMAGE_ALT_TAG_MASK_PRODUCT_INFO','',1,0,7),('IMAGE_TITLE_TAG_MASK_PRODUCT_INFO','',1,0,7),('HEAD_TITLE_TAG_BLOG_INDEX','',1,0,7),('HEAD_DESC_TAG_BLOG_INDEX','',1,0,7),('HEAD_TITLE_TAG_BLOG_POST','',1,0,7),('HEAD_DESC_TAG_BLOG_POST','',1,0,7),('HEAD_H1_TAG_BLOG_POST','',1,0,7),('HEAD_H2_TAG_BLOG_POST','',1,0,7),('HEAD_H3_TAG_BLOG_POST','',1,0,7),('HEAD_TITLE_TAG_BLOG_TAG','',1,0,7),('HEAD_DESC_TAG_BLOG_TAG','',1,0,7),('HEAD_H1_TAG_BLOG_TAG','',1,0,7),('HEAD_H2_TAG_BLOG_TAG','',1,0,7),('HEAD_H3_TAG_BLOG_TAG','',1,0,7),('HEAD_TITLE_TAG_BLOG_CATEGORY','',1,0,7),('HEAD_DESC_TAG_BLOG_CATEGORY','',1,0,7),('HEAD_H1_TAG_BLOG_CATEGORY','',1,0,7),('HEAD_H2_TAG_BLOG_CATEGORY','',1,0,7),('HEAD_H3_TAG_BLOG_CATEGORY','',1,0,7),('HEAD_TITLE_TAG_ALL','',2,0,7),('HEAD_KEY_TAG_ALL','',2,0,7),('HEAD_DESC_TAG_ALL','',2,0,7),('HEAD_TITLE_TAG_DEFAULT','',2,0,7),('HEAD_KEY_TAG_DEFAULT','',2,0,7),('HEAD_DESC_TAG_DEFAULT','',2,0,7),('HEAD_TITLE_TAG_PRODUCT_INFO','',2,0,7),('HEAD_KEY_TAG_PRODUCT_INFO','',2,0,7),('HEAD_DESC_TAG_PRODUCT_INFO','',2,0,7),('HEAD_TITLE_TAG_WHATS_NEW','',2,0,7),('HEAD_KEY_TAG_WHATS_NEW','',2,0,7),('HEAD_DESC_TAG_WHATS_NEW','',2,0,7),('HEAD_TITLE_TAG_SPECIALS','',2,0,7),('HEAD_KEY_TAG_SPECIALS','',2,0,7),('HEAD_DESC_TAG_SPECIALS','',2,0,7),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',2,0,7),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',2,0,7),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',2,0,7),('HEAD_TITLE_TAG_ALL','',3,0,7),('HEAD_KEY_TAG_ALL','',3,0,7),('HEAD_DESC_TAG_ALL','',3,0,7),('HEAD_TITLE_TAG_DEFAULT','E-commerceplatform - TrueLoaded door Holbi Group',3,0,7),('HEAD_KEY_TAG_DEFAULT','',3,0,7),('HEAD_DESC_TAG_DEFAULT','TrueLoaded E-commerceplatform van Holbi Group. eCommerce winkelwagen oplossing. E-commerce site. TrueLoaded door Holbi',3,0,7),('HEAD_TITLE_TAG_PRODUCT_INFO','E-commerce oplossing - ##PRODUCT_NAME## - ##BRAND_NAME##',3,0,7),('HEAD_KEY_TAG_PRODUCT_INFO','',3,0,7),('HEAD_DESC_TAG_PRODUCT_INFO','Verkoop uw producten met e-commerce site: TrueLoaded door Holbi. Dit is ##PRODUCT_NAME## from ##CATEGORY_NAME## geproduceerd door ##BRAND_NAME##',3,0,7),('HEAD_TITLE_TAG_WHATS_NEW','Lijst met de nieuwste producten',3,0,7),('HEAD_KEY_TAG_WHATS_NEW','',3,0,7),('HEAD_DESC_TAG_WHATS_NEW','U vindt het nieuwste product hier met e-commerce website: TrueLoaded door Holbi',3,0,7),('HEAD_TITLE_TAG_SPECIALS','Lijst met specials - verkoop - producten',3,0,7),('HEAD_KEY_TAG_SPECIALS','',3,0,7),('HEAD_DESC_TAG_SPECIALS','Uw klanten zien alle verkopen op uw website mogelijk gemaakt door e-commercesites: TrueLoaded door Holbi',3,0,7),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Lees wat anderen zeggen',3,0,7),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',3,0,7),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Productrecensies: Lees wat anderen over Ecommerce-platform zeggen: TrueLoaded door Holbi',3,0,7),('HEAD_H3_TAG_ALL','',3,0,7),('HEAD_H2_TAG_ALL','',3,0,7),('HEAD_H1_TAG_ALL','',3,0,7),('HEAD_H1_TAG_DEFAULT','E-commerceplatform TrueLoaded door Holbi Group',3,0,7),('HEAD_H2_TAG_DEFAULT','',3,0,7),('HEAD_H3_TAG_DEFAULT','',3,0,7),('HEAD_H1_TAG_PRODUCT_INFO','',3,0,7),('HEAD_H2_TAG_PRODUCT_INFO','',3,0,7),('HEAD_H3_TAG_PRODUCT_INFO','',3,0,7),('HEAD_H1_TAG_WHATS_NEW','nieuwste producten functie',3,0,7),('HEAD_H2_TAG_WHATS_NEW','',3,0,7),('HEAD_H3_TAG_WHATS_NEW','',3,0,7),('HEAD_H1_TAG_SPECIALS','Verkoop functie',3,0,7),('HEAD_H2_TAG_SPECIALS','',3,0,7),('HEAD_H3_TAG_SPECIALS','',3,0,7),('HEAD_TITLE_TAG_PRODUCTS_ALL','Lijst van alle producten op de site',3,0,7),('HEAD_DESC_TAG_PRODUCTS_ALL','Lijst van al uw producten met filters hier beschikbaar. Mogelijk gemaakt door e-commerce platform: TrueLoaded door Holbi',3,0,7),('HEAD_H1_TAG_PRODUCTS_ALL','Volledig assortiment met filtermodule',3,0,7),('HEAD_H2_TAG_PRODUCTS_ALL','',3,0,7),('HEAD_H3_TAG_PRODUCTS_ALL','',3,0,7),('HEAD_TITLE_TAG_FEATURED','Selecteer het assortiment van het product',3,0,7),('HEAD_DESC_TAG_FEATURED','We hebben krachtige functies - geselecteerde beste producten voor uw klanten - ecommerce-site: TrueLoaded door Holbi',3,0,7),('HEAD_H1_TAG_FEATURED','geselecteerde module met de beste producten',3,0,7),('HEAD_H2_TAG_FEATURED','',3,0,7),('HEAD_H3_TAG_FEATURED','',3,0,7),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Functionaliteit van productreviews',3,0,7),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',3,0,7),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',3,0,7),('HEAD_TITLE_TAG_CONTACT_US','Neem contact met ons op over het maken van e-commercesites',3,0,7),('HEAD_DESC_TAG_CONTACT_US','Als u vragen heeft, neem dan contact met ons op. E-commerceplatform: TrueLoaded door Holbi',3,0,7),('HEAD_H1_TAG_CONTACT_US','Holbi Europe NL',3,0,7),('HEAD_H2_TAG_CONTACT_US','Nog vragen? Neem contact met ons op\nTrueLoaded door Holbi',3,0,7),('HEAD_H3_TAG_CONTACT_US','GL7 4EU\nUnited Kingdom\nKempsford\nMo - Fr (9:00-18:00)\nOpening hours\nParadise Farm, High street',3,0,7),('HEAD_TITLE_TAG_GIFT_CARD','Cadeaubon kopen',3,0,7),('HEAD_DESC_TAG_GIFT_CARD','Verkoop een cadeaubon aan uw klanten met een ecommerce-site: TrueLoaded door Holbi',3,0,7),('HEAD_H1_TAG_GIFT_CARD','geschenkkaartfunctionaliteit',3,0,7),('HEAD_H2_TAG_GIFT_CARD','',3,0,7),('HEAD_H3_TAG_GIFT_CARD','',3,0,7),('HEAD_TITLE_TAG_WEDDING_REGISTRY','Trouwregister',3,0,7),('HEAD_DESC_TAG_WEDDING_REGISTRY','Bruiloftregistratiemodule instellen voor uw klanten met e-commerceplatform: TrueLoaded door Holbi',3,0,7),('HEAD_H1_TAG_WEDDING_REGISTRY','Huwelijksregistratiemodule',3,0,7),('HEAD_H2_TAG_WEDDING_REGISTRY','',3,0,7),('HEAD_H3_TAG_WEDDING_REGISTRY','',3,0,7),('HEAD_TITLE_TAG_CATEGORY','E-commerce oplossing TrueLoaded - ##CATEGORY_NAME##',3,0,7),('HEAD_DESC_TAG_CATEGORY','Gebruik krachtig catalogussysteem met e-commerceplatform: TrueLoaded door Holbi. Dit is ##CATEGORY_NAME##.',3,0,7),('HEAD_H1_TAG_CATEGORY','',3,0,7),('HEAD_H2_TAG_CATEGORY','',3,0,7),('HEAD_H3_TAG_CATEGORY','',3,0,7),('HEAD_TITLE_TAG_BRAND','##BRAND_NAME## mogelijk gemaakt door TrueLoaded',3,0,7),('HEAD_DESC_TAG_BRAND','Verkoop je eigen merken zoals: ##BRAND_NAME## aan je klanten via de e-commercesite: TrueLoaded by Holbi',3,0,7),('HEAD_H1_TAG_BRAND','',3,0,7),('HEAD_H2_TAG_BRAND','',3,0,7),('HEAD_H3_TAG_BRAND','',3,0,7),('HEAD_TITLE_TAG_FREE_SAMPLES','Lijst van gratis monsters op de site',3,0,7),('HEAD_DESC_TAG_FREE_SAMPLES','Lijst van al uw gratis monsters met filters hier beschikbaar. Mogelijk gemaakt door e-commerce platform: True Loaded by Holbi',3,0,7),('HEAD_H1_TAG_FREE_SAMPLES','Volledig monstersbereik met filtermodule',3,0,7),('HEAD_H2_TAG_FREE_SAMPLES','',3,0,7),('HEAD_H3_TAG_FREE_SAMPLES','',3,0,7),('HEAD_TITLE_TAG_ALL','',10,0,7),('HEAD_KEY_TAG_ALL','',10,0,7),('HEAD_DESC_TAG_ALL','',10,0,7),('HEAD_TITLE_TAG_DEFAULT','E-Commerce Plattform - TrueLoaded von Holbi Group',10,0,7),('HEAD_KEY_TAG_DEFAULT','',10,0,7),('HEAD_DESC_TAG_DEFAULT','TrueLoaded E-Commerce Plattform von Holbi Group. eCommerce Warenkorb Lösung. E-Commerce Website. TrueLoaded von Holbi',10,0,7),('HEAD_TITLE_TAG_PRODUCT_INFO','E-Commerce-Plattform - ##PRODUCT_NAME## - ##BRAND_NAME##',10,0,7),('HEAD_KEY_TAG_PRODUCT_INFO','',10,0,7),('HEAD_DESC_TAG_PRODUCT_INFO','Verkaufen Sie Ihre Produkte mit E-Commerce-Site: TrueLoaded von Holbi. Dies ist ##PRODUCT_NAME## von ##CATEGORY_NAME##, produziert von ##BRAND_NAME##',10,0,7),('HEAD_TITLE_TAG_WHATS_NEW','Auflistung der neuesten Produkte',10,0,7),('HEAD_KEY_TAG_WHATS_NEW','',10,0,7),('HEAD_DESC_TAG_WHATS_NEW','Sie können das neueste Produkt hier mit E-Commerce-Website finden: TrueLoaded von Holbi',10,0,7),('HEAD_TITLE_TAG_SPECIALS','Auflistung von Specials - Verkauf - Produkte',10,0,7),('HEAD_KEY_TAG_SPECIALS','',10,0,7),('HEAD_DESC_TAG_SPECIALS','Ihre Kunden werden alle Verkäufe auf Ihrer Website sehen, die auf der E-Commerce-Website basieren: TrueLoaded by Holbi',10,0,7),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Lesen Sie, was andere sagen',10,0,7),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',10,0,7),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Produktbewertungen: Lesen Sie, was andere über die Ecommerce-Plattform sagen: TrueLoaded by Holbi',10,0,7),('HEAD_H2_TAG_ALL','',10,0,7),('HEAD_H1_TAG_ALL','',10,0,7),('HEAD_H1_TAG_DEFAULT','E-Commerce Plattform TrueLoaded von Holbi Group',10,0,7),('HEAD_H3_TAG_ALL','',10,0,7),('HEAD_H2_TAG_DEFAULT','',10,0,7),('HEAD_H3_TAG_DEFAULT','',10,0,7),('HEAD_H1_TAG_PRODUCT_INFO','',10,0,7),('HEAD_H2_TAG_PRODUCT_INFO','',10,0,7),('HEAD_H3_TAG_PRODUCT_INFO','',10,0,7),('HEAD_H1_TAG_WHATS_NEW','neueste Produkteigenschaft',10,0,7),('HEAD_H2_TAG_WHATS_NEW','',10,0,7),('HEAD_H3_TAG_WHATS_NEW','',10,0,7),('HEAD_H1_TAG_SPECIALS','Verkaufsfunktion',10,0,7),('HEAD_H2_TAG_SPECIALS','',10,0,7),('HEAD_H3_TAG_SPECIALS','',10,0,7),('HEAD_TITLE_TAG_PRODUCTS_ALL','Auflistung aller Produkte auf der Website',10,0,7),('HEAD_DESC_TAG_PRODUCTS_ALL','Hier finden Sie eine Auflistung aller Produkte mit Filtern. Powered by E-Commerce-Plattform: TrueLoaded von Holbi',10,0,7),('HEAD_H1_TAG_PRODUCTS_ALL','Komplette Produktpalette mit Filtermodul',10,0,7),('HEAD_H2_TAG_PRODUCTS_ALL','',10,0,7),('HEAD_H3_TAG_PRODUCTS_ALL','',10,0,7),('HEAD_TITLE_TAG_FEATURED','Wählen Sie den Produktbereich aus',10,0,7),('HEAD_DESC_TAG_FEATURED','Wir haben eine leistungsstarke Funktion - ausgewählte beste Produkte für Ihre Kunden - E-Commerce-Website: TrueLoaded von Holbi',10,0,7),('HEAD_H1_TAG_FEATURED','ausgewähltes bestes Produktmodul',10,0,7),('HEAD_H2_TAG_FEATURED','',10,0,7),('HEAD_H3_TAG_FEATURED','',10,0,7),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Produkte prüfen Funktionalität',10,0,7),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',10,0,7),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',10,0,7),('HEAD_TITLE_TAG_CONTACT_US','Kontaktieren Sie uns für die Erstellung von E-Commerce-Websites',10,0,7),('HEAD_DESC_TAG_CONTACT_US','Wenn Sie Fragen haben - kontaktieren Sie uns. E-Commerce-Plattform: TrueLoaded von Holbi',10,0,7),('HEAD_H1_TAG_CONTACT_US','HOLBI GROUP LTD DE',10,0,7),('HEAD_H2_TAG_CONTACT_US','Irgendwelche Fragen? kontaktiere uns\nTrueLoaded door Holbi',10,0,7),('HEAD_H3_TAG_CONTACT_US','GL7 4EU\nParadise Farm, High street\nOpening hours\nMo - Fr (9:00-18:00)\nKempsford\nUnited Kingdom',10,0,7),('HEAD_TITLE_TAG_GIFT_CARD','Geschenkkarte kaufen',10,0,7),('HEAD_DESC_TAG_GIFT_CARD','Verkaufen Sie eine Geschenkkarte an Ihre Kunden mit der E-Commerce-Seite: TrueLoaded by Holbi',10,0,7),('HEAD_H1_TAG_GIFT_CARD','Geschenkkartenfunktionalität',10,0,7),('HEAD_H2_TAG_GIFT_CARD','',10,0,7),('HEAD_H3_TAG_GIFT_CARD','',10,0,7),('HEAD_TITLE_TAG_WEDDING_REGISTRY','Hochzeitsliste',10,0,7),('HEAD_DESC_TAG_WEDDING_REGISTRY','Richten Sie für Ihre Kunden ein Hochzeitsregistrierungsmodul mit der Ecommerce-Plattform ein: TrueLoaded by Holbi',10,0,7),('HEAD_H1_TAG_WEDDING_REGISTRY','Hochzeitsregistrierungsmodul',10,0,7),('HEAD_H2_TAG_WEDDING_REGISTRY','',10,0,7),('HEAD_H3_TAG_WEDDING_REGISTRY','',10,0,7),('HEAD_TITLE_TAG_CATEGORY','E-Commerce-Lösung TrueLoaded - ##CATEGORY_NAME##',10,0,7),('HEAD_DESC_TAG_CATEGORY','Verwenden Sie ein leistungsfähiges Katalogsystem mit E-Commerce-Plattform: TrueLoaded von Holbi. Das ist ##CATEGORY_NAME##.',10,0,7),('HEAD_H1_TAG_CATEGORY','',10,0,7),('HEAD_H2_TAG_CATEGORY','',10,0,7),('HEAD_H3_TAG_CATEGORY','',10,0,7),('HEAD_TITLE_TAG_BRAND','##BRAND_NAME## unterstützt von TrueLoaded',10,0,7),('HEAD_DESC_TAG_BRAND','Verkaufen Sie Ihre Marken wie: ##BRAND_NAME## an Ihre Kunden über die E-Commerce-Seite: TrueLoaded by Holbi',10,0,7),('HEAD_H1_TAG_BRAND','',10,0,7),('HEAD_H2_TAG_BRAND','',10,0,7),('HEAD_H3_TAG_BRAND','',10,0,7),('HEAD_TITLE_TAG_FREE_SAMPLES','Auflistung von kostenlosen Proben auf der Website',10,0,7),('HEAD_DESC_TAG_FREE_SAMPLES','Auflistung aller kostenlosen Beispiele mit Filtern hier verfügbar. Powered by E-Commerce-Plattform: True Loaded von Holbi',10,0,7),('HEAD_H1_TAG_FREE_SAMPLES','Voller Probenbereich mit Filtermodul',10,0,7),('HEAD_H2_TAG_FREE_SAMPLES','',10,0,7),('HEAD_H3_TAG_FREE_SAMPLES','',10,0,7),('HEAD_TITLE_TAG_ALL','',11,0,7),('HEAD_KEY_TAG_ALL','',11,0,7),('HEAD_DESC_TAG_ALL','',11,0,7),('HEAD_TITLE_TAG_DEFAULT','Plateforme de commerce électronique - TrueLoaded par Holbi Group',11,0,7),('HEAD_KEY_TAG_DEFAULT','',11,0,7),('HEAD_DESC_TAG_DEFAULT','Plateforme de commerce électronique TrueLoaded du groupe Holbi. Solution de panier eCommerce. Site de commerce électronique. TrueLoaded par Holbi',11,0,7),('HEAD_TITLE_TAG_PRODUCT_INFO','',11,0,7),('HEAD_KEY_TAG_PRODUCT_INFO','',11,0,7),('HEAD_DESC_TAG_PRODUCT_INFO','',11,0,7),('HEAD_TITLE_TAG_WHATS_NEW','Liste des derniers produits',11,0,7),('HEAD_KEY_TAG_WHATS_NEW','',11,0,7),('HEAD_DESC_TAG_WHATS_NEW','Vous pouvez trouver le dernier produit ici avec le site de commerce électronique: TrueLoaded by Holbi',11,0,7),('HEAD_TITLE_TAG_SPECIALS','Liste des promotions - ventes - produits',11,0,7),('HEAD_KEY_TAG_SPECIALS','',11,0,7),('HEAD_DESC_TAG_SPECIALS','Vos clients verront toutes les ventes sur votre site web alimenté par le site de commerce électronique: TrueLoaded par Holbi',11,0,7),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Lisez ce que les autres disent',11,0,7),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',11,0,7),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Avis sur les produits: Lisez ce que les autres disent à propos de la plate-forme de commerce électronique: TrueLoaded by Holbi',11,0,7),('HEAD_H3_TAG_ALL','',11,0,7),('HEAD_H2_TAG_ALL','',11,0,7),('HEAD_H1_TAG_ALL','',11,0,7),('HEAD_H1_TAG_DEFAULT','Plateforme de commerce électronique TrueLoaded par Holbi Group',11,0,7),('HEAD_H2_TAG_DEFAULT','',11,0,7),('HEAD_H3_TAG_DEFAULT','',11,0,7),('HEAD_H1_TAG_PRODUCT_INFO','',11,0,7),('HEAD_H2_TAG_PRODUCT_INFO','',11,0,7),('HEAD_H3_TAG_PRODUCT_INFO','',11,0,7),('HEAD_H1_TAG_WHATS_NEW','dernière caractéristique des produits',11,0,7),('HEAD_H2_TAG_WHATS_NEW','',11,0,7),('HEAD_H3_TAG_WHATS_NEW','',11,0,7),('HEAD_H1_TAG_SPECIALS','Fonction de vente',11,0,7),('HEAD_H2_TAG_SPECIALS','',11,0,7),('HEAD_H3_TAG_SPECIALS','',11,0,7),('HEAD_TITLE_TAG_PRODUCTS_ALL','Liste de tous les produits sur le site',11,0,7),('HEAD_DESC_TAG_PRODUCTS_ALL','Liste de tous vos produits avec des filtres disponibles ici. Propulsé par une plate-forme de commerce électronique: TrueLoaded par Holbi',11,0,7),('HEAD_H1_TAG_PRODUCTS_ALL','Gamme complète de produits avec module de filtres',11,0,7),('HEAD_H2_TAG_PRODUCTS_ALL','',11,0,7),('HEAD_H3_TAG_PRODUCTS_ALL','',11,0,7),('HEAD_TITLE_TAG_FEATURED','Sélectionnez la gamme de produits',11,0,7),('HEAD_DESC_TAG_FEATURED','Nous avons une fonctionnalité puissante - meilleurs produits sélectionnés pour vos clients - site de commerce électronique: TrueLoaded par Holbi',11,0,7),('HEAD_H1_TAG_FEATURED','sélection des meilleurs produits',11,0,7),('HEAD_H2_TAG_FEATURED','',11,0,7),('HEAD_H3_TAG_FEATURED','',11,0,7),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Produits critiques fonctionnalité',11,0,7),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',11,0,7),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',11,0,7),('HEAD_TITLE_TAG_CONTACT_US','',11,0,7),('HEAD_DESC_TAG_CONTACT_US','',11,0,7),('HEAD_H1_TAG_CONTACT_US','',11,0,7),('HEAD_H2_TAG_CONTACT_US','',11,0,7),('HEAD_H3_TAG_CONTACT_US','',11,0,7),('HEAD_TITLE_TAG_GIFT_CARD','',11,0,7),('HEAD_DESC_TAG_GIFT_CARD','',11,0,7),('HEAD_H1_TAG_GIFT_CARD','',11,0,7),('HEAD_H2_TAG_GIFT_CARD','',11,0,7),('HEAD_H3_TAG_GIFT_CARD','',11,0,7),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',11,0,7),('HEAD_DESC_TAG_WEDDING_REGISTRY','',11,0,7),('HEAD_H1_TAG_WEDDING_REGISTRY','',11,0,7),('HEAD_H2_TAG_WEDDING_REGISTRY','',11,0,7),('HEAD_H3_TAG_WEDDING_REGISTRY','',11,0,7),('HEAD_TITLE_TAG_CATEGORY','',11,0,7),('HEAD_DESC_TAG_CATEGORY','',11,0,7),('HEAD_H1_TAG_CATEGORY','',11,0,7),('HEAD_H2_TAG_CATEGORY','',11,0,7),('HEAD_H3_TAG_CATEGORY','',11,0,7),('HEAD_TITLE_TAG_BRAND','',11,0,7),('HEAD_DESC_TAG_BRAND','',11,0,7),('HEAD_H1_TAG_BRAND','',11,0,7),('HEAD_H2_TAG_BRAND','',11,0,7),('HEAD_H3_TAG_BRAND','',11,0,7),('HEAD_TITLE_TAG_FREE_SAMPLES','',11,0,7),('HEAD_DESC_TAG_FREE_SAMPLES','',11,0,7),('HEAD_H1_TAG_FREE_SAMPLES','',11,0,7),('HEAD_H2_TAG_FREE_SAMPLES','',11,0,7),('HEAD_H3_TAG_FREE_SAMPLES','',11,0,7),('HEAD_TITLE_TAG_ALL','',12,0,7),('HEAD_KEY_TAG_ALL','',12,0,7),('HEAD_DESC_TAG_ALL','',12,0,7),('HEAD_TITLE_TAG_DEFAULT','E-handel plattform - TrueLoaded av Holbi Group',12,0,7),('HEAD_KEY_TAG_DEFAULT','',12,0,7),('HEAD_DESC_TAG_DEFAULT','TrueLoaded E-handelsplattform fra Holbi Group. e-handel handlekurv løsning. E-handel nettsted. TrueLoaded av Holbi',12,0,7),('HEAD_TITLE_TAG_PRODUCT_INFO','',12,0,7),('HEAD_KEY_TAG_PRODUCT_INFO','',12,0,7),('HEAD_DESC_TAG_PRODUCT_INFO','',12,0,7),('HEAD_TITLE_TAG_WHATS_NEW','Oppføring av nyeste produkter',12,0,7),('HEAD_KEY_TAG_WHATS_NEW','',12,0,7),('HEAD_DESC_TAG_WHATS_NEW','Du kan finne det nyeste produktet her med e-handel nettsted: TrueLoaded av Holbi',12,0,7),('HEAD_TITLE_TAG_SPECIALS','Oppføring av tilbud - salgsprodukter',12,0,7),('HEAD_KEY_TAG_SPECIALS','',12,0,7),('HEAD_DESC_TAG_SPECIALS','Dine kunder vil se alt salg på nettstedet ditt drevet av e-handelsnettsted: TrueLoaded av Holbi',12,0,7),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Les hva andre sier',12,0,7),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',12,0,7),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Produktanmeldelser: Les hva andre sier om E-handel plattform: TrueLoaded av Holbi',12,0,7),('HEAD_H3_TAG_ALL','',12,0,7),('HEAD_H2_TAG_ALL','',12,0,7),('HEAD_H1_TAG_ALL','',12,0,7),('HEAD_H1_TAG_DEFAULT','E-handel plattform TrueLoaded av Holbi Group',12,0,7),('HEAD_H2_TAG_DEFAULT','',12,0,7),('HEAD_H3_TAG_DEFAULT','',12,0,7),('HEAD_H1_TAG_PRODUCT_INFO','',12,0,7),('HEAD_H2_TAG_PRODUCT_INFO','',12,0,7),('HEAD_H3_TAG_PRODUCT_INFO','',12,0,7),('HEAD_H1_TAG_WHATS_NEW','nyeste produktfunksjonen',12,0,7),('HEAD_H2_TAG_WHATS_NEW','',12,0,7),('HEAD_H3_TAG_WHATS_NEW','',12,0,7),('HEAD_H1_TAG_SPECIALS','Salgsfunksjon',12,0,7),('HEAD_H2_TAG_SPECIALS','',12,0,7),('HEAD_H3_TAG_SPECIALS','',12,0,7),('HEAD_TITLE_TAG_PRODUCTS_ALL','Oppføring av alle produkter på nettstedet',12,0,7),('HEAD_DESC_TAG_PRODUCTS_ALL','Oppføring av alt ditt produkt med filtre tilgjengelig her. Drevet av e-handelsplattform: TrueLoaded av Holbi',12,0,7),('HEAD_H1_TAG_PRODUCTS_ALL','Fullt produktsortiment med filtermodul',12,0,7),('HEAD_H2_TAG_PRODUCTS_ALL','',12,0,7),('HEAD_H3_TAG_PRODUCTS_ALL','',12,0,7),('HEAD_TITLE_TAG_FEATURED','Velg produktets utvalg',12,0,7),('HEAD_DESC_TAG_FEATURED','Vi har en kraftig funksjon - utvalgte beste produkter for kundene dine - e-handelsside: TrueLoaded av Holbi',12,0,7),('HEAD_H1_TAG_FEATURED','valgt beste produktmodul',12,0,7),('HEAD_H2_TAG_FEATURED','',12,0,7),('HEAD_H3_TAG_FEATURED','',12,0,7),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Produktomtaler funksjonalitet',12,0,7),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',12,0,7),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',12,0,7),('HEAD_TITLE_TAG_CONTACT_US','',12,0,7),('HEAD_DESC_TAG_CONTACT_US','',12,0,7),('HEAD_H1_TAG_CONTACT_US','',12,0,7),('HEAD_H2_TAG_CONTACT_US','',12,0,7),('HEAD_H3_TAG_CONTACT_US','',12,0,7),('HEAD_TITLE_TAG_GIFT_CARD','',12,0,7),('HEAD_DESC_TAG_GIFT_CARD','',12,0,7),('HEAD_H1_TAG_GIFT_CARD','',12,0,7),('HEAD_H2_TAG_GIFT_CARD','',12,0,7),('HEAD_H3_TAG_GIFT_CARD','',12,0,7),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',12,0,7),('HEAD_DESC_TAG_WEDDING_REGISTRY','',12,0,7),('HEAD_H1_TAG_WEDDING_REGISTRY','',12,0,7),('HEAD_H2_TAG_WEDDING_REGISTRY','',12,0,7),('HEAD_H3_TAG_WEDDING_REGISTRY','',12,0,7),('HEAD_TITLE_TAG_CATEGORY','',12,0,7),('HEAD_DESC_TAG_CATEGORY','',12,0,7),('HEAD_H1_TAG_CATEGORY','',12,0,7),('HEAD_H2_TAG_CATEGORY','',12,0,7),('HEAD_H3_TAG_CATEGORY','',12,0,7),('HEAD_TITLE_TAG_BRAND','',12,0,7),('HEAD_DESC_TAG_BRAND','',12,0,7),('HEAD_H1_TAG_BRAND','',12,0,7),('HEAD_H2_TAG_BRAND','',12,0,7),('HEAD_H3_TAG_BRAND','',12,0,7),('HEAD_TITLE_TAG_FREE_SAMPLES','',12,0,7),('HEAD_DESC_TAG_FREE_SAMPLES','',12,0,7),('HEAD_H1_TAG_FREE_SAMPLES','',12,0,7),('HEAD_H2_TAG_FREE_SAMPLES','',12,0,7),('HEAD_H3_TAG_FREE_SAMPLES','',12,0,7),('HEAD_TITLE_TAG_ALL','',13,0,7),('HEAD_KEY_TAG_ALL','',13,0,7),('HEAD_DESC_TAG_ALL','',13,0,7),('HEAD_TITLE_TAG_DEFAULT','Piattaforma di e-commerce - TrueLoaded di Holbi Group',13,0,7),('HEAD_KEY_TAG_DEFAULT','',13,0,7),('HEAD_DESC_TAG_DEFAULT','Piattaforma di e-commerce TrueLoaded di Holbi Group. soluzione di eCommerce Shopping Cart. Sito e-commerce TrueLoaded di Holbi',13,0,7),('HEAD_TITLE_TAG_PRODUCT_INFO','',13,0,7),('HEAD_KEY_TAG_PRODUCT_INFO','',13,0,7),('HEAD_DESC_TAG_PRODUCT_INFO','',13,0,7),('HEAD_TITLE_TAG_WHATS_NEW','Elenco degli ultimi prodotti',13,0,7),('HEAD_KEY_TAG_WHATS_NEW','',13,0,7),('HEAD_DESC_TAG_WHATS_NEW','Puoi trovare l\'ultimo prodotto qui con il sito web di e-commerce: TrueLoaded di Holbi',13,0,7),('HEAD_TITLE_TAG_SPECIALS','Elenco di offerte speciali - vendite - prodotti',13,0,7),('HEAD_KEY_TAG_SPECIALS','',13,0,7),('HEAD_DESC_TAG_SPECIALS','I tuoi clienti vedranno tutte le vendite sul tuo sito web supportate dal sito di e-commerce: TrueLoaded by Holbi',13,0,7),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Leggi cosa dicono gli altri',13,0,7),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',13,0,7),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Recensioni dei prodotti: leggi cosa dicono gli altri sulla piattaforma di e-commerce: TrueLoaded by Holbi',13,0,7),('HEAD_H3_TAG_ALL','',13,0,7),('HEAD_H2_TAG_ALL','',13,0,7),('HEAD_H1_TAG_ALL','',13,0,7),('HEAD_H1_TAG_DEFAULT','Piattaforma di e-commerce TrueLoaded di Holbi Group',13,0,7),('HEAD_H2_TAG_DEFAULT','',13,0,7),('HEAD_H3_TAG_DEFAULT','',13,0,7),('HEAD_H1_TAG_PRODUCT_INFO','',13,0,7),('HEAD_H2_TAG_PRODUCT_INFO','',13,0,7),('HEAD_H3_TAG_PRODUCT_INFO','',13,0,7),('HEAD_H1_TAG_WHATS_NEW','ultima funzionalità dei prodotti',13,0,7),('HEAD_H2_TAG_WHATS_NEW','',13,0,7),('HEAD_H3_TAG_WHATS_NEW','',13,0,7),('HEAD_H1_TAG_SPECIALS','Caratteristica di vendita',13,0,7),('HEAD_H2_TAG_SPECIALS','',13,0,7),('HEAD_H3_TAG_SPECIALS','',13,0,7),('HEAD_TITLE_TAG_PRODUCTS_ALL','Elenco di tutti i prodotti sul sito',13,0,7),('HEAD_DESC_TAG_PRODUCTS_ALL','Elenco di tutti i tuoi prodotti con filtri disponibili qui. Basato sulla piattaforma di e-commerce: TrueLoaded di Holbi',13,0,7),('HEAD_H1_TAG_PRODUCTS_ALL','Gamma completa di prodotti con modulo filtri',13,0,7),('HEAD_H2_TAG_PRODUCTS_ALL','',13,0,7),('HEAD_H3_TAG_PRODUCTS_ALL','',13,0,7),('HEAD_TITLE_TAG_FEATURED','Seleziona la gamma del prodotto',13,0,7),('HEAD_DESC_TAG_FEATURED','Abbiamo una potente funzionalità: i migliori prodotti selezionati per i tuoi clienti: sito di e-commerce: TrueLoaded by Holbi',13,0,7),('HEAD_H1_TAG_FEATURED','selezionato il miglior prodotto modulo',13,0,7),('HEAD_H2_TAG_FEATURED','',13,0,7),('HEAD_H3_TAG_FEATURED','',13,0,7),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Funzionalità di recensioni di prodotti',13,0,7),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',13,0,7),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',13,0,7),('HEAD_TITLE_TAG_CONTACT_US','',13,0,7),('HEAD_DESC_TAG_CONTACT_US','',13,0,7),('HEAD_H1_TAG_CONTACT_US','',13,0,7),('HEAD_H2_TAG_CONTACT_US','',13,0,7),('HEAD_H3_TAG_CONTACT_US','',13,0,7),('HEAD_TITLE_TAG_GIFT_CARD','',13,0,7),('HEAD_DESC_TAG_GIFT_CARD','',13,0,7),('HEAD_H1_TAG_GIFT_CARD','',13,0,7),('HEAD_H2_TAG_GIFT_CARD','',13,0,7),('HEAD_H3_TAG_GIFT_CARD','',13,0,7),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',13,0,7),('HEAD_DESC_TAG_WEDDING_REGISTRY','',13,0,7),('HEAD_H1_TAG_WEDDING_REGISTRY','',13,0,7),('HEAD_H2_TAG_WEDDING_REGISTRY','',13,0,7),('HEAD_H3_TAG_WEDDING_REGISTRY','',13,0,7),('HEAD_TITLE_TAG_CATEGORY','',13,0,7),('HEAD_DESC_TAG_CATEGORY','',13,0,7),('HEAD_H1_TAG_CATEGORY','',13,0,7),('HEAD_H2_TAG_CATEGORY','',13,0,7),('HEAD_H3_TAG_CATEGORY','',13,0,7),('HEAD_TITLE_TAG_BRAND','',13,0,7),('HEAD_DESC_TAG_BRAND','',13,0,7),('HEAD_H1_TAG_BRAND','',13,0,7),('HEAD_H2_TAG_BRAND','',13,0,7),('HEAD_H3_TAG_BRAND','',13,0,7),('HEAD_TITLE_TAG_FREE_SAMPLES','',13,0,7),('HEAD_DESC_TAG_FREE_SAMPLES','',13,0,7),('HEAD_H1_TAG_FREE_SAMPLES','',13,0,7),('HEAD_H2_TAG_FREE_SAMPLES','',13,0,7),('HEAD_H3_TAG_FREE_SAMPLES','',13,0,7),('HEAD_TITLE_TAG_ALL','',15,0,7),('HEAD_KEY_TAG_ALL','',15,0,7),('HEAD_DESC_TAG_ALL','',15,0,7),('HEAD_TITLE_TAG_DEFAULT','Електронна комерційна платформа - TrueLoaded від Holbi Group',15,0,7),('HEAD_KEY_TAG_DEFAULT','',15,0,7),('HEAD_DESC_TAG_DEFAULT','TrueLoaded Електронна комерційна платформа від Holbi Group. Рішення для кошика для електронної комерції. Сайт електронної комерції. TrueLoaded від Holbi',15,0,7),('HEAD_TITLE_TAG_PRODUCT_INFO','',15,0,7),('HEAD_KEY_TAG_PRODUCT_INFO','',15,0,7),('HEAD_DESC_TAG_PRODUCT_INFO','',15,0,7),('HEAD_TITLE_TAG_WHATS_NEW','Перелік останніх продуктів',15,0,7),('HEAD_KEY_TAG_WHATS_NEW','',15,0,7),('HEAD_DESC_TAG_WHATS_NEW','Ви можете знайти новітній продукт на сайті електронної комерції: TrueLoaded by Holbi',15,0,7),('HEAD_TITLE_TAG_SPECIALS','Перелік спеціальних продуктів- продаж - продуки',15,0,7),('HEAD_KEY_TAG_SPECIALS','',15,0,7),('HEAD_DESC_TAG_SPECIALS','Ваші клієнти будуть бачити всі розпродажі вашого сайту на сайті електронної комерції: TrueLoaded by Holbi',15,0,7),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Прочитайте, що говорять інші',15,0,7),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',15,0,7),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Огляд продуктів: прочитайте, що говорять інші про платформу платформі електронної комерції: TrueLoaded by Holbi',15,0,7),('HEAD_H2_TAG_ALL','',15,0,7),('HEAD_H1_TAG_ALL','',15,0,7),('HEAD_H3_TAG_ALL','',15,0,7),('HEAD_H1_TAG_DEFAULT','Електронна комерційна платформа TrueLoaded від Holbi Group',15,0,7),('HEAD_H2_TAG_DEFAULT','',15,0,7),('HEAD_H3_TAG_DEFAULT','',15,0,7),('HEAD_H1_TAG_PRODUCT_INFO','',15,0,7),('HEAD_H2_TAG_PRODUCT_INFO','',15,0,7),('HEAD_H3_TAG_PRODUCT_INFO','',15,0,7),('HEAD_H1_TAG_WHATS_NEW','найновіші продукти',15,0,7),('HEAD_H2_TAG_WHATS_NEW','',15,0,7),('HEAD_H3_TAG_WHATS_NEW','',15,0,7),('HEAD_H1_TAG_SPECIALS','Розпродажі',15,0,7),('HEAD_H2_TAG_SPECIALS','',15,0,7),('HEAD_H3_TAG_SPECIALS','',15,0,7),('HEAD_TITLE_TAG_PRODUCTS_ALL','Перелік усіх продуктів на сайті',15,0,7),('HEAD_DESC_TAG_PRODUCTS_ALL','Перелік усіх ваших продуктів із фільтрами доступний тут. Працює на платформі електронної комерції: TrueLoaded by Holbi',15,0,7),('HEAD_H1_TAG_PRODUCTS_ALL','Повний асортимент продукції з модулем фільтрів',15,0,7),('HEAD_H2_TAG_PRODUCTS_ALL','',15,0,7),('HEAD_H3_TAG_PRODUCTS_ALL','',15,0,7),('HEAD_TITLE_TAG_FEATURED','Виберіть діапазон продукту',15,0,7),('HEAD_DESC_TAG_FEATURED','У нас є просунуті функції - вибрані кращі продукти для ваших клієнтів - сайт електронної комерції: TrueLoaded by Holbi',15,0,7),('HEAD_H1_TAG_FEATURED','модуль для вибору кращих продуктів',15,0,7),('HEAD_H2_TAG_FEATURED','',15,0,7),('HEAD_H3_TAG_FEATURED','',15,0,7),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Функціональність огляду продуктів',15,0,7),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',15,0,7),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',15,0,7),('HEAD_TITLE_TAG_CONTACT_US','',15,0,7),('HEAD_DESC_TAG_CONTACT_US','',15,0,7),('HEAD_H1_TAG_CONTACT_US','',15,0,7),('HEAD_H2_TAG_CONTACT_US','',15,0,7),('HEAD_H3_TAG_CONTACT_US','',15,0,7),('HEAD_TITLE_TAG_GIFT_CARD','',15,0,7),('HEAD_DESC_TAG_GIFT_CARD','',15,0,7),('HEAD_H1_TAG_GIFT_CARD','',15,0,7),('HEAD_H2_TAG_GIFT_CARD','',15,0,7),('HEAD_H3_TAG_GIFT_CARD','',15,0,7),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',15,0,7),('HEAD_DESC_TAG_WEDDING_REGISTRY','',15,0,7),('HEAD_H1_TAG_WEDDING_REGISTRY','',15,0,7),('HEAD_H2_TAG_WEDDING_REGISTRY','',15,0,7),('HEAD_H3_TAG_WEDDING_REGISTRY','',15,0,7),('HEAD_TITLE_TAG_CATEGORY','',15,0,7),('HEAD_DESC_TAG_CATEGORY','',15,0,7),('HEAD_H1_TAG_CATEGORY','',15,0,7),('HEAD_H2_TAG_CATEGORY','',15,0,7),('HEAD_H3_TAG_CATEGORY','',15,0,7),('HEAD_TITLE_TAG_BRAND','',15,0,7),('HEAD_DESC_TAG_BRAND','',15,0,7),('HEAD_H1_TAG_BRAND','',15,0,7),('HEAD_H2_TAG_BRAND','',15,0,7),('HEAD_H3_TAG_BRAND','',15,0,7),('HEAD_TITLE_TAG_FREE_SAMPLES','',15,0,7),('HEAD_DESC_TAG_FREE_SAMPLES','',15,0,7),('HEAD_H1_TAG_FREE_SAMPLES','',15,0,7),('HEAD_H2_TAG_FREE_SAMPLES','',15,0,7),('HEAD_H3_TAG_FREE_SAMPLES','',15,0,7),('HEAD_TITLE_TAG_ALL','',17,0,7),('HEAD_KEY_TAG_ALL','',17,0,7),('HEAD_DESC_TAG_ALL','',17,0,7),('HEAD_TITLE_TAG_DEFAULT','Электронная коммерция - TrueLoaded от Holbi Group',17,0,7),('HEAD_KEY_TAG_DEFAULT','',17,0,7),('HEAD_DESC_TAG_DEFAULT','Платформа TrueLoaded для электронной коммерции от Holbi Group. Решение для покупок электронной коммерции. Сайт электронной торговли. TrueLoaded от Holbi',17,0,7),('HEAD_TITLE_TAG_PRODUCT_INFO','',17,0,7),('HEAD_KEY_TAG_PRODUCT_INFO','',17,0,7),('HEAD_DESC_TAG_PRODUCT_INFO','',17,0,7),('HEAD_TITLE_TAG_WHATS_NEW','Список последних продуктов',17,0,7),('HEAD_KEY_TAG_WHATS_NEW','',17,0,7),('HEAD_DESC_TAG_WHATS_NEW','Вы можете найти новейший продукт на сайте электронной коммерции: TrueLoaded by Holbi',17,0,7),('HEAD_TITLE_TAG_SPECIALS','Список специальных продуктов - продажа - продукты',17,0,7),('HEAD_KEY_TAG_SPECIALS','',17,0,7),('HEAD_DESC_TAG_SPECIALS','Ваши клиенты будут видеть все распродажи вашего сайта на сайте электронной коммерции: TrueLoaded by Holbi',17,0,7),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Читайте, что говорят другие',17,0,7),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',17,0,7),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Обзор продуктов: прочитайте, что говорят другие о платформе платформе электронной коммерции: TrueLoaded by Holbi',17,0,7),('HEAD_H3_TAG_ALL','',17,0,7),('HEAD_H2_TAG_ALL','',17,0,7),('HEAD_H1_TAG_ALL','',17,0,7),('HEAD_H1_TAG_DEFAULT','Электронная коммерция TrueLoaded от Holbi Group',17,0,7),('HEAD_H2_TAG_DEFAULT','',17,0,7),('HEAD_H3_TAG_DEFAULT','',17,0,7),('HEAD_H1_TAG_PRODUCT_INFO','',17,0,7),('HEAD_H2_TAG_PRODUCT_INFO','',17,0,7),('HEAD_H3_TAG_PRODUCT_INFO','',17,0,7),('HEAD_H1_TAG_WHATS_NEW','новейшие продукты',17,0,7),('HEAD_H2_TAG_WHATS_NEW','',17,0,7),('HEAD_H3_TAG_WHATS_NEW','',17,0,7),('HEAD_H1_TAG_SPECIALS','Распродажи',17,0,7),('HEAD_H2_TAG_SPECIALS','',17,0,7),('HEAD_H3_TAG_SPECIALS','',17,0,7),('HEAD_TITLE_TAG_PRODUCTS_ALL','Список всех продуктов на сайте',17,0,7),('HEAD_DESC_TAG_PRODUCTS_ALL','Здесь представлен список всех ваших продуктов с фильтрами. Работает на платформе электронной коммерции: TrueLoaded by Holbi',17,0,7),('HEAD_H1_TAG_PRODUCTS_ALL','Полный ассортимент продукции с модулем фильтров',17,0,7),('HEAD_H2_TAG_PRODUCTS_ALL','',17,0,7),('HEAD_H3_TAG_PRODUCTS_ALL','',17,0,7),('HEAD_TITLE_TAG_FEATURED','Выберите диапазон продукта',17,0,7),('HEAD_DESC_TAG_FEATURED','У нас есть продвинутые функции - выбранные лучшие продукты для ваших клиентов - сайт электронной коммерции: TrueLoaded by Holbi',17,0,7),('HEAD_H1_TAG_FEATURED','модуль для выбора лучших продуктов',17,0,7),('HEAD_H2_TAG_FEATURED','',17,0,7),('HEAD_H3_TAG_FEATURED','',17,0,7),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Функциональность обзора продуктов',17,0,7),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',17,0,7),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',17,0,7),('HEAD_TITLE_TAG_CONTACT_US','',17,0,7),('HEAD_DESC_TAG_CONTACT_US','',17,0,7),('HEAD_H1_TAG_CONTACT_US','',17,0,7),('HEAD_H2_TAG_CONTACT_US','',17,0,7),('HEAD_H3_TAG_CONTACT_US','',17,0,7),('HEAD_TITLE_TAG_GIFT_CARD','',17,0,7),('HEAD_DESC_TAG_GIFT_CARD','',17,0,7),('HEAD_H1_TAG_GIFT_CARD','',17,0,7),('HEAD_H2_TAG_GIFT_CARD','',17,0,7),('HEAD_H3_TAG_GIFT_CARD','',17,0,7),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',17,0,7),('HEAD_DESC_TAG_WEDDING_REGISTRY','',17,0,7),('HEAD_H1_TAG_WEDDING_REGISTRY','',17,0,7),('HEAD_H2_TAG_WEDDING_REGISTRY','',17,0,7),('HEAD_H3_TAG_WEDDING_REGISTRY','',17,0,7),('HEAD_TITLE_TAG_CATEGORY','',17,0,7),('HEAD_DESC_TAG_CATEGORY','',17,0,7),('HEAD_H1_TAG_CATEGORY','',17,0,7),('HEAD_H2_TAG_CATEGORY','',17,0,7),('HEAD_H3_TAG_CATEGORY','',17,0,7),('HEAD_TITLE_TAG_BRAND','',17,0,7),('HEAD_DESC_TAG_BRAND','',17,0,7),('HEAD_H1_TAG_BRAND','',17,0,7),('HEAD_H2_TAG_BRAND','',17,0,7),('HEAD_H3_TAG_BRAND','',17,0,7),('HEAD_TITLE_TAG_FREE_SAMPLES','',17,0,7),('HEAD_DESC_TAG_FREE_SAMPLES','',17,0,7),('HEAD_H1_TAG_FREE_SAMPLES','',17,0,7),('HEAD_H2_TAG_FREE_SAMPLES','',17,0,7),('HEAD_H3_TAG_FREE_SAMPLES','',17,0,7),('HEAD_TITLE_TAG_DEFAULT','Platforma e-commerce - TrueLoaded firmy Holbi Group',26,0,7),('HEAD_DESC_TAG_DEFAULT','Platforma TrueLoaded Ecommerce od Holbi Group. Rozwiązanie koszyka e-commerce. Witryna e-commerce. TrueLoaded przez Holbi',26,0,7),('HEAD_H1_TAG_DEFAULT','Platforma e-commerce TrueLoaded firmy Holbi Group',26,0,7),('HEAD_H2_TAG_DEFAULT','',26,0,7),('HEAD_H3_TAG_DEFAULT','',26,0,7),('HEAD_TITLE_TAG_PRODUCTS_ALL','Lista wszystkich produktów na stronie',26,0,7),('HEAD_DESC_TAG_PRODUCTS_ALL','Lista wszystkich produktów z filtrami dostępna tutaj. Obsługiwane przez platformę e-commerce: TrueLoaded by Holbi',26,0,7),('HEAD_H1_TAG_PRODUCTS_ALL','Pełny asortyment produktów z modułem filtrów',26,0,7),('HEAD_H2_TAG_PRODUCTS_ALL','',26,0,7),('HEAD_H3_TAG_PRODUCTS_ALL','',26,0,7),('HEAD_TITLE_TAG_WHATS_NEW','Lista najnowszych produktów',26,0,7),('HEAD_DESC_TAG_WHATS_NEW','Możesz znaleźć najnowszy produkt tutaj ze stroną e-commerce: TrueLoaded by Holbi',26,0,7),('HEAD_H1_TAG_WHATS_NEW','najnowsze funkcje produktów',26,0,7),('HEAD_H2_TAG_WHATS_NEW','',26,0,7),('HEAD_H3_TAG_WHATS_NEW','',26,0,7),('HEAD_TITLE_TAG_SPECIALS','Lista ofert specjalnych - sprzedaż - produkty',26,0,7),('HEAD_DESC_TAG_SPECIALS','Twoi klienci zobaczą całą sprzedaż Twojej witryny internetowej opartą na witrynie e-commerce: TrueLoaded firmy Holbi',26,0,7),('HEAD_H1_TAG_SPECIALS','Funkcja sprzedaży',26,0,7),('HEAD_H2_TAG_SPECIALS','',26,0,7),('HEAD_H3_TAG_SPECIALS','',26,0,7),('HEAD_TITLE_TAG_FEATURED','Wybierz zakres produktu',26,0,7),('HEAD_DESC_TAG_FEATURED','Mamy potężną funkcję - wybrane najlepsze produkty dla Twoich klientów - witrynę e-commerce: TrueLoaded firmy Holbi',26,0,7),('HEAD_H1_TAG_FEATURED','wybrany moduł najlepszych produktów',26,0,7),('HEAD_H2_TAG_FEATURED','',26,0,7),('HEAD_H3_TAG_FEATURED','',26,0,7),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Przeczytaj, co mówią inni',26,0,7),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Recenzje produktów: Przeczytaj, co inni mówią o platformie e-commerce: TrueLoaded by Holbi',26,0,7),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Funkcjonalność recenzji produktów',26,0,7),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',26,0,7),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',26,0,7),('HEAD_TITLE_TAG_CONTACT_US','',26,0,7),('HEAD_DESC_TAG_CONTACT_US','',26,0,7),('HEAD_H1_TAG_CONTACT_US','',26,0,7),('HEAD_H2_TAG_CONTACT_US','',26,0,7),('HEAD_H3_TAG_CONTACT_US','',26,0,7),('HEAD_TITLE_TAG_GIFT_CARD','',26,0,7),('HEAD_DESC_TAG_GIFT_CARD','',26,0,7),('HEAD_H1_TAG_GIFT_CARD','',26,0,7),('HEAD_H2_TAG_GIFT_CARD','',26,0,7),('HEAD_H3_TAG_GIFT_CARD','',26,0,7),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',26,0,7),('HEAD_DESC_TAG_WEDDING_REGISTRY','',26,0,7),('HEAD_H1_TAG_WEDDING_REGISTRY','',26,0,7),('HEAD_H2_TAG_WEDDING_REGISTRY','',26,0,7),('HEAD_H3_TAG_WEDDING_REGISTRY','',26,0,7),('HEAD_TITLE_TAG_PRODUCT_INFO','',26,0,7),('HEAD_DESC_TAG_PRODUCT_INFO','',26,0,7),('HEAD_H1_TAG_PRODUCT_INFO','',26,0,7),('HEAD_H2_TAG_PRODUCT_INFO','',26,0,7),('HEAD_H3_TAG_PRODUCT_INFO','',26,0,7),('HEAD_TITLE_TAG_CATEGORY','',26,0,7),('HEAD_DESC_TAG_CATEGORY','',26,0,7),('HEAD_H1_TAG_CATEGORY','',26,0,7),('HEAD_H2_TAG_CATEGORY','',26,0,7),('HEAD_H3_TAG_CATEGORY','',26,0,7),('HEAD_TITLE_TAG_BRAND','',26,0,7),('HEAD_DESC_TAG_BRAND','',26,0,7),('HEAD_H1_TAG_BRAND','',26,0,7),('HEAD_H2_TAG_BRAND','',26,0,7),('HEAD_H3_TAG_BRAND','',26,0,7),('HEAD_TITLE_TAG_FREE_SAMPLES','',26,0,7),('HEAD_DESC_TAG_FREE_SAMPLES','',26,0,7),('HEAD_H1_TAG_FREE_SAMPLES','',26,0,7),('HEAD_H2_TAG_FREE_SAMPLES','',26,0,7),('HEAD_H3_TAG_FREE_SAMPLES','',26,0,7),('HEAD_TITLE_TAG_ALL','',26,0,7),('HEAD_DESC_TAG_ALL','',26,0,7),('HEAD_H1_TAG_ALL','',26,0,7),('HEAD_H2_TAG_ALL','',26,0,7),('HEAD_H3_TAG_ALL','',26,0,7),('HEAD_TITLE_TAG_ALL','',1,0,8),('HEAD_KEY_TAG_ALL','trueloaded, ecommerce, holbi,holbi group,graphic designer, online designer, self made design, templates',1,0,8),('HEAD_DESC_TAG_ALL','',1,0,8),('HEAD_TITLE_TAG_DEFAULT','Ecommerce platform - osCommerce by Holbi Group',1,0,8),('HEAD_KEY_TAG_DEFAULT','',1,0,8),('HEAD_DESC_TAG_DEFAULT','osCommerce Ecommerce platform from Holbi Group. eCommerce Shopping Cart solution. Ecommerce site. osCommerce by Holbi',1,0,8),('HEAD_TITLE_TAG_PRODUCT_INFO','Ecommerce platform - ##PRODUCT_NAME## - ##BRAND_NAME##',1,0,8),('HEAD_KEY_TAG_PRODUCT_INFO','',1,0,8),('HEAD_DESC_TAG_PRODUCT_INFO','Sell your products with ecommerce site: osCommerce by Holbi. This is ##PRODUCT_NAME## from ##CATEGORY_NAME## produced by ##BRAND_NAME##',1,0,8),('HEAD_TITLE_TAG_WHATS_NEW','Listing of laterst products',1,0,8),('HEAD_KEY_TAG_WHATS_NEW','',1,0,8),('HEAD_DESC_TAG_WHATS_NEW','You may find latest product here with ecommerce website: osCommerce by Holbi',1,0,8),('HEAD_TITLE_TAG_SPECIALS','Listing of specials - sales - products',1,0,8),('HEAD_KEY_TAG_SPECIALS','',1,0,8),('HEAD_DESC_TAG_SPECIALS','Your clients will see all sales on your web site powered by ecommerce site: osCommerce by Holbi',1,0,8),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Read what others are saying',1,0,8),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',1,0,8),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Products reviews: Read what others are saying about Ecommerce platform : osCommerce by Holbi',1,0,8),('HEAD_H1_TAG_ALL','',1,0,8),('HEAD_H1_TAG_DEFAULT','Ecommerce platform osCommerce by Holbi Group',1,0,8),('HEAD_H3_TAG_ALL','',1,0,8),('HEAD_H2_TAG_ALL','',1,0,8),('HEAD_H2_TAG_DEFAULT','',1,0,8),('HEAD_H3_TAG_DEFAULT','',1,0,8),('HEAD_H1_TAG_PRODUCT_INFO','',1,0,8),('HEAD_H2_TAG_PRODUCT_INFO','',1,0,8),('HEAD_H3_TAG_PRODUCT_INFO','',1,0,8),('HEAD_H1_TAG_WHATS_NEW','latest products feature',1,0,8),('HEAD_H2_TAG_WHATS_NEW','',1,0,8),('HEAD_H3_TAG_WHATS_NEW','',1,0,8),('HEAD_H1_TAG_SPECIALS','Sales feature',1,0,8),('HEAD_H2_TAG_SPECIALS','',1,0,8),('HEAD_H3_TAG_SPECIALS','',1,0,8),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Products reviews functionality',1,0,8),('HEAD_TITLE_TAG_PRODUCTS_ALL','Listing of all products on the site',1,0,8),('HEAD_DESC_TAG_PRODUCTS_ALL','Listing of all your product with filters availble here. Powered by ecommerce platform: osCommerce by Holbi',1,0,8),('HEAD_H1_TAG_PRODUCTS_ALL','Full product range with filters module',1,0,8),('HEAD_H2_TAG_PRODUCTS_ALL','',1,0,8),('HEAD_H3_TAG_PRODUCTS_ALL','',1,0,8),('HEAD_TITLE_TAG_FEATURED','Select product\'s range',1,0,8),('HEAD_DESC_TAG_FEATURED','We have powerful feature - selected best products for your clients - ecommerce site: osCommerce by Holbi',1,0,8),('HEAD_H1_TAG_FEATURED','selected best products module',1,0,8),('HEAD_H2_TAG_FEATURED','',1,0,8),('HEAD_H3_TAG_FEATURED','',1,0,8),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',1,0,8),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',1,0,8),('HEAD_TITLE_TAG_CONTACT_US','Contact us about ecommerce site creating',1,0,8),('HEAD_DESC_TAG_CONTACT_US','If you have any questions - contact us. Ecommerce Platform: osCommerce by Holbi',1,0,8),('HEAD_H1_TAG_CONTACT_US','HOLBI GROUP LTD',1,0,8),('HEAD_H2_TAG_CONTACT_US','Any questions? contact us\nosCommerce by Holbi',1,0,8),('HEAD_H3_TAG_CONTACT_US','Paradise Farm, High street\nOpening hours\nMo - Fr (9:00-18:00)\nKempsford\nUnited Kingdom\nGL7 4EU',1,0,8),('HEAD_TITLE_TAG_GIFT_CARD','Buy gift card',1,0,8),('HEAD_DESC_TAG_GIFT_CARD','Sell gift card to your clients with ecommerce site: osCommerce by Holbi',1,0,8),('HEAD_H1_TAG_GIFT_CARD','gift card functionality',1,0,8),('HEAD_H2_TAG_GIFT_CARD','',1,0,8),('HEAD_H3_TAG_GIFT_CARD','',1,0,8),('HEAD_TITLE_TAG_WEDDING_REGISTRY','Wedding registry',1,0,8),('HEAD_DESC_TAG_WEDDING_REGISTRY','Set up wedding registry module for your clients with Ecommerce platform : osCommerce by Holbi',1,0,8),('HEAD_H1_TAG_WEDDING_REGISTRY','Wedding registry module',1,0,8),('HEAD_H2_TAG_WEDDING_REGISTRY','',1,0,8),('HEAD_H3_TAG_WEDDING_REGISTRY','',1,0,8),('HEAD_TITLE_TAG_CATEGORY','Ecommerce website osCommerce - ##CATEGORY_NAME##',1,0,8),('HEAD_DESC_TAG_CATEGORY','Use powerfull catalog system with ecommerce platform : osCommerce by Holbi. This is ##CATEGORY_NAME##.',1,0,8),('HEAD_H1_TAG_CATEGORY','',1,0,8),('HEAD_H2_TAG_CATEGORY','',1,0,8),('HEAD_H3_TAG_CATEGORY','',1,0,8),('HEAD_TITLE_TAG_BRAND','##BRAND_NAME## powered by osCommerce',1,0,8),('HEAD_DESC_TAG_BRAND','Sell your your brands like: ##BRAND_NAME## to your clients using ecommerce site: osCommerce by Holbi',1,0,8),('HEAD_H1_TAG_BRAND','',1,0,8),('HEAD_H2_TAG_BRAND','',1,0,8),('HEAD_H3_TAG_BRAND','',1,0,8),('HEAD_TITLE_TAG_FREE_SAMPLES','Listing of free samples on the site',1,0,8),('HEAD_DESC_TAG_FREE_SAMPLES','Listing of all your free samples with filters availble here. Powered by ecommerce platform: osCommerce by Holbi',1,0,8),('HEAD_H1_TAG_FREE_SAMPLES','Full samples range with filters module',1,0,8),('HEAD_H2_TAG_FREE_SAMPLES','',1,0,8),('HEAD_H3_TAG_FREE_SAMPLES','',1,0,8),('DEFAULT_BREADCRUMB_CATALOG_INDEX','',1,0,8),('IMAGE_ALT_TAG_MASK_CATEGORY','',1,0,8),('IMAGE_TITLE_TAG_MASK_CATEGORY','',1,0,8),('DEFAULT_BREADCRUMB_CATALOG_PRODUCT','',1,0,8),('IMAGE_ALT_TAG_MASK_PRODUCT_INFO','',1,0,8),('IMAGE_TITLE_TAG_MASK_PRODUCT_INFO','',1,0,8),('HEAD_TITLE_TAG_BLOG_INDEX','',1,0,8),('HEAD_DESC_TAG_BLOG_INDEX','',1,0,8),('HEAD_TITLE_TAG_BLOG_POST','',1,0,8),('HEAD_DESC_TAG_BLOG_POST','',1,0,8),('HEAD_H1_TAG_BLOG_POST','',1,0,8),('HEAD_H2_TAG_BLOG_POST','',1,0,8),('HEAD_H3_TAG_BLOG_POST','',1,0,8),('HEAD_TITLE_TAG_BLOG_TAG','',1,0,8),('HEAD_DESC_TAG_BLOG_TAG','',1,0,8),('HEAD_H1_TAG_BLOG_TAG','',1,0,8),('HEAD_H2_TAG_BLOG_TAG','',1,0,8),('HEAD_H3_TAG_BLOG_TAG','',1,0,8),('HEAD_TITLE_TAG_BLOG_CATEGORY','',1,0,8),('HEAD_DESC_TAG_BLOG_CATEGORY','',1,0,8),('HEAD_H1_TAG_BLOG_CATEGORY','',1,0,8),('HEAD_H2_TAG_BLOG_CATEGORY','',1,0,8),('HEAD_H3_TAG_BLOG_CATEGORY','',1,0,8),('HEAD_TITLE_TAG_ALL','',2,0,8),('HEAD_KEY_TAG_ALL','',2,0,8),('HEAD_DESC_TAG_ALL','',2,0,8),('HEAD_TITLE_TAG_DEFAULT','',2,0,8),('HEAD_KEY_TAG_DEFAULT','',2,0,8),('HEAD_DESC_TAG_DEFAULT','',2,0,8),('HEAD_TITLE_TAG_PRODUCT_INFO','',2,0,8),('HEAD_KEY_TAG_PRODUCT_INFO','',2,0,8),('HEAD_DESC_TAG_PRODUCT_INFO','',2,0,8),('HEAD_TITLE_TAG_WHATS_NEW','',2,0,8),('HEAD_KEY_TAG_WHATS_NEW','',2,0,8),('HEAD_DESC_TAG_WHATS_NEW','',2,0,8),('HEAD_TITLE_TAG_SPECIALS','',2,0,8),('HEAD_KEY_TAG_SPECIALS','',2,0,8),('HEAD_DESC_TAG_SPECIALS','',2,0,8),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','',2,0,8),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',2,0,8),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','',2,0,8),('HEAD_TITLE_TAG_ALL','',3,0,8),('HEAD_KEY_TAG_ALL','',3,0,8),('HEAD_DESC_TAG_ALL','',3,0,8),('HEAD_TITLE_TAG_DEFAULT','E-commerceplatform - TrueLoaded door Holbi Group',3,0,8),('HEAD_KEY_TAG_DEFAULT','',3,0,8),('HEAD_DESC_TAG_DEFAULT','TrueLoaded E-commerceplatform van Holbi Group. eCommerce winkelwagen oplossing. E-commerce site. TrueLoaded door Holbi',3,0,8),('HEAD_TITLE_TAG_PRODUCT_INFO','E-commerce oplossing - ##PRODUCT_NAME## - ##BRAND_NAME##',3,0,8),('HEAD_KEY_TAG_PRODUCT_INFO','',3,0,8),('HEAD_DESC_TAG_PRODUCT_INFO','Verkoop uw producten met e-commerce site: TrueLoaded door Holbi. Dit is ##PRODUCT_NAME## from ##CATEGORY_NAME## geproduceerd door ##BRAND_NAME##',3,0,8),('HEAD_TITLE_TAG_WHATS_NEW','Lijst met de nieuwste producten',3,0,8),('HEAD_KEY_TAG_WHATS_NEW','',3,0,8),('HEAD_DESC_TAG_WHATS_NEW','U vindt het nieuwste product hier met e-commerce website: TrueLoaded door Holbi',3,0,8),('HEAD_TITLE_TAG_SPECIALS','Lijst met specials - verkoop - producten',3,0,8),('HEAD_KEY_TAG_SPECIALS','',3,0,8),('HEAD_DESC_TAG_SPECIALS','Uw klanten zien alle verkopen op uw website mogelijk gemaakt door e-commercesites: TrueLoaded door Holbi',3,0,8),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Lees wat anderen zeggen',3,0,8),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',3,0,8),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Productrecensies: Lees wat anderen over Ecommerce-platform zeggen: TrueLoaded door Holbi',3,0,8),('HEAD_H3_TAG_ALL','',3,0,8),('HEAD_H2_TAG_ALL','',3,0,8),('HEAD_H1_TAG_ALL','',3,0,8),('HEAD_H1_TAG_DEFAULT','E-commerceplatform TrueLoaded door Holbi Group',3,0,8),('HEAD_H2_TAG_DEFAULT','',3,0,8),('HEAD_H3_TAG_DEFAULT','',3,0,8),('HEAD_H1_TAG_PRODUCT_INFO','',3,0,8),('HEAD_H2_TAG_PRODUCT_INFO','',3,0,8),('HEAD_H3_TAG_PRODUCT_INFO','',3,0,8),('HEAD_H1_TAG_WHATS_NEW','nieuwste producten functie',3,0,8),('HEAD_H2_TAG_WHATS_NEW','',3,0,8),('HEAD_H3_TAG_WHATS_NEW','',3,0,8),('HEAD_H1_TAG_SPECIALS','Verkoop functie',3,0,8),('HEAD_H2_TAG_SPECIALS','',3,0,8),('HEAD_H3_TAG_SPECIALS','',3,0,8),('HEAD_TITLE_TAG_PRODUCTS_ALL','Lijst van alle producten op de site',3,0,8),('HEAD_DESC_TAG_PRODUCTS_ALL','Lijst van al uw producten met filters hier beschikbaar. Mogelijk gemaakt door e-commerce platform: TrueLoaded door Holbi',3,0,8),('HEAD_H1_TAG_PRODUCTS_ALL','Volledig assortiment met filtermodule',3,0,8),('HEAD_H2_TAG_PRODUCTS_ALL','',3,0,8),('HEAD_H3_TAG_PRODUCTS_ALL','',3,0,8),('HEAD_TITLE_TAG_FEATURED','Selecteer het assortiment van het product',3,0,8),('HEAD_DESC_TAG_FEATURED','We hebben krachtige functies - geselecteerde beste producten voor uw klanten - ecommerce-site: TrueLoaded door Holbi',3,0,8),('HEAD_H1_TAG_FEATURED','geselecteerde module met de beste producten',3,0,8),('HEAD_H2_TAG_FEATURED','',3,0,8),('HEAD_H3_TAG_FEATURED','',3,0,8),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Functionaliteit van productreviews',3,0,8),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',3,0,8),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',3,0,8),('HEAD_TITLE_TAG_CONTACT_US','Neem contact met ons op over het maken van e-commercesites',3,0,8),('HEAD_DESC_TAG_CONTACT_US','Als u vragen heeft, neem dan contact met ons op. E-commerceplatform: TrueLoaded door Holbi',3,0,8),('HEAD_H1_TAG_CONTACT_US','Holbi Europe NL',3,0,8),('HEAD_H2_TAG_CONTACT_US','Nog vragen? Neem contact met ons op\nTrueLoaded door Holbi',3,0,8),('HEAD_H3_TAG_CONTACT_US','GL7 4EU\nUnited Kingdom\nKempsford\nMo - Fr (9:00-18:00)\nOpening hours\nParadise Farm, High street',3,0,8),('HEAD_TITLE_TAG_GIFT_CARD','Cadeaubon kopen',3,0,8),('HEAD_DESC_TAG_GIFT_CARD','Verkoop een cadeaubon aan uw klanten met een ecommerce-site: TrueLoaded door Holbi',3,0,8),('HEAD_H1_TAG_GIFT_CARD','geschenkkaartfunctionaliteit',3,0,8),('HEAD_H2_TAG_GIFT_CARD','',3,0,8),('HEAD_H3_TAG_GIFT_CARD','',3,0,8),('HEAD_TITLE_TAG_WEDDING_REGISTRY','Trouwregister',3,0,8),('HEAD_DESC_TAG_WEDDING_REGISTRY','Bruiloftregistratiemodule instellen voor uw klanten met e-commerceplatform: TrueLoaded door Holbi',3,0,8),('HEAD_H1_TAG_WEDDING_REGISTRY','Huwelijksregistratiemodule',3,0,8),('HEAD_H2_TAG_WEDDING_REGISTRY','',3,0,8),('HEAD_H3_TAG_WEDDING_REGISTRY','',3,0,8),('HEAD_TITLE_TAG_CATEGORY','E-commerce oplossing TrueLoaded - ##CATEGORY_NAME##',3,0,8),('HEAD_DESC_TAG_CATEGORY','Gebruik krachtig catalogussysteem met e-commerceplatform: TrueLoaded door Holbi. Dit is ##CATEGORY_NAME##.',3,0,8),('HEAD_H1_TAG_CATEGORY','',3,0,8),('HEAD_H2_TAG_CATEGORY','',3,0,8),('HEAD_H3_TAG_CATEGORY','',3,0,8),('HEAD_TITLE_TAG_BRAND','##BRAND_NAME## mogelijk gemaakt door TrueLoaded',3,0,8),('HEAD_DESC_TAG_BRAND','Verkoop je eigen merken zoals: ##BRAND_NAME## aan je klanten via de e-commercesite: TrueLoaded by Holbi',3,0,8),('HEAD_H1_TAG_BRAND','',3,0,8),('HEAD_H2_TAG_BRAND','',3,0,8),('HEAD_H3_TAG_BRAND','',3,0,8),('HEAD_TITLE_TAG_FREE_SAMPLES','Lijst van gratis monsters op de site',3,0,8),('HEAD_DESC_TAG_FREE_SAMPLES','Lijst van al uw gratis monsters met filters hier beschikbaar. Mogelijk gemaakt door e-commerce platform: True Loaded by Holbi',3,0,8),('HEAD_H1_TAG_FREE_SAMPLES','Volledig monstersbereik met filtermodule',3,0,8),('HEAD_H2_TAG_FREE_SAMPLES','',3,0,8),('HEAD_H3_TAG_FREE_SAMPLES','',3,0,8),('HEAD_TITLE_TAG_ALL','',10,0,8),('HEAD_KEY_TAG_ALL','',10,0,8),('HEAD_DESC_TAG_ALL','',10,0,8),('HEAD_TITLE_TAG_DEFAULT','E-Commerce Plattform - TrueLoaded von Holbi Group',10,0,8),('HEAD_KEY_TAG_DEFAULT','',10,0,8),('HEAD_DESC_TAG_DEFAULT','TrueLoaded E-Commerce Plattform von Holbi Group. eCommerce Warenkorb Lösung. E-Commerce Website. TrueLoaded von Holbi',10,0,8),('HEAD_TITLE_TAG_PRODUCT_INFO','E-Commerce-Plattform - ##PRODUCT_NAME## - ##BRAND_NAME##',10,0,8),('HEAD_KEY_TAG_PRODUCT_INFO','',10,0,8),('HEAD_DESC_TAG_PRODUCT_INFO','Verkaufen Sie Ihre Produkte mit E-Commerce-Site: TrueLoaded von Holbi. Dies ist ##PRODUCT_NAME## von ##CATEGORY_NAME##, produziert von ##BRAND_NAME##',10,0,8),('HEAD_TITLE_TAG_WHATS_NEW','Auflistung der neuesten Produkte',10,0,8),('HEAD_KEY_TAG_WHATS_NEW','',10,0,8),('HEAD_DESC_TAG_WHATS_NEW','Sie können das neueste Produkt hier mit E-Commerce-Website finden: TrueLoaded von Holbi',10,0,8),('HEAD_TITLE_TAG_SPECIALS','Auflistung von Specials - Verkauf - Produkte',10,0,8),('HEAD_KEY_TAG_SPECIALS','',10,0,8),('HEAD_DESC_TAG_SPECIALS','Ihre Kunden werden alle Verkäufe auf Ihrer Website sehen, die auf der E-Commerce-Website basieren: TrueLoaded by Holbi',10,0,8),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Lesen Sie, was andere sagen',10,0,8),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',10,0,8),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Produktbewertungen: Lesen Sie, was andere über die Ecommerce-Plattform sagen: TrueLoaded by Holbi',10,0,8),('HEAD_H2_TAG_ALL','',10,0,8),('HEAD_H1_TAG_ALL','',10,0,8),('HEAD_H1_TAG_DEFAULT','E-Commerce Plattform TrueLoaded von Holbi Group',10,0,8),('HEAD_H3_TAG_ALL','',10,0,8),('HEAD_H2_TAG_DEFAULT','',10,0,8),('HEAD_H3_TAG_DEFAULT','',10,0,8),('HEAD_H1_TAG_PRODUCT_INFO','',10,0,8),('HEAD_H2_TAG_PRODUCT_INFO','',10,0,8),('HEAD_H3_TAG_PRODUCT_INFO','',10,0,8),('HEAD_H1_TAG_WHATS_NEW','neueste Produkteigenschaft',10,0,8),('HEAD_H2_TAG_WHATS_NEW','',10,0,8),('HEAD_H3_TAG_WHATS_NEW','',10,0,8),('HEAD_H1_TAG_SPECIALS','Verkaufsfunktion',10,0,8),('HEAD_H2_TAG_SPECIALS','',10,0,8),('HEAD_H3_TAG_SPECIALS','',10,0,8),('HEAD_TITLE_TAG_PRODUCTS_ALL','Auflistung aller Produkte auf der Website',10,0,8),('HEAD_DESC_TAG_PRODUCTS_ALL','Hier finden Sie eine Auflistung aller Produkte mit Filtern. Powered by E-Commerce-Plattform: TrueLoaded von Holbi',10,0,8),('HEAD_H1_TAG_PRODUCTS_ALL','Komplette Produktpalette mit Filtermodul',10,0,8),('HEAD_H2_TAG_PRODUCTS_ALL','',10,0,8),('HEAD_H3_TAG_PRODUCTS_ALL','',10,0,8),('HEAD_TITLE_TAG_FEATURED','Wählen Sie den Produktbereich aus',10,0,8),('HEAD_DESC_TAG_FEATURED','Wir haben eine leistungsstarke Funktion - ausgewählte beste Produkte für Ihre Kunden - E-Commerce-Website: TrueLoaded von Holbi',10,0,8),('HEAD_H1_TAG_FEATURED','ausgewähltes bestes Produktmodul',10,0,8),('HEAD_H2_TAG_FEATURED','',10,0,8),('HEAD_H3_TAG_FEATURED','',10,0,8),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Produkte prüfen Funktionalität',10,0,8),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',10,0,8),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',10,0,8),('HEAD_TITLE_TAG_CONTACT_US','Kontaktieren Sie uns für die Erstellung von E-Commerce-Websites',10,0,8),('HEAD_DESC_TAG_CONTACT_US','Wenn Sie Fragen haben - kontaktieren Sie uns. E-Commerce-Plattform: TrueLoaded von Holbi',10,0,8),('HEAD_H1_TAG_CONTACT_US','HOLBI GROUP LTD DE',10,0,8),('HEAD_H2_TAG_CONTACT_US','Irgendwelche Fragen? kontaktiere uns\nTrueLoaded door Holbi',10,0,8),('HEAD_H3_TAG_CONTACT_US','GL7 4EU\nParadise Farm, High street\nOpening hours\nMo - Fr (9:00-18:00)\nKempsford\nUnited Kingdom',10,0,8),('HEAD_TITLE_TAG_GIFT_CARD','Geschenkkarte kaufen',10,0,8),('HEAD_DESC_TAG_GIFT_CARD','Verkaufen Sie eine Geschenkkarte an Ihre Kunden mit der E-Commerce-Seite: TrueLoaded by Holbi',10,0,8),('HEAD_H1_TAG_GIFT_CARD','Geschenkkartenfunktionalität',10,0,8),('HEAD_H2_TAG_GIFT_CARD','',10,0,8),('HEAD_H3_TAG_GIFT_CARD','',10,0,8),('HEAD_TITLE_TAG_WEDDING_REGISTRY','Hochzeitsliste',10,0,8),('HEAD_DESC_TAG_WEDDING_REGISTRY','Richten Sie für Ihre Kunden ein Hochzeitsregistrierungsmodul mit der Ecommerce-Plattform ein: TrueLoaded by Holbi',10,0,8),('HEAD_H1_TAG_WEDDING_REGISTRY','Hochzeitsregistrierungsmodul',10,0,8),('HEAD_H2_TAG_WEDDING_REGISTRY','',10,0,8),('HEAD_H3_TAG_WEDDING_REGISTRY','',10,0,8),('HEAD_TITLE_TAG_CATEGORY','E-Commerce-Lösung TrueLoaded - ##CATEGORY_NAME##',10,0,8),('HEAD_DESC_TAG_CATEGORY','Verwenden Sie ein leistungsfähiges Katalogsystem mit E-Commerce-Plattform: TrueLoaded von Holbi. Das ist ##CATEGORY_NAME##.',10,0,8),('HEAD_H1_TAG_CATEGORY','',10,0,8),('HEAD_H2_TAG_CATEGORY','',10,0,8),('HEAD_H3_TAG_CATEGORY','',10,0,8),('HEAD_TITLE_TAG_BRAND','##BRAND_NAME## unterstützt von TrueLoaded',10,0,8),('HEAD_DESC_TAG_BRAND','Verkaufen Sie Ihre Marken wie: ##BRAND_NAME## an Ihre Kunden über die E-Commerce-Seite: TrueLoaded by Holbi',10,0,8),('HEAD_H1_TAG_BRAND','',10,0,8),('HEAD_H2_TAG_BRAND','',10,0,8),('HEAD_H3_TAG_BRAND','',10,0,8),('HEAD_TITLE_TAG_FREE_SAMPLES','Auflistung von kostenlosen Proben auf der Website',10,0,8),('HEAD_DESC_TAG_FREE_SAMPLES','Auflistung aller kostenlosen Beispiele mit Filtern hier verfügbar. Powered by E-Commerce-Plattform: True Loaded von Holbi',10,0,8),('HEAD_H1_TAG_FREE_SAMPLES','Voller Probenbereich mit Filtermodul',10,0,8),('HEAD_H2_TAG_FREE_SAMPLES','',10,0,8),('HEAD_H3_TAG_FREE_SAMPLES','',10,0,8),('HEAD_TITLE_TAG_ALL','',11,0,8),('HEAD_KEY_TAG_ALL','',11,0,8),('HEAD_DESC_TAG_ALL','',11,0,8),('HEAD_TITLE_TAG_DEFAULT','Plateforme de commerce électronique - TrueLoaded par Holbi Group',11,0,8),('HEAD_KEY_TAG_DEFAULT','',11,0,8),('HEAD_DESC_TAG_DEFAULT','Plateforme de commerce électronique TrueLoaded du groupe Holbi. Solution de panier eCommerce. Site de commerce électronique. TrueLoaded par Holbi',11,0,8),('HEAD_TITLE_TAG_PRODUCT_INFO','',11,0,8),('HEAD_KEY_TAG_PRODUCT_INFO','',11,0,8),('HEAD_DESC_TAG_PRODUCT_INFO','',11,0,8),('HEAD_TITLE_TAG_WHATS_NEW','Liste des derniers produits',11,0,8),('HEAD_KEY_TAG_WHATS_NEW','',11,0,8),('HEAD_DESC_TAG_WHATS_NEW','Vous pouvez trouver le dernier produit ici avec le site de commerce électronique: TrueLoaded by Holbi',11,0,8),('HEAD_TITLE_TAG_SPECIALS','Liste des promotions - ventes - produits',11,0,8),('HEAD_KEY_TAG_SPECIALS','',11,0,8),('HEAD_DESC_TAG_SPECIALS','Vos clients verront toutes les ventes sur votre site web alimenté par le site de commerce électronique: TrueLoaded par Holbi',11,0,8),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Lisez ce que les autres disent',11,0,8),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',11,0,8),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Avis sur les produits: Lisez ce que les autres disent à propos de la plate-forme de commerce électronique: TrueLoaded by Holbi',11,0,8),('HEAD_H3_TAG_ALL','',11,0,8),('HEAD_H2_TAG_ALL','',11,0,8),('HEAD_H1_TAG_ALL','',11,0,8),('HEAD_H1_TAG_DEFAULT','Plateforme de commerce électronique TrueLoaded par Holbi Group',11,0,8),('HEAD_H2_TAG_DEFAULT','',11,0,8),('HEAD_H3_TAG_DEFAULT','',11,0,8),('HEAD_H1_TAG_PRODUCT_INFO','',11,0,8),('HEAD_H2_TAG_PRODUCT_INFO','',11,0,8),('HEAD_H3_TAG_PRODUCT_INFO','',11,0,8),('HEAD_H1_TAG_WHATS_NEW','dernière caractéristique des produits',11,0,8),('HEAD_H2_TAG_WHATS_NEW','',11,0,8),('HEAD_H3_TAG_WHATS_NEW','',11,0,8),('HEAD_H1_TAG_SPECIALS','Fonction de vente',11,0,8),('HEAD_H2_TAG_SPECIALS','',11,0,8),('HEAD_H3_TAG_SPECIALS','',11,0,8),('HEAD_TITLE_TAG_PRODUCTS_ALL','Liste de tous les produits sur le site',11,0,8),('HEAD_DESC_TAG_PRODUCTS_ALL','Liste de tous vos produits avec des filtres disponibles ici. Propulsé par une plate-forme de commerce électronique: TrueLoaded par Holbi',11,0,8),('HEAD_H1_TAG_PRODUCTS_ALL','Gamme complète de produits avec module de filtres',11,0,8),('HEAD_H2_TAG_PRODUCTS_ALL','',11,0,8),('HEAD_H3_TAG_PRODUCTS_ALL','',11,0,8),('HEAD_TITLE_TAG_FEATURED','Sélectionnez la gamme de produits',11,0,8),('HEAD_DESC_TAG_FEATURED','Nous avons une fonctionnalité puissante - meilleurs produits sélectionnés pour vos clients - site de commerce électronique: TrueLoaded par Holbi',11,0,8),('HEAD_H1_TAG_FEATURED','sélection des meilleurs produits',11,0,8),('HEAD_H2_TAG_FEATURED','',11,0,8),('HEAD_H3_TAG_FEATURED','',11,0,8),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Produits critiques fonctionnalité',11,0,8),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',11,0,8),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',11,0,8),('HEAD_TITLE_TAG_CONTACT_US','',11,0,8),('HEAD_DESC_TAG_CONTACT_US','',11,0,8),('HEAD_H1_TAG_CONTACT_US','',11,0,8),('HEAD_H2_TAG_CONTACT_US','',11,0,8),('HEAD_H3_TAG_CONTACT_US','',11,0,8),('HEAD_TITLE_TAG_GIFT_CARD','',11,0,8),('HEAD_DESC_TAG_GIFT_CARD','',11,0,8),('HEAD_H1_TAG_GIFT_CARD','',11,0,8),('HEAD_H2_TAG_GIFT_CARD','',11,0,8),('HEAD_H3_TAG_GIFT_CARD','',11,0,8),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',11,0,8),('HEAD_DESC_TAG_WEDDING_REGISTRY','',11,0,8),('HEAD_H1_TAG_WEDDING_REGISTRY','',11,0,8),('HEAD_H2_TAG_WEDDING_REGISTRY','',11,0,8),('HEAD_H3_TAG_WEDDING_REGISTRY','',11,0,8),('HEAD_TITLE_TAG_CATEGORY','',11,0,8),('HEAD_DESC_TAG_CATEGORY','',11,0,8),('HEAD_H1_TAG_CATEGORY','',11,0,8),('HEAD_H2_TAG_CATEGORY','',11,0,8),('HEAD_H3_TAG_CATEGORY','',11,0,8),('HEAD_TITLE_TAG_BRAND','',11,0,8),('HEAD_DESC_TAG_BRAND','',11,0,8),('HEAD_H1_TAG_BRAND','',11,0,8),('HEAD_H2_TAG_BRAND','',11,0,8),('HEAD_H3_TAG_BRAND','',11,0,8),('HEAD_TITLE_TAG_FREE_SAMPLES','',11,0,8),('HEAD_DESC_TAG_FREE_SAMPLES','',11,0,8),('HEAD_H1_TAG_FREE_SAMPLES','',11,0,8),('HEAD_H2_TAG_FREE_SAMPLES','',11,0,8),('HEAD_H3_TAG_FREE_SAMPLES','',11,0,8),('HEAD_TITLE_TAG_ALL','',12,0,8),('HEAD_KEY_TAG_ALL','',12,0,8),('HEAD_DESC_TAG_ALL','',12,0,8),('HEAD_TITLE_TAG_DEFAULT','E-handel plattform - TrueLoaded av Holbi Group',12,0,8),('HEAD_KEY_TAG_DEFAULT','',12,0,8),('HEAD_DESC_TAG_DEFAULT','TrueLoaded E-handelsplattform fra Holbi Group. e-handel handlekurv løsning. E-handel nettsted. TrueLoaded av Holbi',12,0,8),('HEAD_TITLE_TAG_PRODUCT_INFO','',12,0,8),('HEAD_KEY_TAG_PRODUCT_INFO','',12,0,8),('HEAD_DESC_TAG_PRODUCT_INFO','',12,0,8),('HEAD_TITLE_TAG_WHATS_NEW','Oppføring av nyeste produkter',12,0,8),('HEAD_KEY_TAG_WHATS_NEW','',12,0,8),('HEAD_DESC_TAG_WHATS_NEW','Du kan finne det nyeste produktet her med e-handel nettsted: TrueLoaded av Holbi',12,0,8),('HEAD_TITLE_TAG_SPECIALS','Oppføring av tilbud - salgsprodukter',12,0,8),('HEAD_KEY_TAG_SPECIALS','',12,0,8),('HEAD_DESC_TAG_SPECIALS','Dine kunder vil se alt salg på nettstedet ditt drevet av e-handelsnettsted: TrueLoaded av Holbi',12,0,8),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Les hva andre sier',12,0,8),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',12,0,8),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Produktanmeldelser: Les hva andre sier om E-handel plattform: TrueLoaded av Holbi',12,0,8),('HEAD_H3_TAG_ALL','',12,0,8),('HEAD_H2_TAG_ALL','',12,0,8),('HEAD_H1_TAG_ALL','',12,0,8),('HEAD_H1_TAG_DEFAULT','E-handel plattform TrueLoaded av Holbi Group',12,0,8),('HEAD_H2_TAG_DEFAULT','',12,0,8),('HEAD_H3_TAG_DEFAULT','',12,0,8),('HEAD_H1_TAG_PRODUCT_INFO','',12,0,8),('HEAD_H2_TAG_PRODUCT_INFO','',12,0,8),('HEAD_H3_TAG_PRODUCT_INFO','',12,0,8),('HEAD_H1_TAG_WHATS_NEW','nyeste produktfunksjonen',12,0,8),('HEAD_H2_TAG_WHATS_NEW','',12,0,8),('HEAD_H3_TAG_WHATS_NEW','',12,0,8),('HEAD_H1_TAG_SPECIALS','Salgsfunksjon',12,0,8),('HEAD_H2_TAG_SPECIALS','',12,0,8),('HEAD_H3_TAG_SPECIALS','',12,0,8),('HEAD_TITLE_TAG_PRODUCTS_ALL','Oppføring av alle produkter på nettstedet',12,0,8),('HEAD_DESC_TAG_PRODUCTS_ALL','Oppføring av alt ditt produkt med filtre tilgjengelig her. Drevet av e-handelsplattform: TrueLoaded av Holbi',12,0,8),('HEAD_H1_TAG_PRODUCTS_ALL','Fullt produktsortiment med filtermodul',12,0,8),('HEAD_H2_TAG_PRODUCTS_ALL','',12,0,8),('HEAD_H3_TAG_PRODUCTS_ALL','',12,0,8),('HEAD_TITLE_TAG_FEATURED','Velg produktets utvalg',12,0,8),('HEAD_DESC_TAG_FEATURED','Vi har en kraftig funksjon - utvalgte beste produkter for kundene dine - e-handelsside: TrueLoaded av Holbi',12,0,8),('HEAD_H1_TAG_FEATURED','valgt beste produktmodul',12,0,8),('HEAD_H2_TAG_FEATURED','',12,0,8),('HEAD_H3_TAG_FEATURED','',12,0,8),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Produktomtaler funksjonalitet',12,0,8),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',12,0,8),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',12,0,8),('HEAD_TITLE_TAG_CONTACT_US','',12,0,8),('HEAD_DESC_TAG_CONTACT_US','',12,0,8),('HEAD_H1_TAG_CONTACT_US','',12,0,8),('HEAD_H2_TAG_CONTACT_US','',12,0,8),('HEAD_H3_TAG_CONTACT_US','',12,0,8),('HEAD_TITLE_TAG_GIFT_CARD','',12,0,8),('HEAD_DESC_TAG_GIFT_CARD','',12,0,8),('HEAD_H1_TAG_GIFT_CARD','',12,0,8),('HEAD_H2_TAG_GIFT_CARD','',12,0,8),('HEAD_H3_TAG_GIFT_CARD','',12,0,8),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',12,0,8),('HEAD_DESC_TAG_WEDDING_REGISTRY','',12,0,8),('HEAD_H1_TAG_WEDDING_REGISTRY','',12,0,8),('HEAD_H2_TAG_WEDDING_REGISTRY','',12,0,8),('HEAD_H3_TAG_WEDDING_REGISTRY','',12,0,8),('HEAD_TITLE_TAG_CATEGORY','',12,0,8),('HEAD_DESC_TAG_CATEGORY','',12,0,8),('HEAD_H1_TAG_CATEGORY','',12,0,8),('HEAD_H2_TAG_CATEGORY','',12,0,8),('HEAD_H3_TAG_CATEGORY','',12,0,8),('HEAD_TITLE_TAG_BRAND','',12,0,8),('HEAD_DESC_TAG_BRAND','',12,0,8),('HEAD_H1_TAG_BRAND','',12,0,8),('HEAD_H2_TAG_BRAND','',12,0,8),('HEAD_H3_TAG_BRAND','',12,0,8),('HEAD_TITLE_TAG_FREE_SAMPLES','',12,0,8),('HEAD_DESC_TAG_FREE_SAMPLES','',12,0,8),('HEAD_H1_TAG_FREE_SAMPLES','',12,0,8),('HEAD_H2_TAG_FREE_SAMPLES','',12,0,8),('HEAD_H3_TAG_FREE_SAMPLES','',12,0,8),('HEAD_TITLE_TAG_ALL','',13,0,8),('HEAD_KEY_TAG_ALL','',13,0,8),('HEAD_DESC_TAG_ALL','',13,0,8),('HEAD_TITLE_TAG_DEFAULT','Piattaforma di e-commerce - TrueLoaded di Holbi Group',13,0,8),('HEAD_KEY_TAG_DEFAULT','',13,0,8),('HEAD_DESC_TAG_DEFAULT','Piattaforma di e-commerce TrueLoaded di Holbi Group. soluzione di eCommerce Shopping Cart. Sito e-commerce TrueLoaded di Holbi',13,0,8),('HEAD_TITLE_TAG_PRODUCT_INFO','',13,0,8),('HEAD_KEY_TAG_PRODUCT_INFO','',13,0,8),('HEAD_DESC_TAG_PRODUCT_INFO','',13,0,8),('HEAD_TITLE_TAG_WHATS_NEW','Elenco degli ultimi prodotti',13,0,8),('HEAD_KEY_TAG_WHATS_NEW','',13,0,8),('HEAD_DESC_TAG_WHATS_NEW','Puoi trovare l\'ultimo prodotto qui con il sito web di e-commerce: TrueLoaded di Holbi',13,0,8),('HEAD_TITLE_TAG_SPECIALS','Elenco di offerte speciali - vendite - prodotti',13,0,8),('HEAD_KEY_TAG_SPECIALS','',13,0,8),('HEAD_DESC_TAG_SPECIALS','I tuoi clienti vedranno tutte le vendite sul tuo sito web supportate dal sito di e-commerce: TrueLoaded by Holbi',13,0,8),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Leggi cosa dicono gli altri',13,0,8),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',13,0,8),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Recensioni dei prodotti: leggi cosa dicono gli altri sulla piattaforma di e-commerce: TrueLoaded by Holbi',13,0,8),('HEAD_H3_TAG_ALL','',13,0,8),('HEAD_H2_TAG_ALL','',13,0,8),('HEAD_H1_TAG_ALL','',13,0,8),('HEAD_H1_TAG_DEFAULT','Piattaforma di e-commerce TrueLoaded di Holbi Group',13,0,8),('HEAD_H2_TAG_DEFAULT','',13,0,8),('HEAD_H3_TAG_DEFAULT','',13,0,8),('HEAD_H1_TAG_PRODUCT_INFO','',13,0,8),('HEAD_H2_TAG_PRODUCT_INFO','',13,0,8),('HEAD_H3_TAG_PRODUCT_INFO','',13,0,8),('HEAD_H1_TAG_WHATS_NEW','ultima funzionalità dei prodotti',13,0,8),('HEAD_H2_TAG_WHATS_NEW','',13,0,8),('HEAD_H3_TAG_WHATS_NEW','',13,0,8),('HEAD_H1_TAG_SPECIALS','Caratteristica di vendita',13,0,8),('HEAD_H2_TAG_SPECIALS','',13,0,8),('HEAD_H3_TAG_SPECIALS','',13,0,8),('HEAD_TITLE_TAG_PRODUCTS_ALL','Elenco di tutti i prodotti sul sito',13,0,8),('HEAD_DESC_TAG_PRODUCTS_ALL','Elenco di tutti i tuoi prodotti con filtri disponibili qui. Basato sulla piattaforma di e-commerce: TrueLoaded di Holbi',13,0,8),('HEAD_H1_TAG_PRODUCTS_ALL','Gamma completa di prodotti con modulo filtri',13,0,8),('HEAD_H2_TAG_PRODUCTS_ALL','',13,0,8),('HEAD_H3_TAG_PRODUCTS_ALL','',13,0,8),('HEAD_TITLE_TAG_FEATURED','Seleziona la gamma del prodotto',13,0,8),('HEAD_DESC_TAG_FEATURED','Abbiamo una potente funzionalità: i migliori prodotti selezionati per i tuoi clienti: sito di e-commerce: TrueLoaded by Holbi',13,0,8),('HEAD_H1_TAG_FEATURED','selezionato il miglior prodotto modulo',13,0,8),('HEAD_H2_TAG_FEATURED','',13,0,8),('HEAD_H3_TAG_FEATURED','',13,0,8),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Funzionalità di recensioni di prodotti',13,0,8),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',13,0,8),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',13,0,8),('HEAD_TITLE_TAG_CONTACT_US','',13,0,8),('HEAD_DESC_TAG_CONTACT_US','',13,0,8),('HEAD_H1_TAG_CONTACT_US','',13,0,8),('HEAD_H2_TAG_CONTACT_US','',13,0,8),('HEAD_H3_TAG_CONTACT_US','',13,0,8),('HEAD_TITLE_TAG_GIFT_CARD','',13,0,8),('HEAD_DESC_TAG_GIFT_CARD','',13,0,8),('HEAD_H1_TAG_GIFT_CARD','',13,0,8),('HEAD_H2_TAG_GIFT_CARD','',13,0,8),('HEAD_H3_TAG_GIFT_CARD','',13,0,8),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',13,0,8),('HEAD_DESC_TAG_WEDDING_REGISTRY','',13,0,8),('HEAD_H1_TAG_WEDDING_REGISTRY','',13,0,8),('HEAD_H2_TAG_WEDDING_REGISTRY','',13,0,8),('HEAD_H3_TAG_WEDDING_REGISTRY','',13,0,8),('HEAD_TITLE_TAG_CATEGORY','',13,0,8),('HEAD_DESC_TAG_CATEGORY','',13,0,8),('HEAD_H1_TAG_CATEGORY','',13,0,8),('HEAD_H2_TAG_CATEGORY','',13,0,8),('HEAD_H3_TAG_CATEGORY','',13,0,8),('HEAD_TITLE_TAG_BRAND','',13,0,8),('HEAD_DESC_TAG_BRAND','',13,0,8),('HEAD_H1_TAG_BRAND','',13,0,8),('HEAD_H2_TAG_BRAND','',13,0,8),('HEAD_H3_TAG_BRAND','',13,0,8),('HEAD_TITLE_TAG_FREE_SAMPLES','',13,0,8),('HEAD_DESC_TAG_FREE_SAMPLES','',13,0,8),('HEAD_H1_TAG_FREE_SAMPLES','',13,0,8),('HEAD_H2_TAG_FREE_SAMPLES','',13,0,8),('HEAD_H3_TAG_FREE_SAMPLES','',13,0,8),('HEAD_TITLE_TAG_ALL','',15,0,8),('HEAD_KEY_TAG_ALL','',15,0,8),('HEAD_DESC_TAG_ALL','',15,0,8),('HEAD_TITLE_TAG_DEFAULT','Електронна комерційна платформа - TrueLoaded від Holbi Group',15,0,8),('HEAD_KEY_TAG_DEFAULT','',15,0,8),('HEAD_DESC_TAG_DEFAULT','TrueLoaded Електронна комерційна платформа від Holbi Group. Рішення для кошика для електронної комерції. Сайт електронної комерції. TrueLoaded від Holbi',15,0,8),('HEAD_TITLE_TAG_PRODUCT_INFO','',15,0,8),('HEAD_KEY_TAG_PRODUCT_INFO','',15,0,8),('HEAD_DESC_TAG_PRODUCT_INFO','',15,0,8),('HEAD_TITLE_TAG_WHATS_NEW','Перелік останніх продуктів',15,0,8),('HEAD_KEY_TAG_WHATS_NEW','',15,0,8),('HEAD_DESC_TAG_WHATS_NEW','Ви можете знайти новітній продукт на сайті електронної комерції: TrueLoaded by Holbi',15,0,8),('HEAD_TITLE_TAG_SPECIALS','Перелік спеціальних продуктів- продаж - продуки',15,0,8),('HEAD_KEY_TAG_SPECIALS','',15,0,8),('HEAD_DESC_TAG_SPECIALS','Ваші клієнти будуть бачити всі розпродажі вашого сайту на сайті електронної комерції: TrueLoaded by Holbi',15,0,8),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Прочитайте, що говорять інші',15,0,8),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',15,0,8),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Огляд продуктів: прочитайте, що говорять інші про платформу платформі електронної комерції: TrueLoaded by Holbi',15,0,8),('HEAD_H2_TAG_ALL','',15,0,8),('HEAD_H1_TAG_ALL','',15,0,8),('HEAD_H3_TAG_ALL','',15,0,8),('HEAD_H1_TAG_DEFAULT','Електронна комерційна платформа TrueLoaded від Holbi Group',15,0,8),('HEAD_H2_TAG_DEFAULT','',15,0,8),('HEAD_H3_TAG_DEFAULT','',15,0,8),('HEAD_H1_TAG_PRODUCT_INFO','',15,0,8),('HEAD_H2_TAG_PRODUCT_INFO','',15,0,8),('HEAD_H3_TAG_PRODUCT_INFO','',15,0,8),('HEAD_H1_TAG_WHATS_NEW','найновіші продукти',15,0,8),('HEAD_H2_TAG_WHATS_NEW','',15,0,8),('HEAD_H3_TAG_WHATS_NEW','',15,0,8),('HEAD_H1_TAG_SPECIALS','Розпродажі',15,0,8),('HEAD_H2_TAG_SPECIALS','',15,0,8),('HEAD_H3_TAG_SPECIALS','',15,0,8),('HEAD_TITLE_TAG_PRODUCTS_ALL','Перелік усіх продуктів на сайті',15,0,8),('HEAD_DESC_TAG_PRODUCTS_ALL','Перелік усіх ваших продуктів із фільтрами доступний тут. Працює на платформі електронної комерції: TrueLoaded by Holbi',15,0,8),('HEAD_H1_TAG_PRODUCTS_ALL','Повний асортимент продукції з модулем фільтрів',15,0,8),('HEAD_H2_TAG_PRODUCTS_ALL','',15,0,8),('HEAD_H3_TAG_PRODUCTS_ALL','',15,0,8),('HEAD_TITLE_TAG_FEATURED','Виберіть діапазон продукту',15,0,8),('HEAD_DESC_TAG_FEATURED','У нас є просунуті функції - вибрані кращі продукти для ваших клієнтів - сайт електронної комерції: TrueLoaded by Holbi',15,0,8),('HEAD_H1_TAG_FEATURED','модуль для вибору кращих продуктів',15,0,8),('HEAD_H2_TAG_FEATURED','',15,0,8),('HEAD_H3_TAG_FEATURED','',15,0,8),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Функціональність огляду продуктів',15,0,8),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',15,0,8),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',15,0,8),('HEAD_TITLE_TAG_CONTACT_US','',15,0,8),('HEAD_DESC_TAG_CONTACT_US','',15,0,8),('HEAD_H1_TAG_CONTACT_US','',15,0,8),('HEAD_H2_TAG_CONTACT_US','',15,0,8),('HEAD_H3_TAG_CONTACT_US','',15,0,8),('HEAD_TITLE_TAG_GIFT_CARD','',15,0,8),('HEAD_DESC_TAG_GIFT_CARD','',15,0,8),('HEAD_H1_TAG_GIFT_CARD','',15,0,8),('HEAD_H2_TAG_GIFT_CARD','',15,0,8),('HEAD_H3_TAG_GIFT_CARD','',15,0,8),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',15,0,8),('HEAD_DESC_TAG_WEDDING_REGISTRY','',15,0,8),('HEAD_H1_TAG_WEDDING_REGISTRY','',15,0,8),('HEAD_H2_TAG_WEDDING_REGISTRY','',15,0,8),('HEAD_H3_TAG_WEDDING_REGISTRY','',15,0,8),('HEAD_TITLE_TAG_CATEGORY','',15,0,8),('HEAD_DESC_TAG_CATEGORY','',15,0,8),('HEAD_H1_TAG_CATEGORY','',15,0,8),('HEAD_H2_TAG_CATEGORY','',15,0,8),('HEAD_H3_TAG_CATEGORY','',15,0,8),('HEAD_TITLE_TAG_BRAND','',15,0,8),('HEAD_DESC_TAG_BRAND','',15,0,8),('HEAD_H1_TAG_BRAND','',15,0,8),('HEAD_H2_TAG_BRAND','',15,0,8),('HEAD_H3_TAG_BRAND','',15,0,8),('HEAD_TITLE_TAG_FREE_SAMPLES','',15,0,8),('HEAD_DESC_TAG_FREE_SAMPLES','',15,0,8),('HEAD_H1_TAG_FREE_SAMPLES','',15,0,8),('HEAD_H2_TAG_FREE_SAMPLES','',15,0,8),('HEAD_H3_TAG_FREE_SAMPLES','',15,0,8),('HEAD_TITLE_TAG_ALL','',17,0,8),('HEAD_KEY_TAG_ALL','',17,0,8),('HEAD_DESC_TAG_ALL','',17,0,8),('HEAD_TITLE_TAG_DEFAULT','Электронная коммерция - TrueLoaded от Holbi Group',17,0,8),('HEAD_KEY_TAG_DEFAULT','',17,0,8),('HEAD_DESC_TAG_DEFAULT','Платформа TrueLoaded для электронной коммерции от Holbi Group. Решение для покупок электронной коммерции. Сайт электронной торговли. TrueLoaded от Holbi',17,0,8),('HEAD_TITLE_TAG_PRODUCT_INFO','',17,0,8),('HEAD_KEY_TAG_PRODUCT_INFO','',17,0,8),('HEAD_DESC_TAG_PRODUCT_INFO','',17,0,8),('HEAD_TITLE_TAG_WHATS_NEW','Список последних продуктов',17,0,8),('HEAD_KEY_TAG_WHATS_NEW','',17,0,8),('HEAD_DESC_TAG_WHATS_NEW','Вы можете найти новейший продукт на сайте электронной коммерции: TrueLoaded by Holbi',17,0,8),('HEAD_TITLE_TAG_SPECIALS','Список специальных продуктов - продажа - продукты',17,0,8),('HEAD_KEY_TAG_SPECIALS','',17,0,8),('HEAD_DESC_TAG_SPECIALS','Ваши клиенты будут видеть все распродажи вашего сайта на сайте электронной коммерции: TrueLoaded by Holbi',17,0,8),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Читайте, что говорят другие',17,0,8),('HEAD_KEY_TAG_PRODUCT_REVIEWS_INFO','',17,0,8),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Обзор продуктов: прочитайте, что говорят другие о платформе платформе электронной коммерции: TrueLoaded by Holbi',17,0,8),('HEAD_H3_TAG_ALL','',17,0,8),('HEAD_H2_TAG_ALL','',17,0,8),('HEAD_H1_TAG_ALL','',17,0,8),('HEAD_H1_TAG_DEFAULT','Электронная коммерция TrueLoaded от Holbi Group',17,0,8),('HEAD_H2_TAG_DEFAULT','',17,0,8),('HEAD_H3_TAG_DEFAULT','',17,0,8),('HEAD_H1_TAG_PRODUCT_INFO','',17,0,8),('HEAD_H2_TAG_PRODUCT_INFO','',17,0,8),('HEAD_H3_TAG_PRODUCT_INFO','',17,0,8),('HEAD_H1_TAG_WHATS_NEW','новейшие продукты',17,0,8),('HEAD_H2_TAG_WHATS_NEW','',17,0,8),('HEAD_H3_TAG_WHATS_NEW','',17,0,8),('HEAD_H1_TAG_SPECIALS','Распродажи',17,0,8),('HEAD_H2_TAG_SPECIALS','',17,0,8),('HEAD_H3_TAG_SPECIALS','',17,0,8),('HEAD_TITLE_TAG_PRODUCTS_ALL','Список всех продуктов на сайте',17,0,8),('HEAD_DESC_TAG_PRODUCTS_ALL','Здесь представлен список всех ваших продуктов с фильтрами. Работает на платформе электронной коммерции: TrueLoaded by Holbi',17,0,8),('HEAD_H1_TAG_PRODUCTS_ALL','Полный ассортимент продукции с модулем фильтров',17,0,8),('HEAD_H2_TAG_PRODUCTS_ALL','',17,0,8),('HEAD_H3_TAG_PRODUCTS_ALL','',17,0,8),('HEAD_TITLE_TAG_FEATURED','Выберите диапазон продукта',17,0,8),('HEAD_DESC_TAG_FEATURED','У нас есть продвинутые функции - выбранные лучшие продукты для ваших клиентов - сайт электронной коммерции: TrueLoaded by Holbi',17,0,8),('HEAD_H1_TAG_FEATURED','модуль для выбора лучших продуктов',17,0,8),('HEAD_H2_TAG_FEATURED','',17,0,8),('HEAD_H3_TAG_FEATURED','',17,0,8),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Функциональность обзора продуктов',17,0,8),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',17,0,8),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',17,0,8),('HEAD_TITLE_TAG_CONTACT_US','',17,0,8),('HEAD_DESC_TAG_CONTACT_US','',17,0,8),('HEAD_H1_TAG_CONTACT_US','',17,0,8),('HEAD_H2_TAG_CONTACT_US','',17,0,8),('HEAD_H3_TAG_CONTACT_US','',17,0,8),('HEAD_TITLE_TAG_GIFT_CARD','',17,0,8),('HEAD_DESC_TAG_GIFT_CARD','',17,0,8),('HEAD_H1_TAG_GIFT_CARD','',17,0,8),('HEAD_H2_TAG_GIFT_CARD','',17,0,8),('HEAD_H3_TAG_GIFT_CARD','',17,0,8),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',17,0,8),('HEAD_DESC_TAG_WEDDING_REGISTRY','',17,0,8),('HEAD_H1_TAG_WEDDING_REGISTRY','',17,0,8),('HEAD_H2_TAG_WEDDING_REGISTRY','',17,0,8),('HEAD_H3_TAG_WEDDING_REGISTRY','',17,0,8),('HEAD_TITLE_TAG_CATEGORY','',17,0,8),('HEAD_DESC_TAG_CATEGORY','',17,0,8),('HEAD_H1_TAG_CATEGORY','',17,0,8),('HEAD_H2_TAG_CATEGORY','',17,0,8),('HEAD_H3_TAG_CATEGORY','',17,0,8),('HEAD_TITLE_TAG_BRAND','',17,0,8),('HEAD_DESC_TAG_BRAND','',17,0,8),('HEAD_H1_TAG_BRAND','',17,0,8),('HEAD_H2_TAG_BRAND','',17,0,8),('HEAD_H3_TAG_BRAND','',17,0,8),('HEAD_TITLE_TAG_FREE_SAMPLES','',17,0,8),('HEAD_DESC_TAG_FREE_SAMPLES','',17,0,8),('HEAD_H1_TAG_FREE_SAMPLES','',17,0,8),('HEAD_H2_TAG_FREE_SAMPLES','',17,0,8),('HEAD_H3_TAG_FREE_SAMPLES','',17,0,8),('HEAD_TITLE_TAG_DEFAULT','Platforma e-commerce - TrueLoaded firmy Holbi Group',26,0,8),('HEAD_DESC_TAG_DEFAULT','Platforma TrueLoaded Ecommerce od Holbi Group. Rozwiązanie koszyka e-commerce. Witryna e-commerce. TrueLoaded przez Holbi',26,0,8),('HEAD_H1_TAG_DEFAULT','Platforma e-commerce TrueLoaded firmy Holbi Group',26,0,8),('HEAD_H2_TAG_DEFAULT','',26,0,8),('HEAD_H3_TAG_DEFAULT','',26,0,8),('HEAD_TITLE_TAG_PRODUCTS_ALL','Lista wszystkich produktów na stronie',26,0,8),('HEAD_DESC_TAG_PRODUCTS_ALL','Lista wszystkich produktów z filtrami dostępna tutaj. Obsługiwane przez platformę e-commerce: TrueLoaded by Holbi',26,0,8),('HEAD_H1_TAG_PRODUCTS_ALL','Pełny asortyment produktów z modułem filtrów',26,0,8),('HEAD_H2_TAG_PRODUCTS_ALL','',26,0,8),('HEAD_H3_TAG_PRODUCTS_ALL','',26,0,8),('HEAD_TITLE_TAG_WHATS_NEW','Lista najnowszych produktów',26,0,8),('HEAD_DESC_TAG_WHATS_NEW','Możesz znaleźć najnowszy produkt tutaj ze stroną e-commerce: TrueLoaded by Holbi',26,0,8),('HEAD_H1_TAG_WHATS_NEW','najnowsze funkcje produktów',26,0,8),('HEAD_H2_TAG_WHATS_NEW','',26,0,8),('HEAD_H3_TAG_WHATS_NEW','',26,0,8),('HEAD_TITLE_TAG_SPECIALS','Lista ofert specjalnych - sprzedaż - produkty',26,0,8),('HEAD_DESC_TAG_SPECIALS','Twoi klienci zobaczą całą sprzedaż Twojej witryny internetowej opartą na witrynie e-commerce: TrueLoaded firmy Holbi',26,0,8),('HEAD_H1_TAG_SPECIALS','Funkcja sprzedaży',26,0,8),('HEAD_H2_TAG_SPECIALS','',26,0,8),('HEAD_H3_TAG_SPECIALS','',26,0,8),('HEAD_TITLE_TAG_FEATURED','Wybierz zakres produktu',26,0,8),('HEAD_DESC_TAG_FEATURED','Mamy potężną funkcję - wybrane najlepsze produkty dla Twoich klientów - witrynę e-commerce: TrueLoaded firmy Holbi',26,0,8),('HEAD_H1_TAG_FEATURED','wybrany moduł najlepszych produktów',26,0,8),('HEAD_H2_TAG_FEATURED','',26,0,8),('HEAD_H3_TAG_FEATURED','',26,0,8),('HEAD_TITLE_TAG_PRODUCT_REVIEWS_INFO','Przeczytaj, co mówią inni',26,0,8),('HEAD_DESC_TAG_PRODUCT_REVIEWS_INFO','Recenzje produktów: Przeczytaj, co inni mówią o platformie e-commerce: TrueLoaded by Holbi',26,0,8),('HEAD_H1_TAG_PRODUCT_REVIEWS_INFO','Funkcjonalność recenzji produktów',26,0,8),('HEAD_H2_TAG_PRODUCT_REVIEWS_INFO','',26,0,8),('HEAD_H3_TAG_PRODUCT_REVIEWS_INFO','',26,0,8),('HEAD_TITLE_TAG_CONTACT_US','',26,0,8),('HEAD_DESC_TAG_CONTACT_US','',26,0,8),('HEAD_H1_TAG_CONTACT_US','',26,0,8),('HEAD_H2_TAG_CONTACT_US','',26,0,8),('HEAD_H3_TAG_CONTACT_US','',26,0,8),('HEAD_TITLE_TAG_GIFT_CARD','',26,0,8),('HEAD_DESC_TAG_GIFT_CARD','',26,0,8),('HEAD_H1_TAG_GIFT_CARD','',26,0,8),('HEAD_H2_TAG_GIFT_CARD','',26,0,8),('HEAD_H3_TAG_GIFT_CARD','',26,0,8),('HEAD_TITLE_TAG_WEDDING_REGISTRY','',26,0,8),('HEAD_DESC_TAG_WEDDING_REGISTRY','',26,0,8),('HEAD_H1_TAG_WEDDING_REGISTRY','',26,0,8),('HEAD_H2_TAG_WEDDING_REGISTRY','',26,0,8),('HEAD_H3_TAG_WEDDING_REGISTRY','',26,0,8),('HEAD_TITLE_TAG_PRODUCT_INFO','',26,0,8),('HEAD_DESC_TAG_PRODUCT_INFO','',26,0,8),('HEAD_H1_TAG_PRODUCT_INFO','',26,0,8),('HEAD_H2_TAG_PRODUCT_INFO','',26,0,8),('HEAD_H3_TAG_PRODUCT_INFO','',26,0,8),('HEAD_TITLE_TAG_CATEGORY','',26,0,8),('HEAD_DESC_TAG_CATEGORY','',26,0,8),('HEAD_H1_TAG_CATEGORY','',26,0,8),('HEAD_H2_TAG_CATEGORY','',26,0,8),('HEAD_H3_TAG_CATEGORY','',26,0,8),('HEAD_TITLE_TAG_BRAND','',26,0,8),('HEAD_DESC_TAG_BRAND','',26,0,8),('HEAD_H1_TAG_BRAND','',26,0,8),('HEAD_H2_TAG_BRAND','',26,0,8),('HEAD_H3_TAG_BRAND','',26,0,8),('HEAD_TITLE_TAG_FREE_SAMPLES','',26,0,8),('HEAD_DESC_TAG_FREE_SAMPLES','',26,0,8),('HEAD_H1_TAG_FREE_SAMPLES','',26,0,8),('HEAD_H2_TAG_FREE_SAMPLES','',26,0,8),('HEAD_H3_TAG_FREE_SAMPLES','',26,0,8),('HEAD_TITLE_TAG_ALL','',26,0,8),('HEAD_DESC_TAG_ALL','',26,0,8),('HEAD_H1_TAG_ALL','',26,0,8),('HEAD_H2_TAG_ALL','',26,0,8),('HEAD_H3_TAG_ALL','',26,0,8);
/*!40000 ALTER TABLE `meta_tags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `migration`
--

DROP TABLE IF EXISTS `migration`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `migration` (
  `version` varchar(180) NOT NULL,
  `apply_time` int(11) DEFAULT NULL,
  PRIMARY KEY (`version`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `migration`
--

LOCK TABLES `migration` WRITE;
/*!40000 ALTER TABLE `migration` DISABLE KEYS */;
INSERT INTO `migration` VALUES ('common\\extensions\\CronScheduler\\migrations\\m200124_100718_cron_scheduler',1580223800),('common\\extensions\\ProductDesigner\\migrations\\m191211_173146_product_design_gallery',1577116847),('common\\extensions\\ProductDesigner\\migrations\\m200107_130725_pdg_field_primary',1578679583),('common\\extensions\\ShippingCarrierPick\\migrations\\M190508113034Init',1559908757),('m000000_000000_base',1528895516),('m180403_134513_io_init',1642079614),('m180525_105259_add_default_supplier',1528895520),('m180525_120012_add_supplier_to_warehouse_products',1528895520),('m180531_093047_warehouses_products_reindex',1528895520),('m180601_160033_add_supplier_delivery_time',1528895521),('m180604_141050_add_supplier_custom_fields',1528895521),('m180611_082636_status_to_competitors_products',1531833794),('m180611_144117_avatar_to_vedding_registry',1531833794),('m180619_130417_market_place_field',1531833794),('m180628_123218_bundles_use_set_price',1531833794),('m180710_120723_new_admin_messages',1531833794),('m180809_102019_add_currency_to_supplier',1537281868),('m180810_153935_add_status_to_supplier_products',1537281868),('m180815_143219_email_password_for_supplier',1537281868),('m180817_150138_add_ean_asin_to_suuplier_product',1537281869),('m180904_092411_suppliers_currencies',1537281869),('m180910_163359_address_format_title',1547560009),('m180913_143622_order_manager_storage',1547560009),('m181025_101617_add_platform_settings',1541431807),('m181026_091939_rename_affilifate_id_to_platform_id',1541431807),('m181029_140117_order_comment_template',1541431807),('m181101_145241_support_system',1542297173),('m181107_142809_order_comment_template_upd',1541772009),('m181113_104513_supplier_auto_price',1545056096),('m181210_160024_inventory_tax_class',1545056096),('m181212_103011_db_indexes_properties_n_inventory',1545056096),('m181213_132418_admin_shopping_cart_checkout_details',1547560009),('m181218_100911_ordered_products_report',1545212267),('m181219_125049_orders_products_status_basic',1547560010),('m181225_143811_orders_products_allocate',1547560010),('m190208_100323_orders_transactions',1550159690),('m190215_153356_orders_splinters',1550509627),('m190219_163851_zone_table_except',1550660208),('m190220_091830_redesign_splinters',1551105592),('m190220_100434_warehouse_additional_shipping_charge',1550660208),('m190226_131022_promo_assignement',1551441189),('m190313_163549_create_table_currently_viewing',1552663277),('m190313_205715_speedup',1556885018),('m190315_171404_available_at_warehouses',1553002490),('m190318_090359_products_settings',1553002490),('m190320_095251_transaction_translations',1553090117),('m190328_123503_seo_redirect_code',1554797562),('m190401_122239_dashboard_search_product_translation',1554797562),('m190401_124635_sub_products',1554797563),('m190402_121503_add_newsletter_config',1554797563),('m190402_150858_contact_email',1554797563),('m190403_194321_create_categories_platform_settings_table',1554797563),('m190405_101022_extensions_configuration',1554797563),('m190405_121506_category_image_3',1554797563),('m190409_154347_create_plain_products_name_search_table',1556885018),('m190412_093917_products_notes',1555075029),('m190412_110015_landing_email',1555075029),('m190416_162102_platform_api_site_access',1555771225),('m190417_120944_sub_product_update',1555771225),('m190420_094142_payment_order_status',1556885018),('m190422_101144_mailer_transport',1556885018),('m190422_162454_setup_order_status_bind',1556885018),('m190423_140127_user_group_restrict_update',1556885018),('m190424_155803_stock_history_for_related',1556885019),('m190503_111555_sub_products_status_switch',1556885020),('m190506_112111_backend_products_name_format',1557839028),('m190513_082357_speedup_cart',1557839028),('m190513_144547_create_banners_groups_table',1558450451),('m190513_145830_extend_weight_column',1557839030),('m190513_155623_nova_poshta',1557839030),('m190514_183411_admin_too_many_images_for_inventory',1558360239),('m190516_140355_create_banners_groups_images_table',1558450451),('m190521_111155_speedup_admin',1559908757),('m190524_093427_order_label_update',1559908757),('m190524_135457_product_image_resolutions',1559908757),('m190527_061503_geo_zone_with_postcodes',1559908757),('m190529_120508_setting_quote_qty_input',1559908757),('m190603_133010_terms_widget',1559908757),('m190606_122443_pay_order_on_widgets',1559908758),('m190607_131017_confirm_and_pay_button',1560519019),('m190614_091713_wedding_translate',1560519019),('m190617_100606_add_order_invoice_comment',1561122191),('m190626_160919_sub_product_update',1562771688),('m190628_181542_share_shopping_cart_config',1562771688),('m190702_161553_preview_link',1562771688),('m190704_183344_quote_skip_shipping',1562771688),('m190708_141039_print_order',1562771688),('m190708_181728_orders_export',1564476168),('m190710_092117_category_image_sizes',1562771688),('m190710_162555_ep_link_orders_guid',1564476168),('m190711_161115_product_source',1564476168),('m190712_114531_product_source_update',1564476169),('m190712_133519_brand_image_sizes',1564476169),('m190712_192031_sub_product_update',1564476169),('m190714_213527_bundle_volume',1564476169),('m190715_095900_page_settings',1564476169),('m190715_132332_purchase_orders',1564476169),('m190715_143651_paypal_txn_up',1564476170),('m190716_151738_sub_product_update',1564476170),('m190718_150807_settings_quote_price',1564476170),('m190719_102644_cloud_printers',1564476170),('m190721_134404_global_payments_transactions',1566999382),('m190723_115016_theme_settings',1564476170),('m190724_121830_ep_orders_link_primary',1564476170),('m190724_132050_product_backorder',1564476170),('m190726_125125_product_dimension',1564476170),('m190729_152228_ep_order_issues_update',1564476170),('m190729_163823_promotion_set_up',1566313821),('m190801_110108_ordered_products_report_options',1566313821),('m190802_101042_add_cloud_printer_documents',1566313821),('m190805_132602_webp_images',1566313821),('m190805_172634_search_suggest_sort_blocks_config',1566313821),('m190806_145816_ep_run_freaquency',1566313821),('m190807_104043_sales_person',1566313821),('m190808_140356_create_table_payment_tokens',1566313821),('m190812_092040_payment_tokens_update',1566313821),('m190814_090551_social_links',1566313822),('m190815_100255_organization_data',1566313822),('m190816_170212_quick_order_update',1566313822),('m190821_100224_add_promo_group_limit',1584628951),('m190821_195458_global_po',1566999382),('m190822_164407_design_text',1567087720),('m190828_092848_platform_logo',1566999382),('m190829_104405_platform_logo',1567087720),('m190830_123328_promo_update_multidiscount',1567176429),('m190902_114613_frontend_translation',1568900851),('m190904_081644_promo_update_keys',1568900851),('m190906_105107_default_token',1568377530),('m190909_100519_cache_control_system',1568900851),('m190910_103407_listing_sorting',1568900851),('m190910_171405_google_base_gtin_update',1568900851),('m190912_115318_sagepay_server_skip_3ds',1569923391),('m190913_192330_admin_onbehalf_payment',1569923391),('m190917_100020_speedup_orders_list',1568900851),('m190917_115115_sagepay_server_api_access',1569923391),('m190918_171834_tax_round_per_row',1568900852),('m190926_102124_change_np_shipping_param',1570121782),('m191001_162146_simple_form',1570121782),('m191002_145558_translation_listings_on_product_info',1570121782),('m191003_140746_link_on_email',1570121782),('m191003_151959_add_qty_personal_catalog',1570723999),('m191004_124701_translations_texts',1570201678),('m191007_121745_recovery_cart_only_subscribed',1570723999),('m191008_152733_minimum_order_qty_widget',1570723999),('m191010_094905_np_warning_messages',1571652068),('m191014_130214_missed_translation',1571652068),('m191016_075938_np_add_cargo_description',1571652068),('m191016_155823_pdf_page_settings',1571652068),('m191018_102723_np_remove_main_configuration',1571652068),('m191023_141357_product_without_inventory',1572382455),('m191024_154358_google_settings',1583399966),('m191024_154951_catalog_pages_prefix_url',1572382455),('m191025_134459_delivery_location_wo_root',1572382455),('m191025_142351_create_seo_delivery_location_crosspages_table',1572441476),('m191028_141430_attributes_percents',1572441476),('m191030_111719_default_option_value',1572441476),('m191030_161848_deliveri_location_added_date',1572898865),('m191031_122054_attributes_templates',1572899142),('m191031_173753_seo_delivery_location_categories',1572898865),('m191105_195410_orders_status_active',1573572301),('m191108_165126_add_props',1573572302),('m191111_143515_add_restrict_to_country',1573572302),('m191112_085226_volume_weight_calculate',1573572303),('m191112_124853_listing_seo_headings',1573572303),('m191112_170902_prev_next_product',1573833070),('m191118_105625_zone_table_checkout_note',1575285664),('m191123_105625_prod_max_order_qty',1575644784),('m191126_102155_pca_choice',1575285664),('m191126_195850_status_group_sort_order',1575285664),('m191129_145858_gift_card_notified',1575644784),('m191129_171222_theme_color',1575285664),('m191202_114209_index_giftwrap_messages',1575644784),('m191203_164055_member_login_sessions_view',1575644784),('m191203_164818_barcode_translations',1575644784),('m191204_125706_activity_marketing_values',1575644784),('m191204_225200_giveaway_page_translations',1575644784),('m191206_100804_vat_number_translations',1576508307),('m191206_200110_coupon_exclude_prod_cat',1578679582),('m191210_150247_postcoder_limit',1576508307),('m191211_180653_PO_translations',1576508307),('m191214_065848_bonus_points_currency',1576508307),('m191216_104013_platforms',1576508307),('m191216_144847_search_suggest_categories',1577116847),('m191217_202437_display_both_prices',1578679582),('m191218_141543_order_map_status',1577116847),('m191218_204915_vat_number_validation',1577116847),('m191223_141345_redirect_to_local',1577116847),('m191224_133610_add_translate_blog',1578679582),('m191224_141853_display_billing_address_first',1578679582),('m191225_185023_default_product_listing_sort_order',1578679582),('m191226_150843_add_translate_blog_widget',1578679582),('m200103_122322_admin_login_log',1578679582),('m200103_143714_add_language_to_customer',1578679582),('m200103_145037_add_blog_widget_translate',1578679582),('m200105_090020_cron_clear_bonus_points',1578679582),('m200108_103359_add_blog_translate_cut',1578679583),('m200108_141812_add_bonus_points_rates_to_customers_group',1579030105),('m200109_095129_product_listin',1579269587),('m200113_115332_add_google_product_types_for_categories',1583399968),('m200113_150940_postcoder_searchtype',1579269587),('m200114_131712_transfer_bonus_points_to_credit_amount_in_admin',1579030105),('m200114_155141_suppliers_email_sent_increase',1579030105),('m200120_100005_def_fields_ga',1579611452),('m200121_125858_transfer_bonus_points_translation',1579720320),('m200123_165743_admin_login_session',1580223800),('m200123_175458_add_blog_translate',1580223800),('m200124_181013_admin_device_update',1580223800),('m200127_110619_customer_additional_fields',1580399858),('m200128_111859_platform_please_login',1580223800),('m200128_190029_max_inventory_count',1580288846),('m200130_105036_customer_additionl_fields',1580399858),('m200131_095332_configuration',1581430380),('m200203_144104_add_top_categories_list_phrase',1583399968),('m200210_161310_stock_and_notify',1581430380),('m200211_122730_sorting_translation',1581430381),('m200213_142014_product_data',1581695496),('m200213_195140_review_stars_titles',1581935997),('m200214_113635_platfrom_api_ip_restrict',1581935997),('m200214_115507_add_phone_number_to_shipping_and_billing',1582050861),('m200214_131744_order_widgets',1581695496),('m200218_172928_specials_start_date',1582625050),('m200219_115641_admin_order_editor_text',1582625050),('m200219_200232_specials_transaltion',1583870301),('m200224_151345_subscribe',1582637735),('m200302_130034_featured_types',1583399968),('m200303_154328_bonus_points_change_configuration',1583399968),('m200305_145423_blog_translations',1583422817),('m200309_184301_brands_translation',1583870301),('m200311_165821_brands_all_possible_filters_config',1584628951),('m200319_143140_page_styles',1584713111),('m200320_104750_limit_characters',1585077614),('m200320_133232_translation',1584713111),('m200324_104029_limit_characters',1585077614),('m200324_173629_cart_free_delivery',1585147438),('m200324_194143_seo_redirects_with_get_params',1585147438),('m200325_162722_admin_sms_auth_to_my_store_config',1585169788),('m200401_180000_sort_order_categories_gso_translation',1585767396),('m200403_151539_h_tags_inline',1586350097),('m200407_215656_taxable_trnaslation',1586350097),('m200413_095042_jsonld_product_type',1586862785),('m200413_173737_properties_swatches_and_translation',1586862786),('m200414_100505_password',1586862786),('m200414_150253_fraud',1587404471),('m200415_133222_product_image_field_color',1587404471),('m200416_150552_design_backups',1587404471),('m200417_182634_plain_product_table_name_option_to_config',1587404472),('m200420_072822_property_filters_display_as',1587404472),('m200421_094644_categoris_to_menu',1588086774),('m200423_165204_design_pages',1588086774),('m200426_190826_seo_redirects_regexp',1588086774),('m200427_142115_order_status_group_evaluation_state',1588086775),('m200428_095138_backup',1588086775),('m200428_141029_acl',1588086775),('m200428_201540_blog_seo_update',1588175700),('m200429_095815_blog_tags',1588844151),('m200511_145032_widgets',1589984920),('m200518_185920_featured_start_date',1590055754),('m200519_172749_personal_catalog_wishlist',1590414896),('m200520_152531_specials_types',1590055754),('m200525_093350_delivery_day',1590414897),('m200601_175803_pc_tranlations',1591214177),('m200602_102210_backend_design',1591214177),('m200603_172832_property_filter_by',1591214177),('m200604_103328_sort_product_group_property',1614064693),('m200608_133528_property_filter_steps',1591972088),('m200610_172905_city_link_with_state',1592917672),('m200610_194747_prod_global_sort_translate',1591972088),('m200611_111843_zone_city_postal_codes',1592917672),('m200615_155849_gso_translate',1594031601),('m200618_085524_export_theme',1592917672),('m200618_161234_add_propmo_restriction',1592917672),('m200622_133452_account_title',1592917672),('m200622_155414_batch_selected_translate',1592917672),('m200622_165759_batch_selected_translate',1592917672),('m200625_121912_order_status_update_email',1593181225),('m200626_104231_stock_status_and_term_link',1594031601),('m200630_072731_credit_amount_flag',1594031601),('m200630_091916_order_acl',1594031601),('m200630_125135_gso_categories_translation',1594031601),('m200702_084148_order_owner',1594031601),('m200702_185158_new_products_period',1594031601),('m200703_103915_promo_description_icons_by_lang',1594031602),('m200703_134916_coupon_translation',1594031602),('m200706_140103_buttons_translation',1594048215),('m200707_130223_update_countries_info',1594212566),('m200708_044914_visibility_area_cleanup',1594212566),('m200708_065916_order_reassign',1594212566),('m200708_102711_added_products',1594212566),('m200708_125915_pre_order_stock_indication',1594307448),('m200709_174508_paypal_partner_translation',1595946583),('m200710_075708_meta_tags_product_desc',1596792098),('m200715_082857_promotion_multiple',1594847438),('m200715_125926_password_rules',1595329545),('m200716_175959_personal_wish_translation',1595329545),('m200717_215648_cookie_reaccept_by_info_change',1595946583),('m200720_083516_order_locations',1595329546),('m200720_115834_partially_cancelled_order_status',1595329546),('m200720_163006_password_info',1595329546),('m200722_105101_collection_point_stock_auto_relocate',1595423018),('m200722_143042_promo_translation_sales_icon_restriction',1595431947),('m200723_071745_dashboard',1595946583),('m200723_085119_gdpr',1595946583),('m200724_132511_process_order',1595946583),('m200728_061718_customers_temporary_guest',1595946583),('m200728_074401_collection_points_notify',1595946584),('m200728_122722_customer_acl',1595946584),('m200730_100700_error_403',1596792098),('m200731_071803_product_quantity_units',1599555877),('m200803_120226_two_step_auth',1596792098),('m200803_153800_promotion_stock_indication_restrict',1596792099),('m200804_122310_promotion_additional_css_class',1596792099),('m200805_154532_orders_payment_transaction_full',1596792099),('m200806_101049_orders_delete_history',1596792099),('m200807_082040_collection_points',1596792099),('m200810_134158_groups',1597131876),('m200814_093746_customers_multi_emails',1597409311),('m200817_141042_promotions_sets_qty_each',1598573710),('m200818_153514_paypal_partner_updates',1599555877),('m200820_221348_sage_pay_encrypt_api_access',1598573710),('m200821_100143_add_rma_translations',1614064693),('m200824_141440_add_rma_trans',1598573710),('m200826_105612_payment_transaction_status_update_by_cron',1599555877),('m200827_151910_design',1603104850),('m200831_112634_page_status',1599555878),('m200831_133009_emails_history',1599555878),('m200901_183135_temp_stock_report',1600081910),('m200902_150823_order_payments_assign_credit_notes',1599555878),('m200902_191853_express_buttons_at_checkout_page',1599555878),('m200903_063352_customers_basket',1599555878),('m200903_111219_ext_fraud_address_upgrade',1599555878),('m200903_131058_page_status',1599555878),('m200907_160044_order_product_helper_frontend_constant',1601040894),('m200909_133717_backend_temporary_stock',1600081910),('m200914_062343_zonetable',1600081910),('m200914_105151_product_unit_label',1601040894),('m200918_075940_admin_filters',1601040894),('m200918_123318_add_customer_couponcode_csv_import',1603104851),('m200921_075459_ext_fraud_address_upgrade',1601040894),('m200923_105011_report_products_notify',1601040894),('m200924_063400_products_options_values',1601040894),('m200928_150222_categories_additional_images',1601903379),('m201006_133739_product_video',1603104851),('m201006_174457_ecommerce_tracking_local',1603104851),('m201007_092742_grow_columns_size',1603104851),('m201007_140503_popularity_stats',1603104851),('m201008_131132_backend_orders_search_by_phone',1603104851),('m201013_095312_access_levels',1603104851),('m201014_074221_ext_fraud_address_upgrade',1603104851),('m201014_081752_password_forgotten',1603104851),('m201016_171227_ga_reporting_ecommerce_updates',1603104851),('m201021_093124_packing_slips_summary',1603794370),('m201021_123206_translation_key_max_length',1605174098),('m201021_154641_cron_scheduler_update',1603794370),('m201026_103826_orders_payment',1603794370),('m201027_151107_session_name_for_frontend',1604329863),('m201028_115151_specials_features_status_by_cron',1604329863),('m201029_094452_logger',1604329863),('m201030_150346_product_edit_jump_to_group_product',1605174098),('m201030_163520_promotion_update_label_flag',1605174098),('m201101_124908_fix_promo_personal_gift_translation',1605174098),('m201103_133221_affiliate',1605174098),('m201104_110409_groups',1605174098),('m201104_125516_do_not_anonimize_on_delete',1605174098),('m201105_115707_sales_only_filter',1605174098),('m201109_142108_images',1605174098),('m201110_095755_password_forgotten',1605174098),('m201111_160642_password_forgotten',1605174098),('m201112_144823_specials_disabled',1610438109),('m201115_172607_ep_multi_sheets',1619537826),('m201117_170047_stock_indicator_reset_to_default',1606202538),('m201118_111806_acl',1606202538),('m201118_222208_specials_enabled_manually_no_split_suggest',1610438110),('m201119_151448_top_text',1606202538),('m201123_091203_platforms',1606202539),('m201123_171651_compare',1606202539),('m201123_194023_globalpay_realex_hpp_redirect_link',1614338637),('m201124_151939_coupon_restrict_update',1609839293),('m201125_160655_promotions',1606722275),('m201127_162738_add_depended_products_translation',1606722275),('m201201_110352_special_day',1607100418),('m201201_173552_additional_customer_field',1617874020),('m201202_171516_temp_stock_report_delete_all',1607100418),('m201207_094053_coupon_admin',1607420441),('m201209_110852_delivery_date',1609839293),('m201209_133023_recaptcha',1609839293),('m201211_175458_top_prio_tax_only',1614064693),('m201214_163147_postcoder',1617874020),('m201216_175557_webp_in_emails',1609839293),('m201222_093249_special_day',1609839293),('m201223_141634_additional_customer_field',1617874020),('m210106_113558_groups_commission',1610438110),('m210107_171455_coupons_index',1610438110),('m210108_091746_promotions',1610438110),('m210112_103741_admin_password',1614064693),('m210125_114827_quantity_discount',1614064693),('m210127_162748_promote_sales',1614064693),('m210201_121035_add_unsupported_translation',1614064693),('m210210_150532_skip_top_products_inlists',1614064693),('m210210_193709_subscribers_updates',1615379878),('m210223_132902_default_export_format',1615380802),('m210223_172142_images_with_products_seo_path',1614338637),('m210301_080603_admin',1614591535),('m210301_113018_prod_price_index_dbindexes',1615380802),('m210301_135954_ep_job_structure_update',1615928101),('m210301_143534_ep_product_edit_tab',1615928101),('m210302_140237_subscription',1615379878),('m210302_162256_promos_to_platforms',1615380802),('m210304_145922_ep_link_products_update',1615928101),('m210304_221425_NewslettersToLists',1615379878),('m210311_170008_brand_widget_show_brans_with_active_product',1615928101),('m210315_205130_promo_hide_details_on_depended_products',1615928101),('m210316_112651_menu',1616403946),('m210318_144753_customer_group_admin_edit_price',1616517177),('m210319_212421_promo_tree_only_active_products',1616517177),('m210322_202339_sales_specials_update',1617874020),('m210325_101622_filter_option',1617874020),('m210401_123204_module_restriction_to_platform',1617874020),('m210402_120321_strin_order_number',1617874020),('m210402_130534_admin_login_device_logoff',1617874020),('m210405_111826_stock_limit',1617874021),('m210405_132813_tax_calc_conf_option',1617874021),('m210405_143950_vat_id_formats',1617874021),('m210406_143835_module_restriction_to_platform',1617874021),('m210407_104408_specials_sales_cap_2',1618403337),('m210407_111842_order_price_limit',1617874021),('m210409_110132_facebook_base_feed',1618403337),('m210409_150605_facebook_base_feed_categories',1618403338),('m210412_063307_facebook_feed',1618403338),('m210414_171238_menu_customers_inactive',1618488340),('m210415_111216_admin_login',1618488340),('m210415_171556_order_labels_indexes',1618910006),('m210416_163344_properties_name_alt',1618910006),('m210419_092752_redeem_coupons_idx',1618910006),('m210420_111622_product_group_texts',1620213548),('m210421_185143_sales_main_status',1619537826),('m210422_115145_sales_allow_several_same_date',1619537826),('m210427_051815_sale_specials_ep',1620213548),('m210506_103425_sales_statistics_report_range_translate',1620319505),('m210512_195509_netsuite_conf',1621594861),('m210513_130520_design_boxes_cache',1622021123),('m210513_174053_sales_index',1621594861),('m210518_165431_new_admin_restricted_assign_platform_message',1621594861),('m210521_152439_zone_table_update',1622475132),('m210524_122616_inventory_date_available',1622475132),('m210527_111432_google_settings_index',1622475132),('m210527_140106_payment_error_message',1622475132),('m210528_110219_language_show_admin',1622475132),('m210531_170150_repeat_customer',1622719813),('m210601_141422_settings_multiinventory',1622719813),('m210602_160947_repeat_customer2',1622719813),('m210603_133357_copy_menu',1623403563),('m210603_185306_repeat_customer3',1623403563),('m210607_155832_ups_shipping_label',1626443725),('m210608_094552_customer',1623403563),('m210609_084654_delivery_date',1623403563),('m210610_095323_amazon',1623403563),('m210611_101823_netsuite_translation',1623915056),('m210611_164026_product_copy_translation',1623915056),('m210614_081824_gift_card_info',1623915056),('m210616_093301_collection_points',1623915056),('m210621_145723_customs_fields_eori_etc',1624446415),('m210622_131253_disabled_days',1624446415),('m210623_165813_platforms_to_zones_update',1626443725),('m210623_224608_tax_rates_up_amount',1626443725),('m210624_174520_geo_zone_taxapplicable',1626443726),('m210705_203842_invoice_number_field',1626443891),('m210713_081038_emails_history',1626882710),('m210714_083800_category_banner_group',1626443891),('m210720_100445_recovery_cart',1626882710),('m210721_102501_products_relocate',1627638159),('m210723_120717_coupons',1627638160),('m210728_080859_max_storage_periood_and_cleanup_logs',1627638160),('m210729_124358_menu_builder',1627638160),('m210730_141132_coupons_to_platforms',1629193046),('m210803_132411_extensions',1629193046),('m210805_101755_warehouses_relocate',1629193046),('m210805_115017_menu_builder',1629193046),('m210805_141156_loqate_worldwide',1632490694),('m210809_091537_menu_components',1629193046),('m210811_100144_google_base_attributes_update',1631098863),('m210811_160236_extensions',1629193046),('m210813_115714_outofstock_action',1629193047),('m210813_123623_translate',1629193047),('m210825_112613_two_step_auth_security_key_mask',1629984115),('m210826_112039_translate',1630404987),('m210826_182206_bestsellers_dates_texts',1630404987),('m210828_152602_admin_order_quick_status_filer',1630404987),('m210830_082839_additional_platforms',1630404987),('m210830_093854_extensions',1630404987),('m210901_112039_translate',1631098863),('m210907_134456_suppliers_price_discount',1632131659),('m210907_135555_stocktaking_report_texts',1632131659),('m210908_114304_limited_specials_index',1632131659),('m210909_111258_category_xsell',1632131659),('m210910_085103_banner_svg',1632131660),('m210917_182451_pos_updates',1636710525),('m210924_095932_install',1632490694),('m210924_170303_remove_google_pagespeed',1636042859),('m211004_123313_extensions',1636042859),('m211005_055540_pos_update',1636042859),('m211005_102802_promo_colors',1636042859),('m211006_150825_index_cache',1636042859),('m211011_104900_coupon_flag_single_per_order',1636042859),('m211011_152415_admin_login_error_notify_email_tempalte',1636042859),('m211016_161257_remember_me',1636042859),('m211018_153141_universal_diff_log',1636042859),('m211022_113734_categories_cache',1636557666),('m211027_144454_group_default_landing_page',1636042860),('m211027_183549_pos_translation',1636042860),('m211029_212055_visitor_country_platform',1636710525),('m211101_100858_pos_updates',1636710525),('m211101_110009_page_status_index',1636042860),('m211103_144832_promotion_per_product_sort',1636042860),('m211108_202957_rma_updates',1636710525),('m211110_193615_subscribers_2_opt_in',1636710525),('m211115_115848_quotation',1636983597),('m211115_123727_admin_copy_Attributes_texts',1637863173),('m211116_110517_payment_online_success_status_default',1637070946),('m211117_094625_designer_tables',1637863176),('m211124_150836_quy_more_max',1638437625),('m211201_225757_paypal_partner_update',1640258286),('m211203_085916_designer_timestamp',1640258305),('m211214_173009_paypal_partner_3dsa',1640258305),('m211224_125343_system_check_notification',1642079614),('m220105_155118_shipping_surchase_options',1642079614),('m220105_182945_force_disable_category_products',1642079614),('m220106_105253_force_disable_enable_category_products',1642079614),('m220111_140232_pos_invoice_conf',1642079614),('m220111_185613_paypal_translation',1642079614),('m220112_093027_hooks',1642079614),('m220112_105105_menu_platform_source',1642079614),('m220117_111422_security_update_password_otp',1642520892),('m220117_170035_password_format_changed_text',1642520892),('m220118_133614_system_check_notification_translation',1642520892),('m220120_172252_admin_login_view_invalid',1642773891),('m220122_211813_paypal_partner_texts',1652628650),('m220124_122721_admin_reset_password_secure',1652628652),('m220126_171926_old_password_update',1652628653),('m220201_192723_klarna_finance',1652628653),('m220204_084853_app_store',1652628653),('m220215_102752_install',1652628653),('m220218_095350_chat',1652628654),('m220324_140622_system_update',1652628654),('m220324_172227_klarna_express_texts',1652628654),('m220329_135621_widget_status',1652628655),('m220331_140142_extensions',1652628655),('m220411_120355_search_index',1652628657),('m220419_150209_products',1652628664),('m220425_101405_settings',1652628665),('m220429_083404_contact_to_pages',1652628666),('m220504_113026_whitelist',1652628666),('m220505_105639_supplier_extra_fields',1663763427),('m220505_130224_autologin_doublecheck',1652628666),('m220512_095649_platform_arrange_watermark',1653316212),('m220516_104058_translates',1653316212),('m220520_114403_move_pdfcatalogues_to_extention',1653316212),('m220520_114425_move_communication_to_extention',1653316213),('m220526_152808_admin_app_widget',1654088005),('m220527_102054_translations',1654088006),('m220527_112528_remove_promotions',1653658742),('m220527_124219_install',1654088006),('m220527_150726_them_groups',1654088008),('m220527_210228_del_outdated_paypals',1654088008),('m220528_192534_remove_products_collections',1654022135),('m220530_115123_remove_productsrelocate_and_producttemplates',1654022136),('m220530_115125_remove_customers_basket_and_trustpilot',1654022745),('m220531_101809_move_platform_themes',1654088008),('m220531_170158_xsell_type_code',1654088010),('m220601_124056_sagepay_to_opayo',1654089144),('m220603_075042_acl',1654522014),('m220607_163712_link_nofollow',1655110794),('m220607_203939_paypal_partner_hide_main_button',1655110794),('m220608_152304_remove_ext_quotations',1655093697),('m220608_152314_remove_ext_samples',1655093698),('m220610_120335_locations_sort_order',1656062247),('m220610_222419_edit_price_popup',1655110794),('m220613_042640_remove_trade_form_and_addit_cust_fields',1655110796),('m220614_110232_remove_purchase_orders',1655284462),('m220615_071323_admin',1655284463),('m220615_093731_remove_special_day',1655491381),('m220615_143538_remove_reports',1655491392),('m220616_141629_install',1656062247),('m220617_135704_seo_delivery_location_to_extension',1656062249),('m220620_125717_add_shipping_online_offline',1655730327),('m220620_135513_department',1656062249),('m220621_110348_loqate_rename',1656062249),('m220622_132527_remove_collection_points',1656062250),('m220622_134540_extract_platform_working_timetable',1656062251),('m220623_071644_groups',1656491782),('m220624_074752_remove_old_menus_and_acls',1656064204),('m220624_123312_remove_old_menus_and_acls3',1656513276),('m220627_091808_install',1656491783),('m220627_093605_extract_platform_localization_page',1656491783),('m220628_102717_banners_group',1656491784),('m220628_170337_warehouses_products_layers',1663763427),('m220629_130941_remove_affiliate',1656587618),('m220629_223436_loqate_not_configured_text',1656868460),('m220630_123117_ppp_sagepay_texts_links',1656868460),('m220630_134447_remove_competitors',1656600530),('m220701_081155_remove_products_global_sort',1656868460),('m220704_081807_modules_migrations',1657031168),('m220706_104225_widget_groups',1657120207),('m220706_150538_remove_messages_acl_and_menu',1657120207),('m220707_112928_drop_delivery_location',1657698956),('m220707_135849_remove_google_base',1657698956),('m220707_144426_remove_facebook_base',1657698957),('m220707_161322_translate',1657698957),('m220712_141216_news',1657900012),('m220713_075823_remove_postcoder_and_loqate',1657738885),('m220713_102102_remove_facebook_feed_data',1657900041),('m220714_075402_remove_google_base_data_structures',1657900115),('m220714_083844_remove_google_other',1657900116),('m220714_084301_news',1657900117),('m220714_122812_update_google_analitic',1657900120),('m220715_081238_remove_recover_cart_acl_and_other',1657873586),('m220715_082501_news',1657900120),('m220715_085548_configuration',1657900121),('m220715_100335_admin_menu_newsletter_by_extension_status',1657900122),('m220715_102543_move_google_keyword_to_ext',1657900127),('m220715_111829_email_builder_nesletter_as_Extension',1657900128),('m220715_153941_remove_recovery_cart_not_constant',1657900128),('m220717_123123_modules_edit_platform',1658130345),('m220718_093317_news',1658305397),('m220718_101609_blog_add_rss',1658139555),('m220719_064653_remove_obsolete_and_others',1658216939),('m220719_065956_image_maps',1658305398),('m220719_150410_change_table_modules',1658303197),('m220721_133512_add_index',1659942718),('m220722_145452_edit_image',1659355585),('m220727_095640_supplier_address_fields',1663763427),('m220728_135735_supplier_add_flag',1664204731),('m220805_074648_install',1659954130),('m220806_151620_smtp_mail_update',1659954130),('m220808_183319_remove_promotions_remains',1660571276),('m220809_115039_install',1660571276),('m220810_115020_upd_translations',1660571277),('m220812_133305_smtp_mail_update',1661353032),('m220817_172702_remove_order_journal_acl',1661353032),('m220819_090148_install',1661353032),('m220819_160133_warehouses_products_batches',1663763428),('m220819_181109_remove_translation_keys',1661353032),('m220822_093740_info_and_invoices',1661353033),('m220822_155832_admin_hooks_index',1661353033),('m220823_132646_remove_supplier_priority_remains',1661353033),('m220825_111754_stock_deficit_translation',1661848837),('m220828_083820_add_supplier_sort',1663763428),('m220829_134709_product_stock_popup_translation',1663763428),('m220830_213528_stock_control_text',1663763428),('m220831_132104_stock_deficit_translation',1663763428),('m220831_210444_stock_texts',1663763428),('m220901_111314_styles',1663763428),('m220901_142849_specials_sales_updates',1663763428),('m220902_075330_remove_quotation_stock_ind_and_terms',1663763428),('m220902_095212_install',1663763428),('m220902_123455_translate',1663763428),('m220906_145906_product_supplier_landed_price_changes',1663763428),('m220908_082852_translate',1663763428),('m220912_094538_install',1663763428),('m220912_101943_isbn_setting',1663763428),('m220915_103749_translate',1663763428),('m220916_000909_admin_stock_detail_refresh',1663763428),('m220922_140555_default_sorting',1664204731),('m220926_080507_add_supplier_translation',1664204731),('m220927_182629_add_unique_indexes_for_table_with_language',1666789368),('m220928_154358_admin_hidden_languages_update',1666789368),('m220928_173649_tax_rate_company_number',1666789368),('m220929_165749_country_currency',1666789369),('m220930_150914_fix_copyright_in_backend',1666789369),('m221001_093359_install_errorlogviewer_and_productstemplate',1666789369),('m221003_103215_departments',1666789369),('m221003_193450_revert_copyright',1666789369),('m221007_401315_gift_message',1666789369),('m221013_160540_autologoff_on_checkout_success',1666789369),('m221016_175933_email_refunded_amount',1670422327),('m221017_042146_config_checkout_btn',1666789369),('m221017_054702_reinstall_translation_error_log_viewer',1666789369),('m221017_132017_admin_token_date',1666789369),('m221018_131607_translate_login_on_form',1666789369),('m221019_081031_add_products_price_index',1666789369),('m221019_103845_departments',1666789369),('m221020_154504_company_name_per_tax_rate',1666789369),('m221024_072555_configuration',1666789369),('m221025_121246_remove_old_config_keys',1666789369),('m221025_140007_themes_upd',1666789394),('m221025_150425_remove_separate_shipping_config',1666789394),('m221031_194901_tax_rate_company_Address',1670422327),('m221109_161613_checkout_recalculate_fields',1670422327),('m221109_174108_tmp_orders_admin_controller',1670422327),('m221111_101354_remove_nova_pochta_translations',1670422327),('m221117_115255_pos_restricted_ips',1670422327),('m221123_190553_remove_old_translations_newsletters_subscribers',1670422327),('m221124_143824_translate',1670422327),('m221130_153146_drop_customer_code_config',1670422327),('m221201_151018_add_translate_to_elv',1670422327),('m221202_102514_install',1670422327),('m221204_183128_change_translation_elv',1670422327),('m221204_203334_add_translation_elv_fix',1670422327),('m221205_103313_elv_translation',1670422327),('m221206_191255_add_missed_key_for_ordercontroller',1670422327),('m221207_114721_remove_magelink_ext',1670498938),('m221208_143240_designer',1677071647),('m221212_144859_customers_external_ids_table',1677071647),('m221214_080551_fix_usergroups_menu',1677071647),('m221214_161954_add_translation',1677071647),('m221215_144105_banners',1677071659),('m221215_204555_add_translation_to_elv',1677071659),('m221216_104246_col_in_row_list',1677071662),('m221217_010132_paypal_partner_extra_config_options',1677071662),('m221223_092305_banners',1677071662),('m221226_130941_remove_old_translation_and_config_from_vat_on_order_extension',1677071663),('m221227_113247_deleting_unused_translations_and_configs',1677071663),('m221227_181602_drop_old_connectors',1677071663),('m221228_220552_exact_and_neighbour',1677071663),('m230102_134728_paypal_partner_updates',1677071663),('m230104_140128_banners',1677071663),('m230105_185650_products_price_exc_round',1677071663),('m230106_120153_translate',1677071663),('m230109_102127_max_and_minimum_order_qty',1677071663),('m230109_134925_translate',1677071663),('m230109_162801_drop_unused_competitors_translate',1677071663),('m230111_185439_fix_email_for_forgotten_password',1677071663),('m230112_140521_xsell_backlink_translate',1677071663),('m230116_133307_coupon_free_shipping_update',1677071663),('m230117_153311_paypal_translation',1677071663),('m230118_123112_banners',1677071668),('m230118_153127_account_captcha',1677071671),('m230119_154528_banners',1677071671),('m230120_203604_product_properties_filters_drop_old_config',1677071671),('m230126_171904_personal_catalog',1677071671),('m230129_211109_remove_cron_menu_acl',1677071671),('m230130_231004_paypal_tracking',1677071671),('m230131_195925_merge_customers_ext',1677071671),('m230131_213458_remove_old_wishlist',1677071671),('m230202_162544_delayed_despatch_unused',1677071671),('m230205_125456_banners',1677071672),('m230207_124828_translate',1677071672),('m230207_142440_checkout_logged_customer',1677071672),('m230208_095749_paypal_text_upon_invoice',1677071672),('m230209_113504_support_system',1677071672),('m230209_214241_paypal_updates',1677071672),('m230210_125633_menu_user_groups',1677071672),('m230212_194528_paypal_updates',1677071672),('m230214_091359_designer',1677071672),('m230214_165527_paypal_ux',1677071672),('m230214_183752_delivery_options_ext',1677071672),('m230215_132613_user_groups_restrictions_stock_available',1677071672),('m230215_134433_modules_zero_price',1677071672),('m230216_100305_install',1677071672),('m230216_135830_design',1677071672),('m230217_105317_designer',1677071672),('m230220_093254_banners',1677071672),('m230220_114137_fix_translation_en',1677071672),('m230220_170623_fix_translation_en2',1677071672),('m230221_085943_themes',1677071682),('m230221_094259_paypal_text',1677071682),('m230222_163752_fix_translation_en3',1677515415),('m230227_093502_oscb_settings_inc_ver',1677515415),('m230227_095742_themes_feb_upd',1677515435),('m230227_101417_translations_feb_upd',1677515435),('m230227_194319_upd_new_feb_themes',1677573478),('m230228_075030_fix_banners_upd_files',1677573481),('m230302_073446_remove_banner_group2',1677750893),('m230302_111052_fix_translation_en4',1677771747),('m230302_141937_revert_sms_constants',1677771747),('m230303_183322_fix_translation_en5',1683006408),('m230306_153811_delivery_location_translate',1683006408),('m230307_183107_2level_attribute_selection',1683006408),('m230308_173022_fix_wrong_link_for_login_instead_of_price',1683006408),('m230309_105432_design_table_row',1683006408),('m230313_111506_widget_groups',1683006408),('m230314_153432_resend_code',1683006408),('m230315_125715_skip_cart_page',1683006408),('m230315_161731_fix_translation_en5',1683006408),('m230316_103858_main_styles',1683006408),('m230320_164537_order_status_for_purchase_orders',1683006408),('m230322_143242_update_translation',1683006408),('m230323_074536_install',1683006408),('m230323_115002_fix_translation_en6',1683006408),('m230331_151806_admin_login_otp',1683006408),('m230403_082454_add_placeholders',1683006411),('m230411_150526_design_wizard',1683006411),('m230413_111917_password_forgotten_block_ip',1683006411),('m230413_121603_fix_sorting_translations',1683006411),('m230417_111119_customers_credit_history_index',1683006411),('m230418_123905_export_widgets',1683006411),('m230418_202057_speed_up_themes_flushing',1683006411),('m230419_144324_theme_wizard_log',1683006411),('m230424_083825_registration',1683006411),('m230424_161441_fix_translations_for_email_templates_keys',1683006411),('m230426_132026_fix_theme_style_indexes',1683006420),('m230426_163314_add_placeholders',1683006420),('m230430_181341_add_stock_indication_limit_qty',1683006420),('m230510_141915_add_placeholder',1696445880),('m230510_190235_payment_tokens_texts',1696445880),('m230518_210435_up_cross_translate',1696445880),('m230524_112916_invoice_number_format_drop_old_translation',1696445880),('m230526_105159_delete_extra_groups_translation',1696445880),('m230530_114523_remove_maintenance',1696445881),('m230531_085145_filter_without_images',1696445881),('m230601_104616_add_translate_for_brand',1696445881),('m230601_194613_add_weight_unit',1696445881),('m230604_135935_text_coupons',1696445881),('m230605_111342_fix_furniture_checkout_412',1696445887),('m230606_090219_add_email_address',1696445887),('m230608_114742_multicart_delete_old_translation',1696445887),('m230608_121800_order_quantity_step_delete_old_translation',1696445887),('m230612_161708_remove_old_action_bonus_translations',1696445887),('m230614_122146_notify_products_date_remove_old_translation',1696445887),('m230614_131212_report_products_notify_remove_old_translation',1696445887),('m230621_101221_show_inactive_remove_old_translation',1696445887),('m230621_111024_filescatalog_remove_old_translation',1696445887),('m230621_112859_questionnaire_remove_old_translation',1696445887),('m230621_123824_ep_autoimport_idx',1696445887),('m230628_052714_add_product_model_translation',1696445887),('m230628_142037_category_name_length',1696445888),('m230629_114033_menu_translates',1696445888),('m230629_173816_warehouse_priority_delete_old_translation',1696445888),('m230630_080745_categories_images',1696445888),('m230630_144720_cron_delete_old_translation',1696445888),('m230707_160455_add_translation_for_account_page',1696445888),('m230710_160049_remove_bonus_point_translation',1696445888),('m230711_161326_select_products',1696445888),('m230712_145145_delete_config_key',1696445888),('m230713_085019_message_styles',1696445888),('m230714_135902_remove_old_bonusactions_translations',1696445888),('m230717_212415_module_tokens',1696445888),('m230721_163716_groups_sort_order',1696445888),('m230724_055917_order_translates',1696445889),('m230727_090538_order_translations',1696445889),('m230731_142904_product_identifier_flags',1696445889),('m230801_091937_add_asian_languages',1696445889),('m230801_110343_featured_add_translate',1696445889),('m230804_085614_address',1696445889),('m230808_103013_order_translate',1696445889),('m230809_075221_order_translate',1696445889),('m230809_172247_shipping_carrier_pick_remove_old_translation',1696445889),('m230810_142224_remove_referfriend_remains',1696445889),('m230811_085653_search_settings_update',1696445889),('m230811_154825_groups_products_sets_discount',1696445889),('m230814_092348_add_dbg_consts',1696445889),('m230814_095121_admin_email_login_confirmation_page',1696445889),('m230815_084713_order_translate',1696445889),('m230815_104408_coupon_updates',1696445889),('m230816_132155_search_history',1696445889),('m230816_142130_backend_search_settings_update',1696445889),('m230816_163826_themes_oscomerce',1696445909),('m230818_120111_hide_empty_brands',1696445909),('m230820_181852_add_extension_overwrite_config_translate',1696445909),('m230821_111027_order_translate',1696445909),('m230821_125355_design_changes',1696445909),('m230821_182640_themes_changes',1696445928),('m230823_143022_acl',1696445929),('m230830_232727_search_design',1696445968),('m230906_091349_enlarge_values_field_in_orders_products_attributes',1696445968),('m230906_115705_contact_us_enquiry_template',1696445968),('m230913_081835_translate',1696445968),('m230914_093529_main_styles',1696445968),('m230915_104027_order_is_dropship',1696445968),('m230915_171023_super_login_acl',1696445968),('m230921_102015_currency_numeric_code',1696445968),('m230921_103117_css_version',1696445968),('m230925_104915_add_tax_rates_classes_switch_for_edit_order',1696445968),('m231002_080841_translate',1696445968),('m231003_101116_change_install_warning',1696445968),('m231003_113102_translation_for_categories',1696445968),('m231003_174343_translation_for_categories_fix',1696445968),('m231010_144919_translate',1697187650),('m231011_095359_theme_styles_groups',1713808246),('m231018_094601_virtual_gift_card_model',1713808247),('m231018_114212_fix_old_themes',1713808255),('m231025_132347_speedup_manufacturer_products_idx_for_menu',1713808255),('m231103_095453_main_styles_tabs',1713808255),('m231110_151406_add_coupon_index',1713808255),('m231116_114310_coupon_maximum_amount_lmit',1713808255),('m231127_172641_add_form_expired_message',1713808255),('m231218_151517_subscribers_delete_old_config',1713808255),('m231220_152142_order_customer_billing_email',1713808255),('m231221_110222_add_placeholders',1713808256),('m231222_133418_copy_product_review',1713808256),('m231226_120625_remove_product_price_free',1713808256),('m240103_140120_add_translation',1713808256),('m240116_174229_add_comment_from_reordered',1713808256),('m240129_171650_payment_fee_order_limit',1713808256),('m240130_162517_multi_session',1713808256),('m240206_110508_max_show_attribute_length',1713808256),('m240216_163155_add_label_extra_params',1713808256),('m240216_164642_honeypot_verification',1713808256),('m240216_184210_add_credit_note_const',1713808256),('m240221_163200_socials_new_account_country',1713808256),('m240222_175630_show_order_stats',1713808256),('m240222_220916_texts_from_scart_to_admin',1713808256),('m240304_155549_sale_text_save_product_info',1713808256),('m240313_143541_remove_catalog_pages',1713808256),('m240315_093052_menu_item_settings',1713808256);
/*!40000 ALTER TABLE `migration` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `module_tokens`
--

DROP TABLE IF EXISTS `module_tokens`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `module_tokens` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `class` varchar(64) NOT NULL DEFAULT '',
  `token` text,
  `valid_until` datetime NOT NULL,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `admin_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `idx_class_ids_until` (`class`,`platform_id`,`admin_id`,`valid_until`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `module_tokens`
--

LOCK TABLES `module_tokens` WRITE;
/*!40000 ALTER TABLE `module_tokens` DISABLE KEYS */;
/*!40000 ALTER TABLE `module_tokens` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `modules`
--

DROP TABLE IF EXISTS `modules`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `modules` (
  `module_id` int(11) NOT NULL AUTO_INCREMENT,
  `type` varchar(32) NOT NULL DEFAULT 'extension',
  `code` varchar(128) NOT NULL,
  `version` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `version_db` decimal(15,4) DEFAULT '0.0000',
  `state` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0-not installed,1-installed,2-enabled',
  `installed_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `installed_admin_id` int(11) NOT NULL,
  `changed_time` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `changed_admin_id` int(11) NOT NULL,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`module_id`),
  UNIQUE KEY `type_platform_code` (`type`,`platform_id`,`code`)
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `modules`
--

LOCK TABLES `modules` WRITE;
/*!40000 ALTER TABLE `modules` DISABLE KEYS */;
INSERT INTO `modules` VALUES (1,'extension','OscLink',1.0100,1.0100,0,'2022-07-20 18:52:41',40,'2022-07-20 18:52:48',0,0),(2,'payment','sage_pay_server',0.0001,0.0001,1,'2022-07-24 15:05:27',41,'2022-07-24 15:05:43',0,9),(3,'payment','paypal_express_app',0.0001,0.0001,0,'2022-07-24 15:08:23',41,'2022-07-24 15:08:48',0,9),(4,'extension','ErrorLogViewer',1.0000,1.0000,1,'2022-10-26 14:02:49',0,'2022-10-26 14:02:49',0,0),(5,'extension','StockControl',1.0000,1.0000,0,'2022-10-26 14:04:14',33,'2022-10-26 14:04:14',0,0),(6,'extension','ProductTemplates',0.0001,0.0001,0,'2022-12-08 11:27:11',90,'2022-12-08 11:27:11',0,0);
/*!40000 ALTER TABLE `modules` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `modules_countries`
--

DROP TABLE IF EXISTS `modules_countries`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `modules_countries` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `code` varchar(64) NOT NULL DEFAULT '',
  `countries` text NOT NULL,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=147 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `modules_countries`
--

LOCK TABLES `modules_countries` WRITE;
/*!40000 ALTER TABLE `modules_countries` DISABLE KEYS */;
INSERT INTO `modules_countries` VALUES (1,'liqpay','GBR',1),(2,'ot_paid','',1),(3,'flat','',1),(4,'ot_subtotal','',1),(5,'ot_shipping','',1),(6,'ot_total','',1),(7,'usps','',1),(8,'offline','',1),(9,'ot_gift_wrap','',1),(10,'amazon_payment','',1),(11,'zonetable','',1),(12,'np','',1),(13,'fedex1','',1),(14,'cod','',1),(15,'ot_due','',1),(16,'ot_coupon','',1),(17,'ot_loworderfee','',1),(18,'ot_gv','',1),(19,'ot_shippingfee','',1),(20,'ot_paymentfee','',1),(21,'ot_tax','',1),(22,'rbsworldpay_hosted','',1),(23,'paypalipn','',1),(24,'paypal_express','',1),(25,'ot_refund','',1),(26,'liqpay','GBR',4),(27,'ot_paid','',4),(28,'flat','',4),(29,'ot_subtotal','',4),(30,'ot_shipping','',4),(31,'ot_total','',4),(32,'usps','',4),(33,'offline','',4),(34,'ot_gift_wrap','',4),(35,'amazon_payment','',4),(36,'zonetable','',4),(37,'np','',4),(38,'fedex1','',4),(39,'cod','',4),(40,'ot_due','',4),(41,'ot_coupon','',4),(42,'ot_loworderfee','',4),(43,'ot_gv','',4),(44,'ot_shippingfee','',4),(45,'ot_paymentfee','',4),(46,'ot_tax','',4),(47,'rbsworldpay_hosted','',4),(48,'paypalipn','',4),(49,'paypal_express','',4),(50,'ot_refund','',4),(57,'liqpay','GBR',5),(58,'ot_paid','',5),(59,'flat','',5),(60,'ot_subtotal','',5),(61,'ot_shipping','',5),(62,'ot_total','',5),(63,'usps','',5),(64,'offline','',5),(65,'ot_gift_wrap','',5),(66,'amazon_payment','',5),(67,'zonetable','',5),(68,'np','',5),(69,'fedex1','',5),(70,'cod','',5),(71,'ot_due','',5),(72,'ot_coupon','',5),(73,'ot_loworderfee','',5),(74,'ot_gv','',5),(75,'ot_shippingfee','',5),(76,'ot_paymentfee','',5),(77,'ot_tax','',5),(78,'rbsworldpay_hosted','',5),(79,'paypalipn','',5),(80,'paypal_express','',5),(81,'ot_refund','',5),(88,'liqpay','GBR',6),(89,'ot_paid','',6),(90,'flat','',6),(91,'ot_subtotal','',6),(92,'ot_shipping','',6),(93,'ot_total','',6),(94,'usps','',6),(95,'offline','',6),(96,'ot_gift_wrap','',6),(97,'amazon_payment','',6),(98,'zonetable','',6),(99,'np','',6),(100,'fedex1','',6),(101,'cod','',6),(102,'ot_due','',6),(103,'ot_coupon','',6),(104,'ot_loworderfee','',6),(105,'ot_gv','',6),(106,'ot_shippingfee','',6),(107,'ot_paymentfee','',6),(108,'ot_tax','',6),(109,'rbsworldpay_hosted','',6),(110,'paypalipn','',6),(111,'paypal_express','',6),(112,'ot_refund','',6),(113,'sage_pay_server','',1),(114,'stripe_checkout','',1),(115,'fedex','',1),(116,'flat','',7),(117,'flat','',8),(118,'paypalipn','',8),(119,'cod','',7),(120,'cod','',8),(121,'paypalipn','',7),(122,'cod','',9),(123,'flat','',9),(124,'paypal_partner','',1),(125,'percent','',1),(126,'flat','',10),(127,'zonetable','',10),(128,'percent','',10),(129,'percent','',7),(130,'zonetable','',7),(131,'zonetable','',8),(132,'percent','',8),(133,'percent','',9),(134,'zonetable','',9),(135,'sage_pay_server','',10),(136,'sage_pay_server','',7),(137,'sage_pay_server','',8),(138,'sage_pay_server','',9),(139,'stripe_checkout','',10),(140,'stripe_checkout','',7),(141,'stripe_checkout','',8),(142,'stripe_checkout','',9),(143,'paypal_partner','',10),(144,'paypal_partner','',7),(145,'paypal_partner','',8),(146,'paypal_partner','',9);
/*!40000 ALTER TABLE `modules_countries` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `modules_groups_settings`
--

DROP TABLE IF EXISTS `modules_groups_settings`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `modules_groups_settings` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `code` varchar(64) NOT NULL DEFAULT '',
  `group_list` text NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `modules_groups_settings`
--

LOCK TABLES `modules_groups_settings` WRITE;
/*!40000 ALTER TABLE `modules_groups_settings` DISABLE KEYS */;
/*!40000 ALTER TABLE `modules_groups_settings` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `modules_labels`
--

DROP TABLE IF EXISTS `modules_labels`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `modules_labels` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `code` varchar(64) NOT NULL DEFAULT '',
  `labels_list` text NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `modules_labels`
--

LOCK TABLES `modules_labels` WRITE;
/*!40000 ALTER TABLE `modules_labels` DISABLE KEYS */;
/*!40000 ALTER TABLE `modules_labels` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `modules_migrations`
--

DROP TABLE IF EXISTS `modules_migrations`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `modules_migrations` (
  `migration_id` int(11) NOT NULL AUTO_INCREMENT,
  `type` varchar(32) NOT NULL DEFAULT 'extension',
  `code` varchar(128) NOT NULL,
  `ver_from` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `ver_to` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `classname` varchar(255) NOT NULL,
  `result` text,
  `applied_time` datetime DEFAULT CURRENT_TIMESTAMP,
  `applied_admin_id` int(11) NOT NULL,
  PRIMARY KEY (`migration_id`),
  KEY `code_type` (`code`,`type`),
  KEY `classname` (`classname`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `modules_migrations`
--

LOCK TABLES `modules_migrations` WRITE;
/*!40000 ALTER TABLE `modules_migrations` DISABLE KEYS */;
/*!40000 ALTER TABLE `modules_migrations` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `modules_visibility`
--

DROP TABLE IF EXISTS `modules_visibility`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `modules_visibility` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `code` varchar(64) NOT NULL DEFAULT '',
  `area` text NOT NULL,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `code_idx` (`code`)
) ENGINE=InnoDB AUTO_INCREMENT=147 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `modules_visibility`
--

LOCK TABLES `modules_visibility` WRITE;
/*!40000 ALTER TABLE `modules_visibility` DISABLE KEYS */;
INSERT INTO `modules_visibility` VALUES (1,'usps','admin,pos,shop_order,shop_quote,shop_sample',1),(2,'offline','admin,pos,shop_order,shop_quote,shop_sample',1),(3,'ot_gift_wrap','admin,shop_order,shop_quote,1,2,3,4,5,6',1),(4,'flat','admin,shop_order,shop_quote,shop_sample',1),(5,'amazon_payment','admin,pos,shop_order,shop_quote,shop_sample',1),(6,'zonetable','admin,pos,shop_order,shop_quote,shop_sample',1),(7,'np','admin,pos,shop_order,shop_quote,shop_sample',1),(8,'fedex1','admin,pos,shop_order,shop_quote,shop_sample',1),(9,'ot_subtotal','admin,shop_order,shop_quote,1,2,3,4,5,6',1),(10,'cod','admin,shop_order,shop_quote,shop_sample',1),(11,'ot_paid','admin,shop_order',1),(12,'ot_due','admin,shop_order,shop_quote,shop_sample',1),(13,'ot_coupon','admin,shop_order,shop_quote,1,2,3,4,5,6',1),(14,'ot_loworderfee','admin,shop_order,1,2,3,4,5,6',1),(15,'ot_shipping','admin,shop_order,shop_quote,shop_sample,1,2,3,4,5,6',1),(16,'ot_gv','admin,shop_order,shop_quote,1,2,3,4,5,6',1),(17,'ot_shippingfee','admin,shop_order,shop_quote,shop_sample,1,2,3,4,5,6',1),(18,'ot_paymentfee','admin,shop_order,shop_quote,1,2,3,4,5,6',1),(19,'ot_total','admin,shop_order,shop_quote,shop_sample,1,2,3,4,5,6',1),(20,'ot_tax','admin,shop_order,shop_quote,1,2,3,4,5,6',1),(21,'rbsworldpay_hosted','admin,shop_order,shop_quote,shop_sample',1),(22,'paypalipn','admin,shop_order,shop_quote,shop_sample',1),(23,'paypal_express','admin,shop_order,shop_quote,shop_sample',1),(24,'liqpay','admin,shop_order,shop_quote,shop_sample',1),(25,'ot_refund','admin,shop_order,shop_quote,shop_sample',1),(26,'usps','admin,pos,shop_order,shop_quote,shop_sample',4),(27,'offline','admin,pos,shop_order,shop_quote,shop_sample',4),(28,'ot_gift_wrap','admin,shop_order,shop_quote,1,2,3,4,5,6',4),(29,'flat','admin,shop_order,shop_quote,shop_sample',4),(30,'amazon_payment','admin,pos,shop_order,shop_quote,shop_sample',4),(31,'zonetable','admin,pos,shop_order,shop_quote,shop_sample',4),(32,'np','admin,pos,shop_order,shop_quote,shop_sample',4),(33,'fedex1','admin,pos,shop_order,shop_quote,shop_sample',4),(34,'ot_subtotal','admin,shop_order,shop_quote,1,2,3,4,5,6',4),(35,'cod','admin,shop_order,shop_quote,shop_sample',4),(36,'ot_paid','admin,shop_order',4),(37,'ot_due','admin,shop_order,shop_quote,shop_sample',4),(38,'ot_coupon','admin,shop_order,shop_quote,1,2,3,4,5,6',4),(39,'ot_loworderfee','admin,shop_order,1,2,3,4,5,6',4),(40,'ot_shipping','admin,shop_order,shop_quote,shop_sample,1,2,3,4,5,6',4),(41,'ot_gv','admin,shop_order,shop_quote,1,2,3,4,5,6',4),(42,'ot_shippingfee','admin,shop_order,shop_quote,shop_sample,1,2,3,4,5,6',4),(43,'ot_paymentfee','admin,shop_order,shop_quote,1,2,3,4,5,6',4),(44,'ot_total','admin,shop_order,shop_quote,shop_sample,1,2,3,4,5,6',4),(45,'ot_tax','admin,shop_order,shop_quote,1,2,3,4,5,6',4),(46,'rbsworldpay_hosted','admin,shop_order,shop_quote,shop_sample',4),(47,'paypalipn','admin,shop_order,shop_quote,shop_sample',4),(48,'paypal_express','admin,shop_order,shop_quote,shop_sample',4),(49,'liqpay','admin,shop_order,shop_quote,shop_sample',4),(50,'ot_refund','admin,shop_order,shop_quote,shop_sample',4),(57,'usps','admin,pos,shop_order,shop_quote,shop_sample',5),(58,'offline','admin,pos,shop_order,shop_quote,shop_sample',5),(59,'ot_gift_wrap','admin,shop_order,shop_quote,1,2,3,4,5,6',5),(60,'flat','admin,shop_order,shop_quote,shop_sample',5),(61,'amazon_payment','admin,pos,shop_order,shop_quote,shop_sample',5),(62,'zonetable','admin,pos,shop_order,shop_quote,shop_sample',5),(63,'np','admin,pos,shop_order,shop_quote,shop_sample',5),(64,'fedex1','admin,pos,shop_order,shop_quote,shop_sample',5),(65,'ot_subtotal','admin,shop_order,shop_quote,1,2,3,4,5,6',5),(66,'cod','admin,shop_order,shop_quote,shop_sample',5),(67,'ot_paid','admin,shop_order',5),(68,'ot_due','admin,shop_order,shop_quote,shop_sample',5),(69,'ot_coupon','admin,shop_order,shop_quote,1,2,3,4,5,6',5),(70,'ot_loworderfee','admin,shop_order,1,2,3,4,5,6',5),(71,'ot_shipping','admin,shop_order,shop_quote,shop_sample,1,2,3,4,5,6',5),(72,'ot_gv','admin,shop_order,shop_quote,1,2,3,4,5,6',5),(73,'ot_shippingfee','admin,shop_order,shop_quote,shop_sample,1,2,3,4,5,6',5),(74,'ot_paymentfee','admin,shop_order,shop_quote,1,2,3,4,5,6',5),(75,'ot_total','admin,shop_order,shop_quote,shop_sample,1,2,3,4,5,6',5),(76,'ot_tax','admin,shop_order,shop_quote,1,2,3,4,5,6',5),(77,'rbsworldpay_hosted','admin,shop_order,shop_quote,shop_sample',5),(78,'paypalipn','admin,shop_order,shop_quote,shop_sample',5),(79,'paypal_express','admin,shop_order,shop_quote,shop_sample',5),(80,'liqpay','admin,shop_order,shop_quote,shop_sample',5),(81,'ot_refund','admin,shop_order,shop_quote,shop_sample',5),(88,'usps','admin,pos,shop_order,shop_quote,shop_sample',6),(89,'offline','admin,pos,shop_order,shop_quote,shop_sample',6),(90,'ot_gift_wrap','admin,shop_order,shop_quote,1,2,3,4,5,6',6),(91,'flat','admin,shop_order,shop_quote,shop_sample',6),(92,'amazon_payment','admin,pos,shop_order,shop_quote,shop_sample',6),(93,'zonetable','admin,pos,shop_order,shop_quote,shop_sample',6),(94,'np','admin,pos,shop_order,shop_quote,shop_sample',6),(95,'fedex1','admin,pos,shop_order,shop_quote,shop_sample',6),(96,'ot_subtotal','admin,shop_order,shop_quote,1,2,3,4,5,6',6),(97,'cod','admin,shop_order,shop_quote,shop_sample',6),(98,'ot_paid','admin,shop_order',6),(99,'ot_due','admin,shop_order,shop_quote,shop_sample',6),(100,'ot_coupon','admin,shop_order,shop_quote,1,2,3,4,5,6',6),(101,'ot_loworderfee','admin,shop_order,1,2,3,4,5,6',6),(102,'ot_shipping','admin,shop_order,shop_quote,shop_sample,1,2,3,4,5,6',6),(103,'ot_gv','admin,shop_order,shop_quote,1,2,3,4,5,6',6),(104,'ot_shippingfee','admin,shop_order,shop_quote,shop_sample,1,2,3,4,5,6',6),(105,'ot_paymentfee','admin,shop_order,shop_quote,1,2,3,4,5,6',6),(106,'ot_total','admin,shop_order,shop_quote,shop_sample,1,2,3,4,5,6',6),(107,'ot_tax','admin,shop_order,shop_quote,1,2,3,4,5,6',6),(108,'rbsworldpay_hosted','admin,shop_order,shop_quote,shop_sample',6),(109,'paypalipn','admin,shop_order,shop_quote,shop_sample',6),(110,'paypal_express','admin,shop_order,shop_quote,shop_sample',6),(111,'liqpay','admin,shop_order,shop_quote,shop_sample',6),(112,'ot_refund','admin,shop_order,shop_quote,shop_sample',6),(113,'sage_pay_server','admin,moderator,shop_order,shop_quote,shop_sample',1),(114,'stripe_checkout','admin,moderator,shop_order,shop_quote,shop_sample',1),(115,'fedex','admin,moderator,pos,shop_order,shop_quote,shop_sample',1),(116,'flat','admin,shop_order,shop_quote,shop_sample',7),(117,'flat','admin,shop_order,shop_quote,shop_sample',8),(118,'paypalipn','admin,shop_order,shop_quote,shop_sample',8),(119,'cod','admin,moderator,shop_order,shop_quote,shop_sample',7),(120,'cod','admin,moderator,shop_order,shop_quote,shop_sample',8),(121,'paypalipn','admin,moderator,shop_order,shop_quote,shop_sample',7),(122,'cod','admin,shop_order',9),(123,'flat','admin,shop_order,shop_quote,shop_sample',9),(124,'paypal_partner','admin,shop_order,shop_quote,shop_sample',1),(125,'percent','admin,shop_order,shop_quote,shop_sample',1),(126,'flat','admin,shop_order,shop_quote,shop_sample',10),(127,'zonetable','admin,shop_order,shop_quote,shop_sample',10),(128,'percent','admin,shop_order,shop_quote,shop_sample',10),(129,'percent','admin,shop_order,shop_quote,shop_sample',7),(130,'zonetable','admin,shop_order,shop_quote,shop_sample',7),(131,'zonetable','admin,shop_order,shop_quote,shop_sample',8),(132,'percent','admin,shop_order,shop_quote,shop_sample',8),(133,'percent','admin,shop_order,shop_quote,shop_sample',9),(134,'zonetable','admin,shop_order,shop_quote,shop_sample',9),(135,'sage_pay_server','admin,moderator,shop_order,shop_quote,shop_sample',10),(136,'sage_pay_server','admin,shop_order,shop_quote,shop_sample',7),(137,'sage_pay_server','admin,shop_order,shop_quote,shop_sample',8),(138,'sage_pay_server','admin,moderator,shop_order,shop_quote,shop_sample',9),(139,'stripe_checkout','admin,shop_order,shop_quote,shop_sample',10),(140,'stripe_checkout','admin,shop_order,shop_quote,shop_sample',7),(141,'stripe_checkout','admin,shop_order,shop_quote,shop_sample',8),(142,'stripe_checkout','admin,shop_order,shop_quote,shop_sample',9),(143,'paypal_partner','admin,shop_order,shop_quote,shop_sample',10),(144,'paypal_partner','admin,shop_order,shop_quote,shop_sample',7),(145,'paypal_partner','admin,shop_order,shop_quote,shop_sample',8),(146,'paypal_partner','admin,shop_order,shop_quote,shop_sample',9);
/*!40000 ALTER TABLE `modules_visibility` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `newsletter_orders`
--

DROP TABLE IF EXISTS `newsletter_orders`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `newsletter_orders` (
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `provider` varchar(96) NOT NULL,
  PRIMARY KEY (`orders_id`,`provider`),
  KEY `idx_provider` (`provider`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `newsletter_orders`
--

LOCK TABLES `newsletter_orders` WRITE;
/*!40000 ALTER TABLE `newsletter_orders` DISABLE KEYS */;
/*!40000 ALTER TABLE `newsletter_orders` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `newsletter_passed`
--

DROP TABLE IF EXISTS `newsletter_passed`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `newsletter_passed` (
  `local_id` int(11) NOT NULL DEFAULT '0',
  `remote_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `provider` varchar(120) CHARACTER SET utf8 COLLATE utf8_bin NOT NULL DEFAULT '',
  UNIQUE KEY `local_id` (`local_id`,`remote_id`,`platform_id`,`provider`),
  KEY `idx_local_id` (`local_id`),
  KEY `idx_platform_id` (`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `newsletter_passed`
--

LOCK TABLES `newsletter_passed` WRITE;
/*!40000 ALTER TABLE `newsletter_passed` DISABLE KEYS */;
/*!40000 ALTER TABLE `newsletter_passed` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `newsletter_products`
--

DROP TABLE IF EXISTS `newsletter_products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `newsletter_products` (
  `products_id` int(11) NOT NULL DEFAULT '0',
  `uprid` varchar(256) DEFAULT NULL,
  `provider` varchar(96) NOT NULL,
  PRIMARY KEY (`products_id`,`provider`),
  KEY `idx_provider` (`provider`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `newsletter_products`
--

LOCK TABLES `newsletter_products` WRITE;
/*!40000 ALTER TABLE `newsletter_products` DISABLE KEYS */;
/*!40000 ALTER TABLE `newsletter_products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `newsletter_subscribers`
--

DROP TABLE IF EXISTS `newsletter_subscribers`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `newsletter_subscribers` (
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `provider` varchar(96) NOT NULL,
  `customer_type` int(5) NOT NULL DEFAULT '0' COMMENT '0-customer, 1-subscriber',
  PRIMARY KEY (`customers_id`,`provider`,`customer_type`),
  KEY `idx_provider` (`provider`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `newsletter_subscribers`
--

LOCK TABLES `newsletter_subscribers` WRITE;
/*!40000 ALTER TABLE `newsletter_subscribers` DISABLE KEYS */;
/*!40000 ALTER TABLE `newsletter_subscribers` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `newsletters`
--

DROP TABLE IF EXISTS `newsletters`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `newsletters` (
  `newsletters_id` int(11) NOT NULL AUTO_INCREMENT,
  `title` varchar(255) NOT NULL DEFAULT '',
  `content` text NOT NULL,
  `module` varchar(255) NOT NULL DEFAULT '',
  `date_added` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `date_sent` datetime DEFAULT NULL,
  `status` int(1) DEFAULT NULL,
  `locked` int(1) DEFAULT '0',
  `affiliate_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`newsletters_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `newsletters`
--

LOCK TABLES `newsletters` WRITE;
/*!40000 ALTER TABLE `newsletters` DISABLE KEYS */;
/*!40000 ALTER TABLE `newsletters` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `options_templates`
--

DROP TABLE IF EXISTS `options_templates`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `options_templates` (
  `options_templates_id` int(11) NOT NULL AUTO_INCREMENT,
  `options_templates_name` varchar(64) DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  PRIMARY KEY (`options_templates_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `options_templates`
--

LOCK TABLES `options_templates` WRITE;
/*!40000 ALTER TABLE `options_templates` DISABLE KEYS */;
/*!40000 ALTER TABLE `options_templates` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `options_templates_attributes`
--

DROP TABLE IF EXISTS `options_templates_attributes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `options_templates_attributes` (
  `options_templates_attributes_id` int(11) NOT NULL AUTO_INCREMENT,
  `options_templates_id` int(11) NOT NULL DEFAULT '0',
  `options_id` int(11) NOT NULL DEFAULT '0',
  `options_values_id` int(11) NOT NULL DEFAULT '0',
  `options_values_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `price_prefix` char(3) NOT NULL DEFAULT '+',
  `products_options_sort_order` int(6) NOT NULL DEFAULT '0',
  `product_attributes_one_time` tinyint(1) NOT NULL DEFAULT '0',
  `products_attributes_weight` decimal(6,3) NOT NULL DEFAULT '0.000',
  `products_attributes_weight_prefix` char(3) NOT NULL DEFAULT '+',
  `products_attributes_units` int(4) NOT NULL DEFAULT '0',
  `products_attributes_units_price` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `products_attributes_discount_price` varchar(255) NOT NULL DEFAULT '',
  `products_attributes_filename` varchar(255) NOT NULL DEFAULT '',
  `products_attributes_maxdays` int(11) DEFAULT NULL,
  `products_attributes_maxcount` int(11) DEFAULT NULL,
  `default_option_value` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`options_templates_attributes_id`),
  KEY `options_templates_idx` (`options_templates_id`,`options_id`,`options_values_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `options_templates_attributes`
--

LOCK TABLES `options_templates_attributes` WRITE;
/*!40000 ALTER TABLE `options_templates_attributes` DISABLE KEYS */;
/*!40000 ALTER TABLE `options_templates_attributes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `options_templates_attributes_prices`
--

DROP TABLE IF EXISTS `options_templates_attributes_prices`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `options_templates_attributes_prices` (
  `options_templates_attributes_id` int(11) NOT NULL DEFAULT '0',
  `groups_id` int(11) NOT NULL DEFAULT '0',
  `currencies_id` int(11) NOT NULL DEFAULT '0',
  `attributes_group_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `attributes_group_discount_price` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`options_templates_attributes_id`,`groups_id`,`currencies_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `options_templates_attributes_prices`
--

LOCK TABLES `options_templates_attributes_prices` WRITE;
/*!40000 ALTER TABLE `options_templates_attributes_prices` DISABLE KEYS */;
/*!40000 ALTER TABLE `options_templates_attributes_prices` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders`
--

DROP TABLE IF EXISTS `orders`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders` (
  `orders_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `department_id` int(11) NOT NULL DEFAULT '0',
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `basket_id` int(11) NOT NULL DEFAULT '0',
  `customers_name` varchar(64) NOT NULL DEFAULT '',
  `customers_firstname` varchar(255) NOT NULL DEFAULT '',
  `customers_lastname` varchar(255) NOT NULL DEFAULT '',
  `customers_company` varchar(32) DEFAULT NULL,
  `customers_company_vat` varchar(32) NOT NULL DEFAULT '',
  `customers_company_vat_status` int(4) NOT NULL DEFAULT '0',
  `customers_street_address` varchar(64) NOT NULL DEFAULT '',
  `customers_suburb` varchar(32) DEFAULT NULL,
  `customers_city` varchar(32) NOT NULL DEFAULT '',
  `customers_postcode` varchar(10) NOT NULL DEFAULT '',
  `customers_state` varchar(32) DEFAULT NULL,
  `customers_country` varchar(64) NOT NULL DEFAULT '',
  `customers_telephone` varchar(32) NOT NULL DEFAULT '',
  `customers_email_address` varchar(96) NOT NULL DEFAULT '',
  `customers_address_format_id` int(5) NOT NULL DEFAULT '0',
  `delivery_gender` char(4) NOT NULL DEFAULT '',
  `delivery_name` varchar(255) NOT NULL DEFAULT '',
  `delivery_firstname` varchar(255) NOT NULL DEFAULT '',
  `delivery_lastname` varchar(255) NOT NULL DEFAULT '',
  `delivery_company` varchar(32) DEFAULT NULL,
  `delivery_street_address` varchar(64) NOT NULL DEFAULT '',
  `delivery_suburb` varchar(32) DEFAULT NULL,
  `delivery_city` varchar(32) NOT NULL DEFAULT '',
  `delivery_postcode` varchar(10) NOT NULL DEFAULT '',
  `delivery_state` varchar(32) DEFAULT NULL,
  `delivery_country` varchar(64) NOT NULL DEFAULT '',
  `delivery_email_address` varchar(96) NOT NULL DEFAULT '',
  `delivery_telephone` varchar(32) NOT NULL DEFAULT '',
  `delivery_company_vat` varchar(32) DEFAULT NULL,
  `delivery_company_vat_status` varchar(32) DEFAULT NULL,
  `delivery_address_format_id` int(5) NOT NULL DEFAULT '0',
  `delivery_address_book_id` int(11) NOT NULL DEFAULT '0',
  `billing_gender` char(4) NOT NULL DEFAULT '',
  `billing_name` varchar(64) NOT NULL DEFAULT '',
  `billing_firstname` varchar(255) NOT NULL DEFAULT '',
  `billing_lastname` varchar(255) NOT NULL DEFAULT '',
  `billing_company` varchar(32) DEFAULT NULL,
  `billing_street_address` varchar(64) NOT NULL DEFAULT '',
  `billing_suburb` varchar(32) DEFAULT NULL,
  `billing_city` varchar(32) NOT NULL DEFAULT '',
  `billing_postcode` varchar(10) NOT NULL DEFAULT '',
  `billing_state` varchar(32) DEFAULT NULL,
  `billing_country` varchar(64) NOT NULL DEFAULT '',
  `billing_email_address` varchar(96) NOT NULL DEFAULT '',
  `billing_telephone` varchar(32) NOT NULL DEFAULT '',
  `billing_company_vat` varchar(32) DEFAULT NULL,
  `billing_company_vat_status` varchar(32) DEFAULT NULL,
  `billing_address_format_id` int(5) NOT NULL DEFAULT '0',
  `billing_address_book_id` int(11) NOT NULL DEFAULT '0',
  `payment_method` varchar(255) NOT NULL DEFAULT '',
  `payment_info` text,
  `cc_type` varchar(20) DEFAULT NULL,
  `cc_owner` varchar(64) DEFAULT NULL,
  `cc_number` varchar(32) DEFAULT NULL,
  `cc_expires` varchar(4) DEFAULT NULL,
  `cc_cvn` varchar(7) DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `date_purchased` datetime DEFAULT NULL,
  `orders_status` int(5) NOT NULL DEFAULT '0',
  `orders_date_finished` datetime DEFAULT NULL,
  `currency` char(3) DEFAULT NULL,
  `currency_value` decimal(14,6) DEFAULT NULL,
  `currency_value_default` decimal(14,6) DEFAULT NULL,
  `settlement_date` datetime DEFAULT '0000-00-00 00:00:00',
  `approval_code` varchar(100) NOT NULL DEFAULT '',
  `transaction_id` varchar(32) DEFAULT NULL,
  `shipping_class` varchar(64) NOT NULL DEFAULT '',
  `label_class` varchar(64) NOT NULL DEFAULT '',
  `payment_class` varchar(64) NOT NULL DEFAULT '',
  `orders_type` int(11) NOT NULL DEFAULT '0',
  `admin_id` int(11) NOT NULL DEFAULT '0',
  `shipping_method` varchar(255) NOT NULL DEFAULT '',
  `payment_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `search_engines_id` int(11) NOT NULL DEFAULT '0',
  `search_words_id` int(11) NOT NULL DEFAULT '0',
  `last_xml_import` datetime DEFAULT NULL,
  `last_xml_export` datetime DEFAULT NULL,
  `edit_orders_recalculate_totals` int(11) NOT NULL DEFAULT '1',
  `gv` tinyint(1) NOT NULL DEFAULT '0',
  `customers_landline` varchar(32) NOT NULL DEFAULT '',
  `tracking_number` text NOT NULL,
  `real_tracking_number` varchar(255) NOT NULL DEFAULT '',
  `lat` float(15,8) NOT NULL DEFAULT '0.00000000',
  `lng` float(15,8) NOT NULL DEFAULT '0.00000000',
  `shipping_weight` decimal(11,6) NOT NULL DEFAULT '0.000000',
  `adjusted` tinyint(4) NOT NULL DEFAULT '0',
  `stock_updated` tinyint(1) NOT NULL DEFAULT '0',
  `reference_id` int(11) DEFAULT NULL,
  `trustpilot_invited` tinyint(1) NOT NULL DEFAULT '0',
  `trustpilot_invite_create_date` datetime DEFAULT NULL,
  `trustpilot_connect_via` varchar(8) NOT NULL DEFAULT '',
  `delivery_date` date DEFAULT NULL,
  `bonus_points_redeem` decimal(15,2) NOT NULL DEFAULT '0.00',
  `bonus_applied` tinyint(4) DEFAULT '0',
  `products_price_qty_round` tinyint(1) NOT NULL DEFAULT '0',
  `external_orders_id` varchar(32) NOT NULL DEFAULT '',
  `cash_data_summ` decimal(14,2) NOT NULL DEFAULT '0.00',
  `cash_data_change` decimal(14,2) NOT NULL DEFAULT '0.00',
  `pointto` int(11) NOT NULL DEFAULT '0',
  `card_reference_id` varchar(50) NOT NULL DEFAULT '',
  `cross_up_email_send` int(11) DEFAULT '0',
  `idweb_code` varchar(15) NOT NULL DEFAULT '',
  `_api_order_time_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `_api_order_time_processed` timestamp NULL DEFAULT NULL,
  `api_client_order_id` varchar(32) NOT NULL DEFAULT '',
  `parcel_label_pdf` mediumtext NOT NULL,
  `orders_allocate_allow` tinyint(1) NOT NULL DEFAULT '0',
  `hold_on_date` date DEFAULT NULL,
  `purchase_order` varchar(16) DEFAULT NULL,
  `order_number` varchar(48) NOT NULL DEFAULT '',
  `customers_customs_number` varchar(50) DEFAULT NULL,
  `customers_customs_number_status` int(1) NOT NULL DEFAULT '0',
  `billing_customs_number` varchar(50) DEFAULT NULL,
  `billing_customs_number_status` int(1) NOT NULL DEFAULT '0',
  `delivery_customs_number` varchar(50) DEFAULT NULL,
  `delivery_customs_number_status` int(1) NOT NULL DEFAULT '0',
  `invoice_number` varchar(48) NOT NULL DEFAULT '',
  `drop_ship` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`orders_id`),
  KEY `search_words_id` (`search_words_id`),
  KEY `idx_date_purchased` (`date_purchased`),
  KEY `customers_id` (`customers_id`),
  KEY `platform_id` (`platform_id`),
  KEY `basket_id` (`basket_id`),
  KEY `customers_email_address` (`customers_email_address`),
  KEY `trustpilot_invited` (`trustpilot_invited`),
  KEY `external_orders_id` (`external_orders_id`,`platform_id`),
  KEY `idweb_code` (`idweb_code`),
  KEY `api_client_order_id` (`api_client_order_id`),
  KEY `admin_id_idx` (`admin_id`),
  KEY `payment_method_idx` (`payment_method`),
  KEY `idx_orders_status` (`orders_status`),
  KEY `idx_order_number` (`order_number`),
  KEY `idx_invoice_number` (`invoice_number`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders`
--

LOCK TABLES `orders` WRITE;
/*!40000 ALTER TABLE `orders` DISABLE KEYS */;
INSERT INTO `orders` VALUES (2,7,0,43,0,'Li Chong','Li','Chong',NULL,'',0,'184 Ban Qiao Lu',NULL,'Xinghua Shi','225700',NULL,'China','','Li.Chong@holbi.co.uk',5,'','Li Chong','Li','Chong',NULL,'184 Ban Qiao Lu',NULL,'Xinghua Shi','225700',NULL,'China','','',NULL,NULL,5,0,'','Li Chong','Li','Chong',NULL,'184 Ban Qiao Lu',NULL,'Xinghua Shi','225700',NULL,'China','','',NULL,NULL,5,0,'',NULL,NULL,NULL,NULL,NULL,NULL,NULL,'2022-07-22 19:12:07',3,NULL,'GBP',1.000000,NULL,'0000-00-00 00:00:00','',NULL,'flat_flat','','',0,0,'3-5 days delivery (Best Way)',0,1,0,0,NULL,NULL,1,0,'','','',0.00000000,0.00000000,0.000000,0,0,NULL,0,NULL,'',NULL,0.00,0,0,'',0.00,0.00,0,'',0,'','[[regtime]]',NULL,'','',0,NULL,NULL,'',NULL,0,NULL,0,NULL,0,'',0),(3,10,0,2,0,'Mandy Cross','Mandy','Cross',NULL,'',0,'30A Ospringe Road',NULL,'London','NW5 2JB',NULL,'United Kingdom','','Mandy.Cross@holbi.co.uk',6,'','Mandy Cross','Mandy','Cross',NULL,'30A Ospringe Road',NULL,'London','NW5 2JB',NULL,'United Kingdom','','',NULL,NULL,6,0,'','Mandy Cross','Mandy','Cross',NULL,'30A Ospringe Road',NULL,'London','NW5 2JB',NULL,'United Kingdom','','',NULL,NULL,6,0,'',NULL,NULL,NULL,NULL,NULL,NULL,NULL,'2022-07-22 19:12:51',3,NULL,'GBP',1.000000,NULL,'0000-00-00 00:00:00','',NULL,'flat_flat','','',0,0,'3-5 days delivery (Best Way)',0,1,0,0,NULL,NULL,1,0,'','','',0.00000000,0.00000000,0.000000,0,0,NULL,0,NULL,'',NULL,0.00,0,0,'',0.00,0.00,0,'',0,'','[[regtime]]',NULL,'','',0,NULL,NULL,'',NULL,0,NULL,0,NULL,0,'',0),(4,8,0,1,0,'Abraham Dalton','Abraham','Dalton',NULL,'',0,'A205, Castle Exchange','41 Broad Street','Nottingham','NG1 3AP',NULL,'United Kingdom','','Abraham.Dalton@holbi.co.uk',6,'','Abraham Dalton','Abraham','Dalton',NULL,'A205, Castle Exchange','41 Broad Street','Nottingham','NG1 3AP',NULL,'United Kingdom','','',NULL,NULL,6,0,'','Abraham Dalton','Abraham','Dalton',NULL,'A205, Castle Exchange','41 Broad Street','Nottingham','NG1 3AP',NULL,'United Kingdom','','',NULL,NULL,6,0,'',NULL,NULL,NULL,NULL,NULL,NULL,NULL,'2022-07-22 19:14:25',100001,NULL,'GBP',1.000000,NULL,'0000-00-00 00:00:00','',NULL,'flat_flat','','',0,0,'3-5 days delivery (Best Way)',0,1,0,0,NULL,NULL,1,0,'','','',0.00000000,0.00000000,1.000000,0,0,NULL,0,NULL,'',NULL,0.00,0,0,'',0.00,0.00,0,'',0,'','[[regtime]]',NULL,'','',0,NULL,NULL,'',NULL,0,NULL,0,NULL,0,'',0);
/*!40000 ALTER TABLE `orders` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_check`
--

DROP TABLE IF EXISTS `orders_check`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_check` (
  `orders_check_id` int(11) NOT NULL AUTO_INCREMENT,
  `tmp_orders_id` int(11) NOT NULL DEFAULT '0',
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `date_time_added` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `debug_info` text NOT NULL,
  PRIMARY KEY (`orders_check_id`),
  UNIQUE KEY `tmp_orders_id` (`tmp_orders_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_check`
--

LOCK TABLES `orders_check` WRITE;
/*!40000 ALTER TABLE `orders_check` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_check` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_comment_template`
--

DROP TABLE IF EXISTS `orders_comment_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_comment_template` (
  `comment_template_id` int(11) NOT NULL AUTO_INCREMENT,
  `status` tinyint(1) NOT NULL DEFAULT '1',
  `visibility` varchar(255) NOT NULL DEFAULT ',order,',
  `sort_order` int(2) DEFAULT '0',
  `hide_for_platforms` varchar(1024) NOT NULL DEFAULT '',
  `hide_from_admin` varchar(1024) NOT NULL DEFAULT '',
  `show_for_admin_group` varchar(1024) NOT NULL DEFAULT ',*,',
  `date_modified` datetime DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  PRIMARY KEY (`comment_template_id`),
  KEY `orders_comment_template_idx` (`status`,`sort_order`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_comment_template`
--

LOCK TABLES `orders_comment_template` WRITE;
/*!40000 ALTER TABLE `orders_comment_template` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_comment_template` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_comment_template_text`
--

DROP TABLE IF EXISTS `orders_comment_template_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_comment_template_text` (
  `comment_template_id` int(4) NOT NULL,
  `language_id` int(4) NOT NULL,
  `name` varchar(255) DEFAULT NULL,
  `comment_template` text NOT NULL,
  PRIMARY KEY (`comment_template_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_comment_template_text`
--

LOCK TABLES `orders_comment_template_text` WRITE;
/*!40000 ALTER TABLE `orders_comment_template_text` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_comment_template_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_comments`
--

DROP TABLE IF EXISTS `orders_comments`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_comments` (
  `orders_comments_id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `comments` text,
  `date_added` datetime DEFAULT NULL,
  `admin_id` int(11) DEFAULT NULL,
  `for_invoice` int(1) NOT NULL DEFAULT '0',
  `visible` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`orders_comments_id`),
  KEY `idx_order` (`orders_id`),
  KEY `idx_admin` (`admin_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_comments`
--

LOCK TABLES `orders_comments` WRITE;
/*!40000 ALTER TABLE `orders_comments` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_comments` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_delete_history`
--

DROP TABLE IF EXISTS `orders_delete_history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_delete_history` (
  `orders_history_id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `comments` text,
  `admin_id` int(11) NOT NULL DEFAULT '0',
  `date_added` datetime DEFAULT NULL,
  PRIMARY KEY (`orders_history_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_delete_history`
--

LOCK TABLES `orders_delete_history` WRITE;
/*!40000 ALTER TABLE `orders_delete_history` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_delete_history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_history`
--

DROP TABLE IF EXISTS `orders_history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_history` (
  `orders_history_id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `comments` mediumtext NOT NULL,
  `admin_id` int(11) NOT NULL DEFAULT '0',
  `date_added` datetime DEFAULT NULL,
  PRIMARY KEY (`orders_history_id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_history`
--

LOCK TABLES `orders_history` WRITE;
/*!40000 ALTER TABLE `orders_history` DISABLE KEYS */;
INSERT INTO `orders_history` VALUES (1,2,'Order imported',0,'[[regtime]]'),(2,3,'Order imported',0,'[[regtime]]'),(3,4,'Order imported',0,'[[regtime]]');
/*!40000 ALTER TABLE `orders_history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_label`
--

DROP TABLE IF EXISTS `orders_label`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_label` (
  `orders_label_id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `label_class` varchar(64) NOT NULL DEFAULT '',
  `tracking_numbers_id` int(11) NOT NULL DEFAULT '0',
  `tracking_number` varchar(255) NOT NULL DEFAULT '',
  `parcel_label_pdf` mediumtext NOT NULL,
  `admin_id` int(11) NOT NULL DEFAULT '0',
  `date_created` datetime DEFAULT NULL,
  `label_status` int(1) NOT NULL DEFAULT '0',
  `label_module_error` varchar(1024) DEFAULT NULL,
  `shipment_digest` text NOT NULL,
  `extra_params` text,
  PRIMARY KEY (`orders_label_id`),
  KEY `idx_orders_id` (`orders_id`),
  KEY `idx_tracking_numbers_id` (`tracking_numbers_id`),
  KEY `idx_tracking_number` (`tracking_number`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_label`
--

LOCK TABLES `orders_label` WRITE;
/*!40000 ALTER TABLE `orders_label` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_label` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_label_to_orders_products`
--

DROP TABLE IF EXISTS `orders_label_to_orders_products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_label_to_orders_products` (
  `orders_label_id` int(11) NOT NULL DEFAULT '0',
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `orders_products_id` int(11) NOT NULL DEFAULT '0',
  `products_quantity` int(2) NOT NULL DEFAULT '0',
  PRIMARY KEY (`orders_label_id`,`orders_products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_label_to_orders_products`
--

LOCK TABLES `orders_label_to_orders_products` WRITE;
/*!40000 ALTER TABLE `orders_label_to_orders_products` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_label_to_orders_products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_parent`
--

DROP TABLE IF EXISTS `orders_parent`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_parent` (
  `orders_id` int(11) NOT NULL,
  `owner_class` varchar(128) NOT NULL DEFAULT '',
  PRIMARY KEY (`orders_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_parent`
--

LOCK TABLES `orders_parent` WRITE;
/*!40000 ALTER TABLE `orders_parent` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_parent` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_payment`
--

DROP TABLE IF EXISTS `orders_payment`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_payment` (
  `orders_payment_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `orders_payment_id_parent` int(10) unsigned NOT NULL DEFAULT '0',
  `orders_payment_order_id` int(10) unsigned NOT NULL DEFAULT '0',
  `orders_payment_module` varchar(100) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `orders_payment_module_name` varchar(250) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `orders_payment_is_credit` tinyint(1) NOT NULL DEFAULT '0',
  `orders_payment_status` tinyint(1) unsigned NOT NULL DEFAULT '0',
  `orders_payment_amount` decimal(15,2) NOT NULL DEFAULT '0.00',
  `orders_payment_currency` varchar(10) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `orders_payment_currency_rate` decimal(15,8) unsigned NOT NULL DEFAULT '1.00000000',
  `orders_payment_snapshot` text CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL,
  `orders_payment_transaction_id` varchar(200) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `orders_payment_transaction_status` varchar(100) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL DEFAULT '',
  `orders_payment_transaction_commentary` text CHARACTER SET utf8 COLLATE utf8_unicode_ci,
  `orders_payment_transaction_date` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `orders_payment_admin_create` int(10) unsigned NOT NULL DEFAULT '0',
  `orders_payment_date_create` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `orders_payment_admin_update` int(10) unsigned NOT NULL DEFAULT '0',
  `orders_payment_date_update` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `orders_payment_transaction_full` text COMMENT 'Payments require extra param(s) for refund, payment module should save these params in this field',
  `credit_note_id` int(11) NOT NULL DEFAULT '0',
  `payment_type` varchar(30) NOT NULL DEFAULT '' COMMENT 'authorise|authorisation|capture|refund - for online payments getTransactionDetails',
  `deferred` int(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`orders_payment_id`),
  KEY `orders_payment_id_parent` (`orders_payment_id_parent`),
  KEY `idx_orders_payment_date_update` (`orders_payment_date_update`),
  KEY `idx_orders_payment_order_id` (`orders_payment_order_id`),
  KEY `idx_orders_payment_date_transaction_id` (`orders_payment_transaction_date`,`orders_payment_transaction_id`),
  KEY `idx_orders_payment_transaction_id` (`orders_payment_transaction_id`),
  KEY `idx_orders_payment_module_status` (`orders_payment_module`,`orders_payment_status`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_payment`
--

LOCK TABLES `orders_payment` WRITE;
/*!40000 ALTER TABLE `orders_payment` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_payment` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_products`
--

DROP TABLE IF EXISTS `orders_products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_products` (
  `orders_products_id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `products_id` int(11) NOT NULL DEFAULT '0',
  `products_model` varchar(25) DEFAULT NULL,
  `products_name` text NOT NULL,
  `products_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `final_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `products_tax` decimal(7,4) NOT NULL DEFAULT '0.0000',
  `products_quantity` int(2) NOT NULL DEFAULT '0',
  `qty_cnld` int(11) NOT NULL DEFAULT '0',
  `qty_rcvd` int(11) NOT NULL DEFAULT '0',
  `qty_dspd` int(11) NOT NULL DEFAULT '0',
  `qty_dlvd` int(11) NOT NULL DEFAULT '0',
  `qty_rtrn` int(11) NOT NULL DEFAULT '0',
  `uprid` varchar(255) NOT NULL DEFAULT '',
  `sets_array` text NOT NULL,
  `is_giveaway` int(11) NOT NULL DEFAULT '0',
  `gift_wrap_price` decimal(15,2) NOT NULL DEFAULT '0.00',
  `gift_wrapped` tinyint(1) NOT NULL DEFAULT '0',
  `is_virtual` tinyint(1) NOT NULL DEFAULT '0',
  `gv_state` enum('none','pending','released','canceled') NOT NULL DEFAULT 'none',
  `overwritten` text NOT NULL,
  `packagings` int(11) DEFAULT '0',
  `units` int(11) NOT NULL DEFAULT '0',
  `packs` int(11) DEFAULT '0',
  `elements` text NOT NULL,
  `template_uprid` tinytext NOT NULL,
  `parent_product` tinytext NOT NULL,
  `sub_products` tinytext NOT NULL,
  `bonus_points_cost` decimal(15,2) NOT NULL DEFAULT '0.00',
  `orders_products_status` int(11) NOT NULL DEFAULT '0',
  `orders_products_status_manual` int(11) NOT NULL DEFAULT '0',
  `products_quantity_recieved` int(11) NOT NULL DEFAULT '0',
  `promo_id` int(11) DEFAULT '0',
  `sort_order` int(4) NOT NULL DEFAULT '0',
  `products_weight` decimal(6,3) NOT NULL DEFAULT '0.000',
  `relation_type` varchar(32) NOT NULL DEFAULT '',
  `props` text NOT NULL,
  `specials_id` int(11) NOT NULL DEFAULT '0',
  `discount_description` varchar(255) NOT NULL DEFAULT '',
  `rma_allow_date` date NOT NULL DEFAULT '0000-00-00',
  PRIMARY KEY (`orders_products_id`),
  KEY `idx_orders_id` (`orders_id`),
  KEY `products_id` (`products_id`),
  KEY `idx_products_name` (`products_name`(128)),
  KEY `specials_id` (`specials_id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_products`
--

LOCK TABLES `orders_products` WRITE;
/*!40000 ALTER TABLE `orders_products` DISABLE KEYS */;
INSERT INTO `orders_products` VALUES (1,2,54,'PJAC08-0400P3','JACK 4 PIECE KING BEDROOM SUITE',1303.478260,1303.478260,0.0000,1,0,0,0,0,0,'54','',0,0.00,0,0,'none','',NULL,1,NULL,'','54','','',0.00,0,0,0,0,0,0.000,'','',0,'','0000-00-00'),(2,3,44,'629373','CANON PIXMA TS5350 AllinOne Wireless Inkjet Printer',58.325000,58.325000,20.0000,1,0,0,0,0,0,'44','',0,0.00,0,0,'none','',NULL,1,NULL,'','44','','',0.00,0,0,0,0,0,0.000,'','',0,'','0000-00-00'),(3,4,29,'Royal-41003-03','Royal London 41003-03',157.500000,157.500000,20.0000,1,0,0,0,0,0,'29','',0,0.00,0,0,'none','',NULL,1,NULL,'','29','','',0.00,0,0,0,0,0,1.000,'','',0,'','0000-00-00');
/*!40000 ALTER TABLE `orders_products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_products_allocate`
--

DROP TABLE IF EXISTS `orders_products_allocate`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_products_allocate` (
  `orders_products_id` int(11) NOT NULL,
  `warehouse_id` int(11) NOT NULL,
  `suppliers_id` int(11) NOT NULL,
  `location_id` int(11) NOT NULL,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `prid` int(11) NOT NULL DEFAULT '0',
  `products_id` varchar(255) NOT NULL DEFAULT '',
  `allocate_received` int(11) NOT NULL DEFAULT '0',
  `allocate_dispatched` int(11) NOT NULL DEFAULT '0',
  `allocate_delivered` int(11) NOT NULL DEFAULT '0',
  `is_temporary` tinyint(1) NOT NULL DEFAULT '0',
  `datetime` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `suppliers_price` decimal(8,2) NOT NULL DEFAULT '0.00',
  `layers_id` int(11) NOT NULL DEFAULT '0',
  `batch_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`orders_products_id`,`warehouse_id`,`suppliers_id`,`location_id`,`layers_id`,`batch_id`),
  KEY `idx_orders_products_id` (`orders_products_id`),
  KEY `idx_warehouse_id` (`warehouse_id`),
  KEY `idx_suppliers_id` (`suppliers_id`),
  KEY `idx_location_id` (`location_id`),
  KEY `idx_platform_id` (`platform_id`),
  KEY `idx_orders_id` (`orders_id`),
  KEY `idx_prid` (`prid`),
  KEY `idx_products_id` (`products_id`),
  KEY `idx_layers_id` (`layers_id`),
  KEY `idx_batch_id` (`batch_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_products_allocate`
--

LOCK TABLES `orders_products_allocate` WRITE;
/*!40000 ALTER TABLE `orders_products_allocate` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_products_allocate` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_products_attributes`
--

DROP TABLE IF EXISTS `orders_products_attributes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_products_attributes` (
  `orders_products_attributes_id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `orders_products_id` int(11) NOT NULL DEFAULT '0',
  `products_options` text NOT NULL,
  `products_options_values` varchar(255) NOT NULL DEFAULT '',
  `options_values_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `price_prefix` char(3) NOT NULL DEFAULT '+',
  `products_options_id` int(11) NOT NULL DEFAULT '0',
  `products_options_values_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`orders_products_attributes_id`),
  KEY `orders_id` (`orders_id`),
  KEY `orders_products_id` (`orders_products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_products_attributes`
--

LOCK TABLES `orders_products_attributes` WRITE;
/*!40000 ALTER TABLE `orders_products_attributes` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_products_attributes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_products_download`
--

DROP TABLE IF EXISTS `orders_products_download`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_products_download` (
  `orders_products_download_id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `orders_products_id` int(11) NOT NULL DEFAULT '0',
  `orders_products_filename` varchar(255) NOT NULL DEFAULT '',
  `download_maxdays` int(2) NOT NULL DEFAULT '0',
  `download_count` int(2) NOT NULL DEFAULT '0',
  `download_count_1` int(2) NOT NULL DEFAULT '0',
  `orders_products_name` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`orders_products_download_id`),
  KEY `orders_id` (`orders_id`),
  KEY `orders_products_id` (`orders_products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_products_download`
--

LOCK TABLES `orders_products_download` WRITE;
/*!40000 ALTER TABLE `orders_products_download` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_products_download` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_products_status`
--

DROP TABLE IF EXISTS `orders_products_status`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_products_status` (
  `orders_products_status_id` int(11) NOT NULL,
  `language_id` int(11) NOT NULL DEFAULT '1',
  `orders_products_status_name` varchar(32) NOT NULL DEFAULT '',
  `orders_products_status_name_long` varchar(64) NOT NULL DEFAULT '',
  `orders_products_status_colour` varchar(16) NOT NULL DEFAULT '#000000',
  PRIMARY KEY (`orders_products_status_id`,`language_id`),
  KEY `idx_orders_products_status_name` (`orders_products_status_name`),
  KEY `idx_orders_products_status_name_long` (`orders_products_status_name_long`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_products_status`
--

LOCK TABLES `orders_products_status` WRITE;
/*!40000 ALTER TABLE `orders_products_status` DISABLE KEYS */;
INSERT INTO `orders_products_status` VALUES (1,1,'Qted','Quoted','#667981'),(1,3,'Qted','Quoted','#667981'),(1,10,'Qted','Quoted','#667981'),(1,11,'Qted','Quoted','#667981'),(1,12,'Qted','Quoted','#667981'),(1,13,'Qted','Quoted','#667981'),(1,15,'Qted','Quoted','#667981'),(1,17,'Qted','Quoted','#667981'),(1,26,'Qted','Quoted','#667981'),(1,28,'Qted','Quoted','#667981'),(1,29,'Qted','Quoted','#667981'),(10,1,'StckDfct','Stock deficit','#ff9100'),(10,3,'StckDfct','Stock deficit','#ff9100'),(10,10,'StckDfct','Stock deficit','#ff9100'),(10,11,'StckDfct','Stock deficit','#ff9100'),(10,12,'StckDfct','Stock deficit','#ff9100'),(10,13,'StckDfct','Stock deficit','#ff9100'),(10,15,'StckDfct','Stock deficit','#ff9100'),(10,17,'StckDfct','Stock deficit','#ff9100'),(10,26,'StckDfct','Stock deficit','#ff9100'),(10,28,'StckDfct','Stock deficit','#ff9100'),(10,29,'StckDfct','Stock deficit','#ff9100'),(12,1,'StckPndg','Stock pending','#8e8d0d'),(12,3,'StckPndg','Stock pending','#8e8d0d'),(12,10,'StckPndg','Stock pending','#8e8d0d'),(12,11,'StckPndg','Stock pending','#8e8d0d'),(12,12,'StckPndg','Stock pending','#8e8d0d'),(12,13,'StckPndg','Stock pending','#8e8d0d'),(12,15,'StckPndg','Stock pending','#8e8d0d'),(12,17,'StckPndg','Stock pending','#8e8d0d'),(12,26,'StckPndg','Stock pending','#8e8d0d'),(12,28,'StckPndg','Stock pending','#8e8d0d'),(12,29,'StckPndg','Stock pending','#8e8d0d'),(15,1,'StckOrdr','Stock ordered','#aa00ff'),(15,3,'StckOrdr','Stock ordered','#aa00ff'),(15,10,'StckOrdr','Stock ordered','#aa00ff'),(15,11,'StckOrdr','Stock ordered','#aa00ff'),(15,12,'StckOrdr','Stock ordered','#aa00ff'),(15,13,'StckOrdr','Stock ordered','#aa00ff'),(15,15,'StckOrdr','Stock ordered','#aa00ff'),(15,17,'StckOrdr','Stock ordered','#aa00ff'),(15,26,'StckOrdr','Stock ordered','#aa00ff'),(15,28,'StckOrdr','Stock ordered','#aa00ff'),(15,29,'StckOrdr','Stock ordered','#aa00ff'),(20,1,'Rcvd','Received','#283593'),(20,3,'Rcvd','Received','#283593'),(20,10,'Rcvd','Received','#283593'),(20,11,'Rcvd','Received','#283593'),(20,12,'Rcvd','Received','#283593'),(20,13,'Rcvd','Received','#283593'),(20,15,'Rcvd','Received','#283593'),(20,17,'Rcvd','Received','#283593'),(20,26,'Rcvd','Received','#283593'),(20,28,'Rcvd','Received','#283593'),(20,29,'Rcvd','Received','#283593'),(30,1,'Dspd','Dispatched','#2962ff'),(30,3,'Dspd','Dispatched','#2962ff'),(30,10,'Dspd','Dispatched','#2962ff'),(30,11,'Dspd','Dispatched','#2962ff'),(30,12,'Dspd','Dispatched','#2962ff'),(30,13,'Dspd','Dispatched','#2962ff'),(30,15,'Dspd','Dispatched','#2962ff'),(30,17,'Dspd','Dispatched','#2962ff'),(30,26,'Dspd','Dispatched','#2962ff'),(30,28,'Dspd','Dispatched','#2962ff'),(30,29,'Dspd','Dispatched','#2962ff'),(40,1,'Dlvd','Delivered','#028908'),(40,3,'Dlvd','Delivered','#028908'),(40,10,'Dlvd','Delivered','#028908'),(40,11,'Dlvd','Delivered','#028908'),(40,12,'Dlvd','Delivered','#028908'),(40,13,'Dlvd','Delivered','#028908'),(40,15,'Dlvd','Delivered','#028908'),(40,17,'Dlvd','Delivered','#028908'),(40,26,'Dlvd','Delivered','#028908'),(40,28,'Dlvd','Delivered','#028908'),(40,29,'Dlvd','Delivered','#028908'),(50,1,'Cnld','Cancelled','#ff0000'),(50,3,'Cnld','Cancelled','#ff0000'),(50,10,'Cnld','Cancelled','#ff0000'),(50,11,'Cnld','Cancelled','#ff0000'),(50,12,'Cnld','Cancelled','#ff0000'),(50,13,'Cnld','Cancelled','#ff0000'),(50,15,'Cnld','Cancelled','#ff0000'),(50,17,'Cnld','Cancelled','#ff0000'),(50,26,'Cnld','Cancelled','#ff0000'),(50,28,'Cnld','Cancelled','#ff0000'),(50,29,'Cnld','Cancelled','#ff0000');
/*!40000 ALTER TABLE `orders_products_status` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_products_status_history`
--

DROP TABLE IF EXISTS `orders_products_status_history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_products_status_history` (
  `orders_products_history_id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `orders_products_id` int(11) NOT NULL DEFAULT '0',
  `orders_products_status_id` int(11) NOT NULL DEFAULT '0',
  `orders_products_status_manual_id` int(11) NOT NULL DEFAULT '0',
  `date_added` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `comments` text,
  `admin_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`orders_products_history_id`),
  KEY `idx_orders_id` (`orders_id`),
  KEY `idx_orders_products_id` (`orders_products_id`),
  KEY `idx_orders_products_status_id` (`orders_products_status_id`),
  KEY `idx_orders_products_status_manual_id` (`orders_products_status_manual_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_products_status_history`
--

LOCK TABLES `orders_products_status_history` WRITE;
/*!40000 ALTER TABLE `orders_products_status_history` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_products_status_history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_products_status_manual`
--

DROP TABLE IF EXISTS `orders_products_status_manual`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_products_status_manual` (
  `orders_products_status_manual_id` int(11) NOT NULL,
  `language_id` int(11) NOT NULL DEFAULT '1',
  `orders_products_status_manual_name` varchar(32) NOT NULL DEFAULT '',
  `orders_products_status_manual_name_long` varchar(64) NOT NULL DEFAULT '',
  `orders_products_status_manual_colour` varchar(16) NOT NULL DEFAULT '#000000',
  PRIMARY KEY (`orders_products_status_manual_id`,`language_id`),
  KEY `idx_orders_products_status_manual_name` (`orders_products_status_manual_name`),
  KEY `idx_orders_products_status_manual_name_long` (`orders_products_status_manual_name_long`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_products_status_manual`
--

LOCK TABLES `orders_products_status_manual` WRITE;
/*!40000 ALTER TABLE `orders_products_status_manual` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_products_status_manual` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_products_status_manual_matrix`
--

DROP TABLE IF EXISTS `orders_products_status_manual_matrix`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_products_status_manual_matrix` (
  `orders_products_status_manual_id` int(11) NOT NULL,
  `orders_products_status_id` int(11) NOT NULL,
  PRIMARY KEY (`orders_products_status_manual_id`,`orders_products_status_id`),
  KEY `idx_orders_products_status_manual_id` (`orders_products_status_manual_id`),
  KEY `idx_orders_products_status_id` (`orders_products_status_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_products_status_manual_matrix`
--

LOCK TABLES `orders_products_status_manual_matrix` WRITE;
/*!40000 ALTER TABLE `orders_products_status_manual_matrix` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_products_status_manual_matrix` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_splinters`
--

DROP TABLE IF EXISTS `orders_splinters`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_splinters` (
  `splinters_id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_id` int(11) DEFAULT NULL,
  `splinters_status` tinyint(3) DEFAULT NULL,
  `splinters_order` text,
  `splinters_type` tinyint(3) DEFAULT NULL,
  `admin_id` int(11) DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  `splinters_suborder_id` int(11) DEFAULT NULL,
  `qty` int(11) DEFAULT NULL,
  `value_exc_vat` float DEFAULT NULL,
  `value_inc_tax` float DEFAULT NULL,
  `splinters_owner` varchar(255) DEFAULT NULL,
  `date_status_changed` datetime DEFAULT NULL,
  PRIMARY KEY (`splinters_id`),
  KEY `idx_orders_id` (`orders_id`),
  KEY `idx_splinters_type` (`splinters_type`)
) ENGINE=InnoDB AUTO_INCREMENT=3068 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_splinters`
--

LOCK TABLES `orders_splinters` WRITE;
/*!40000 ALTER TABLE `orders_splinters` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_splinters` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_status`
--

DROP TABLE IF EXISTS `orders_status`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_status` (
  `orders_status_id` int(11) NOT NULL DEFAULT '0',
  `orders_status_groups_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '1',
  `orders_status_name` varchar(32) NOT NULL DEFAULT '',
  `orders_status_template` varchar(255) DEFAULT NULL,
  `automated` tinyint(1) NOT NULL DEFAULT '0',
  `orders_status_template_confirm` varchar(255) DEFAULT NULL,
  `orders_status_template_sms` varchar(255) NOT NULL DEFAULT '',
  `order_evaluation_state_id` int(11) NOT NULL DEFAULT '0',
  `order_evaluation_state_default` tinyint(1) NOT NULL DEFAULT '0',
  `orders_status_allocate_allow` tinyint(1) NOT NULL DEFAULT '0',
  `orders_status_release_deferred` tinyint(1) NOT NULL DEFAULT '0',
  `orders_status_send_ga` tinyint(1) NOT NULL DEFAULT '-1',
  `comment_template_id` int(11) NOT NULL DEFAULT '0',
  `hidden` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`orders_status_id`,`language_id`),
  KEY `idx_orders_status_name` (`orders_status_name`),
  KEY `idx_orders_status_groups_id` (`orders_status_groups_id`),
  KEY `idx_order_evaluation_state_id` (`order_evaluation_state_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_status`
--

LOCK TABLES `orders_status` WRITE;
/*!40000 ALTER TABLE `orders_status` DISABLE KEYS */;
INSERT INTO `orders_status` VALUES (1,1,1,'Redirected at payment gateway','',0,'','',0,0,1,0,-1,0,0),(2,1,1,'Processing','',0,'','',0,0,1,0,-1,0,0),(3,4,1,'Delivered','Order Status Update',0,'','',30,1,1,0,-1,0,0),(4,4,1,'Allow Download','',0,'','',30,0,1,0,-1,0,0),(5,5,1,'Canceled','',0,'','',50,1,0,0,-1,0,0),(33,9,1,'Pending','',0,'','',5,0,0,0,-1,0,0),(34,9,1,'Partly Received','',0,'','',15,0,0,0,-1,0,0),(35,9,1,'Received','',0,'','',25,0,0,0,-1,0,0),(100001,5,1,'Deleted','',0,'','',50,0,0,0,-1,0,0),(100002,6,1,'Active','',0,'','',0,0,0,0,-1,0,0),(100003,6,1,'Canceled','',0,'','',0,0,0,0,-1,0,0),(100004,6,1,'Future','',0,'','',0,0,0,0,-1,0,0),(100005,6,1,'Expired','',0,'','',0,0,0,0,-1,0,0),(100006,2,1,'Payment Successful','',0,'Order Confirmation','',0,0,1,0,-1,0,0),(100007,1,1,'Awaiting for payment','Order Status Update',0,'Order Confirmation','',0,0,1,0,-1,0,0),(100011,7,1,'Canceled','',0,'','',0,0,0,0,-1,0,0),(100012,7,1,'Processed','',0,'','',0,0,0,0,-1,0,0),(100013,7,1,'Awaits confirmation','',0,'','',0,0,0,0,-1,0,0),(100015,8,1,'Active','',0,'','',0,0,0,0,-1,0,0),(100016,8,1,'Processed','',0,'','',0,0,0,0,-1,0,0),(100026,2,1,'Exported','',0,'','',0,0,1,0,-1,0,0),(100027,2,1,'Partially refunded','',0,'','',60,0,1,0,-1,0,0),(100028,7,1,'Active','',0,'','',0,0,0,0,-1,0,0),(100029,9,1,'Canceled',NULL,0,NULL,'',55,0,0,0,-1,0,0),(100030,9,1,'Completed',NULL,0,NULL,'',35,0,0,0,-1,0,0);
/*!40000 ALTER TABLE `orders_status` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_status_groups`
--

DROP TABLE IF EXISTS `orders_status_groups`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_status_groups` (
  `orders_status_groups_id` int(11) NOT NULL AUTO_INCREMENT,
  `language_id` int(11) NOT NULL DEFAULT '1',
  `orders_status_groups_name` varchar(32) NOT NULL DEFAULT '',
  `orders_status_groups_color` varchar(16) NOT NULL DEFAULT '',
  `orders_status_type_id` int(11) NOT NULL DEFAULT '0',
  `order_group_evaluation_state_id` int(11) NOT NULL DEFAULT '0',
  `orders_status_groups_store_temporary` tinyint(1) NOT NULL DEFAULT '0',
  `orders_status_groups_send_ga` tinyint(1) NOT NULL DEFAULT '0',
  `sort_order` int(5) NOT NULL DEFAULT '0',
  PRIMARY KEY (`orders_status_groups_id`,`language_id`)
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_status_groups`
--

LOCK TABLES `orders_status_groups` WRITE;
/*!40000 ALTER TABLE `orders_status_groups` DISABLE KEYS */;
INSERT INTO `orders_status_groups` VALUES (1,1,'New Orders','#feae03',1,0,1,0,1),(2,1,'Processing Orders','#0060bf',1,0,0,0,2),(3,1,'Partly Completed Orders','#0060bf',1,0,0,0,3),(4,1,'Completed Orders','#1fbc27',1,0,0,0,4),(5,1,'Cancelled Orders','#f62f1a',1,0,0,0,5),(6,1,'Subscription','',2,0,0,0,6),(7,1,'Quotation','',3,0,0,0,7),(8,1,'Samples','',4,0,0,0,8),(9,1,'Purchase Orders','',5,0,0,0,9);
/*!40000 ALTER TABLE `orders_status_groups` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_status_history`
--

DROP TABLE IF EXISTS `orders_status_history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_status_history` (
  `orders_status_history_id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `orders_status_id` int(5) NOT NULL DEFAULT '0',
  `date_added` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `customer_notified` int(1) DEFAULT '0',
  `comments` text,
  `admin_id` int(11) NOT NULL DEFAULT '0',
  `smscomments` text,
  PRIMARY KEY (`orders_status_history_id`),
  KEY `orders_id` (`orders_id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_status_history`
--

LOCK TABLES `orders_status_history` WRITE;
/*!40000 ALTER TABLE `orders_status_history` DISABLE KEYS */;
INSERT INTO `orders_status_history` VALUES (1,2,3,'0000-00-00 00:00:00',0,'',0,NULL),(2,3,3,'0000-00-00 00:00:00',0,'',0,NULL),(3,4,100001,'0000-00-00 00:00:00',0,'',0,NULL);
/*!40000 ALTER TABLE `orders_status_history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_status_to_design_template`
--

DROP TABLE IF EXISTS `orders_status_to_design_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_status_to_design_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_status_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `email_design_template` varchar(256) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_status_to_design_template`
--

LOCK TABLES `orders_status_to_design_template` WRITE;
/*!40000 ALTER TABLE `orders_status_to_design_template` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_status_to_design_template` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_status_type`
--

DROP TABLE IF EXISTS `orders_status_type`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_status_type` (
  `orders_status_type_id` int(11) NOT NULL AUTO_INCREMENT,
  `language_id` int(11) NOT NULL DEFAULT '1',
  `orders_status_type_name` varchar(32) NOT NULL DEFAULT '',
  `orders_status_type_color` varchar(16) NOT NULL DEFAULT '',
  PRIMARY KEY (`orders_status_type_id`,`language_id`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_status_type`
--

LOCK TABLES `orders_status_type` WRITE;
/*!40000 ALTER TABLE `orders_status_type` DISABLE KEYS */;
INSERT INTO `orders_status_type` VALUES (1,1,'Orders',''),(1,3,'Orders',''),(1,10,'Orders',''),(1,11,'Orders',''),(1,12,'Orders',''),(1,13,'Orders',''),(1,15,'Orders',''),(1,17,'Orders',''),(1,26,'Orders',''),(1,28,'Orders',''),(1,29,'Orders',''),(2,1,'Subscriptions',''),(2,3,'Subscriptions',''),(2,10,'Subscriptions',''),(2,11,'Subscriptions',''),(2,12,'Subscriptions',''),(2,13,'Subscriptions',''),(2,15,'Subscriptions',''),(2,17,'Subscriptions',''),(2,26,'Subscriptions',''),(2,28,'Subscriptions',''),(2,29,'Subscriptions',''),(3,1,'Quotations',''),(3,3,'Quotations',''),(3,10,'Quotations',''),(3,11,'Quotations',''),(3,12,'Quotations',''),(3,13,'Quotations',''),(3,15,'Quotations',''),(3,17,'Quotations',''),(3,26,'Quotations',''),(3,28,'Quotations',''),(3,29,'Quotations',''),(4,1,'Samples',''),(4,3,'Samples',''),(4,10,'Samples',''),(4,11,'Samples',''),(4,12,'Samples',''),(4,13,'Samples',''),(4,15,'Samples',''),(4,17,'Samples',''),(4,26,'Samples',''),(4,28,'Samples',''),(4,29,'Samples',''),(5,1,'Purchase orders',''),(5,3,'Purchase orders',''),(5,10,'Purchase orders',''),(5,11,'Purchase orders',''),(5,12,'Purchase orders',''),(5,13,'Purchase orders',''),(5,15,'Purchase orders',''),(5,17,'Purchase orders',''),(5,26,'Purchase orders',''),(5,28,'Purchase orders',''),(5,29,'Purchase orders','');
/*!40000 ALTER TABLE `orders_status_type` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_total`
--

DROP TABLE IF EXISTS `orders_total`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_total` (
  `orders_total_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `title` varchar(255) NOT NULL DEFAULT '',
  `text` varchar(255) NOT NULL DEFAULT '',
  `value` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `class` varchar(32) NOT NULL DEFAULT '',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `text_inc_tax` varchar(255) DEFAULT NULL,
  `text_exc_tax` varchar(255) DEFAULT NULL,
  `tax_class_id` int(11) NOT NULL DEFAULT '0',
  `value_inc_tax` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `value_exc_vat` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `is_removed` tinyint(4) DEFAULT '0',
  `currency` char(3) NOT NULL DEFAULT '',
  `currency_value` decimal(14,6) NOT NULL DEFAULT '0.000000',
  PRIMARY KEY (`orders_total_id`),
  KEY `idx_orders_total_orders_id` (`orders_id`),
  KEY `idx_sort_order` (`sort_order`),
  KEY `class` (`class`)
) ENGINE=InnoDB AUTO_INCREMENT=21 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_total`
--

LOCK TABLES `orders_total` WRITE;
/*!40000 ALTER TABLE `orders_total` DISABLE KEYS */;
INSERT INTO `orders_total` VALUES (1,2,'Sub-Total:','£1,303.48',1303.480000,'ot_subtotal',300,'£1,303.48','£1,303.48',0,1303.480000,1303.480000,0,'GBP',1.000000),(2,2,'3-5 days delivery (Best Way):','£5.00',5.000000,'ot_shipping',304,'£5.00','£5.00',0,5.000000,5.000000,0,'GBP',1.000000),(3,2,'Total:','£1,308.48',1308.480000,'ot_total',311,'£1,308.48','£1,308.48',0,1308.480000,1308.480000,0,'GBP',1.000000),(4,2,'Amount Paid:','£1,308.48',1308.480000,'ot_paid',312,'£1,308.48','£1,308.48',0,1308.480000,1308.480000,0,'GBP',1.000000),(5,2,'Amount Due:','£0.00',0.000000,'ot_due',313,'£0.00','£0.00',0,0.000000,0.000000,0,'GBP',1.000000),(6,2,'Amount Refunded:','£0.00',0.000000,'ot_refund',314,'£0.00','£0.00',0,0.000000,0.000000,0,'GBP',1.000000),(7,3,'Sub-Total:','£69.99',69.990000,'ot_subtotal',300,'£69.99','£58.33',0,69.990000,58.330000,0,'GBP',1.000000),(8,3,'3-5 days delivery (Best Way):','£6.00',6.000000,'ot_shipping',304,'£6.00','£5.00',0,6.000000,5.000000,0,'GBP',1.000000),(9,3,'VAT 20%:','£12.67',12.665000,'ot_tax',310,'£12.67','£12.67',0,12.665000,12.665000,0,'GBP',1.000000),(10,3,'Total:','£75.99',75.990000,'ot_total',311,'£75.99','£63.33',0,75.990000,63.330000,0,'GBP',1.000000),(11,3,'Amount Paid:','£75.99',75.990000,'ot_paid',312,'£75.99','£75.99',0,75.990000,75.990000,0,'GBP',1.000000),(12,3,'Amount Due:','£0.00',0.000000,'ot_due',313,'£0.00','-£12.66',0,0.000000,-12.660000,0,'GBP',1.000000),(13,3,'Amount Refunded:','£0.00',0.000000,'ot_refund',314,'£0.00','£0.00',0,0.000000,0.000000,0,'GBP',1.000000),(14,4,'Sub-Total:','£189.00',189.000000,'ot_subtotal',300,'£189.00','£157.50',0,189.000000,157.500000,0,'GBP',1.000000),(15,4,'3-5 days delivery (Best Way):','£6.00',6.000000,'ot_shipping',304,'£6.00','£5.00',0,6.000000,5.000000,0,'GBP',1.000000),(16,4,'VAT 20%:','£32.50',32.500000,'ot_tax',310,'£32.50','£32.50',0,32.500000,32.500000,0,'GBP',1.000000),(17,4,'Total:','£195.00',195.000000,'ot_total',311,'£195.00','£162.50',0,195.000000,162.500000,0,'GBP',1.000000),(18,4,'Amount Paid:','£195.00',195.000000,'ot_paid',312,'£195.00','£195.00',0,195.000000,195.000000,0,'GBP',1.000000),(19,4,'Amount Due:','£0.00',0.000000,'ot_due',313,'£0.00','-£32.50',0,0.000000,-32.500000,0,'GBP',1.000000),(20,4,'Amount Refunded:','£0.00',0.000000,'ot_refund',314,'£0.00','£0.00',0,0.000000,0.000000,0,'GBP',1.000000);
/*!40000 ALTER TABLE `orders_total` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_transactions`
--

DROP TABLE IF EXISTS `orders_transactions`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_transactions` (
  `orders_transactions_id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_id` int(11) DEFAULT NULL,
  `transaction_id` varchar(128) DEFAULT NULL,
  `payment_class` varchar(64) DEFAULT NULL,
  `transaction_amount` decimal(15,2) DEFAULT NULL,
  `transaction_currency` varchar(3) DEFAULT NULL,
  `transaction_status` varchar(128) DEFAULT NULL,
  `comments` text,
  `date_created` datetime DEFAULT NULL,
  `admin_id` int(11) DEFAULT NULL,
  `splinters_suborder_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`orders_transactions_id`),
  KEY `idx_orders_id` (`orders_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_transactions`
--

LOCK TABLES `orders_transactions` WRITE;
/*!40000 ALTER TABLE `orders_transactions` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_transactions` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `orders_transactions_children`
--

DROP TABLE IF EXISTS `orders_transactions_children`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `orders_transactions_children` (
  `orders_transactions_child_id` int(11) NOT NULL AUTO_INCREMENT,
  `orders_transactions_id` int(11) DEFAULT NULL,
  `transaction_id` varchar(128) DEFAULT NULL,
  `transaction_amount` decimal(15,2) DEFAULT NULL,
  `transaction_currency` varchar(3) DEFAULT NULL,
  `transaction_status` varchar(128) DEFAULT NULL,
  `comments` text,
  `date_created` datetime DEFAULT NULL,
  `admin_id` int(11) DEFAULT NULL,
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `splinters_suborder_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`orders_transactions_child_id`),
  KEY `idx_orders_transactions_id` (`orders_transactions_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `orders_transactions_children`
--

LOCK TABLES `orders_transactions_children` WRITE;
/*!40000 ALTER TABLE `orders_transactions_children` DISABLE KEYS */;
/*!40000 ALTER TABLE `orders_transactions_children` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `page_status`
--

DROP TABLE IF EXISTS `page_status`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `page_status` (
  `page_status_id` int(11) NOT NULL AUTO_INCREMENT,
  `type` varchar(64) DEFAULT NULL,
  `page_id` int(11) NOT NULL DEFAULT '0',
  `status` varchar(64) DEFAULT NULL,
  PRIMARY KEY (`page_status_id`),
  KEY `page_status_type_status_idx` (`type`,`status`),
  KEY `page_status_type_page_id_idx` (`type`,`page_id`)
) ENGINE=InnoDB AUTO_INCREMENT=21 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `page_status`
--

LOCK TABLES `page_status` WRITE;
/*!40000 ALTER TABLE `page_status` DISABLE KEYS */;
INSERT INTO `page_status` VALUES (1,'information',9,'public'),(2,'information',12,'public'),(3,'information',13,'public'),(4,'information',17,'public'),(5,'information',19,'public'),(6,'information',21,'public'),(7,'information',22,'public'),(8,'information',28,'public'),(9,'information',29,'public'),(10,'information',30,'public'),(11,'information',36,'public'),(12,'information',0,'draft'),(13,'information',37,'public'),(14,'information',38,'public'),(15,'information',39,'public'),(16,'information',40,'draft'),(17,'information',41,'public'),(18,'information',42,'public'),(19,'information',43,'public'),(20,'information',44,'public');
/*!40000 ALTER TABLE `page_status` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `page_status_switch`
--

DROP TABLE IF EXISTS `page_status_switch`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `page_status_switch` (
  `page_status_switch_id` int(11) NOT NULL AUTO_INCREMENT,
  `page_status_id` int(11) NOT NULL DEFAULT '0',
  `status` varchar(64) DEFAULT NULL,
  `period` varchar(64) DEFAULT NULL,
  `date` datetime DEFAULT NULL,
  PRIMARY KEY (`page_status_switch_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `page_status_switch`
--

LOCK TABLES `page_status_switch` WRITE;
/*!40000 ALTER TABLE `page_status_switch` DISABLE KEYS */;
/*!40000 ALTER TABLE `page_status_switch` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `page_styles`
--

DROP TABLE IF EXISTS `page_styles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `page_styles` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `style` varchar(256) DEFAULT NULL,
  `type` varchar(256) DEFAULT NULL,
  `page_id` int(11) DEFAULT NULL,
  `platform_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `page_styles`
--

LOCK TABLES `page_styles` WRITE;
/*!40000 ALTER TABLE `page_styles` DISABLE KEYS */;
/*!40000 ALTER TABLE `page_styles` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `payment_fee`
--

DROP TABLE IF EXISTS `payment_fee`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `payment_fee` (
  `payment_fee_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `payment_code` varchar(64) DEFAULT NULL,
  `percent_prefix` int(4) NOT NULL DEFAULT '1',
  `percent_value` double(11,2) NOT NULL DEFAULT '0.00',
  `fixed_prefix` int(4) NOT NULL DEFAULT '1',
  `fixed_value` decimal(11,2) NOT NULL DEFAULT '0.00',
  `minimum_order` decimal(11,2) NOT NULL DEFAULT '0.00',
  `maximum_order` decimal(11,2) NOT NULL DEFAULT '0.00',
  PRIMARY KEY (`payment_fee_id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `payment_fee`
--

LOCK TABLES `payment_fee` WRITE;
/*!40000 ALTER TABLE `payment_fee` DISABLE KEYS */;
INSERT INTO `payment_fee` VALUES (1,1,'cod',1,0.00,1,0.00,0.00,0.00);
/*!40000 ALTER TABLE `payment_fee` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `payment_offline`
--

DROP TABLE IF EXISTS `payment_offline`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `payment_offline` (
  `payment_offline_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `payment_offline_title` varchar(64) DEFAULT NULL,
  `payment_offline_description` text,
  `sort_order` tinyint(1) NOT NULL DEFAULT '0',
  `status` int(1) NOT NULL DEFAULT '1'
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `payment_offline`
--

LOCK TABLES `payment_offline` WRITE;
/*!40000 ALTER TABLE `payment_offline` DISABLE KEYS */;
INSERT INTO `payment_offline` VALUES (2,3,1,'Cash on Delivery','',2,1),(2,3,3,'Cash on Delivery','',2,1),(2,3,10,'Cash on Delivery','',2,1),(2,3,11,'Cash on Delivery','',2,1),(2,3,12,'Cash on Delivery','',2,1),(2,3,13,'Cash on Delivery','',2,1),(2,3,15,'Cash on Delivery','',2,1),(2,3,17,'Cash on Delivery','',2,1),(3,2,1,'Cash on Delivery','',3,1),(3,2,3,'Cash on Delivery','',3,1),(3,2,10,'Cash on Delivery','',3,1),(3,2,11,'Cash on Delivery','',3,1),(3,2,12,'Cash on Delivery','',3,1),(3,2,13,'Cash on Delivery','',3,1),(3,2,15,'Cash on Delivery','',3,1),(3,2,17,'Cash on Delivery','',3,1),(4,1,1,'Cash on Delivery','',1,1),(5,1,3,'Cash on Delivery','',1,1),(6,1,10,'Cash on Delivery','',1,1),(7,1,11,'Cash on Delivery','',1,1),(8,1,12,'Cash on Delivery','',1,1),(9,1,13,'Cash on Delivery','',1,1),(10,1,15,'Cash on Delivery','',1,1),(11,1,17,'Cash on Delivery','',1,1),(12,7,1,'Cash on Delivery','',1,1),(13,7,3,'Cash on Delivery','',1,1),(14,7,10,'Cash on Delivery','',1,1),(15,7,11,'Cash on Delivery','',1,1),(16,7,12,'Cash on Delivery','',1,1),(17,7,13,'Cash on Delivery','',1,1),(18,7,15,'Cash on Delivery','',1,1),(19,7,17,'Cash on Delivery','',1,1);
/*!40000 ALTER TABLE `payment_offline` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `payment_tokens`
--

DROP TABLE IF EXISTS `payment_tokens`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `payment_tokens` (
  `payment_tokens_id` int(11) NOT NULL AUTO_INCREMENT,
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `payment_class` varchar(127) NOT NULL DEFAULT '',
  `card_name` varchar(200) NOT NULL DEFAULT '',
  `card_type` varchar(20) NOT NULL DEFAULT '',
  `exp_date` varchar(10) NOT NULL DEFAULT '',
  `last_digits` varchar(20) NOT NULL DEFAULT '',
  `token` varchar(8096) NOT NULL DEFAULT '',
  `is_default` smallint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`payment_tokens_id`),
  KEY `IDX_customers_id` (`customers_id`),
  KEY `IDX_payment_class` (`payment_class`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `payment_tokens`
--

LOCK TABLES `payment_tokens` WRITE;
/*!40000 ALTER TABLE `payment_tokens` DISABLE KEYS */;
/*!40000 ALTER TABLE `payment_tokens` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paypal`
--

DROP TABLE IF EXISTS `paypal`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `paypal` (
  `paypal_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `txn_type` varchar(10) NOT NULL DEFAULT '',
  `reason_code` varchar(15) DEFAULT NULL,
  `payment_type` varchar(7) NOT NULL DEFAULT '',
  `payment_status` varchar(17) NOT NULL DEFAULT '',
  `pending_reason` varchar(14) DEFAULT NULL,
  `invoice` varchar(64) DEFAULT NULL,
  `mc_currency` char(3) NOT NULL DEFAULT '',
  `first_name` varchar(32) NOT NULL DEFAULT '',
  `last_name` varchar(32) NOT NULL DEFAULT '',
  `payer_business_name` varchar(64) DEFAULT NULL,
  `address_name` varchar(32) DEFAULT NULL,
  `address_street` varchar(64) DEFAULT NULL,
  `address_city` varchar(32) DEFAULT NULL,
  `address_state` varchar(32) DEFAULT NULL,
  `address_zip` varchar(10) DEFAULT NULL,
  `address_country` varchar(64) DEFAULT NULL,
  `address_status` varchar(11) DEFAULT NULL,
  `payer_email` varchar(96) NOT NULL DEFAULT '',
  `payer_id` varchar(32) NOT NULL DEFAULT '',
  `payer_status` varchar(10) NOT NULL DEFAULT '',
  `payment_date` datetime DEFAULT NULL,
  `payment_time_zone` varchar(4) NOT NULL DEFAULT '',
  `business` varchar(96) NOT NULL DEFAULT '',
  `receiver_email` varchar(96) NOT NULL DEFAULT '',
  `receiver_id` varchar(32) NOT NULL DEFAULT '',
  `txn_id` varchar(17) NOT NULL DEFAULT '',
  `parent_txn_id` varchar(17) DEFAULT NULL,
  `num_cart_items` tinyint(4) unsigned NOT NULL DEFAULT '1',
  `mc_gross` decimal(7,2) NOT NULL DEFAULT '0.00',
  `mc_fee` decimal(7,2) NOT NULL DEFAULT '0.00',
  `payment_gross` decimal(7,2) DEFAULT NULL,
  `payment_fee` decimal(7,2) DEFAULT NULL,
  `settle_amount` decimal(7,2) DEFAULT NULL,
  `settle_currency` char(3) DEFAULT NULL,
  `exchange_rate` decimal(4,2) DEFAULT NULL,
  `quantity` int(11) NOT NULL DEFAULT '0',
  `tax` decimal(7,2) DEFAULT NULL,
  `notify_version` decimal(2,1) NOT NULL DEFAULT '0.0',
  `verify_sign` varchar(128) NOT NULL DEFAULT '',
  `last_modified` datetime DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  `memo` text,
  PRIMARY KEY (`paypal_id`),
  UNIQUE KEY `txn_id` (`txn_id`),
  KEY `parent_txn_id` (`parent_txn_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paypal`
--

LOCK TABLES `paypal` WRITE;
/*!40000 ALTER TABLE `paypal` DISABLE KEYS */;
/*!40000 ALTER TABLE `paypal` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paypal_checkout`
--

DROP TABLE IF EXISTS `paypal_checkout`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `paypal_checkout` (
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `txn_signature` varchar(32) NOT NULL DEFAULT '',
  `checkout_info` text NOT NULL,
  PRIMARY KEY (`orders_id`),
  UNIQUE KEY `txn_signature` (`txn_signature`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paypal_checkout`
--

LOCK TABLES `paypal_checkout` WRITE;
/*!40000 ALTER TABLE `paypal_checkout` DISABLE KEYS */;
/*!40000 ALTER TABLE `paypal_checkout` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paypal_payment_status_history`
--

DROP TABLE IF EXISTS `paypal_payment_status_history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `paypal_payment_status_history` (
  `payment_status_history_id` int(11) NOT NULL AUTO_INCREMENT,
  `paypal_id` int(11) NOT NULL DEFAULT '0',
  `payment_status` varchar(17) NOT NULL DEFAULT '',
  `pending_reason` varchar(14) DEFAULT NULL,
  `reason_code` varchar(15) DEFAULT NULL,
  `date_added` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (`payment_status_history_id`),
  KEY `paypal_id` (`paypal_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paypal_payment_status_history`
--

LOCK TABLES `paypal_payment_status_history` WRITE;
/*!40000 ALTER TABLE `paypal_payment_status_history` DISABLE KEYS */;
/*!40000 ALTER TABLE `paypal_payment_status_history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paypal_seller_info`
--

DROP TABLE IF EXISTS `paypal_seller_info`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `paypal_seller_info` (
  `psi_id` int(11) NOT NULL AUTO_INCREMENT,
  `partner_id` varchar(32) NOT NULL DEFAULT '',
  `fee_percent` float NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `tracking_id` varchar(127) NOT NULL DEFAULT '',
  `email_address` varchar(64) NOT NULL DEFAULT '',
  `payer_id` varchar(32) NOT NULL DEFAULT '',
  `entry_company` varchar(32) NOT NULL DEFAULT '',
  `entry_firstname` varchar(32) NOT NULL DEFAULT '',
  `entry_lastname` varchar(32) NOT NULL DEFAULT '',
  `entry_street_address` varchar(64) NOT NULL DEFAULT '',
  `entry_suburb` varchar(32) DEFAULT NULL,
  `entry_postcode` varchar(10) NOT NULL DEFAULT '',
  `entry_city` varchar(32) NOT NULL DEFAULT '',
  `entry_state` varchar(32) DEFAULT NULL,
  `entry_country_id` int(11) NOT NULL DEFAULT '0',
  `entry_zone_id` int(11) NOT NULL DEFAULT '0',
  `is_onboard` int(1) NOT NULL DEFAULT '0',
  `entry_telephone` varchar(32) NOT NULL DEFAULT '',
  `fee_editable` int(1) NOT NULL DEFAULT '0',
  `own_client_id` varchar(255) NOT NULL DEFAULT '',
  `own_client_secret` varchar(255) NOT NULL DEFAULT '',
  `paypal_partner_ccp_status` int(1) NOT NULL DEFAULT '0',
  `three_ds_settings` varchar(4096) NOT NULL DEFAULT '',
  `boarding_json` text NOT NULL,
  `boarding_date` date NOT NULL DEFAULT '0000-00-00',
  `status` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`psi_id`)
) ENGINE=InnoDB AUTO_INCREMENT=14 DEFAULT CHARSET=utf8mb4;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paypal_seller_info`
--

LOCK TABLES `paypal_seller_info` WRITE;
/*!40000 ALTER TABLE `paypal_seller_info` DISABLE KEYS */;
INSERT INTO `paypal_seller_info` VALUES (1,'9TZHDRH8BP3US',0,1,'KZMazwzbTzynYl47qoQYpKArHWtmMiPxNAF3B-QojDG1UtSTRKWrtCGVwOPxclm-WYUHhGKAP8RHibHZxNRwMW6IUI7DxLpUtcmmH6VgPXVVKKRoWhedWxBoxIGknr0','','','','','','5 jupiter house',NULL,'RG7 8NN','',NULL,222,0,1,'0123456789',0,'','',0,'[]','','0000-00-00',0),(3,'88LZN7N3UWLF8',0,1,'aTbP64F8JTyv7Ngh4AktKkd5YcerJdeZItxsplBlzpQ-_cn9ZU3Sq0tD5bIe95VcmKYwy_6zE10g__LaKp5JbZxxki1KgLGvp1rHPevuKBjgLVM1rj0DNKYrR77AAJ7','info@oscommerce.com','KDKM8LNUKAQL4','','osC4','','5 jupiter house','','RG7 8NN','','',222,0,1,'0123456789',0,'Ad1UJlMj9BKThV6rWyktLD5ggqp2uL4iFnFtYIKwAcKULWu3OoaGHw4NO2v8bmx86-6RIcWB_LoSOGsr','EIJD-t20vHM2Ke8UTMT8v3OGrnKhd92cvbJQpd8yYzoJOxEmdwQNTvJuVigwlFarsuXBA59kkp85Edo6',0,'[]','{\"merchant_id\":\"KDKM8LNUKAQL4\",\"tracking_id\":\"info@oscommerce.com\",\"products\":[{\"name\":\"PPCP_CUSTOM\",\"vetting_status\":\"SUBSCRIBED\",\"capabilities\":[\"AMEX_OPTBLUE\",\"CARD_PROCESSING_VIRTUAL_TERMINAL\",\"COMMERCIAL_ENTITY\",\"CUSTOM_CARD_PROCESSING\",\"DEBIT_CARD_SWITCH\",\"FRAUD_TOOL_ACCESS\"]},{\"name\":\"PPCP_STANDARD\",\"vetting_status\":\"SUBSCRIBED\",\"capabilities\":[]},{\"name\":\"MOBILE_PAYMENT_ACCEPTANCE\",\"status\":\"ACTIVE\"}],\"capabilities\":[{\"name\":\"CARD_PROCESSING_VIRTUAL_TERMINAL\",\"status\":\"ACTIVE\"},{\"name\":\"AMEX_OPTBLUE\",\"status\":\"ACTIVE\"},{\"name\":\"DEBIT_CARD_SWITCH\",\"status\":\"ACTIVE\"},{\"name\":\"FRAUD_TOOL_ACCESS\",\"status\":\"ACTIVE\"},{\"name\":\"COMMERCIAL_ENTITY\",\"status\":\"ACTIVE\"},{\"name\":\"CUSTOM_CARD_PROCESSING\",\"status\":\"ACTIVE\"}],\"payments_receivable\":true,\"legal_name\":\"Test Store\",\"primary_email_confirmed\":true}','2023-10-05',1),(4,'9TZHDRH8BP3US',0,7,'7ZMazwzbTzynYl47qoQYpKArHWtmMiPxNAF3B-QojDG1UtSTRKWrtCGVwOPxclm-WYUHhGKAP8RHibHZxNRwMW6IUI7DxLpUtcmmH6VgPXVVKKRoWhedWxBoxIGknr0','','','','','','5 jupiter house',NULL,'RG7 8NN','',NULL,222,0,1,'0123456789',0,'','',0,'[]','','0000-00-00',0),(5,'88LZN7N3UWLF8',0,7,'7TbP64F8JTyv7Ngh4AktKkd5YcerJdeZItxsplBlzpQ-_cn9ZU3Sq0tD5bIe95VcmKYwy_6zE10g__LaKp5JbZxxki1KgLGvp1rHPevuKBjgLVM1rj0DNKYrR77AAJ7','info@oscommerce.com','KDKM8LNUKAQL4','','osC4','','5 jupiter house','','RG7 8NN','','',222,0,1,'0123456789',0,'Ad1UJlMj9BKThV6rWyktLD5ggqp2uL4iFnFtYIKwAcKULWu3OoaGHw4NO2v8bmx86-6RIcWB_LoSOGsr','EIJD-t20vHM2Ke8UTMT8v3OGrnKhd92cvbJQpd8yYzoJOxEmdwQNTvJuVigwlFarsuXBA59kkp85Edo6',0,'[]','{\"merchant_id\":\"KDKM8LNUKAQL4\",\"tracking_id\":\"info@oscommerce.com\",\"products\":[{\"name\":\"PPCP_CUSTOM\",\"vetting_status\":\"SUBSCRIBED\",\"capabilities\":[\"AMEX_OPTBLUE\",\"CARD_PROCESSING_VIRTUAL_TERMINAL\",\"COMMERCIAL_ENTITY\",\"CUSTOM_CARD_PROCESSING\",\"DEBIT_CARD_SWITCH\",\"FRAUD_TOOL_ACCESS\"]},{\"name\":\"PPCP_STANDARD\",\"vetting_status\":\"SUBSCRIBED\",\"capabilities\":[]},{\"name\":\"MOBILE_PAYMENT_ACCEPTANCE\",\"status\":\"ACTIVE\"}],\"capabilities\":[{\"name\":\"CARD_PROCESSING_VIRTUAL_TERMINAL\",\"status\":\"ACTIVE\"},{\"name\":\"AMEX_OPTBLUE\",\"status\":\"ACTIVE\"},{\"name\":\"DEBIT_CARD_SWITCH\",\"status\":\"ACTIVE\"},{\"name\":\"FRAUD_TOOL_ACCESS\",\"status\":\"ACTIVE\"},{\"name\":\"COMMERCIAL_ENTITY\",\"status\":\"ACTIVE\"},{\"name\":\"CUSTOM_CARD_PROCESSING\",\"status\":\"ACTIVE\"}],\"payments_receivable\":true,\"legal_name\":\"Test Store\",\"primary_email_confirmed\":true}','2023-10-05',1),(6,'9TZHDRH8BP3US',0,8,'8ZMazwzbTzynYl47qoQYpKArHWtmMiPxNAF3B-QojDG1UtSTRKWrtCGVwOPxclm-WYUHhGKAP8RHibHZxNRwMW6IUI7DxLpUtcmmH6VgPXVVKKRoWhedWxBoxIGknr0','','','','','','5 jupiter house',NULL,'RG7 8NN','',NULL,222,0,1,'0123456789',0,'','',0,'[]','','0000-00-00',0),(7,'88LZN7N3UWLF8',0,8,'8TbP64F8JTyv7Ngh4AktKkd5YcerJdeZItxsplBlzpQ-_cn9ZU3Sq0tD5bIe95VcmKYwy_6zE10g__LaKp5JbZxxki1KgLGvp1rHPevuKBjgLVM1rj0DNKYrR77AAJ7','info@oscommerce.com','KDKM8LNUKAQL4','','osC4','','5 jupiter house','','RG7 8NN','','',222,0,1,'0123456789',0,'Ad1UJlMj9BKThV6rWyktLD5ggqp2uL4iFnFtYIKwAcKULWu3OoaGHw4NO2v8bmx86-6RIcWB_LoSOGsr','EIJD-t20vHM2Ke8UTMT8v3OGrnKhd92cvbJQpd8yYzoJOxEmdwQNTvJuVigwlFarsuXBA59kkp85Edo6',0,'[]','{\"merchant_id\":\"KDKM8LNUKAQL4\",\"tracking_id\":\"info@oscommerce.com\",\"products\":[{\"name\":\"PPCP_CUSTOM\",\"vetting_status\":\"SUBSCRIBED\",\"capabilities\":[\"AMEX_OPTBLUE\",\"CARD_PROCESSING_VIRTUAL_TERMINAL\",\"COMMERCIAL_ENTITY\",\"CUSTOM_CARD_PROCESSING\",\"DEBIT_CARD_SWITCH\",\"FRAUD_TOOL_ACCESS\"]},{\"name\":\"PPCP_STANDARD\",\"vetting_status\":\"SUBSCRIBED\",\"capabilities\":[]},{\"name\":\"MOBILE_PAYMENT_ACCEPTANCE\",\"status\":\"ACTIVE\"}],\"capabilities\":[{\"name\":\"CARD_PROCESSING_VIRTUAL_TERMINAL\",\"status\":\"ACTIVE\"},{\"name\":\"AMEX_OPTBLUE\",\"status\":\"ACTIVE\"},{\"name\":\"DEBIT_CARD_SWITCH\",\"status\":\"ACTIVE\"},{\"name\":\"FRAUD_TOOL_ACCESS\",\"status\":\"ACTIVE\"},{\"name\":\"COMMERCIAL_ENTITY\",\"status\":\"ACTIVE\"},{\"name\":\"CUSTOM_CARD_PROCESSING\",\"status\":\"ACTIVE\"}],\"payments_receivable\":true,\"legal_name\":\"Test Store\",\"primary_email_confirmed\":true}','2023-10-05',1),(8,'9TZHDRH8BP3US',0,9,'9ZMazwzbTzynYl47qoQYpKArHWtmMiPxNAF3B-QojDG1UtSTRKWrtCGVwOPxclm-WYUHhGKAP8RHibHZxNRwMW6IUI7DxLpUtcmmH6VgPXVVKKRoWhedWxBoxIGknr0','','','','','','5 jupiter house',NULL,'RG7 8NN','',NULL,222,0,1,'0123456789',0,'','',0,'[]','','0000-00-00',0),(9,'88LZN7N3UWLF8',0,9,'9TbP64F8JTyv7Ngh4AktKkd5YcerJdeZItxsplBlzpQ-_cn9ZU3Sq0tD5bIe95VcmKYwy_6zE10g__LaKp5JbZxxki1KgLGvp1rHPevuKBjgLVM1rj0DNKYrR77AAJ7','info@oscommerce.com','KDKM8LNUKAQL4','','osC4','','5 jupiter house','','RG7 8NN','','',222,0,1,'0123456789',0,'Ad1UJlMj9BKThV6rWyktLD5ggqp2uL4iFnFtYIKwAcKULWu3OoaGHw4NO2v8bmx86-6RIcWB_LoSOGsr','EIJD-t20vHM2Ke8UTMT8v3OGrnKhd92cvbJQpd8yYzoJOxEmdwQNTvJuVigwlFarsuXBA59kkp85Edo6',0,'[]','{\"merchant_id\":\"KDKM8LNUKAQL4\",\"tracking_id\":\"info@oscommerce.com\",\"products\":[{\"name\":\"PPCP_CUSTOM\",\"vetting_status\":\"SUBSCRIBED\",\"capabilities\":[\"AMEX_OPTBLUE\",\"CARD_PROCESSING_VIRTUAL_TERMINAL\",\"COMMERCIAL_ENTITY\",\"CUSTOM_CARD_PROCESSING\",\"DEBIT_CARD_SWITCH\",\"FRAUD_TOOL_ACCESS\"]},{\"name\":\"PPCP_STANDARD\",\"vetting_status\":\"SUBSCRIBED\",\"capabilities\":[]},{\"name\":\"MOBILE_PAYMENT_ACCEPTANCE\",\"status\":\"ACTIVE\"}],\"capabilities\":[{\"name\":\"CARD_PROCESSING_VIRTUAL_TERMINAL\",\"status\":\"ACTIVE\"},{\"name\":\"AMEX_OPTBLUE\",\"status\":\"ACTIVE\"},{\"name\":\"DEBIT_CARD_SWITCH\",\"status\":\"ACTIVE\"},{\"name\":\"FRAUD_TOOL_ACCESS\",\"status\":\"ACTIVE\"},{\"name\":\"COMMERCIAL_ENTITY\",\"status\":\"ACTIVE\"},{\"name\":\"CUSTOM_CARD_PROCESSING\",\"status\":\"ACTIVE\"}],\"payments_receivable\":true,\"legal_name\":\"Test Store\",\"primary_email_confirmed\":true}','2023-10-05',1),(10,'9TZHDRH8BP3US',0,10,'10MazwzbTzynYl47qoQYpKArHWtmMiPxNAF3B-QojDG1UtSTRKWrtCGVwOPxclm-WYUHhGKAP8RHibHZxNRwMW6IUI7DxLpUtcmmH6VgPXVVKKRoWhedWxBoxIGknr0','','','','','','5 jupiter house',NULL,'RG7 8NN','',NULL,222,0,1,'0123456789',0,'','',0,'[]','','0000-00-00',0),(11,'88LZN7N3UWLF8',0,10,'10bP64F8JTyv7Ngh4AktKkd5YcerJdeZItxsplBlzpQ-_cn9ZU3Sq0tD5bIe95VcmKYwy_6zE10g__LaKp5JbZxxki1KgLGvp1rHPevuKBjgLVM1rj0DNKYrR77AAJ7','info@oscommerce.com','KDKM8LNUKAQL4','','osC4','','5 jupiter house','','RG7 8NN','','',222,0,1,'0123456789',0,'Ad1UJlMj9BKThV6rWyktLD5ggqp2uL4iFnFtYIKwAcKULWu3OoaGHw4NO2v8bmx86-6RIcWB_LoSOGsr','EIJD-t20vHM2Ke8UTMT8v3OGrnKhd92cvbJQpd8yYzoJOxEmdwQNTvJuVigwlFarsuXBA59kkp85Edo6',0,'[]','{\"merchant_id\":\"KDKM8LNUKAQL4\",\"tracking_id\":\"info@oscommerce.com\",\"products\":[{\"name\":\"PPCP_CUSTOM\",\"vetting_status\":\"SUBSCRIBED\",\"capabilities\":[\"AMEX_OPTBLUE\",\"CARD_PROCESSING_VIRTUAL_TERMINAL\",\"COMMERCIAL_ENTITY\",\"CUSTOM_CARD_PROCESSING\",\"DEBIT_CARD_SWITCH\",\"FRAUD_TOOL_ACCESS\"]},{\"name\":\"PPCP_STANDARD\",\"vetting_status\":\"SUBSCRIBED\",\"capabilities\":[]},{\"name\":\"MOBILE_PAYMENT_ACCEPTANCE\",\"status\":\"ACTIVE\"}],\"capabilities\":[{\"name\":\"CARD_PROCESSING_VIRTUAL_TERMINAL\",\"status\":\"ACTIVE\"},{\"name\":\"AMEX_OPTBLUE\",\"status\":\"ACTIVE\"},{\"name\":\"DEBIT_CARD_SWITCH\",\"status\":\"ACTIVE\"},{\"name\":\"FRAUD_TOOL_ACCESS\",\"status\":\"ACTIVE\"},{\"name\":\"COMMERCIAL_ENTITY\",\"status\":\"ACTIVE\"},{\"name\":\"CUSTOM_CARD_PROCESSING\",\"status\":\"ACTIVE\"}],\"payments_receivable\":true,\"legal_name\":\"Test Store\",\"primary_email_confirmed\":true}','2023-10-05',1);
/*!40000 ALTER TABLE `paypal_seller_info` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paypalipn_txn`
--

DROP TABLE IF EXISTS `paypalipn_txn`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `paypalipn_txn` (
  `paypalipn_txn_id` int(11) NOT NULL AUTO_INCREMENT,
  `txn_id` varchar(17) NOT NULL DEFAULT '',
  `ipn_result` varchar(10) NOT NULL DEFAULT '',
  `receiver_email` varchar(255) NOT NULL DEFAULT '',
  `business` varchar(255) NOT NULL DEFAULT '',
  `item_name` varchar(96) NOT NULL DEFAULT '',
  `item_number` int(11) NOT NULL DEFAULT '0',
  `quantity` int(11) NOT NULL DEFAULT '0',
  `invoice` varchar(255) NOT NULL DEFAULT '',
  `custom` varchar(255) NOT NULL DEFAULT '',
  `option_name1` varchar(255) NOT NULL DEFAULT '',
  `option_selection1` varchar(255) NOT NULL DEFAULT '',
  `option_name2` varchar(255) NOT NULL DEFAULT '',
  `option_selection2` varchar(255) NOT NULL DEFAULT '',
  `num_cart_items` int(11) NOT NULL DEFAULT '0',
  `payment_status` varchar(10) NOT NULL DEFAULT '',
  `pending_reason` varchar(10) NOT NULL DEFAULT '',
  `payment_date` varchar(100) NOT NULL DEFAULT '',
  `settle_amount` varchar(32) NOT NULL DEFAULT '',
  `settle_currency` varchar(32) NOT NULL DEFAULT '',
  `exchange_rate` varchar(32) NOT NULL DEFAULT '',
  `payment_gross` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `payment_fee` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `mc_gross` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `mc_fee` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `mc_currency` varchar(10) NOT NULL DEFAULT '',
  `tax` varchar(32) NOT NULL DEFAULT '',
  `txn_type` varchar(10) NOT NULL DEFAULT '',
  `memo` varchar(255) NOT NULL DEFAULT '',
  `first_name` varchar(32) NOT NULL DEFAULT '',
  `last_name` varchar(32) NOT NULL DEFAULT '',
  `address_street` varchar(64) NOT NULL DEFAULT '',
  `address_city` varchar(64) NOT NULL DEFAULT '',
  `address_state` varchar(64) NOT NULL DEFAULT '',
  `address_zip` varchar(10) NOT NULL DEFAULT '',
  `address_country` varchar(64) NOT NULL DEFAULT '',
  `address_status` varchar(11) NOT NULL DEFAULT '',
  `payer_email` varchar(96) NOT NULL DEFAULT '',
  `payer_id` varchar(128) NOT NULL DEFAULT '',
  `payer_status` varchar(15) NOT NULL DEFAULT '',
  `payment_type` varchar(7) NOT NULL DEFAULT '',
  `notify_version` varchar(5) NOT NULL DEFAULT '',
  `verify_sign` varchar(128) NOT NULL DEFAULT '',
  `payment_class` varchar(64) DEFAULT NULL,
  `is_assigned` int(1) DEFAULT '1',
  `platform_id` int(11) DEFAULT '0',
  PRIMARY KEY (`paypalipn_txn_id`),
  KEY `txn_id` (`txn_id`),
  KEY `idx_item_number` (`item_number`),
  KEY `idx_class` (`payment_class`),
  KEY `idx_assigned` (`is_assigned`),
  KEY `idx_platform` (`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paypalipn_txn`
--

LOCK TABLES `paypalipn_txn` WRITE;
/*!40000 ALTER TABLE `paypalipn_txn` DISABLE KEYS */;
/*!40000 ALTER TABLE `paypalipn_txn` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `pctemplates`
--

DROP TABLE IF EXISTS `pctemplates`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `pctemplates` (
  `pctemplates_id` int(11) NOT NULL AUTO_INCREMENT,
  `pctemplates_name` varchar(64) DEFAULT NULL,
  `pctemplates_image` varchar(64) DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  PRIMARY KEY (`pctemplates_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `pctemplates`
--

LOCK TABLES `pctemplates` WRITE;
/*!40000 ALTER TABLE `pctemplates` DISABLE KEYS */;
/*!40000 ALTER TABLE `pctemplates` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `pctemplates_info`
--

DROP TABLE IF EXISTS `pctemplates_info`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `pctemplates_info` (
  `pctemplates_id` int(11) NOT NULL DEFAULT '0',
  `languages_id` int(11) NOT NULL DEFAULT '0',
  `pctemplates_description` text,
  PRIMARY KEY (`pctemplates_id`,`languages_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `pctemplates_info`
--

LOCK TABLES `pctemplates_info` WRITE;
/*!40000 ALTER TABLE `pctemplates_info` DISABLE KEYS */;
/*!40000 ALTER TABLE `pctemplates_info` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `plain_products_name_search`
--

DROP TABLE IF EXISTS `plain_products_name_search`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `plain_products_name_search` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `status` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `products_name` varchar(255) NOT NULL DEFAULT '',
  `search_details` longtext NOT NULL,
  `search_soundex` longtext NOT NULL,
  `tmp_prid` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `idx_status` (`status`,`language_id`),
  KEY `idx_id_status` (`id`,`language_id`),
  KEY `idx_language` (`language_id`),
  KEY `idx_tmp_prid` (`tmp_prid`),
  KEY `idx_products_name` (`products_name`),
  FULLTEXT KEY `ft_search_details` (`search_details`)
) ENGINE=InnoDB AUTO_INCREMENT=62 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `plain_products_name_search`
--

LOCK TABLES `plain_products_name_search` WRITE;
/*!40000 ALTER TABLE `plain_products_name_search` DISABLE KEYS */;
INSERT INTO `plain_products_name_search` VALUES (1,2,1,'DKNY Women\'s NY2146 Soho Colored Chronograph Bracelet Watch','DKNY Women\'s NY2146 Soho Colored Chronograph Bracelet Watch thoroughly modern DKNY watch from the Lexington collection Case measurements 38 mm wide 38 mm long 11 mm thick Bracelet measurements 20 mm wide inches long Box measurements inches wide inches long inches high dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch DKNY NY2146 B00GN3PLU2 4053858190559 For her','',0),(2,2,1,'Puma Women\'s Motor White Polyurethane Quartz Watch with Black Dial','Puma Women\'s Motor White Polyurethane Quartz Watch with Black Dial This Puma Motor watch features combination of sporty influences and classic style for look that works well on and off the field This watch features calendar subdials and easy to read hands for quick and accurate timekeeping Case measurements 45 mm wide 12 mm thick Strap measurements 20 mm wide 7.5 inches long puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial Puma PU102742005 B0097E9NGC 0716459 41497 For her','',0),(3,2,1,'Puma Women\'s Motor Pink Polyurethane Analog Quartz Watch','Puma Women\'s Motor Pink Polyurethane Analog Quartz Watch This sporty Puma watch is constructed with comfortable pink polyurethane strap seemlessly attached to lightweight plastic case Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at o&#39;clock Case measurements 42 mm wide mm thick Strap measurements 11 mm wide 7.5 inches long puma-women-s-motor-pink-polyurethane-analog-quartz-watch Puma PU102812003 B00BCQ7A0Y 0716459418920 For her','',0),(4,2,1,'Guess Men\'s U25004L1 Silver Stainless-Steel Quartz Watch with Silver Dial','Guess Men\'s U25004L1 Silver Stainless-Steel Quartz Watch with Silver Dial Make every moment count with this splendid timepiece by Guess An intricate design and diamond detail adds class and sophistication to this versatile watch Case measurements 48 mm wide 15 mm thick Bracelet measurements 24 mm wide 8.5 inches long guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial U25004L1 B002WJ2LTA 91661370878 For him','',0),(5,2,1,'Tommy Hilfiger Men\'s Skywinder Stainless Steel and Leather Strap Watch','Tommy Hilfiger Men\'s Skywinder Stainless Steel and Leather Strap Watch This eye-catching timepiece by Tommy Hilfiger showcases dark stainless steel case on textured navy blue leather strap The deep blue dial of this men&#39;s watch includes white Arabic numeral and stick hour markers with date display at o&#39;clock tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch 11807012 B00BNY51TM 0885997014687 For him','',0),(6,2,1,'Tommy Hilfiger Men\'s 1790708 Black Silicone Sport Watch','Tommy Hilfiger Men\'s 1790708 Black Silicone Sport Watch Tommy Hilfiger Men&#39;s Sport Watch This classic timepiece by Tommy Hilfiger features Stainless steel case and Silicone Strap Black dial precise quartz movement and water-resistance level of up to 50 meters finish this fine timepiece Case measurements 44 mm in diameter 44 mm long 11 mm thick Bracelet measurements 22 mm wide inches long tommy-hilfiger-men-s-1790708-black-silicone-sport-watch 1790708 B003CUYGDW 8699031062112 For him','',0),(7,2,1,'Tommy Hilfiger Men\'s Black Silicone Quartz Watch','Tommy Hilfiger Men\'s Black Silicone Quartz Watch Show off your laid-back personality with this casual Tommy Hilfiger timepiece with bold orange accent With easy-to-read markers and comfortable strap this watch is the perfect way to stay in style and on time Hands Silvertone orange luminescen Calendar Date at o&#39;clock Case measurements 46 mm wide 14 mm thick Strap measurements 25 mm wide 8.5 inches long tommy-hilfiger-men-s-black-silicone-quartz-watch 1790853 B006G0F0TE 4015573328303 For him','',0),(8,2,1,'Gucci Men\'s YA126238 \'Timeless\' Grey Dial Stainless Steel Chrono','Gucci Men\'s YA126238 Timeless Grey Dial Stainless Steel Chrono Since 1921 the house of Gucci has been at the forefront of fashion manufacturing handbags shoes sneakers sunglasses wallets belts scarves jewelry and fashionable timepieces This timepiece features grey dial with chronograph functions Case measurements 44 mm in diameter 10 mm thick Bracelet measurements 22 mm wide inches long Box measurements inches wide inches long inches high gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono Gucci YA126238 B008B0K8JE 0731903327535 For him','',0),(9,2,1,'DKNY Women\'s NY8183 Gold Stainless Steel Quartz Watch with White zusä','DKNY Women\'s NY8183 Gold Stainless Steel Quartz Watch with White zusä Case measurements 42 wide 14 mm thick Strap/Bracelet measurements 21mm wide 7.5 inches long dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white DKNY NY8183 B004MRIAK4 4051432089015 For her','',0),(10,2,1,'Interlocking G Small Brown Dial Ladies Watch','Interlocking Small Brown Dial Ladies Watch Subdials Day date 24-hour Case measurements 45 mm wide 12 mm thick Strap measurements 20 mm wide 7.5 inches long interlocking-g-small-brown-dial-ladies-watch YA133504 B00CALV452 5249787412353 For her','',0),(11,2,1,'Gucci Women\'s YA129444 Gucci U Play Collection Stainless Steel Watch with Striped Nylon Band','Gucci Women\'s YA129444 Gucci Play Collection Stainless Steel Watch with Striped Nylon Band This sporty Puma watch is constructed with comfortable pink polyurethane strap seemlessly attached to lightweight plastic case Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at o&#39;clock Case measurements 42 mm wide mm thick Strap measurements 11 mm wide 7.5 inches long gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band Puma YA129444 B00K0D88TW 0731903349230 For her','',0),(12,2,1,'Gucci Men\'s YA133202 \'Grammy XL Interlocking\' Yellow Dial Black Leather Strap','Gucci Men\'s YA133202 Grammy XL Interlocking Yellow Dial Black Leather Strap Since 1921 the house of Gucci has been at the forefront of fashion manufacturing handbags shoes sneakers sunglasses wallets belts scarves jewelry and fashionable timepieces Case Brushed and polished black PVD coated stainless steel Bezel Brushed and polished black PVD coated stainless steel double Strap Black leather with goldtone Grammy logo pin at the 12 o&#39;clock position and embossed Gucci logo at the o&#39;clock position Special Edition GRAMMY&reg; Watch Case measurements 42 mm in diameter mm thick gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp YA133202 B00B0CCU7I 42429557413 For him','',0),(13,2,1,'Casio G-SHOCK G100-1BV Wrist Watch PRICE- 1200','Casio G-SHOCK G100-1BV Wrist Watch PRICE 1200 Profile Men Watch Design Round Face Chronograph Watch Format Anadigi Face Digital Black Subdial Face Analog Black Black Main Dial with EL Backlight Watch Casing Resin Black Wrist Band Resin Black Strap with Buckle Features 12/24hr Format Features Stopwatch (1/100 Second) Features Calendar (Auto (pre-programmed until the year 2039)) Water Resistance 656 ft Durability Water Resistant Durability Anti-magnetic Durability Shock Resistant casio-men-s-g100-1bv-g-shock-watch-in-black-resin Casio G100-1BV B000AR7S3A 4971850739050 For him For all','',0),(14,2,1,'Casio Baby-G BG169G-7B Face Protector Ion-Plated Metal White Rose Gold Watch Digital1','Casio Baby-G BG169G-7B Face Protector Ion-Plated Metal White Rose Gold Watch Digital1 This Baby-G BLX from the Tide Graph series allows for maximum fun and function in the water It features an attractive white finish with white accents as well as stopwatch 200M Water Resistance and Tide Graph (tide level for specific date and time) Subdials One Tide Graph Calendar Day date and year display Additional Features Shock Resistant Tide Graph World Time (29 time zones) Alarms 1/100 second stopwatch Full Auto-Calendar 12/24 Hour Formats One more thing It can do world better old model old model BG169G-7B casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital BG169G-7B B01ETNXGOK For her For all','',0),(15,2,1,'Casio Men\'s Core MTP1192E-7A Brown Leather Quartz Watch with White Dial','Casio Men\'s Core MTP1192E-7A Brown Leather Quartz Watch with White Dial Calendar Day and Date Case measurements 36 wide mm thick casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial Casio MTP1192E-7A B009SAYZYU 4971850775195 For him','',0),(16,2,1,'Casio General Men\'s Watches Edifice Digital-Analog Combination','Casio General Men\'s Watches Edifice Digital-Analog Combination Upgrade to style and sophistication with this elegant Casio watch Calendar Date and Month Case measurements 45 wide 13 mm thick casio-general-men-s-watches-edifice-digital-analog-combination EFA121D-7AV B001MDFVJ4 4971850873839 For him','',0),(17,2,1,'Casio Men\'s W753-2AV Blue Resin Quartz Watch with Digital Dial','Casio Men\'s W753-2AV Blue Resin Quartz Watch with Digital Dial Perfect for the person that cant get enough technology this watch will keep you looking great while keeping you punctual provided you dont lose track of time fiddling with this watchs nifty chronograph Calendar Day Date and Month Case measurements 40 wide 12 mm thick casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p Casio W753-2AV B000AR7RZ4 4971850827740 For him','',0),(18,2,1,'Nemesis Women\'s Classic Yellow Plant Art Leather Cuff Band Watch','Nemesis Women\'s Classic Yellow Plant Art Leather Cuff Band Watch This Nemesis Yellow Plant Art leather band watch features round silvertone case with various floral designs on white dial This watch highlights 100-percent USA made genuine black leather band with thorn designs on the side nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch THR827N B004RTTFH4 For her','',0),(19,2,1,'Nemesis Men\'s Brown Wide Leather Cuff Band Analog Brown Dial Watch','Nemesis Men\'s Brown Wide Leather Cuff Band Analog Brown Dial Watch Simply stunning this Nemesis Silver Small Triangle&nbsp; Watch features stainless steel case Run on precise Japanese Quartz movement technology this Nemesis triangle watch features leather strap.&nbsp; nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch Nemesis BBB516S B00AQ6U4RC 0751744227344 For him','',0),(20,2,1,'Nemesis Men\'s Wide Sunrise Black Leather Cuff Watch','Nemesis Men\'s Wide Sunrise Black Leather Cuff Watch silver and black gradient dial sits in the polished alloy case of this casual watch from Nemesis wide black leather strap with silvertone rings and studs finishes the bold style of this timepiece.&nbsp; nemesis-men-s-wide-sunrise-black-leather-cuff-watch Nemesis TWXB078K B007VZ3XPG 0609788671077 For him','',0),(21,2,1,'Cartier Men\'s Santos 18k Gold and Steel Automatic Watch1','Cartier Men\'s Santos 18k Gold and Steel Automatic Watch1 This elegant wristwatch boasts two-tone case with 18-karat yellow gold and steel The Cartier men&#39;s watch is from the Santos collection With classic leather strap this timepiece is truly timeless Square stainless steel case 18-karat yellow gold bezel with rivet detailing Silver dial Luminescent black index-style hands Black Roman numerals Second sweep Brown leather strap Push-button deployment clasp Sapphire crystal Push/pull crown Automatic movement Water resistant to 100 meters Case measures 38 mm wide 10 mm thick Strap measures 23 mm wide inches long cartier-men-s-santos-18k-gold-and-steel-automatic-watch W20072X7 B000FTLNFM 0761245625965 For him','',0),(22,2,1,'Edox Men\'s \'Les Vauberts Automatic\' Yellow Goldtone Stainless Steel Mechanical A','Edox Men\'s Les Vauberts Automatic Yellow Goldtone Stainless Steel Mechanical The Edox men&#39;s &#39;Les Vauberts Automatic&#39; Swiss mechanical watch features yellow goldplated case with contrasting silvertone dial and warm yellow goldtone hands and indices This handsome watch is finished on dark brown leather strap edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a Edox 85010-37J-AID B00KNTGLU6 7640156422757 For him','',0),(23,2,1,'Edox Men\'s \'WRC\' Stainless Steel Multifunction Chronograph Watch','Edox Men\'s WRC Stainless Steel Multifunction Chronograph Watch Edox presents this gorgeous stainless steel watch which features several bells and whistles With beautiful blue face three subdials and sleek bracelet this watch is the perfect way to stay on time and in style.&nbsp; edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch Edox 01112-3-BUIN B0089TDQ8C 7640156420012 For him','',0),(24,2,1,'Concord Men\'s \'Saratoga\' Black Stainless Steel Swiss Quartz Watch','Concord Men\'s Saratoga Black Stainless Steel Swiss Quartz Watch Add modern pop of style to your look with this sleek stainless steel watch from Concord smooth black dial easy-to-read calendar date and comfortable two-tone bracelet makes this watch the perfect way to stay on time and in style.&nbsp; concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch 0311818 B00HERO10W 0885997087742 For him','',0),(25,2,1,'Citizen Eco-Drive Silver Tone Men','Citizen Eco-Drive Silver Tone Men Sport sophisticated classic look with this Citizen stainless steel watch With easy-to-read markers and comfortable strap this watch is the perfect way to stay on time and in style.&nbsp; citizen-eco-drive-silver-tone-men AO9030-05E B00CB99Z5E 13205101670 For him','',0),(26,2,1,'Citizen Men\'s \'Eco-Drive\' Primo Black/ Blue Chronograph Watch','Citizen Men\'s Eco-Drive Primo Black/ Blue Chronograph Watch This stylish chronograph from citizen features detailed dial with chronograph subdials and calendar window for excellent timekeeping ability This stainless steel watch is finished with comfortable polyurethane strap with pin buckle clasp Subdials Standard chronograph Calendar Date window at o&#39;clock Power reserve 180 Days Case measurements 45 mm wide 45 mm long 12 mm thick Strap measurements 23 mm wide 8.5 inches long Box measurements inches wide inches long inches high citizen-men-s-eco-drive-primo-black-blue-chronograph-watch Citizen CA0467-03E B009G75M38 13205100048 For him','',0),(27,2,1,'Citizen Men\'s Eco-Drive AT2215-07E Black Leather Eco-Drive Watch with Black Dial','Citizen Men\'s Eco-Drive AT2215-07E Black Leather Eco-Drive Watch with Black Dial Show off your laid-back personality with this casual Citizen timepiece Case measurements 41 wide 12 mm thick Strap/Bracelet measurements 25mm wide 8.5 inches long citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial AT2215-07E B00BNPIANK 4562195133322 For him','',0),(28,2,1,'Citizen Men\'s BJ8050-08E Eco-Drive Professional Diver Black Sport Watch','Citizen Men\'s BJ8050-08E Eco-Drive Professional Diver Black Sport Watch Men&#39;s timepiece boasts contemporary rubber strap Citizen diver wristwatch is designed for mixed gas diving With bold design men&#39;s casual watch is perfect for everyday wear Round stainless steel case Screw-down caseback Black dial Silvertone hands and hour markers Black rubber strap Pin buckle 6-mm non-reflective curved crystal glass Screw-down crown Water resistant to 300 meters citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch Citizen BJ8050-08E B000EQU15O 4003702659930 For him','',0),(29,2,1,'Royal London 41003-03','Royal London 41003-03 Gender &nbsp;:&nbsp;Gents Movement &nbsp;:&nbsp;Date Chronograph Dial colour &nbsp;:&nbsp;Black Indication &nbsp;:&nbsp;Baton Case material &nbsp;:&nbsp;PVD Black ATM &nbsp;:&nbsp;100 metres Band material &nbsp;:&nbsp;Leather Band colour &nbsp;:&nbsp;Black Case width (mm) &nbsp;:&nbsp;44.5 Case height (mm) &nbsp;:&nbsp;44.0 Case thickness (mm) &nbsp;:&nbsp;13.30 chasy-royal-london-41003-03 Royal-41003-03 5051496065481 For him For all','',0),(30,2,1,'COZY SLEEP QUEEN MATTRESS','COZY SLEEP QUEEN MATTRESS The Cozy Sleep mattress doesn&#39;t compromise on quality High quality knitted fabric gives you firm feel 4cm comfort foam provides cushioning feel for your body and 16cm continous spring supports your body ensuring you have good night&#39;s sleep &nbsp; Construction High quality knitted fabric cm comfort foam 16cm continous spring &nbsp; Warranty &nbsp;1 year Dimensions &nbsp;H:24 W:153 D:203 CM &nbsp; Why We Love It This is fantastically priced mattress for the level of quality support and freedom that it provides Queen Mattress PK Furniture Buy queen mattress online now at PK Furniture EDLP DEAL COZY SLEEP QUEEN MATTRESS WARRANTY YEAR cozy-sleep-queen-mattress QUEEN MATTRESS COZY SLEEP COZY SLEEP 00GM21-01Y014-Q Mattress','',0),(31,2,1,'COZY SLEEP DOUBLE MATTRESS','COZY SLEEP DOUBLE MATTRESS The Cozy Sleep mattress doesn&#39;t compromise on quality High quality knitted fabric gives you firm feel 4cm comfort foam provides cushioning feel for your body and 16cm continous spring supports your body ensuring you have good night&#39;s sleep &nbsp; Construction High quality knitted fabric cm comfort foam 16cm continous spring &nbsp; Warranty &nbsp;1 year Dimensions &nbsp;H:24 W:137 D:188 CM &nbsp; Why We Love It This is fantastically priced mattress for the level of quality support and freedom that it provides Double Mattress PK Furniture Buy double mattress online now at PK Furniture COZY SLEEP EDLP DEAL COZY SLEEP DOUBLE MATTRESS WARRANTY YEAR cozy-sleep-double-mattress DOUBLE MATTRESS COZY SLEEP COZY SLEEP 00GM21-01Y014-D Mattress','',0),(32,2,1,'Country 6PCS Package 1Xqb+2Xbs+1Xtb+1Xdt+1Xdm','Country 6PCS Package 1Xqb+2Xbs+1Xtb+1Xdt+1Xdm Material Warranty Year Dimension:H D:CM EDLP DEAL COUNTRY 6PCS PACKAGE 1XQB+2XBS+1XTB+1XDT+1XDM country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462 COUNTRY PCOU04-SMKGUM Bedroom suites','',0),(33,2,1,'JACK 5 PIECE KING BEDROOM SUITE','JACK PIECE KING BEDROOM SUITE x&nbsp;Jack &nbsp; King Bed Jack Bedside Table Jack Dressing Table x&nbsp;Jack &nbsp; Dressing&nbsp;Mirror &nbsp; EDLP DEAL JACK 5PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XDT+1XDM jack-5-piece-king-bedroom-suites JACK PJAC09-050093 Bedroom suites','',0),(34,2,1,'JACK 4 PIECE KING BEDROOM SUITE','JACK PIECE KING BEDROOM SUITE The rustic Jack super king bed frame is completed with dark wood finish giving robust yet modern look making your bedroom distinctive x&nbsp;Jack King Bed Jack Bedside Table&nbsp; Jack Tallboy Material Veneer Warranty Year Bed Frame Dimension H:120 W:171 D:207 CM Bedside Dimension H:55 W:54 D:45 CM Tallboy Dimension H:110 W:95 D:46 CM EDLP DEAL JACK 4PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XTB jack-4-piece-king-bedroom-suites JACK PJAC08-0400P3 Bedroom suites','',0),(35,2,1,'HAMPTONS 5 PIECE QUEEN BEDROOM SUITE','HAMPTONS PIECE QUEEN BEDROOM SUITE With bold contrasting wood grain and natural protective qualities the Hamptons range is perfect for connecting modern lifestyle with the characteristic flavor&nbsp;of simple country style Hampton Queen Bed Frame Hampton Bedside Tables Hampton Dressing Table Hampton Dressing Mirror Material Acacia Veneer Warranty Year Bed Frame&nbsp; Dimension H:120 W:165 D:218 CM Bed Side Dimension H:115 W:100 D:48 CM Dressing Table Dimension 85 W:135 D:48 CM Dressing Mirror Dimension H:80 W:112 D:2 CM EDLP DEAL HAMPTONS 5PCS PACKAGE 1XQB+2XBS+1XDT+1XDM hamptons-5-piece-queen-bedroom-suites HAMPTONS PHAM02-05A201 Bedroom suites','',0),(36,2,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','BROLLY QUILTED FITTED MATTRESS PROTECTOR KING EDLP DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR KING brolly-quilted-fitted-mattress-protector-king BROLLY 00MPKQ-010000-K Accessories','',0),(37,2,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','BROLLY QUILTED FITTED MATTRESS PROTECTOR QUEEN EDLP DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR QUEEN brolly-quilted-fitted-mattress-protector-queen BROLLY 00MPQQ-010000-Q Accessories','',0),(38,2,1,'FURTEX','FURTEX MESSINA CUSHION TURQUORISE messina-cushion-turquorise FURTEX 22585C Accessories','',0),(39,2,1,'FURTEX','FURTEX Metrix Cushion Orange PK Furniture Buy metrix cushion orange online now at PK Furniture METRIX CUSHION ORANGE metrix-cushion-orange METRIX CUSHION ORANGE FURTEX FURTEX 22898C Accessories','',0),(40,2,1,'FURTEX','FURTEX CLARA THROW LIME clara-throw-lime FURTEX 23077T Accessories','',0),(41,2,1,'FURTEX','FURTEX CLARA THROW PEACOCK clara-throw-peacock FURTEX 23078T Accessories','',0),(42,2,1,'OLIVIA 3 DRAWER DRESSING TABLE','OLIVIA DRAWER DRESSING TABLE This easy-to-love style takes the best of the past and updates it with modern eye Whether it&rsquo;s part of master bedroom set or an eclectic living room arrangement this dresser is sure to draw attention &nbsp; Material &nbsp; MDF Dimension &nbsp;&nbsp;W 99.5 D:47.5 H:76 CM Drawer Dressing Table PK Furniture Buy drawer dressing table online now at PK Furniture OLIVIA DRAWER DRESSING TABLE olivia-3-drawer-dressing-table DRAWER DRESSING TABLE OLIVIA OLIVIA OLIVIA-TB308DE-DT Clearance','',0),(43,2,1,'CLAYTON RECLINER LOUNGE SUITE','CLAYTON RECLINER LOUNGE SUITE Material Air Leather and Plywood Frame Colours Available Brown and Beige Dimension Seater H:100 W:216 D:100 CM Seater H:100 W:106 D:100 CM Recliner Lounge Suite Brown PK Furniture Buy recliner lounge suite brown online now at PK Furniture EDLP DEAL CLAYTON 3RR+2RR BROWN clayton-3rr-2rr-brown RECLINER LOUNGE SUITE BROWN CLAYTON CLAYTON CLAYTON32-R8308-BROWN Clearance','',0),(44,2,1,'CLAYTON RECLINER LOUNGE SUITE','CLAYTON RECLINER LOUNGE SUITE Material &nbsp;Air Leather Plywood Frame Colours Available &nbsp;Brown and Beige Dimension &nbsp; Seater H:100 W:216 D:100 CM Seater H:100 W:106 D:100 CM Single Seater H:100 W:103 D:96 CM Recliner Lounge Suite Brown PK Furniture Buy recliner lounge suite brown online now at PK Furniture EDLP DEAL CLAYTON 3RR+2RR+SR BROWN clayton-3rr-2rr-sr-brown RECLINER LOUNGE SUITE BROWN CLAYTON CLAYTON CLAYTON321-R8308-BROWN Clearance','',0),(45,2,1,'VERONICA 4 PIECE QUEEN BEDROOM SUITE','VERONICA PIECE QUEEN BEDROOM SUITE Ready for new look in your restful retreat Go for simply stylish display with this bedroom suite Crafted from pine wood it showcases clean-lined frame with an espresso finish and high slatted headrest &nbsp; Material &nbsp;Pine Dimension Queen Bed:&nbsp;H:118 W:167 D:225 CM Bedside:&nbsp;H:63 W:48 D:40 CM Tallboy:&nbsp;H:120 W:90 D:43&nbsp;CM Set Includes Veronica&nbsp;Queen Bed Frame Veronica Bedside Tables Veronica&nbsp;Tallboy EDLP DEAL NEW VERONICA 4PCS PACKAGE 1XQB+2XBS+1XTB new-veronica-4pcs-package-1xqb-2xbs-1xtb VERONICA VERONICAQUEEN4-NEW Bedroom suites','',0),(46,2,1,'MONA 2 SEATER SOFA','MONA SEATER SOFA The latest European style Mona Sofa looks great and sits well Well made with dark coloured wooden legs and webbed seat system providing lasting comfort and quality The sofa is available in four fabric options and would look&nbsp;great wherever it is placed and would definitely make the room look enhancing &nbsp; Material Velvet Fabric and Wooden Legs Colours Available Merlot Red Royal Blue Forest Green and Stone Grey Dimension H:94 W:125 D:78 CM mona-1237-red MONA MONA-1237-RED Clearance','',0),(47,2,1,'MICHAEL 7 PIECE 150 DINING SUITE','MICHAEL PIECE 150 DINING SUITE The combination of glass and solid timber legs gives this dining suite contemporary look that is perfect for everyday living.&nbsp; The Michael Dining Table comes in Grey or&nbsp;Black tempered glass top and two sizes (150CM or 180CM) that you can choose from that is suitable&nbsp;for&nbsp;your dining room.&nbsp;&nbsp; &nbsp; Material Tempered Glass Top Solid Beech Legs Colours Available:&nbsp; Grey and&nbsp;Black Dimension Table Dimension 72.8 W:150 D:90 CM Chair Dimension H:87 W:48 D:57 CM Suite includes Michael 150 Dining Table&nbsp; Michael Dining Chair EDLP DEAL&nbsp; MICHAEL &nbsp;150 DINING PACKAGE BLACK TABLE BLUE CHAIRS michael-150-dining-package-black-1-table-6-blue-chairs MICHAEL MICHAEL-150BLK-PACKAGE Clearance','',0),(48,2,1,'CASPER 5 PIECE 120 DINING SUITE','CASPER PIECE 120 DINING SUITE Give your home designer flair with this stylish dining set.&nbsp;&nbsp;The&nbsp;unique design&nbsp;provides characterful look that will go well&nbsp;in&nbsp;any living and dining room setting.&nbsp;&nbsp;Creating an uplifting new look for your home has never been easier with this beautiful&nbsp;Casper range.&nbsp; &nbsp; Material &nbsp;Solid Rubberwood MDF /&nbsp; Walnut Veneer Dimension Table Dimension:&nbsp;H:75 W:120 D:120 CM Chair Dimension:&nbsp;H:77.5 W:56.5 D:63.5 CM Suite includes Casper 120 Dining Table Casper Dining Chair EDLP DEAL&nbsp; CASPER &nbsp;120 DINING PACKAGE TABLE CHAIRS casper-120-dining-package-1-x-table-4-chairs CASPER CASPERPACKAGE Clearance','',0),(49,2,1,'JONAS 7 PIECE OUTDOOR DINING SET','JONAS PIECE OUTDOOR DINING SET timeless classic the Jonas Piece Outdoor Dining Set is flawless little entertainer Comprised of 180 Outdoor Table and&nbsp;6&nbsp;x Outdoor Chairs,&nbsp;the Jonas Outdoor Setting has solid wooden frame constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp; Comes with year warranty and ready to assemble &nbsp; Material &nbsp;FSC Certified Eucalyptus Dimension Outdoor Table H:76&nbsp;X W:180 D:90 CM Outdoor Chair H:86&nbsp;X W:60 D:55&nbsp;CM Suite includes Jonas Outdoor Dining Table Jonas Outdoor Dining Chair EDLP DEAL jonas180package JONAS JONAS180PACKAGE Outdoor','',0),(50,2,1,'JONAS 5 PIECE OUTDOOR BAR SETTING','JONAS PIECE OUTDOOR BAR SETTING timeless classic the Jonas Piece Outdoor Bar Setting is flawless little entertainer Comprised of 120 Outdoor Bar Table and 4&nbsp;x Outdoor Bar Chairs,&nbsp;the Jonas Outdoor Setting has solid wooden frame constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp; Comes with year warranty and ready to assemble &nbsp; Material &nbsp;FSC Certified Eucalyptus Dimension Outdoor Bar Table H:90 W:120 D:60 CM Outdoor Bar Chair H:65 W:42 D:38 CM Suite includes Jonas Outdoor Bar Table Jonas Outdoor Bar Chair EDLP DEAL jonasbarpackage JONAS JONASBARPACKAGE Outdoor','',0),(51,2,1,'JONAS JACK AND JILL OUTDOOR SETTING','JONAS JACK AND JILL OUTDOOR SETTING timeless classic the Jonas Jack and Jill Setting is flawless little entertainer Comprised of armchairs joined by tray table,&nbsp;the Jonas Outdoor Setting has solid wooden frame constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp; Comes with year warranty and&nbsp;ready to assemble &nbsp; Material &nbsp;FSC Certified Eucalyptus Dimension &nbsp;H:86 W:154 D:56 CM EDLP DEAL huc25806 JONAS HUC25806 Outdoor','',0),(52,2,1,'JONAS 4 PIECE OUTDOOR LOUNGE SETTING','JONAS PIECE OUTDOOR LOUNGE SETTING timeless classic the Jonas Piece Outdoor Lounge Setting is flawless little entertainer Comprised of Seater 2&nbsp;x Single Armchairs and Coffee Table,&nbsp;the Jonas Outdoor Lounge Setting has solid wooden frame constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp; Comes with year warranty and ready to assemble &nbsp; Material &nbsp;FSC Certified Eucalyptus Dimension Outdoor Seater H:80 W:151&nbsp;X D:81&nbsp;CM Outdoor Armchair H:80 W:76&nbsp;X D:81 CM Outdoor Coffee Table H:50 W:110 D:60 CM Suite includes Jonas Outdoor Seater Jonas Outdoor Armchair Jonas Outdoor Coffee Table EDLP DEAL jonaslounge JONAS JONASLOUNGE Outdoor','',0),(53,2,1,'ERIN TRUNDLE BED WITH POCKET SPRING MATTRESSES','ERIN TRUNDLE BED WITH POCKET SPRING MATTRESSES Add versatility and convenience to your bedroom or guest room with the Erin trundle bed The underbed rolls out easily with spacious underbed drawers for convenient storage Consisting of one king single bed and matching single trundle bed with mattresses the Erin will help you get the most out of your bedroom&#39;s space coming in handy for kids sleepovers or unexpected visits from guests It&#39;s great way to maintain neat bedroom space You can also upgrade the mattresses from Erin Mattresses to Cozy Sleep Mattresses and Ultra Sleep Mattresses based on your requirements.&nbsp;&nbsp; &nbsp; Material Fabric Wooden Frame Dimension H:61 W:107 D:203 CM EDLP DEAL erin-trundle-bed-with-mattresses ERIN 00TB03-NEWERIN-KS Mattress','',0),(54,2,1,'BERRY 3 SEATER WITH CHAISE','BERRY SEATER WITH CHAISE You don&#39;t need to sacrifice comfort for style with the Berry sofa Available in two sophisticated colours the Berry comes in seater seater and sofa with chaise &nbsp; Material &nbsp;Fabric Colours Available &nbsp;Cream,&nbsp;Steel&nbsp;Grey Dark Grey and Beige Dimension &nbsp;H:85 W:235 D:150 CM EDLP DEAL 199523-berbei-3sc BERRY 199523-BERBEI-3S/C Clearance','',0),(55,2,1,'ZEDS QUASAR QUEEN MATTRESS IN A BOX','ZEDS QUASAR QUEEN MATTRESS IN BOX The Zeds Quasar Mattress in Box strikes the perfect balance between comfort and convenience This Pillow Top mattress features traditional&nbsp; Pocket spring construction that will provide comfort and all over body support With generous layer of soft fillings and foam you can rest soundly all night long Packaged in box this mattress is easy to transport and even easier to set up; simply open the box cut the plastic seal and roll the mattress out &nbsp; Product Features Generous layer of soft fillings provides comfort and support&nbsp; Pillow Top&nbsp; Pocket Spring Easy to transport Comes rolled up in box Easy to transport Carton comes with handle and wheels Note Once mattress is decompressed it can not be put back into the box &nbsp; Dimensions &nbsp;H:26 W:153 D:203 CM &nbsp; Deliver to anywhere in North Island or to Christchurch for $95 only EDLP ZEDS &nbsp;QUASAR&nbsp; QUEEN &nbsp;MATTRESS IN BOX WARRANTY YEARS r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box ZEDS QUASAR PR539-ZEDS QUASAR-Q Mattress','',0),(56,2,1,'GIFT CARD','GIFT CARD gift-card VIRTUAL_GIFT_CARD','',0),(57,2,1,'HAMPTONS 5 PIECE QUEEN BEDROOM SUITE','pham02-05a201 HAMPTONS PHAM02-05A201 Bedroom suites','',0),(58,2,1,'CASPER 5 PIECE 120 DINING SUITE','casperpackage CASPER CASPERPACKAGE Clearance','',0),(59,2,1,'MONA 2 SEATER SOFA','mona-1237-red MONA MONA-1237-RED Clearance','',0),(60,2,1,'JONAS 5 PIECE OUTDOOR BAR SETTING','jonasbarpackage JONAS JONASBARPACKAGE Outdoor','',0),(61,2,1,'BERRY 3 SEATER WITH CHAISE','199523-berbei-3sc BERRY 199523-BERBEI-3S/C Clearance','',0);
/*!40000 ALTER TABLE `plain_products_name_search` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `plain_products_name_to_products`
--

DROP TABLE IF EXISTS `plain_products_name_to_products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `plain_products_name_to_products` (
  `plain_id` int(11) NOT NULL DEFAULT '0',
  `products_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `department_id` int(11) NOT NULL DEFAULT '0',
  `last_modified` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`plain_id`,`products_id`,`platform_id`,`department_id`),
  KEY `idx_last_modified` (`last_modified`,`products_id`),
  KEY `plain_products_name_to_products_platform_idx` (`platform_id`,`department_id`,`products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `plain_products_name_to_products`
--

LOCK TABLES `plain_products_name_to_products` WRITE;
/*!40000 ALTER TABLE `plain_products_name_to_products` DISABLE KEYS */;
INSERT INTO `plain_products_name_to_products` VALUES (1,1,1,0,'2021-11-05 15:29:59'),(2,2,1,0,'2021-11-05 15:30:00'),(3,3,1,0,'2021-11-05 15:30:01'),(4,4,1,0,'2021-11-05 15:30:01'),(5,5,1,0,'2021-11-05 15:30:03'),(6,6,1,0,'2021-11-05 15:30:03'),(7,7,1,0,'2021-11-05 15:30:04'),(8,8,1,0,'2021-11-05 15:30:05'),(9,9,1,0,'2021-11-05 15:30:06'),(10,10,1,0,'2021-11-05 15:30:06'),(11,11,1,0,'2021-11-05 15:30:07'),(12,12,1,0,'2021-11-05 15:30:07'),(14,14,1,0,'2021-11-05 15:30:08'),(15,15,1,0,'2021-11-05 15:30:10'),(17,17,1,0,'2021-11-05 15:30:11'),(18,18,1,0,'2021-11-05 15:30:11'),(19,19,1,0,'2021-11-05 15:30:12'),(20,20,1,0,'2021-11-05 15:30:12'),(22,22,1,0,'2021-11-05 15:30:13'),(23,23,1,0,'2021-11-05 15:30:14'),(24,24,1,0,'2021-11-05 15:30:15'),(25,25,1,0,'2021-11-05 15:30:16'),(26,26,1,0,'2021-11-05 15:30:17'),(27,27,1,0,'2021-11-05 15:30:17'),(29,29,1,0,'2021-11-05 15:30:18'),(21,21,1,0,'2021-11-10 10:01:26'),(16,16,1,0,'2021-11-15 17:58:50'),(28,28,1,0,'2021-11-16 09:58:32'),(13,13,1,0,'2021-11-16 12:13:42'),(30,30,1,0,'2021-12-21 16:54:23'),(31,31,1,0,'2021-12-21 16:54:27'),(32,32,1,0,'2021-12-21 16:54:30'),(33,33,1,0,'2021-12-21 16:54:36'),(34,34,1,0,'2021-12-21 16:54:42'),(36,36,1,0,'2021-12-21 16:54:52'),(37,37,1,0,'2021-12-21 16:54:59'),(38,38,1,0,'2021-12-21 16:55:00'),(39,39,1,0,'2021-12-21 16:55:02'),(40,40,1,0,'2021-12-21 16:55:03'),(41,41,1,0,'2021-12-21 16:55:04'),(42,42,1,0,'2021-12-21 16:55:08'),(43,43,1,0,'2021-12-21 16:55:12'),(44,44,1,0,'2021-12-21 16:55:18'),(45,45,1,0,'2021-12-21 16:55:20'),(47,47,1,0,'2021-12-21 16:55:30'),(49,49,1,0,'2021-12-21 16:55:39'),(51,51,1,0,'2021-12-21 16:55:40'),(52,52,1,0,'2021-12-21 16:55:41'),(53,53,1,0,'2021-12-21 16:55:51'),(55,55,1,0,'2021-12-21 16:56:04'),(56,56,1,0,'2021-12-21 16:56:04'),(57,35,7,0,'2021-12-21 17:33:15'),(58,48,7,0,'2021-12-21 17:33:39'),(59,46,7,0,'2021-12-21 17:33:53'),(60,50,7,0,'2021-12-21 17:34:20'),(61,54,7,0,'2021-12-21 17:34:59');
/*!40000 ALTER TABLE `plain_products_name_to_products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platform_currencies_margin`
--

DROP TABLE IF EXISTS `platform_currencies_margin`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platform_currencies_margin` (
  `platform_id` int(11) NOT NULL,
  `currencies_id` int(11) NOT NULL,
  `use_custom_currency_value` tinyint(1) DEFAULT '0',
  `currency_value` decimal(13,8) NOT NULL DEFAULT '1.00000000',
  `margin_value` decimal(13,8) NOT NULL DEFAULT '0.00000000',
  `margin_type` varchar(8) NOT NULL DEFAULT '',
  PRIMARY KEY (`platform_id`,`currencies_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platform_currencies_margin`
--

LOCK TABLES `platform_currencies_margin` WRITE;
/*!40000 ALTER TABLE `platform_currencies_margin` DISABLE KEYS */;
INSERT INTO `platform_currencies_margin` VALUES (1,2,0,1.00000000,0.00000000,'%'),(1,11,0,1.00000000,0.00000000,'%'),(1,15,0,1.00000000,0.00000000,'%'),(7,2,0,1.00000000,0.00000000,'%'),(7,11,0,1.00000000,0.00000000,'%'),(7,15,0,1.00000000,0.00000000,'%'),(8,2,0,1.00000000,0.00000000,'%'),(8,11,0,1.00000000,0.00000000,'%'),(8,15,0,1.00000000,0.00000000,'%'),(9,2,0,1.00000000,0.00000000,'%'),(9,11,0,1.00000000,0.00000000,'%'),(9,15,0,1.00000000,0.00000000,'%'),(10,2,0,1.00000000,0.00000000,'%'),(10,11,0,1.00000000,0.00000000,'%'),(10,15,0,1.00000000,0.00000000,'%');
/*!40000 ALTER TABLE `platform_currencies_margin` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platform_inventory_control`
--

DROP TABLE IF EXISTS `platform_inventory_control`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platform_inventory_control` (
  `products_id` varchar(160) NOT NULL,
  `platform_id` int(11) NOT NULL,
  `current_quantity` int(11) NOT NULL DEFAULT '0',
  `manual_quantity` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`products_id`,`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platform_inventory_control`
--

LOCK TABLES `platform_inventory_control` WRITE;
/*!40000 ALTER TABLE `platform_inventory_control` DISABLE KEYS */;
/*!40000 ALTER TABLE `platform_inventory_control` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platform_stock_control`
--

DROP TABLE IF EXISTS `platform_stock_control`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platform_stock_control` (
  `products_id` int(11) NOT NULL,
  `platform_id` int(11) NOT NULL,
  `current_quantity` int(11) NOT NULL DEFAULT '0',
  `manual_quantity` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`products_id`,`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platform_stock_control`
--

LOCK TABLES `platform_stock_control` WRITE;
/*!40000 ALTER TABLE `platform_stock_control` DISABLE KEYS */;
/*!40000 ALTER TABLE `platform_stock_control` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms`
--

DROP TABLE IF EXISTS `platforms`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms` (
  `platform_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_owner` varchar(64) NOT NULL DEFAULT '',
  `platform_name` varchar(64) NOT NULL DEFAULT '',
  `platform_url` varchar(128) NOT NULL DEFAULT '',
  `platform_url_secure` varchar(128) NOT NULL DEFAULT '',
  `ssl_enabled` tinyint(1) NOT NULL DEFAULT '0',
  `is_default` tinyint(1) NOT NULL DEFAULT '0',
  `platform_email_address` varchar(64) NOT NULL DEFAULT '',
  `platform_email_from` varchar(64) NOT NULL DEFAULT '',
  `platform_email_extra` varchar(64) NOT NULL DEFAULT '',
  `platform_telephone` varchar(32) NOT NULL DEFAULT '',
  `platform_landline` varchar(32) NOT NULL DEFAULT '',
  `date_added` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `is_virtual` int(1) NOT NULL DEFAULT '0',
  `is_default_address` int(1) NOT NULL DEFAULT '0',
  `is_default_contact` int(1) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `status` int(1) NOT NULL DEFAULT '1',
  `defined_languages` varchar(64) NOT NULL DEFAULT '',
  `defined_currencies` varchar(64) NOT NULL DEFAULT '',
  `default_language` varchar(5) NOT NULL DEFAULT '',
  `default_currency` varchar(5) NOT NULL DEFAULT '',
  `platform_code` varchar(16) DEFAULT NULL,
  `need_login` tinyint(1) NOT NULL DEFAULT '0',
  `use_social_login` tinyint(4) NOT NULL DEFAULT '0',
  `is_marketplace` int(1) NOT NULL DEFAULT '0',
  `sattelite_platform_id` int(11) NOT NULL DEFAULT '0',
  `platform_prefix` varchar(255) NOT NULL DEFAULT '',
  `contact_us_email` varchar(96) NOT NULL DEFAULT '',
  `landing_contact_email` varchar(96) NOT NULL DEFAULT '',
  `organization_site` varchar(255) NOT NULL DEFAULT '',
  `organization_type` varchar(255) NOT NULL DEFAULT '',
  `logo` varchar(255) NOT NULL DEFAULT '',
  `default_platform_id` int(11) DEFAULT '0',
  `platform_please_login` tinyint(1) NOT NULL DEFAULT '0',
  `exclusion_rules` text NOT NULL,
  `checkout_logged_customer` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`platform_id`)
) ENGINE=InnoDB AUTO_INCREMENT=11 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms`
--

LOCK TABLES `platforms` WRITE;
/*!40000 ALTER TABLE `platforms` DISABLE KEYS */;
INSERT INTO `platforms` VALUES (1,'[[store_owner]]','[[store_name]]','[[domhost]][[relativeurl]]','',[[ssl_enabled]],1,'[[admin_email]]','[[store_email]]','','','','2016-07-15 14:06:22',NULL,0,0,0,1,1,'en','GBP,EUR,USD','en','GBP','',0,0,0,0,'','','','','','0',1,0,'a:3:{s:4:\"type\";a:0:{}s:5:\"value\";a:0:{}s:6:\"method\";a:0:{}}',0),(4,'Store Owner','Amazon','','',0,0,'','','','','','2016-10-22 10:11:30',NULL,0,1,1,6,0,'','','','',NULL,0,0,1,0,'','','','','','',0,0,'',0),(5,'Store Owner','Ebay','','',0,0,'','','','','','2016-10-22 10:11:48',NULL,0,1,1,7,0,'','','','',NULL,0,0,1,0,'','','','','','',0,0,'',0),(6,'Store Owner','Google Shop','','',0,0,'','','','','','2016-10-22 10:12:15',NULL,0,1,1,5,0,'','','','',NULL,0,0,1,0,'','','','','','',0,0,'',0),(7,'[[store_owner]]','Furniture','[[domhost]][[relativeurl]]/furniture','',[[ssl_enabled]],0,'[[admin_email]]','[[store_email]]','','','','2021-12-21 16:55:29',NULL,0,0,0,2,1,'en','GBP,EUR,USD','en','GBP','',0,0,0,0,'','','','','','0',7,0,'a:3:{s:4:\"type\";a:0:{}s:5:\"value\";a:0:{}s:6:\"method\";a:0:{}}',0),(8,'[[store_owner]]','Watch','[[domhost]][[relativeurl]]/watch','',[[ssl_enabled]],0,'[[admin_email]]','[[store_email]]','','','','2021-12-21 16:55:38',NULL,0,0,0,3,1,'en','GBP,EUR,USD','en','GBP','',0,0,0,0,'','','','','','0',8,0,'a:3:{s:4:\"type\";a:0:{}s:5:\"value\";a:0:{}s:6:\"method\";a:0:{}}',0),(9,'[[store_owner]]','b2b supermarket','[[domhost]][[relativeurl]]/b2b-supermarket','',[[ssl_enabled]],0,'[[admin_email]]','[[store_email]]','','','','2021-12-21 16:55:38',NULL,0,0,0,3,1,'en','GBP,EUR,USD','en','GBP','',0,0,0,0,'','','','','','0',8,0,'a:3:{s:4:\"type\";a:0:{}s:5:\"value\";a:0:{}s:6:\"method\";a:0:{}}',0),(10,'[[store_owner]]','Print Shop','[[domhost]][[relativeurl]]/printshop','',[[ssl_enabled]],0,'[[admin_email]]','[[store_email]]','','','','2021-12-21 16:55:38',NULL,0,0,0,3,1,'en','GBP,EUR,USD','en','GBP','',0,0,0,0,'','','','','','0',8,0,'a:3:{s:4:\"type\";a:0:{}s:5:\"value\";a:0:{}s:6:\"method\";a:0:{}}',0);
/*!40000 ALTER TABLE `platforms` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_address_book`
--

DROP TABLE IF EXISTS `platforms_address_book`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_address_book` (
  `platforms_address_book_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `is_default` tinyint(1) NOT NULL DEFAULT '0',
  `entry_company` varchar(64) DEFAULT NULL,
  `entry_company_vat` varchar(128) NOT NULL DEFAULT '',
  `entry_company_reg_number` varchar(128) NOT NULL DEFAULT '',
  `entry_postcode` varchar(10) NOT NULL DEFAULT '',
  `entry_street_address` varchar(64) NOT NULL DEFAULT '',
  `entry_suburb` varchar(32) DEFAULT NULL,
  `entry_city` varchar(32) NOT NULL DEFAULT '',
  `entry_state` varchar(32) DEFAULT NULL,
  `entry_country_id` int(11) NOT NULL DEFAULT '0',
  `entry_zone_id` int(11) NOT NULL DEFAULT '0',
  `lat` float(15,8) NOT NULL DEFAULT '0.00000000',
  `lng` float(15,8) NOT NULL DEFAULT '0.00000000',
  PRIMARY KEY (`platforms_address_book_id`),
  KEY `idx_address_book_platform_id` (`platform_id`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_address_book`
--

LOCK TABLES `platforms_address_book` WRITE;
/*!40000 ALTER TABLE `platforms_address_book` DISABLE KEYS */;
INSERT INTO `platforms_address_book` VALUES (1,1,1,'','','','[[store_pincode]]','[[store_address]]','','','',222,0,51.67033005,-1.77763808),(2,7,1,'','','','[[store_pincode]]','[[store_address]]','','','',222,0,51.67033005,-1.77763808),(3,8,1,'','','','[[store_pincode]]','[[store_address]]','','','',222,0,51.67033005,-1.77763808),(4,9,1,'','','','[[store_pincode]]','[[store_address]]','','','',222,0,51.67033005,-1.77763808),(5,10,1,'','','','[[store_pincode]]','[[store_address]]','','','',222,0,51.67033005,-1.77763808);
/*!40000 ALTER TABLE `platforms_address_book` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_api`
--

DROP TABLE IF EXISTS `platforms_api`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_api` (
  `platform_id` int(11) NOT NULL,
  `api_key` varchar(48) NOT NULL DEFAULT '',
  `categories_allow_create` tinyint(1) NOT NULL DEFAULT '1',
  `categories_allow_update` tinyint(1) NOT NULL DEFAULT '1',
  `products_allow_create` tinyint(1) NOT NULL DEFAULT '1',
  `products_allow_update` tinyint(1) NOT NULL DEFAULT '1',
  `products_allow_remove_owned` tinyint(1) NOT NULL DEFAULT '1',
  `site_access_permission` int(1) NOT NULL DEFAULT '0',
  `ip_allowed` text,
  PRIMARY KEY (`platform_id`),
  KEY `api_key` (`api_key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_api`
--

LOCK TABLES `platforms_api` WRITE;
/*!40000 ALTER TABLE `platforms_api` DISABLE KEYS */;
INSERT INTO `platforms_api` VALUES (1,'eb9647e3752711e8a24e441ea153b5c0tvkctu7r0tw1e9xi',1,1,1,1,1,0,''),(7,'ee55b576627e11ecaad90cc47ac62becttdrekeikgmpwvh5',1,1,1,1,1,0,''),(8,'f10df31a627e11ecaad90cc47ac62becaaskcvtd8unkduvv',1,1,1,1,1,0,'');
/*!40000 ALTER TABLE `platforms_api` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_categories`
--

DROP TABLE IF EXISTS `platforms_categories`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_categories` (
  `platform_id` int(11) NOT NULL,
  `categories_id` int(11) NOT NULL,
  PRIMARY KEY (`categories_id`,`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_categories`
--

LOCK TABLES `platforms_categories` WRITE;
/*!40000 ALTER TABLE `platforms_categories` DISABLE KEYS */;
INSERT INTO `platforms_categories` VALUES (1,0),(4,0),(5,0),(6,0),(7,0),(8,0),(9,0),(10,0),(1,1),(8,1),(1,2),(8,2),(1,3),(8,3),(1,4),(8,4),(1,5),(9,5),(1,6),(9,6),(1,7),(9,7),(1,8),(9,8),(1,9),(10,9),(1,10),(10,10),(1,11),(10,11),(1,12),(10,12),(1,13),(7,13),(1,14),(7,14),(1,15),(7,15),(1,16),(7,16),(1,17),(7,17),(1,18),(7,18);
/*!40000 ALTER TABLE `platforms_categories` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_configuration`
--

DROP TABLE IF EXISTS `platforms_configuration`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_configuration` (
  `configuration_id` int(11) NOT NULL AUTO_INCREMENT,
  `configuration_title` varchar(64) NOT NULL DEFAULT '',
  `configuration_key` varchar(64) NOT NULL DEFAULT '',
  `configuration_value` varchar(2048) NOT NULL DEFAULT '',
  `configuration_description` varchar(255) NOT NULL DEFAULT '',
  `configuration_group_id` varchar(128) NOT NULL DEFAULT '',
  `sort_order` int(5) DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  `use_function` varchar(255) DEFAULT NULL,
  `set_function` varchar(255) DEFAULT NULL,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`configuration_id`),
  UNIQUE KEY `platform_id` (`platform_id`,`configuration_key`)
) ENGINE=InnoDB AUTO_INCREMENT=8058 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_configuration`
--

LOCK TABLES `platforms_configuration` WRITE;
/*!40000 ALTER TABLE `platforms_configuration` DISABLE KEYS */;
INSERT INTO `platforms_configuration` VALUES (7,'Installed Modules','MODULE_PAYMENT_INSTALLED','paypal_partner.php;sage_pay_server.php;stripe_checkout.php;cod.php;offline.php','List of payment module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: cc.php;cod.php;paypal.php)','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:16:47','2003-07-17 10:29:22',NULL,NULL,1),(19,'CC Set Order Status','MODULE_PAYMENT_CC_ORDER_STATUS_ID','0','Set the status of CC orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:49:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(25,'CC Payment Zone','MODULE_PAYMENT_CC_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:49:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(31,'CC Sort order of display.','MODULE_PAYMENT_CC_SORT_ORDER','60','Sort order of CC display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:49:38',NULL,NULL,1),(37,'CC Split Credit Card E-Mail Address','MODULE_PAYMENT_CC_EMAIL','','If an e-mail address is entered, the middle digits of the credit card number will be sent to the e-mail address (the outside digits are stored in the database with the middle digits censored)','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:49:38',NULL,NULL,1),(43,'CC Enable Credit Card Module','MODULE_PAYMENT_CC_STATUS','True','Do you want to accept credit card payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:31','2016-04-11 15:49:38',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(73,'Enable GeoTrust QuickPayments Module','MODULE_PAYMENT_GEOTRUST_STATUS','False','Do you want to accept GeoTrust QuickPayments?','BOX_CONFIGURATION_MODULE',1,'2016-04-12 14:50:29','2016-02-05 17:19:45',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(79,'Zone für diese Zahlungsweise','MODULE_PAYMENT_INVOICE_ZONE','3','Wenn Sie eine Zone auswählen, wird diese Zahlungsweise nur in dieser Zone angeboten.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:46:07','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(85,'Rechnung','MODULE_PAYMENT_INVOICE_STATUS','False','Wollen Sie Zahlungen per Rechnung anbieten?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:30','2016-04-11 15:46:07',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(91,'GeoTrust Merchant ID','MODULE_PAYMENT_GEOTRUST_MERCHANT_ID','serial #','Merchant Serial # to use for the GEOTRUST QuickPayments service','BOX_CONFIGURATION_MODULE',2,NULL,'2016-02-05 17:19:45',NULL,NULL,1),(97,'GeoTrust Sort order of display.','MODULE_PAYMENT_GEOTRUST_SORT_ORDER','40','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-02-05 17:19:45',NULL,NULL,1),(103,'GeoTrust Payment Zone','MODULE_PAYMENT_GEOTRUST_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-02-05 17:19:45','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(109,'GeoTrust Set Order Status','MODULE_PAYMENT_GEOTRUST_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-02-05 17:19:45','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(115,'Enable 2CheckOut Module','MODULE_PAYMENT_2CHECKOUT_STATUS','False','Do you want to accept 2CheckOut payments?','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(121,'2CheckOut Login/Store Number','MODULE_PAYMENT_2CHECKOUT_LOGIN','18157','Login/Store Number used for the 2CheckOut service','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21',NULL,NULL,1),(127,'2CheckOut Transaction Mode','MODULE_PAYMENT_2CHECKOUT_TESTMODE','Test','Transaction mode used for the 2Checkout service','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21',NULL,'tep_cfg_select_option(array(\'Test\', \'Production\'), ',1),(133,'2CheckOut Merchant Notifications','MODULE_PAYMENT_2CHECKOUT_EMAIL_MERCHANT','True','Should 2CheckOut e-mail a receipt to the store owner?','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(139,'2CheckOut Sort order of display.','MODULE_PAYMENT_2CHECKOUT_SORT_ORDER','100','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-08 16:55:21',NULL,NULL,1),(145,'2CheckOut Payment Zone','MODULE_PAYMENT_2CHECKOUT_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-08 16:55:21','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(151,'2CheckOut Set Order Status','MODULE_PAYMENT_2CHECKOUT_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(157,'Reihenfolge der Anzeige','MODULE_PAYMENT_INVOICE_SORT_ORDER','50','Niedrigste wird zuerst angezeigt.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:46:07',NULL,NULL,1),(163,'Order Status','MODULE_PAYMENT_INVOICE_ORDER_STATUS_ID','1','Festlegung des Status für Bestellungen, welche mit dieser Zahlungsweise durchgeführt werden.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:46:07','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(169,'Enable Check/Money Order Module','MODULE_PAYMENT_MONEYORDER_STATUS','True','Do you want to accept Check/Money Order payments?','BOX_CONFIGURATION_MODULE',1,'2016-04-13 17:08:47','2016-04-11 15:48:09',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(175,'Money Order Make Payable to:','MODULE_PAYMENT_MONEYORDER_PAYTO','','Who should payments be made payable to?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-04-11 15:48:09',NULL,NULL,1),(181,'Money Order Sort order of display.','MODULE_PAYMENT_MONEYORDER_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:48:09',NULL,NULL,1),(187,'Money Order Payment Zone','MODULE_PAYMENT_MONEYORDER_ZONE','4','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:48:09','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(193,'Money Order Set Order Status','MODULE_PAYMENT_MONEYORDER_ORDER_STATUS_ID','1','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:48:09','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(199,'Enable Free Charge Module','MODULE_PAYMENT_FREECHARGER_STATUS','False','Do you want to accept Free Charge payments?','BOX_CONFIGURATION_MODULE',1,'2016-04-12 14:50:32','2016-04-11 15:50:23',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(205,'Free Charge Sort order of display.','MODULE_PAYMENT_FREECHARGER_SORT_ORDER','70','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:50:23',NULL,NULL,1),(211,'Free Charge Payment Zone','MODULE_PAYMENT_FREECHARGER_ZONE','4','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:50:23','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(217,'Free Charge Set Order Status','MODULE_PAYMENT_FREECHARGER_ORDER_STATUS_ID','3','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:50:23','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(223,'Enable Authorize.net Module','MODULE_PAYMENT_AUTHORIZENET_STATUS','False','Do you want to accept Authorize.net payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:33','2016-04-11 15:51:38',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(229,'Authorizenet Login Username','MODULE_PAYMENT_AUTHORIZENET_LOGIN','testing','The login username used for the Authorize.net service','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,NULL,1),(235,'Authorizenet Transaction Key','MODULE_PAYMENT_AUTHORIZENET_TXNKEY','Test','Transaction Key used for encrypting TP data','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,NULL,1),(241,'Authorizenet Transaction Mode','MODULE_PAYMENT_AUTHORIZENET_TESTMODE','Test','Transaction mode used for processing orders','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,'tep_cfg_select_option(array(\'Test\', \'Production\'), ',1),(247,'Authorizenet Transaction Method','MODULE_PAYMENT_AUTHORIZENET_METHOD','Credit Card','Transaction method used for processing orders','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,'tep_cfg_select_option(array(\'Credit Card\', \'eCheck\'), ',1),(253,'Authorizenet Customer Notifications','MODULE_PAYMENT_AUTHORIZENET_EMAIL_CUSTOMER','False','Should Authorize.Net e-mail a receipt to the customer?','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(259,'Authorizenet - Sort order of display.','MODULE_PAYMENT_AUTHORIZENET_SORT_ORDER','80','Authorizenet - Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:51:38',NULL,NULL,1),(265,'Authorizenet - Payment Zone','MODULE_PAYMENT_AUTHORIZENET_ZONE','0','Authorizenet - If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:51:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(271,'Authorizenet - Set Order Status','MODULE_PAYMENT_AUTHORIZENET_ORDER_STATUS_ID','0','Authorizenet - Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(277,'Enable EFSnet Module','MODULE_PAYMENT_EFSNET_STATUS','False','Do you want to accept EFSNet payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:34','2016-04-11 15:57:06',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(283,'EFSnet Login Username','MODULE_PAYMENT_EFSNET_STOREID','testing','The StoreID used for the EFSNet service','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06',NULL,NULL,1),(289,'EFSnet Transaction Key','MODULE_PAYMENT_EFSNET_STOREKEY','Test','Store Key used for encrypting data','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06',NULL,NULL,1),(295,'EFSnet Transaction Mode','MODULE_PAYMENT_EFSNET_TESTMODE','Test','Transaction mode used for processing orders','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06',NULL,'tep_cfg_select_option(array(\'Test\', \'Production\'), ',1),(301,'EFSnet Transaction Method','MODULE_PAYMENT_EFSNET_METHOD','CreditCardCharge','Transaction method used for processing orders','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06',NULL,'tep_cfg_select_option(array(\'CreditCardCharge\',\'CreditCardAuthorize\'), ',1),(307,'EFSnet Sort order of display.','MODULE_PAYMENT_EFSNET_SORT_ORDER','90','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:57:06',NULL,NULL,1),(313,'EFSnet Payment Zone','MODULE_PAYMENT_EFSNET_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:57:06','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(319,'EFSnet Set Order Status','MODULE_PAYMENT_EFSNET_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(523,'cURL Program Location','MODULE_PAYMENT_SAGE_PAY_SERVER_CURL','/usr/bin/curl','The location to the cURL program application.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:11:50',NULL,NULL,1),(571,'Int\'l Shipping Methods','MODULE_SHIPPING_USPS_TYPES_INTL','Priority Mail Express International, Priority Mail International','Select the international services to be offered:','BOX_CONFIGURATION_MODULE',15,NULL,'2016-11-16 13:31:02',NULL,'tep_cfg_select_multioption(array(\'Priority Mail Express International\', \'Priority Mail International\'),',1),(577,'Installed Modules','MODULE_SHIPPING_INSTALLED','flat.php;freeshipper.php;zonetable.php;item.php;percent.php;table.php;zones.php','List of shipping module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ups.php;flat.php;item.php)','BOX_CONFIGURATION_MODULE',0,'2022-06-24 14:23:54','2003-07-17 10:29:22',NULL,NULL,1),(583,'FREESHIPPER Sort Order','MODULE_SHIPPING_FREESHIPPER_SORT_ORDER','30','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:27:21',NULL,NULL,1),(589,'Flat Sort Order','MODULE_SHIPPING_FLAT_SORT_ORDER','10','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 14:03:53',NULL,NULL,1),(595,'Item Shipping Sort Order','MODULE_SHIPPING_ITEM_SORT_ORDER','50','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:59:56',NULL,NULL,1),(601,'Sort Order','MODULE_SHIPPING_USPS_SORT_ORDER','80','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2016-11-16 13:31:02','2016-11-16 13:31:02',NULL,NULL,1),(607,'Domestic Shipping Methods','MODULE_SHIPPING_USPS_TYPES','First Class, Priority Mail, Priority Mail Express','Select the domestic services to be offered:','BOX_CONFIGURATION_MODULE',14,NULL,'2016-11-16 13:31:02',NULL,'tep_cfg_select_multioption(array(\'First Class\', \'Priority Mail\', \'Priority Mail Express\'),',1),(613,'Shipping Zone','MODULE_SHIPPING_USPS_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(619,'Tax Class','MODULE_SHIPPING_USPS_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(625,'Handling Fee','MODULE_SHIPPING_USPS_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02',NULL,NULL,1),(631,'Zone 1 Handling Fee','MODULE_SHIPPING_ZONES_HANDLING_1','0','Handling Fee for this shipping zone','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:47:33',NULL,NULL,1),(637,'Zone 1 Shipping Table','MODULE_SHIPPING_ZONES_COST_1','3:8.50,7:10.50,99:20.00','Shipping rates to Zone 1 destinations based on a group of maximum order weights. Example: 3:8.50,7:10.50,... Weights less than or equal to 3 would cost 8.50 for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:47:33',NULL,NULL,1),(643,'Zone 1 Countries','MODULE_SHIPPING_ZONES_COUNTRIES_1','US,CA','Comma separated list of two character ISO country codes that are part of Zone 1.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:47:33',NULL,NULL,1),(649,'Zones Sort Order','MODULE_SHIPPING_ZONES_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:47:33',NULL,NULL,1),(655,'Zones Tax Class','MODULE_SHIPPING_ZONES_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:47:33','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(661,'Zones Enable Zones Method','MODULE_SHIPPING_ZONES_STATUS','False','Do you want to offer zone rate shipping?','BOX_CONFIGURATION_MODULE',0,'2022-02-23 15:42:02','2016-11-16 13:47:33',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(667,'Percentage Sort Order','MODULE_SHIPPING_PERCENT_SORT_ORDER','60','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:52:35',NULL,NULL,1),(673,'Flat Shipping Zone','MODULE_SHIPPING_FLAT_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 14:03:53','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(679,'Flat Tax Class','MODULE_SHIPPING_FLAT_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 14:03:53','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(685,'Flat Shipping Cost','MODULE_SHIPPING_FLAT_COST','5','The shipping cost for all orders using this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 14:03:53',NULL,NULL,1),(691,'Enable Flat Shipping','MODULE_SHIPPING_FLAT_STATUS','True','Do you want to offer flat rate shipping?','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:36:10','2016-11-16 14:03:53',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(697,'Item Shipping Shipping Zone','MODULE_SHIPPING_ITEM_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:59:56','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(703,'Item Shipping Tax Class','MODULE_SHIPPING_ITEM_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:59:56','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(709,'Item Shipping Handling Fee','MODULE_SHIPPING_ITEM_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:59:56',NULL,NULL,1),(715,'Item Shipping Shipping Cost','MODULE_SHIPPING_ITEM_COST','0','The shipping cost will be multiplied by the number of items in an order that uses this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:59:56',NULL,NULL,1),(721,'Enable Item Shipping','MODULE_SHIPPING_ITEM_STATUS','False','Do you want to offer per item rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-01-11 16:18:17','2016-11-16 13:59:56',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(727,'Percentage Shipping Zone','MODULE_SHIPPING_PERCENT_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(733,'Percentage Tax Class','MODULE_SHIPPING_PERCENT_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(739,'Percentage A Flat Rate of','MODULE_SHIPPING_PERCENT_FLAT_USE','6.50','A Flat Rate used for all orders.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35',NULL,NULL,1),(745,'Percentage A Flat Rate for orders under','MODULE_SHIPPING_PERCENT_LESS_THEN','34.75','A Flat Rate for all orders that are under the amount shown.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35',NULL,NULL,1),(751,'Percentage Rate','MODULE_SHIPPING_PERCENT_RATE','.18','The Percentage Rate all .01 to .99 for all orders using this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35',NULL,NULL,1),(757,'Enable Percent Shipping','MODULE_SHIPPING_PERCENT_STATUS','True','Do you want to offer percent rate shipping?','BOX_CONFIGURATION_MODULE',0,'2022-06-24 14:34:30','2016-11-16 13:52:35',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(763,'Which server to use','MODULE_SHIPPING_USPS_SERVER','test','An account at USPS is needed to use the Production server','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02',NULL,'tep_cfg_select_option(array(\'test\', \'production\'), ',1),(769,'Enter the USPS Password','MODULE_SHIPPING_USPS_PASSWORD','','See USERID, above.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02',NULL,NULL,1),(775,'Enter the USPS User ID','MODULE_SHIPPING_USPS_USERID','','Enter the USPS USERID assigned to you.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02',NULL,NULL,1),(781,'FREESHIPPER Shipping Zone','MODULE_SHIPPING_FREESHIPPER_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:27:21','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(787,'FREESHIPPER Tax Class','MODULE_SHIPPING_FREESHIPPER_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:27:21','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(793,'Free Shipping Cost','MODULE_SHIPPING_FREESHIPPER_COST','0.00','What is the Shipping cost? The Handling fee will also be added.','BOX_CONFIGURATION_MODULE',6,NULL,'2016-11-16 13:27:21',NULL,NULL,1),(799,'Enable Free Shipping','MODULE_SHIPPING_FREESHIPPER_STATUS','False','Do you want to offer Free shipping?','BOX_CONFIGURATION_MODULE',5,'2017-07-19 15:13:02','2016-11-16 13:27:21',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(805,'Enable USPS Shipping','MODULE_SHIPPING_USPS_STATUS','False','Do you want to offer USPS shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-21 16:18:57','2016-11-16 13:31:02',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(811,'UPS Shipping Methods','MODULE_SHIPPING_UPS_TYPES','1DM, 1DML, 1DA, 1DAL, 1DAPI, 1DP, 1DPL, 2DM, 2DML, 2DA, 2DAL, 3DS, GND, STD, XPR, XPRL, XDM, XDML, XPD','Select the UPS services to be offered.','BOX_CONFIGURATION_MODULE',13,NULL,'2016-11-16 13:01:59',NULL,'tep_cfg_select_multioption(array(\'1DM\',\'1DML\', \'1DA\', \'1DAL\', \'1DAPI\', \'1DP\', \'1DPL\', \'2DM\', \'2DML\', \'2DA\', \'2DAL\', \'3DS\',\'GND\', \'STD\', \'XPR\', \'XPRL\', \'XDM\', \'XDML\', \'XPD\'), ',1),(817,'UPS Sort order of display.','MODULE_SHIPPING_UPS_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:01:59',NULL,NULL,1),(823,'UPS Shipping Zone','MODULE_SHIPPING_UPS_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(829,'UPS Handling Fee','MODULE_SHIPPING_UPS_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59',NULL,NULL,1),(835,'UPS Tax Class','MODULE_SHIPPING_UPS_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(841,'UPS Residential Delivery?','MODULE_SHIPPING_UPS_RES','RES','Quote for Residential (RES) or Commercial Delivery (COM)','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59',NULL,NULL,1),(847,'UPS Packaging?','MODULE_SHIPPING_UPS_PACKAGE','CP','CP - Your Packaging, ULE - UPS Letter, UT - UPS Tube, UBE - UPS Express Box','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59',NULL,NULL,1),(853,'Enable UPS Shipping','MODULE_SHIPPING_UPS_STATUS','False','Do you want to offer UPS shipping?','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:46:54','2016-11-16 13:01:59',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(859,'UPS Pickup Method','MODULE_SHIPPING_UPS_PICKUP','CC','How do you give packages to UPS? CC - Customer Counter, RDP - Daily Pickup, OTP - One Time Pickup, LC - Letter Center, OCA - On Call Air','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59',NULL,NULL,1),(865,'Table Method Sort Order','MODULE_SHIPPING_TABLE_SORT_ORDER','70','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-24 17:14:14',NULL,NULL,1),(871,'Table Method Shipping Zone','MODULE_SHIPPING_TABLE_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(877,'Table Method Handling Fee','MODULE_SHIPPING_TABLE_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14',NULL,NULL,1),(883,'Table Method Tax Class','MODULE_SHIPPING_TABLE_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(889,'Table Method','MODULE_SHIPPING_TABLE_MODE','weight','The shipping cost is based on the order total or the total weight of the items ordered.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14',NULL,'tep_cfg_select_option(array(\'weight\', \'price\'), ',1),(895,'Table Method Shipping Table','MODULE_SHIPPING_TABLE_COST','25:8.50,50:5.50,10000:0.00','The shipping cost is based on the total cost or weight of items. Example: 25:8.50,50:5.50,etc.. Up to 25 charge 8.50, from there to 50 charge 5.50, etc','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14',NULL,NULL,1),(901,'USPS Options','MODULE_SHIPPING_USPS_OPTIONS','Display weight, Display transit time','Select from the following the USPS options.','BOX_CONFIGURATION_MODULE',16,NULL,'2016-11-16 13:31:02',NULL,'tep_cfg_select_multioption(array(\'Display weight\', \'Display transit time\'), ',1),(907,'Enable Table Method','MODULE_SHIPPING_TABLE_STATUS','False','Do you want to offer table rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-02-22 16:42:12','2016-11-24 17:14:14',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(913,'Installed Modules','MODULE_ORDER_TOTAL_INSTALLED','ot_subtotal.php;ot_coupon.php;ot_gift_wrap.php;ot_loworderfee.php;ot_shipping.php;ot_gv.php;ot_shippingfee.php;ot_paymentfee.php;ot_bonus_points.php;ot_subtax.php;ot_tax.php;ot_total.php;ot_paid.php;ot_due.php;ot_refund.php','List of order_total module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ot_subtotal.php;ot_tax.php;ot_shipping.php;ot_total.php)','BOX_CONFIGURATION_MODULE',0,'2020-10-09 13:42:16','2003-07-17 10:29:22',NULL,NULL,1),(919,'Sort Order','MODULE_ORDER_TOTAL_SUBTOTAL_SORT_ORDER','10','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:10:43',NULL,NULL,1),(925,'Display Sub-Total','MODULE_ORDER_TOTAL_SUBTOTAL_STATUS','true','Do you want to display the order sub-total cost?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:01:29','2016-11-16 12:10:43',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(931,'Sort Order','MODULE_ORDER_TOTAL_TAX_SORT_ORDER','110','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:08:32',NULL,NULL,1),(937,'Display Tax','MODULE_ORDER_TOTAL_TAX_STATUS','true','Do you want to display the order tax value?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 12:08:32',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(943,'Sort Order','MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER','120','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:06:52',NULL,NULL,1),(949,'Display Total','MODULE_ORDER_TOTAL_TOTAL_STATUS','true','Do you want to display the total order value?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 12:06:52',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(955,'Tax Class','MODULE_ORDER_TOTAL_COUPON_TAX_CLASS','0','Use the following tax class when treating Discount Coupon as Credit Note.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 12:12:22','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(961,'Re-calculate Tax','MODULE_ORDER_TOTAL_COUPON_CALC_TAX','None','Re-Calculate Tax','BOX_CONFIGURATION_MODULE',7,NULL,'2016-11-16 12:12:22',NULL,'tep_cfg_select_option(array(\'None\', \'Standard\', \'Credit Note\'), ',1),(967,'Include Tax','MODULE_ORDER_TOTAL_COUPON_INC_TAX','false','Include Tax in calculation.','BOX_CONFIGURATION_MODULE',6,NULL,'2016-11-16 12:12:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(973,'Include Shipping','MODULE_ORDER_TOTAL_COUPON_INC_SHIPPING','false','Include Shipping in calculation','BOX_CONFIGURATION_MODULE',5,NULL,'2016-11-16 12:12:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(979,'Sort Order','MODULE_ORDER_TOTAL_COUPON_SORT_ORDER','20','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:12:22',NULL,NULL,1),(985,'Credit including Tax','MODULE_ORDER_TOTAL_GV_CREDIT_TAX','false','Add tax to purchased Gift Voucher when crediting to Account','BOX_CONFIGURATION_MODULE',8,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(991,'Tax Class','MODULE_ORDER_TOTAL_GV_TAX_CLASS','0','Use the following tax class when treating Gift Voucher as Credit Note.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:44:20','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(997,'Re-calculate Tax','MODULE_ORDER_TOTAL_GV_CALC_TAX','None','Re-Calculate Tax','BOX_CONFIGURATION_MODULE',7,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'None\', \'Standard\', \'Credit Note\'), ',1),(1003,'Include Tax','MODULE_ORDER_TOTAL_GV_INC_TAX','true','Include Tax in calculation.','BOX_CONFIGURATION_MODULE',6,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1009,'Include Shipping','MODULE_ORDER_TOTAL_GV_INC_SHIPPING','true','Include Shipping in calculation','BOX_CONFIGURATION_MODULE',5,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1015,'Sort Order','MODULE_ORDER_TOTAL_GV_SORT_ORDER','60','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:44:20',NULL,NULL,1),(1021,'Queue Purchases','MODULE_ORDER_TOTAL_GV_QUEUE','true','Do you want to queue purchases of the Gift Voucher?','BOX_CONFIGURATION_MODULE',3,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1027,'Display Total','MODULE_ORDER_TOTAL_GV_STATUS','true','Do you want to display the Gift Voucher value?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1063,'Tax Class','MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS','0','Use the following tax class on the low order fee.','BOX_CONFIGURATION_MODULE',7,NULL,'2016-11-16 13:47:46','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(1069,'Attach Low Order Fee On Orders Made','MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION','both','Attach low order fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,NULL,'2016-11-16 13:47:46',NULL,'tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',1),(1075,'Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_FEE','5','Low order fee.','BOX_CONFIGURATION_MODULE',5,NULL,'2016-11-16 13:47:46','currencies->format',NULL,1),(1081,'Order Fee For Orders Under','MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER','50','Add the low order fee to orders under this amount.','BOX_CONFIGURATION_MODULE',4,NULL,'2016-11-16 13:47:46','currencies->format',NULL,1),(1087,'Allow Low Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE','false','Do you want to allow low order fees?','BOX_CONFIGURATION_MODULE',3,NULL,'2016-11-16 13:47:46',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1093,'Sort Order','MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER','40','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:47:46',NULL,NULL,1),(1099,'Sort Order','MODULE_ORDER_TOTAL_GIFT_WRAP_SORT_ORDER','30','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:46:52',NULL,NULL,1),(1105,'Tax Class','MODULE_ORDER_TOTAL_GIFT_WRAP_TAX_CLASS','3','Use the following tax class on the Gift Wrap Order Fee.','BOX_CONFIGURATION_MODULE',7,NULL,'2016-11-16 12:46:52','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(1111,'Display Total','MODULE_ORDER_TOTAL_COUPON_STATUS','true','Do you want to display the Discount Coupon value?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:01:31','2016-11-16 12:12:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1117,'Display Low Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS','true','Do you want to display the low order fee?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 13:47:46',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1129,'Provide Free Shipping For Orders Made','MODULE_ORDER_TOTAL_SHIPPING_DESTINATION','both','Provide free shipping for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',5,NULL,'2016-11-16 13:51:20',NULL,'tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',1),(1135,'Free Shipping For Orders Over','MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER','100','Provide free shipping for orders over the set amount.','BOX_CONFIGURATION_MODULE',4,NULL,'2016-11-16 13:51:20','currencies->format',NULL,1),(1141,'Allow Free Shipping','MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING','false','Do you want to allow free shipping?','BOX_CONFIGURATION_MODULE',3,NULL,'2016-11-16 13:51:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1147,'Sort Order','MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER','50','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:51:20',NULL,NULL,1),(1153,'Display Shipping','MODULE_ORDER_TOTAL_SHIPPING_STATUS','true','Do you want to display the order shipping cost?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 13:51:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1159,'Display Gift Wrap Order Fee','MODULE_ORDER_TOTAL_GIFT_WRAP_STATUS','true','Do you want to display the Gift Wrap Order Fee?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:02:22','2016-11-16 12:46:52',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1165,'Allowed Order Statuses','MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID','4, 3, 2','Select the status of orders to be processed.','BOX_CONFIGURATION_MODULE',13,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_multioption_order_statuses(',1),(1171,'Modules Sort','DD_MODULE_SHIPPING_SORT','flat.php;ups.php;freeshipper.php;zonetable.php;item.php;percent.php;table.php;usps.php;zones.php;zonesperitem.php;fedex1.php;dp.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-04-11 15:39:31',NULL,NULL,1),(1177,'Modules Sort','DD_MODULE_ORDER_TOTAL_SORT','ot_subtotal.php;ot_coupon.php;ot_gift_wrap.php;ot_loworderfee.php;ot_shipping.php;ot_gv.php;ot_shippingfee.php;ot_paymentfee.php;ot_bonus_points.php;ot_subtax.php;ot_tax.php;ot_total.php;ot_paid.php;ot_due.php;ot_fixed_payment_chg.php;ot_custom.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-09-28 11:28:21','2016-04-11 15:34:09',NULL,NULL,1),(1201,'Enable Zones Per Item Method','MODULE_SHIPPING_ZONESPERITEM_STATUS','False','Do you want to offer zone rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-14 15:08:27','2016-12-21 15:38:29',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(1202,'Zones Per Item Tax Class','MODULE_SHIPPING_ZONESPERITEM_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:38:29','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(1203,'Zones Per Item Sort Order','MODULE_SHIPPING_ZONESPERITEM_SORT_ORDER','100','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-12-21 15:38:29',NULL,NULL,1),(1204,'Number of Zones','MODULE_SHIPPING_ZONESPERITEM_NUMBER_OF_ZONES','1','Number of zones needed.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:38:29',NULL,NULL,1),(1205,'Zone 1 Geo Zone','MODULE_SHIPPING_ZONESPERITEM_GEO_ZONE_1','0','Select Geo Zone of this Zone 1.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,1),(1206,'Zone 1 Standard Initial Item Charge','MODULE_SHIPPING_ZONESPERITEM_STANDARD_INITIAL_ITEM_CHARGE_1','2.50','Standard Initial Item Charge for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,1),(1207,'Zone 1 Standard Additional Item Charge','MODULE_SHIPPING_ZONESPERITEM_STANDARD_ADDITIONAL_ITEM_CHARGE_1','0.50','Standard Additional Item Charge for this shipping zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,1),(1208,'Zone 1 Standard Free Delivery Amount','MODULE_SHIPPING_ZONESPERITEM_STANDARD_FREE_DELIVERY_AMOUNT_1','20.00','Amount of subtotal for free standard delivery for this shipping zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,1),(1209,'Zone 1 Premium Initial Item Charge','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_INITIAL_ITEM_CHARGE_1','4.50','Premium Initial Item Charge for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,1),(1210,'Zone 1 Premium Additional Item Charge','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_ADDITIONAL_ITEM_CHARGE_1','0.00','Premium Additional Item Charge for this shipping zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,1),(1211,'Zone 1 Premium Free Delivery Amount','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_FREE_DELIVERY_AMOUNT_1','20.00','Amount of subtotal for free premium delivery for this shipping zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,1),(1216,'Set status for covered order','MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID_COVERS','2','Covered order','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-27 15:46:30','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(1217,'Enable Table Method','MODULE_SHIPPING_ZONE_TABLE_STATUS','True','Do you want to offer Zone Table rate shipping?','BOX_CONFIGURATION_MODULE',0,'2022-02-23 15:41:57','2017-01-05 14:27:17',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(1218,'Handling Fee','MODULE_SHIPPING_ZONE_TABLE_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2017-01-05 14:27:17',NULL,NULL,1),(1219,'Tax Class','MODULE_SHIPPING_ZONE_TABLE_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2017-01-05 14:27:17','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(1220,'Sort Order','MODULE_SHIPPING_ZONE_TABLE_SORT_ORDER','40','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2017-01-05 14:27:17',NULL,NULL,1),(1230,'Display Shipping Fee','MODULE_ORDER_TOTAL_SHIPPINGFEE_STATUS','true','Do you want to display the shipping Fee?','BOX_CONFIGURATION_MODULE',1,NULL,'2017-01-13 11:37:45',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1231,'Sort Order','MODULE_ORDER_TOTAL_SHIPPINGFEE_SORT_ORDER','70','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-01-13 11:37:45',NULL,NULL,1),(1232,'Allow Shipping Fee','MODULE_ORDER_TOTAL_SHIPPINGFEE_ALLOW_FEE','false','Do you want to allow shipping fees?','BOX_CONFIGURATION_MODULE',3,NULL,'2017-01-13 11:37:45',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1233,'Attach Shipping Fee on Orders Made','MODULE_ORDER_TOTAL_SHIPPINGFEE_DESTINATION','both','Attach shipping fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,NULL,'2017-01-13 11:37:45',NULL,'tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',1),(1234,'Tax Class','MODULE_ORDER_TOTAL_SHIPPINGFEE_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',7,NULL,'2017-01-13 11:37:45','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(1235,'Display Payment Fee','MODULE_ORDER_TOTAL_PAYMENTFEE_STATUS','true','Do you want to display the payment fee?','BOX_CONFIGURATION_MODULE',1,NULL,'2017-01-13 11:37:59',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1236,'Sort Order','MODULE_ORDER_TOTAL_PAYMENTFEE_SORT_ORDER','80','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-01-13 11:37:59',NULL,NULL,1),(1237,'Allow Payment Fee','MODULE_ORDER_TOTAL_PAYMENTFEE_ALLOW_FEE','false','Do you want to allow payment fees?','BOX_CONFIGURATION_MODULE',3,NULL,'2017-01-13 11:37:59',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1238,'Attach Payment Fee On Orders Made','MODULE_ORDER_TOTAL_PAYMENTFEE_DESTINATION','both','Attach payment fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,NULL,'2017-01-13 11:37:59',NULL,'tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',1),(1239,'Tax Class','MODULE_ORDER_TOTAL_PAYMENTFEE_TAX_CLASS','0','Use the following tax class on the payment fee.','BOX_CONFIGURATION_MODULE',7,NULL,'2017-01-13 11:37:59','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(1247,'Display Subtotal for taxation','MODULE_ORDER_TOTAL_SUBTAX_STATUS','true','Do you want to display the subtotal for taxation value?','BOX_CONFIGURATION_MODULE',1,NULL,'2017-02-22 14:10:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1248,'Sort Order','MODULE_ORDER_TOTAL_SUBTAX_SORT_ORDER','100','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-02-22 14:10:20',NULL,NULL,1),(1279,'Display Admount Paid','MODULE_ORDER_TOTAL_PAID_STATUS','true','Do you want to display the Admount Paid?','BOX_CONFIGURATION_MODULE',140,NULL,'2017-04-01 11:18:23',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1280,'Sort Order','MODULE_ORDER_TOTAL_PAID_SORT_ORDER','130','Sort order of display.','BOX_CONFIGURATION_MODULE',140,'2017-10-11 15:53:32','2017-04-01 11:18:23',NULL,NULL,1),(1281,'Display Admount Due','MODULE_ORDER_TOTAL_DUE_STATUS','true','Do you want to display the Admount Due?','BOX_CONFIGURATION_MODULE',150,NULL,'2017-04-01 11:18:33',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(1282,'Sort Order','MODULE_ORDER_TOTAL_DUE_SORT_ORDER','140','Sort order of display.','BOX_CONFIGURATION_MODULE',150,'2017-10-11 15:53:32','2017-04-01 11:18:33',NULL,NULL,1),(1287,'Modules Sort','DD_MODULE_PAYMENT_SORT','cod.php;cash.php;paypalipn.php;sage_pay_server.php;offline.php;rbsworldpay_hosted.php;paypal_express.php;recurly.php;liqpay.php;klarna_checkout.php;amazon_payment.php;for_collect.php;multisafepay.php;paypal.php;paypal_pro_hs.php;pxpay.php;stripe_ds.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2018-03-22 13:24:41','2017-04-03 09:43:41',NULL,NULL,1),(1288,'OFFLINE Enable Module','MODULE_PAYMENT_OFFLINE_STATUS','False','Do you want to accept OFFLINE payments?','BOX_CONFIGURATION_MODULE',1,'2022-07-18 14:31:07','2017-04-03 11:25:11',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(1289,'OFFLINE Payment Zone','MODULE_PAYMENT_OFFLINE_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'2022-07-18 14:31:07','2017-04-03 11:25:11','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(1290,'OFFLINE Order Status','MODULE_PAYMENT_OFFLINE_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'2022-07-18 14:31:07','2017-04-03 11:25:11','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(1291,'OFFLINE Sort order of display.','MODULE_PAYMENT_OFFLINE_SORT_ORDER','50','Sort order of OFFLINE display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:16:47','2017-04-03 11:25:11',NULL,NULL,1),(1292,'Enable WorldPay Hosted Payment Pages','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_STATUS','False','','BOX_CONFIGURATION_MODULE',0,'2018-01-11 16:18:09','2017-04-08 14:31:29',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(1293,'Installation ID','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_INSTALLATION_ID','','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,NULL,1),(1294,'Callback Password','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_CALLBACK_PASSWORD','','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,NULL,1),(1295,'MD5 Password','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_MD5_PASSWORD','','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,NULL,1),(1296,'Transaction Method','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TRANSACTION_METHOD','Capture','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,'tep_cfg_select_option(array(\'Pre-Authorization\', \'Capture\'), ',1),(1297,'Set Preparing Order Status','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_PREPARE_ORDER_STATUS_ID','1','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(1298,'Set Order Status','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_ORDER_STATUS_ID','100006','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(1299,'Transactions Order Status Level','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TRANSACTIONS_ORDER_STATUS_ID','1','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(1300,'Payment Zone','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_ZONE','0','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(1301,'Test Mode','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TESTMODE','True','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(1302,'Debug E-Mail Address','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_DEBUG_EMAIL','','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,NULL,1),(1303,'Sort order of display.','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_SORT_ORDER','20','','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:34:41','2017-04-08 14:31:29',NULL,NULL,1),(1514,'Verify meta tag','TRUSTPILOT_VERIFY_META_TAG','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',1),(1515,'Select integration','TRUSTPILOT_CONNECT_VIA','bccMail','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','tep_cfg_select_option(array(\'bccMail\', \'API\'),',1),(1516,'BCC Trustpilot email','TRUSTPILOT_BCC_EMAIL','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',1),(1517,'Public API key','TRUSTPILOT_API_KEY','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',1),(1518,'Private API secret','TRUSTPILOT_API_SECRET','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',1),(1519,'Business username','TRUSTPILOT_API_USERNAME','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',1),(1520,'Business password','TRUSTPILOT_API_PASSWORD','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',1),(1521,'Business Unit Id','TRUSTPILOT_BUSINESS_UNIT_ID','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-12 17:42:38','','',1),(1522,'Sender Name','TRUSTPILOT_SENDER_NAME','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',1),(1523,'Sender Email','TRUSTPILOT_SENDER_EMAIL','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',1),(1524,'Redirect URL','TRUSTPILOT_REDIRECT_URI','https://uk.trustpilot.com','https://www.trustpilot.com','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',1),(1525,'Delay invite send (days)','TRUSTPILOT_INVITE_DELAY','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',1),(1526,'Filter orders by','TRUSTPILOT_INVITE_ORDER_AMOUNT_BY','ot_total','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','tep_cfg_select_option(array(\'ot_subtotal\', \'ot_total\'),',1),(1527,'Filter orders by amount, from','TRUSTPILOT_INVITE_ORDER_AMOUNT_FROM','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',1),(1528,'Filter orders by amount, not above','TRUSTPILOT_INVITE_ORDER_AMOUNT_TO','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',1),(1529,'Status','TRUSTPILOT_STATUS','Disabled','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','tep_cfg_select_option(array(\'Disabled\', \'Enabled\'),',1),(1557,'Verify meta tag','TRUSTPILOT_VERIFY_META_TAG','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',4),(1558,'Select integration','TRUSTPILOT_CONNECT_VIA','bccMail','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','tep_cfg_select_option(array(\'bccMail\', \'API\'),',4),(1559,'BCC Trustpilot email','TRUSTPILOT_BCC_EMAIL','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',4),(1560,'Public API key','TRUSTPILOT_API_KEY','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',4),(1561,'Private API secret','TRUSTPILOT_API_SECRET','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',4),(1562,'Business username','TRUSTPILOT_API_USERNAME','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',4),(1563,'Business password','TRUSTPILOT_API_PASSWORD','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',4),(1564,'Business Unit Id','TRUSTPILOT_BUSINESS_UNIT_ID','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-12 17:42:38','','',4),(1565,'Sender Name','TRUSTPILOT_SENDER_NAME','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',4),(1566,'Sender Email','TRUSTPILOT_SENDER_EMAIL','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',4),(1567,'Redirect URL','TRUSTPILOT_REDIRECT_URI','https://uk.trustpilot.com','https://www.trustpilot.com','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',4),(1568,'Delay invite send (days)','TRUSTPILOT_INVITE_DELAY','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',4),(1569,'Filter orders by','TRUSTPILOT_INVITE_ORDER_AMOUNT_BY','ot_total','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','tep_cfg_select_option(array(\'ot_subtotal\', \'ot_total\'),',4),(1570,'Filter orders by amount, from','TRUSTPILOT_INVITE_ORDER_AMOUNT_FROM','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',4),(1571,'Filter orders by amount, not above','TRUSTPILOT_INVITE_ORDER_AMOUNT_TO','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',4),(1572,'Status','TRUSTPILOT_STATUS','Disabled','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','tep_cfg_select_option(array(\'Disabled\', \'Enabled\'),',4),(1647,'Modules Sort','DD_MODULE_ORDER_TOTAL_SORT','ot_subtotal.php;ot_coupon.php;ot_gift_wrap.php;ot_loworderfee.php;ot_shipping.php;ot_codcharge.php;ot_gv.php;ot_shippingfee.php;ot_paymentfee.php;ot_subtax.php;ot_tax.php;ot_total.php;ot_fixed_payment_chg.php;ot_custom.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-02-28 17:43:11','2016-04-11 15:34:09','','',0),(1648,'Modules Sort','DD_MODULE_PAYMENT_SORT','offline.php;paypal.php;cod.php;klarna_checkout.php;recurly.php;paypalipn.php;multisafepay.php;sage_pay_server.php;rbsworldpay_hosted.php;paypal_express.php;stripe_ds.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:45:21','2017-04-03 09:43:41','','',0),(1649,'Modules Sort','DD_MODULE_SHIPPING_SORT','flat.php;ups.php;freeshipper.php;zonetable.php;item.php;percent.php;table.php;usps.php;zones.php;zonesperitem.php;fedex1.php;dp.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-04-11 15:39:31','','',0),(1650,'Re-calculate Tax','MODULE_ORDER_TOTAL_COUPON_CALC_TAX','None','Re-Calculate Tax','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2016-11-16 12:12:22','','tep_cfg_select_option(array(\'None\', \'Standard\', \'Credit Note\'), ',0),(1651,'Include Shipping','MODULE_ORDER_TOTAL_COUPON_INC_SHIPPING','false','Include Shipping in calculation','BOX_CONFIGURATION_MODULE',5,'0000-00-00 00:00:00','2016-11-16 12:12:22','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1652,'Include Tax','MODULE_ORDER_TOTAL_COUPON_INC_TAX','false','Include Tax in calculation.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2016-11-16 12:12:22','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1653,'Sort Order','MODULE_ORDER_TOTAL_COUPON_SORT_ORDER','20','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-02-28 17:43:11','2016-11-16 12:12:22','','',0),(1654,'Display Total','MODULE_ORDER_TOTAL_COUPON_STATUS','true','Do you want to display the Discount Coupon value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 12:12:22','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1655,'Tax Class','MODULE_ORDER_TOTAL_COUPON_TAX_CLASS','0','Use the following tax class when treating Discount Coupon as Credit Note.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 12:12:22','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1656,'Sort Order','MODULE_ORDER_TOTAL_DUE_SORT_ORDER','140','Sort order of display.','BOX_CONFIGURATION_MODULE',150,'2017-04-01 11:18:33','2017-04-01 11:18:33','','',0),(1657,'Display Admount Due','MODULE_ORDER_TOTAL_DUE_STATUS','true','Do you want to display the Admount Due?','BOX_CONFIGURATION_MODULE',150,'0000-00-00 00:00:00','2017-04-01 11:18:33','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1658,'Sort Order','MODULE_ORDER_TOTAL_GIFT_WRAP_SORT_ORDER','30','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-02-28 17:43:11','2016-11-16 12:46:52','','',0),(1659,'Display Gift Wrap Order Fee','MODULE_ORDER_TOTAL_GIFT_WRAP_STATUS','true','Do you want to display the Gift Wrap Order Fee?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 12:46:52','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1660,'Tax Class','MODULE_ORDER_TOTAL_GIFT_WRAP_TAX_CLASS','0','Use the following tax class on the Gift Wrap Order Fee.','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2016-11-16 12:46:52','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1661,'Re-calculate Tax','MODULE_ORDER_TOTAL_GV_CALC_TAX','None','Re-Calculate Tax','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'None\', \'Standard\', \'Credit Note\'), ',0),(1662,'Credit including Tax','MODULE_ORDER_TOTAL_GV_CREDIT_TAX','false','Add tax to purchased Gift Voucher when crediting to Account','BOX_CONFIGURATION_MODULE',8,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1663,'Include Shipping','MODULE_ORDER_TOTAL_GV_INC_SHIPPING','true','Include Shipping in calculation','BOX_CONFIGURATION_MODULE',5,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1664,'Include Tax','MODULE_ORDER_TOTAL_GV_INC_TAX','true','Include Tax in calculation.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1665,'Allowed Order Statuses','MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID','4, 3, 2','Select the status of orders to be processed.','BOX_CONFIGURATION_MODULE',13,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_multioption_order_statuses(',0),(1666,'Set status for covered order','MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID_COVERS','2','Covered order','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-27 15:46:30','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1667,'Queue Purchases','MODULE_ORDER_TOTAL_GV_QUEUE','true','Do you want to queue purchases of the Gift Voucher?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1668,'Sort Order','MODULE_ORDER_TOTAL_GV_SORT_ORDER','70','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-02-28 17:43:11','2016-11-16 13:44:20','','',0),(1669,'Display Total','MODULE_ORDER_TOTAL_GV_STATUS','true','Do you want to display the Gift Voucher value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1670,'Tax Class','MODULE_ORDER_TOTAL_GV_TAX_CLASS','0','Use the following tax class when treating Gift Voucher as Credit Note.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:44:20','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1671,'Installed Modules','MODULE_ORDER_TOTAL_INSTALLED','ot_subtotal.php;ot_coupon.php;ot_gift_wrap.php;ot_loworderfee.php;ot_shipping.php;ot_gv.php;ot_shippingfee.php;ot_paymentfee.php;ot_subtax.php;ot_tax.php;ot_total.php;ot_paid.php;ot_due.php','List of order_total module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ot_subtotal.php;ot_tax.php;ot_shipping.php;ot_total.php)','BOX_CONFIGURATION_MODULE',0,'2017-04-01 11:18:33','2003-07-17 10:29:22','','',0),(1672,'Attach Low Order Fee On Orders Made','MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION','both','Attach low order fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2016-11-16 13:47:46','','tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',0),(1673,'Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_FEE','5','Low order fee.','BOX_CONFIGURATION_MODULE',5,'0000-00-00 00:00:00','2016-11-16 13:47:46','currencies->format','',0),(1674,'Allow Low Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE','false','Do you want to allow low order fees?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2016-11-16 13:47:46','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1675,'Order Fee For Orders Under','MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER','50','Add the low order fee to orders under this amount.','BOX_CONFIGURATION_MODULE',4,'0000-00-00 00:00:00','2016-11-16 13:47:46','currencies->format','',0),(1676,'Sort Order','MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER','40','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-02-28 17:43:11','2016-11-16 13:47:46','','',0),(1677,'Display Low Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS','true','Do you want to display the low order fee?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 13:47:46','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1678,'Tax Class','MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS','0','Use the following tax class on the low order fee.','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2016-11-16 13:47:46','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1679,'Sort Order','MODULE_ORDER_TOTAL_PAID_SORT_ORDER','130','Sort order of display.','BOX_CONFIGURATION_MODULE',140,'2017-04-01 11:18:23','2017-04-01 11:18:23','','',0),(1680,'Display Admount Paid','MODULE_ORDER_TOTAL_PAID_STATUS','true','Do you want to display the Admount Paid?','BOX_CONFIGURATION_MODULE',140,'0000-00-00 00:00:00','2017-04-01 11:18:23','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1681,'Allow Payment Fee','MODULE_ORDER_TOTAL_PAYMENTFEE_ALLOW_FEE','false','Do you want to allow payment fees?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2017-01-13 11:37:59','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1682,'Attach Payment Fee On Orders Made','MODULE_ORDER_TOTAL_PAYMENTFEE_DESTINATION','both','Attach payment fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2017-01-13 11:37:59','','tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',0),(1683,'Sort Order','MODULE_ORDER_TOTAL_PAYMENTFEE_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-02-28 17:43:11','2017-01-13 11:37:59','','',0),(1684,'Display Payment Fee','MODULE_ORDER_TOTAL_PAYMENTFEE_STATUS','true','Do you want to display the payment fee?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2017-01-13 11:37:59','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1685,'Tax Class','MODULE_ORDER_TOTAL_PAYMENTFEE_TAX_CLASS','0','Use the following tax class on the payment fee.','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2017-01-13 11:37:59','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1686,'Allow Shipping Fee','MODULE_ORDER_TOTAL_SHIPPINGFEE_ALLOW_FEE','false','Do you want to allow shipping fees?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2017-01-13 11:37:45','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1687,'Attach Shipping Fee on Orders Made','MODULE_ORDER_TOTAL_SHIPPINGFEE_DESTINATION','both','Attach shipping fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2017-01-13 11:37:45','','tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',0),(1688,'Sort Order','MODULE_ORDER_TOTAL_SHIPPINGFEE_SORT_ORDER','80','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-02-28 17:43:11','2017-01-13 11:37:45','','',0),(1689,'Display Shipping Fee','MODULE_ORDER_TOTAL_SHIPPINGFEE_STATUS','true','Do you want to display the shipping Fee?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2017-01-13 11:37:45','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1690,'Tax Class','MODULE_ORDER_TOTAL_SHIPPINGFEE_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2017-01-13 11:37:45','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1691,'Provide Free Shipping For Orders Made','MODULE_ORDER_TOTAL_SHIPPING_DESTINATION','both','Provide free shipping for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',5,'0000-00-00 00:00:00','2016-11-16 13:51:20','','tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',0),(1692,'Allow Free Shipping','MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING','true','Do you want to allow free shipping?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2016-11-16 13:51:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1693,'Free Shipping For Orders Over','MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER','50','Provide free shipping for orders over the set amount.','BOX_CONFIGURATION_MODULE',4,'0000-00-00 00:00:00','2016-11-16 13:51:20','currencies->format','',0),(1694,'Sort Order','MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER','50','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-02-28 17:43:11','2016-11-16 13:51:20','','',0),(1695,'Display Shipping','MODULE_ORDER_TOTAL_SHIPPING_STATUS','true','Do you want to display the order shipping cost?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 13:51:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1696,'Sort Order','MODULE_ORDER_TOTAL_SUBTAX_SORT_ORDER','100','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-02-28 17:43:11','2017-02-22 14:10:20','','',0),(1697,'Display Subtotal for taxation','MODULE_ORDER_TOTAL_SUBTAX_STATUS','true','Do you want to display the subtotal for taxation value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2017-02-22 14:10:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1698,'Sort Order','MODULE_ORDER_TOTAL_SUBTOTAL_SORT_ORDER','10','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-02-28 17:43:11','2016-11-16 12:10:43','','',0),(1699,'Display Sub-Total','MODULE_ORDER_TOTAL_SUBTOTAL_STATUS','true','Do you want to display the order sub-total cost?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 12:10:43','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1700,'Sort Order','MODULE_ORDER_TOTAL_TAX_SORT_ORDER','110','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-02-28 17:43:11','2016-11-16 12:08:32','','',0),(1701,'Display Tax','MODULE_ORDER_TOTAL_TAX_STATUS','true','Do you want to display the order tax value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 12:08:32','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1703,'Sort Order','MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER','120','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-02-28 17:43:11','2016-11-16 12:06:52','','',0),(1704,'Display Total','MODULE_ORDER_TOTAL_TOTAL_STATUS','true','Do you want to display the total order value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 12:06:52','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(1705,'2CheckOut Merchant Notifications','MODULE_PAYMENT_2CHECKOUT_EMAIL_MERCHANT','True','Should 2CheckOut e-mail a receipt to the store owner?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1706,'2CheckOut Login/Store Number','MODULE_PAYMENT_2CHECKOUT_LOGIN','18157','Login/Store Number used for the 2CheckOut service','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','','',0),(1707,'2CheckOut Set Order Status','MODULE_PAYMENT_2CHECKOUT_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1708,'2CheckOut Sort order of display.','MODULE_PAYMENT_2CHECKOUT_SORT_ORDER','100','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-08 16:55:21','','',0),(1709,'Enable 2CheckOut Module','MODULE_PAYMENT_2CHECKOUT_STATUS','False','Do you want to accept 2CheckOut payments?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1710,'2CheckOut Transaction Mode','MODULE_PAYMENT_2CHECKOUT_TESTMODE','Test','Transaction mode used for the 2Checkout service','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','','tep_cfg_select_option(array(\'Test\', \'Production\'), ',0),(1711,'2CheckOut Payment Zone','MODULE_PAYMENT_2CHECKOUT_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-08 16:55:21','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1712,'Authorizenet Customer Notifications','MODULE_PAYMENT_AUTHORIZENET_EMAIL_CUSTOMER','False','Should Authorize.Net e-mail a receipt to the customer?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1713,'Authorizenet Login Username','MODULE_PAYMENT_AUTHORIZENET_LOGIN','testing','The login username used for the Authorize.net service','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','',0),(1714,'Authorizenet Transaction Method','MODULE_PAYMENT_AUTHORIZENET_METHOD','Credit Card','Transaction method used for processing orders','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','tep_cfg_select_option(array(\'Credit Card\', \'eCheck\'), ',0),(1715,'Authorizenet - Set Order Status','MODULE_PAYMENT_AUTHORIZENET_ORDER_STATUS_ID','0','Authorizenet - Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1716,'Authorizenet - Sort order of display.','MODULE_PAYMENT_AUTHORIZENET_SORT_ORDER','80','Authorizenet - Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:51:38','','',0),(1717,'Enable Authorize.net Module','MODULE_PAYMENT_AUTHORIZENET_STATUS','False','Do you want to accept Authorize.net payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:33','2016-04-11 15:51:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1718,'Authorizenet Transaction Mode','MODULE_PAYMENT_AUTHORIZENET_TESTMODE','Test','Transaction mode used for processing orders','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','tep_cfg_select_option(array(\'Test\', \'Production\'), ',0),(1719,'Authorizenet Transaction Key','MODULE_PAYMENT_AUTHORIZENET_TXNKEY','Test','Transaction Key used for encrypting TP data','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','',0),(1720,'Authorizenet - Payment Zone','MODULE_PAYMENT_AUTHORIZENET_ZONE','0','Authorizenet - If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:51:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1721,'CC Split Credit Card E-Mail Address','MODULE_PAYMENT_CC_EMAIL','','If an e-mail address is entered, the middle digits of the credit card number will be sent to the e-mail address (the outside digits are stored in the database with the middle digits censored)','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:49:38','','',0),(1722,'CC Set Order Status','MODULE_PAYMENT_CC_ORDER_STATUS_ID','0','Set the status of CC orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:49:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1723,'CC Sort order of display.','MODULE_PAYMENT_CC_SORT_ORDER','60','Sort order of CC display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:49:38','','',0),(1724,'CC Enable Credit Card Module','MODULE_PAYMENT_CC_STATUS','True','Do you want to accept credit card payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:31','2016-04-11 15:49:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1725,'CC Payment Zone','MODULE_PAYMENT_CC_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:49:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1726,'COD Set Order Status','MODULE_PAYMENT_COD_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 11:58:28','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1727,'COD Sort order of display.','MODULE_PAYMENT_COD_SORT_ORDER','30','Sort order of COD display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:45:21','2016-11-16 11:58:28','','',0),(1728,'COD Enable Cash On Delivery Module','MODULE_PAYMENT_COD_STATUS','False','Do you want to accept Cash On Delevery payments?','BOX_CONFIGURATION_MODULE',1,'2017-08-03 11:32:27','2016-11-16 11:58:28','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1729,'COD Payment Zone','MODULE_PAYMENT_COD_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-11-16 11:58:28','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1730,'EFSnet Transaction Method','MODULE_PAYMENT_EFSNET_METHOD','CreditCardCharge','Transaction method used for processing orders','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','','tep_cfg_select_option(array(\'CreditCardCharge\',\'CreditCardAuthorize\'), ',0),(1731,'EFSnet Set Order Status','MODULE_PAYMENT_EFSNET_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1732,'EFSnet Sort order of display.','MODULE_PAYMENT_EFSNET_SORT_ORDER','90','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:57:06','','',0),(1733,'Enable EFSnet Module','MODULE_PAYMENT_EFSNET_STATUS','False','Do you want to accept EFSNet payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:34','2016-04-11 15:57:06','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1734,'EFSnet Login Username','MODULE_PAYMENT_EFSNET_STOREID','testing','The StoreID used for the EFSNet service','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','','',0),(1735,'EFSnet Transaction Key','MODULE_PAYMENT_EFSNET_STOREKEY','Test','Store Key used for encrypting data','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','','',0),(1736,'EFSnet Transaction Mode','MODULE_PAYMENT_EFSNET_TESTMODE','Test','Transaction mode used for processing orders','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','','tep_cfg_select_option(array(\'Test\', \'Production\'), ',0),(1737,'EFSnet Payment Zone','MODULE_PAYMENT_EFSNET_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:57:06','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1738,'Free Charge Set Order Status','MODULE_PAYMENT_FREECHARGER_ORDER_STATUS_ID','3','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:50:23','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1739,'Free Charge Sort order of display.','MODULE_PAYMENT_FREECHARGER_SORT_ORDER','70','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:50:23','','',0),(1740,'Enable Free Charge Module','MODULE_PAYMENT_FREECHARGER_STATUS','False','Do you want to accept Free Charge payments?','BOX_CONFIGURATION_MODULE',1,'2016-04-12 14:50:32','2016-04-11 15:50:23','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1741,'Free Charge Payment Zone','MODULE_PAYMENT_FREECHARGER_ZONE','4','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:50:23','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1742,'GeoTrust Merchant ID','MODULE_PAYMENT_GEOTRUST_MERCHANT_ID','serial #','Merchant Serial # to use for the GEOTRUST QuickPayments service','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-02-05 17:19:45','','',0),(1743,'GeoTrust Set Order Status','MODULE_PAYMENT_GEOTRUST_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-02-05 17:19:45','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1744,'GeoTrust Sort order of display.','MODULE_PAYMENT_GEOTRUST_SORT_ORDER','40','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-02-05 17:19:45','','',0),(1745,'Enable GeoTrust QuickPayments Module','MODULE_PAYMENT_GEOTRUST_STATUS','False','Do you want to accept GeoTrust QuickPayments?','BOX_CONFIGURATION_MODULE',1,'2016-04-12 14:50:29','2016-02-05 17:19:45','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1746,'GeoTrust Payment Zone','MODULE_PAYMENT_GEOTRUST_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-02-05 17:19:45','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1747,'Installed Modules','MODULE_PAYMENT_INSTALLED','offline.php;cod.php;klarna_checkout.php;recurly.php;paypalipn.php;multisafepay.php;sage_pay_server.php;rbsworldpay_hosted.php;paypal_express.php','List of payment module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: cc.php;cod.php;paypal.php)','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:47:39','2003-07-17 10:29:22','','',0),(1748,'Order Status','MODULE_PAYMENT_INVOICE_ORDER_STATUS_ID','1','Festlegung des Status für Bestellungen, welche mit dieser Zahlungsweise durchgeführt werden.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:46:07','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1749,'Reihenfolge der Anzeige','MODULE_PAYMENT_INVOICE_SORT_ORDER','50','Niedrigste wird zuerst angezeigt.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:46:07','','',0),(1750,'Rechnung','MODULE_PAYMENT_INVOICE_STATUS','False','Wollen Sie Zahlungen per Rechnung anbieten?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:30','2016-04-11 15:46:07','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1751,'Zone für diese Zahlungsweise','MODULE_PAYMENT_INVOICE_ZONE','3','Wenn Sie eine Zone auswählen, wird diese Zahlungsweise nur in dieser Zone angeboten.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:46:07','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1752,'Conditions','MODULE_PAYMENT_KLARNA_CHECKOUT_CONDITIONS','https://www.trueloaded.co.uk/privacy-policy','URL with condition details','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-06-02 15:09:37','','',0),(1753,'Merchant ID','MODULE_PAYMENT_KLARNA_CHECKOUT_EID','9708','Merchant ID (estore id) to use for the Klarna service (provided by Klarna)','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-06-02 15:09:37','','',0),(1754,'Set Order Status','MODULE_PAYMENT_KLARNA_CHECKOUT_ORDER_STATUS_ID','100006','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-06-02 15:09:37','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1755,'Shared secret','MODULE_PAYMENT_KLARNA_CHECKOUT_SECRET','wUqehA5niTIV2PO','Shared secret to use with the Klarna service (provided by Klarna).','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-06-02 15:09:37','','',0),(1756,'Shipping Method','MODULE_PAYMENT_KLARNA_CHECKOUT_SHIPPING_METHOD','0','Set the default shipping method to be used','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-06-02 15:09:37','tep_get_shipping_module_name','tep_cfg_pull_down_shipping_modules(',0),(1757,'Enable Klarna Module','MODULE_PAYMENT_KLARNA_CHECKOUT_STATUS','False','Do you want to accept Klarna payments?','BOX_CONFIGURATION_MODULE',0,'2017-06-05 12:00:42','2017-06-02 15:09:37','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1758,'Test Mode','MODULE_PAYMENT_KLARNA_CHECKOUT_TEST_MODE','True','Do you want to activate the Testmode?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-06-02 15:09:37','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1759,'Money Order Set Order Status','MODULE_PAYMENT_MONEYORDER_ORDER_STATUS_ID','1','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:48:09','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1760,'Money Order Make Payable to:','MODULE_PAYMENT_MONEYORDER_PAYTO','','Who should payments be made payable to?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-04-11 15:48:09','','',0),(1761,'Money Order Sort order of display.','MODULE_PAYMENT_MONEYORDER_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:48:09','','',0),(1762,'Enable Check/Money Order Module','MODULE_PAYMENT_MONEYORDER_STATUS','True','Do you want to accept Check/Money Order payments?','BOX_CONFIGURATION_MODULE',1,'2016-04-13 17:08:47','2016-04-11 15:48:09','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1763,'Money Order Payment Zone','MODULE_PAYMENT_MONEYORDER_ZONE','4','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:48:09','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1764,'Account ID','MODULE_PAYMENT_MULTISAFEPAY_ACCOUNT_ID','90144082','Your merchant account ID','BOX_CONFIGURATION_MODULE',22,'0000-00-00 00:00:00','2016-11-16 14:11:38','','',0),(1765,'Type account','MODULE_PAYMENT_MULTISAFEPAY_API_SERVER','Test account','<a href=\'http://www.multisafepay.com/nl/klantenservice-zakelijk/open-een-testaccount.html\' target=\'_blank\' style=\'text-decoration: underline; font-weight: bold; color:#696916; \'>Sign up for a free test account!</a>','BOX_CONFIGURATION_MODULE',21,'0000-00-00 00:00:00','2016-11-16 14:11:38','','tep_cfg_select_option(array(\'Live account\', \'Test account\'), ',0),(1766,'Auto Redirect','MODULE_PAYMENT_MULTISAFEPAY_AUTO_REDIRECT','True','Enable auto redirect after payment','BOX_CONFIGURATION_MODULE',20,'0000-00-00 00:00:00','2016-11-16 14:11:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1767,'Set Completed Order Status','MODULE_PAYMENT_MULTISAFEPAY_ORDER_STATUS_ID_COMPLETED','1','Completed successfully','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:11:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1768,'Set Declined Order Status','MODULE_PAYMENT_MULTISAFEPAY_ORDER_STATUS_ID_DECLINED','5','Declined (e.g. fraud, not enough balance)','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:11:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1769,'Set Expired Order Status','MODULE_PAYMENT_MULTISAFEPAY_ORDER_STATUS_ID_EXPIRED','5','Expired','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:11:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1770,'Set Initialized Order Status','MODULE_PAYMENT_MULTISAFEPAY_ORDER_STATUS_ID_INITIALIZED','1','In progress','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:11:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1771,'Set Partial refunded Order Status','MODULE_PAYMENT_MULTISAFEPAY_ORDER_STATUS_ID_PARTIAL_REFUNDED','1','Partial Refunded','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:11:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1772,'Set Refunded Order Status','MODULE_PAYMENT_MULTISAFEPAY_ORDER_STATUS_ID_REFUNDED','5','refunded','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:11:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1773,'Set Reserved Order Status','MODULE_PAYMENT_MULTISAFEPAY_ORDER_STATUS_ID_RESERVED','1','Reserved','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:11:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1774,'Set Reversed Order Status','MODULE_PAYMENT_MULTISAFEPAY_ORDER_STATUS_ID_REVERSED','1','Undone','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:11:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1775,'Set Uncleared Order Status','MODULE_PAYMENT_MULTISAFEPAY_ORDER_STATUS_ID_UNCLEARED','1','Not yet cleared','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:11:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1776,'Set Voided Order Status','MODULE_PAYMENT_MULTISAFEPAY_ORDER_STATUS_ID_VOID','5','Cancelled','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:11:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1777,'Site ID','MODULE_PAYMENT_MULTISAFEPAY_SITE_ID','11484','ID of this site','BOX_CONFIGURATION_MODULE',23,'0000-00-00 00:00:00','2016-11-16 14:11:38','','',0),(1778,'Site Code','MODULE_PAYMENT_MULTISAFEPAY_SITE_SECURE_CODE','162653','Site code for this site','BOX_CONFIGURATION_MODULE',24,'0000-00-00 00:00:00','2016-11-16 14:11:38','','',0),(1779,'Sort order of display.','MODULE_PAYMENT_MULTISAFEPAY_SORT_ORDER','70','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:45:21','2016-11-16 14:11:38','','',0),(1780,'MultiSafepay enabled','MODULE_PAYMENT_MULTISAFEPAY_STATUS','False','Enable MultiSafepay payments for this website','BOX_CONFIGURATION_MODULE',20,'2017-05-31 11:14:50','2016-11-16 14:11:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1781,'Enable gateway titles in checkout','MODULE_PAYMENT_MULTISAFEPAY_TITLES_ENABLER','True','Enable the gateway title in checkout','BOX_CONFIGURATION_MODULE',20,'0000-00-00 00:00:00','2016-11-16 14:11:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1782,'Enable icons in gateway titles. If disabled it will overrule opt','MODULE_PAYMENT_MULTISAFEPAY_TITLES_ICON_DISABLED','True','Enable the icon in the checkout title for the gateway','BOX_CONFIGURATION_MODULE',20,'0000-00-00 00:00:00','2016-11-16 14:11:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1783,'Payment Zone','MODULE_PAYMENT_MULTISAFEPAY_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',25,'0000-00-00 00:00:00','2016-11-16 14:11:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1784,'OFFLINE Order Status','MODULE_PAYMENT_OFFLINE_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-03 11:25:11','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1785,'OFFLINE Sort order of display.','MODULE_PAYMENT_OFFLINE_SORT_ORDER','10','Sort order of OFFLINE display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:45:21','2017-04-03 11:25:11','','',0),(1786,'OFFLINE Enable Module','MODULE_PAYMENT_OFFLINE_STATUS','True','Do you want to accept OFFLINE payments?','BOX_CONFIGURATION_MODULE',1,'2017-08-11 14:46:23','2017-04-03 11:25:11','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1787,'OFFLINE Payment Zone','MODULE_PAYMENT_OFFLINE_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2017-04-03 11:25:11','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1820,'Callback Password','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_CALLBACK_PASSWORD','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','',0),(1821,'Debug E-Mail Address','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_DEBUG_EMAIL','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','',0),(1822,'Installation ID','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_INSTALLATION_ID','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','',0),(1823,'MD5 Password','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_MD5_PASSWORD','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','',0),(1824,'Set Order Status','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_ORDER_STATUS_ID','100006','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1825,'Set Preparing Order Status','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_PREPARE_ORDER_STATUS_ID','1','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1826,'Sort order of display.','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_SORT_ORDER','90','','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:45:21','2017-04-08 14:31:29','','',0),(1827,'Enable WorldPay Hosted Payment Pages','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_STATUS','False','','BOX_CONFIGURATION_MODULE',0,'2017-05-29 13:43:09','2017-04-08 14:31:29','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1828,'Test Mode','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TESTMODE','True','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1829,'Transactions Order Status Level','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TRANSACTIONS_ORDER_STATUS_ID','1','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1830,'Transaction Method','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TRANSACTION_METHOD','Capture','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','tep_cfg_select_option(array(\'Pre-Authorization\', \'Capture\'), ',0),(1831,'Payment Zone','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_ZONE','0','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1832,'API key','MODULE_PAYMENT_RECURLY_SERVER_KEY','b6374349fbd84182ac1730a872d01734','Your private API key','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-03-10 10:41:35','','',0),(1833,'Set Order Status','MODULE_PAYMENT_RECURLY_SERVER_ORDER_STATUS_ID','2','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-03-10 10:41:35','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1834,'Sort order of display.','MODULE_PAYMENT_RECURLY_SERVER_SORT_ORDER','50','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:45:21','2017-03-10 10:41:35','','',0),(1835,'Enable Recurly Module','MODULE_PAYMENT_RECURLY_SERVER_STATUS','False','Do you want to accept Recurly payments?','BOX_CONFIGURATION_MODULE',0,'2017-06-15 11:27:56','2017-03-10 10:41:35','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1836,'Your subdomain','MODULE_PAYMENT_RECURLY_SERVER_SUBDOMAIN','holbi','https://<your-subdomain>.recurly.com','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-03-10 10:41:35','','',0),(1837,'Payment Zone','MODULE_PAYMENT_RECURLY_SERVER_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2017-03-10 10:41:35','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1838,'cURL Program Location','MODULE_PAYMENT_SAGE_PAY_SERVER_CURL','/usr/bin/curl','The location to the cURL program application.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:11:50','','',0),(1839,'Set Order Status','MODULE_PAYMENT_SAGE_PAY_SERVER_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:11:50','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(1840,'Profile Payment Page','MODULE_PAYMENT_SAGE_PAY_SERVER_PROFILE_PAGE','Normal','Profile page to use for the payment page.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:11:50','','tep_cfg_select_option(array(\'Normal\', \'Low\'), ',0),(1841,'Sort order of display.','MODULE_PAYMENT_SAGE_PAY_SERVER_SORT_ORDER','80','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:45:21','2016-11-24 17:11:50','','',0),(1842,'Enable Sage Pay Server Module','MODULE_PAYMENT_SAGE_PAY_SERVER_STATUS','False','Do you want to accept Sage Pay Server payments?','BOX_CONFIGURATION_MODULE',0,'2017-05-29 13:42:59','2016-11-24 17:11:50','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1843,'Transaction Method','MODULE_PAYMENT_SAGE_PAY_SERVER_TRANSACTION_METHOD','Authenticate','The processing method to use for each transaction.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:11:50','','tep_cfg_select_option(array(\'Authenticate\', \'Deferred\', \'Payment\'), ',0),(1844,'Transaction Server','MODULE_PAYMENT_SAGE_PAY_SERVER_TRANSACTION_SERVER','Test','Perform transactions on the production server or on the testing server.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:11:50','','tep_cfg_select_option(array(\'Live\', \'Test\', \'Simulator\'), ',0),(1845,'Vendor Login Name','MODULE_PAYMENT_SAGE_PAY_SERVER_VENDOR_LOGIN_NAME','airplanflighteq','The vendor login name to connect to the gateway with.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:11:50','','',0),(1846,'Payment Zone','MODULE_PAYMENT_SAGE_PAY_SERVER_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-11-24 17:11:50','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1847,'Flat Shipping Cost','MODULE_SHIPPING_FLAT_COST','0.1','The shipping cost for all orders using this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:03:53','','',0),(1848,'Flat Sort Order','MODULE_SHIPPING_FLAT_SORT_ORDER','10','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 14:03:53','','',0),(1849,'Enable Flat Shipping','MODULE_SHIPPING_FLAT_STATUS','True','Do you want to offer flat rate shipping?','BOX_CONFIGURATION_MODULE',0,'2017-03-10 12:13:22','2016-11-16 14:03:53','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1850,'Flat Tax Class','MODULE_SHIPPING_FLAT_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:03:53','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1851,'Flat Shipping Zone','MODULE_SHIPPING_FLAT_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:03:53','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1852,'Free Shipping Cost','MODULE_SHIPPING_FREESHIPPER_COST','0.00','What is the Shipping cost? The Handling fee will also be added.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2016-11-16 13:27:21','','',0),(1853,'FREESHIPPER Sort Order','MODULE_SHIPPING_FREESHIPPER_SORT_ORDER','30','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:27:21','','',0),(1854,'Enable Free Shipping','MODULE_SHIPPING_FREESHIPPER_STATUS','False','Do you want to offer Free shipping?','BOX_CONFIGURATION_MODULE',5,'2017-07-19 15:13:02','2016-11-16 13:27:21','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1855,'FREESHIPPER Tax Class','MODULE_SHIPPING_FREESHIPPER_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:27:21','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1856,'FREESHIPPER Shipping Zone','MODULE_SHIPPING_FREESHIPPER_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:27:21','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1857,'Installed Modules','MODULE_SHIPPING_INSTALLED','flat.php;ups.php;freeshipper.php;zonetable.php;item.php;percent.php;table.php;usps.php;zones.php;zonesperitem.php','List of shipping module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ups.php;flat.php;item.php)','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2003-07-17 10:29:22','','',0),(1858,'Item Shipping Shipping Cost','MODULE_SHIPPING_ITEM_COST','0','The shipping cost will be multiplied by the number of items in an order that uses this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:59:56','','',0),(1859,'Item Shipping Handling Fee','MODULE_SHIPPING_ITEM_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:59:56','','',0),(1860,'Item Shipping Sort Order','MODULE_SHIPPING_ITEM_SORT_ORDER','50','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:59:56','','',0),(1861,'Enable Item Shipping','MODULE_SHIPPING_ITEM_STATUS','False','Do you want to offer per item rate shipping?','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:43','2016-11-16 13:59:56','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1862,'Item Shipping Tax Class','MODULE_SHIPPING_ITEM_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:59:56','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1863,'Item Shipping Shipping Zone','MODULE_SHIPPING_ITEM_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:59:56','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1864,'Percentage A Flat Rate of','MODULE_SHIPPING_PERCENT_FLAT_USE','6.50','A Flat Rate used for all orders.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','','',0),(1865,'Percentage A Flat Rate for orders under','MODULE_SHIPPING_PERCENT_LESS_THEN','34.75','A Flat Rate for all orders that are under the amount shown.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','','',0),(1866,'Percentage Rate','MODULE_SHIPPING_PERCENT_RATE','.18','The Percentage Rate all .01 to .99 for all orders using this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','','',0),(1867,'Percentage Sort Order','MODULE_SHIPPING_PERCENT_SORT_ORDER','60','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:52:35','','',0),(1868,'Enable Percent Shipping','MODULE_SHIPPING_PERCENT_STATUS','True','Do you want to offer percent rate shipping?','BOX_CONFIGURATION_MODULE',0,'2017-08-15 10:28:36','2016-11-16 13:52:35','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1869,'Percentage Tax Class','MODULE_SHIPPING_PERCENT_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1870,'Percentage Shipping Zone','MODULE_SHIPPING_PERCENT_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1871,'Table Method Shipping Table','MODULE_SHIPPING_TABLE_COST','25:8.50,50:5.50,10000:0.00','The shipping cost is based on the total cost or weight of items. Example: 25:8.50,50:5.50,etc.. Up to 25 charge 8.50, from there to 50 charge 5.50, etc','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','','',0),(1872,'Table Method Handling Fee','MODULE_SHIPPING_TABLE_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','','',0),(1873,'Table Method','MODULE_SHIPPING_TABLE_MODE','weight','The shipping cost is based on the order total or the total weight of the items ordered.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','','tep_cfg_select_option(array(\'weight\', \'price\'), ',0),(1874,'Table Method Sort Order','MODULE_SHIPPING_TABLE_SORT_ORDER','70','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-24 17:14:14','','',0),(1875,'Enable Table Method','MODULE_SHIPPING_TABLE_STATUS','False','Do you want to offer table rate shipping?','BOX_CONFIGURATION_MODULE',0,'2017-05-29 13:48:08','2016-11-24 17:14:14','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1876,'Table Method Tax Class','MODULE_SHIPPING_TABLE_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1877,'Table Method Shipping Zone','MODULE_SHIPPING_TABLE_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1878,'UPS Handling Fee','MODULE_SHIPPING_UPS_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','','',0),(1879,'UPS Packaging?','MODULE_SHIPPING_UPS_PACKAGE','CP','CP - Your Packaging, ULE - UPS Letter, UT - UPS Tube, UBE - UPS Express Box','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','','',0),(1880,'UPS Pickup Method','MODULE_SHIPPING_UPS_PICKUP','CC','How do you give packages to UPS? CC - Customer Counter, RDP - Daily Pickup, OTP - One Time Pickup, LC - Letter Center, OCA - On Call Air','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','','',0),(1881,'UPS Residential Delivery?','MODULE_SHIPPING_UPS_RES','RES','Quote for Residential (RES) or Commercial Delivery (COM)','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','','',0),(1882,'UPS Sort order of display.','MODULE_SHIPPING_UPS_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:01:59','','',0),(1883,'Enable UPS Shipping','MODULE_SHIPPING_UPS_STATUS','False','Do you want to offer UPS shipping?','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:46:54','2016-11-16 13:01:59','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1884,'UPS Tax Class','MODULE_SHIPPING_UPS_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1885,'UPS Shipping Methods','MODULE_SHIPPING_UPS_TYPES','1DM, 1DML, 1DA, 1DAL, 1DAPI, 1DP, 1DPL, 2DM, 2DML, 2DA, 2DAL, 3DS, GND, STD, XPR, XPRL, XDM, XDML, XPD','Select the UPS services to be offered.','BOX_CONFIGURATION_MODULE',13,'0000-00-00 00:00:00','2016-11-16 13:01:59','','tep_cfg_select_multioption(array(\'1DM\',\'1DML\', \'1DA\', \'1DAL\', \'1DAPI\', \'1DP\', \'1DPL\', \'2DM\', \'2DML\', \'2DA\', \'2DAL\', \'3DS\',\'GND\', \'STD\', \'XPR\', \'XPRL\', \'XDM\', \'XDML\', \'XPD\'), ',0),(1886,'UPS Shipping Zone','MODULE_SHIPPING_UPS_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1887,'Handling Fee','MODULE_SHIPPING_USPS_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','','',0),(1888,'USPS Options','MODULE_SHIPPING_USPS_OPTIONS','Display weight, Display transit time','Select from the following the USPS options.','BOX_CONFIGURATION_MODULE',16,'0000-00-00 00:00:00','2016-11-16 13:31:02','','tep_cfg_select_multioption(array(\'Display weight\', \'Display transit time\'), ',0),(1889,'Enter the USPS Password','MODULE_SHIPPING_USPS_PASSWORD','NONE','See USERID, above.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','','',0),(1890,'Which server to use','MODULE_SHIPPING_USPS_SERVER','production','An account at USPS is needed to use the Production server','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','','tep_cfg_select_option(array(\'test\', \'production\'), ',0),(1891,'Sort Order','MODULE_SHIPPING_USPS_SORT_ORDER','80','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2016-11-16 13:31:02','2016-11-16 13:31:02','','',0),(1892,'Enable USPS Shipping','MODULE_SHIPPING_USPS_STATUS','False','Do you want to offer USPS shipping?','BOX_CONFIGURATION_MODULE',0,'2017-05-29 13:48:30','2016-11-16 13:31:02','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1893,'Tax Class','MODULE_SHIPPING_USPS_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1894,'Domestic Shipping Methods','MODULE_SHIPPING_USPS_TYPES','Express, Priority, First Class, Parcel','Select the domestic services to be offered:','BOX_CONFIGURATION_MODULE',14,'0000-00-00 00:00:00','2016-11-16 13:31:02','','tep_cfg_select_multioption(array(\'Express\', \'Priority\', \'First Class\', \'Parcel\'), ',0),(1895,'Int\'l Shipping Methods','MODULE_SHIPPING_USPS_TYPES_INTL','GXG Document, GXG Non-Document, Express, Priority Lg, Priority Sm, Priority Var, Airmail Letter, Airmail Parcel, Surface Letter, Surface Post','Select the international services to be offered:','BOX_CONFIGURATION_MODULE',15,'0000-00-00 00:00:00','2016-11-16 13:31:02','','tep_cfg_select_multioption(array(\'GXG Document\', \'GXG Non-Document\', \'Express\', \'Priority Lg\', \'Priority Sm\', \'Priority Var\', \'Airmail Letter\', \'Airmail Parcel\', \'Surface Letter\', \'Surface Post\'), ',0),(1896,'Enter the USPS User ID','MODULE_SHIPPING_USPS_USERID','NONE','Enter the USPS USERID assigned to you.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','','',0),(1897,'Shipping Zone','MODULE_SHIPPING_USPS_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(1898,'Zone 1 Geo Zone','MODULE_SHIPPING_ZONESPERITEM_GEO_ZONE_1','0','Select Geo Zone of this Zone 1.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',0),(1899,'Number of Zones','MODULE_SHIPPING_ZONESPERITEM_NUMBER_OF_ZONES','1','Number of zones needed.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:38:29','','',0),(1900,'Zone 1 Premium Additional Item Charge','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_ADDITIONAL_ITEM_CHARGE_1','0.00','Premium Additional Item Charge for this shipping zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',0),(1901,'Zone 1 Premium Free Delivery Amount','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_FREE_DELIVERY_AMOUNT_1','20.00','Amount of subtotal for free premium delivery for this shipping zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',0),(1902,'Zone 1 Premium Initial Item Charge','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_INITIAL_ITEM_CHARGE_1','4.50','Premium Initial Item Charge for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',0),(1903,'Zones Per Item Sort Order','MODULE_SHIPPING_ZONESPERITEM_SORT_ORDER','100','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-12-21 15:38:29','','',0),(1904,'Zone 1 Standard Additional Item Charge','MODULE_SHIPPING_ZONESPERITEM_STANDARD_ADDITIONAL_ITEM_CHARGE_1','0.50','Standard Additional Item Charge for this shipping zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',0),(1905,'Zone 1 Standard Free Delivery Amount','MODULE_SHIPPING_ZONESPERITEM_STANDARD_FREE_DELIVERY_AMOUNT_1','20.00','Amount of subtotal for free standard delivery for this shipping zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',0),(1906,'Zone 1 Standard Initial Item Charge','MODULE_SHIPPING_ZONESPERITEM_STANDARD_INITIAL_ITEM_CHARGE_1','2.50','Standard Initial Item Charge for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',0),(1907,'Enable Zones Per Item Method','MODULE_SHIPPING_ZONESPERITEM_STATUS','False','Do you want to offer zone rate shipping?','BOX_CONFIGURATION_MODULE',0,'2017-05-29 13:48:32','2016-12-21 15:38:29','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1908,'Zones Per Item Tax Class','MODULE_SHIPPING_ZONESPERITEM_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:38:29','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1909,'Zone 1 Shipping Table','MODULE_SHIPPING_ZONES_COST_1','3:8.50,7:10.50,99:20.00','Shipping rates to Zone 1 destinations based on a group of maximum order weights. Example: 3:8.50,7:10.50,... Weights less than or equal to 3 would cost 8.50 for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:47:33','','',0),(1910,'Zone 1 Countries','MODULE_SHIPPING_ZONES_COUNTRIES_1','US,CA','Comma separated list of two character ISO country codes that are part of Zone 1.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:47:33','','',0),(1911,'Zone 1 Handling Fee','MODULE_SHIPPING_ZONES_HANDLING_1','0','Handling Fee for this shipping zone','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:47:33','','',0),(1912,'Zones Sort Order','MODULE_SHIPPING_ZONES_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:47:33','','',0),(1913,'Zones Enable Zones Method','MODULE_SHIPPING_ZONES_STATUS','False','Do you want to offer zone rate shipping?','BOX_CONFIGURATION_MODULE',0,'2017-05-29 13:48:31','2016-11-16 13:47:33','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1914,'Zones Tax Class','MODULE_SHIPPING_ZONES_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:47:33','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(1915,'Handling Fee','MODULE_SHIPPING_ZONE_TABLE_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-01-05 14:27:17','','',0),(1916,'Sort Order','MODULE_SHIPPING_ZONE_TABLE_SORT_ORDER','40','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2017-01-05 14:27:17','','',0),(1917,'Enable Table Method','MODULE_SHIPPING_ZONE_TABLE_STATUS','True','Do you want to offer Zone Table rate shipping?','BOX_CONFIGURATION_MODULE',0,'2017-08-15 10:34:01','2017-01-05 14:27:17','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(1918,'Tax Class','MODULE_SHIPPING_ZONE_TABLE_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-01-05 14:27:17','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(2556,'Your Fedex Account Number','MODULE_SHIPPING_FEDEX1_ACCOUNT','103645646','Enter the fedex Account Number assigned to you, required','BOX_CONFIGURATION_MODULE',11,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2557,'First line of street address','MODULE_SHIPPING_FEDEX1_ADDRESS_1','None','Enter the first line of your ship from street address, required','BOX_CONFIGURATION_MODULE',13,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2558,'Second line of street address','MODULE_SHIPPING_FEDEX1_ADDRESS_2','None','Enter the second line of your ship from street address, leave set to NONE if you do not need to specify a second line','BOX_CONFIGURATION_MODULE',14,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2559,'City name','MODULE_SHIPPING_FEDEX1_CITY','None','Enter the city name for the ship from street address, required','BOX_CONFIGURATION_MODULE',15,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2560,'cURL Path','MODULE_SHIPPING_FEDEX1_CURL','NONE','Enter the path to the cURL program, normally, leave this set to NONE to execute cURL using PHP','BOX_CONFIGURATION_MODULE',12,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2561,'Debug Mode','MODULE_SHIPPING_FEDEX1_DEBUG','False','Turn on Debug','BOX_CONFIGURATION_MODULE',19,'0000-00-00 00:00:00','2017-08-22 16:54:19','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(2562,'Drop off type','MODULE_SHIPPING_FEDEX1_DROPOFF','1','Dropoff type (1 = Regular pickup, 2 = request courier, 3 = drop box, 4 = drop at BSC, 5 = drop at station)?','BOX_CONFIGURATION_MODULE',20,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2563,'Enable Envelope Rates?','MODULE_SHIPPING_FEDEX1_ENVELOPE','False','Do you want to offer Fedex Envelope rates? All items under 1/2 LB (.23KG) will quote using the envelope rate if True.','BOX_CONFIGURATION_MODULE',10,'0000-00-00 00:00:00','2017-08-22 16:54:19','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(2564,'Insurance?','MODULE_SHIPPING_FEDEX1_INSURE','None','Insure packages over what dollar amount?','BOX_CONFIGURATION_MODULE',22,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2565,'Your Fedex Meter ID','MODULE_SHIPPING_FEDEX1_METER','None','Enter the Fedex MeterID assigned to you, set to NONE to obtain a new meter number','BOX_CONFIGURATION_MODULE',12,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2566,'Phone number','MODULE_SHIPPING_FEDEX1_PHONE','None','Enter a contact phone number for your company, required','BOX_CONFIGURATION_MODULE',18,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2567,'Postal code','MODULE_SHIPPING_FEDEX1_POSTAL','None','Enter the postal code for the ship from street address, required','BOX_CONFIGURATION_MODULE',17,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2568,'Residential surcharge?','MODULE_SHIPPING_FEDEX1_RESIDENTIAL','0','Residential Surcharge (in addition to other surcharge) for Express packages within US, or ground packages within Canada?','BOX_CONFIGURATION_MODULE',21,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2569,'Which server to use','MODULE_SHIPPING_FEDEX1_SERVER','production','You must have an account with Fedex','BOX_CONFIGURATION_MODULE',19,'0000-00-00 00:00:00','2017-08-22 16:54:19','','tep_cfg_select_option(array(\'test\', \'production\'), ',0),(2570,'Sort Order','MODULE_SHIPPING_FEDEX1_SORT_ORDER','120','Sort order of display.','BOX_CONFIGURATION_MODULE',24,'2017-08-22 16:54:19','2017-08-22 16:54:19','','',0),(2571,'State or Province name','MODULE_SHIPPING_FEDEX1_STATE','None','Enter the 2 letter state or province name for the ship from street address, required for Canada and US','BOX_CONFIGURATION_MODULE',16,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2572,'Enable Fedex Shipping','MODULE_SHIPPING_FEDEX1_STATUS','False','Do you want to offer Fedex shipping?','BOX_CONFIGURATION_MODULE',10,'2017-09-08 10:00:41','2017-08-22 16:54:19','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(2573,'Fedex surcharge?','MODULE_SHIPPING_FEDEX1_SURCHARGE','0','Surcharge amount to add to shipping charge?','BOX_CONFIGURATION_MODULE',21,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2574,'Tax Class','MODULE_SHIPPING_FEDEX1_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',23,'0000-00-00 00:00:00','2017-08-22 16:54:19','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',0),(2575,'Timeout in Seconds','MODULE_SHIPPING_FEDEX1_TIMEOUT','None','Enter the maximum time in seconds you would wait for a rate request from Fedex? Leave NONE for default timeout.','BOX_CONFIGURATION_MODULE',22,'0000-00-00 00:00:00','2017-08-22 16:54:19','','',0),(2576,'Display Transit Times','MODULE_SHIPPING_FEDEX1_TRANSIT','True','Do you want to show transit times for ground or home delivery rates?','BOX_CONFIGURATION_MODULE',10,'0000-00-00 00:00:00','2017-08-22 16:54:19','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(2577,'Weight Units','MODULE_SHIPPING_FEDEX1_WEIGHT','LBS','Weight Units:','BOX_CONFIGURATION_MODULE',19,'0000-00-00 00:00:00','2017-08-22 16:54:19','','tep_cfg_select_option(array(\'LBS\', \'KGS\'), ',0),(2578,'Sort rates: ','MODULE_SHIPPING_FEDEX1_WEIGHT_SORT','High to Low','Sort rates top to bottom: ','BOX_CONFIGURATION_MODULE',19,'0000-00-00 00:00:00','2017-08-22 16:54:19','','tep_cfg_select_option(array(\'High to Low\', \'Low to High\'), ',0),(2859,'Display Bonus Points','MODULE_ORDER_TOTAL_BONUS_POINTS_STATUS','true','Do you want this module to display?','BOX_CONFIGURATION_MODULE',1,'2017-10-11 16:41:24','2017-10-11 15:53:24',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(2860,'Order Status for Points applying','MODULE_ORDER_TOTAL_BONUS_POINTS_ORDER_STATUS_ID','3','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-10-11 15:53:24','\\common\\helpers\\Order::get_status_name','tep_cfg_select_multioption_order_statuses(',1),(2861,'Sort Order','MODULE_ORDER_TOTAL_BONUS_POINTS_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-10-11 15:53:24',NULL,NULL,1),(2862,'Set status for covered order','MODULE_ORDER_TOTAL_BONUS_POINTS_ORDER_STATUS_ID_COVERS','2','Covered order','BOX_CONFIGURATION_MODULE',0,NULL,'2017-10-11 15:53:24','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(2863,'Order Status for Points applying','MODULE_ORDER_TOTAL_BONUS_POINTS_ORDER_STATUS_ID','3','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-10-11 15:53:24','\\common\\helpers\\Order::get_status_name','tep_cfg_select_multioption_order_statuses(',0),(2864,'Set status for covered order','MODULE_ORDER_TOTAL_BONUS_POINTS_ORDER_STATUS_ID_COVERS','2','Covered order','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-10-11 15:53:24','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(2865,'Sort Order','MODULE_ORDER_TOTAL_BONUS_POINTS_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-10-11 15:53:24','','',0),(2866,'Display Bonus Points','MODULE_ORDER_TOTAL_BONUS_POINTS_STATUS','true','Do you want this module to display?','BOX_CONFIGURATION_MODULE',1,'2017-10-11 16:41:24','2017-10-11 15:53:24','','tep_cfg_select_option(array(\'true\', \'false\'), ',0),(2971,'COD Enable Cash On Delivery Module','MODULE_PAYMENT_COD_STATUS','True','Do you want to accept Cash On Delevery payments?','BOX_CONFIGURATION_MODULE',1,'2022-07-18 14:31:07','2018-01-11 15:06:47',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(2972,'COD Payment Zone','MODULE_PAYMENT_COD_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'2022-07-18 14:31:07','2018-01-11 15:06:47','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(2973,'COD Set Order Status','MODULE_PAYMENT_COD_ORDER_STATUS_ID','100007','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'2022-07-18 14:31:07','2018-01-11 15:06:47','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(2974,'COD Sort order of display.','MODULE_PAYMENT_COD_SORT_ORDER','40','Sort order of COD display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:16:47','2018-01-11 15:06:47',NULL,NULL,1),(3008,'CASH Enable Cash Payment Module','MODULE_PAYMENT_CASH_STATUS','False','Do you want to accept Cash Payment?','BOX_CONFIGURATION_MODULE',1,'2018-03-22 13:24:29','2018-01-17 11:52:46',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(3009,'CASH Payment Zone','MODULE_PAYMENT_CASH_ZONED','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2018-01-17 11:52:46','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(3010,'CASH Set Order Status','MODULE_PAYMENT_CASH_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2018-01-17 11:52:46','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(3011,'CASH Sort order of display.','MODULE_PAYMENT_CASH_SORT_ORDER','60','Sort order of CASH display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:34:41','2018-01-17 11:52:46',NULL,NULL,1),(3035,'Installed Modules','MODULE_DROPSHIPPING_INSTALLED','','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,NULL,'2018-01-26 09:39:27',NULL,NULL,1),(3047,'Set Order Status','MODULE_PAYMENT_LIQPAY_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',4,NULL,'2018-01-26 15:33:32','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(3088,'Enable Item Shipping','MODULE_SHIPPING_NP_STATUS','False','Do you want to offer NovaPoshta shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-22 13:24:50','2018-02-16 15:24:13',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(3089,'NovaPoshta ApiKey','MODULE_SHIPPING_NP_APIKEY','dd791bafa70224a996085024e0687e8c','','BOX_CONFIGURATION_MODULE',0,NULL,'2018-02-16 15:24:13',NULL,NULL,1),(3090,'NovaPoshta Shipping Shipping Cost','MODULE_SHIPPING_NP_COST','40','','BOX_CONFIGURATION_MODULE',0,NULL,'2018-02-16 15:24:13',NULL,NULL,1),(3091,'NP Shipping Sort Order','MODULE_SHIPPING_NP_SORT_ORDER','130','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2018-02-16 15:24:13','2018-02-16 15:24:13',NULL,NULL,1),(3092,'','','','','',NULL,'2018-03-21 14:47:35','2018-03-21 14:47:35',NULL,NULL,1),(3095,'','','','','',NULL,'2018-03-21 14:47:35','2018-03-21 14:47:35',NULL,NULL,4),(3096,'','','','','',NULL,'2018-03-21 14:47:35','2018-03-21 14:47:35',NULL,NULL,5),(3097,'','','','','',NULL,'2018-03-21 14:47:35','2018-03-21 14:47:35',NULL,NULL,6),(3127,'CASH Set Order Status','MODULE_PAYMENT_CASH_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-01-17 11:52:46','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(3128,'CASH Sort order of display.','MODULE_PAYMENT_CASH_SORT_ORDER','20','Sort order of CASH display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2018-01-26 11:25:26','2018-01-17 11:52:46','','',0),(3129,'CASH Enable Cash Payment Module','MODULE_PAYMENT_CASH_STATUS','True','Do you want to accept Cash Payment?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2018-01-17 11:52:46','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(3130,'CASH Payment Zone','MODULE_PAYMENT_CASH_ZONED','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2018-01-17 11:52:46','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',0),(3131,'LIQPAY Set Order Paid Status','MODULE_PAYMENT_LIQPAY_ORDER_PAID_STATUS_ID','100006','Set the paid status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',15,'0000-00-00 00:00:00','2018-01-26 15:33:32','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(3132,'LIQPAY Set Order Processing Status','MODULE_PAYMENT_LIQPAY_ORDER_PROCESS_STATUS_ID','0','Set the process status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',14,'0000-00-00 00:00:00','2018-01-26 15:33:32','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(3133,'Set Order Status','MODULE_PAYMENT_LIQPAY_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',4,'0000-00-00 00:00:00','2018-01-26 15:33:32','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',0),(3134,'LIQPAY private key','MODULE_PAYMENT_LIQPAY_PRIVATE_KEY','3AzhW6dumTaq6HKdEbSEQ5FQmvRUbWMqiFeQgQe5','','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2018-01-26 15:33:32','','',0),(3135,'LIQPAY public key','MODULE_PAYMENT_LIQPAY_PUBLIC_KEY','i82430386736','','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2018-01-26 15:33:32','','',0),(3136,'LIQPAY Test mode','MODULE_PAYMENT_LIQPAY_SANDBOX','True','Test mode','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2018-01-26 15:33:32','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(3137,'Sort order of display.','MODULE_PAYMENT_LIQPAY_SORT_ORDER','110','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',5,'2018-01-26 15:33:32','2018-01-26 15:33:32','','',0),(3138,'LIQPAY Enable Module','MODULE_PAYMENT_LIQPAY_STATUS','True','Do you want to accept LIQPAY payments?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2018-01-26 15:33:32','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(3139,'NovaPoshta ApiKey','MODULE_SHIPPING_NP_APIKEY','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-02-16 15:24:13','','',0),(3140,'NovaPoshta Shipping Shipping Cost','MODULE_SHIPPING_NP_COST','40','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-02-16 15:24:13','','',0),(3141,'NP Shipping Sort Order','MODULE_SHIPPING_NP_SORT_ORDER','130','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2018-02-16 15:24:13','2018-02-16 15:24:13','','',0),(3142,'Enable Item Shipping','MODULE_SHIPPING_NP_STATUS','True','Do you want to offer NovaPoshta shipping?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-02-16 15:24:13','','tep_cfg_select_option(array(\'True\', \'False\'), ',0),(3219,'MAILCHIMP_STATUS','MAILCHIMP_STATUS','Disabled','','',NULL,NULL,NULL,NULL,NULL,1),(3220,'MAILCHIMP_API_KEY','MAILCHIMP_API_KEY','','','',NULL,NULL,NULL,NULL,NULL,1),(3221,'MAILCHIMP_STATUS_CUSTOMERS','MAILCHIMP_STATUS_CUSTOMERS','Disabled','','',NULL,NULL,NULL,NULL,NULL,1),(3231,'MAILCHIMP_STATUS','MAILCHIMP_STATUS','Disabled','','',NULL,NULL,NULL,NULL,NULL,6),(3232,'MAILCHIMP_API_KEY','MAILCHIMP_API_KEY','','','',NULL,NULL,NULL,NULL,NULL,6),(3233,'MAILCHIMP_STATUS_CUSTOMERS','MAILCHIMP_STATUS_CUSTOMERS','Disabled','','',NULL,NULL,NULL,NULL,NULL,6),(4437,'Enable NP Tracking','MODULE_SHIPPING_NP_TRACKING_STATUS','True','Do you want to enable NP tracking?','BOX_CONFIGURATION_MODULE',0,NULL,'2018-10-02 09:43:28',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(5313,'Display billing address','DISPLAY_BILLING_ADDRESS','True','Display billing address on checkout and user account?','BOX_CONFIGURATION_MYSTORE',0,'2019-03-26 16:54:24','2019-03-26 16:54:24',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(5607,'Number of shipping results','MODULE_ORDER_TOTAL_SHIPPING_RESULT_COUNT','','Limit results (if empty - unlimited).','BOX_CONFIGURATION_MODULE',6,NULL,'2019-03-27 14:56:48',NULL,NULL,1),(5608,'Limit shipping results sort mode','MODULE_ORDER_TOTAL_SHIPPING_LIMIT_RESULT_SORT','Cheapest first','','BOX_CONFIGURATION_MODULE',7,NULL,'2019-03-27 14:56:48',NULL,'tep_cfg_select_option(array(\'Cheapest first\', \'Modules sort order\'), ',1),(5609,'Installed Modules','MODULE_LABEL_INSTALLED','dpd.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2022-03-14 09:45:31','2019-03-27 15:11:27',NULL,NULL,1),(6200,'Skip 3D secure amount','MODULE_PAYMENT_SAGE_PAY_3DS_SKIP','','Skip 3D secure verification when paid by token on orders below','BOX_CONFIGURATION_MODULE',100,NULL,'2019-10-01 10:49:51',NULL,NULL,0),(6201,'Account login','MODULE_PAYMENT_SAGE_PAY_SERVER_ACCOUNT','','Account login to get transaction details','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-01 10:49:51',NULL,NULL,0),(6202,'Account password','MODULE_PAYMENT_SAGE_PAY_SERVER_ACCOUNT_PASSWORD','','Account password to get transaction details','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-01 10:49:51',NULL,NULL,0),(6216,'NovaPoshta ApiKey','MODULE_SHIPPING_NP_API_KEY','','','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-22 13:18:12',NULL,NULL,1),(6217,'Preferred Shipping Method','MODULE_SHIPPING_NP_PREFERRED_METHOD','WarehouseToWarehouse','Sort order of display.','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-22 13:18:12',NULL,'tep_cfg_select_option(array(\'WarehouseToWarehouse\', \'WarehouseToDoors\'), ',1),(6218,'Tracking Url','MODULE_SHIPPING_NP_TRACKING_NUMBER_URL','https://novaposhta.ua/tracking/?newtracking=1&cargo_number=','Url for tracking cargo','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-22 13:18:12',NULL,NULL,1),(6219,'If no rates found allow complete order','MODULE_SHIPPING_ZONE_ALLOW_ERROR_PASS','False','Display \"please call us for a quote\" and allow complete order.','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-22 13:18:12',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6220,'Bonus apply minimum cart','MODULE_ORDER_TOTAL_BONUS_POINTS_MINIMUM_CART','0','Subtotal for allow to apply bonus points','6',4,NULL,'2020-10-09 13:42:05',NULL,NULL,1),(6221,'Tax Class','MODULE_ORDER_TOTAL_BONUS_POINTS_TAX_CLASS','0','Use the following tax class on the payment fee.','6',7,NULL,'2020-10-09 13:42:05','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(6222,'Allow Gift Message for order','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE','False','Allow Gift Message for whole order','6',3,NULL,'2020-10-09 13:42:05',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),',1),(6223,'Gift Message price','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_COST','','Gift Message price','6',4,NULL,'2020-10-09 13:42:05',NULL,NULL,1),(6224,'Gift Message max words count','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_WORDS','','Gift Message max words count, live empty to ignore','6',5,NULL,'2020-10-09 13:42:05',NULL,NULL,1),(6225,'Gift Message max characters count','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_CHARS','','Gift Message max characters count, live empty to ignore','6',6,NULL,'2020-10-09 13:42:05',NULL,NULL,1),(6227,'Display Amount Refund','MODULE_ORDER_TOTAL_REFUND_STATUS','true','Do you want to display the Amount Refund?','6',160,NULL,'2020-10-09 13:42:16',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(6228,'Sort Order','MODULE_ORDER_TOTAL_REFUND_SORT_ORDER','160','Sort order of display.','6',160,'2020-10-09 13:42:16','2020-10-09 13:42:16',NULL,NULL,1),(6277,'User Groups status','UserGroups_EXTENSION_STATUS','True','','6',0,NULL,'2021-08-17 10:37:26',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',0),(6279,'Additional Platforms status','AdditionalPlatforms_EXTENSION_STATUS','True','','6',0,NULL,'2021-08-31 11:16:27',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',0),(6283,'Signaturefields','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_SIGNATUREFIELDS','--none--','Select Signaturefields. Please copy and past this value to worldpay: <b><span id=\"signature\"></span></b>','6',0,NULL,'2021-11-03 17:01:14',NULL,'select_multioption(array(\'amount\',\'currency\',\'cartId\'), ',1),(6287,'Delivery Date Management','MODULE_SHIPPING_FLAT_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',1),(6288,'Delivery Date ownership settings','MODULE_SHIPPING_FLAT_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',1),(6289,'Delivery Date Management','MODULE_SHIPPING_FREESHIPPER_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',1),(6290,'Delivery Date ownership settings','MODULE_SHIPPING_FREESHIPPER_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',1),(6291,'Delivery Date Management','MODULE_SHIPPING_ITEM_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',1),(6292,'Delivery Date ownership settings','MODULE_SHIPPING_ITEM_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',1),(6293,'Delivery Date Management','MODULE_SHIPPING_NP_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',1),(6294,'Delivery Date ownership settings','MODULE_SHIPPING_NP_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',1),(6295,'Percentage from Order incl. Tax','MODULE_SHIPPING_PERCENT_SUBTOTAL_INCL_TAX','True','Calculate order amount incl. tax or excl. tax?','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6296,'Delivery Date Management','MODULE_SHIPPING_PERCENT_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',1),(6297,'Delivery Date ownership settings','MODULE_SHIPPING_PERCENT_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',1),(6298,'Delivery Date Management','MODULE_SHIPPING_TABLE_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',1),(6299,'Delivery Date ownership settings','MODULE_SHIPPING_TABLE_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',1),(6300,'Delivery Date Management','MODULE_SHIPPING_UPS_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',1),(6301,'Delivery Date ownership settings','MODULE_SHIPPING_UPS_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',1),(6302,'Delivery Date Management','MODULE_SHIPPING_USPS_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',1),(6303,'Delivery Date ownership settings','MODULE_SHIPPING_USPS_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',1),(6304,'Delivery Date Management','MODULE_SHIPPING_ZONES_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',1),(6305,'Delivery Date ownership settings','MODULE_SHIPPING_ZONES_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',1),(6306,'Delivery Date Management','MODULE_SHIPPING_ZONESPERITEM_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',1),(6307,'Delivery Date ownership settings','MODULE_SHIPPING_ZONESPERITEM_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',1),(6308,'Delivery Date Management','MODULE_SHIPPING_ZONE_TABLE_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',1),(6309,'Delivery Date ownership settings','MODULE_SHIPPING_ZONE_TABLE_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',1),(6310,'One coupon per order only.','MODULE_ORDER_TOTAL_COUPON_ONE_PER_ORDER_ONLY','False','Allow only 1 coupon per order.','6',3,NULL,'2021-11-03 17:02:00',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6311,'Enable Stripe Module','MODULE_PAYMENT_STRIPE_CHECKOUT_STATUS','True','Do you want to accept Stripe payments?','6',0,'2022-07-18 14:31:07','2021-11-15 09:11:10',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6312,'Publishable API Key','MODULE_PAYMENT_STRIPE_CHECKOUT_PUBLISHABLE_KEY','pk_test_51L5tlzLrdFbMtgAWVb82LINlf6po2qfbkRmjCc3o02yH88tlzoCC96f8EnpUmVGgQR104lCdO4WdiqmEpzefgrbE00YzVLdKk0','The Stripe account publishable API key to use.','6',0,'2022-07-18 14:31:07','2021-11-15 09:11:10',NULL,NULL,1),(6313,'Secret API Key','MODULE_PAYMENT_STRIPE_CHECKOUT_SECRET_KEY','ê~{ìúa1ý(DÀã®2766082757708cc49245af5c139610c81f44b09a21810a842426a963c537bc2døçÜ9®D±E­ÃO:¥;/JÃB¼:ÝyvÃÂWxYÎmÊèÈ¶ÀHèÂß0|æ@F¼²	ÍGððü³Ýú£V¢¨3(½I\"ºßÚ$Æuãz	ÁOÎWh¦÷IÝþØ$%õ(pQ!Sãà>î','The Stripe account secret API key to use with the publishable key.','6',0,'2022-07-18 14:31:07','2021-11-15 09:11:10','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',1),(6314,'Webhook Secret','MODULE_PAYMENT_STRIPE_CHECKOUT_WEBHOOK_SECRET','whsec_u42Yb3X9Da4N1eNwwJts7TWImDLH1lT1','The Stripe account webhook signing secret.','6',0,'2022-07-18 14:31:07','2021-11-15 09:11:10',NULL,NULL,1),(6315,'Set Order Status Before Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_ORDER_STATUS_ID','1','Set the status of orders before redirect to Gateway','6',0,'2022-07-18 14:31:07','2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(6316,'Set Order Status Completed Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_COMPLETED_ORDER_STATUS_ID','100006','Set the status of orders completed successfully','6',0,'2022-07-18 14:31:07','2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(6317,'Set Order Status Cancelled Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_CANCELLED_ORDER_STATUS_ID','5','Set the status of orders cancelled','6',0,'2022-07-18 14:31:07','2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(6318,'Update Stock Before Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_UPDATE_STOCK_BEFORE_PAYMENT','False','Should Products Stock be updated even when the payment is not yet COMPLETED?','6',0,'2022-07-18 14:31:07','2021-11-15 09:11:10',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6319,'Payment Zone','MODULE_PAYMENT_STRIPE_CHECKOUT_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',0,'2022-07-18 14:31:07','2021-11-15 09:11:10','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(6320,'Debug E-Mail Address','MODULE_PAYMENT_STRIPE_CHECKOUT_DEBUG_EMAIL','','All parameters of an invalid transaction will be sent to this email address.','6',0,'2022-07-18 14:31:07','2021-11-15 09:11:10',NULL,NULL,1),(6321,'Sort order of display.','MODULE_PAYMENT_STRIPE_CHECKOUT_SORT_ORDER','30','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:16:47','2021-11-15 09:11:10',NULL,NULL,1),(6322,'Enable Collect Shipping','MODULE_SHIPPING_FEDEX_STATUS','False','Do you want to offer collect shipping?','6',0,'2021-11-15 09:14:43','2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6323,'Web Service Mode','MODULE_SHIPPING_FEDEX_MODE','Test','Web Service Mode','6',2,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'Test\', \'Production\'), ',1),(6324,'FedEx Web Services Key','MODULE_SHIPPING_FEDEX_KEY','','Enter FedEx Web Services Key','6',2,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6325,'FedEx Web Services Password','MODULE_SHIPPING_FEDEX_PWD','','Enter FedEx Web Services Password','6',3,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6326,'FedEx Account Number','MODULE_SHIPPING_FEDEX_ACT_NUM','','Enter FedEx Account Number','6',4,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6327,'FedEx Meter Number','MODULE_SHIPPING_FEDEX_METER_NUM','','Enter FedEx Meter Number','6',5,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6328,'Weight Units','MODULE_SHIPPING_FEDEX_WEIGHT','KG','Weight Units:','6',6,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'LB\', \'KG\'), ',1),(6329,'First line of street address','MODULE_SHIPPING_FEDEX_ADDRESS_1','','Enter the first line of your ship-from street address, required','6',7,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6330,'Second line of street address','MODULE_SHIPPING_FEDEX_ADDRESS_2','','Enter the second line of your ship-from street address, leave blank if you do not need to specify a second line','6',8,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6331,'City name','MODULE_SHIPPING_FEDEX_CITY','','Enter the city name for the ship-from street address, required','6',9,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6332,'State or Province name','MODULE_SHIPPING_FEDEX_STATE','','Enter the 2 letter state or province name for the ship-from street address, required for Canada and US','6',10,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6333,'Postal code','MODULE_SHIPPING_FEDEX_POSTAL','','Enter the postal code for the ship-from street address, required','6',11,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6334,'Country','MODULE_SHIPPING_FEDEX_COUNTRY','222','Select the postal country for the ship-from address, required','6',11,NULL,'2021-11-15 09:14:28','\\backend\\models\\Configuration::tep_get_country_name','tep_cfg_pull_down_country_list(',1),(6335,'Phone number','MODULE_SHIPPING_FEDEX_PHONE','','Enter a contact phone number for your company, required','6',12,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6336,'Shipping Delay','MODULE_SHIPPING_FEDEX_SHIPPING_DAYS_DELAY','1','How many days from when an order is placed to when you ship it (Decimals are allowed). Arrival date estimations are based on this value.','6',13,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6337,'Currency Exchange Rates Conversion','MODULE_SHIPPING_FEDEX_CURRENCY','1','Set your currency exchange rate here if needed. Note that this data must be a number (integer like 32 or with a floating point like 32.48) and will have to be updated by you regularly to match exchange fluctuations.','6',14,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6338,'Drop off type','MODULE_SHIPPING_FEDEX_DROPOFF','REGULAR_PICKUP','Dropoff type?','6',15,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'REGULAR_PICKUP\',\'REQUEST_COURIER\',\'DROP_BOX\',\'BUSINESS_SERVICE_CENTER\',\'STATION\'), ',1),(6339,'Enable Domestic NBD','MODULE_SHIPPING_FEDEX_DOMESTIC_NEXT_DAY','true','Enable FedEx Domestic Next Business Day','6',16,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(6340,'Enable International Priority','MODULE_SHIPPING_FEDEX_INTERNATIONAL_PRIORITY','true','Enable FedEx Express International Priority','6',17,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(6341,'Enable International Economy','MODULE_SHIPPING_FEDEX_INTERNATIONAL_ECONOMY','true','Enable FedEx Express International Economy','6',18,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',1),(6342,'Domestic NBD Handling Fee','MODULE_SHIPPING_FEDEX_DOMESTIC_HANDLING_FEE','','Add a domestic handling fee or leave blank (example: 15 or 15%)','6',20,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6343,'International Express Handling Fee','MODULE_SHIPPING_FEDEX_INT_EXPRESS_HANDLING_FEE','','Add an international handling fee or leave blank (example: 15 or 15%)','6',21,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6344,'FedEx Rates','MODULE_SHIPPING_FEDEX_RATES','LIST','FedEx Rates','6',22,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'LIST\',\'ACCOUNT\'), ',1),(6345,'FedEx Packaging Type','MODULE_SHIPPING_FEDEX_PACKAGING_TYPE','YOUR_PACKAGING','FedEx Packaging Type','6',22,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'YOUR_PACKAGING\',\'FEDEX_10KG_BOX\', \'FEDEX_25KG_BOX\', \'FEDEX_BOX\', \'FEDEX_ENVELOPE\', \'FEDEX_EXTRA_LARGE_BOX\', \'FEDEX_LARGE_BOX\', \'FEDEX_MEDIUM_BOX\', \'FEDEX_PAK\', \'FEDEX_SMALL_BOX\', \'FEDEX_TUBE\'), ',1),(6346,'Signature Option','MODULE_SHIPPING_FEDEX_SIGNATURE_OPTION','-1','Require a signature on order subtotal greater than or equal to (set to -1 to disable):','6',23,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6347,'Signature Option Type','MODULE_SHIPPING_FEDEX_SIGNATURE_OPTION_TYPE','SERVICE_DEFAULT','Select Signature Option Type','6',23,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'ADULT\', \'DIRECT\', \'INDIRECT\', \'NO_SIGNATURE_REQUIRED\', \'SERVICE_DEFAULT\'), ',1),(6348,'Insurance?','MODULE_SHIPPING_FEDEX_INSURE','-1','Insure packages over what amount? (set to -1 to disable)','6',22,NULL,'2021-11-15 09:14:28',NULL,NULL,1),(6349,'Shipping Tax Class','MODULE_SHIPPING_FEDEX_TAX_CLASS','0','Use the following tax class on the shipping fee.','6',0,NULL,'2021-11-15 09:14:28','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',1),(6350,'Shipping Shipping Zone','MODULE_SHIPPING_FEDEX_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','6',0,NULL,'2021-11-15 09:14:28','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(6351,'Delivery Date Management','MODULE_SHIPPING_FEDEX_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',1),(6352,'Delivery Date ownership settings','MODULE_SHIPPING_FEDEX_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',1),(6353,'Shipping Sort Order','MODULE_SHIPPING_FEDEX_SORT_ORDER','140','Sort order of display.','6',100,'2021-11-15 09:14:28','2021-11-15 09:14:28',NULL,NULL,1),(6385,'PayPal IPN Use cURL','MODULE_PAYMENT_PAYPALIPN_CURL','False','Use cURL to communicate with PayPal?<br>cURL has been <b>DETECTED</b> in your system','6',4,NULL,'2021-11-16 09:30:10',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6398,'Enable Sage Pay Server Module','MODULE_PAYMENT_SAGE_PAY_SERVER_STATUS','True','Do you want to accept Sage Pay Server payments?','6',0,'2022-07-18 14:31:07','2021-11-16 09:33:25',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6399,'Vendor Login Name','MODULE_PAYMENT_SAGE_PAY_SERVER_VENDOR_LOGIN_NAME','protx','The vendor login name to connect to the gateway with.','6',0,'2022-07-18 14:31:07','2021-11-16 09:33:25',NULL,NULL,1),(6400,'Account login','MODULE_PAYMENT_SAGE_PAY_SERVER_ACCOUNT','','Account login to get transaction details','6',0,'2022-07-18 14:31:07','2021-11-16 09:33:25','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',1),(6401,'Account Password','MODULE_PAYMENT_SAGE_PAY_SERVER_ACCOUNT_PASSWORD','','Account password to get transaction details','6',0,'2022-07-18 14:31:07','2021-11-16 09:33:25','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',1),(6402,'Profile Payment Page','MODULE_PAYMENT_SAGE_PAY_SERVER_PROFILE_PAGE','Normal','Profile page to use for the payment page.','6',0,'2022-07-18 14:31:07','2021-11-16 09:33:25',NULL,'tep_cfg_select_option(array(\'Normal\', \'Low\'), ',1),(6403,'Transaction Method','MODULE_PAYMENT_SAGE_PAY_SERVER_TRANSACTION_METHOD','Payment','The processing method to use for each transaction.','6',0,'2022-07-18 14:31:07','2021-11-16 09:33:25',NULL,'tep_cfg_select_option(array(\'Authenticate\', \'Deferred\', \'Payment\'), ',1),(6404,'Transaction Server','MODULE_PAYMENT_SAGE_PAY_SERVER_TRANSACTION_SERVER','Test','Perform transactions on the production server or on the testing server.','6',0,'2022-07-18 14:31:07','2021-11-16 09:33:25',NULL,'tep_cfg_select_option(array(\'Live\', \'Test\', \'Simulator\'), ',1),(6405,'T3M verification','MODULE_PAYMENT_SAGE_PAY_SERVER_T3M_VERIFICATION','Info','Info - ignore if not available instantly, Optional - check for updates for up to 3 days, required - do not accept transaction if none t3m info available','6',0,'2022-07-18 14:31:07','2021-11-16 09:33:25',NULL,'tep_cfg_select_option(array(\'Info\', \'Optional\', \'Required\'), ',1),(6406,'Allow tokens','MODULE_PAYMENT_SAGE_PAY_SERVER_USE_TOKENS','False','Allow to save tokens.','6',0,'2022-07-18 14:31:07','2021-11-16 09:33:25',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6407,'Payment Zone','MODULE_PAYMENT_SAGE_PAY_SERVER_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',2,'2022-07-18 14:31:07','2021-11-16 09:33:25','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(6408,'Set Order Status','MODULE_PAYMENT_SAGE_PAY_SERVER_ORDER_STATUS_ID','100006','Set the status of orders made with this payment module to this value','6',0,'2022-07-18 14:31:07','2021-11-16 09:33:25','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(6409,'Skip 3D secure amount','MODULE_PAYMENT_SAGE_PAY_3DS_SKIP','','Skip 3D secure verification when paid by token on orders below','6',100,'2022-07-18 14:31:07','2021-11-16 09:33:25',NULL,NULL,1),(6410,'Sort order of display.','MODULE_PAYMENT_SAGE_PAY_SERVER_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:16:47','2021-11-16 09:33:25',NULL,NULL,1),(6411,'Allow PayPal IPN','MODULE_PAYMENT_PAYPALIPN_STATUS','True','Do you want to accept PayPal IPN payments and notifications?','6',1,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6412,'PayPal IPN ID','MODULE_PAYMENT_PAYPALIPN_ID','paypal.sandbox.business@holbi.co.uk','Your business ID at PayPal. Usually the email address you signed up with. You can create a free PayPal account at <a href=\"http://www.paypal.com/\" target=\"_blank\">http://www.paypal.com</a>.','6',2,NULL,'2021-11-16 13:52:41',NULL,'',1),(6413,'PayPal IPN Notify URL','MODULE_PAYMENT_PAYPALIPN_NOTIFY_URL','callback/paypal-notify','Exact location in which your callback/paypal-notify resides.','6',3,NULL,'2021-11-16 13:52:41',NULL,'\\common\\modules\\orderPayment\\urlchecker(',1),(6414,'API Username','MODULE_PAYMENT_PAYPALIPN_USERNAME','','The username to use for the PayPal API service.','6',0,NULL,'2021-11-16 13:52:41',NULL,'',1),(6415,'API Password','MODULE_PAYMENT_PAYPALIPN_PASSWORD','','The password to use for the PayPal API service.','6',0,NULL,'2021-11-16 13:52:41',NULL,'',1),(6416,'Use API Signature','MODULE_PAYMENT_PAYPALIPN_SIGNATURE','','The signature to use for the PayPal API service.','6',0,NULL,'2021-11-16 13:52:41',NULL,'',1),(6417,'or API Certificate','MODULE_PAYMENT_PAYPALIPN_CERTIFICATE','','The certificate to use for the PayPal API service.','6',0,NULL,'2021-11-16 13:52:41',NULL,'cfg_upload_file(',1),(6418,'API Application Client ID','MODULE_PAYMENT_PAYPALIPN_CLIENT_ID','','The Client ID of app','6',0,NULL,'2021-11-16 13:52:41',NULL,'',1),(6419,'API Application Client Secret Key','MODULE_PAYMENT_PPAYPALIPN_CLIENT_SECRET','','The Client Secret Key of app','6',0,NULL,'2021-11-16 13:52:41',NULL,'',1),(6420,'PayPal IPN Add Shipping to Amount','MODULE_PAYMENT_PAYPALIPN_ADD_SHIPPING_TO_AMOUNT','False','Add shipping amount to order amount? (will set shipping amount to $0 in PayPal)','6',5,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6421,'PayPal IPN Add Tax to Amount','MODULE_PAYMENT_PAYPALIPN_ADD_TAX_TO_AMOUNT','False','Add tax amount to order amount? (will set tax amount to $0 in PayPal)','6',5,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6422,'PayPal IPN Update Stock Before Payment','MODULE_PAYMENT_PAYPALIPN_UPDATE_STOCK_BEFORE_PAYMENT','False','Should Products Stock be updated even when the payment is not yet COMPLETED?','6',6,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6423,'PayPal IPN Allowed Currencies','MODULE_PAYMENT_PAYPALIPN_ALLOWED_CURRENCIES','GBP,EUR,USD','Allowed currencies in which customers can pay.<br>Allowed by PayPal: USD,EUR,GBP,CAD,JPY<br>Allowed in your shop: GBP,EUR,USD<br>To add more currencies to your shop go to Localization->Currencies.','6',9,NULL,'2021-11-16 13:52:41',NULL,'',1),(6424,'PayPal IPN Default Currency','MODULE_PAYMENT_PAYPALIPN_DEFAULT_CURRENCY','GBP','Default currency to use when customer try to pay in a NON allowed (because of PayPal or you) currency','6',10,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array (\n 0 => \'GBP\',\n 1 => \'EUR\',\n 2 => \'USD\',\n), ',1),(6425,'PayPal IPN Test Mode','MODULE_PAYMENT_PAYPALIPN_TEST_MODE','True','Run in TEST MODE? If so, you will be able to send TEST IPN from Admin->PayPal_IPN->Test_IPN, BUT you will not be able to receive real IPN\'s from PayPal.','6',11,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(6426,'PayPal IPN Payment Zone','MODULE_PAYMENT_PAYPALIPN_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',13,NULL,'2021-11-16 13:52:41','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',1),(6427,'PayPal IPN Set Status Before Payment','MODULE_PAYMENT_PAYPALIPN_ORDER_BEFORE_PAYMENT_ID','1','Set the status of ordersbefore redirect to Gateway','6',14,NULL,'2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(6428,'PayPal IPN Set Order Status','MODULE_PAYMENT_PAYPALIPN_ORDER_STATUS_ID','100006','Set the status of orders made with this payment module to this value','6',14,NULL,'2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(6429,'PayPal Transactions Cancel Order Status','MODULE_PAYMENT_PAYPALIPN_CANCEL_ORDER_STATUS_ID','5','','6',0,NULL,'2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',1),(6430,'PayPal IPN Debug Email','MODULE_PAYMENT_PAYPALIPN_DEBUG_EMAIL','','PayPal IPN Debug Email','6',15,NULL,'2021-11-16 13:52:41',NULL,'',1),(6431,'PayPal IPN Sort order of display.','MODULE_PAYMENT_PAYPALIPN_SORT_ORDER','80','Sort order of display. Lowest is displayed first.','6',12,'2021-11-16 13:52:41','2021-11-16 13:52:41',NULL,'',1),(6432,'','','','','',0,'2018-03-21 14:47:35','2018-03-21 14:47:35','','',7),(6433,'Modules Sort','DD_MODULE_ORDER_TOTAL_SORT','ot_subtotal.php;ot_coupon.php;ot_gift_wrap.php;ot_loworderfee.php;ot_shipping.php;ot_gv.php;ot_shippingfee.php;ot_paymentfee.php;ot_bonus_points.php;ot_subtax.php;ot_tax.php;ot_total.php;ot_paid.php;ot_due.php;ot_fixed_payment_chg.php;ot_custom.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-09-28 11:28:21','2016-04-11 15:34:09','','',7),(6434,'Modules Sort','DD_MODULE_PAYMENT_SORT','cod.php;cash.php;paypalipn.php;sage_pay_server.php;offline.php;rbsworldpay_hosted.php;paypal_express.php;recurly.php;liqpay.php;klarna_checkout.php;amazon_payment.php;for_collect.php;multisafepay.php;paypal.php;paypal_pro_hs.php;pxpay.php;stripe_ds.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2018-03-22 13:24:41','2017-04-03 09:43:41','','',7),(6435,'Modules Sort','DD_MODULE_SHIPPING_SORT','flat.php;ups.php;freeshipper.php;zonetable.php;item.php;percent.php;table.php;usps.php;zones.php;zonesperitem.php;fedex1.php;dp.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-04-11 15:39:31','','',7),(6436,'Display billing address','DISPLAY_BILLING_ADDRESS','True','Display billing address on checkout and user account?','BOX_CONFIGURATION_MYSTORE',0,'2019-03-26 16:54:24','2019-03-26 16:54:24','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6440,'MAILCHIMP_API_KEY','MAILCHIMP_API_KEY','','','',0,'0000-00-00 00:00:00','0000-00-00 00:00:00','','',7),(6441,'MAILCHIMP_STATUS','MAILCHIMP_STATUS','Disabled','','',0,'0000-00-00 00:00:00','0000-00-00 00:00:00','','',7),(6442,'MAILCHIMP_STATUS_CUSTOMERS','MAILCHIMP_STATUS_CUSTOMERS','Disabled','','',0,'0000-00-00 00:00:00','0000-00-00 00:00:00','','',7),(6443,'Installed Modules','MODULE_DROPSHIPPING_INSTALLED','','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-01-26 09:39:27','','',7),(6444,'Installed Modules','MODULE_LABEL_INSTALLED','','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2019-03-27 15:11:27','','',7),(6445,'Bonus apply minimum cart','MODULE_ORDER_TOTAL_BONUS_POINTS_MINIMUM_CART','0','Subtotal for allow to apply bonus points','6',4,'0000-00-00 00:00:00','2020-10-09 13:42:05','','',7),(6446,'Order Status for Points applying','MODULE_ORDER_TOTAL_BONUS_POINTS_ORDER_STATUS_ID','3','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-10-11 15:53:24','\\common\\helpers\\Order::get_status_name','tep_cfg_select_multioption_order_statuses(',7),(6447,'Set status for covered order','MODULE_ORDER_TOTAL_BONUS_POINTS_ORDER_STATUS_ID_COVERS','2','Covered order','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-10-11 15:53:24','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6448,'Sort Order','MODULE_ORDER_TOTAL_BONUS_POINTS_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-10-11 15:53:24','','',7),(6449,'Display Bonus Points','MODULE_ORDER_TOTAL_BONUS_POINTS_STATUS','true','Do you want this module to display?','BOX_CONFIGURATION_MODULE',1,'2017-10-11 16:41:24','2017-10-11 15:53:24','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6450,'Tax Class','MODULE_ORDER_TOTAL_BONUS_POINTS_TAX_CLASS','0','Use the following tax class on the payment fee.','6',7,'0000-00-00 00:00:00','2020-10-09 13:42:05','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6451,'Re-calculate Tax','MODULE_ORDER_TOTAL_COUPON_CALC_TAX','None','Re-Calculate Tax','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2016-11-16 12:12:22','','tep_cfg_select_option(array(\'None\', \'Standard\', \'Credit Note\'), ',7),(6452,'Include Shipping','MODULE_ORDER_TOTAL_COUPON_INC_SHIPPING','false','Include Shipping in calculation','BOX_CONFIGURATION_MODULE',5,'0000-00-00 00:00:00','2016-11-16 12:12:22','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6453,'Include Tax','MODULE_ORDER_TOTAL_COUPON_INC_TAX','false','Include Tax in calculation.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2016-11-16 12:12:22','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6454,'One coupon per order only.','MODULE_ORDER_TOTAL_COUPON_ONE_PER_ORDER_ONLY','False','Allow only 1 coupon per order.','6',3,'0000-00-00 00:00:00','2021-11-03 17:02:00','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6455,'Sort Order','MODULE_ORDER_TOTAL_COUPON_SORT_ORDER','20','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:12:22','','',7),(6456,'Display Total','MODULE_ORDER_TOTAL_COUPON_STATUS','true','Do you want to display the Discount Coupon value?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:01:31','2016-11-16 12:12:22','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6457,'Tax Class','MODULE_ORDER_TOTAL_COUPON_TAX_CLASS','0','Use the following tax class when treating Discount Coupon as Credit Note.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 12:12:22','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6458,'Sort Order','MODULE_ORDER_TOTAL_DUE_SORT_ORDER','140','Sort order of display.','BOX_CONFIGURATION_MODULE',150,'2017-10-11 15:53:32','2017-04-01 11:18:33','','',7),(6459,'Display Admount Due','MODULE_ORDER_TOTAL_DUE_STATUS','true','Do you want to display the Admount Due?','BOX_CONFIGURATION_MODULE',150,'0000-00-00 00:00:00','2017-04-01 11:18:33','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6460,'Allow Gift Message for order','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE','False','Allow Gift Message for whole order','6',3,'0000-00-00 00:00:00','2020-10-09 13:42:05','','tep_cfg_select_option(array(\'True\', \'False\'),',7),(6461,'Gift Message max characters count','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_CHARS','','Gift Message max characters count, live empty to ignore','6',6,'0000-00-00 00:00:00','2020-10-09 13:42:05','','',7),(6462,'Gift Message price','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_COST','','Gift Message price','6',4,'0000-00-00 00:00:00','2020-10-09 13:42:05','','',7),(6463,'Gift Message max words count','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_WORDS','','Gift Message max words count, live empty to ignore','6',5,'0000-00-00 00:00:00','2020-10-09 13:42:05','','',7),(6464,'Sort Order','MODULE_ORDER_TOTAL_GIFT_WRAP_SORT_ORDER','30','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:46:52','','',7),(6465,'Display Gift Wrap Order Fee','MODULE_ORDER_TOTAL_GIFT_WRAP_STATUS','true','Do you want to display the Gift Wrap Order Fee?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:02:22','2016-11-16 12:46:52','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6466,'Tax Class','MODULE_ORDER_TOTAL_GIFT_WRAP_TAX_CLASS','3','Use the following tax class on the Gift Wrap Order Fee.','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2016-11-16 12:46:52','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6467,'Re-calculate Tax','MODULE_ORDER_TOTAL_GV_CALC_TAX','None','Re-Calculate Tax','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'None\', \'Standard\', \'Credit Note\'), ',7),(6468,'Credit including Tax','MODULE_ORDER_TOTAL_GV_CREDIT_TAX','false','Add tax to purchased Gift Voucher when crediting to Account','BOX_CONFIGURATION_MODULE',8,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6469,'Include Shipping','MODULE_ORDER_TOTAL_GV_INC_SHIPPING','true','Include Shipping in calculation','BOX_CONFIGURATION_MODULE',5,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6470,'Include Tax','MODULE_ORDER_TOTAL_GV_INC_TAX','true','Include Tax in calculation.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6471,'Allowed Order Statuses','MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID','4, 3, 2','Select the status of orders to be processed.','BOX_CONFIGURATION_MODULE',13,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_multioption_order_statuses(',7),(6472,'Set status for covered order','MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID_COVERS','2','Covered order','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-27 15:46:30','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6473,'Queue Purchases','MODULE_ORDER_TOTAL_GV_QUEUE','true','Do you want to queue purchases of the Gift Voucher?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6474,'Sort Order','MODULE_ORDER_TOTAL_GV_SORT_ORDER','60','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:44:20','','',7),(6475,'Display Total','MODULE_ORDER_TOTAL_GV_STATUS','true','Do you want to display the Gift Voucher value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6476,'Tax Class','MODULE_ORDER_TOTAL_GV_TAX_CLASS','0','Use the following tax class when treating Gift Voucher as Credit Note.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:44:20','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6477,'Installed Modules','MODULE_ORDER_TOTAL_INSTALLED','ot_subtotal.php;ot_coupon.php;ot_gift_wrap.php;ot_loworderfee.php;ot_shipping.php;ot_gv.php;ot_shippingfee.php;ot_paymentfee.php;ot_bonus_points.php;ot_subtax.php;ot_tax.php;ot_total.php;ot_paid.php;ot_due.php;ot_refund.php','List of order_total module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ot_subtotal.php;ot_tax.php;ot_shipping.php;ot_total.php)','BOX_CONFIGURATION_MODULE',0,'2020-10-09 13:42:16','2003-07-17 10:29:22','','',7),(6478,'Attach Low Order Fee On Orders Made','MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION','both','Attach low order fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2016-11-16 13:47:46','','tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',7),(6479,'Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_FEE','5','Low order fee.','BOX_CONFIGURATION_MODULE',5,'0000-00-00 00:00:00','2016-11-16 13:47:46','currencies->format','',7),(6480,'Allow Low Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE','false','Do you want to allow low order fees?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2016-11-16 13:47:46','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6481,'Order Fee For Orders Under','MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER','50','Add the low order fee to orders under this amount.','BOX_CONFIGURATION_MODULE',4,'0000-00-00 00:00:00','2016-11-16 13:47:46','currencies->format','',7),(6482,'Sort Order','MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER','40','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:47:46','','',7),(6483,'Display Low Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS','true','Do you want to display the low order fee?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 13:47:46','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6484,'Tax Class','MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS','0','Use the following tax class on the low order fee.','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2016-11-16 13:47:46','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6485,'Sort Order','MODULE_ORDER_TOTAL_PAID_SORT_ORDER','130','Sort order of display.','BOX_CONFIGURATION_MODULE',140,'2017-10-11 15:53:32','2017-04-01 11:18:23','','',7),(6486,'Display Admount Paid','MODULE_ORDER_TOTAL_PAID_STATUS','true','Do you want to display the Admount Paid?','BOX_CONFIGURATION_MODULE',140,'0000-00-00 00:00:00','2017-04-01 11:18:23','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6487,'Allow Payment Fee','MODULE_ORDER_TOTAL_PAYMENTFEE_ALLOW_FEE','false','Do you want to allow payment fees?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2017-01-13 11:37:59','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6488,'Attach Payment Fee On Orders Made','MODULE_ORDER_TOTAL_PAYMENTFEE_DESTINATION','both','Attach payment fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2017-01-13 11:37:59','','tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',7),(6489,'Sort Order','MODULE_ORDER_TOTAL_PAYMENTFEE_SORT_ORDER','80','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-01-13 11:37:59','','',7),(6490,'Display Payment Fee','MODULE_ORDER_TOTAL_PAYMENTFEE_STATUS','true','Do you want to display the payment fee?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2017-01-13 11:37:59','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6491,'Tax Class','MODULE_ORDER_TOTAL_PAYMENTFEE_TAX_CLASS','0','Use the following tax class on the payment fee.','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2017-01-13 11:37:59','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6492,'Sort Order','MODULE_ORDER_TOTAL_REFUND_SORT_ORDER','160','Sort order of display.','6',160,'2020-10-09 13:42:16','2020-10-09 13:42:16','','',7),(6493,'Display Amount Refund','MODULE_ORDER_TOTAL_REFUND_STATUS','true','Do you want to display the Amount Refund?','6',160,'0000-00-00 00:00:00','2020-10-09 13:42:16','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6494,'Allow Shipping Fee','MODULE_ORDER_TOTAL_SHIPPINGFEE_ALLOW_FEE','false','Do you want to allow shipping fees?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2017-01-13 11:37:45','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6495,'Attach Shipping Fee on Orders Made','MODULE_ORDER_TOTAL_SHIPPINGFEE_DESTINATION','both','Attach shipping fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2017-01-13 11:37:45','','tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',7),(6496,'Sort Order','MODULE_ORDER_TOTAL_SHIPPINGFEE_SORT_ORDER','70','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-01-13 11:37:45','','',7),(6497,'Display Shipping Fee','MODULE_ORDER_TOTAL_SHIPPINGFEE_STATUS','true','Do you want to display the shipping Fee?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2017-01-13 11:37:45','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6498,'Tax Class','MODULE_ORDER_TOTAL_SHIPPINGFEE_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2017-01-13 11:37:45','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6499,'Provide Free Shipping For Orders Made','MODULE_ORDER_TOTAL_SHIPPING_DESTINATION','both','Provide free shipping for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',5,'0000-00-00 00:00:00','2016-11-16 13:51:20','','tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',7),(6500,'Allow Free Shipping','MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING','false','Do you want to allow free shipping?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2016-11-16 13:51:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6501,'Free Shipping For Orders Over','MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER','100','Provide free shipping for orders over the set amount.','BOX_CONFIGURATION_MODULE',4,'0000-00-00 00:00:00','2016-11-16 13:51:20','currencies->format','',7),(6502,'Limit shipping results sort mode','MODULE_ORDER_TOTAL_SHIPPING_LIMIT_RESULT_SORT','Cheapest first','','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2019-03-27 14:56:48','','tep_cfg_select_option(array(\'Cheapest first\', \'Modules sort order\'), ',7),(6503,'Number of shipping results','MODULE_ORDER_TOTAL_SHIPPING_RESULT_COUNT','','Limit results (if empty - unlimited).','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2019-03-27 14:56:48','','',7),(6504,'Sort Order','MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER','50','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:51:20','','',7),(6505,'Display Shipping','MODULE_ORDER_TOTAL_SHIPPING_STATUS','true','Do you want to display the order shipping cost?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 13:51:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6506,'Sort Order','MODULE_ORDER_TOTAL_SUBTAX_SORT_ORDER','100','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-02-22 14:10:20','','',7),(6507,'Display Subtotal for taxation','MODULE_ORDER_TOTAL_SUBTAX_STATUS','true','Do you want to display the subtotal for taxation value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2017-02-22 14:10:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6508,'Sort Order','MODULE_ORDER_TOTAL_SUBTOTAL_SORT_ORDER','10','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:10:43','','',7),(6509,'Display Sub-Total','MODULE_ORDER_TOTAL_SUBTOTAL_STATUS','true','Do you want to display the order sub-total cost?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:01:29','2016-11-16 12:10:43','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6510,'Sort Order','MODULE_ORDER_TOTAL_TAX_SORT_ORDER','110','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:08:32','','',7),(6511,'Display Tax','MODULE_ORDER_TOTAL_TAX_STATUS','true','Do you want to display the order tax value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 12:08:32','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6514,'Sort Order','MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER','120','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:06:52','','',7),(6515,'Display Total','MODULE_ORDER_TOTAL_TOTAL_STATUS','true','Do you want to display the total order value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 12:06:52','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6516,'2CheckOut Merchant Notifications','MODULE_PAYMENT_2CHECKOUT_EMAIL_MERCHANT','True','Should 2CheckOut e-mail a receipt to the store owner?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6517,'2CheckOut Login/Store Number','MODULE_PAYMENT_2CHECKOUT_LOGIN','18157','Login/Store Number used for the 2CheckOut service','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','','',7),(6518,'2CheckOut Set Order Status','MODULE_PAYMENT_2CHECKOUT_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6519,'2CheckOut Sort order of display.','MODULE_PAYMENT_2CHECKOUT_SORT_ORDER','100','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-08 16:55:21','','',7),(6520,'Enable 2CheckOut Module','MODULE_PAYMENT_2CHECKOUT_STATUS','False','Do you want to accept 2CheckOut payments?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6521,'2CheckOut Transaction Mode','MODULE_PAYMENT_2CHECKOUT_TESTMODE','Test','Transaction mode used for the 2Checkout service','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','','tep_cfg_select_option(array(\'Test\', \'Production\'), ',7),(6522,'2CheckOut Payment Zone','MODULE_PAYMENT_2CHECKOUT_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-08 16:55:21','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6523,'Authorizenet Customer Notifications','MODULE_PAYMENT_AUTHORIZENET_EMAIL_CUSTOMER','False','Should Authorize.Net e-mail a receipt to the customer?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6524,'Authorizenet Login Username','MODULE_PAYMENT_AUTHORIZENET_LOGIN','testing','The login username used for the Authorize.net service','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','',7),(6525,'Authorizenet Transaction Method','MODULE_PAYMENT_AUTHORIZENET_METHOD','Credit Card','Transaction method used for processing orders','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','tep_cfg_select_option(array(\'Credit Card\', \'eCheck\'), ',7),(6526,'Authorizenet - Set Order Status','MODULE_PAYMENT_AUTHORIZENET_ORDER_STATUS_ID','0','Authorizenet - Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6527,'Authorizenet - Sort order of display.','MODULE_PAYMENT_AUTHORIZENET_SORT_ORDER','80','Authorizenet - Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:51:38','','',7),(6528,'Enable Authorize.net Module','MODULE_PAYMENT_AUTHORIZENET_STATUS','False','Do you want to accept Authorize.net payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:33','2016-04-11 15:51:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6529,'Authorizenet Transaction Mode','MODULE_PAYMENT_AUTHORIZENET_TESTMODE','Test','Transaction mode used for processing orders','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','tep_cfg_select_option(array(\'Test\', \'Production\'), ',7),(6530,'Authorizenet Transaction Key','MODULE_PAYMENT_AUTHORIZENET_TXNKEY','Test','Transaction Key used for encrypting TP data','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','',7),(6531,'Authorizenet - Payment Zone','MODULE_PAYMENT_AUTHORIZENET_ZONE','0','Authorizenet - If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:51:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6532,'CASH Set Order Status','MODULE_PAYMENT_CASH_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-01-17 11:52:46','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6533,'CASH Sort order of display.','MODULE_PAYMENT_CASH_SORT_ORDER','60','Sort order of CASH display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:34:41','2018-01-17 11:52:46','','',7),(6534,'CASH Enable Cash Payment Module','MODULE_PAYMENT_CASH_STATUS','False','Do you want to accept Cash Payment?','BOX_CONFIGURATION_MODULE',1,'2018-03-22 13:24:29','2018-01-17 11:52:46','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6535,'CASH Payment Zone','MODULE_PAYMENT_CASH_ZONED','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2018-01-17 11:52:46','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6536,'CC Split Credit Card E-Mail Address','MODULE_PAYMENT_CC_EMAIL','','If an e-mail address is entered, the middle digits of the credit card number will be sent to the e-mail address (the outside digits are stored in the database with the middle digits censored)','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:49:38','','',7),(6537,'CC Set Order Status','MODULE_PAYMENT_CC_ORDER_STATUS_ID','0','Set the status of CC orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:49:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6538,'CC Sort order of display.','MODULE_PAYMENT_CC_SORT_ORDER','60','Sort order of CC display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:49:38','','',7),(6539,'CC Enable Credit Card Module','MODULE_PAYMENT_CC_STATUS','True','Do you want to accept credit card payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:31','2016-04-11 15:49:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6540,'CC Payment Zone','MODULE_PAYMENT_CC_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:49:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6541,'COD Set Order Status','MODULE_PAYMENT_COD_ORDER_STATUS_ID','100007','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'2022-07-18 14:32:27','2018-01-11 15:06:47','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6542,'COD Sort order of display.','MODULE_PAYMENT_COD_SORT_ORDER','40','Sort order of COD display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:16:57','2018-01-11 15:06:47','','',7),(6543,'COD Enable Cash On Delivery Module','MODULE_PAYMENT_COD_STATUS','True','Do you want to accept Cash On Delevery payments?','BOX_CONFIGURATION_MODULE',1,'2022-07-18 14:32:27','2018-01-11 15:06:47','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6544,'COD Payment Zone','MODULE_PAYMENT_COD_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'2022-07-18 14:32:27','2018-01-11 15:06:47','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6545,'EFSnet Transaction Method','MODULE_PAYMENT_EFSNET_METHOD','CreditCardCharge','Transaction method used for processing orders','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','','tep_cfg_select_option(array(\'CreditCardCharge\',\'CreditCardAuthorize\'), ',7),(6546,'EFSnet Set Order Status','MODULE_PAYMENT_EFSNET_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6547,'EFSnet Sort order of display.','MODULE_PAYMENT_EFSNET_SORT_ORDER','90','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:57:06','','',7),(6548,'Enable EFSnet Module','MODULE_PAYMENT_EFSNET_STATUS','False','Do you want to accept EFSNet payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:34','2016-04-11 15:57:06','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6549,'EFSnet Login Username','MODULE_PAYMENT_EFSNET_STOREID','testing','The StoreID used for the EFSNet service','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','','',7),(6550,'EFSnet Transaction Key','MODULE_PAYMENT_EFSNET_STOREKEY','Test','Store Key used for encrypting data','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','','',7),(6551,'EFSnet Transaction Mode','MODULE_PAYMENT_EFSNET_TESTMODE','Test','Transaction mode used for processing orders','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','','tep_cfg_select_option(array(\'Test\', \'Production\'), ',7),(6552,'EFSnet Payment Zone','MODULE_PAYMENT_EFSNET_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:57:06','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6553,'Free Charge Set Order Status','MODULE_PAYMENT_FREECHARGER_ORDER_STATUS_ID','3','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:50:23','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6554,'Free Charge Sort order of display.','MODULE_PAYMENT_FREECHARGER_SORT_ORDER','70','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:50:23','','',7),(6555,'Enable Free Charge Module','MODULE_PAYMENT_FREECHARGER_STATUS','False','Do you want to accept Free Charge payments?','BOX_CONFIGURATION_MODULE',1,'2016-04-12 14:50:32','2016-04-11 15:50:23','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6556,'Free Charge Payment Zone','MODULE_PAYMENT_FREECHARGER_ZONE','4','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:50:23','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6557,'GeoTrust Merchant ID','MODULE_PAYMENT_GEOTRUST_MERCHANT_ID','serial #','Merchant Serial # to use for the GEOTRUST QuickPayments service','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-02-05 17:19:45','','',7),(6558,'GeoTrust Set Order Status','MODULE_PAYMENT_GEOTRUST_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-02-05 17:19:45','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6559,'GeoTrust Sort order of display.','MODULE_PAYMENT_GEOTRUST_SORT_ORDER','40','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-02-05 17:19:45','','',7),(6560,'Enable GeoTrust QuickPayments Module','MODULE_PAYMENT_GEOTRUST_STATUS','False','Do you want to accept GeoTrust QuickPayments?','BOX_CONFIGURATION_MODULE',1,'2016-04-12 14:50:29','2016-02-05 17:19:45','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6561,'GeoTrust Payment Zone','MODULE_PAYMENT_GEOTRUST_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-02-05 17:19:45','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6562,'Installed Modules','MODULE_PAYMENT_INSTALLED','paypal_partner.php;sage_pay_server.php;stripe_checkout.php;cod.php;offline.php','List of payment module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: cc.php;cod.php;paypal.php)','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:16:57','2003-07-17 10:29:22','','',7),(6563,'Order Status','MODULE_PAYMENT_INVOICE_ORDER_STATUS_ID','1','Festlegung des Status für Bestellungen, welche mit dieser Zahlungsweise durchgeführt werden.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:46:07','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6564,'Reihenfolge der Anzeige','MODULE_PAYMENT_INVOICE_SORT_ORDER','50','Niedrigste wird zuerst angezeigt.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:46:07','','',7),(6565,'Rechnung','MODULE_PAYMENT_INVOICE_STATUS','False','Wollen Sie Zahlungen per Rechnung anbieten?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:30','2016-04-11 15:46:07','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6566,'Zone für diese Zahlungsweise','MODULE_PAYMENT_INVOICE_ZONE','3','Wenn Sie eine Zone auswählen, wird diese Zahlungsweise nur in dieser Zone angeboten.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:46:07','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6567,'Set Order Status','MODULE_PAYMENT_LIQPAY_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',4,'0000-00-00 00:00:00','2018-01-26 15:33:32','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6568,'Money Order Set Order Status','MODULE_PAYMENT_MONEYORDER_ORDER_STATUS_ID','1','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:48:09','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6569,'Money Order Make Payable to:','MODULE_PAYMENT_MONEYORDER_PAYTO','','Who should payments be made payable to?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-04-11 15:48:09','','',7),(6570,'Money Order Sort order of display.','MODULE_PAYMENT_MONEYORDER_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:48:09','','',7),(6571,'Enable Check/Money Order Module','MODULE_PAYMENT_MONEYORDER_STATUS','True','Do you want to accept Check/Money Order payments?','BOX_CONFIGURATION_MODULE',1,'2016-04-13 17:08:47','2016-04-11 15:48:09','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6572,'Money Order Payment Zone','MODULE_PAYMENT_MONEYORDER_ZONE','4','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:48:09','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6573,'OFFLINE Order Status','MODULE_PAYMENT_OFFLINE_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'2022-07-18 14:32:27','2017-04-03 11:25:11','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6574,'OFFLINE Sort order of display.','MODULE_PAYMENT_OFFLINE_SORT_ORDER','50','Sort order of OFFLINE display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:16:57','2017-04-03 11:25:11','','',7),(6575,'OFFLINE Enable Module','MODULE_PAYMENT_OFFLINE_STATUS','False','Do you want to accept OFFLINE payments?','BOX_CONFIGURATION_MODULE',1,'2022-07-18 14:32:27','2017-04-03 11:25:11','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6576,'OFFLINE Payment Zone','MODULE_PAYMENT_OFFLINE_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'2022-07-18 14:32:27','2017-04-03 11:25:11','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6577,'PayPal IPN Add Shipping to Amount','MODULE_PAYMENT_PAYPALIPN_ADD_SHIPPING_TO_AMOUNT','False','Add shipping amount to order amount? (will set shipping amount to $0 in PayPal)','6',5,'0000-00-00 00:00:00','2021-11-16 13:52:41','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6578,'PayPal IPN Add Tax to Amount','MODULE_PAYMENT_PAYPALIPN_ADD_TAX_TO_AMOUNT','False','Add tax amount to order amount? (will set tax amount to $0 in PayPal)','6',5,'0000-00-00 00:00:00','2021-11-16 13:52:41','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6579,'PayPal IPN Allowed Currencies','MODULE_PAYMENT_PAYPALIPN_ALLOWED_CURRENCIES','GBP,EUR,USD','Allowed currencies in which customers can pay.<br>Allowed by PayPal: USD,EUR,GBP,CAD,JPY<br>Allowed in your shop: GBP,EUR,USD<br>To add more currencies to your shop go to Localization->Currencies.','6',9,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',7),(6580,'PayPal Transactions Cancel Order Status','MODULE_PAYMENT_PAYPALIPN_CANCEL_ORDER_STATUS_ID','5','','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6581,'or API Certificate','MODULE_PAYMENT_PAYPALIPN_CERTIFICATE','','The certificate to use for the PayPal API service.','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','','cfg_upload_file(',7),(6582,'API Application Client ID','MODULE_PAYMENT_PAYPALIPN_CLIENT_ID','','The Client ID of app','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',7),(6583,'PayPal IPN Use cURL','MODULE_PAYMENT_PAYPALIPN_CURL','False','Use cURL to communicate with PayPal?<br>cURL has been <b>DETECTED</b> in your system','6',4,'0000-00-00 00:00:00','2021-11-16 09:30:10','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6584,'PayPal IPN Debug Email','MODULE_PAYMENT_PAYPALIPN_DEBUG_EMAIL','','PayPal IPN Debug Email','6',15,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',7),(6585,'PayPal IPN Default Currency','MODULE_PAYMENT_PAYPALIPN_DEFAULT_CURRENCY','GBP','Default currency to use when customer try to pay in a NON allowed (because of PayPal or you) currency','6',10,'0000-00-00 00:00:00','2021-11-16 13:52:41','','tep_cfg_select_option(array (\n 0 => \'GBP\',\n 1 => \'EUR\',\n 2 => \'USD\',\n), ',7),(6586,'PayPal IPN ID','MODULE_PAYMENT_PAYPALIPN_ID','paypal.sandbox.business@holbi.co.uk','Your business ID at PayPal. Usually the email address you signed up with. You can create a free PayPal account at <a href=\"http://www.paypal.com/\" target=\"_blank\">http://www.paypal.com</a>.','6',2,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',7),(6587,'PayPal IPN Notify URL','MODULE_PAYMENT_PAYPALIPN_NOTIFY_URL','callback/paypal-notify','Exact location in which your callback/paypal-notify resides.','6',3,'0000-00-00 00:00:00','2021-11-16 13:52:41','','\\common\\modules\\orderPayment\\urlchecker(',7),(6588,'PayPal IPN Set Status Before Payment','MODULE_PAYMENT_PAYPALIPN_ORDER_BEFORE_PAYMENT_ID','1','Set the status of ordersbefore redirect to Gateway','6',14,'0000-00-00 00:00:00','2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6589,'PayPal IPN Set Order Status','MODULE_PAYMENT_PAYPALIPN_ORDER_STATUS_ID','100006','Set the status of orders made with this payment module to this value','6',14,'0000-00-00 00:00:00','2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6590,'API Password','MODULE_PAYMENT_PAYPALIPN_PASSWORD','','The password to use for the PayPal API service.','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',7),(6591,'Use API Signature','MODULE_PAYMENT_PAYPALIPN_SIGNATURE','','The signature to use for the PayPal API service.','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',7),(6592,'PayPal IPN Sort order of display.','MODULE_PAYMENT_PAYPALIPN_SORT_ORDER','80','Sort order of display. Lowest is displayed first.','6',12,'2021-11-16 13:52:41','2021-11-16 13:52:41','','',7),(6593,'Allow PayPal IPN','MODULE_PAYMENT_PAYPALIPN_STATUS','True','Do you want to accept PayPal IPN payments and notifications?','6',1,'0000-00-00 00:00:00','2021-11-16 13:52:41','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6594,'PayPal IPN Test Mode','MODULE_PAYMENT_PAYPALIPN_TEST_MODE','True','Run in TEST MODE? If so, you will be able to send TEST IPN from Admin->PayPal_IPN->Test_IPN, BUT you will not be able to receive real IPN\'s from PayPal.','6',11,'0000-00-00 00:00:00','2021-11-16 13:52:41','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6595,'PayPal IPN Update Stock Before Payment','MODULE_PAYMENT_PAYPALIPN_UPDATE_STOCK_BEFORE_PAYMENT','False','Should Products Stock be updated even when the payment is not yet COMPLETED?','6',6,'0000-00-00 00:00:00','2021-11-16 13:52:41','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6596,'API Username','MODULE_PAYMENT_PAYPALIPN_USERNAME','','The username to use for the PayPal API service.','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',7),(6597,'PayPal IPN Payment Zone','MODULE_PAYMENT_PAYPALIPN_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',13,'0000-00-00 00:00:00','2021-11-16 13:52:41','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6598,'API Application Client Secret Key','MODULE_PAYMENT_PPAYPALIPN_CLIENT_SECRET','','The Client Secret Key of app','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',7),(6599,'Callback Password','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_CALLBACK_PASSWORD','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','',7),(6600,'Debug E-Mail Address','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_DEBUG_EMAIL','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','',7),(6601,'Installation ID','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_INSTALLATION_ID','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','',7),(6602,'MD5 Password','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_MD5_PASSWORD','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','',7),(6603,'Set Order Status','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_ORDER_STATUS_ID','100006','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6604,'Set Preparing Order Status','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_PREPARE_ORDER_STATUS_ID','1','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6605,'Signaturefields','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_SIGNATUREFIELDS','--none--','Select Signaturefields. Please copy and past this value to worldpay: <b><span id=\"signature\"></span></b>','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:14','','select_multioption(array(\'amount\',\'currency\',\'cartId\'), ',7),(6606,'Sort order of display.','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_SORT_ORDER','20','','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:34:41','2017-04-08 14:31:29','','',7),(6607,'Enable WorldPay Hosted Payment Pages','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_STATUS','False','','BOX_CONFIGURATION_MODULE',0,'2018-01-11 16:18:09','2017-04-08 14:31:29','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6608,'Test Mode','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TESTMODE','True','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6609,'Transactions Order Status Level','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TRANSACTIONS_ORDER_STATUS_ID','1','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6610,'Transaction Method','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TRANSACTION_METHOD','Capture','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','tep_cfg_select_option(array(\'Pre-Authorization\', \'Capture\'), ',7),(6611,'Payment Zone','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_ZONE','0','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6612,'Skip 3D secure amount','MODULE_PAYMENT_SAGE_PAY_3DS_SKIP','','Skip 3D secure verification when paid by token on orders below','6',100,'2022-07-18 14:32:27','2021-11-16 09:33:25','','',7),(6613,'Account login','MODULE_PAYMENT_SAGE_PAY_SERVER_ACCOUNT','','Account login to get transaction details','6',0,'2022-07-18 14:32:27','2021-11-16 09:33:25','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',7),(6614,'Account Password','MODULE_PAYMENT_SAGE_PAY_SERVER_ACCOUNT_PASSWORD','','Account password to get transaction details','6',0,'2022-07-18 14:32:27','2021-11-16 09:33:25','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',7),(6615,'cURL Program Location','MODULE_PAYMENT_SAGE_PAY_SERVER_CURL','/usr/bin/curl','The location to the cURL program application.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:11:50','','',7),(6616,'Set Order Status','MODULE_PAYMENT_SAGE_PAY_SERVER_ORDER_STATUS_ID','100006','Set the status of orders made with this payment module to this value','6',0,'2022-07-18 14:32:27','2021-11-16 09:33:25','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6617,'Profile Payment Page','MODULE_PAYMENT_SAGE_PAY_SERVER_PROFILE_PAGE','Normal','Profile page to use for the payment page.','6',0,'2022-07-18 14:32:27','2021-11-16 09:33:25','','tep_cfg_select_option(array(\'Normal\', \'Low\'), ',7),(6618,'Sort order of display.','MODULE_PAYMENT_SAGE_PAY_SERVER_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:16:57','2021-11-16 09:33:25','','',7),(6619,'Enable Sage Pay Server Module','MODULE_PAYMENT_SAGE_PAY_SERVER_STATUS','True','Do you want to accept Sage Pay Server payments?','6',0,'2022-07-18 14:32:27','2021-11-16 09:33:25','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6620,'T3M verification','MODULE_PAYMENT_SAGE_PAY_SERVER_T3M_VERIFICATION','Info','Info - ignore if not available instantly, Optional - check for updates for up to 3 days, required - do not accept transaction if none t3m info available','6',0,'2022-07-18 14:32:27','2021-11-16 09:33:25','','tep_cfg_select_option(array(\'Info\', \'Optional\', \'Required\'), ',7),(6621,'Transaction Method','MODULE_PAYMENT_SAGE_PAY_SERVER_TRANSACTION_METHOD','Payment','The processing method to use for each transaction.','6',0,'2022-07-18 14:32:27','2021-11-16 09:33:25','','tep_cfg_select_option(array(\'Authenticate\', \'Deferred\', \'Payment\'), ',7),(6622,'Transaction Server','MODULE_PAYMENT_SAGE_PAY_SERVER_TRANSACTION_SERVER','Test','Perform transactions on the production server or on the testing server.','6',0,'2022-07-18 14:32:27','2021-11-16 09:33:25','','tep_cfg_select_option(array(\'Live\', \'Test\', \'Simulator\'), ',7),(6623,'Allow tokens','MODULE_PAYMENT_SAGE_PAY_SERVER_USE_TOKENS','False','Allow to save tokens.','6',0,'2022-07-18 14:32:27','2021-11-16 09:33:25','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6624,'Vendor Login Name','MODULE_PAYMENT_SAGE_PAY_SERVER_VENDOR_LOGIN_NAME','protx','The vendor login name to connect to the gateway with.','6',0,'2022-07-18 14:32:27','2021-11-16 09:33:25','','',7),(6625,'Payment Zone','MODULE_PAYMENT_SAGE_PAY_SERVER_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',2,'2022-07-18 14:32:27','2021-11-16 09:33:25','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6626,'Set Order Status Cancelled Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_CANCELLED_ORDER_STATUS_ID','5','Set the status of orders cancelled','6',0,'2022-07-18 14:32:27','2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6627,'Set Order Status Completed Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_COMPLETED_ORDER_STATUS_ID','100006','Set the status of orders completed successfully','6',0,'2022-07-18 14:32:27','2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6628,'Debug E-Mail Address','MODULE_PAYMENT_STRIPE_CHECKOUT_DEBUG_EMAIL','','All parameters of an invalid transaction will be sent to this email address.','6',0,'2022-07-18 14:32:27','2021-11-15 09:11:10','','',7),(6629,'Set Order Status Before Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_ORDER_STATUS_ID','1','Set the status of orders before redirect to Gateway','6',0,'2022-07-18 14:32:27','2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',7),(6630,'Publishable API Key','MODULE_PAYMENT_STRIPE_CHECKOUT_PUBLISHABLE_KEY','pk_test_51L5tlzLrdFbMtgAWVb82LINlf6po2qfbkRmjCc3o02yH88tlzoCC96f8EnpUmVGgQR104lCdO4WdiqmEpzefgrbE00YzVLdKk0','The Stripe account publishable API key to use.','6',0,'2022-07-18 14:32:27','2021-11-15 09:11:10','','',7),(6631,'Secret API Key','MODULE_PAYMENT_STRIPE_CHECKOUT_SECRET_KEY','#+áÆ<W¾KTE4ab41c5dba2620205fb4a12813ec20a9ccd57d214c4a11ece699186d549b25e5úÿïD,÷±¿oI»NGáz¦ëlliºú^eW¼ó\n\r³°ýâª/ZÖp tºV0ö©zR`Ì:)Rl«ÆÌgôe4Çç£²·©Ù2#`vÙøZmM\'¢SÝJÀç7þÄO>±UÉ\\:PÛ','The Stripe account secret API key to use with the publishable key.','6',0,'0000-00-00 00:00:00','2021-11-15 09:11:10','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',7),(6632,'Sort order of display.','MODULE_PAYMENT_STRIPE_CHECKOUT_SORT_ORDER','30','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:16:57','2021-11-15 09:11:10','','',7),(6633,'Enable Stripe Module','MODULE_PAYMENT_STRIPE_CHECKOUT_STATUS','True','Do you want to accept Stripe payments?','6',0,'2022-07-18 14:32:27','2021-11-15 09:11:10','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6634,'Update Stock Before Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_UPDATE_STOCK_BEFORE_PAYMENT','False','Should Products Stock be updated even when the payment is not yet COMPLETED?','6',0,'2022-07-18 14:32:27','2021-11-15 09:11:10','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6635,'Webhook Secret','MODULE_PAYMENT_STRIPE_CHECKOUT_WEBHOOK_SECRET','whsec_HExwr6qITymk3PEKFcS9LaaTkyzrKwVw','The Stripe account webhook signing secret.','6',0,'2022-07-18 14:32:27','2021-11-15 09:11:10','','',7),(6636,'Payment Zone','MODULE_PAYMENT_STRIPE_CHECKOUT_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',0,'2022-07-18 14:32:27','2021-11-15 09:11:10','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6637,'FedEx Account Number','MODULE_SHIPPING_FEDEX_ACT_NUM','','Enter FedEx Account Number','6',4,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6638,'First line of street address','MODULE_SHIPPING_FEDEX_ADDRESS_1','','Enter the first line of your ship-from street address, required','6',7,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6639,'Second line of street address','MODULE_SHIPPING_FEDEX_ADDRESS_2','','Enter the second line of your ship-from street address, leave blank if you do not need to specify a second line','6',8,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6640,'City name','MODULE_SHIPPING_FEDEX_CITY','','Enter the city name for the ship-from street address, required','6',9,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6641,'Country','MODULE_SHIPPING_FEDEX_COUNTRY','222','Select the postal country for the ship-from address, required','6',11,'0000-00-00 00:00:00','2021-11-15 09:14:28','\\backend\\models\\Configuration::tep_get_country_name','tep_cfg_pull_down_country_list(',7),(6642,'Currency Exchange Rates Conversion','MODULE_SHIPPING_FEDEX_CURRENCY','1','Set your currency exchange rate here if needed. Note that this data must be a number (integer like 32 or with a floating point like 32.48) and will have to be updated by you regularly to match exchange fluctuations.','6',14,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6643,'Delivery Date Management','MODULE_SHIPPING_FEDEX_DATE_SETTING','Use default','Preferred delivery date rules','6',80,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',7),(6644,'Delivery Date ownership settings','MODULE_SHIPPING_FEDEX_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',7),(6645,'Domestic NBD Handling Fee','MODULE_SHIPPING_FEDEX_DOMESTIC_HANDLING_FEE','','Add a domestic handling fee or leave blank (example: 15 or 15%)','6',20,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6646,'Enable Domestic NBD','MODULE_SHIPPING_FEDEX_DOMESTIC_NEXT_DAY','true','Enable FedEx Domestic Next Business Day','6',16,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6647,'Drop off type','MODULE_SHIPPING_FEDEX_DROPOFF','REGULAR_PICKUP','Dropoff type?','6',15,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'REGULAR_PICKUP\',\'REQUEST_COURIER\',\'DROP_BOX\',\'BUSINESS_SERVICE_CENTER\',\'STATION\'), ',7),(6648,'Insurance?','MODULE_SHIPPING_FEDEX_INSURE','-1','Insure packages over what amount? (set to -1 to disable)','6',22,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6649,'Enable International Economy','MODULE_SHIPPING_FEDEX_INTERNATIONAL_ECONOMY','true','Enable FedEx Express International Economy','6',18,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6650,'Enable International Priority','MODULE_SHIPPING_FEDEX_INTERNATIONAL_PRIORITY','true','Enable FedEx Express International Priority','6',17,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'true\', \'false\'), ',7),(6651,'International Express Handling Fee','MODULE_SHIPPING_FEDEX_INT_EXPRESS_HANDLING_FEE','','Add an international handling fee or leave blank (example: 15 or 15%)','6',21,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6652,'FedEx Web Services Key','MODULE_SHIPPING_FEDEX_KEY','','Enter FedEx Web Services Key','6',2,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6653,'FedEx Meter Number','MODULE_SHIPPING_FEDEX_METER_NUM','','Enter FedEx Meter Number','6',5,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6654,'Web Service Mode','MODULE_SHIPPING_FEDEX_MODE','Test','Web Service Mode','6',2,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'Test\', \'Production\'), ',7),(6655,'FedEx Packaging Type','MODULE_SHIPPING_FEDEX_PACKAGING_TYPE','YOUR_PACKAGING','FedEx Packaging Type','6',22,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'YOUR_PACKAGING\',\'FEDEX_10KG_BOX\', \'FEDEX_25KG_BOX\', \'FEDEX_BOX\', \'FEDEX_ENVELOPE\', \'FEDEX_EXTRA_LARGE_BOX\', \'FEDEX_LARGE_BOX\', \'FEDEX_MEDIUM_BOX\', \'FEDEX_PAK\', \'FEDEX_SMALL_BOX\', \'FEDEX_TUBE\'), ',7),(6656,'Phone number','MODULE_SHIPPING_FEDEX_PHONE','','Enter a contact phone number for your company, required','6',12,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6657,'Postal code','MODULE_SHIPPING_FEDEX_POSTAL','','Enter the postal code for the ship-from street address, required','6',11,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6658,'FedEx Web Services Password','MODULE_SHIPPING_FEDEX_PWD','','Enter FedEx Web Services Password','6',3,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6659,'FedEx Rates','MODULE_SHIPPING_FEDEX_RATES','LIST','FedEx Rates','6',22,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'LIST\',\'ACCOUNT\'), ',7),(6660,'Shipping Delay','MODULE_SHIPPING_FEDEX_SHIPPING_DAYS_DELAY','1','How many days from when an order is placed to when you ship it (Decimals are allowed). Arrival date estimations are based on this value.','6',13,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6661,'Signature Option','MODULE_SHIPPING_FEDEX_SIGNATURE_OPTION','-1','Require a signature on order subtotal greater than or equal to (set to -1 to disable):','6',23,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6662,'Signature Option Type','MODULE_SHIPPING_FEDEX_SIGNATURE_OPTION_TYPE','SERVICE_DEFAULT','Select Signature Option Type','6',23,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'ADULT\', \'DIRECT\', \'INDIRECT\', \'NO_SIGNATURE_REQUIRED\', \'SERVICE_DEFAULT\'), ',7),(6663,'Shipping Sort Order','MODULE_SHIPPING_FEDEX_SORT_ORDER','140','Sort order of display.','6',100,'2021-11-15 09:14:28','2021-11-15 09:14:28','','',7),(6664,'State or Province name','MODULE_SHIPPING_FEDEX_STATE','','Enter the 2 letter state or province name for the ship-from street address, required for Canada and US','6',10,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',7),(6665,'Enable Collect Shipping','MODULE_SHIPPING_FEDEX_STATUS','False','Do you want to offer collect shipping?','6',0,'2021-11-15 09:14:43','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6666,'Shipping Tax Class','MODULE_SHIPPING_FEDEX_TAX_CLASS','0','Use the following tax class on the shipping fee.','6',0,'0000-00-00 00:00:00','2021-11-15 09:14:28','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6667,'Weight Units','MODULE_SHIPPING_FEDEX_WEIGHT','KG','Weight Units:','6',6,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'LB\', \'KG\'), ',7),(6668,'Shipping Shipping Zone','MODULE_SHIPPING_FEDEX_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','6',0,'0000-00-00 00:00:00','2021-11-15 09:14:28','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6669,'Flat Shipping Cost','MODULE_SHIPPING_FLAT_COST','5','The shipping cost for all orders using this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:03:53','','',7),(6670,'Delivery Date Management','MODULE_SHIPPING_FLAT_DATE_SETTING','Use default','Preferred delivery date rules','6',80,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',7),(6671,'Delivery Date ownership settings','MODULE_SHIPPING_FLAT_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',7),(6672,'Flat Sort Order','MODULE_SHIPPING_FLAT_SORT_ORDER','10','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 14:03:53','','',7),(6673,'Enable Flat Shipping','MODULE_SHIPPING_FLAT_STATUS','True','Do you want to offer flat rate shipping?','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:36:10','2016-11-16 14:03:53','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6674,'Flat Tax Class','MODULE_SHIPPING_FLAT_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:03:53','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6675,'Flat Shipping Zone','MODULE_SHIPPING_FLAT_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:03:53','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6676,'Free Shipping Cost','MODULE_SHIPPING_FREESHIPPER_COST','0.00','What is the Shipping cost? The Handling fee will also be added.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2016-11-16 13:27:21','','',7),(6677,'Delivery Date Management','MODULE_SHIPPING_FREESHIPPER_DATE_SETTING','Use default','Preferred delivery date rules','6',80,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',7),(6678,'Delivery Date ownership settings','MODULE_SHIPPING_FREESHIPPER_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',7),(6679,'FREESHIPPER Sort Order','MODULE_SHIPPING_FREESHIPPER_SORT_ORDER','30','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:27:21','','',7),(6680,'Enable Free Shipping','MODULE_SHIPPING_FREESHIPPER_STATUS','False','Do you want to offer Free shipping?','BOX_CONFIGURATION_MODULE',5,'2017-07-19 15:13:02','2016-11-16 13:27:21','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6681,'FREESHIPPER Tax Class','MODULE_SHIPPING_FREESHIPPER_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:27:21','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6682,'FREESHIPPER Shipping Zone','MODULE_SHIPPING_FREESHIPPER_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:27:21','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6683,'Installed Modules','MODULE_SHIPPING_INSTALLED','flat.php;freeshipper.php;zonetable.php;item.php;percent.php;table.php;zones.php','List of shipping module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ups.php;flat.php;item.php)','BOX_CONFIGURATION_MODULE',0,'2022-06-24 14:32:29','2003-07-17 10:29:22','','',7),(6684,'Item Shipping Shipping Cost','MODULE_SHIPPING_ITEM_COST','0','The shipping cost will be multiplied by the number of items in an order that uses this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:59:56','','',7),(6685,'Delivery Date Management','MODULE_SHIPPING_ITEM_DATE_SETTING','Use default','Preferred delivery date rules','6',80,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',7),(6686,'Delivery Date ownership settings','MODULE_SHIPPING_ITEM_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',7),(6687,'Item Shipping Handling Fee','MODULE_SHIPPING_ITEM_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:59:56','','',7),(6688,'Item Shipping Sort Order','MODULE_SHIPPING_ITEM_SORT_ORDER','50','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:59:56','','',7),(6689,'Enable Item Shipping','MODULE_SHIPPING_ITEM_STATUS','False','Do you want to offer per item rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-01-11 16:18:17','2016-11-16 13:59:56','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6690,'Item Shipping Tax Class','MODULE_SHIPPING_ITEM_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:59:56','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6691,'Item Shipping Shipping Zone','MODULE_SHIPPING_ITEM_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:59:56','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6692,'NovaPoshta ApiKey','MODULE_SHIPPING_NP_APIKEY','dd791bafa70224a996085024e0687e8c','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-02-16 15:24:13','','',7),(6693,'NovaPoshta ApiKey','MODULE_SHIPPING_NP_API_KEY','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2019-10-22 13:18:12','','',7),(6694,'NovaPoshta Shipping Shipping Cost','MODULE_SHIPPING_NP_COST','40','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-02-16 15:24:13','','',7),(6695,'Delivery Date Management','MODULE_SHIPPING_NP_DATE_SETTING','Use default','Preferred delivery date rules','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',7),(6696,'Delivery Date ownership settings','MODULE_SHIPPING_NP_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',7),(6697,'Preferred Shipping Method','MODULE_SHIPPING_NP_PREFERRED_METHOD','WarehouseToWarehouse','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2019-10-22 13:18:12','','tep_cfg_select_option(array(\'WarehouseToWarehouse\', \'WarehouseToDoors\'), ',7),(6698,'NP Shipping Sort Order','MODULE_SHIPPING_NP_SORT_ORDER','130','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2018-02-16 15:24:13','2018-02-16 15:24:13','','',7),(6699,'Enable Item Shipping','MODULE_SHIPPING_NP_STATUS','False','Do you want to offer NovaPoshta shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-22 13:24:50','2018-02-16 15:24:13','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6700,'Tracking Url','MODULE_SHIPPING_NP_TRACKING_NUMBER_URL','https://novaposhta.ua/tracking/?newtracking=1&cargo_number=','Url for tracking cargo','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2019-10-22 13:18:12','','',7),(6701,'Enable NP Tracking','MODULE_SHIPPING_NP_TRACKING_STATUS','True','Do you want to enable NP tracking?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-10-02 09:43:28','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6702,'Delivery Date Management','MODULE_SHIPPING_PERCENT_DATE_SETTING','Use default','Preferred delivery date rules','6',80,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',7),(6703,'Delivery Date ownership settings','MODULE_SHIPPING_PERCENT_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',7),(6704,'Percentage A Flat Rate of','MODULE_SHIPPING_PERCENT_FLAT_USE','6.50','A Flat Rate used for all orders.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','','',7),(6705,'Percentage A Flat Rate for orders under','MODULE_SHIPPING_PERCENT_LESS_THEN','34.75','A Flat Rate for all orders that are under the amount shown.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','','',7),(6706,'Percentage Rate','MODULE_SHIPPING_PERCENT_RATE','.18','The Percentage Rate all .01 to .99 for all orders using this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','','',7),(6707,'Percentage Sort Order','MODULE_SHIPPING_PERCENT_SORT_ORDER','60','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:52:35','','',7),(6708,'Enable Percent Shipping','MODULE_SHIPPING_PERCENT_STATUS','True','Do you want to offer percent rate shipping?','BOX_CONFIGURATION_MODULE',0,'2022-06-24 16:54:00','2016-11-16 13:52:35','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6709,'Percentage from Order incl. Tax','MODULE_SHIPPING_PERCENT_SUBTOTAL_INCL_TAX','True','Calculate order amount incl. tax or excl. tax?','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6710,'Percentage Tax Class','MODULE_SHIPPING_PERCENT_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6711,'Percentage Shipping Zone','MODULE_SHIPPING_PERCENT_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6712,'Table Method Shipping Table','MODULE_SHIPPING_TABLE_COST','25:8.50,50:5.50,10000:0.00','The shipping cost is based on the total cost or weight of items. Example: 25:8.50,50:5.50,etc.. Up to 25 charge 8.50, from there to 50 charge 5.50, etc','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','','',7),(6713,'Delivery Date Management','MODULE_SHIPPING_TABLE_DATE_SETTING','Use default','Preferred delivery date rules','6',80,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',7),(6714,'Delivery Date ownership settings','MODULE_SHIPPING_TABLE_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',7),(6715,'Table Method Handling Fee','MODULE_SHIPPING_TABLE_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','','',7),(6716,'Table Method','MODULE_SHIPPING_TABLE_MODE','weight','The shipping cost is based on the order total or the total weight of the items ordered.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','','tep_cfg_select_option(array(\'weight\', \'price\'), ',7),(6717,'Table Method Sort Order','MODULE_SHIPPING_TABLE_SORT_ORDER','70','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-24 17:14:14','','',7),(6718,'Enable Table Method','MODULE_SHIPPING_TABLE_STATUS','False','Do you want to offer table rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-02-22 16:42:12','2016-11-24 17:14:14','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6719,'Table Method Tax Class','MODULE_SHIPPING_TABLE_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6720,'Table Method Shipping Zone','MODULE_SHIPPING_TABLE_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6721,'Delivery Date Management','MODULE_SHIPPING_UPS_DATE_SETTING','Use default','Preferred delivery date rules','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',7),(6722,'Delivery Date ownership settings','MODULE_SHIPPING_UPS_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',7),(6723,'UPS Handling Fee','MODULE_SHIPPING_UPS_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','','',7),(6724,'UPS Packaging?','MODULE_SHIPPING_UPS_PACKAGE','CP','CP - Your Packaging, ULE - UPS Letter, UT - UPS Tube, UBE - UPS Express Box','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','','',7),(6725,'UPS Pickup Method','MODULE_SHIPPING_UPS_PICKUP','CC','How do you give packages to UPS? CC - Customer Counter, RDP - Daily Pickup, OTP - One Time Pickup, LC - Letter Center, OCA - On Call Air','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','','',7),(6726,'UPS Residential Delivery?','MODULE_SHIPPING_UPS_RES','RES','Quote for Residential (RES) or Commercial Delivery (COM)','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','','',7),(6727,'UPS Sort order of display.','MODULE_SHIPPING_UPS_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:01:59','','',7),(6728,'Enable UPS Shipping','MODULE_SHIPPING_UPS_STATUS','False','Do you want to offer UPS shipping?','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:46:54','2016-11-16 13:01:59','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6729,'UPS Tax Class','MODULE_SHIPPING_UPS_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6730,'UPS Shipping Methods','MODULE_SHIPPING_UPS_TYPES','1DM, 1DML, 1DA, 1DAL, 1DAPI, 1DP, 1DPL, 2DM, 2DML, 2DA, 2DAL, 3DS, GND, STD, XPR, XPRL, XDM, XDML, XPD','Select the UPS services to be offered.','BOX_CONFIGURATION_MODULE',13,'0000-00-00 00:00:00','2016-11-16 13:01:59','','tep_cfg_select_multioption(array(\'1DM\',\'1DML\', \'1DA\', \'1DAL\', \'1DAPI\', \'1DP\', \'1DPL\', \'2DM\', \'2DML\', \'2DA\', \'2DAL\', \'3DS\',\'GND\', \'STD\', \'XPR\', \'XPRL\', \'XDM\', \'XDML\', \'XPD\'), ',7),(6731,'UPS Shipping Zone','MODULE_SHIPPING_UPS_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6732,'Delivery Date Management','MODULE_SHIPPING_USPS_DATE_SETTING','Use default','Preferred delivery date rules','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',7),(6733,'Delivery Date ownership settings','MODULE_SHIPPING_USPS_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',7),(6734,'Handling Fee','MODULE_SHIPPING_USPS_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','','',7),(6735,'USPS Options','MODULE_SHIPPING_USPS_OPTIONS','Display weight, Display transit time','Select from the following the USPS options.','BOX_CONFIGURATION_MODULE',16,'0000-00-00 00:00:00','2016-11-16 13:31:02','','tep_cfg_select_multioption(array(\'Display weight\', \'Display transit time\'), ',7),(6736,'Enter the USPS Password','MODULE_SHIPPING_USPS_PASSWORD','','See USERID, above.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','','',7),(6737,'Which server to use','MODULE_SHIPPING_USPS_SERVER','test','An account at USPS is needed to use the Production server','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','','tep_cfg_select_option(array(\'test\', \'production\'), ',7),(6738,'Sort Order','MODULE_SHIPPING_USPS_SORT_ORDER','80','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2016-11-16 13:31:02','2016-11-16 13:31:02','','',7),(6739,'Enable USPS Shipping','MODULE_SHIPPING_USPS_STATUS','False','Do you want to offer USPS shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-21 16:18:57','2016-11-16 13:31:02','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6740,'Tax Class','MODULE_SHIPPING_USPS_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6741,'Domestic Shipping Methods','MODULE_SHIPPING_USPS_TYPES','First Class, Priority Mail, Priority Mail Express','Select the domestic services to be offered:','BOX_CONFIGURATION_MODULE',14,'0000-00-00 00:00:00','2016-11-16 13:31:02','','tep_cfg_select_multioption(array(\'First Class\', \'Priority Mail\', \'Priority Mail Express\'),',7),(6742,'Int\'l Shipping Methods','MODULE_SHIPPING_USPS_TYPES_INTL','Priority Mail Express International, Priority Mail International','Select the international services to be offered:','BOX_CONFIGURATION_MODULE',15,'0000-00-00 00:00:00','2016-11-16 13:31:02','','tep_cfg_select_multioption(array(\'Priority Mail Express International\', \'Priority Mail International\'),',7),(6743,'Enter the USPS User ID','MODULE_SHIPPING_USPS_USERID','','Enter the USPS USERID assigned to you.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','','',7),(6744,'Shipping Zone','MODULE_SHIPPING_USPS_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',7),(6745,'Delivery Date Management','MODULE_SHIPPING_ZONESPERITEM_DATE_SETTING','Use default','Preferred delivery date rules','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',7),(6746,'Delivery Date ownership settings','MODULE_SHIPPING_ZONESPERITEM_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',7),(6747,'Zone 1 Geo Zone','MODULE_SHIPPING_ZONESPERITEM_GEO_ZONE_1','0','Select Geo Zone of this Zone 1.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',7),(6748,'Number of Zones','MODULE_SHIPPING_ZONESPERITEM_NUMBER_OF_ZONES','1','Number of zones needed.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:38:29','','',7),(6749,'Zone 1 Premium Additional Item Charge','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_ADDITIONAL_ITEM_CHARGE_1','0.00','Premium Additional Item Charge for this shipping zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',7),(6750,'Zone 1 Premium Free Delivery Amount','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_FREE_DELIVERY_AMOUNT_1','20.00','Amount of subtotal for free premium delivery for this shipping zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',7),(6751,'Zone 1 Premium Initial Item Charge','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_INITIAL_ITEM_CHARGE_1','4.50','Premium Initial Item Charge for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',7),(6752,'Zones Per Item Sort Order','MODULE_SHIPPING_ZONESPERITEM_SORT_ORDER','100','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-12-21 15:38:29','','',7),(6753,'Zone 1 Standard Additional Item Charge','MODULE_SHIPPING_ZONESPERITEM_STANDARD_ADDITIONAL_ITEM_CHARGE_1','0.50','Standard Additional Item Charge for this shipping zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',7),(6754,'Zone 1 Standard Free Delivery Amount','MODULE_SHIPPING_ZONESPERITEM_STANDARD_FREE_DELIVERY_AMOUNT_1','20.00','Amount of subtotal for free standard delivery for this shipping zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',7),(6755,'Zone 1 Standard Initial Item Charge','MODULE_SHIPPING_ZONESPERITEM_STANDARD_INITIAL_ITEM_CHARGE_1','2.50','Standard Initial Item Charge for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',7),(6756,'Enable Zones Per Item Method','MODULE_SHIPPING_ZONESPERITEM_STATUS','False','Do you want to offer zone rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-14 15:08:27','2016-12-21 15:38:29','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6757,'Zones Per Item Tax Class','MODULE_SHIPPING_ZONESPERITEM_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:38:29','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6758,'Zone 1 Shipping Table','MODULE_SHIPPING_ZONES_COST_1','3:8.50,7:10.50,99:20.00','Shipping rates to Zone 1 destinations based on a group of maximum order weights. Example: 3:8.50,7:10.50,... Weights less than or equal to 3 would cost 8.50 for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:47:33','','',7),(6759,'Zone 1 Countries','MODULE_SHIPPING_ZONES_COUNTRIES_1','US,CA','Comma separated list of two character ISO country codes that are part of Zone 1.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:47:33','','',7),(6760,'Delivery Date Management','MODULE_SHIPPING_ZONES_DATE_SETTING','Use default','Preferred delivery date rules','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',7),(6761,'Delivery Date ownership settings','MODULE_SHIPPING_ZONES_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',7),(6762,'Zone 1 Handling Fee','MODULE_SHIPPING_ZONES_HANDLING_1','0','Handling Fee for this shipping zone','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:47:33','','',7),(6763,'Zones Sort Order','MODULE_SHIPPING_ZONES_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:47:33','','',7),(6764,'Zones Enable Zones Method','MODULE_SHIPPING_ZONES_STATUS','False','Do you want to offer zone rate shipping?','BOX_CONFIGURATION_MODULE',0,'2017-05-29 13:48:31','2016-11-16 13:47:33','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6765,'Zones Tax Class','MODULE_SHIPPING_ZONES_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:47:33','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6766,'If no rates found allow complete order','MODULE_SHIPPING_ZONE_ALLOW_ERROR_PASS','False','Display \"please call us for a quote\" and allow complete order.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2019-10-22 13:18:12','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6767,'Delivery Date Management','MODULE_SHIPPING_ZONE_TABLE_DATE_SETTING','Use default','Preferred delivery date rules','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',7),(6768,'Delivery Date ownership settings','MODULE_SHIPPING_ZONE_TABLE_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',7),(6769,'Handling Fee','MODULE_SHIPPING_ZONE_TABLE_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-01-05 14:27:17','','',7),(6770,'Sort Order','MODULE_SHIPPING_ZONE_TABLE_SORT_ORDER','40','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2017-01-05 14:27:17','','',7),(6771,'Enable Table Method','MODULE_SHIPPING_ZONE_TABLE_STATUS','True','Do you want to offer Zone Table rate shipping?','BOX_CONFIGURATION_MODULE',0,'2022-06-24 16:53:59','2017-01-05 14:27:17','','tep_cfg_select_option(array(\'True\', \'False\'), ',7),(6772,'Tax Class','MODULE_SHIPPING_ZONE_TABLE_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-01-05 14:27:17','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',7),(6773,'Public API key','TRUSTPILOT_API_KEY','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',7),(6774,'Business password','TRUSTPILOT_API_PASSWORD','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',7),(6775,'Private API secret','TRUSTPILOT_API_SECRET','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',7),(6776,'Business username','TRUSTPILOT_API_USERNAME','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',7),(6777,'BCC Trustpilot email','TRUSTPILOT_BCC_EMAIL','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',7),(6778,'Business Unit Id','TRUSTPILOT_BUSINESS_UNIT_ID','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-12 17:42:38','','',7),(6779,'Select integration','TRUSTPILOT_CONNECT_VIA','bccMail','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','tep_cfg_select_option(array(\'bccMail\', \'API\'),',7),(6780,'Delay invite send (days)','TRUSTPILOT_INVITE_DELAY','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',7),(6781,'Filter orders by','TRUSTPILOT_INVITE_ORDER_AMOUNT_BY','ot_total','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','tep_cfg_select_option(array(\'ot_subtotal\', \'ot_total\'),',7),(6782,'Filter orders by amount, from','TRUSTPILOT_INVITE_ORDER_AMOUNT_FROM','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',7),(6783,'Filter orders by amount, not above','TRUSTPILOT_INVITE_ORDER_AMOUNT_TO','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',7),(6784,'Redirect URL','TRUSTPILOT_REDIRECT_URI','https://uk.trustpilot.com','https://www.trustpilot.com','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',7),(6785,'Sender Email','TRUSTPILOT_SENDER_EMAIL','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',7),(6786,'Sender Name','TRUSTPILOT_SENDER_NAME','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',7),(6787,'Status','TRUSTPILOT_STATUS','Disabled','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','tep_cfg_select_option(array(\'Disabled\', \'Enabled\'),',7),(6788,'Verify meta tag','TRUSTPILOT_VERIFY_META_TAG','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',7),(6789,'','','','','',0,'2018-03-21 14:47:35','2018-03-21 14:47:35','','',8),(6790,'Modules Sort','DD_MODULE_ORDER_TOTAL_SORT','ot_subtotal.php;ot_coupon.php;ot_gift_wrap.php;ot_loworderfee.php;ot_shipping.php;ot_gv.php;ot_shippingfee.php;ot_paymentfee.php;ot_bonus_points.php;ot_subtax.php;ot_tax.php;ot_total.php;ot_paid.php;ot_due.php;ot_fixed_payment_chg.php;ot_custom.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-09-28 11:28:21','2016-04-11 15:34:09','','',8),(6791,'Modules Sort','DD_MODULE_PAYMENT_SORT','cod.php;cash.php;paypalipn.php;sage_pay_server.php;offline.php;rbsworldpay_hosted.php;paypal_express.php;recurly.php;liqpay.php;klarna_checkout.php;amazon_payment.php;for_collect.php;multisafepay.php;paypal.php;paypal_pro_hs.php;pxpay.php;stripe_ds.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2018-03-22 13:24:41','2017-04-03 09:43:41','','',8),(6792,'Modules Sort','DD_MODULE_SHIPPING_SORT','flat.php;ups.php;freeshipper.php;zonetable.php;item.php;percent.php;table.php;usps.php;zones.php;zonesperitem.php;fedex1.php;dp.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-04-11 15:39:31','','',8),(6793,'Display billing address','DISPLAY_BILLING_ADDRESS','True','Display billing address on checkout and user account?','BOX_CONFIGURATION_MYSTORE',0,'2019-03-26 16:54:24','2019-03-26 16:54:24','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6797,'MAILCHIMP_API_KEY','MAILCHIMP_API_KEY','','','',0,'0000-00-00 00:00:00','0000-00-00 00:00:00','','',8),(6798,'MAILCHIMP_STATUS','MAILCHIMP_STATUS','Disabled','','',0,'0000-00-00 00:00:00','0000-00-00 00:00:00','','',8),(6799,'MAILCHIMP_STATUS_CUSTOMERS','MAILCHIMP_STATUS_CUSTOMERS','Disabled','','',0,'0000-00-00 00:00:00','0000-00-00 00:00:00','','',8),(6800,'Installed Modules','MODULE_DROPSHIPPING_INSTALLED','','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-01-26 09:39:27','','',8),(6801,'Installed Modules','MODULE_LABEL_INSTALLED','','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2019-03-27 15:11:27','','',8),(6802,'Bonus apply minimum cart','MODULE_ORDER_TOTAL_BONUS_POINTS_MINIMUM_CART','0','Subtotal for allow to apply bonus points','6',4,'0000-00-00 00:00:00','2020-10-09 13:42:05','','',8),(6803,'Order Status for Points applying','MODULE_ORDER_TOTAL_BONUS_POINTS_ORDER_STATUS_ID','3','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-10-11 15:53:24','\\common\\helpers\\Order::get_status_name','tep_cfg_select_multioption_order_statuses(',8),(6804,'Set status for covered order','MODULE_ORDER_TOTAL_BONUS_POINTS_ORDER_STATUS_ID_COVERS','2','Covered order','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-10-11 15:53:24','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6805,'Sort Order','MODULE_ORDER_TOTAL_BONUS_POINTS_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-10-11 15:53:24','','',8),(6806,'Display Bonus Points','MODULE_ORDER_TOTAL_BONUS_POINTS_STATUS','true','Do you want this module to display?','BOX_CONFIGURATION_MODULE',1,'2017-10-11 16:41:24','2017-10-11 15:53:24','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6807,'Tax Class','MODULE_ORDER_TOTAL_BONUS_POINTS_TAX_CLASS','0','Use the following tax class on the payment fee.','6',7,'0000-00-00 00:00:00','2020-10-09 13:42:05','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(6808,'Re-calculate Tax','MODULE_ORDER_TOTAL_COUPON_CALC_TAX','None','Re-Calculate Tax','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2016-11-16 12:12:22','','tep_cfg_select_option(array(\'None\', \'Standard\', \'Credit Note\'), ',8),(6809,'Include Shipping','MODULE_ORDER_TOTAL_COUPON_INC_SHIPPING','false','Include Shipping in calculation','BOX_CONFIGURATION_MODULE',5,'0000-00-00 00:00:00','2016-11-16 12:12:22','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6810,'Include Tax','MODULE_ORDER_TOTAL_COUPON_INC_TAX','false','Include Tax in calculation.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2016-11-16 12:12:22','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6811,'One coupon per order only.','MODULE_ORDER_TOTAL_COUPON_ONE_PER_ORDER_ONLY','False','Allow only 1 coupon per order.','6',3,'0000-00-00 00:00:00','2021-11-03 17:02:00','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6812,'Sort Order','MODULE_ORDER_TOTAL_COUPON_SORT_ORDER','20','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:12:22','','',8),(6813,'Display Total','MODULE_ORDER_TOTAL_COUPON_STATUS','true','Do you want to display the Discount Coupon value?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:01:31','2016-11-16 12:12:22','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6814,'Tax Class','MODULE_ORDER_TOTAL_COUPON_TAX_CLASS','0','Use the following tax class when treating Discount Coupon as Credit Note.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 12:12:22','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(6815,'Sort Order','MODULE_ORDER_TOTAL_DUE_SORT_ORDER','140','Sort order of display.','BOX_CONFIGURATION_MODULE',150,'2017-10-11 15:53:32','2017-04-01 11:18:33','','',8),(6816,'Display Admount Due','MODULE_ORDER_TOTAL_DUE_STATUS','true','Do you want to display the Admount Due?','BOX_CONFIGURATION_MODULE',150,'0000-00-00 00:00:00','2017-04-01 11:18:33','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6817,'Allow Gift Message for order','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE','False','Allow Gift Message for whole order','6',3,'0000-00-00 00:00:00','2020-10-09 13:42:05','','tep_cfg_select_option(array(\'True\', \'False\'),',8),(6818,'Gift Message max characters count','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_CHARS','','Gift Message max characters count, live empty to ignore','6',6,'0000-00-00 00:00:00','2020-10-09 13:42:05','','',8),(6819,'Gift Message price','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_COST','','Gift Message price','6',4,'0000-00-00 00:00:00','2020-10-09 13:42:05','','',8),(6820,'Gift Message max words count','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_WORDS','','Gift Message max words count, live empty to ignore','6',5,'0000-00-00 00:00:00','2020-10-09 13:42:05','','',8),(6821,'Sort Order','MODULE_ORDER_TOTAL_GIFT_WRAP_SORT_ORDER','30','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:46:52','','',8),(6822,'Display Gift Wrap Order Fee','MODULE_ORDER_TOTAL_GIFT_WRAP_STATUS','true','Do you want to display the Gift Wrap Order Fee?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:02:22','2016-11-16 12:46:52','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6823,'Tax Class','MODULE_ORDER_TOTAL_GIFT_WRAP_TAX_CLASS','3','Use the following tax class on the Gift Wrap Order Fee.','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2016-11-16 12:46:52','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(6824,'Re-calculate Tax','MODULE_ORDER_TOTAL_GV_CALC_TAX','None','Re-Calculate Tax','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'None\', \'Standard\', \'Credit Note\'), ',8),(6825,'Credit including Tax','MODULE_ORDER_TOTAL_GV_CREDIT_TAX','false','Add tax to purchased Gift Voucher when crediting to Account','BOX_CONFIGURATION_MODULE',8,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6826,'Include Shipping','MODULE_ORDER_TOTAL_GV_INC_SHIPPING','true','Include Shipping in calculation','BOX_CONFIGURATION_MODULE',5,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6827,'Include Tax','MODULE_ORDER_TOTAL_GV_INC_TAX','true','Include Tax in calculation.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6828,'Allowed Order Statuses','MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID','4, 3, 2','Select the status of orders to be processed.','BOX_CONFIGURATION_MODULE',13,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_multioption_order_statuses(',8),(6829,'Set status for covered order','MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID_COVERS','2','Covered order','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-27 15:46:30','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6830,'Queue Purchases','MODULE_ORDER_TOTAL_GV_QUEUE','true','Do you want to queue purchases of the Gift Voucher?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6831,'Sort Order','MODULE_ORDER_TOTAL_GV_SORT_ORDER','60','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:44:20','','',8),(6832,'Display Total','MODULE_ORDER_TOTAL_GV_STATUS','true','Do you want to display the Gift Voucher value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 13:44:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6833,'Tax Class','MODULE_ORDER_TOTAL_GV_TAX_CLASS','0','Use the following tax class when treating Gift Voucher as Credit Note.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:44:20','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(6834,'Installed Modules','MODULE_ORDER_TOTAL_INSTALLED','ot_subtotal.php;ot_coupon.php;ot_gift_wrap.php;ot_loworderfee.php;ot_shipping.php;ot_gv.php;ot_shippingfee.php;ot_paymentfee.php;ot_bonus_points.php;ot_subtax.php;ot_tax.php;ot_total.php;ot_paid.php;ot_due.php;ot_refund.php','List of order_total module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ot_subtotal.php;ot_tax.php;ot_shipping.php;ot_total.php)','BOX_CONFIGURATION_MODULE',0,'2020-10-09 13:42:16','2003-07-17 10:29:22','','',8),(6835,'Attach Low Order Fee On Orders Made','MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION','both','Attach low order fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2016-11-16 13:47:46','','tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',8),(6836,'Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_FEE','5','Low order fee.','BOX_CONFIGURATION_MODULE',5,'0000-00-00 00:00:00','2016-11-16 13:47:46','currencies->format','',8),(6837,'Allow Low Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE','false','Do you want to allow low order fees?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2016-11-16 13:47:46','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6838,'Order Fee For Orders Under','MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER','50','Add the low order fee to orders under this amount.','BOX_CONFIGURATION_MODULE',4,'0000-00-00 00:00:00','2016-11-16 13:47:46','currencies->format','',8),(6839,'Sort Order','MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER','40','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:47:46','','',8),(6840,'Display Low Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS','true','Do you want to display the low order fee?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 13:47:46','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6841,'Tax Class','MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS','0','Use the following tax class on the low order fee.','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2016-11-16 13:47:46','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(6842,'Sort Order','MODULE_ORDER_TOTAL_PAID_SORT_ORDER','130','Sort order of display.','BOX_CONFIGURATION_MODULE',140,'2017-10-11 15:53:32','2017-04-01 11:18:23','','',8),(6843,'Display Admount Paid','MODULE_ORDER_TOTAL_PAID_STATUS','true','Do you want to display the Admount Paid?','BOX_CONFIGURATION_MODULE',140,'0000-00-00 00:00:00','2017-04-01 11:18:23','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6844,'Allow Payment Fee','MODULE_ORDER_TOTAL_PAYMENTFEE_ALLOW_FEE','false','Do you want to allow payment fees?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2017-01-13 11:37:59','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6845,'Attach Payment Fee On Orders Made','MODULE_ORDER_TOTAL_PAYMENTFEE_DESTINATION','both','Attach payment fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2017-01-13 11:37:59','','tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',8),(6846,'Sort Order','MODULE_ORDER_TOTAL_PAYMENTFEE_SORT_ORDER','80','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-01-13 11:37:59','','',8),(6847,'Display Payment Fee','MODULE_ORDER_TOTAL_PAYMENTFEE_STATUS','true','Do you want to display the payment fee?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2017-01-13 11:37:59','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6848,'Tax Class','MODULE_ORDER_TOTAL_PAYMENTFEE_TAX_CLASS','0','Use the following tax class on the payment fee.','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2017-01-13 11:37:59','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(6849,'Sort Order','MODULE_ORDER_TOTAL_REFUND_SORT_ORDER','160','Sort order of display.','6',160,'2020-10-09 13:42:16','2020-10-09 13:42:16','','',8),(6850,'Display Amount Refund','MODULE_ORDER_TOTAL_REFUND_STATUS','true','Do you want to display the Amount Refund?','6',160,'0000-00-00 00:00:00','2020-10-09 13:42:16','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6851,'Allow Shipping Fee','MODULE_ORDER_TOTAL_SHIPPINGFEE_ALLOW_FEE','false','Do you want to allow shipping fees?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2017-01-13 11:37:45','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6852,'Attach Shipping Fee on Orders Made','MODULE_ORDER_TOTAL_SHIPPINGFEE_DESTINATION','both','Attach shipping fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2017-01-13 11:37:45','','tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',8),(6853,'Sort Order','MODULE_ORDER_TOTAL_SHIPPINGFEE_SORT_ORDER','70','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-01-13 11:37:45','','',8),(6854,'Display Shipping Fee','MODULE_ORDER_TOTAL_SHIPPINGFEE_STATUS','true','Do you want to display the shipping Fee?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2017-01-13 11:37:45','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6855,'Tax Class','MODULE_ORDER_TOTAL_SHIPPINGFEE_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2017-01-13 11:37:45','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(6856,'Provide Free Shipping For Orders Made','MODULE_ORDER_TOTAL_SHIPPING_DESTINATION','both','Provide free shipping for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',5,'0000-00-00 00:00:00','2016-11-16 13:51:20','','tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',8),(6857,'Allow Free Shipping','MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING','false','Do you want to allow free shipping?','BOX_CONFIGURATION_MODULE',3,'0000-00-00 00:00:00','2016-11-16 13:51:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6858,'Free Shipping For Orders Over','MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER','100','Provide free shipping for orders over the set amount.','BOX_CONFIGURATION_MODULE',4,'0000-00-00 00:00:00','2016-11-16 13:51:20','currencies->format','',8),(6859,'Limit shipping results sort mode','MODULE_ORDER_TOTAL_SHIPPING_LIMIT_RESULT_SORT','Cheapest first','','BOX_CONFIGURATION_MODULE',7,'0000-00-00 00:00:00','2019-03-27 14:56:48','','tep_cfg_select_option(array(\'Cheapest first\', \'Modules sort order\'), ',8),(6860,'Number of shipping results','MODULE_ORDER_TOTAL_SHIPPING_RESULT_COUNT','','Limit results (if empty - unlimited).','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2019-03-27 14:56:48','','',8),(6861,'Sort Order','MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER','50','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:51:20','','',8),(6862,'Display Shipping','MODULE_ORDER_TOTAL_SHIPPING_STATUS','true','Do you want to display the order shipping cost?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 13:51:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6863,'Sort Order','MODULE_ORDER_TOTAL_SUBTAX_SORT_ORDER','100','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-02-22 14:10:20','','',8),(6864,'Display Subtotal for taxation','MODULE_ORDER_TOTAL_SUBTAX_STATUS','true','Do you want to display the subtotal for taxation value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2017-02-22 14:10:20','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6865,'Sort Order','MODULE_ORDER_TOTAL_SUBTOTAL_SORT_ORDER','10','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:10:43','','',8),(6866,'Display Sub-Total','MODULE_ORDER_TOTAL_SUBTOTAL_STATUS','true','Do you want to display the order sub-total cost?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:01:29','2016-11-16 12:10:43','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6867,'Sort Order','MODULE_ORDER_TOTAL_TAX_SORT_ORDER','110','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:08:32','','',8),(6868,'Display Tax','MODULE_ORDER_TOTAL_TAX_STATUS','true','Do you want to display the order tax value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 12:08:32','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6871,'Sort Order','MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER','120','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:06:52','','',8),(6872,'Display Total','MODULE_ORDER_TOTAL_TOTAL_STATUS','true','Do you want to display the total order value?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-11-16 12:06:52','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(6873,'2CheckOut Merchant Notifications','MODULE_PAYMENT_2CHECKOUT_EMAIL_MERCHANT','True','Should 2CheckOut e-mail a receipt to the store owner?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6874,'2CheckOut Login/Store Number','MODULE_PAYMENT_2CHECKOUT_LOGIN','18157','Login/Store Number used for the 2CheckOut service','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','','',8),(6875,'2CheckOut Set Order Status','MODULE_PAYMENT_2CHECKOUT_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6876,'2CheckOut Sort order of display.','MODULE_PAYMENT_2CHECKOUT_SORT_ORDER','100','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-08 16:55:21','','',8),(6877,'Enable 2CheckOut Module','MODULE_PAYMENT_2CHECKOUT_STATUS','False','Do you want to accept 2CheckOut payments?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6878,'2CheckOut Transaction Mode','MODULE_PAYMENT_2CHECKOUT_TESTMODE','Test','Transaction mode used for the 2Checkout service','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-08 16:55:21','','tep_cfg_select_option(array(\'Test\', \'Production\'), ',8),(6879,'2CheckOut Payment Zone','MODULE_PAYMENT_2CHECKOUT_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-08 16:55:21','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6880,'Authorizenet Customer Notifications','MODULE_PAYMENT_AUTHORIZENET_EMAIL_CUSTOMER','False','Should Authorize.Net e-mail a receipt to the customer?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6881,'Authorizenet Login Username','MODULE_PAYMENT_AUTHORIZENET_LOGIN','testing','The login username used for the Authorize.net service','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','',8),(6882,'Authorizenet Transaction Method','MODULE_PAYMENT_AUTHORIZENET_METHOD','Credit Card','Transaction method used for processing orders','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','tep_cfg_select_option(array(\'Credit Card\', \'eCheck\'), ',8),(6883,'Authorizenet - Set Order Status','MODULE_PAYMENT_AUTHORIZENET_ORDER_STATUS_ID','0','Authorizenet - Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6884,'Authorizenet - Sort order of display.','MODULE_PAYMENT_AUTHORIZENET_SORT_ORDER','80','Authorizenet - Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:51:38','','',8),(6885,'Enable Authorize.net Module','MODULE_PAYMENT_AUTHORIZENET_STATUS','False','Do you want to accept Authorize.net payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:33','2016-04-11 15:51:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6886,'Authorizenet Transaction Mode','MODULE_PAYMENT_AUTHORIZENET_TESTMODE','Test','Transaction mode used for processing orders','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','tep_cfg_select_option(array(\'Test\', \'Production\'), ',8),(6887,'Authorizenet Transaction Key','MODULE_PAYMENT_AUTHORIZENET_TXNKEY','Test','Transaction Key used for encrypting TP data','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:51:38','','',8),(6888,'Authorizenet - Payment Zone','MODULE_PAYMENT_AUTHORIZENET_ZONE','0','Authorizenet - If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:51:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6889,'CASH Set Order Status','MODULE_PAYMENT_CASH_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-01-17 11:52:46','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6890,'CASH Sort order of display.','MODULE_PAYMENT_CASH_SORT_ORDER','60','Sort order of CASH display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:34:41','2018-01-17 11:52:46','','',8),(6891,'CASH Enable Cash Payment Module','MODULE_PAYMENT_CASH_STATUS','False','Do you want to accept Cash Payment?','BOX_CONFIGURATION_MODULE',1,'2018-03-22 13:24:29','2018-01-17 11:52:46','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6892,'CASH Payment Zone','MODULE_PAYMENT_CASH_ZONED','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2018-01-17 11:52:46','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6893,'CC Split Credit Card E-Mail Address','MODULE_PAYMENT_CC_EMAIL','','If an e-mail address is entered, the middle digits of the credit card number will be sent to the e-mail address (the outside digits are stored in the database with the middle digits censored)','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:49:38','','',8),(6894,'CC Set Order Status','MODULE_PAYMENT_CC_ORDER_STATUS_ID','0','Set the status of CC orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:49:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6895,'CC Sort order of display.','MODULE_PAYMENT_CC_SORT_ORDER','60','Sort order of CC display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:49:38','','',8),(6896,'CC Enable Credit Card Module','MODULE_PAYMENT_CC_STATUS','True','Do you want to accept credit card payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:31','2016-04-11 15:49:38','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6897,'CC Payment Zone','MODULE_PAYMENT_CC_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:49:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6898,'COD Set Order Status','MODULE_PAYMENT_COD_ORDER_STATUS_ID','100007','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-01-11 15:06:47','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6899,'COD Sort order of display.','MODULE_PAYMENT_COD_SORT_ORDER','40','Sort order of COD display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:17:01','2018-01-11 15:06:47','','',8),(6900,'COD Enable Cash On Delivery Module','MODULE_PAYMENT_COD_STATUS','True','Do you want to accept Cash On Delevery payments?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2018-01-11 15:06:47','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6901,'COD Payment Zone','MODULE_PAYMENT_COD_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2018-01-11 15:06:47','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6902,'EFSnet Transaction Method','MODULE_PAYMENT_EFSNET_METHOD','CreditCardCharge','Transaction method used for processing orders','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','','tep_cfg_select_option(array(\'CreditCardCharge\',\'CreditCardAuthorize\'), ',8),(6903,'EFSnet Set Order Status','MODULE_PAYMENT_EFSNET_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6904,'EFSnet Sort order of display.','MODULE_PAYMENT_EFSNET_SORT_ORDER','90','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:57:06','','',8),(6905,'Enable EFSnet Module','MODULE_PAYMENT_EFSNET_STATUS','False','Do you want to accept EFSNet payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:34','2016-04-11 15:57:06','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6906,'EFSnet Login Username','MODULE_PAYMENT_EFSNET_STOREID','testing','The StoreID used for the EFSNet service','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','','',8),(6907,'EFSnet Transaction Key','MODULE_PAYMENT_EFSNET_STOREKEY','Test','Store Key used for encrypting data','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','','',8),(6908,'EFSnet Transaction Mode','MODULE_PAYMENT_EFSNET_TESTMODE','Test','Transaction mode used for processing orders','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:57:06','','tep_cfg_select_option(array(\'Test\', \'Production\'), ',8),(6909,'EFSnet Payment Zone','MODULE_PAYMENT_EFSNET_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:57:06','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6910,'Free Charge Set Order Status','MODULE_PAYMENT_FREECHARGER_ORDER_STATUS_ID','3','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:50:23','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6911,'Free Charge Sort order of display.','MODULE_PAYMENT_FREECHARGER_SORT_ORDER','70','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:50:23','','',8),(6912,'Enable Free Charge Module','MODULE_PAYMENT_FREECHARGER_STATUS','False','Do you want to accept Free Charge payments?','BOX_CONFIGURATION_MODULE',1,'2016-04-12 14:50:32','2016-04-11 15:50:23','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6913,'Free Charge Payment Zone','MODULE_PAYMENT_FREECHARGER_ZONE','4','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:50:23','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6914,'GeoTrust Merchant ID','MODULE_PAYMENT_GEOTRUST_MERCHANT_ID','serial #','Merchant Serial # to use for the GEOTRUST QuickPayments service','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-02-05 17:19:45','','',8),(6915,'GeoTrust Set Order Status','MODULE_PAYMENT_GEOTRUST_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-02-05 17:19:45','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6916,'GeoTrust Sort order of display.','MODULE_PAYMENT_GEOTRUST_SORT_ORDER','40','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-02-05 17:19:45','','',8),(6917,'Enable GeoTrust QuickPayments Module','MODULE_PAYMENT_GEOTRUST_STATUS','False','Do you want to accept GeoTrust QuickPayments?','BOX_CONFIGURATION_MODULE',1,'2016-04-12 14:50:29','2016-02-05 17:19:45','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6918,'GeoTrust Payment Zone','MODULE_PAYMENT_GEOTRUST_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-02-05 17:19:45','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6919,'Installed Modules','MODULE_PAYMENT_INSTALLED','paypal_partner.php;sage_pay_server.php;stripe_checkout.php;cod.php;offline.php','List of payment module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: cc.php;cod.php;paypal.php)','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:17:01','2003-07-17 10:29:22','','',8),(6920,'Order Status','MODULE_PAYMENT_INVOICE_ORDER_STATUS_ID','1','Festlegung des Status für Bestellungen, welche mit dieser Zahlungsweise durchgeführt werden.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:46:07','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6921,'Reihenfolge der Anzeige','MODULE_PAYMENT_INVOICE_SORT_ORDER','50','Niedrigste wird zuerst angezeigt.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:46:07','','',8),(6922,'Rechnung','MODULE_PAYMENT_INVOICE_STATUS','False','Wollen Sie Zahlungen per Rechnung anbieten?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:30','2016-04-11 15:46:07','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6923,'Zone für diese Zahlungsweise','MODULE_PAYMENT_INVOICE_ZONE','3','Wenn Sie eine Zone auswählen, wird diese Zahlungsweise nur in dieser Zone angeboten.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:46:07','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6924,'Set Order Status','MODULE_PAYMENT_LIQPAY_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',4,'0000-00-00 00:00:00','2018-01-26 15:33:32','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6925,'Money Order Set Order Status','MODULE_PAYMENT_MONEYORDER_ORDER_STATUS_ID','1','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-04-11 15:48:09','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6926,'Money Order Make Payable to:','MODULE_PAYMENT_MONEYORDER_PAYTO','','Who should payments be made payable to?','BOX_CONFIGURATION_MODULE',1,'0000-00-00 00:00:00','2016-04-11 15:48:09','','',8),(6927,'Money Order Sort order of display.','MODULE_PAYMENT_MONEYORDER_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:48:09','','',8),(6928,'Enable Check/Money Order Module','MODULE_PAYMENT_MONEYORDER_STATUS','True','Do you want to accept Check/Money Order payments?','BOX_CONFIGURATION_MODULE',1,'2016-04-13 17:08:47','2016-04-11 15:48:09','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6929,'Money Order Payment Zone','MODULE_PAYMENT_MONEYORDER_ZONE','4','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2016-04-11 15:48:09','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6930,'OFFLINE Order Status','MODULE_PAYMENT_OFFLINE_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-03 11:25:11','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6931,'OFFLINE Sort order of display.','MODULE_PAYMENT_OFFLINE_SORT_ORDER','50','Sort order of OFFLINE display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:17:01','2017-04-03 11:25:11','','',8),(6932,'OFFLINE Enable Module','MODULE_PAYMENT_OFFLINE_STATUS','False','Do you want to accept OFFLINE payments?','BOX_CONFIGURATION_MODULE',1,'2018-01-12 09:59:49','2017-04-03 11:25:11','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6933,'OFFLINE Payment Zone','MODULE_PAYMENT_OFFLINE_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,'0000-00-00 00:00:00','2017-04-03 11:25:11','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6934,'PayPal IPN Add Shipping to Amount','MODULE_PAYMENT_PAYPALIPN_ADD_SHIPPING_TO_AMOUNT','False','Add shipping amount to order amount? (will set shipping amount to $0 in PayPal)','6',5,'0000-00-00 00:00:00','2021-11-16 13:52:41','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6935,'PayPal IPN Add Tax to Amount','MODULE_PAYMENT_PAYPALIPN_ADD_TAX_TO_AMOUNT','False','Add tax amount to order amount? (will set tax amount to $0 in PayPal)','6',5,'0000-00-00 00:00:00','2021-11-16 13:52:41','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6936,'PayPal IPN Allowed Currencies','MODULE_PAYMENT_PAYPALIPN_ALLOWED_CURRENCIES','GBP,EUR,USD','Allowed currencies in which customers can pay.<br>Allowed by PayPal: USD,EUR,GBP,CAD,JPY<br>Allowed in your shop: GBP,EUR,USD<br>To add more currencies to your shop go to Localization->Currencies.','6',9,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',8),(6937,'PayPal Transactions Cancel Order Status','MODULE_PAYMENT_PAYPALIPN_CANCEL_ORDER_STATUS_ID','5','','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6938,'or API Certificate','MODULE_PAYMENT_PAYPALIPN_CERTIFICATE','','The certificate to use for the PayPal API service.','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','','cfg_upload_file(',8),(6939,'API Application Client ID','MODULE_PAYMENT_PAYPALIPN_CLIENT_ID','','The Client ID of app','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',8),(6940,'PayPal IPN Use cURL','MODULE_PAYMENT_PAYPALIPN_CURL','False','Use cURL to communicate with PayPal?<br>cURL has been <b>DETECTED</b> in your system','6',4,'0000-00-00 00:00:00','2021-11-16 09:30:10','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6941,'PayPal IPN Debug Email','MODULE_PAYMENT_PAYPALIPN_DEBUG_EMAIL','','PayPal IPN Debug Email','6',15,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',8),(6942,'PayPal IPN Default Currency','MODULE_PAYMENT_PAYPALIPN_DEFAULT_CURRENCY','GBP','Default currency to use when customer try to pay in a NON allowed (because of PayPal or you) currency','6',10,'0000-00-00 00:00:00','2021-11-16 13:52:41','','tep_cfg_select_option(array (\n 0 => \'GBP\',\n 1 => \'EUR\',\n 2 => \'USD\',\n), ',8),(6943,'PayPal IPN ID','MODULE_PAYMENT_PAYPALIPN_ID','paypal.sandbox.business@holbi.co.uk','Your business ID at PayPal. Usually the email address you signed up with. You can create a free PayPal account at <a href=\"http://www.paypal.com/\" target=\"_blank\">http://www.paypal.com</a>.','6',2,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',8),(6944,'PayPal IPN Notify URL','MODULE_PAYMENT_PAYPALIPN_NOTIFY_URL','callback/paypal-notify','Exact location in which your callback/paypal-notify resides.','6',3,'0000-00-00 00:00:00','2021-11-16 13:52:41','','\\common\\modules\\orderPayment\\urlchecker(',8),(6945,'PayPal IPN Set Status Before Payment','MODULE_PAYMENT_PAYPALIPN_ORDER_BEFORE_PAYMENT_ID','1','Set the status of ordersbefore redirect to Gateway','6',14,'0000-00-00 00:00:00','2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6946,'PayPal IPN Set Order Status','MODULE_PAYMENT_PAYPALIPN_ORDER_STATUS_ID','100006','Set the status of orders made with this payment module to this value','6',14,'0000-00-00 00:00:00','2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6947,'API Password','MODULE_PAYMENT_PAYPALIPN_PASSWORD','','The password to use for the PayPal API service.','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',8),(6948,'Use API Signature','MODULE_PAYMENT_PAYPALIPN_SIGNATURE','','The signature to use for the PayPal API service.','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',8),(6949,'PayPal IPN Sort order of display.','MODULE_PAYMENT_PAYPALIPN_SORT_ORDER','80','Sort order of display. Lowest is displayed first.','6',12,'2021-11-16 13:52:41','2021-11-16 13:52:41','','',8),(6950,'Allow PayPal IPN','MODULE_PAYMENT_PAYPALIPN_STATUS','True','Do you want to accept PayPal IPN payments and notifications?','6',1,'0000-00-00 00:00:00','2021-11-16 13:52:41','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6951,'PayPal IPN Test Mode','MODULE_PAYMENT_PAYPALIPN_TEST_MODE','True','Run in TEST MODE? If so, you will be able to send TEST IPN from Admin->PayPal_IPN->Test_IPN, BUT you will not be able to receive real IPN\'s from PayPal.','6',11,'0000-00-00 00:00:00','2021-11-16 13:52:41','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6952,'PayPal IPN Update Stock Before Payment','MODULE_PAYMENT_PAYPALIPN_UPDATE_STOCK_BEFORE_PAYMENT','False','Should Products Stock be updated even when the payment is not yet COMPLETED?','6',6,'0000-00-00 00:00:00','2021-11-16 13:52:41','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6953,'API Username','MODULE_PAYMENT_PAYPALIPN_USERNAME','','The username to use for the PayPal API service.','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',8),(6954,'PayPal IPN Payment Zone','MODULE_PAYMENT_PAYPALIPN_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',13,'0000-00-00 00:00:00','2021-11-16 13:52:41','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6955,'API Application Client Secret Key','MODULE_PAYMENT_PPAYPALIPN_CLIENT_SECRET','','The Client Secret Key of app','6',0,'0000-00-00 00:00:00','2021-11-16 13:52:41','','',8),(6956,'Callback Password','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_CALLBACK_PASSWORD','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','',8),(6957,'Debug E-Mail Address','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_DEBUG_EMAIL','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','',8),(6958,'Installation ID','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_INSTALLATION_ID','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','',8),(6959,'MD5 Password','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_MD5_PASSWORD','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','',8),(6960,'Set Order Status','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_ORDER_STATUS_ID','100006','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6961,'Set Preparing Order Status','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_PREPARE_ORDER_STATUS_ID','1','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6962,'Signaturefields','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_SIGNATUREFIELDS','--none--','Select Signaturefields. Please copy and past this value to worldpay: <b><span id=\"signature\"></span></b>','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:14','','select_multioption(array(\'amount\',\'currency\',\'cartId\'), ',8),(6963,'Sort order of display.','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_SORT_ORDER','20','','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:34:41','2017-04-08 14:31:29','','',8),(6964,'Enable WorldPay Hosted Payment Pages','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_STATUS','False','','BOX_CONFIGURATION_MODULE',0,'2018-01-11 16:18:09','2017-04-08 14:31:29','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6965,'Test Mode','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TESTMODE','True','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6966,'Transactions Order Status Level','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TRANSACTIONS_ORDER_STATUS_ID','1','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6967,'Transaction Method','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TRANSACTION_METHOD','Capture','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','','tep_cfg_select_option(array(\'Pre-Authorization\', \'Capture\'), ',8),(6968,'Payment Zone','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_ZONE','0','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-04-08 14:31:29','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6969,'Skip 3D secure amount','MODULE_PAYMENT_SAGE_PAY_3DS_SKIP','','Skip 3D secure verification when paid by token on orders below','6',100,'0000-00-00 00:00:00','2021-11-16 09:33:25','','',8),(6970,'Account login','MODULE_PAYMENT_SAGE_PAY_SERVER_ACCOUNT','','Account login to get transaction details','6',0,'0000-00-00 00:00:00','2021-11-16 09:33:25','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',8),(6971,'Account Password','MODULE_PAYMENT_SAGE_PAY_SERVER_ACCOUNT_PASSWORD','','Account password to get transaction details','6',0,'0000-00-00 00:00:00','2021-11-16 09:33:25','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',8),(6972,'cURL Program Location','MODULE_PAYMENT_SAGE_PAY_SERVER_CURL','/usr/bin/curl','The location to the cURL program application.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:11:50','','',8),(6973,'Set Order Status','MODULE_PAYMENT_SAGE_PAY_SERVER_ORDER_STATUS_ID','1','Set the status of orders made with this payment module to this value','6',0,'0000-00-00 00:00:00','2021-11-16 09:33:25','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6974,'Profile Payment Page','MODULE_PAYMENT_SAGE_PAY_SERVER_PROFILE_PAGE','Normal','Profile page to use for the payment page.','6',0,'0000-00-00 00:00:00','2021-11-16 09:33:25','','tep_cfg_select_option(array(\'Normal\', \'Low\'), ',8),(6975,'Sort order of display.','MODULE_PAYMENT_SAGE_PAY_SERVER_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:17:01','2021-11-16 09:33:25','','',8),(6976,'Enable Sage Pay Server Module','MODULE_PAYMENT_SAGE_PAY_SERVER_STATUS','True','Do you want to accept Sage Pay Server payments?','6',0,'2022-06-24 17:50:57','2021-11-16 09:33:25','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6977,'T3M verification','MODULE_PAYMENT_SAGE_PAY_SERVER_T3M_VERIFICATION','Info','Info - ignore if not available instantly, Optional - check for updates for up to 3 days, required - do not accept transaction if none t3m info available','6',0,'0000-00-00 00:00:00','2021-11-16 09:33:25','','tep_cfg_select_option(array(\'Info\', \'Optional\', \'Required\'), ',8),(6978,'Transaction Method','MODULE_PAYMENT_SAGE_PAY_SERVER_TRANSACTION_METHOD','Payment','The processing method to use for each transaction.','6',0,'0000-00-00 00:00:00','2021-11-16 09:33:25','','tep_cfg_select_option(array(\'Authenticate\', \'Deferred\', \'Payment\'), ',8),(6979,'Transaction Server','MODULE_PAYMENT_SAGE_PAY_SERVER_TRANSACTION_SERVER','Test','Perform transactions on the production server or on the testing server.','6',0,'0000-00-00 00:00:00','2021-11-16 09:33:25','','tep_cfg_select_option(array(\'Live\', \'Test\', \'Simulator\'), ',8),(6980,'Allow tokens','MODULE_PAYMENT_SAGE_PAY_SERVER_USE_TOKENS','False','Allow to save tokens.','6',0,'0000-00-00 00:00:00','2021-11-16 09:33:25','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6981,'Vendor Login Name','MODULE_PAYMENT_SAGE_PAY_SERVER_VENDOR_LOGIN_NAME','protx','The vendor login name to connect to the gateway with.','6',0,'0000-00-00 00:00:00','2021-11-16 09:33:25','','',8),(6982,'Payment Zone','MODULE_PAYMENT_SAGE_PAY_SERVER_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',2,'0000-00-00 00:00:00','2021-11-16 09:33:25','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6983,'Set Order Status Cancelled Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_CANCELLED_ORDER_STATUS_ID','5','Set the status of orders cancelled','6',0,'0000-00-00 00:00:00','2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6984,'Set Order Status Completed Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_COMPLETED_ORDER_STATUS_ID','100006','Set the status of orders completed successfully','6',0,'0000-00-00 00:00:00','2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6985,'Debug E-Mail Address','MODULE_PAYMENT_STRIPE_CHECKOUT_DEBUG_EMAIL','','All parameters of an invalid transaction will be sent to this email address.','6',0,'0000-00-00 00:00:00','2021-11-15 09:11:10','','',8),(6986,'Set Order Status Before Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_ORDER_STATUS_ID','1','Set the status of orders before redirect to Gateway','6',0,'0000-00-00 00:00:00','2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',8),(6987,'Publishable API Key','MODULE_PAYMENT_STRIPE_CHECKOUT_PUBLISHABLE_KEY','pk_test_51L5tlzLrdFbMtgAWVb82LINlf6po2qfbkRmjCc3o02yH88tlzoCC96f8EnpUmVGgQR104lCdO4WdiqmEpzefgrbE00YzVLdKk0','The Stripe account publishable API key to use.','6',0,'0000-00-00 00:00:00','2021-11-15 09:11:10','','',8),(6988,'Secret API Key','MODULE_PAYMENT_STRIPE_CHECKOUT_SECRET_KEY','npß/ôÂ K¿þïòa8703ac65ffa0cfa01475ce89e480a0417936d94cdf4be647f96cc7806263a87±z\ZoªDxÜI+6ólëfCÞ¹À£=ü6ç.¾Àµ¨N;¼\nTiÆÏ+Z¬uêzÐ*m¥ßm1\rs?èq<A7¢9Ô*\'ðzùdsìVRöÕp¤Õxºîê>®ÚºeÌÝ#f¡Æµ©n£ÿGQèÇNñç´¿','The Stripe account secret API key to use with the publishable key.','6',0,'0000-00-00 00:00:00','2021-11-15 09:11:10','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',8),(6989,'Sort order of display.','MODULE_PAYMENT_STRIPE_CHECKOUT_SORT_ORDER','30','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:17:01','2021-11-15 09:11:10','','',8),(6990,'Enable Stripe Module','MODULE_PAYMENT_STRIPE_CHECKOUT_STATUS','True','Do you want to accept Stripe payments?','6',0,'0000-00-00 00:00:00','2021-11-15 09:11:10','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6991,'Update Stock Before Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_UPDATE_STOCK_BEFORE_PAYMENT','False','Should Products Stock be updated even when the payment is not yet COMPLETED?','6',0,'0000-00-00 00:00:00','2021-11-15 09:11:10','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(6992,'Webhook Secret','MODULE_PAYMENT_STRIPE_CHECKOUT_WEBHOOK_SECRET','whsec_HExwr6qITymk3PEKFcS9LaaTkyzrKwVw','The Stripe account webhook signing secret.','6',0,'0000-00-00 00:00:00','2021-11-15 09:11:10','','',8),(6993,'Payment Zone','MODULE_PAYMENT_STRIPE_CHECKOUT_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',0,'0000-00-00 00:00:00','2021-11-15 09:11:10','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(6994,'FedEx Account Number','MODULE_SHIPPING_FEDEX_ACT_NUM','','Enter FedEx Account Number','6',4,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(6995,'First line of street address','MODULE_SHIPPING_FEDEX_ADDRESS_1','','Enter the first line of your ship-from street address, required','6',7,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(6996,'Second line of street address','MODULE_SHIPPING_FEDEX_ADDRESS_2','','Enter the second line of your ship-from street address, leave blank if you do not need to specify a second line','6',8,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(6997,'City name','MODULE_SHIPPING_FEDEX_CITY','','Enter the city name for the ship-from street address, required','6',9,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(6998,'Country','MODULE_SHIPPING_FEDEX_COUNTRY','222','Select the postal country for the ship-from address, required','6',11,'0000-00-00 00:00:00','2021-11-15 09:14:28','\\backend\\models\\Configuration::tep_get_country_name','tep_cfg_pull_down_country_list(',8),(6999,'Currency Exchange Rates Conversion','MODULE_SHIPPING_FEDEX_CURRENCY','1','Set your currency exchange rate here if needed. Note that this data must be a number (integer like 32 or with a floating point like 32.48) and will have to be updated by you regularly to match exchange fluctuations.','6',14,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(7000,'Delivery Date Management','MODULE_SHIPPING_FEDEX_DATE_SETTING','Use default','Preferred delivery date rules','6',80,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',8),(7001,'Delivery Date ownership settings','MODULE_SHIPPING_FEDEX_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',8),(7002,'Domestic NBD Handling Fee','MODULE_SHIPPING_FEDEX_DOMESTIC_HANDLING_FEE','','Add a domestic handling fee or leave blank (example: 15 or 15%)','6',20,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(7003,'Enable Domestic NBD','MODULE_SHIPPING_FEDEX_DOMESTIC_NEXT_DAY','true','Enable FedEx Domestic Next Business Day','6',16,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(7004,'Drop off type','MODULE_SHIPPING_FEDEX_DROPOFF','REGULAR_PICKUP','Dropoff type?','6',15,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'REGULAR_PICKUP\',\'REQUEST_COURIER\',\'DROP_BOX\',\'BUSINESS_SERVICE_CENTER\',\'STATION\'), ',8),(7005,'Insurance?','MODULE_SHIPPING_FEDEX_INSURE','-1','Insure packages over what amount? (set to -1 to disable)','6',22,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(7006,'Enable International Economy','MODULE_SHIPPING_FEDEX_INTERNATIONAL_ECONOMY','true','Enable FedEx Express International Economy','6',18,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(7007,'Enable International Priority','MODULE_SHIPPING_FEDEX_INTERNATIONAL_PRIORITY','true','Enable FedEx Express International Priority','6',17,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'true\', \'false\'), ',8),(7008,'International Express Handling Fee','MODULE_SHIPPING_FEDEX_INT_EXPRESS_HANDLING_FEE','','Add an international handling fee or leave blank (example: 15 or 15%)','6',21,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(7009,'FedEx Web Services Key','MODULE_SHIPPING_FEDEX_KEY','','Enter FedEx Web Services Key','6',2,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(7010,'FedEx Meter Number','MODULE_SHIPPING_FEDEX_METER_NUM','','Enter FedEx Meter Number','6',5,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(7011,'Web Service Mode','MODULE_SHIPPING_FEDEX_MODE','Test','Web Service Mode','6',2,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'Test\', \'Production\'), ',8),(7012,'FedEx Packaging Type','MODULE_SHIPPING_FEDEX_PACKAGING_TYPE','YOUR_PACKAGING','FedEx Packaging Type','6',22,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'YOUR_PACKAGING\',\'FEDEX_10KG_BOX\', \'FEDEX_25KG_BOX\', \'FEDEX_BOX\', \'FEDEX_ENVELOPE\', \'FEDEX_EXTRA_LARGE_BOX\', \'FEDEX_LARGE_BOX\', \'FEDEX_MEDIUM_BOX\', \'FEDEX_PAK\', \'FEDEX_SMALL_BOX\', \'FEDEX_TUBE\'), ',8),(7013,'Phone number','MODULE_SHIPPING_FEDEX_PHONE','','Enter a contact phone number for your company, required','6',12,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(7014,'Postal code','MODULE_SHIPPING_FEDEX_POSTAL','','Enter the postal code for the ship-from street address, required','6',11,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(7015,'FedEx Web Services Password','MODULE_SHIPPING_FEDEX_PWD','','Enter FedEx Web Services Password','6',3,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(7016,'FedEx Rates','MODULE_SHIPPING_FEDEX_RATES','LIST','FedEx Rates','6',22,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'LIST\',\'ACCOUNT\'), ',8),(7017,'Shipping Delay','MODULE_SHIPPING_FEDEX_SHIPPING_DAYS_DELAY','1','How many days from when an order is placed to when you ship it (Decimals are allowed). Arrival date estimations are based on this value.','6',13,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(7018,'Signature Option','MODULE_SHIPPING_FEDEX_SIGNATURE_OPTION','-1','Require a signature on order subtotal greater than or equal to (set to -1 to disable):','6',23,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(7019,'Signature Option Type','MODULE_SHIPPING_FEDEX_SIGNATURE_OPTION_TYPE','SERVICE_DEFAULT','Select Signature Option Type','6',23,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'ADULT\', \'DIRECT\', \'INDIRECT\', \'NO_SIGNATURE_REQUIRED\', \'SERVICE_DEFAULT\'), ',8),(7020,'Shipping Sort Order','MODULE_SHIPPING_FEDEX_SORT_ORDER','140','Sort order of display.','6',100,'2021-11-15 09:14:28','2021-11-15 09:14:28','','',8),(7021,'State or Province name','MODULE_SHIPPING_FEDEX_STATE','','Enter the 2 letter state or province name for the ship-from street address, required for Canada and US','6',10,'0000-00-00 00:00:00','2021-11-15 09:14:28','','',8),(7022,'Enable Collect Shipping','MODULE_SHIPPING_FEDEX_STATUS','False','Do you want to offer collect shipping?','6',0,'2021-11-15 09:14:43','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7023,'Shipping Tax Class','MODULE_SHIPPING_FEDEX_TAX_CLASS','0','Use the following tax class on the shipping fee.','6',0,'0000-00-00 00:00:00','2021-11-15 09:14:28','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(7024,'Weight Units','MODULE_SHIPPING_FEDEX_WEIGHT','KG','Weight Units:','6',6,'0000-00-00 00:00:00','2021-11-15 09:14:28','','tep_cfg_select_option(array(\'LB\', \'KG\'), ',8),(7025,'Shipping Shipping Zone','MODULE_SHIPPING_FEDEX_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','6',0,'0000-00-00 00:00:00','2021-11-15 09:14:28','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(7026,'Flat Shipping Cost','MODULE_SHIPPING_FLAT_COST','5','The shipping cost for all orders using this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:03:53','','',8),(7027,'Delivery Date Management','MODULE_SHIPPING_FLAT_DATE_SETTING','Use default','Preferred delivery date rules','6',80,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',8),(7028,'Delivery Date ownership settings','MODULE_SHIPPING_FLAT_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',8),(7029,'Flat Sort Order','MODULE_SHIPPING_FLAT_SORT_ORDER','10','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 14:03:53','','',8),(7030,'Enable Flat Shipping','MODULE_SHIPPING_FLAT_STATUS','True','Do you want to offer flat rate shipping?','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:36:10','2016-11-16 14:03:53','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7031,'Flat Tax Class','MODULE_SHIPPING_FLAT_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:03:53','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(7032,'Flat Shipping Zone','MODULE_SHIPPING_FLAT_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 14:03:53','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(7033,'Free Shipping Cost','MODULE_SHIPPING_FREESHIPPER_COST','0.00','What is the Shipping cost? The Handling fee will also be added.','BOX_CONFIGURATION_MODULE',6,'0000-00-00 00:00:00','2016-11-16 13:27:21','','',8),(7034,'Delivery Date Management','MODULE_SHIPPING_FREESHIPPER_DATE_SETTING','Use default','Preferred delivery date rules','6',80,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',8),(7035,'Delivery Date ownership settings','MODULE_SHIPPING_FREESHIPPER_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',8),(7036,'FREESHIPPER Sort Order','MODULE_SHIPPING_FREESHIPPER_SORT_ORDER','30','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:27:21','','',8),(7037,'Enable Free Shipping','MODULE_SHIPPING_FREESHIPPER_STATUS','False','Do you want to offer Free shipping?','BOX_CONFIGURATION_MODULE',5,'2017-07-19 15:13:02','2016-11-16 13:27:21','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7038,'FREESHIPPER Tax Class','MODULE_SHIPPING_FREESHIPPER_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:27:21','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(7039,'FREESHIPPER Shipping Zone','MODULE_SHIPPING_FREESHIPPER_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:27:21','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(7040,'Installed Modules','MODULE_SHIPPING_INSTALLED','flat.php;freeshipper.php;zonetable.php;item.php;percent.php;table.php;zones.php','List of shipping module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ups.php;flat.php;item.php)','BOX_CONFIGURATION_MODULE',0,'2022-06-24 14:32:29','2003-07-17 10:29:22','','',8),(7041,'Item Shipping Shipping Cost','MODULE_SHIPPING_ITEM_COST','0','The shipping cost will be multiplied by the number of items in an order that uses this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:59:56','','',8),(7042,'Delivery Date Management','MODULE_SHIPPING_ITEM_DATE_SETTING','Use default','Preferred delivery date rules','6',80,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',8),(7043,'Delivery Date ownership settings','MODULE_SHIPPING_ITEM_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',8),(7044,'Item Shipping Handling Fee','MODULE_SHIPPING_ITEM_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:59:56','','',8),(7045,'Item Shipping Sort Order','MODULE_SHIPPING_ITEM_SORT_ORDER','50','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:59:56','','',8),(7046,'Enable Item Shipping','MODULE_SHIPPING_ITEM_STATUS','False','Do you want to offer per item rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-01-11 16:18:17','2016-11-16 13:59:56','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7047,'Item Shipping Tax Class','MODULE_SHIPPING_ITEM_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:59:56','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(7048,'Item Shipping Shipping Zone','MODULE_SHIPPING_ITEM_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:59:56','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(7049,'NovaPoshta ApiKey','MODULE_SHIPPING_NP_APIKEY','dd791bafa70224a996085024e0687e8c','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-02-16 15:24:13','','',8),(7050,'NovaPoshta ApiKey','MODULE_SHIPPING_NP_API_KEY','','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2019-10-22 13:18:12','','',8),(7051,'NovaPoshta Shipping Shipping Cost','MODULE_SHIPPING_NP_COST','40','','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-02-16 15:24:13','','',8),(7052,'Delivery Date Management','MODULE_SHIPPING_NP_DATE_SETTING','Use default','Preferred delivery date rules','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',8),(7053,'Delivery Date ownership settings','MODULE_SHIPPING_NP_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',8),(7054,'Preferred Shipping Method','MODULE_SHIPPING_NP_PREFERRED_METHOD','WarehouseToWarehouse','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2019-10-22 13:18:12','','tep_cfg_select_option(array(\'WarehouseToWarehouse\', \'WarehouseToDoors\'), ',8),(7055,'NP Shipping Sort Order','MODULE_SHIPPING_NP_SORT_ORDER','130','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2018-02-16 15:24:13','2018-02-16 15:24:13','','',8),(7056,'Enable Item Shipping','MODULE_SHIPPING_NP_STATUS','False','Do you want to offer NovaPoshta shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-22 13:24:50','2018-02-16 15:24:13','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7057,'Tracking Url','MODULE_SHIPPING_NP_TRACKING_NUMBER_URL','https://novaposhta.ua/tracking/?newtracking=1&cargo_number=','Url for tracking cargo','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2019-10-22 13:18:12','','',8),(7058,'Enable NP Tracking','MODULE_SHIPPING_NP_TRACKING_STATUS','True','Do you want to enable NP tracking?','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2018-10-02 09:43:28','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7059,'Delivery Date Management','MODULE_SHIPPING_PERCENT_DATE_SETTING','Use default','Preferred delivery date rules','6',80,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',8),(7060,'Delivery Date ownership settings','MODULE_SHIPPING_PERCENT_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',8),(7061,'Percentage A Flat Rate of','MODULE_SHIPPING_PERCENT_FLAT_USE','6.50','A Flat Rate used for all orders.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','','',8),(7062,'Percentage A Flat Rate for orders under','MODULE_SHIPPING_PERCENT_LESS_THEN','34.75','A Flat Rate for all orders that are under the amount shown.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','','',8),(7063,'Percentage Rate','MODULE_SHIPPING_PERCENT_RATE','.18','The Percentage Rate all .01 to .99 for all orders using this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','','',8),(7064,'Percentage Sort Order','MODULE_SHIPPING_PERCENT_SORT_ORDER','60','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:52:35','','',8),(7065,'Enable Percent Shipping','MODULE_SHIPPING_PERCENT_STATUS','True','Do you want to offer percent rate shipping?','BOX_CONFIGURATION_MODULE',0,'2022-06-24 17:02:42','2016-11-16 13:52:35','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7066,'Percentage from Order incl. Tax','MODULE_SHIPPING_PERCENT_SUBTOTAL_INCL_TAX','True','Calculate order amount incl. tax or excl. tax?','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7067,'Percentage Tax Class','MODULE_SHIPPING_PERCENT_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(7068,'Percentage Shipping Zone','MODULE_SHIPPING_PERCENT_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:52:35','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(7069,'Table Method Shipping Table','MODULE_SHIPPING_TABLE_COST','25:8.50,50:5.50,10000:0.00','The shipping cost is based on the total cost or weight of items. Example: 25:8.50,50:5.50,etc.. Up to 25 charge 8.50, from there to 50 charge 5.50, etc','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','','',8),(7070,'Delivery Date Management','MODULE_SHIPPING_TABLE_DATE_SETTING','Use default','Preferred delivery date rules','6',80,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',8),(7071,'Delivery Date ownership settings','MODULE_SHIPPING_TABLE_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',8),(7072,'Table Method Handling Fee','MODULE_SHIPPING_TABLE_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','','',8),(7073,'Table Method','MODULE_SHIPPING_TABLE_MODE','weight','The shipping cost is based on the order total or the total weight of the items ordered.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','','tep_cfg_select_option(array(\'weight\', \'price\'), ',8),(7074,'Table Method Sort Order','MODULE_SHIPPING_TABLE_SORT_ORDER','70','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-24 17:14:14','','',8),(7075,'Enable Table Method','MODULE_SHIPPING_TABLE_STATUS','False','Do you want to offer table rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-02-22 16:42:12','2016-11-24 17:14:14','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7076,'Table Method Tax Class','MODULE_SHIPPING_TABLE_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(7077,'Table Method Shipping Zone','MODULE_SHIPPING_TABLE_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-24 17:14:14','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(7078,'Delivery Date Management','MODULE_SHIPPING_UPS_DATE_SETTING','Use default','Preferred delivery date rules','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',8),(7079,'Delivery Date ownership settings','MODULE_SHIPPING_UPS_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',8),(7080,'UPS Handling Fee','MODULE_SHIPPING_UPS_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','','',8),(7081,'UPS Packaging?','MODULE_SHIPPING_UPS_PACKAGE','CP','CP - Your Packaging, ULE - UPS Letter, UT - UPS Tube, UBE - UPS Express Box','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','','',8),(7082,'UPS Pickup Method','MODULE_SHIPPING_UPS_PICKUP','CC','How do you give packages to UPS? CC - Customer Counter, RDP - Daily Pickup, OTP - One Time Pickup, LC - Letter Center, OCA - On Call Air','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','','',8),(7083,'UPS Residential Delivery?','MODULE_SHIPPING_UPS_RES','RES','Quote for Residential (RES) or Commercial Delivery (COM)','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','','',8),(7084,'UPS Sort order of display.','MODULE_SHIPPING_UPS_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:01:59','','',8),(7085,'Enable UPS Shipping','MODULE_SHIPPING_UPS_STATUS','False','Do you want to offer UPS shipping?','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:46:54','2016-11-16 13:01:59','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7086,'UPS Tax Class','MODULE_SHIPPING_UPS_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(7087,'UPS Shipping Methods','MODULE_SHIPPING_UPS_TYPES','1DM, 1DML, 1DA, 1DAL, 1DAPI, 1DP, 1DPL, 2DM, 2DML, 2DA, 2DAL, 3DS, GND, STD, XPR, XPRL, XDM, XDML, XPD','Select the UPS services to be offered.','BOX_CONFIGURATION_MODULE',13,'0000-00-00 00:00:00','2016-11-16 13:01:59','','tep_cfg_select_multioption(array(\'1DM\',\'1DML\', \'1DA\', \'1DAL\', \'1DAPI\', \'1DP\', \'1DPL\', \'2DM\', \'2DML\', \'2DA\', \'2DAL\', \'3DS\',\'GND\', \'STD\', \'XPR\', \'XPRL\', \'XDM\', \'XDML\', \'XPD\'), ',8),(7088,'UPS Shipping Zone','MODULE_SHIPPING_UPS_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:01:59','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(7089,'Delivery Date Management','MODULE_SHIPPING_USPS_DATE_SETTING','Use default','Preferred delivery date rules','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',8),(7090,'Delivery Date ownership settings','MODULE_SHIPPING_USPS_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',8),(7091,'Handling Fee','MODULE_SHIPPING_USPS_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','','',8),(7092,'USPS Options','MODULE_SHIPPING_USPS_OPTIONS','Display weight, Display transit time','Select from the following the USPS options.','BOX_CONFIGURATION_MODULE',16,'0000-00-00 00:00:00','2016-11-16 13:31:02','','tep_cfg_select_multioption(array(\'Display weight\', \'Display transit time\'), ',8),(7093,'Enter the USPS Password','MODULE_SHIPPING_USPS_PASSWORD','','See USERID, above.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','','',8),(7094,'Which server to use','MODULE_SHIPPING_USPS_SERVER','test','An account at USPS is needed to use the Production server','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','','tep_cfg_select_option(array(\'test\', \'production\'), ',8),(7095,'Sort Order','MODULE_SHIPPING_USPS_SORT_ORDER','80','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2016-11-16 13:31:02','2016-11-16 13:31:02','','',8),(7096,'Enable USPS Shipping','MODULE_SHIPPING_USPS_STATUS','False','Do you want to offer USPS shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-21 16:18:57','2016-11-16 13:31:02','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7097,'Tax Class','MODULE_SHIPPING_USPS_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(7098,'Domestic Shipping Methods','MODULE_SHIPPING_USPS_TYPES','First Class, Priority Mail, Priority Mail Express','Select the domestic services to be offered:','BOX_CONFIGURATION_MODULE',14,'0000-00-00 00:00:00','2016-11-16 13:31:02','','tep_cfg_select_multioption(array(\'First Class\', \'Priority Mail\', \'Priority Mail Express\'),',8),(7099,'Int\'l Shipping Methods','MODULE_SHIPPING_USPS_TYPES_INTL','Priority Mail Express International, Priority Mail International','Select the international services to be offered:','BOX_CONFIGURATION_MODULE',15,'0000-00-00 00:00:00','2016-11-16 13:31:02','','tep_cfg_select_multioption(array(\'Priority Mail Express International\', \'Priority Mail International\'),',8),(7100,'Enter the USPS User ID','MODULE_SHIPPING_USPS_USERID','','Enter the USPS USERID assigned to you.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','','',8),(7101,'Shipping Zone','MODULE_SHIPPING_USPS_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:31:02','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',8),(7102,'Delivery Date Management','MODULE_SHIPPING_ZONESPERITEM_DATE_SETTING','Use default','Preferred delivery date rules','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',8),(7103,'Delivery Date ownership settings','MODULE_SHIPPING_ZONESPERITEM_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',8),(7104,'Zone 1 Geo Zone','MODULE_SHIPPING_ZONESPERITEM_GEO_ZONE_1','0','Select Geo Zone of this Zone 1.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',8),(7105,'Number of Zones','MODULE_SHIPPING_ZONESPERITEM_NUMBER_OF_ZONES','1','Number of zones needed.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:38:29','','',8),(7106,'Zone 1 Premium Additional Item Charge','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_ADDITIONAL_ITEM_CHARGE_1','0.00','Premium Additional Item Charge for this shipping zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',8),(7107,'Zone 1 Premium Free Delivery Amount','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_FREE_DELIVERY_AMOUNT_1','20.00','Amount of subtotal for free premium delivery for this shipping zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',8),(7108,'Zone 1 Premium Initial Item Charge','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_INITIAL_ITEM_CHARGE_1','4.50','Premium Initial Item Charge for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',8),(7109,'Zones Per Item Sort Order','MODULE_SHIPPING_ZONESPERITEM_SORT_ORDER','100','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-12-21 15:38:29','','',8),(7110,'Zone 1 Standard Additional Item Charge','MODULE_SHIPPING_ZONESPERITEM_STANDARD_ADDITIONAL_ITEM_CHARGE_1','0.50','Standard Additional Item Charge for this shipping zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',8),(7111,'Zone 1 Standard Free Delivery Amount','MODULE_SHIPPING_ZONESPERITEM_STANDARD_FREE_DELIVERY_AMOUNT_1','20.00','Amount of subtotal for free standard delivery for this shipping zone.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',8),(7112,'Zone 1 Standard Initial Item Charge','MODULE_SHIPPING_ZONESPERITEM_STANDARD_INITIAL_ITEM_CHARGE_1','2.50','Standard Initial Item Charge for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:58:18','','',8),(7113,'Enable Zones Per Item Method','MODULE_SHIPPING_ZONESPERITEM_STATUS','False','Do you want to offer zone rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-14 15:08:27','2016-12-21 15:38:29','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7114,'Zones Per Item Tax Class','MODULE_SHIPPING_ZONESPERITEM_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-12-21 15:38:29','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(7115,'Zone 1 Shipping Table','MODULE_SHIPPING_ZONES_COST_1','3:8.50,7:10.50,99:20.00','Shipping rates to Zone 1 destinations based on a group of maximum order weights. Example: 3:8.50,7:10.50,... Weights less than or equal to 3 would cost 8.50 for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:47:33','','',8),(7116,'Zone 1 Countries','MODULE_SHIPPING_ZONES_COUNTRIES_1','US,CA','Comma separated list of two character ISO country codes that are part of Zone 1.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:47:33','','',8),(7117,'Delivery Date Management','MODULE_SHIPPING_ZONES_DATE_SETTING','Use default','Preferred delivery date rules','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',8),(7118,'Delivery Date ownership settings','MODULE_SHIPPING_ZONES_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',8),(7119,'Zone 1 Handling Fee','MODULE_SHIPPING_ZONES_HANDLING_1','0','Handling Fee for this shipping zone','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:47:33','','',8),(7120,'Zones Sort Order','MODULE_SHIPPING_ZONES_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:47:33','','',8),(7121,'Zones Enable Zones Method','MODULE_SHIPPING_ZONES_STATUS','False','Do you want to offer zone rate shipping?','BOX_CONFIGURATION_MODULE',0,'2017-05-29 13:48:31','2016-11-16 13:47:33','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7122,'Zones Tax Class','MODULE_SHIPPING_ZONES_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2016-11-16 13:47:33','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(7123,'If no rates found allow complete order','MODULE_SHIPPING_ZONE_ALLOW_ERROR_PASS','False','Display \"please call us for a quote\" and allow complete order.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2019-10-22 13:18:12','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7124,'Delivery Date Management','MODULE_SHIPPING_ZONE_TABLE_DATE_SETTING','Use default','Preferred delivery date rules','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',8),(7125,'Delivery Date ownership settings','MODULE_SHIPPING_ZONE_TABLE_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,'0000-00-00 00:00:00','2021-11-03 17:01:34','','tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',8),(7126,'Handling Fee','MODULE_SHIPPING_ZONE_TABLE_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-01-05 14:27:17','','',8),(7127,'Sort Order','MODULE_SHIPPING_ZONE_TABLE_SORT_ORDER','40','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2017-01-05 14:27:17','','',8),(7128,'Enable Table Method','MODULE_SHIPPING_ZONE_TABLE_STATUS','True','Do you want to offer Zone Table rate shipping?','BOX_CONFIGURATION_MODULE',0,'2022-06-24 17:00:38','2017-01-05 14:27:17','','tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7129,'Tax Class','MODULE_SHIPPING_ZONE_TABLE_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,'0000-00-00 00:00:00','2017-01-05 14:27:17','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',8),(7130,'Public API key','TRUSTPILOT_API_KEY','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',8),(7131,'Business password','TRUSTPILOT_API_PASSWORD','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',8),(7132,'Private API secret','TRUSTPILOT_API_SECRET','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',8),(7133,'Business username','TRUSTPILOT_API_USERNAME','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',8),(7134,'BCC Trustpilot email','TRUSTPILOT_BCC_EMAIL','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',8),(7135,'Business Unit Id','TRUSTPILOT_BUSINESS_UNIT_ID','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-12 17:42:38','','',8),(7136,'Select integration','TRUSTPILOT_CONNECT_VIA','bccMail','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','tep_cfg_select_option(array(\'bccMail\', \'API\'),',8),(7137,'Delay invite send (days)','TRUSTPILOT_INVITE_DELAY','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',8),(7138,'Filter orders by','TRUSTPILOT_INVITE_ORDER_AMOUNT_BY','ot_total','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','tep_cfg_select_option(array(\'ot_subtotal\', \'ot_total\'),',8),(7139,'Filter orders by amount, from','TRUSTPILOT_INVITE_ORDER_AMOUNT_FROM','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',8),(7140,'Filter orders by amount, not above','TRUSTPILOT_INVITE_ORDER_AMOUNT_TO','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',8),(7141,'Redirect URL','TRUSTPILOT_REDIRECT_URI','https://uk.trustpilot.com','https://www.trustpilot.com','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',8),(7142,'Sender Email','TRUSTPILOT_SENDER_EMAIL','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',8),(7143,'Sender Name','TRUSTPILOT_SENDER_NAME','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',8),(7144,'Status','TRUSTPILOT_STATUS','Disabled','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','tep_cfg_select_option(array(\'Disabled\', \'Enabled\'),',8),(7145,'Verify meta tag','TRUSTPILOT_VERIFY_META_TAG','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',8),(7156,'Save order before payment','MODULE_PAYMENT_SAGE_PAY_SERVER_ORDER_BEFORE_PAYMENT','False','Save order before redirect to payment gateway','6',0,'2022-07-18 14:31:07','2021-12-24 10:27:07',NULL,'tep_cfg_select_option(array(\'True\', \'False\', \'Temp\'), ',1),(7157,'Save order before payment','MODULE_PAYMENT_SAGE_PAY_SERVER_ORDER_BEFORE_PAYMENT','False','Save order before redirect to payment gateway','6',0,'2022-07-18 14:32:27','2021-12-24 10:27:10',NULL,'tep_cfg_select_option(array(\'True\', \'False\', \'Temp\'), ',7),(7158,'Save order before payment','MODULE_PAYMENT_SAGE_PAY_SERVER_ORDER_BEFORE_PAYMENT','False','Save order before redirect to payment gateway','6',0,NULL,'2021-12-24 10:27:10',NULL,'tep_cfg_select_option(array(\'True\', \'False\', \'Temp\'), ',8),(7163,'','','','','',NULL,'2018-03-21 14:47:35','2018-03-21 14:47:35',NULL,NULL,9),(7164,'Modules Sort','DD_MODULE_ORDER_TOTAL_SORT','ot_subtotal.php;ot_coupon.php;ot_gift_wrap.php;ot_loworderfee.php;ot_shipping.php;ot_gv.php;ot_shippingfee.php;ot_paymentfee.php;ot_bonus_points.php;ot_subtax.php;ot_tax.php;ot_total.php;ot_paid.php;ot_due.php;ot_fixed_payment_chg.php;ot_custom.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-09-28 11:28:21','2016-04-11 15:34:09',NULL,NULL,9),(7165,'Modules Sort','DD_MODULE_PAYMENT_SORT','cod.php;cash.php;paypalipn.php;sage_pay_server.php;offline.php;rbsworldpay_hosted.php;paypal_express.php;recurly.php;liqpay.php;klarna_checkout.php;amazon_payment.php;for_collect.php;multisafepay.php;paypal.php;paypal_pro_hs.php;pxpay.php;stripe_ds.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2018-03-22 13:24:41','2017-04-03 09:43:41',NULL,NULL,9),(7166,'Modules Sort','DD_MODULE_SHIPPING_SORT','flat.php;ups.php;freeshipper.php;zonetable.php;item.php;percent.php;table.php;usps.php;zones.php;zonesperitem.php;fedex1.php;dp.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-04-11 15:39:31',NULL,NULL,9),(7167,'Display billing address','DISPLAY_BILLING_ADDRESS','True','Display billing address on checkout and user account?','BOX_CONFIGURATION_MYSTORE',0,'2019-03-26 16:54:24','2019-03-26 16:54:24',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7171,'MAILCHIMP_API_KEY','MAILCHIMP_API_KEY','','','',NULL,NULL,NULL,NULL,NULL,9),(7172,'MAILCHIMP_STATUS','MAILCHIMP_STATUS','Disabled','','',NULL,NULL,NULL,NULL,NULL,9),(7173,'MAILCHIMP_STATUS_CUSTOMERS','MAILCHIMP_STATUS_CUSTOMERS','Disabled','','',NULL,NULL,NULL,NULL,NULL,9),(7174,'Installed Modules','MODULE_DROPSHIPPING_INSTALLED','','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,NULL,'2018-01-26 09:39:27',NULL,NULL,9),(7175,'Installed Modules','MODULE_LABEL_INSTALLED','','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,NULL,'2019-03-27 15:11:27',NULL,NULL,9),(7176,'Bonus apply minimum cart','MODULE_ORDER_TOTAL_BONUS_POINTS_MINIMUM_CART','0','Subtotal for allow to apply bonus points','6',4,NULL,'2020-10-09 13:42:05',NULL,NULL,9),(7177,'Order Status for Points applying','MODULE_ORDER_TOTAL_BONUS_POINTS_ORDER_STATUS_ID','3','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-10-11 15:53:24','\\common\\helpers\\Order::get_status_name','tep_cfg_select_multioption_order_statuses(',9),(7178,'Set status for covered order','MODULE_ORDER_TOTAL_BONUS_POINTS_ORDER_STATUS_ID_COVERS','2','Covered order','BOX_CONFIGURATION_MODULE',0,NULL,'2017-10-11 15:53:24','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7179,'Sort Order','MODULE_ORDER_TOTAL_BONUS_POINTS_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-10-11 15:53:24',NULL,NULL,9),(7180,'Display Bonus Points','MODULE_ORDER_TOTAL_BONUS_POINTS_STATUS','true','Do you want this module to display?','BOX_CONFIGURATION_MODULE',1,'2017-10-11 16:41:24','2017-10-11 15:53:24',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7181,'Tax Class','MODULE_ORDER_TOTAL_BONUS_POINTS_TAX_CLASS','0','Use the following tax class on the payment fee.','6',7,NULL,'2020-10-09 13:42:05','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7182,'Re-calculate Tax','MODULE_ORDER_TOTAL_COUPON_CALC_TAX','None','Re-Calculate Tax','BOX_CONFIGURATION_MODULE',7,NULL,'2016-11-16 12:12:22',NULL,'tep_cfg_select_option(array(\'None\', \'Standard\', \'Credit Note\'), ',9),(7183,'Include Shipping','MODULE_ORDER_TOTAL_COUPON_INC_SHIPPING','false','Include Shipping in calculation','BOX_CONFIGURATION_MODULE',5,NULL,'2016-11-16 12:12:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7184,'Include Tax','MODULE_ORDER_TOTAL_COUPON_INC_TAX','false','Include Tax in calculation.','BOX_CONFIGURATION_MODULE',6,NULL,'2016-11-16 12:12:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7185,'One coupon per order only.','MODULE_ORDER_TOTAL_COUPON_ONE_PER_ORDER_ONLY','False','Allow only 1 coupon per order.','6',3,NULL,'2021-11-03 17:02:00',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7186,'Sort Order','MODULE_ORDER_TOTAL_COUPON_SORT_ORDER','20','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:12:22',NULL,NULL,9),(7187,'Display Total','MODULE_ORDER_TOTAL_COUPON_STATUS','true','Do you want to display the Discount Coupon value?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:01:31','2016-11-16 12:12:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7188,'Tax Class','MODULE_ORDER_TOTAL_COUPON_TAX_CLASS','0','Use the following tax class when treating Discount Coupon as Credit Note.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 12:12:22','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7189,'Sort Order','MODULE_ORDER_TOTAL_DUE_SORT_ORDER','140','Sort order of display.','BOX_CONFIGURATION_MODULE',150,'2017-10-11 15:53:32','2017-04-01 11:18:33',NULL,NULL,9),(7190,'Display Admount Due','MODULE_ORDER_TOTAL_DUE_STATUS','false','Do you want to display the Admount Due?','BOX_CONFIGURATION_MODULE',150,'2022-02-21 08:11:11','2017-04-01 11:18:33',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7191,'Allow Gift Message for order','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE','False','Allow Gift Message for whole order','6',3,NULL,'2020-10-09 13:42:05',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),',9),(7192,'Gift Message max characters count','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_CHARS','','Gift Message max characters count, live empty to ignore','6',6,NULL,'2020-10-09 13:42:05',NULL,NULL,9),(7193,'Gift Message price','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_COST','','Gift Message price','6',4,NULL,'2020-10-09 13:42:05',NULL,NULL,9),(7194,'Gift Message max words count','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_WORDS','','Gift Message max words count, live empty to ignore','6',5,NULL,'2020-10-09 13:42:05',NULL,NULL,9),(7195,'Sort Order','MODULE_ORDER_TOTAL_GIFT_WRAP_SORT_ORDER','30','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:46:52',NULL,NULL,9),(7196,'Display Gift Wrap Order Fee','MODULE_ORDER_TOTAL_GIFT_WRAP_STATUS','true','Do you want to display the Gift Wrap Order Fee?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:02:22','2016-11-16 12:46:52',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7197,'Tax Class','MODULE_ORDER_TOTAL_GIFT_WRAP_TAX_CLASS','3','Use the following tax class on the Gift Wrap Order Fee.','BOX_CONFIGURATION_MODULE',7,NULL,'2016-11-16 12:46:52','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7198,'Re-calculate Tax','MODULE_ORDER_TOTAL_GV_CALC_TAX','None','Re-Calculate Tax','BOX_CONFIGURATION_MODULE',7,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'None\', \'Standard\', \'Credit Note\'), ',9),(7199,'Credit including Tax','MODULE_ORDER_TOTAL_GV_CREDIT_TAX','false','Add tax to purchased Gift Voucher when crediting to Account','BOX_CONFIGURATION_MODULE',8,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7200,'Include Shipping','MODULE_ORDER_TOTAL_GV_INC_SHIPPING','true','Include Shipping in calculation','BOX_CONFIGURATION_MODULE',5,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7201,'Include Tax','MODULE_ORDER_TOTAL_GV_INC_TAX','true','Include Tax in calculation.','BOX_CONFIGURATION_MODULE',6,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7202,'Allowed Order Statuses','MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID','4, 3, 2','Select the status of orders to be processed.','BOX_CONFIGURATION_MODULE',13,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_multioption_order_statuses(',9),(7203,'Set status for covered order','MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID_COVERS','2','Covered order','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-27 15:46:30','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7204,'Queue Purchases','MODULE_ORDER_TOTAL_GV_QUEUE','true','Do you want to queue purchases of the Gift Voucher?','BOX_CONFIGURATION_MODULE',3,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7205,'Sort Order','MODULE_ORDER_TOTAL_GV_SORT_ORDER','60','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:44:20',NULL,NULL,9),(7206,'Display Total','MODULE_ORDER_TOTAL_GV_STATUS','true','Do you want to display the Gift Voucher value?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7207,'Tax Class','MODULE_ORDER_TOTAL_GV_TAX_CLASS','0','Use the following tax class when treating Gift Voucher as Credit Note.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:44:20','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7208,'Installed Modules','MODULE_ORDER_TOTAL_INSTALLED','ot_subtotal.php;ot_coupon.php;ot_gift_wrap.php;ot_loworderfee.php;ot_shipping.php;ot_gv.php;ot_shippingfee.php;ot_paymentfee.php;ot_bonus_points.php;ot_subtax.php;ot_tax.php;ot_total.php;ot_paid.php;ot_due.php;ot_refund.php','List of order_total module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ot_subtotal.php;ot_tax.php;ot_shipping.php;ot_total.php)','BOX_CONFIGURATION_MODULE',0,'2020-10-09 13:42:16','2003-07-17 10:29:22',NULL,NULL,9),(7209,'Attach Low Order Fee On Orders Made','MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION','both','Attach low order fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,NULL,'2016-11-16 13:47:46',NULL,'tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',9),(7210,'Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_FEE','5','Low order fee.','BOX_CONFIGURATION_MODULE',5,NULL,'2016-11-16 13:47:46','currencies->format',NULL,9),(7211,'Allow Low Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE','false','Do you want to allow low order fees?','BOX_CONFIGURATION_MODULE',3,NULL,'2016-11-16 13:47:46',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7212,'Order Fee For Orders Under','MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER','50','Add the low order fee to orders under this amount.','BOX_CONFIGURATION_MODULE',4,NULL,'2016-11-16 13:47:46','currencies->format',NULL,9),(7213,'Sort Order','MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER','40','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:47:46',NULL,NULL,9),(7214,'Display Low Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS','true','Do you want to display the low order fee?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 13:47:46',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7215,'Tax Class','MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS','0','Use the following tax class on the low order fee.','BOX_CONFIGURATION_MODULE',7,NULL,'2016-11-16 13:47:46','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7216,'Sort Order','MODULE_ORDER_TOTAL_PAID_SORT_ORDER','130','Sort order of display.','BOX_CONFIGURATION_MODULE',140,'2017-10-11 15:53:32','2017-04-01 11:18:23',NULL,NULL,9),(7217,'Display Admount Paid','MODULE_ORDER_TOTAL_PAID_STATUS','false','Do you want to display the Admount Paid?','BOX_CONFIGURATION_MODULE',140,'2022-02-21 08:11:14','2017-04-01 11:18:23',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7218,'Allow Payment Fee','MODULE_ORDER_TOTAL_PAYMENTFEE_ALLOW_FEE','false','Do you want to allow payment fees?','BOX_CONFIGURATION_MODULE',3,NULL,'2017-01-13 11:37:59',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7219,'Attach Payment Fee On Orders Made','MODULE_ORDER_TOTAL_PAYMENTFEE_DESTINATION','both','Attach payment fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,NULL,'2017-01-13 11:37:59',NULL,'tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',9),(7220,'Sort Order','MODULE_ORDER_TOTAL_PAYMENTFEE_SORT_ORDER','80','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-01-13 11:37:59',NULL,NULL,9),(7221,'Display Payment Fee','MODULE_ORDER_TOTAL_PAYMENTFEE_STATUS','true','Do you want to display the payment fee?','BOX_CONFIGURATION_MODULE',1,NULL,'2017-01-13 11:37:59',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7222,'Tax Class','MODULE_ORDER_TOTAL_PAYMENTFEE_TAX_CLASS','0','Use the following tax class on the payment fee.','BOX_CONFIGURATION_MODULE',7,NULL,'2017-01-13 11:37:59','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7223,'Sort Order','MODULE_ORDER_TOTAL_REFUND_SORT_ORDER','160','Sort order of display.','6',160,'2020-10-09 13:42:16','2020-10-09 13:42:16',NULL,NULL,9),(7224,'Display Amount Refund','MODULE_ORDER_TOTAL_REFUND_STATUS','false','Do you want to display the Amount Refund?','6',160,'2022-02-21 08:11:08','2020-10-09 13:42:16',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7225,'Allow Shipping Fee','MODULE_ORDER_TOTAL_SHIPPINGFEE_ALLOW_FEE','false','Do you want to allow shipping fees?','BOX_CONFIGURATION_MODULE',3,NULL,'2017-01-13 11:37:45',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7226,'Attach Shipping Fee on Orders Made','MODULE_ORDER_TOTAL_SHIPPINGFEE_DESTINATION','both','Attach shipping fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,NULL,'2017-01-13 11:37:45',NULL,'tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',9),(7227,'Sort Order','MODULE_ORDER_TOTAL_SHIPPINGFEE_SORT_ORDER','70','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-01-13 11:37:45',NULL,NULL,9),(7228,'Display Shipping Fee','MODULE_ORDER_TOTAL_SHIPPINGFEE_STATUS','true','Do you want to display the shipping Fee?','BOX_CONFIGURATION_MODULE',1,NULL,'2017-01-13 11:37:45',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7229,'Tax Class','MODULE_ORDER_TOTAL_SHIPPINGFEE_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',7,NULL,'2017-01-13 11:37:45','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7230,'Provide Free Shipping For Orders Made','MODULE_ORDER_TOTAL_SHIPPING_DESTINATION','both','Provide free shipping for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',5,NULL,'2016-11-16 13:51:20',NULL,'tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',9),(7231,'Allow Free Shipping','MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING','false','Do you want to allow free shipping?','BOX_CONFIGURATION_MODULE',3,NULL,'2016-11-16 13:51:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7232,'Free Shipping For Orders Over','MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER','100','Provide free shipping for orders over the set amount.','BOX_CONFIGURATION_MODULE',4,NULL,'2016-11-16 13:51:20','currencies->format',NULL,9),(7233,'Limit shipping results sort mode','MODULE_ORDER_TOTAL_SHIPPING_LIMIT_RESULT_SORT','Cheapest first','','BOX_CONFIGURATION_MODULE',7,NULL,'2019-03-27 14:56:48',NULL,'tep_cfg_select_option(array(\'Cheapest first\', \'Modules sort order\'), ',9),(7234,'Number of shipping results','MODULE_ORDER_TOTAL_SHIPPING_RESULT_COUNT','','Limit results (if empty - unlimited).','BOX_CONFIGURATION_MODULE',6,NULL,'2019-03-27 14:56:48',NULL,NULL,9),(7235,'Sort Order','MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER','50','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:51:20',NULL,NULL,9),(7236,'Display Shipping','MODULE_ORDER_TOTAL_SHIPPING_STATUS','true','Do you want to display the order shipping cost?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 13:51:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7237,'Sort Order','MODULE_ORDER_TOTAL_SUBTAX_SORT_ORDER','100','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-02-22 14:10:20',NULL,NULL,9),(7238,'Display Subtotal for taxation','MODULE_ORDER_TOTAL_SUBTAX_STATUS','true','Do you want to display the subtotal for taxation value?','BOX_CONFIGURATION_MODULE',1,NULL,'2017-02-22 14:10:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7239,'Sort Order','MODULE_ORDER_TOTAL_SUBTOTAL_SORT_ORDER','10','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:10:43',NULL,NULL,9),(7240,'Display Sub-Total','MODULE_ORDER_TOTAL_SUBTOTAL_STATUS','true','Do you want to display the order sub-total cost?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:01:29','2016-11-16 12:10:43',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7241,'Sort Order','MODULE_ORDER_TOTAL_TAX_SORT_ORDER','110','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:08:32',NULL,NULL,9),(7242,'Display Tax','MODULE_ORDER_TOTAL_TAX_STATUS','true','Do you want to display the order tax value?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 12:08:32',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7245,'Sort Order','MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER','120','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:06:52',NULL,NULL,9),(7246,'Display Total','MODULE_ORDER_TOTAL_TOTAL_STATUS','true','Do you want to display the total order value?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 12:06:52',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7247,'2CheckOut Merchant Notifications','MODULE_PAYMENT_2CHECKOUT_EMAIL_MERCHANT','True','Should 2CheckOut e-mail a receipt to the store owner?','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7248,'2CheckOut Login/Store Number','MODULE_PAYMENT_2CHECKOUT_LOGIN','18157','Login/Store Number used for the 2CheckOut service','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21',NULL,NULL,9),(7249,'2CheckOut Set Order Status','MODULE_PAYMENT_2CHECKOUT_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7250,'2CheckOut Sort order of display.','MODULE_PAYMENT_2CHECKOUT_SORT_ORDER','100','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-08 16:55:21',NULL,NULL,9),(7251,'Enable 2CheckOut Module','MODULE_PAYMENT_2CHECKOUT_STATUS','False','Do you want to accept 2CheckOut payments?','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7252,'2CheckOut Transaction Mode','MODULE_PAYMENT_2CHECKOUT_TESTMODE','Test','Transaction mode used for the 2Checkout service','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21',NULL,'tep_cfg_select_option(array(\'Test\', \'Production\'), ',9),(7253,'2CheckOut Payment Zone','MODULE_PAYMENT_2CHECKOUT_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-08 16:55:21','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7254,'Authorizenet Customer Notifications','MODULE_PAYMENT_AUTHORIZENET_EMAIL_CUSTOMER','False','Should Authorize.Net e-mail a receipt to the customer?','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7255,'Authorizenet Login Username','MODULE_PAYMENT_AUTHORIZENET_LOGIN','testing','The login username used for the Authorize.net service','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,NULL,9),(7256,'Authorizenet Transaction Method','MODULE_PAYMENT_AUTHORIZENET_METHOD','Credit Card','Transaction method used for processing orders','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,'tep_cfg_select_option(array(\'Credit Card\', \'eCheck\'), ',9),(7257,'Authorizenet - Set Order Status','MODULE_PAYMENT_AUTHORIZENET_ORDER_STATUS_ID','0','Authorizenet - Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7258,'Authorizenet - Sort order of display.','MODULE_PAYMENT_AUTHORIZENET_SORT_ORDER','80','Authorizenet - Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:51:38',NULL,NULL,9),(7259,'Enable Authorize.net Module','MODULE_PAYMENT_AUTHORIZENET_STATUS','False','Do you want to accept Authorize.net payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:33','2016-04-11 15:51:38',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7260,'Authorizenet Transaction Mode','MODULE_PAYMENT_AUTHORIZENET_TESTMODE','Test','Transaction mode used for processing orders','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,'tep_cfg_select_option(array(\'Test\', \'Production\'), ',9),(7261,'Authorizenet Transaction Key','MODULE_PAYMENT_AUTHORIZENET_TXNKEY','Test','Transaction Key used for encrypting TP data','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,NULL,9),(7262,'Authorizenet - Payment Zone','MODULE_PAYMENT_AUTHORIZENET_ZONE','0','Authorizenet - If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:51:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7263,'CASH Set Order Status','MODULE_PAYMENT_CASH_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2018-01-17 11:52:46','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7264,'CASH Sort order of display.','MODULE_PAYMENT_CASH_SORT_ORDER','60','Sort order of CASH display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:34:41','2018-01-17 11:52:46',NULL,NULL,9),(7265,'CASH Enable Cash Payment Module','MODULE_PAYMENT_CASH_STATUS','False','Do you want to accept Cash Payment?','BOX_CONFIGURATION_MODULE',1,'2018-03-22 13:24:29','2018-01-17 11:52:46',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7266,'CASH Payment Zone','MODULE_PAYMENT_CASH_ZONED','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2018-01-17 11:52:46','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7267,'CC Split Credit Card E-Mail Address','MODULE_PAYMENT_CC_EMAIL','','If an e-mail address is entered, the middle digits of the credit card number will be sent to the e-mail address (the outside digits are stored in the database with the middle digits censored)','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:49:38',NULL,NULL,9),(7268,'CC Set Order Status','MODULE_PAYMENT_CC_ORDER_STATUS_ID','0','Set the status of CC orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:49:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7269,'CC Sort order of display.','MODULE_PAYMENT_CC_SORT_ORDER','60','Sort order of CC display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:49:38',NULL,NULL,9),(7270,'CC Enable Credit Card Module','MODULE_PAYMENT_CC_STATUS','True','Do you want to accept credit card payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:31','2016-04-11 15:49:38',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7271,'CC Payment Zone','MODULE_PAYMENT_CC_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:49:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7272,'COD Set Order Status','MODULE_PAYMENT_COD_ORDER_STATUS_ID','100007','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2018-01-11 15:06:47','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7273,'COD Sort order of display.','MODULE_PAYMENT_COD_SORT_ORDER','40','Sort order of COD display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:17:11','2018-01-11 15:06:47',NULL,NULL,9),(7274,'COD Enable Cash On Delivery Module','MODULE_PAYMENT_COD_STATUS','True','Do you want to accept Cash On Delevery payments?','BOX_CONFIGURATION_MODULE',1,NULL,'2018-01-11 15:06:47',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7275,'COD Payment Zone','MODULE_PAYMENT_COD_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2018-01-11 15:06:47','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7276,'EFSnet Transaction Method','MODULE_PAYMENT_EFSNET_METHOD','CreditCardCharge','Transaction method used for processing orders','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06',NULL,'tep_cfg_select_option(array(\'CreditCardCharge\',\'CreditCardAuthorize\'), ',9),(7277,'EFSnet Set Order Status','MODULE_PAYMENT_EFSNET_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7278,'EFSnet Sort order of display.','MODULE_PAYMENT_EFSNET_SORT_ORDER','90','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:57:06',NULL,NULL,9),(7279,'Enable EFSnet Module','MODULE_PAYMENT_EFSNET_STATUS','False','Do you want to accept EFSNet payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:34','2016-04-11 15:57:06',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7280,'EFSnet Login Username','MODULE_PAYMENT_EFSNET_STOREID','testing','The StoreID used for the EFSNet service','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06',NULL,NULL,9),(7281,'EFSnet Transaction Key','MODULE_PAYMENT_EFSNET_STOREKEY','Test','Store Key used for encrypting data','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06',NULL,NULL,9),(7282,'EFSnet Transaction Mode','MODULE_PAYMENT_EFSNET_TESTMODE','Test','Transaction mode used for processing orders','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06',NULL,'tep_cfg_select_option(array(\'Test\', \'Production\'), ',9),(7283,'EFSnet Payment Zone','MODULE_PAYMENT_EFSNET_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:57:06','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7284,'Free Charge Set Order Status','MODULE_PAYMENT_FREECHARGER_ORDER_STATUS_ID','3','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:50:23','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7285,'Free Charge Sort order of display.','MODULE_PAYMENT_FREECHARGER_SORT_ORDER','70','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:50:23',NULL,NULL,9),(7286,'Enable Free Charge Module','MODULE_PAYMENT_FREECHARGER_STATUS','False','Do you want to accept Free Charge payments?','BOX_CONFIGURATION_MODULE',1,'2016-04-12 14:50:32','2016-04-11 15:50:23',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7287,'Free Charge Payment Zone','MODULE_PAYMENT_FREECHARGER_ZONE','4','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:50:23','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7288,'GeoTrust Merchant ID','MODULE_PAYMENT_GEOTRUST_MERCHANT_ID','serial #','Merchant Serial # to use for the GEOTRUST QuickPayments service','BOX_CONFIGURATION_MODULE',2,NULL,'2016-02-05 17:19:45',NULL,NULL,9),(7289,'GeoTrust Set Order Status','MODULE_PAYMENT_GEOTRUST_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-02-05 17:19:45','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7290,'GeoTrust Sort order of display.','MODULE_PAYMENT_GEOTRUST_SORT_ORDER','40','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-02-05 17:19:45',NULL,NULL,9),(7291,'Enable GeoTrust QuickPayments Module','MODULE_PAYMENT_GEOTRUST_STATUS','False','Do you want to accept GeoTrust QuickPayments?','BOX_CONFIGURATION_MODULE',1,'2016-04-12 14:50:29','2016-02-05 17:19:45',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7292,'GeoTrust Payment Zone','MODULE_PAYMENT_GEOTRUST_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-02-05 17:19:45','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7293,'Installed Modules','MODULE_PAYMENT_INSTALLED','paypal_partner.php;sage_pay_server.php;stripe_checkout.php;cod.php;offline.php','List of payment module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: cc.php;cod.php;paypal.php)','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:17:11','2003-07-17 10:29:22',NULL,NULL,9),(7294,'Order Status','MODULE_PAYMENT_INVOICE_ORDER_STATUS_ID','1','Festlegung des Status für Bestellungen, welche mit dieser Zahlungsweise durchgeführt werden.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:46:07','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7295,'Reihenfolge der Anzeige','MODULE_PAYMENT_INVOICE_SORT_ORDER','50','Niedrigste wird zuerst angezeigt.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:46:07',NULL,NULL,9),(7296,'Rechnung','MODULE_PAYMENT_INVOICE_STATUS','False','Wollen Sie Zahlungen per Rechnung anbieten?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:30','2016-04-11 15:46:07',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7297,'Zone für diese Zahlungsweise','MODULE_PAYMENT_INVOICE_ZONE','3','Wenn Sie eine Zone auswählen, wird diese Zahlungsweise nur in dieser Zone angeboten.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:46:07','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7298,'Set Order Status','MODULE_PAYMENT_LIQPAY_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',4,NULL,'2018-01-26 15:33:32','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7299,'Money Order Set Order Status','MODULE_PAYMENT_MONEYORDER_ORDER_STATUS_ID','1','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:48:09','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7300,'Money Order Make Payable to:','MODULE_PAYMENT_MONEYORDER_PAYTO','','Who should payments be made payable to?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-04-11 15:48:09',NULL,NULL,9),(7301,'Money Order Sort order of display.','MODULE_PAYMENT_MONEYORDER_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:48:09',NULL,NULL,9),(7302,'Enable Check/Money Order Module','MODULE_PAYMENT_MONEYORDER_STATUS','True','Do you want to accept Check/Money Order payments?','BOX_CONFIGURATION_MODULE',1,'2016-04-13 17:08:47','2016-04-11 15:48:09',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7303,'Money Order Payment Zone','MODULE_PAYMENT_MONEYORDER_ZONE','4','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:48:09','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7304,'OFFLINE Order Status','MODULE_PAYMENT_OFFLINE_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-03 11:25:11','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7305,'OFFLINE Sort order of display.','MODULE_PAYMENT_OFFLINE_SORT_ORDER','50','Sort order of OFFLINE display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:17:11','2017-04-03 11:25:11',NULL,NULL,9),(7306,'OFFLINE Enable Module','MODULE_PAYMENT_OFFLINE_STATUS','False','Do you want to accept OFFLINE payments?','BOX_CONFIGURATION_MODULE',1,'2018-01-12 09:59:49','2017-04-03 11:25:11',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7307,'OFFLINE Payment Zone','MODULE_PAYMENT_OFFLINE_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2017-04-03 11:25:11','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7308,'PayPal IPN Add Shipping to Amount','MODULE_PAYMENT_PAYPALIPN_ADD_SHIPPING_TO_AMOUNT','False','Add shipping amount to order amount? (will set shipping amount to $0 in PayPal)','6',5,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7309,'PayPal IPN Add Tax to Amount','MODULE_PAYMENT_PAYPALIPN_ADD_TAX_TO_AMOUNT','False','Add tax amount to order amount? (will set tax amount to $0 in PayPal)','6',5,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7310,'PayPal IPN Allowed Currencies','MODULE_PAYMENT_PAYPALIPN_ALLOWED_CURRENCIES','GBP,EUR,USD','Allowed currencies in which customers can pay.<br>Allowed by PayPal: USD,EUR,GBP,CAD,JPY<br>Allowed in your shop: GBP,EUR,USD<br>To add more currencies to your shop go to Localization->Currencies.','6',9,NULL,'2021-11-16 13:52:41',NULL,'',9),(7311,'PayPal Transactions Cancel Order Status','MODULE_PAYMENT_PAYPALIPN_CANCEL_ORDER_STATUS_ID','5','','6',0,NULL,'2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7312,'or API Certificate','MODULE_PAYMENT_PAYPALIPN_CERTIFICATE','','The certificate to use for the PayPal API service.','6',0,NULL,'2021-11-16 13:52:41',NULL,'cfg_upload_file(',9),(7313,'API Application Client ID','MODULE_PAYMENT_PAYPALIPN_CLIENT_ID','','The Client ID of app','6',0,NULL,'2021-11-16 13:52:41',NULL,'',9),(7314,'PayPal IPN Use cURL','MODULE_PAYMENT_PAYPALIPN_CURL','False','Use cURL to communicate with PayPal?<br>cURL has been <b>DETECTED</b> in your system','6',4,NULL,'2021-11-16 09:30:10',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7315,'PayPal IPN Debug Email','MODULE_PAYMENT_PAYPALIPN_DEBUG_EMAIL','','PayPal IPN Debug Email','6',15,NULL,'2021-11-16 13:52:41',NULL,'',9),(7316,'PayPal IPN Default Currency','MODULE_PAYMENT_PAYPALIPN_DEFAULT_CURRENCY','GBP','Default currency to use when customer try to pay in a NON allowed (because of PayPal or you) currency','6',10,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array (\n 0 => \'GBP\',\n 1 => \'EUR\',\n 2 => \'USD\',\n), ',9),(7317,'PayPal IPN ID','MODULE_PAYMENT_PAYPALIPN_ID','paypal.sandbox.business@holbi.co.uk','Your business ID at PayPal. Usually the email address you signed up with. You can create a free PayPal account at <a href=\"http://www.paypal.com/\" target=\"_blank\">http://www.paypal.com</a>.','6',2,NULL,'2021-11-16 13:52:41',NULL,'',9),(7318,'PayPal IPN Notify URL','MODULE_PAYMENT_PAYPALIPN_NOTIFY_URL','callback/paypal-notify','Exact location in which your callback/paypal-notify resides.','6',3,NULL,'2021-11-16 13:52:41',NULL,'\\common\\modules\\orderPayment\\urlchecker(',9),(7319,'PayPal IPN Set Status Before Payment','MODULE_PAYMENT_PAYPALIPN_ORDER_BEFORE_PAYMENT_ID','1','Set the status of ordersbefore redirect to Gateway','6',14,NULL,'2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7320,'PayPal IPN Set Order Status','MODULE_PAYMENT_PAYPALIPN_ORDER_STATUS_ID','100006','Set the status of orders made with this payment module to this value','6',14,NULL,'2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7321,'API Password','MODULE_PAYMENT_PAYPALIPN_PASSWORD','','The password to use for the PayPal API service.','6',0,NULL,'2021-11-16 13:52:41',NULL,'',9),(7322,'Use API Signature','MODULE_PAYMENT_PAYPALIPN_SIGNATURE','','The signature to use for the PayPal API service.','6',0,NULL,'2021-11-16 13:52:41',NULL,'',9),(7323,'PayPal IPN Sort order of display.','MODULE_PAYMENT_PAYPALIPN_SORT_ORDER','80','Sort order of display. Lowest is displayed first.','6',12,'2021-11-16 13:52:41','2021-11-16 13:52:41',NULL,'',9),(7324,'Allow PayPal IPN','MODULE_PAYMENT_PAYPALIPN_STATUS','True','Do you want to accept PayPal IPN payments and notifications?','6',1,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7325,'PayPal IPN Test Mode','MODULE_PAYMENT_PAYPALIPN_TEST_MODE','True','Run in TEST MODE? If so, you will be able to send TEST IPN from Admin->PayPal_IPN->Test_IPN, BUT you will not be able to receive real IPN\'s from PayPal.','6',11,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7326,'PayPal IPN Update Stock Before Payment','MODULE_PAYMENT_PAYPALIPN_UPDATE_STOCK_BEFORE_PAYMENT','False','Should Products Stock be updated even when the payment is not yet COMPLETED?','6',6,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7327,'API Username','MODULE_PAYMENT_PAYPALIPN_USERNAME','','The username to use for the PayPal API service.','6',0,NULL,'2021-11-16 13:52:41',NULL,'',9),(7328,'PayPal IPN Payment Zone','MODULE_PAYMENT_PAYPALIPN_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',13,NULL,'2021-11-16 13:52:41','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7329,'API Application Client Secret Key','MODULE_PAYMENT_PPAYPALIPN_CLIENT_SECRET','','The Client Secret Key of app','6',0,NULL,'2021-11-16 13:52:41',NULL,'',9),(7330,'Callback Password','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_CALLBACK_PASSWORD','','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,NULL,9),(7331,'Debug E-Mail Address','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_DEBUG_EMAIL','','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,NULL,9),(7332,'Installation ID','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_INSTALLATION_ID','','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,NULL,9),(7333,'MD5 Password','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_MD5_PASSWORD','','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,NULL,9),(7334,'Set Order Status','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_ORDER_STATUS_ID','100006','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7335,'Set Preparing Order Status','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_PREPARE_ORDER_STATUS_ID','1','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7336,'Signaturefields','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_SIGNATUREFIELDS','--none--','Select Signaturefields. Please copy and past this value to worldpay: <b><span id=\"signature\"></span></b>','6',0,NULL,'2021-11-03 17:01:14',NULL,'select_multioption(array(\'amount\',\'currency\',\'cartId\'), ',9),(7337,'Sort order of display.','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_SORT_ORDER','20','','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:34:41','2017-04-08 14:31:29',NULL,NULL,9),(7338,'Enable WorldPay Hosted Payment Pages','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_STATUS','False','','BOX_CONFIGURATION_MODULE',0,'2018-01-11 16:18:09','2017-04-08 14:31:29',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7339,'Test Mode','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TESTMODE','True','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7340,'Transactions Order Status Level','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TRANSACTIONS_ORDER_STATUS_ID','1','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7341,'Transaction Method','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TRANSACTION_METHOD','Capture','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,'tep_cfg_select_option(array(\'Pre-Authorization\', \'Capture\'), ',9),(7342,'Payment Zone','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_ZONE','0','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7346,'cURL Program Location','MODULE_PAYMENT_SAGE_PAY_SERVER_CURL','/usr/bin/curl','The location to the cURL program application.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:11:50',NULL,NULL,9),(7358,'Set Order Status Cancelled Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_CANCELLED_ORDER_STATUS_ID','5','Set the status of orders cancelled','6',0,NULL,'2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7359,'Set Order Status Completed Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_COMPLETED_ORDER_STATUS_ID','100006','Set the status of orders completed successfully','6',0,NULL,'2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7360,'Debug E-Mail Address','MODULE_PAYMENT_STRIPE_CHECKOUT_DEBUG_EMAIL','','All parameters of an invalid transaction will be sent to this email address.','6',0,NULL,'2021-11-15 09:11:10',NULL,NULL,9),(7361,'Set Order Status Before Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_ORDER_STATUS_ID','1','Set the status of orders before redirect to Gateway','6',0,NULL,'2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(7362,'Publishable API Key','MODULE_PAYMENT_STRIPE_CHECKOUT_PUBLISHABLE_KEY','pk_test_51L5tlzLrdFbMtgAWVb82LINlf6po2qfbkRmjCc3o02yH88tlzoCC96f8EnpUmVGgQR104lCdO4WdiqmEpzefgrbE00YzVLdKk0','The Stripe account publishable API key to use.','6',0,NULL,'2021-11-15 09:11:10',NULL,NULL,9),(7363,'Secret API Key','MODULE_PAYMENT_STRIPE_CHECKOUT_SECRET_KEY','0Û£/%³¸L§Ìe709bae011d46dab9341ffed2a7591cdfefef80308bbcff36508f3e7ca5eda093Öµ<Y3_\\Ä!)¼5l)èÆ	Ú\Zåj	df.\'}özé\0ÔïÚ?/;)	§ë¨£^<VvZCÝp8XÚuçwBôÕêÿe69	í3§ÁçÆ>wÌºº/³²ÜãÖÉ~{´gE5éE¤)ò','The Stripe account secret API key to use with the publishable key.','6',0,NULL,'2021-11-15 09:11:10','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',9),(7364,'Sort order of display.','MODULE_PAYMENT_STRIPE_CHECKOUT_SORT_ORDER','30','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:17:11','2021-11-15 09:11:10',NULL,NULL,9),(7365,'Enable Stripe Module','MODULE_PAYMENT_STRIPE_CHECKOUT_STATUS','True','Do you want to accept Stripe payments?','6',0,'2022-06-24 17:54:59','2021-11-15 09:11:10',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7366,'Update Stock Before Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_UPDATE_STOCK_BEFORE_PAYMENT','False','Should Products Stock be updated even when the payment is not yet COMPLETED?','6',0,NULL,'2021-11-15 09:11:10',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7367,'Webhook Secret','MODULE_PAYMENT_STRIPE_CHECKOUT_WEBHOOK_SECRET','whsec_HExwr6qITymk3PEKFcS9LaaTkyzrKwVw','The Stripe account webhook signing secret.','6',0,NULL,'2021-11-15 09:11:10',NULL,NULL,9),(7368,'Payment Zone','MODULE_PAYMENT_STRIPE_CHECKOUT_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',0,NULL,'2021-11-15 09:11:10','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7369,'FedEx Account Number','MODULE_SHIPPING_FEDEX_ACT_NUM','','Enter FedEx Account Number','6',4,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7370,'First line of street address','MODULE_SHIPPING_FEDEX_ADDRESS_1','','Enter the first line of your ship-from street address, required','6',7,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7371,'Second line of street address','MODULE_SHIPPING_FEDEX_ADDRESS_2','','Enter the second line of your ship-from street address, leave blank if you do not need to specify a second line','6',8,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7372,'City name','MODULE_SHIPPING_FEDEX_CITY','','Enter the city name for the ship-from street address, required','6',9,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7373,'Country','MODULE_SHIPPING_FEDEX_COUNTRY','222','Select the postal country for the ship-from address, required','6',11,NULL,'2021-11-15 09:14:28','\\backend\\models\\Configuration::tep_get_country_name','tep_cfg_pull_down_country_list(',9),(7374,'Currency Exchange Rates Conversion','MODULE_SHIPPING_FEDEX_CURRENCY','1','Set your currency exchange rate here if needed. Note that this data must be a number (integer like 32 or with a floating point like 32.48) and will have to be updated by you regularly to match exchange fluctuations.','6',14,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7375,'Delivery Date Management','MODULE_SHIPPING_FEDEX_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',9),(7376,'Delivery Date ownership settings','MODULE_SHIPPING_FEDEX_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',9),(7377,'Domestic NBD Handling Fee','MODULE_SHIPPING_FEDEX_DOMESTIC_HANDLING_FEE','','Add a domestic handling fee or leave blank (example: 15 or 15%)','6',20,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7378,'Enable Domestic NBD','MODULE_SHIPPING_FEDEX_DOMESTIC_NEXT_DAY','true','Enable FedEx Domestic Next Business Day','6',16,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7379,'Drop off type','MODULE_SHIPPING_FEDEX_DROPOFF','REGULAR_PICKUP','Dropoff type?','6',15,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'REGULAR_PICKUP\',\'REQUEST_COURIER\',\'DROP_BOX\',\'BUSINESS_SERVICE_CENTER\',\'STATION\'), ',9),(7380,'Insurance?','MODULE_SHIPPING_FEDEX_INSURE','-1','Insure packages over what amount? (set to -1 to disable)','6',22,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7381,'Enable International Economy','MODULE_SHIPPING_FEDEX_INTERNATIONAL_ECONOMY','true','Enable FedEx Express International Economy','6',18,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7382,'Enable International Priority','MODULE_SHIPPING_FEDEX_INTERNATIONAL_PRIORITY','true','Enable FedEx Express International Priority','6',17,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',9),(7383,'International Express Handling Fee','MODULE_SHIPPING_FEDEX_INT_EXPRESS_HANDLING_FEE','','Add an international handling fee or leave blank (example: 15 or 15%)','6',21,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7384,'FedEx Web Services Key','MODULE_SHIPPING_FEDEX_KEY','','Enter FedEx Web Services Key','6',2,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7385,'FedEx Meter Number','MODULE_SHIPPING_FEDEX_METER_NUM','','Enter FedEx Meter Number','6',5,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7386,'Web Service Mode','MODULE_SHIPPING_FEDEX_MODE','Test','Web Service Mode','6',2,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'Test\', \'Production\'), ',9),(7387,'FedEx Packaging Type','MODULE_SHIPPING_FEDEX_PACKAGING_TYPE','YOUR_PACKAGING','FedEx Packaging Type','6',22,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'YOUR_PACKAGING\',\'FEDEX_10KG_BOX\', \'FEDEX_25KG_BOX\', \'FEDEX_BOX\', \'FEDEX_ENVELOPE\', \'FEDEX_EXTRA_LARGE_BOX\', \'FEDEX_LARGE_BOX\', \'FEDEX_MEDIUM_BOX\', \'FEDEX_PAK\', \'FEDEX_SMALL_BOX\', \'FEDEX_TUBE\'), ',9),(7388,'Phone number','MODULE_SHIPPING_FEDEX_PHONE','','Enter a contact phone number for your company, required','6',12,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7389,'Postal code','MODULE_SHIPPING_FEDEX_POSTAL','','Enter the postal code for the ship-from street address, required','6',11,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7390,'FedEx Web Services Password','MODULE_SHIPPING_FEDEX_PWD','','Enter FedEx Web Services Password','6',3,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7391,'FedEx Rates','MODULE_SHIPPING_FEDEX_RATES','LIST','FedEx Rates','6',22,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'LIST\',\'ACCOUNT\'), ',9),(7392,'Shipping Delay','MODULE_SHIPPING_FEDEX_SHIPPING_DAYS_DELAY','1','How many days from when an order is placed to when you ship it (Decimals are allowed). Arrival date estimations are based on this value.','6',13,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7393,'Signature Option','MODULE_SHIPPING_FEDEX_SIGNATURE_OPTION','-1','Require a signature on order subtotal greater than or equal to (set to -1 to disable):','6',23,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7394,'Signature Option Type','MODULE_SHIPPING_FEDEX_SIGNATURE_OPTION_TYPE','SERVICE_DEFAULT','Select Signature Option Type','6',23,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'ADULT\', \'DIRECT\', \'INDIRECT\', \'NO_SIGNATURE_REQUIRED\', \'SERVICE_DEFAULT\'), ',9),(7395,'Shipping Sort Order','MODULE_SHIPPING_FEDEX_SORT_ORDER','140','Sort order of display.','6',100,'2021-11-15 09:14:28','2021-11-15 09:14:28',NULL,NULL,9),(7396,'State or Province name','MODULE_SHIPPING_FEDEX_STATE','','Enter the 2 letter state or province name for the ship-from street address, required for Canada and US','6',10,NULL,'2021-11-15 09:14:28',NULL,NULL,9),(7397,'Enable Collect Shipping','MODULE_SHIPPING_FEDEX_STATUS','False','Do you want to offer collect shipping?','6',0,'2021-11-15 09:14:43','2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7398,'Shipping Tax Class','MODULE_SHIPPING_FEDEX_TAX_CLASS','0','Use the following tax class on the shipping fee.','6',0,NULL,'2021-11-15 09:14:28','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7399,'Weight Units','MODULE_SHIPPING_FEDEX_WEIGHT','KG','Weight Units:','6',6,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'LB\', \'KG\'), ',9),(7400,'Shipping Shipping Zone','MODULE_SHIPPING_FEDEX_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','6',0,NULL,'2021-11-15 09:14:28','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7401,'Flat Shipping Cost','MODULE_SHIPPING_FLAT_COST','5','The shipping cost for all orders using this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 14:03:53',NULL,NULL,9),(7402,'Delivery Date Management','MODULE_SHIPPING_FLAT_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',9),(7403,'Delivery Date ownership settings','MODULE_SHIPPING_FLAT_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',9),(7404,'Flat Sort Order','MODULE_SHIPPING_FLAT_SORT_ORDER','10','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 14:03:53',NULL,NULL,9),(7405,'Enable Flat Shipping','MODULE_SHIPPING_FLAT_STATUS','True','Do you want to offer flat rate shipping?','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:36:10','2016-11-16 14:03:53',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7406,'Flat Tax Class','MODULE_SHIPPING_FLAT_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 14:03:53','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7407,'Flat Shipping Zone','MODULE_SHIPPING_FLAT_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 14:03:53','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7408,'Free Shipping Cost','MODULE_SHIPPING_FREESHIPPER_COST','0.00','What is the Shipping cost? The Handling fee will also be added.','BOX_CONFIGURATION_MODULE',6,NULL,'2016-11-16 13:27:21',NULL,NULL,9),(7409,'Delivery Date Management','MODULE_SHIPPING_FREESHIPPER_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',9),(7410,'Delivery Date ownership settings','MODULE_SHIPPING_FREESHIPPER_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',9),(7411,'FREESHIPPER Sort Order','MODULE_SHIPPING_FREESHIPPER_SORT_ORDER','30','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:27:21',NULL,NULL,9),(7412,'Enable Free Shipping','MODULE_SHIPPING_FREESHIPPER_STATUS','False','Do you want to offer Free shipping?','BOX_CONFIGURATION_MODULE',5,'2017-07-19 15:13:02','2016-11-16 13:27:21',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7413,'FREESHIPPER Tax Class','MODULE_SHIPPING_FREESHIPPER_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:27:21','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7414,'FREESHIPPER Shipping Zone','MODULE_SHIPPING_FREESHIPPER_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:27:21','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7415,'Installed Modules','MODULE_SHIPPING_INSTALLED','flat.php;freeshipper.php;zonetable.php;item.php;percent.php;table.php;zones.php','List of shipping module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ups.php;flat.php;item.php)','BOX_CONFIGURATION_MODULE',0,'2022-06-24 14:32:30','2003-07-17 10:29:22',NULL,NULL,9),(7416,'Item Shipping Shipping Cost','MODULE_SHIPPING_ITEM_COST','0','The shipping cost will be multiplied by the number of items in an order that uses this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:59:56',NULL,NULL,9),(7417,'Delivery Date Management','MODULE_SHIPPING_ITEM_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',9),(7418,'Delivery Date ownership settings','MODULE_SHIPPING_ITEM_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',9),(7419,'Item Shipping Handling Fee','MODULE_SHIPPING_ITEM_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:59:56',NULL,NULL,9),(7420,'Item Shipping Sort Order','MODULE_SHIPPING_ITEM_SORT_ORDER','50','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:59:56',NULL,NULL,9),(7421,'Enable Item Shipping','MODULE_SHIPPING_ITEM_STATUS','False','Do you want to offer per item rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-01-11 16:18:17','2016-11-16 13:59:56',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7422,'Item Shipping Tax Class','MODULE_SHIPPING_ITEM_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:59:56','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7423,'Item Shipping Shipping Zone','MODULE_SHIPPING_ITEM_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:59:56','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7424,'NovaPoshta ApiKey','MODULE_SHIPPING_NP_APIKEY','dd791bafa70224a996085024e0687e8c','','BOX_CONFIGURATION_MODULE',0,NULL,'2018-02-16 15:24:13',NULL,NULL,9),(7425,'NovaPoshta ApiKey','MODULE_SHIPPING_NP_API_KEY','','','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-22 13:18:12',NULL,NULL,9),(7426,'NovaPoshta Shipping Shipping Cost','MODULE_SHIPPING_NP_COST','40','','BOX_CONFIGURATION_MODULE',0,NULL,'2018-02-16 15:24:13',NULL,NULL,9),(7427,'Delivery Date Management','MODULE_SHIPPING_NP_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',9),(7428,'Delivery Date ownership settings','MODULE_SHIPPING_NP_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',9),(7429,'Preferred Shipping Method','MODULE_SHIPPING_NP_PREFERRED_METHOD','WarehouseToWarehouse','Sort order of display.','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-22 13:18:12',NULL,'tep_cfg_select_option(array(\'WarehouseToWarehouse\', \'WarehouseToDoors\'), ',9),(7430,'NP Shipping Sort Order','MODULE_SHIPPING_NP_SORT_ORDER','130','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2018-02-16 15:24:13','2018-02-16 15:24:13',NULL,NULL,9),(7431,'Enable Item Shipping','MODULE_SHIPPING_NP_STATUS','False','Do you want to offer NovaPoshta shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-22 13:24:50','2018-02-16 15:24:13',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7432,'Tracking Url','MODULE_SHIPPING_NP_TRACKING_NUMBER_URL','https://novaposhta.ua/tracking/?newtracking=1&cargo_number=','Url for tracking cargo','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-22 13:18:12',NULL,NULL,9),(7433,'Enable NP Tracking','MODULE_SHIPPING_NP_TRACKING_STATUS','True','Do you want to enable NP tracking?','BOX_CONFIGURATION_MODULE',0,NULL,'2018-10-02 09:43:28',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7434,'Delivery Date Management','MODULE_SHIPPING_PERCENT_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',9),(7435,'Delivery Date ownership settings','MODULE_SHIPPING_PERCENT_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',9),(7436,'Percentage A Flat Rate of','MODULE_SHIPPING_PERCENT_FLAT_USE','6.50','A Flat Rate used for all orders.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35',NULL,NULL,9),(7437,'Percentage A Flat Rate for orders under','MODULE_SHIPPING_PERCENT_LESS_THEN','34.75','A Flat Rate for all orders that are under the amount shown.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35',NULL,NULL,9),(7438,'Percentage Rate','MODULE_SHIPPING_PERCENT_RATE','.18','The Percentage Rate all .01 to .99 for all orders using this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35',NULL,NULL,9),(7439,'Percentage Sort Order','MODULE_SHIPPING_PERCENT_SORT_ORDER','60','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:52:35',NULL,NULL,9),(7440,'Enable Percent Shipping','MODULE_SHIPPING_PERCENT_STATUS','True','Do you want to offer percent rate shipping?','BOX_CONFIGURATION_MODULE',0,'2022-06-24 17:03:13','2016-11-16 13:52:35',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7441,'Percentage from Order incl. Tax','MODULE_SHIPPING_PERCENT_SUBTOTAL_INCL_TAX','True','Calculate order amount incl. tax or excl. tax?','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7442,'Percentage Tax Class','MODULE_SHIPPING_PERCENT_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7443,'Percentage Shipping Zone','MODULE_SHIPPING_PERCENT_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7444,'Table Method Shipping Table','MODULE_SHIPPING_TABLE_COST','25:8.50,50:5.50,10000:0.00','The shipping cost is based on the total cost or weight of items. Example: 25:8.50,50:5.50,etc.. Up to 25 charge 8.50, from there to 50 charge 5.50, etc','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14',NULL,NULL,9),(7445,'Delivery Date Management','MODULE_SHIPPING_TABLE_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',9),(7446,'Delivery Date ownership settings','MODULE_SHIPPING_TABLE_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',9),(7447,'Table Method Handling Fee','MODULE_SHIPPING_TABLE_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14',NULL,NULL,9),(7448,'Table Method','MODULE_SHIPPING_TABLE_MODE','weight','The shipping cost is based on the order total or the total weight of the items ordered.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14',NULL,'tep_cfg_select_option(array(\'weight\', \'price\'), ',9),(7449,'Table Method Sort Order','MODULE_SHIPPING_TABLE_SORT_ORDER','70','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-24 17:14:14',NULL,NULL,9),(7450,'Enable Table Method','MODULE_SHIPPING_TABLE_STATUS','False','Do you want to offer table rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-02-22 16:42:12','2016-11-24 17:14:14',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7451,'Table Method Tax Class','MODULE_SHIPPING_TABLE_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7452,'Table Method Shipping Zone','MODULE_SHIPPING_TABLE_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7453,'Delivery Date Management','MODULE_SHIPPING_UPS_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',9),(7454,'Delivery Date ownership settings','MODULE_SHIPPING_UPS_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',9),(7455,'UPS Handling Fee','MODULE_SHIPPING_UPS_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59',NULL,NULL,9),(7456,'UPS Packaging?','MODULE_SHIPPING_UPS_PACKAGE','CP','CP - Your Packaging, ULE - UPS Letter, UT - UPS Tube, UBE - UPS Express Box','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59',NULL,NULL,9),(7457,'UPS Pickup Method','MODULE_SHIPPING_UPS_PICKUP','CC','How do you give packages to UPS? CC - Customer Counter, RDP - Daily Pickup, OTP - One Time Pickup, LC - Letter Center, OCA - On Call Air','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59',NULL,NULL,9),(7458,'UPS Residential Delivery?','MODULE_SHIPPING_UPS_RES','RES','Quote for Residential (RES) or Commercial Delivery (COM)','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59',NULL,NULL,9),(7459,'UPS Sort order of display.','MODULE_SHIPPING_UPS_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:01:59',NULL,NULL,9),(7460,'Enable UPS Shipping','MODULE_SHIPPING_UPS_STATUS','False','Do you want to offer UPS shipping?','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:46:54','2016-11-16 13:01:59',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7461,'UPS Tax Class','MODULE_SHIPPING_UPS_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7462,'UPS Shipping Methods','MODULE_SHIPPING_UPS_TYPES','1DM, 1DML, 1DA, 1DAL, 1DAPI, 1DP, 1DPL, 2DM, 2DML, 2DA, 2DAL, 3DS, GND, STD, XPR, XPRL, XDM, XDML, XPD','Select the UPS services to be offered.','BOX_CONFIGURATION_MODULE',13,NULL,'2016-11-16 13:01:59',NULL,'tep_cfg_select_multioption(array(\'1DM\',\'1DML\', \'1DA\', \'1DAL\', \'1DAPI\', \'1DP\', \'1DPL\', \'2DM\', \'2DML\', \'2DA\', \'2DAL\', \'3DS\',\'GND\', \'STD\', \'XPR\', \'XPRL\', \'XDM\', \'XDML\', \'XPD\'), ',9),(7463,'UPS Shipping Zone','MODULE_SHIPPING_UPS_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7464,'Delivery Date Management','MODULE_SHIPPING_USPS_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',9),(7465,'Delivery Date ownership settings','MODULE_SHIPPING_USPS_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',9),(7466,'Handling Fee','MODULE_SHIPPING_USPS_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02',NULL,NULL,9),(7467,'USPS Options','MODULE_SHIPPING_USPS_OPTIONS','Display weight, Display transit time','Select from the following the USPS options.','BOX_CONFIGURATION_MODULE',16,NULL,'2016-11-16 13:31:02',NULL,'tep_cfg_select_multioption(array(\'Display weight\', \'Display transit time\'), ',9),(7468,'Enter the USPS Password','MODULE_SHIPPING_USPS_PASSWORD','','See USERID, above.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02',NULL,NULL,9),(7469,'Which server to use','MODULE_SHIPPING_USPS_SERVER','test','An account at USPS is needed to use the Production server','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02',NULL,'tep_cfg_select_option(array(\'test\', \'production\'), ',9),(7470,'Sort Order','MODULE_SHIPPING_USPS_SORT_ORDER','80','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2016-11-16 13:31:02','2016-11-16 13:31:02',NULL,NULL,9),(7471,'Enable USPS Shipping','MODULE_SHIPPING_USPS_STATUS','False','Do you want to offer USPS shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-21 16:18:57','2016-11-16 13:31:02',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7472,'Tax Class','MODULE_SHIPPING_USPS_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7473,'Domestic Shipping Methods','MODULE_SHIPPING_USPS_TYPES','First Class, Priority Mail, Priority Mail Express','Select the domestic services to be offered:','BOX_CONFIGURATION_MODULE',14,NULL,'2016-11-16 13:31:02',NULL,'tep_cfg_select_multioption(array(\'First Class\', \'Priority Mail\', \'Priority Mail Express\'),',9),(7474,'Int\'l Shipping Methods','MODULE_SHIPPING_USPS_TYPES_INTL','Priority Mail Express International, Priority Mail International','Select the international services to be offered:','BOX_CONFIGURATION_MODULE',15,NULL,'2016-11-16 13:31:02',NULL,'tep_cfg_select_multioption(array(\'Priority Mail Express International\', \'Priority Mail International\'),',9),(7475,'Enter the USPS User ID','MODULE_SHIPPING_USPS_USERID','','Enter the USPS USERID assigned to you.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02',NULL,NULL,9),(7476,'Shipping Zone','MODULE_SHIPPING_USPS_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(7477,'Delivery Date Management','MODULE_SHIPPING_ZONESPERITEM_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',9),(7478,'Delivery Date ownership settings','MODULE_SHIPPING_ZONESPERITEM_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',9),(7479,'Zone 1 Geo Zone','MODULE_SHIPPING_ZONESPERITEM_GEO_ZONE_1','0','Select Geo Zone of this Zone 1.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,9),(7480,'Number of Zones','MODULE_SHIPPING_ZONESPERITEM_NUMBER_OF_ZONES','1','Number of zones needed.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:38:29',NULL,NULL,9),(7481,'Zone 1 Premium Additional Item Charge','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_ADDITIONAL_ITEM_CHARGE_1','0.00','Premium Additional Item Charge for this shipping zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,9),(7482,'Zone 1 Premium Free Delivery Amount','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_FREE_DELIVERY_AMOUNT_1','20.00','Amount of subtotal for free premium delivery for this shipping zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,9),(7483,'Zone 1 Premium Initial Item Charge','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_INITIAL_ITEM_CHARGE_1','4.50','Premium Initial Item Charge for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,9),(7484,'Zones Per Item Sort Order','MODULE_SHIPPING_ZONESPERITEM_SORT_ORDER','100','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-12-21 15:38:29',NULL,NULL,9),(7485,'Zone 1 Standard Additional Item Charge','MODULE_SHIPPING_ZONESPERITEM_STANDARD_ADDITIONAL_ITEM_CHARGE_1','0.50','Standard Additional Item Charge for this shipping zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,9),(7486,'Zone 1 Standard Free Delivery Amount','MODULE_SHIPPING_ZONESPERITEM_STANDARD_FREE_DELIVERY_AMOUNT_1','20.00','Amount of subtotal for free standard delivery for this shipping zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,9),(7487,'Zone 1 Standard Initial Item Charge','MODULE_SHIPPING_ZONESPERITEM_STANDARD_INITIAL_ITEM_CHARGE_1','2.50','Standard Initial Item Charge for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,9),(7488,'Enable Zones Per Item Method','MODULE_SHIPPING_ZONESPERITEM_STATUS','False','Do you want to offer zone rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-14 15:08:27','2016-12-21 15:38:29',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7489,'Zones Per Item Tax Class','MODULE_SHIPPING_ZONESPERITEM_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:38:29','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7490,'Zone 1 Shipping Table','MODULE_SHIPPING_ZONES_COST_1','3:8.50,7:10.50,99:20.00','Shipping rates to Zone 1 destinations based on a group of maximum order weights. Example: 3:8.50,7:10.50,... Weights less than or equal to 3 would cost 8.50 for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:47:33',NULL,NULL,9),(7491,'Zone 1 Countries','MODULE_SHIPPING_ZONES_COUNTRIES_1','US,CA','Comma separated list of two character ISO country codes that are part of Zone 1.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:47:33',NULL,NULL,9),(7492,'Delivery Date Management','MODULE_SHIPPING_ZONES_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',9),(7493,'Delivery Date ownership settings','MODULE_SHIPPING_ZONES_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',9),(7494,'Zone 1 Handling Fee','MODULE_SHIPPING_ZONES_HANDLING_1','0','Handling Fee for this shipping zone','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:47:33',NULL,NULL,9),(7495,'Zones Sort Order','MODULE_SHIPPING_ZONES_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:47:33',NULL,NULL,9),(7496,'Zones Enable Zones Method','MODULE_SHIPPING_ZONES_STATUS','False','Do you want to offer zone rate shipping?','BOX_CONFIGURATION_MODULE',0,'2017-05-29 13:48:31','2016-11-16 13:47:33',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7497,'Zones Tax Class','MODULE_SHIPPING_ZONES_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:47:33','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7498,'If no rates found allow complete order','MODULE_SHIPPING_ZONE_ALLOW_ERROR_PASS','False','Display \"please call us for a quote\" and allow complete order.','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-22 13:18:12',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7499,'Delivery Date Management','MODULE_SHIPPING_ZONE_TABLE_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',9),(7500,'Delivery Date ownership settings','MODULE_SHIPPING_ZONE_TABLE_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',9),(7501,'Handling Fee','MODULE_SHIPPING_ZONE_TABLE_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2017-01-05 14:27:17',NULL,NULL,9),(7502,'Sort Order','MODULE_SHIPPING_ZONE_TABLE_SORT_ORDER','40','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2017-01-05 14:27:17',NULL,NULL,9),(7503,'Enable Table Method','MODULE_SHIPPING_ZONE_TABLE_STATUS','True','Do you want to offer Zone Table rate shipping?','BOX_CONFIGURATION_MODULE',0,'2022-06-24 17:03:40','2017-01-05 14:27:17',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7504,'Tax Class','MODULE_SHIPPING_ZONE_TABLE_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2017-01-05 14:27:17','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',9),(7505,'Public API key','TRUSTPILOT_API_KEY','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',9),(7506,'Business password','TRUSTPILOT_API_PASSWORD','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',9),(7507,'Private API secret','TRUSTPILOT_API_SECRET','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',9),(7508,'Business username','TRUSTPILOT_API_USERNAME','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',9),(7509,'BCC Trustpilot email','TRUSTPILOT_BCC_EMAIL','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',9),(7510,'Business Unit Id','TRUSTPILOT_BUSINESS_UNIT_ID','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-12 17:42:38','','',9),(7511,'Select integration','TRUSTPILOT_CONNECT_VIA','bccMail','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','tep_cfg_select_option(array(\'bccMail\', \'API\'),',9),(7512,'Delay invite send (days)','TRUSTPILOT_INVITE_DELAY','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',9),(7513,'Filter orders by','TRUSTPILOT_INVITE_ORDER_AMOUNT_BY','ot_total','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','tep_cfg_select_option(array(\'ot_subtotal\', \'ot_total\'),',9),(7514,'Filter orders by amount, from','TRUSTPILOT_INVITE_ORDER_AMOUNT_FROM','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',9),(7515,'Filter orders by amount, not above','TRUSTPILOT_INVITE_ORDER_AMOUNT_TO','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',9),(7516,'Redirect URL','TRUSTPILOT_REDIRECT_URI','https://uk.trustpilot.com','https://www.trustpilot.com','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',9),(7517,'Sender Email','TRUSTPILOT_SENDER_EMAIL','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',9),(7518,'Sender Name','TRUSTPILOT_SENDER_NAME','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',9),(7519,'Status','TRUSTPILOT_STATUS','Disabled','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','tep_cfg_select_option(array(\'Disabled\', \'Enabled\'),',9),(7520,'Verify meta tag','TRUSTPILOT_VERIFY_META_TAG','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',9),(7522,'','','','','',NULL,'2018-03-21 14:47:35','2018-03-21 14:47:35',NULL,NULL,10),(7523,'Modules Sort','DD_MODULE_ORDER_TOTAL_SORT','ot_subtotal.php;ot_coupon.php;ot_gift_wrap.php;ot_loworderfee.php;ot_shipping.php;ot_gv.php;ot_shippingfee.php;ot_paymentfee.php;ot_bonus_points.php;ot_subtax.php;ot_tax.php;ot_total.php;ot_paid.php;ot_due.php;ot_fixed_payment_chg.php;ot_custom.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-09-28 11:28:21','2016-04-11 15:34:09',NULL,NULL,10),(7524,'Modules Sort','DD_MODULE_PAYMENT_SORT','cod.php;cash.php;paypalipn.php;sage_pay_server.php;offline.php;rbsworldpay_hosted.php;paypal_express.php;recurly.php;liqpay.php;klarna_checkout.php;amazon_payment.php;for_collect.php;multisafepay.php;paypal.php;paypal_pro_hs.php;pxpay.php;stripe_ds.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2018-03-22 13:24:41','2017-04-03 09:43:41',NULL,NULL,10),(7525,'Modules Sort','DD_MODULE_SHIPPING_SORT','flat.php;ups.php;freeshipper.php;zonetable.php;item.php;percent.php;table.php;usps.php;zones.php;zonesperitem.php;fedex1.php;dp.php','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-04-11 15:39:31',NULL,NULL,10),(7526,'Display billing address','DISPLAY_BILLING_ADDRESS','True','Display billing address on checkout and user account?','BOX_CONFIGURATION_MYSTORE',0,'2019-03-26 16:54:24','2019-03-26 16:54:24',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7530,'MAILCHIMP_API_KEY','MAILCHIMP_API_KEY','','','',NULL,NULL,NULL,NULL,NULL,10),(7531,'MAILCHIMP_STATUS','MAILCHIMP_STATUS','Disabled','','',NULL,NULL,NULL,NULL,NULL,10),(7532,'MAILCHIMP_STATUS_CUSTOMERS','MAILCHIMP_STATUS_CUSTOMERS','Disabled','','',NULL,NULL,NULL,NULL,NULL,10),(7533,'Installed Modules','MODULE_DROPSHIPPING_INSTALLED','','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,NULL,'2018-01-26 09:39:27',NULL,NULL,10),(7534,'Installed Modules','MODULE_LABEL_INSTALLED','','This is automatically updated. No need to edit.','BOX_CONFIGURATION_MODULE',0,NULL,'2019-03-27 15:11:27',NULL,NULL,10),(7535,'Bonus apply minimum cart','MODULE_ORDER_TOTAL_BONUS_POINTS_MINIMUM_CART','0','Subtotal for allow to apply bonus points','6',4,NULL,'2020-10-09 13:42:05',NULL,NULL,10),(7536,'Order Status for Points applying','MODULE_ORDER_TOTAL_BONUS_POINTS_ORDER_STATUS_ID','3','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-10-11 15:53:24','\\common\\helpers\\Order::get_status_name','tep_cfg_select_multioption_order_statuses(',10),(7537,'Set status for covered order','MODULE_ORDER_TOTAL_BONUS_POINTS_ORDER_STATUS_ID_COVERS','2','Covered order','BOX_CONFIGURATION_MODULE',0,NULL,'2017-10-11 15:53:24','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7538,'Sort Order','MODULE_ORDER_TOTAL_BONUS_POINTS_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-10-11 15:53:24',NULL,NULL,10),(7539,'Display Bonus Points','MODULE_ORDER_TOTAL_BONUS_POINTS_STATUS','true','Do you want this module to display?','BOX_CONFIGURATION_MODULE',1,'2017-10-11 16:41:24','2017-10-11 15:53:24',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7540,'Tax Class','MODULE_ORDER_TOTAL_BONUS_POINTS_TAX_CLASS','0','Use the following tax class on the payment fee.','6',7,NULL,'2020-10-09 13:42:05','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7541,'Re-calculate Tax','MODULE_ORDER_TOTAL_COUPON_CALC_TAX','None','Re-Calculate Tax','BOX_CONFIGURATION_MODULE',7,NULL,'2016-11-16 12:12:22',NULL,'tep_cfg_select_option(array(\'None\', \'Standard\', \'Credit Note\'), ',10),(7542,'Include Shipping','MODULE_ORDER_TOTAL_COUPON_INC_SHIPPING','false','Include Shipping in calculation','BOX_CONFIGURATION_MODULE',5,NULL,'2016-11-16 12:12:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7543,'Include Tax','MODULE_ORDER_TOTAL_COUPON_INC_TAX','false','Include Tax in calculation.','BOX_CONFIGURATION_MODULE',6,NULL,'2016-11-16 12:12:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7544,'One coupon per order only.','MODULE_ORDER_TOTAL_COUPON_ONE_PER_ORDER_ONLY','False','Allow only 1 coupon per order.','6',3,NULL,'2021-11-03 17:02:00',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7545,'Sort Order','MODULE_ORDER_TOTAL_COUPON_SORT_ORDER','20','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:12:22',NULL,NULL,10),(7546,'Display Total','MODULE_ORDER_TOTAL_COUPON_STATUS','true','Do you want to display the Discount Coupon value?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:01:31','2016-11-16 12:12:22',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7547,'Tax Class','MODULE_ORDER_TOTAL_COUPON_TAX_CLASS','0','Use the following tax class when treating Discount Coupon as Credit Note.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 12:12:22','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7548,'Sort Order','MODULE_ORDER_TOTAL_DUE_SORT_ORDER','140','Sort order of display.','BOX_CONFIGURATION_MODULE',150,'2017-10-11 15:53:32','2017-04-01 11:18:33',NULL,NULL,10),(7549,'Display Admount Due','MODULE_ORDER_TOTAL_DUE_STATUS','true','Do you want to display the Admount Due?','BOX_CONFIGURATION_MODULE',150,NULL,'2017-04-01 11:18:33',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7550,'Allow Gift Message for order','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE','False','Allow Gift Message for whole order','6',3,NULL,'2020-10-09 13:42:05',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),',10),(7551,'Gift Message max characters count','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_CHARS','','Gift Message max characters count, live empty to ignore','6',6,NULL,'2020-10-09 13:42:05',NULL,NULL,10),(7552,'Gift Message price','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_COST','','Gift Message price','6',4,NULL,'2020-10-09 13:42:05',NULL,NULL,10),(7553,'Gift Message max words count','MODULE_ORDER_TOTAL_GIFT_WRAP_MESSAGE_WORDS','','Gift Message max words count, live empty to ignore','6',5,NULL,'2020-10-09 13:42:05',NULL,NULL,10),(7554,'Sort Order','MODULE_ORDER_TOTAL_GIFT_WRAP_SORT_ORDER','30','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:46:52',NULL,NULL,10),(7555,'Display Gift Wrap Order Fee','MODULE_ORDER_TOTAL_GIFT_WRAP_STATUS','true','Do you want to display the Gift Wrap Order Fee?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:02:22','2016-11-16 12:46:52',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7556,'Tax Class','MODULE_ORDER_TOTAL_GIFT_WRAP_TAX_CLASS','3','Use the following tax class on the Gift Wrap Order Fee.','BOX_CONFIGURATION_MODULE',7,NULL,'2016-11-16 12:46:52','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7557,'Re-calculate Tax','MODULE_ORDER_TOTAL_GV_CALC_TAX','None','Re-Calculate Tax','BOX_CONFIGURATION_MODULE',7,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'None\', \'Standard\', \'Credit Note\'), ',10),(7558,'Credit including Tax','MODULE_ORDER_TOTAL_GV_CREDIT_TAX','false','Add tax to purchased Gift Voucher when crediting to Account','BOX_CONFIGURATION_MODULE',8,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7559,'Include Shipping','MODULE_ORDER_TOTAL_GV_INC_SHIPPING','true','Include Shipping in calculation','BOX_CONFIGURATION_MODULE',5,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7560,'Include Tax','MODULE_ORDER_TOTAL_GV_INC_TAX','true','Include Tax in calculation.','BOX_CONFIGURATION_MODULE',6,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7561,'Allowed Order Statuses','MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID','4, 3, 2','Select the status of orders to be processed.','BOX_CONFIGURATION_MODULE',13,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_multioption_order_statuses(',10),(7562,'Set status for covered order','MODULE_ORDER_TOTAL_GV_ORDER_STATUS_ID_COVERS','2','Covered order','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-27 15:46:30','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7563,'Queue Purchases','MODULE_ORDER_TOTAL_GV_QUEUE','true','Do you want to queue purchases of the Gift Voucher?','BOX_CONFIGURATION_MODULE',3,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7564,'Sort Order','MODULE_ORDER_TOTAL_GV_SORT_ORDER','60','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:44:20',NULL,NULL,10),(7565,'Display Total','MODULE_ORDER_TOTAL_GV_STATUS','true','Do you want to display the Gift Voucher value?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 13:44:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7566,'Tax Class','MODULE_ORDER_TOTAL_GV_TAX_CLASS','0','Use the following tax class when treating Gift Voucher as Credit Note.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:44:20','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7567,'Installed Modules','MODULE_ORDER_TOTAL_INSTALLED','ot_subtotal.php;ot_coupon.php;ot_gift_wrap.php;ot_loworderfee.php;ot_shipping.php;ot_gv.php;ot_shippingfee.php;ot_paymentfee.php;ot_bonus_points.php;ot_subtax.php;ot_tax.php;ot_total.php;ot_paid.php;ot_due.php;ot_refund.php','List of order_total module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ot_subtotal.php;ot_tax.php;ot_shipping.php;ot_total.php)','BOX_CONFIGURATION_MODULE',0,'2020-10-09 13:42:16','2003-07-17 10:29:22',NULL,NULL,10),(7568,'Attach Low Order Fee On Orders Made','MODULE_ORDER_TOTAL_LOWORDERFEE_DESTINATION','both','Attach low order fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,NULL,'2016-11-16 13:47:46',NULL,'tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',10),(7569,'Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_FEE','5','Low order fee.','BOX_CONFIGURATION_MODULE',5,NULL,'2016-11-16 13:47:46','currencies->format',NULL,10),(7570,'Allow Low Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_LOW_ORDER_FEE','false','Do you want to allow low order fees?','BOX_CONFIGURATION_MODULE',3,NULL,'2016-11-16 13:47:46',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7571,'Order Fee For Orders Under','MODULE_ORDER_TOTAL_LOWORDERFEE_ORDER_UNDER','50','Add the low order fee to orders under this amount.','BOX_CONFIGURATION_MODULE',4,NULL,'2016-11-16 13:47:46','currencies->format',NULL,10),(7572,'Sort Order','MODULE_ORDER_TOTAL_LOWORDERFEE_SORT_ORDER','40','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:47:46',NULL,NULL,10),(7573,'Display Low Order Fee','MODULE_ORDER_TOTAL_LOWORDERFEE_STATUS','true','Do you want to display the low order fee?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 13:47:46',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7574,'Tax Class','MODULE_ORDER_TOTAL_LOWORDERFEE_TAX_CLASS','0','Use the following tax class on the low order fee.','BOX_CONFIGURATION_MODULE',7,NULL,'2016-11-16 13:47:46','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7575,'Sort Order','MODULE_ORDER_TOTAL_PAID_SORT_ORDER','130','Sort order of display.','BOX_CONFIGURATION_MODULE',140,'2017-10-11 15:53:32','2017-04-01 11:18:23',NULL,NULL,10),(7576,'Display Admount Paid','MODULE_ORDER_TOTAL_PAID_STATUS','true','Do you want to display the Admount Paid?','BOX_CONFIGURATION_MODULE',140,NULL,'2017-04-01 11:18:23',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7577,'Allow Payment Fee','MODULE_ORDER_TOTAL_PAYMENTFEE_ALLOW_FEE','false','Do you want to allow payment fees?','BOX_CONFIGURATION_MODULE',3,NULL,'2017-01-13 11:37:59',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7578,'Attach Payment Fee On Orders Made','MODULE_ORDER_TOTAL_PAYMENTFEE_DESTINATION','both','Attach payment fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,NULL,'2017-01-13 11:37:59',NULL,'tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',10),(7579,'Sort Order','MODULE_ORDER_TOTAL_PAYMENTFEE_SORT_ORDER','80','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-01-13 11:37:59',NULL,NULL,10),(7580,'Display Payment Fee','MODULE_ORDER_TOTAL_PAYMENTFEE_STATUS','true','Do you want to display the payment fee?','BOX_CONFIGURATION_MODULE',1,NULL,'2017-01-13 11:37:59',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7581,'Tax Class','MODULE_ORDER_TOTAL_PAYMENTFEE_TAX_CLASS','0','Use the following tax class on the payment fee.','BOX_CONFIGURATION_MODULE',7,NULL,'2017-01-13 11:37:59','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7582,'Sort Order','MODULE_ORDER_TOTAL_REFUND_SORT_ORDER','160','Sort order of display.','6',160,'2020-10-09 13:42:16','2020-10-09 13:42:16',NULL,NULL,10),(7583,'Display Amount Refund','MODULE_ORDER_TOTAL_REFUND_STATUS','true','Do you want to display the Amount Refund?','6',160,NULL,'2020-10-09 13:42:16',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7584,'Allow Shipping Fee','MODULE_ORDER_TOTAL_SHIPPINGFEE_ALLOW_FEE','false','Do you want to allow shipping fees?','BOX_CONFIGURATION_MODULE',3,NULL,'2017-01-13 11:37:45',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7585,'Attach Shipping Fee on Orders Made','MODULE_ORDER_TOTAL_SHIPPINGFEE_DESTINATION','both','Attach shipping fee for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',6,NULL,'2017-01-13 11:37:45',NULL,'tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',10),(7586,'Sort Order','MODULE_ORDER_TOTAL_SHIPPINGFEE_SORT_ORDER','70','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-01-13 11:37:45',NULL,NULL,10),(7587,'Display Shipping Fee','MODULE_ORDER_TOTAL_SHIPPINGFEE_STATUS','true','Do you want to display the shipping Fee?','BOX_CONFIGURATION_MODULE',1,NULL,'2017-01-13 11:37:45',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7588,'Tax Class','MODULE_ORDER_TOTAL_SHIPPINGFEE_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',7,NULL,'2017-01-13 11:37:45','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7589,'Provide Free Shipping For Orders Made','MODULE_ORDER_TOTAL_SHIPPING_DESTINATION','both','Provide free shipping for orders sent to the set destination.','BOX_CONFIGURATION_MODULE',5,NULL,'2016-11-16 13:51:20',NULL,'tep_cfg_select_option(array(\'national\', \'international\', \'both\'), ',10),(7590,'Allow Free Shipping','MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING','false','Do you want to allow free shipping?','BOX_CONFIGURATION_MODULE',3,NULL,'2016-11-16 13:51:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7591,'Free Shipping For Orders Over','MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER','100','Provide free shipping for orders over the set amount.','BOX_CONFIGURATION_MODULE',4,NULL,'2016-11-16 13:51:20','currencies->format',NULL,10),(7592,'Limit shipping results sort mode','MODULE_ORDER_TOTAL_SHIPPING_LIMIT_RESULT_SORT','Cheapest first','','BOX_CONFIGURATION_MODULE',7,NULL,'2019-03-27 14:56:48',NULL,'tep_cfg_select_option(array(\'Cheapest first\', \'Modules sort order\'), ',10),(7593,'Number of shipping results','MODULE_ORDER_TOTAL_SHIPPING_RESULT_COUNT','','Limit results (if empty - unlimited).','BOX_CONFIGURATION_MODULE',6,NULL,'2019-03-27 14:56:48',NULL,NULL,10),(7594,'Sort Order','MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER','50','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 13:51:20',NULL,NULL,10),(7595,'Display Shipping','MODULE_ORDER_TOTAL_SHIPPING_STATUS','true','Do you want to display the order shipping cost?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 13:51:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7596,'Sort Order','MODULE_ORDER_TOTAL_SUBTAX_SORT_ORDER','100','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2017-02-22 14:10:20',NULL,NULL,10),(7597,'Display Subtotal for taxation','MODULE_ORDER_TOTAL_SUBTAX_STATUS','true','Do you want to display the subtotal for taxation value?','BOX_CONFIGURATION_MODULE',1,NULL,'2017-02-22 14:10:20',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7598,'Sort Order','MODULE_ORDER_TOTAL_SUBTOTAL_SORT_ORDER','10','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:10:43',NULL,NULL,10),(7599,'Display Sub-Total','MODULE_ORDER_TOTAL_SUBTOTAL_STATUS','true','Do you want to display the order sub-total cost?','BOX_CONFIGURATION_MODULE',1,'2018-02-26 16:01:29','2016-11-16 12:10:43',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7600,'Sort Order','MODULE_ORDER_TOTAL_TAX_SORT_ORDER','110','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:08:32',NULL,NULL,10),(7601,'Display Tax','MODULE_ORDER_TOTAL_TAX_STATUS','true','Do you want to display the order tax value?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 12:08:32',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7604,'Sort Order','MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER','120','Sort order of display.','BOX_CONFIGURATION_MODULE',2,'2017-10-11 15:53:32','2016-11-16 12:06:52',NULL,NULL,10),(7605,'Display Total','MODULE_ORDER_TOTAL_TOTAL_STATUS','true','Do you want to display the total order value?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-11-16 12:06:52',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7606,'2CheckOut Merchant Notifications','MODULE_PAYMENT_2CHECKOUT_EMAIL_MERCHANT','True','Should 2CheckOut e-mail a receipt to the store owner?','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7607,'2CheckOut Login/Store Number','MODULE_PAYMENT_2CHECKOUT_LOGIN','18157','Login/Store Number used for the 2CheckOut service','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21',NULL,NULL,10),(7608,'2CheckOut Set Order Status','MODULE_PAYMENT_2CHECKOUT_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7609,'2CheckOut Sort order of display.','MODULE_PAYMENT_2CHECKOUT_SORT_ORDER','100','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-08 16:55:21',NULL,NULL,10),(7610,'Enable 2CheckOut Module','MODULE_PAYMENT_2CHECKOUT_STATUS','False','Do you want to accept 2CheckOut payments?','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7611,'2CheckOut Transaction Mode','MODULE_PAYMENT_2CHECKOUT_TESTMODE','Test','Transaction mode used for the 2Checkout service','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-08 16:55:21',NULL,'tep_cfg_select_option(array(\'Test\', \'Production\'), ',10),(7612,'2CheckOut Payment Zone','MODULE_PAYMENT_2CHECKOUT_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-08 16:55:21','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7613,'Authorizenet Customer Notifications','MODULE_PAYMENT_AUTHORIZENET_EMAIL_CUSTOMER','False','Should Authorize.Net e-mail a receipt to the customer?','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7614,'Authorizenet Login Username','MODULE_PAYMENT_AUTHORIZENET_LOGIN','testing','The login username used for the Authorize.net service','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,NULL,10),(7615,'Authorizenet Transaction Method','MODULE_PAYMENT_AUTHORIZENET_METHOD','Credit Card','Transaction method used for processing orders','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,'tep_cfg_select_option(array(\'Credit Card\', \'eCheck\'), ',10),(7616,'Authorizenet - Set Order Status','MODULE_PAYMENT_AUTHORIZENET_ORDER_STATUS_ID','0','Authorizenet - Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7617,'Authorizenet - Sort order of display.','MODULE_PAYMENT_AUTHORIZENET_SORT_ORDER','80','Authorizenet - Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:51:38',NULL,NULL,10),(7618,'Enable Authorize.net Module','MODULE_PAYMENT_AUTHORIZENET_STATUS','False','Do you want to accept Authorize.net payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:33','2016-04-11 15:51:38',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7619,'Authorizenet Transaction Mode','MODULE_PAYMENT_AUTHORIZENET_TESTMODE','Test','Transaction mode used for processing orders','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,'tep_cfg_select_option(array(\'Test\', \'Production\'), ',10),(7620,'Authorizenet Transaction Key','MODULE_PAYMENT_AUTHORIZENET_TXNKEY','Test','Transaction Key used for encrypting TP data','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:51:38',NULL,NULL,10),(7621,'Authorizenet - Payment Zone','MODULE_PAYMENT_AUTHORIZENET_ZONE','0','Authorizenet - If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:51:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7622,'CASH Set Order Status','MODULE_PAYMENT_CASH_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2018-01-17 11:52:46','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7623,'CASH Sort order of display.','MODULE_PAYMENT_CASH_SORT_ORDER','60','Sort order of CASH display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:34:41','2018-01-17 11:52:46',NULL,NULL,10),(7624,'CASH Enable Cash Payment Module','MODULE_PAYMENT_CASH_STATUS','False','Do you want to accept Cash Payment?','BOX_CONFIGURATION_MODULE',1,'2018-03-22 13:24:29','2018-01-17 11:52:46',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7625,'CASH Payment Zone','MODULE_PAYMENT_CASH_ZONED','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2018-01-17 11:52:46','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7626,'CC Split Credit Card E-Mail Address','MODULE_PAYMENT_CC_EMAIL','','If an e-mail address is entered, the middle digits of the credit card number will be sent to the e-mail address (the outside digits are stored in the database with the middle digits censored)','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:49:38',NULL,NULL,10),(7627,'CC Set Order Status','MODULE_PAYMENT_CC_ORDER_STATUS_ID','0','Set the status of CC orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:49:38','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7628,'CC Sort order of display.','MODULE_PAYMENT_CC_SORT_ORDER','60','Sort order of CC display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:49:38',NULL,NULL,10),(7629,'CC Enable Credit Card Module','MODULE_PAYMENT_CC_STATUS','True','Do you want to accept credit card payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:31','2016-04-11 15:49:38',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7630,'CC Payment Zone','MODULE_PAYMENT_CC_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:49:38','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7631,'COD Set Order Status','MODULE_PAYMENT_COD_ORDER_STATUS_ID','100007','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2018-01-11 15:06:47','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7632,'COD Sort order of display.','MODULE_PAYMENT_COD_SORT_ORDER','40','Sort order of COD display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:16:52','2018-01-11 15:06:47',NULL,NULL,10),(7633,'COD Enable Cash On Delivery Module','MODULE_PAYMENT_COD_STATUS','True','Do you want to accept Cash On Delevery payments?','BOX_CONFIGURATION_MODULE',1,NULL,'2018-01-11 15:06:47',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7634,'COD Payment Zone','MODULE_PAYMENT_COD_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2018-01-11 15:06:47','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7635,'EFSnet Transaction Method','MODULE_PAYMENT_EFSNET_METHOD','CreditCardCharge','Transaction method used for processing orders','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06',NULL,'tep_cfg_select_option(array(\'CreditCardCharge\',\'CreditCardAuthorize\'), ',10),(7636,'EFSnet Set Order Status','MODULE_PAYMENT_EFSNET_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7637,'EFSnet Sort order of display.','MODULE_PAYMENT_EFSNET_SORT_ORDER','90','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:57:06',NULL,NULL,10),(7638,'Enable EFSnet Module','MODULE_PAYMENT_EFSNET_STATUS','False','Do you want to accept EFSNet payments?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:34','2016-04-11 15:57:06',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7639,'EFSnet Login Username','MODULE_PAYMENT_EFSNET_STOREID','testing','The StoreID used for the EFSNet service','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06',NULL,NULL,10),(7640,'EFSnet Transaction Key','MODULE_PAYMENT_EFSNET_STOREKEY','Test','Store Key used for encrypting data','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06',NULL,NULL,10),(7641,'EFSnet Transaction Mode','MODULE_PAYMENT_EFSNET_TESTMODE','Test','Transaction mode used for processing orders','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:57:06',NULL,'tep_cfg_select_option(array(\'Test\', \'Production\'), ',10),(7642,'EFSnet Payment Zone','MODULE_PAYMENT_EFSNET_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:57:06','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7643,'Free Charge Set Order Status','MODULE_PAYMENT_FREECHARGER_ORDER_STATUS_ID','3','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:50:23','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7644,'Free Charge Sort order of display.','MODULE_PAYMENT_FREECHARGER_SORT_ORDER','70','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:50:23',NULL,NULL,10),(7645,'Enable Free Charge Module','MODULE_PAYMENT_FREECHARGER_STATUS','False','Do you want to accept Free Charge payments?','BOX_CONFIGURATION_MODULE',1,'2016-04-12 14:50:32','2016-04-11 15:50:23',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7646,'Free Charge Payment Zone','MODULE_PAYMENT_FREECHARGER_ZONE','4','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:50:23','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7647,'GeoTrust Merchant ID','MODULE_PAYMENT_GEOTRUST_MERCHANT_ID','serial #','Merchant Serial # to use for the GEOTRUST QuickPayments service','BOX_CONFIGURATION_MODULE',2,NULL,'2016-02-05 17:19:45',NULL,NULL,10),(7648,'GeoTrust Set Order Status','MODULE_PAYMENT_GEOTRUST_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-02-05 17:19:45','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7649,'GeoTrust Sort order of display.','MODULE_PAYMENT_GEOTRUST_SORT_ORDER','40','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-02-05 17:19:45',NULL,NULL,10),(7650,'Enable GeoTrust QuickPayments Module','MODULE_PAYMENT_GEOTRUST_STATUS','False','Do you want to accept GeoTrust QuickPayments?','BOX_CONFIGURATION_MODULE',1,'2016-04-12 14:50:29','2016-02-05 17:19:45',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7651,'GeoTrust Payment Zone','MODULE_PAYMENT_GEOTRUST_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-02-05 17:19:45','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7652,'Installed Modules','MODULE_PAYMENT_INSTALLED','paypal_partner.php;sage_pay_server.php;stripe_checkout.php;cod.php;offline.php','List of payment module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: cc.php;cod.php;paypal.php)','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:16:52','2003-07-17 10:29:22',NULL,NULL,10),(7653,'Order Status','MODULE_PAYMENT_INVOICE_ORDER_STATUS_ID','1','Festlegung des Status für Bestellungen, welche mit dieser Zahlungsweise durchgeführt werden.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:46:07','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7654,'Reihenfolge der Anzeige','MODULE_PAYMENT_INVOICE_SORT_ORDER','50','Niedrigste wird zuerst angezeigt.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:46:07',NULL,NULL,10),(7655,'Rechnung','MODULE_PAYMENT_INVOICE_STATUS','False','Wollen Sie Zahlungen per Rechnung anbieten?','BOX_CONFIGURATION_MODULE',0,'2016-04-12 14:50:30','2016-04-11 15:46:07',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7656,'Zone für diese Zahlungsweise','MODULE_PAYMENT_INVOICE_ZONE','3','Wenn Sie eine Zone auswählen, wird diese Zahlungsweise nur in dieser Zone angeboten.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:46:07','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7657,'Set Order Status','MODULE_PAYMENT_LIQPAY_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',4,NULL,'2018-01-26 15:33:32','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7658,'Money Order Set Order Status','MODULE_PAYMENT_MONEYORDER_ORDER_STATUS_ID','1','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2016-04-11 15:48:09','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7659,'Money Order Make Payable to:','MODULE_PAYMENT_MONEYORDER_PAYTO','','Who should payments be made payable to?','BOX_CONFIGURATION_MODULE',1,NULL,'2016-04-11 15:48:09',NULL,NULL,10),(7660,'Money Order Sort order of display.','MODULE_PAYMENT_MONEYORDER_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2016-04-13 17:09:07','2016-04-11 15:48:09',NULL,NULL,10),(7661,'Enable Check/Money Order Module','MODULE_PAYMENT_MONEYORDER_STATUS','True','Do you want to accept Check/Money Order payments?','BOX_CONFIGURATION_MODULE',1,'2016-04-13 17:08:47','2016-04-11 15:48:09',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7662,'Money Order Payment Zone','MODULE_PAYMENT_MONEYORDER_ZONE','4','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2016-04-11 15:48:09','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7663,'OFFLINE Order Status','MODULE_PAYMENT_OFFLINE_ORDER_STATUS_ID','0','Set the status of orders made with this payment module to this value','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-03 11:25:11','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7664,'OFFLINE Sort order of display.','MODULE_PAYMENT_OFFLINE_SORT_ORDER','50','Sort order of OFFLINE display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2022-07-25 09:16:52','2017-04-03 11:25:11',NULL,NULL,10),(7665,'OFFLINE Enable Module','MODULE_PAYMENT_OFFLINE_STATUS','False','Do you want to accept OFFLINE payments?','BOX_CONFIGURATION_MODULE',1,'2018-01-12 09:59:49','2017-04-03 11:25:11',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7666,'OFFLINE Payment Zone','MODULE_PAYMENT_OFFLINE_ZONE','0','If a zone is selected, only enable this payment method for that zone.','BOX_CONFIGURATION_MODULE',2,NULL,'2017-04-03 11:25:11','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7667,'PayPal IPN Add Shipping to Amount','MODULE_PAYMENT_PAYPALIPN_ADD_SHIPPING_TO_AMOUNT','False','Add shipping amount to order amount? (will set shipping amount to $0 in PayPal)','6',5,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7668,'PayPal IPN Add Tax to Amount','MODULE_PAYMENT_PAYPALIPN_ADD_TAX_TO_AMOUNT','False','Add tax amount to order amount? (will set tax amount to $0 in PayPal)','6',5,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7669,'PayPal IPN Allowed Currencies','MODULE_PAYMENT_PAYPALIPN_ALLOWED_CURRENCIES','GBP,EUR,USD','Allowed currencies in which customers can pay.<br>Allowed by PayPal: USD,EUR,GBP,CAD,JPY<br>Allowed in your shop: GBP,EUR,USD<br>To add more currencies to your shop go to Localization->Currencies.','6',9,NULL,'2021-11-16 13:52:41',NULL,'',10),(7670,'PayPal Transactions Cancel Order Status','MODULE_PAYMENT_PAYPALIPN_CANCEL_ORDER_STATUS_ID','5','','6',0,NULL,'2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7671,'or API Certificate','MODULE_PAYMENT_PAYPALIPN_CERTIFICATE','','The certificate to use for the PayPal API service.','6',0,NULL,'2021-11-16 13:52:41',NULL,'cfg_upload_file(',10),(7672,'API Application Client ID','MODULE_PAYMENT_PAYPALIPN_CLIENT_ID','','The Client ID of app','6',0,NULL,'2021-11-16 13:52:41',NULL,'',10),(7673,'PayPal IPN Use cURL','MODULE_PAYMENT_PAYPALIPN_CURL','False','Use cURL to communicate with PayPal?<br>cURL has been <b>DETECTED</b> in your system','6',4,NULL,'2021-11-16 09:30:10',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7674,'PayPal IPN Debug Email','MODULE_PAYMENT_PAYPALIPN_DEBUG_EMAIL','','PayPal IPN Debug Email','6',15,NULL,'2021-11-16 13:52:41',NULL,'',10),(7675,'PayPal IPN Default Currency','MODULE_PAYMENT_PAYPALIPN_DEFAULT_CURRENCY','GBP','Default currency to use when customer try to pay in a NON allowed (because of PayPal or you) currency','6',10,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array (\n 0 => \'GBP\',\n 1 => \'EUR\',\n 2 => \'USD\',\n), ',10),(7676,'PayPal IPN ID','MODULE_PAYMENT_PAYPALIPN_ID','paypal.sandbox.business@holbi.co.uk','Your business ID at PayPal. Usually the email address you signed up with. You can create a free PayPal account at <a href=\"http://www.paypal.com/\" target=\"_blank\">http://www.paypal.com</a>.','6',2,NULL,'2021-11-16 13:52:41',NULL,'',10),(7677,'PayPal IPN Notify URL','MODULE_PAYMENT_PAYPALIPN_NOTIFY_URL','callback/paypal-notify','Exact location in which your callback/paypal-notify resides.','6',3,NULL,'2021-11-16 13:52:41',NULL,'\\common\\modules\\orderPayment\\urlchecker(',10),(7678,'PayPal IPN Set Status Before Payment','MODULE_PAYMENT_PAYPALIPN_ORDER_BEFORE_PAYMENT_ID','1','Set the status of ordersbefore redirect to Gateway','6',14,NULL,'2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7679,'PayPal IPN Set Order Status','MODULE_PAYMENT_PAYPALIPN_ORDER_STATUS_ID','100006','Set the status of orders made with this payment module to this value','6',14,NULL,'2021-11-16 13:52:41','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7680,'API Password','MODULE_PAYMENT_PAYPALIPN_PASSWORD','','The password to use for the PayPal API service.','6',0,NULL,'2021-11-16 13:52:41',NULL,'',10),(7681,'Use API Signature','MODULE_PAYMENT_PAYPALIPN_SIGNATURE','','The signature to use for the PayPal API service.','6',0,NULL,'2021-11-16 13:52:41',NULL,'',10),(7682,'PayPal IPN Sort order of display.','MODULE_PAYMENT_PAYPALIPN_SORT_ORDER','80','Sort order of display. Lowest is displayed first.','6',12,'2021-11-16 13:52:41','2021-11-16 13:52:41',NULL,'',10),(7683,'Allow PayPal IPN','MODULE_PAYMENT_PAYPALIPN_STATUS','True','Do you want to accept PayPal IPN payments and notifications?','6',1,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7684,'PayPal IPN Test Mode','MODULE_PAYMENT_PAYPALIPN_TEST_MODE','True','Run in TEST MODE? If so, you will be able to send TEST IPN from Admin->PayPal_IPN->Test_IPN, BUT you will not be able to receive real IPN\'s from PayPal.','6',11,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7685,'PayPal IPN Update Stock Before Payment','MODULE_PAYMENT_PAYPALIPN_UPDATE_STOCK_BEFORE_PAYMENT','False','Should Products Stock be updated even when the payment is not yet COMPLETED?','6',6,NULL,'2021-11-16 13:52:41',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7686,'API Username','MODULE_PAYMENT_PAYPALIPN_USERNAME','','The username to use for the PayPal API service.','6',0,NULL,'2021-11-16 13:52:41',NULL,'',10),(7687,'PayPal IPN Payment Zone','MODULE_PAYMENT_PAYPALIPN_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',13,NULL,'2021-11-16 13:52:41','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7688,'API Application Client Secret Key','MODULE_PAYMENT_PPAYPALIPN_CLIENT_SECRET','','The Client Secret Key of app','6',0,NULL,'2021-11-16 13:52:41',NULL,'',10),(7689,'Callback Password','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_CALLBACK_PASSWORD','','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,NULL,10),(7690,'Debug E-Mail Address','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_DEBUG_EMAIL','','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,NULL,10),(7691,'Installation ID','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_INSTALLATION_ID','','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,NULL,10),(7692,'MD5 Password','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_MD5_PASSWORD','','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,NULL,10),(7693,'Set Order Status','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_ORDER_STATUS_ID','100006','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7694,'Set Preparing Order Status','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_PREPARE_ORDER_STATUS_ID','1','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7695,'Signaturefields','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_SIGNATUREFIELDS','--none--','Select Signaturefields. Please copy and past this value to worldpay: <b><span id=\"signature\"></span></b>','6',0,NULL,'2021-11-03 17:01:14',NULL,'select_multioption(array(\'amount\',\'currency\',\'cartId\'), ',10),(7696,'Sort order of display.','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_SORT_ORDER','20','','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:34:41','2017-04-08 14:31:29',NULL,NULL,10),(7697,'Enable WorldPay Hosted Payment Pages','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_STATUS','False','','BOX_CONFIGURATION_MODULE',0,'2018-01-11 16:18:09','2017-04-08 14:31:29',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7698,'Test Mode','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TESTMODE','True','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7699,'Transactions Order Status Level','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TRANSACTIONS_ORDER_STATUS_ID','1','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7700,'Transaction Method','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_TRANSACTION_METHOD','Capture','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29',NULL,'tep_cfg_select_option(array(\'Pre-Authorization\', \'Capture\'), ',10),(7701,'Payment Zone','MODULE_PAYMENT_RBSWORLDPAY_HOSTED_ZONE','0','','BOX_CONFIGURATION_MODULE',0,NULL,'2017-04-08 14:31:29','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7702,'Skip 3D secure amount','MODULE_PAYMENT_SAGE_PAY_3DS_SKIP','','Skip 3D secure verification when paid by token on orders below','6',100,NULL,'2021-11-16 09:33:25',NULL,NULL,10),(7703,'Account login','MODULE_PAYMENT_SAGE_PAY_SERVER_ACCOUNT','','Account login to get transaction details','6',0,NULL,'2021-11-16 09:33:25','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',10),(7704,'Account Password','MODULE_PAYMENT_SAGE_PAY_SERVER_ACCOUNT_PASSWORD','','Account password to get transaction details','6',0,NULL,'2021-11-16 09:33:25','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',10),(7705,'cURL Program Location','MODULE_PAYMENT_SAGE_PAY_SERVER_CURL','/usr/bin/curl','The location to the cURL program application.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:11:50',NULL,NULL,10),(7706,'Save order before payment','MODULE_PAYMENT_SAGE_PAY_SERVER_ORDER_BEFORE_PAYMENT','False','Save order before redirect to payment gateway','6',0,NULL,'2021-12-24 10:27:07',NULL,'tep_cfg_select_option(array(\'True\', \'False\', \'Temp\'), ',10),(7707,'Set Order Status','MODULE_PAYMENT_SAGE_PAY_SERVER_ORDER_STATUS_ID','100006','Set the status of orders made with this payment module to this value','6',0,NULL,'2021-11-16 09:33:25','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7708,'Profile Payment Page','MODULE_PAYMENT_SAGE_PAY_SERVER_PROFILE_PAGE','Normal','Profile page to use for the payment page.','6',0,NULL,'2021-11-16 09:33:25',NULL,'tep_cfg_select_option(array(\'Normal\', \'Low\'), ',10),(7709,'Sort order of display.','MODULE_PAYMENT_SAGE_PAY_SERVER_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:16:52','2021-11-16 09:33:25',NULL,NULL,10),(7710,'Enable Sage Pay Server Module','MODULE_PAYMENT_SAGE_PAY_SERVER_STATUS','True','Do you want to accept Sage Pay Server payments?','6',0,'2022-06-24 17:49:50','2021-11-16 09:33:25',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7711,'T3M verification','MODULE_PAYMENT_SAGE_PAY_SERVER_T3M_VERIFICATION','Info','Info - ignore if not available instantly, Optional - check for updates for up to 3 days, required - do not accept transaction if none t3m info available','6',0,NULL,'2021-11-16 09:33:25',NULL,'tep_cfg_select_option(array(\'Info\', \'Optional\', \'Required\'), ',10),(7712,'Transaction Method','MODULE_PAYMENT_SAGE_PAY_SERVER_TRANSACTION_METHOD','Payment','The processing method to use for each transaction.','6',0,NULL,'2021-11-16 09:33:25',NULL,'tep_cfg_select_option(array(\'Authenticate\', \'Deferred\', \'Payment\'), ',10),(7713,'Transaction Server','MODULE_PAYMENT_SAGE_PAY_SERVER_TRANSACTION_SERVER','Test','Perform transactions on the production server or on the testing server.','6',0,NULL,'2021-11-16 09:33:25',NULL,'tep_cfg_select_option(array(\'Live\', \'Test\', \'Simulator\'), ',10),(7714,'Allow tokens','MODULE_PAYMENT_SAGE_PAY_SERVER_USE_TOKENS','False','Allow to save tokens.','6',0,NULL,'2021-11-16 09:33:25',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7715,'Vendor Login Name','MODULE_PAYMENT_SAGE_PAY_SERVER_VENDOR_LOGIN_NAME','protx','The vendor login name to connect to the gateway with.','6',0,NULL,'2021-11-16 09:33:25',NULL,NULL,10),(7716,'Payment Zone','MODULE_PAYMENT_SAGE_PAY_SERVER_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',2,NULL,'2021-11-16 09:33:25','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7717,'Set Order Status Cancelled Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_CANCELLED_ORDER_STATUS_ID','5','Set the status of orders cancelled','6',0,NULL,'2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7718,'Set Order Status Completed Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_COMPLETED_ORDER_STATUS_ID','100006','Set the status of orders completed successfully','6',0,NULL,'2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7719,'Debug E-Mail Address','MODULE_PAYMENT_STRIPE_CHECKOUT_DEBUG_EMAIL','','All parameters of an invalid transaction will be sent to this email address.','6',0,NULL,'2021-11-15 09:11:10',NULL,NULL,10),(7720,'Set Order Status Before Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_ORDER_STATUS_ID','1','Set the status of orders before redirect to Gateway','6',0,NULL,'2021-11-15 09:11:10','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',10),(7721,'Publishable API Key','MODULE_PAYMENT_STRIPE_CHECKOUT_PUBLISHABLE_KEY','pk_test_51L5tlzLrdFbMtgAWVb82LINlf6po2qfbkRmjCc3o02yH88tlzoCC96f8EnpUmVGgQR104lCdO4WdiqmEpzefgrbE00YzVLdKk0','The Stripe account publishable API key to use.','6',0,NULL,'2021-11-15 09:11:10',NULL,NULL,10),(7722,'Secret API Key','MODULE_PAYMENT_STRIPE_CHECKOUT_SECRET_KEY','Ó9gÖQ»õ¸Á_i×o^daecbdee61c47847f8f5bdea1ffd12e4628b94dba32f878cf0dcc788d3f44f3e9HâÙÅyl$¿$9kodÒ&ÚMè±ÿ,Xµg,ÿN¸Ê<àêI²stë5/ ¸rï*ËæÛU¨OÂ´RýÛ´`Eè\r|4Ò©}Ae6¡Kz@^\0öhcã.¥·Ë$&n}t{y¶3Ø­äS(XÚ','The Stripe account secret API key to use with the publishable key.','6',0,NULL,'2021-11-15 09:11:10','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',10),(7723,'Sort order of display.','MODULE_PAYMENT_STRIPE_CHECKOUT_SORT_ORDER','30','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:16:52','2021-11-15 09:11:10',NULL,NULL,10),(7724,'Enable Stripe Module','MODULE_PAYMENT_STRIPE_CHECKOUT_STATUS','True','Do you want to accept Stripe payments?','6',0,'2022-06-24 17:53:39','2021-11-15 09:11:10',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7725,'Update Stock Before Payment','MODULE_PAYMENT_STRIPE_CHECKOUT_UPDATE_STOCK_BEFORE_PAYMENT','False','Should Products Stock be updated even when the payment is not yet COMPLETED?','6',0,NULL,'2021-11-15 09:11:10',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7726,'Webhook Secret','MODULE_PAYMENT_STRIPE_CHECKOUT_WEBHOOK_SECRET','whsec_HExwr6qITymk3PEKFcS9LaaTkyzrKwVw','The Stripe account webhook signing secret.','6',0,NULL,'2021-11-15 09:11:10',NULL,NULL,10),(7727,'Payment Zone','MODULE_PAYMENT_STRIPE_CHECKOUT_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',0,NULL,'2021-11-15 09:11:10','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7728,'FedEx Account Number','MODULE_SHIPPING_FEDEX_ACT_NUM','','Enter FedEx Account Number','6',4,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7729,'First line of street address','MODULE_SHIPPING_FEDEX_ADDRESS_1','','Enter the first line of your ship-from street address, required','6',7,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7730,'Second line of street address','MODULE_SHIPPING_FEDEX_ADDRESS_2','','Enter the second line of your ship-from street address, leave blank if you do not need to specify a second line','6',8,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7731,'City name','MODULE_SHIPPING_FEDEX_CITY','','Enter the city name for the ship-from street address, required','6',9,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7732,'Country','MODULE_SHIPPING_FEDEX_COUNTRY','222','Select the postal country for the ship-from address, required','6',11,NULL,'2021-11-15 09:14:28','\\backend\\models\\Configuration::tep_get_country_name','tep_cfg_pull_down_country_list(',10),(7733,'Currency Exchange Rates Conversion','MODULE_SHIPPING_FEDEX_CURRENCY','1','Set your currency exchange rate here if needed. Note that this data must be a number (integer like 32 or with a floating point like 32.48) and will have to be updated by you regularly to match exchange fluctuations.','6',14,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7734,'Delivery Date Management','MODULE_SHIPPING_FEDEX_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',10),(7735,'Delivery Date ownership settings','MODULE_SHIPPING_FEDEX_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',10),(7736,'Domestic NBD Handling Fee','MODULE_SHIPPING_FEDEX_DOMESTIC_HANDLING_FEE','','Add a domestic handling fee or leave blank (example: 15 or 15%)','6',20,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7737,'Enable Domestic NBD','MODULE_SHIPPING_FEDEX_DOMESTIC_NEXT_DAY','true','Enable FedEx Domestic Next Business Day','6',16,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7738,'Drop off type','MODULE_SHIPPING_FEDEX_DROPOFF','REGULAR_PICKUP','Dropoff type?','6',15,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'REGULAR_PICKUP\',\'REQUEST_COURIER\',\'DROP_BOX\',\'BUSINESS_SERVICE_CENTER\',\'STATION\'), ',10),(7739,'Insurance?','MODULE_SHIPPING_FEDEX_INSURE','-1','Insure packages over what amount? (set to -1 to disable)','6',22,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7740,'Enable International Economy','MODULE_SHIPPING_FEDEX_INTERNATIONAL_ECONOMY','true','Enable FedEx Express International Economy','6',18,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7741,'Enable International Priority','MODULE_SHIPPING_FEDEX_INTERNATIONAL_PRIORITY','true','Enable FedEx Express International Priority','6',17,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'true\', \'false\'), ',10),(7742,'International Express Handling Fee','MODULE_SHIPPING_FEDEX_INT_EXPRESS_HANDLING_FEE','','Add an international handling fee or leave blank (example: 15 or 15%)','6',21,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7743,'FedEx Web Services Key','MODULE_SHIPPING_FEDEX_KEY','','Enter FedEx Web Services Key','6',2,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7744,'FedEx Meter Number','MODULE_SHIPPING_FEDEX_METER_NUM','','Enter FedEx Meter Number','6',5,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7745,'Web Service Mode','MODULE_SHIPPING_FEDEX_MODE','Test','Web Service Mode','6',2,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'Test\', \'Production\'), ',10),(7746,'FedEx Packaging Type','MODULE_SHIPPING_FEDEX_PACKAGING_TYPE','YOUR_PACKAGING','FedEx Packaging Type','6',22,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'YOUR_PACKAGING\',\'FEDEX_10KG_BOX\', \'FEDEX_25KG_BOX\', \'FEDEX_BOX\', \'FEDEX_ENVELOPE\', \'FEDEX_EXTRA_LARGE_BOX\', \'FEDEX_LARGE_BOX\', \'FEDEX_MEDIUM_BOX\', \'FEDEX_PAK\', \'FEDEX_SMALL_BOX\', \'FEDEX_TUBE\'), ',10),(7747,'Phone number','MODULE_SHIPPING_FEDEX_PHONE','','Enter a contact phone number for your company, required','6',12,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7748,'Postal code','MODULE_SHIPPING_FEDEX_POSTAL','','Enter the postal code for the ship-from street address, required','6',11,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7749,'FedEx Web Services Password','MODULE_SHIPPING_FEDEX_PWD','','Enter FedEx Web Services Password','6',3,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7750,'FedEx Rates','MODULE_SHIPPING_FEDEX_RATES','LIST','FedEx Rates','6',22,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'LIST\',\'ACCOUNT\'), ',10),(7751,'Shipping Delay','MODULE_SHIPPING_FEDEX_SHIPPING_DAYS_DELAY','1','How many days from when an order is placed to when you ship it (Decimals are allowed). Arrival date estimations are based on this value.','6',13,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7752,'Signature Option','MODULE_SHIPPING_FEDEX_SIGNATURE_OPTION','-1','Require a signature on order subtotal greater than or equal to (set to -1 to disable):','6',23,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7753,'Signature Option Type','MODULE_SHIPPING_FEDEX_SIGNATURE_OPTION_TYPE','SERVICE_DEFAULT','Select Signature Option Type','6',23,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'ADULT\', \'DIRECT\', \'INDIRECT\', \'NO_SIGNATURE_REQUIRED\', \'SERVICE_DEFAULT\'), ',10),(7754,'Shipping Sort Order','MODULE_SHIPPING_FEDEX_SORT_ORDER','140','Sort order of display.','6',100,'2021-11-15 09:14:28','2021-11-15 09:14:28',NULL,NULL,10),(7755,'State or Province name','MODULE_SHIPPING_FEDEX_STATE','','Enter the 2 letter state or province name for the ship-from street address, required for Canada and US','6',10,NULL,'2021-11-15 09:14:28',NULL,NULL,10),(7756,'Enable Collect Shipping','MODULE_SHIPPING_FEDEX_STATUS','False','Do you want to offer collect shipping?','6',0,'2021-11-15 09:14:43','2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7757,'Shipping Tax Class','MODULE_SHIPPING_FEDEX_TAX_CLASS','0','Use the following tax class on the shipping fee.','6',0,NULL,'2021-11-15 09:14:28','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7758,'Weight Units','MODULE_SHIPPING_FEDEX_WEIGHT','KG','Weight Units:','6',6,NULL,'2021-11-15 09:14:28',NULL,'tep_cfg_select_option(array(\'LB\', \'KG\'), ',10),(7759,'Shipping Shipping Zone','MODULE_SHIPPING_FEDEX_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','6',0,NULL,'2021-11-15 09:14:28','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7760,'Flat Shipping Cost','MODULE_SHIPPING_FLAT_COST','5','The shipping cost for all orders using this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 14:03:53',NULL,NULL,10),(7761,'Delivery Date Management','MODULE_SHIPPING_FLAT_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',10),(7762,'Delivery Date ownership settings','MODULE_SHIPPING_FLAT_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',10),(7763,'Flat Sort Order','MODULE_SHIPPING_FLAT_SORT_ORDER','10','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 14:03:53',NULL,NULL,10),(7764,'Enable Flat Shipping','MODULE_SHIPPING_FLAT_STATUS','True','Do you want to offer flat rate shipping?','BOX_CONFIGURATION_MODULE',0,'2021-11-16 09:36:10','2016-11-16 14:03:53',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7765,'Flat Tax Class','MODULE_SHIPPING_FLAT_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 14:03:53','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7766,'Flat Shipping Zone','MODULE_SHIPPING_FLAT_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 14:03:53','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7767,'Free Shipping Cost','MODULE_SHIPPING_FREESHIPPER_COST','0.00','What is the Shipping cost? The Handling fee will also be added.','BOX_CONFIGURATION_MODULE',6,NULL,'2016-11-16 13:27:21',NULL,NULL,10),(7768,'Delivery Date Management','MODULE_SHIPPING_FREESHIPPER_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',10),(7769,'Delivery Date ownership settings','MODULE_SHIPPING_FREESHIPPER_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',10),(7770,'FREESHIPPER Sort Order','MODULE_SHIPPING_FREESHIPPER_SORT_ORDER','30','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:27:21',NULL,NULL,10),(7771,'Enable Free Shipping','MODULE_SHIPPING_FREESHIPPER_STATUS','False','Do you want to offer Free shipping?','BOX_CONFIGURATION_MODULE',5,'2017-07-19 15:13:02','2016-11-16 13:27:21',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7772,'FREESHIPPER Tax Class','MODULE_SHIPPING_FREESHIPPER_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:27:21','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7773,'FREESHIPPER Shipping Zone','MODULE_SHIPPING_FREESHIPPER_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:27:21','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7774,'Installed Modules','MODULE_SHIPPING_INSTALLED','flat.php;freeshipper.php;zonetable.php;item.php;percent.php;table.php;zones.php','List of shipping module filenames separated by a semi-colon. This is automatically updated. No need to edit. (Example: ups.php;flat.php;item.php)','BOX_CONFIGURATION_MODULE',0,'2022-06-24 14:32:28','2003-07-17 10:29:22',NULL,NULL,10),(7775,'Item Shipping Shipping Cost','MODULE_SHIPPING_ITEM_COST','0','The shipping cost will be multiplied by the number of items in an order that uses this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:59:56',NULL,NULL,10),(7776,'Delivery Date Management','MODULE_SHIPPING_ITEM_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',10),(7777,'Delivery Date ownership settings','MODULE_SHIPPING_ITEM_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',10),(7778,'Item Shipping Handling Fee','MODULE_SHIPPING_ITEM_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:59:56',NULL,NULL,10),(7779,'Item Shipping Sort Order','MODULE_SHIPPING_ITEM_SORT_ORDER','50','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:59:56',NULL,NULL,10),(7780,'Enable Item Shipping','MODULE_SHIPPING_ITEM_STATUS','False','Do you want to offer per item rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-01-11 16:18:17','2016-11-16 13:59:56',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7781,'Item Shipping Tax Class','MODULE_SHIPPING_ITEM_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:59:56','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7782,'Item Shipping Shipping Zone','MODULE_SHIPPING_ITEM_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:59:56','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7783,'NovaPoshta ApiKey','MODULE_SHIPPING_NP_APIKEY','dd791bafa70224a996085024e0687e8c','','BOX_CONFIGURATION_MODULE',0,NULL,'2018-02-16 15:24:13',NULL,NULL,10),(7784,'NovaPoshta ApiKey','MODULE_SHIPPING_NP_API_KEY','','','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-22 13:18:12',NULL,NULL,10),(7785,'NovaPoshta Shipping Shipping Cost','MODULE_SHIPPING_NP_COST','40','','BOX_CONFIGURATION_MODULE',0,NULL,'2018-02-16 15:24:13',NULL,NULL,10),(7786,'Delivery Date Management','MODULE_SHIPPING_NP_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',10),(7787,'Delivery Date ownership settings','MODULE_SHIPPING_NP_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',10),(7788,'Preferred Shipping Method','MODULE_SHIPPING_NP_PREFERRED_METHOD','WarehouseToWarehouse','Sort order of display.','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-22 13:18:12',NULL,'tep_cfg_select_option(array(\'WarehouseToWarehouse\', \'WarehouseToDoors\'), ',10),(7789,'NP Shipping Sort Order','MODULE_SHIPPING_NP_SORT_ORDER','130','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2018-02-16 15:24:13','2018-02-16 15:24:13',NULL,NULL,10),(7790,'Enable Item Shipping','MODULE_SHIPPING_NP_STATUS','False','Do you want to offer NovaPoshta shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-22 13:24:50','2018-02-16 15:24:13',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7791,'Tracking Url','MODULE_SHIPPING_NP_TRACKING_NUMBER_URL','https://novaposhta.ua/tracking/?newtracking=1&cargo_number=','Url for tracking cargo','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-22 13:18:12',NULL,NULL,10),(7792,'Enable NP Tracking','MODULE_SHIPPING_NP_TRACKING_STATUS','True','Do you want to enable NP tracking?','BOX_CONFIGURATION_MODULE',0,NULL,'2018-10-02 09:43:28',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7793,'Delivery Date Management','MODULE_SHIPPING_PERCENT_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',10),(7794,'Delivery Date ownership settings','MODULE_SHIPPING_PERCENT_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',10),(7795,'Percentage A Flat Rate of','MODULE_SHIPPING_PERCENT_FLAT_USE','6.50','A Flat Rate used for all orders.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35',NULL,NULL,10),(7796,'Percentage A Flat Rate for orders under','MODULE_SHIPPING_PERCENT_LESS_THEN','34.75','A Flat Rate for all orders that are under the amount shown.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35',NULL,NULL,10),(7797,'Percentage Rate','MODULE_SHIPPING_PERCENT_RATE','.18','The Percentage Rate all .01 to .99 for all orders using this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35',NULL,NULL,10),(7798,'Percentage Sort Order','MODULE_SHIPPING_PERCENT_SORT_ORDER','60','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:52:35',NULL,NULL,10),(7799,'Enable Percent Shipping','MODULE_SHIPPING_PERCENT_STATUS','True','Do you want to offer percent rate shipping?','BOX_CONFIGURATION_MODULE',0,'2022-06-24 16:47:44','2016-11-16 13:52:35',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7800,'Percentage from Order incl. Tax','MODULE_SHIPPING_PERCENT_SUBTOTAL_INCL_TAX','True','Calculate order amount incl. tax or excl. tax?','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7801,'Percentage Tax Class','MODULE_SHIPPING_PERCENT_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7802,'Percentage Shipping Zone','MODULE_SHIPPING_PERCENT_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:52:35','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7803,'Table Method Shipping Table','MODULE_SHIPPING_TABLE_COST','25:8.50,50:5.50,10000:0.00','The shipping cost is based on the total cost or weight of items. Example: 25:8.50,50:5.50,etc.. Up to 25 charge 8.50, from there to 50 charge 5.50, etc','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14',NULL,NULL,10),(7804,'Delivery Date Management','MODULE_SHIPPING_TABLE_DATE_SETTING','Use default','Preferred delivery date rules','6',80,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',10),(7805,'Delivery Date ownership settings','MODULE_SHIPPING_TABLE_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',90,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',10),(7806,'Table Method Handling Fee','MODULE_SHIPPING_TABLE_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14',NULL,NULL,10),(7807,'Table Method','MODULE_SHIPPING_TABLE_MODE','weight','The shipping cost is based on the order total or the total weight of the items ordered.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14',NULL,'tep_cfg_select_option(array(\'weight\', \'price\'), ',10),(7808,'Table Method Sort Order','MODULE_SHIPPING_TABLE_SORT_ORDER','70','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-24 17:14:14',NULL,NULL,10),(7809,'Enable Table Method','MODULE_SHIPPING_TABLE_STATUS','False','Do you want to offer table rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-02-22 16:42:12','2016-11-24 17:14:14',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7810,'Table Method Tax Class','MODULE_SHIPPING_TABLE_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7811,'Table Method Shipping Zone','MODULE_SHIPPING_TABLE_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-24 17:14:14','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7812,'Delivery Date Management','MODULE_SHIPPING_UPS_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',10),(7813,'Delivery Date ownership settings','MODULE_SHIPPING_UPS_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',10),(7814,'UPS Handling Fee','MODULE_SHIPPING_UPS_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59',NULL,NULL,10),(7815,'UPS Packaging?','MODULE_SHIPPING_UPS_PACKAGE','CP','CP - Your Packaging, ULE - UPS Letter, UT - UPS Tube, UBE - UPS Express Box','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59',NULL,NULL,10),(7816,'UPS Pickup Method','MODULE_SHIPPING_UPS_PICKUP','CC','How do you give packages to UPS? CC - Customer Counter, RDP - Daily Pickup, OTP - One Time Pickup, LC - Letter Center, OCA - On Call Air','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59',NULL,NULL,10),(7817,'UPS Residential Delivery?','MODULE_SHIPPING_UPS_RES','RES','Quote for Residential (RES) or Commercial Delivery (COM)','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59',NULL,NULL,10),(7818,'UPS Sort order of display.','MODULE_SHIPPING_UPS_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:01:59',NULL,NULL,10),(7819,'Enable UPS Shipping','MODULE_SHIPPING_UPS_STATUS','False','Do you want to offer UPS shipping?','BOX_CONFIGURATION_MODULE',0,'2017-08-11 14:46:54','2016-11-16 13:01:59',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7820,'UPS Tax Class','MODULE_SHIPPING_UPS_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7821,'UPS Shipping Methods','MODULE_SHIPPING_UPS_TYPES','1DM, 1DML, 1DA, 1DAL, 1DAPI, 1DP, 1DPL, 2DM, 2DML, 2DA, 2DAL, 3DS, GND, STD, XPR, XPRL, XDM, XDML, XPD','Select the UPS services to be offered.','BOX_CONFIGURATION_MODULE',13,NULL,'2016-11-16 13:01:59',NULL,'tep_cfg_select_multioption(array(\'1DM\',\'1DML\', \'1DA\', \'1DAL\', \'1DAPI\', \'1DP\', \'1DPL\', \'2DM\', \'2DML\', \'2DA\', \'2DAL\', \'3DS\',\'GND\', \'STD\', \'XPR\', \'XPRL\', \'XDM\', \'XDML\', \'XPD\'), ',10),(7822,'UPS Shipping Zone','MODULE_SHIPPING_UPS_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:01:59','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7823,'Delivery Date Management','MODULE_SHIPPING_USPS_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',10),(7824,'Delivery Date ownership settings','MODULE_SHIPPING_USPS_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',10),(7825,'Handling Fee','MODULE_SHIPPING_USPS_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02',NULL,NULL,10),(7826,'USPS Options','MODULE_SHIPPING_USPS_OPTIONS','Display weight, Display transit time','Select from the following the USPS options.','BOX_CONFIGURATION_MODULE',16,NULL,'2016-11-16 13:31:02',NULL,'tep_cfg_select_multioption(array(\'Display weight\', \'Display transit time\'), ',10),(7827,'Enter the USPS Password','MODULE_SHIPPING_USPS_PASSWORD','','See USERID, above.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02',NULL,NULL,10),(7828,'Which server to use','MODULE_SHIPPING_USPS_SERVER','test','An account at USPS is needed to use the Production server','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02',NULL,'tep_cfg_select_option(array(\'test\', \'production\'), ',10),(7829,'Sort Order','MODULE_SHIPPING_USPS_SORT_ORDER','80','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2016-11-16 13:31:02','2016-11-16 13:31:02',NULL,NULL,10),(7830,'Enable USPS Shipping','MODULE_SHIPPING_USPS_STATUS','False','Do you want to offer USPS shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-21 16:18:57','2016-11-16 13:31:02',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7831,'Tax Class','MODULE_SHIPPING_USPS_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7832,'Domestic Shipping Methods','MODULE_SHIPPING_USPS_TYPES','First Class, Priority Mail, Priority Mail Express','Select the domestic services to be offered:','BOX_CONFIGURATION_MODULE',14,NULL,'2016-11-16 13:31:02',NULL,'tep_cfg_select_multioption(array(\'First Class\', \'Priority Mail\', \'Priority Mail Express\'),',10),(7833,'Int\'l Shipping Methods','MODULE_SHIPPING_USPS_TYPES_INTL','Priority Mail Express International, Priority Mail International','Select the international services to be offered:','BOX_CONFIGURATION_MODULE',15,NULL,'2016-11-16 13:31:02',NULL,'tep_cfg_select_multioption(array(\'Priority Mail Express International\', \'Priority Mail International\'),',10),(7834,'Enter the USPS User ID','MODULE_SHIPPING_USPS_USERID','','Enter the USPS USERID assigned to you.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02',NULL,NULL,10),(7835,'Shipping Zone','MODULE_SHIPPING_USPS_ZONE','0','If a zone is selected, only enable this shipping method for that zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:31:02','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',10),(7836,'Delivery Date Management','MODULE_SHIPPING_ZONESPERITEM_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',10),(7837,'Delivery Date ownership settings','MODULE_SHIPPING_ZONESPERITEM_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',10),(7838,'Zone 1 Geo Zone','MODULE_SHIPPING_ZONESPERITEM_GEO_ZONE_1','0','Select Geo Zone of this Zone 1.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,10),(7839,'Number of Zones','MODULE_SHIPPING_ZONESPERITEM_NUMBER_OF_ZONES','1','Number of zones needed.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:38:29',NULL,NULL,10),(7840,'Zone 1 Premium Additional Item Charge','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_ADDITIONAL_ITEM_CHARGE_1','0.00','Premium Additional Item Charge for this shipping zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,10),(7841,'Zone 1 Premium Free Delivery Amount','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_FREE_DELIVERY_AMOUNT_1','20.00','Amount of subtotal for free premium delivery for this shipping zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,10),(7842,'Zone 1 Premium Initial Item Charge','MODULE_SHIPPING_ZONESPERITEM_PREMIUM_INITIAL_ITEM_CHARGE_1','4.50','Premium Initial Item Charge for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,10),(7843,'Zones Per Item Sort Order','MODULE_SHIPPING_ZONESPERITEM_SORT_ORDER','100','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-12-21 15:38:29',NULL,NULL,10),(7844,'Zone 1 Standard Additional Item Charge','MODULE_SHIPPING_ZONESPERITEM_STANDARD_ADDITIONAL_ITEM_CHARGE_1','0.50','Standard Additional Item Charge for this shipping zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,10),(7845,'Zone 1 Standard Free Delivery Amount','MODULE_SHIPPING_ZONESPERITEM_STANDARD_FREE_DELIVERY_AMOUNT_1','20.00','Amount of subtotal for free standard delivery for this shipping zone.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,10),(7846,'Zone 1 Standard Initial Item Charge','MODULE_SHIPPING_ZONESPERITEM_STANDARD_INITIAL_ITEM_CHARGE_1','2.50','Standard Initial Item Charge for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:58:18',NULL,NULL,10),(7847,'Enable Zones Per Item Method','MODULE_SHIPPING_ZONESPERITEM_STATUS','False','Do you want to offer zone rate shipping?','BOX_CONFIGURATION_MODULE',0,'2018-03-14 15:08:27','2016-12-21 15:38:29',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7848,'Zones Per Item Tax Class','MODULE_SHIPPING_ZONESPERITEM_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-12-21 15:38:29','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7849,'Zone 1 Shipping Table','MODULE_SHIPPING_ZONES_COST_1','3:8.50,7:10.50,99:20.00','Shipping rates to Zone 1 destinations based on a group of maximum order weights. Example: 3:8.50,7:10.50,... Weights less than or equal to 3 would cost 8.50 for Zone 1 destinations.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:47:33',NULL,NULL,10),(7850,'Zone 1 Countries','MODULE_SHIPPING_ZONES_COUNTRIES_1','US,CA','Comma separated list of two character ISO country codes that are part of Zone 1.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:47:33',NULL,NULL,10),(7851,'Delivery Date Management','MODULE_SHIPPING_ZONES_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',10),(7852,'Delivery Date ownership settings','MODULE_SHIPPING_ZONES_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',10),(7853,'Zone 1 Handling Fee','MODULE_SHIPPING_ZONES_HANDLING_1','0','Handling Fee for this shipping zone','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:47:33',NULL,NULL,10),(7854,'Zones Sort Order','MODULE_SHIPPING_ZONES_SORT_ORDER','90','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2016-11-16 13:47:33',NULL,NULL,10),(7855,'Zones Enable Zones Method','MODULE_SHIPPING_ZONES_STATUS','False','Do you want to offer zone rate shipping?','BOX_CONFIGURATION_MODULE',0,'2017-05-29 13:48:31','2016-11-16 13:47:33',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7856,'Zones Tax Class','MODULE_SHIPPING_ZONES_TAX_CLASS','0','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2016-11-16 13:47:33','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7857,'If no rates found allow complete order','MODULE_SHIPPING_ZONE_ALLOW_ERROR_PASS','False','Display \"please call us for a quote\" and allow complete order.','BOX_CONFIGURATION_MODULE',0,NULL,'2019-10-22 13:18:12',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7858,'Delivery Date Management','MODULE_SHIPPING_ZONE_TABLE_DATE_SETTING','Use default','Preferred delivery date rules','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_option(array(\'Use default\', \'Use ownership\'), ',10),(7859,'Delivery Date ownership settings','MODULE_SHIPPING_ZONE_TABLE_DISABLED_DAYS','Saturday, Sunday','Disabled dates','6',0,NULL,'2021-11-03 17:01:34',NULL,'tep_cfg_select_multioption(array(\'Monday\', \'Tuesday\', \'Wednesday\', \'Thursday\', \'Friday\', \'Saturday\', \'Sunday\'),',10),(7860,'Handling Fee','MODULE_SHIPPING_ZONE_TABLE_HANDLING','0','Handling fee for this shipping method.','BOX_CONFIGURATION_MODULE',0,NULL,'2017-01-05 14:27:17',NULL,NULL,10),(7861,'Sort Order','MODULE_SHIPPING_ZONE_TABLE_SORT_ORDER','40','Sort order of display.','BOX_CONFIGURATION_MODULE',0,'2017-08-09 13:35:49','2017-01-05 14:27:17',NULL,NULL,10),(7862,'Enable Table Method','MODULE_SHIPPING_ZONE_TABLE_STATUS','True','Do you want to offer Zone Table rate shipping?','BOX_CONFIGURATION_MODULE',0,'2022-06-24 16:47:39','2017-01-05 14:27:17',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7863,'Tax Class','MODULE_SHIPPING_ZONE_TABLE_TAX_CLASS','3','Use the following tax class on the shipping fee.','BOX_CONFIGURATION_MODULE',0,NULL,'2017-01-05 14:27:17','\\common\\helpers\\Tax::get_tax_class_title','tep_cfg_pull_down_tax_classes(',10),(7864,'Public API key','TRUSTPILOT_API_KEY','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',10),(7865,'Business password','TRUSTPILOT_API_PASSWORD','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',10),(7866,'Private API secret','TRUSTPILOT_API_SECRET','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',10),(7867,'Business username','TRUSTPILOT_API_USERNAME','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',10),(7868,'BCC Trustpilot email','TRUSTPILOT_BCC_EMAIL','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',10),(7869,'Business Unit Id','TRUSTPILOT_BUSINESS_UNIT_ID','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-12 17:42:38','','',10),(7870,'Select integration','TRUSTPILOT_CONNECT_VIA','bccMail','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','tep_cfg_select_option(array(\'bccMail\', \'API\'),',10),(7871,'Delay invite send (days)','TRUSTPILOT_INVITE_DELAY','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',10),(7872,'Filter orders by','TRUSTPILOT_INVITE_ORDER_AMOUNT_BY','ot_total','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','tep_cfg_select_option(array(\'ot_subtotal\', \'ot_total\'),',10),(7873,'Filter orders by amount, from','TRUSTPILOT_INVITE_ORDER_AMOUNT_FROM','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',10),(7874,'Filter orders by amount, not above','TRUSTPILOT_INVITE_ORDER_AMOUNT_TO','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',10),(7875,'Redirect URL','TRUSTPILOT_REDIRECT_URI','https://uk.trustpilot.com','https://www.trustpilot.com','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-06-23 12:30:28','','',10),(7876,'Sender Email','TRUSTPILOT_SENDER_EMAIL','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',10),(7877,'Sender Name','TRUSTPILOT_SENDER_NAME','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 17:53:17','','',10),(7878,'Status','TRUSTPILOT_STATUS','Disabled','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','tep_cfg_select_option(array(\'Disabled\', \'Enabled\'),',10),(7879,'Verify meta tag','TRUSTPILOT_VERIFY_META_TAG','','','BOX_CONFIGURATION_TRUSTPILOT',1,'0000-00-00 00:00:00','2017-05-10 14:52:30','','',10),(7889,'Enable DPD Labels','MODULE_LABEL_DPD_STATUS','True','Do you want to offer DPD labels?','6',0,NULL,'2022-03-14 09:45:30',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(7890,'Username','MODULE_LABEL_DPD_USERNAME','','Username','6',1,NULL,'2022-03-14 09:45:30',NULL,NULL,1),(7891,'Password','MODULE_LABEL_DPD_PASSWORD','','Password','6',2,NULL,'2022-03-14 09:45:30',NULL,NULL,1),(7892,'DPD Sort Order','MODULE_LABEL_DPD_SORT_ORDER','30','Sort order of display.','6',10,'2022-03-14 09:45:31','2022-03-14 09:45:30',NULL,NULL,1),(7912,'Enable PayPal Checkout v2','MODULE_PAYMENT_PAYPAL_PARTNER_STATUS','True','Do you want to accept PayPal Checkout payments?','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(7913,'Show PayPal button on product','MODULE_PAYMENT_PAYPAL_PARTNER_BUY_IMMEDIATELLY','False','Allow to make PayPal purchase from product page','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',1),(7914,'Show PayPal Pay later info','MODULE_PAYMENT_PAYPAL_PARTNER_PAY_LATER','False','Displays Pay Later messaging for available offers. Restrictions apply. See terms and learn more on PayPal <a target=\'blank\' href=\'https://developer.paypal.com/docs/commerce-platforms/admin-panel/\'>PayPal</a>','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',1),(7915,'Transaction Method','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTION_METHOD','sale','The processing method to use for each transaction.','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'tep_cfg_select_option(array(\'authorize\', \'sale\'), ',1),(7916,'Set Pending Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_ORDER_STATUS_ID','1','Set the status of pending orders made with this payment module to this value','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'tep_cfg_pull_down_order_statuses(',1),(7917,'Set Paid Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTIONS_ORDER_STATUS_ID','100006','Set the paid status of orders made with this payment module to this value','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'tep_cfg_pull_down_order_statuses(',1),(7918,'Set Cancelled Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_CANCEL_ORDER_STATUS_ID','5','Set the cancelled status of orders made with this payment module to this value','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'tep_cfg_pull_down_order_statuses(',1),(7919,'Payment Zone','MODULE_PAYMENT_PAYPAL_PARTNER_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'tep_cfg_pull_down_zone_classes(',1),(7920,'Transaction Server','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTION_SERVER','Sandbox','Use the live or testing (sandbox) gateway server to process transactions?','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'tep_cfg_select_option(array(\'Live\', \'Sandbox\'), ',1),(7921,'Dynamic Button Color','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_COLOR','gold','Color for Dynamic Button','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'multiOption(\'dropdown\', array(\'gold\', \'blue\', \'silver\', \'white\', \'black\'), ',1),(7922,'Dynamic Button Shape','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_SHAPE','pill','Shape for Dynamic Button','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'multiOption(\'dropdown\', array(\'pill\', \'rect\'), ',1),(7923,'Dynamic Button Size','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_SIZE','small','Size for Dynamic Button','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'multiOption(\'dropdown\', array(\'small\', \'medium\', \'large\', \'responsive\'), ',1),(7924,'Dynamic Button Label','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_LABEL','checkout','Label for Dynamic Button','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'multiOption(\'dropdown\', array(\'checkout\', \'pay\', \'buynow\', \'paypal\'), ',1),(7927,'Enable funding','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_FUNDING','--none--','Enable funding (other possible are disabled)','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,'multiOption(\'checkbox\', \\common\\modules\\orderPayment\\paypal_partner::possibleFundingArray(), ',1),(7928,'Debug E-Mail Address','MODULE_PAYMENT_PAYPAL_PARTNER_DEBUG_EMAIL','','All parameters of an invalid transaction will be sent to this email address.','6',0,'2022-07-18 14:31:07','2022-06-02 08:51:14',NULL,NULL,1),(7929,'Sort order of display','MODULE_PAYMENT_PAYPAL_PARTNER_SORT_ORDER','10','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:16:47','2022-06-02 08:51:14',NULL,NULL,1),(7930,'Self Install Creation status','SelfInstallCreation_EXTENSION_STATUS','True','','6',0,'2022-06-08 17:04:17','2022-06-08 17:04:17',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',0),(7931,'Coupons And Vauchers status','CouponsAndVauchers_EXTENSION_STATUS','True','','6',0,NULL,'2022-06-24 08:33:12',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',0),(7932,'Modules Visibility status','ModulesVisibility_EXTENSION_STATUS','True','','6',0,NULL,'2022-06-24 08:33:21',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',0),(7934,'Enable PayPal Checkout v2','MODULE_PAYMENT_PAYPAL_PARTNER_STATUS','True','Do you want to accept PayPal Checkout payments?','6',0,NULL,'2022-06-24 17:55:55',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7935,'Show PayPal button on product','MODULE_PAYMENT_PAYPAL_PARTNER_BUY_IMMEDIATELLY','False','Allow to make PayPal purchase from product page','6',0,NULL,'2022-06-24 17:55:55',NULL,'multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',10),(7936,'Show PayPal Pay later info','MODULE_PAYMENT_PAYPAL_PARTNER_PAY_LATER','False','Displays Pay Later messaging for available offers. Restrictions apply. See terms and learn more on PayPal <a target=\'blank\' href=\'https://developer.paypal.com/docs/commerce-platforms/admin-panel/\'>PayPal</a>','6',0,NULL,'2022-06-24 17:55:55',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',10),(7937,'Transaction Method','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTION_METHOD','sale','The processing method to use for each transaction.','6',0,NULL,'2022-06-24 17:55:55',NULL,'tep_cfg_select_option(array(\'authorize\', \'sale\'), ',10),(7938,'Set Pending Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_ORDER_STATUS_ID','1','Set the status of pending orders made with this payment module to this value','6',0,NULL,'2022-06-24 17:55:55',NULL,'tep_cfg_pull_down_order_statuses(',10),(7939,'Set Paid Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTIONS_ORDER_STATUS_ID','100006','Set the paid status of orders made with this payment module to this value','6',0,NULL,'2022-06-24 17:55:55',NULL,'tep_cfg_pull_down_order_statuses(',10),(7940,'Set Cancelled Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_CANCEL_ORDER_STATUS_ID','5','Set the cancelled status of orders made with this payment module to this value','6',0,NULL,'2022-06-24 17:55:55',NULL,'tep_cfg_pull_down_order_statuses(',10),(7941,'Payment Zone','MODULE_PAYMENT_PAYPAL_PARTNER_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',0,NULL,'2022-06-24 17:55:55',NULL,'tep_cfg_pull_down_zone_classes(',10),(7942,'Transaction Server','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTION_SERVER','Sandbox','Use the live or testing (sandbox) gateway server to process transactions?','6',0,NULL,'2022-06-24 17:55:55',NULL,'tep_cfg_select_option(array(\'Live\', \'Sandbox\'), ',10),(7943,'Dynamic Button Color','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_COLOR','gold','Color for Dynamic Button','6',0,NULL,'2022-06-24 17:55:55',NULL,'multiOption(\'dropdown\', array(\'gold\', \'blue\', \'silver\', \'white\', \'black\'), ',10),(7944,'Dynamic Button Shape','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_SHAPE','pill','Shape for Dynamic Button','6',0,NULL,'2022-06-24 17:55:55',NULL,'multiOption(\'dropdown\', array(\'pill\', \'rect\'), ',10),(7945,'Dynamic Button Size','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_SIZE','small','Size for Dynamic Button','6',0,NULL,'2022-06-24 17:55:55',NULL,'multiOption(\'dropdown\', array(\'small\', \'medium\', \'large\', \'responsive\'), ',10),(7946,'Dynamic Button Label','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_LABEL','checkout','Label for Dynamic Button','6',0,NULL,'2022-06-24 17:55:55',NULL,'multiOption(\'dropdown\', array(\'checkout\', \'pay\', \'buynow\', \'paypal\'), ',10),(7949,'Enable funding','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_FUNDING','--none--','Enable funding (other possible are disabled)','6',0,NULL,'2022-06-24 17:55:55',NULL,'multiOption(\'checkbox\', \\common\\modules\\orderPayment\\paypal_partner::possibleFundingArray(), ',10),(7950,'Debug E-Mail Address','MODULE_PAYMENT_PAYPAL_PARTNER_DEBUG_EMAIL','','All parameters of an invalid transaction will be sent to this email address.','6',0,NULL,'2022-06-24 17:55:55',NULL,NULL,10),(7951,'Sort order of display','MODULE_PAYMENT_PAYPAL_PARTNER_SORT_ORDER','10','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:16:52','2022-06-24 17:55:55',NULL,NULL,10),(7952,'Enable PayPal Checkout v2','MODULE_PAYMENT_PAYPAL_PARTNER_STATUS','True','Do you want to accept PayPal Checkout payments?','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',7),(7953,'Show PayPal button on product','MODULE_PAYMENT_PAYPAL_PARTNER_BUY_IMMEDIATELLY','False','Allow to make PayPal purchase from product page','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',7),(7954,'Show PayPal Pay later info','MODULE_PAYMENT_PAYPAL_PARTNER_PAY_LATER','False','Displays Pay Later messaging for available offers. Restrictions apply. See terms and learn more on PayPal <a target=\'blank\' href=\'https://developer.paypal.com/docs/commerce-platforms/admin-panel/\'>PayPal</a>','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',7),(7955,'Transaction Method','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTION_METHOD','sale','The processing method to use for each transaction.','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'tep_cfg_select_option(array(\'authorize\', \'sale\'), ',7),(7956,'Set Pending Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_ORDER_STATUS_ID','1','Set the status of pending orders made with this payment module to this value','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'tep_cfg_pull_down_order_statuses(',7),(7957,'Set Paid Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTIONS_ORDER_STATUS_ID','100006','Set the paid status of orders made with this payment module to this value','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'tep_cfg_pull_down_order_statuses(',7),(7958,'Set Cancelled Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_CANCEL_ORDER_STATUS_ID','5','Set the cancelled status of orders made with this payment module to this value','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'tep_cfg_pull_down_order_statuses(',7),(7959,'Payment Zone','MODULE_PAYMENT_PAYPAL_PARTNER_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'tep_cfg_pull_down_zone_classes(',7),(7960,'Transaction Server','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTION_SERVER','Sandbox','Use the live or testing (sandbox) gateway server to process transactions?','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'tep_cfg_select_option(array(\'Live\', \'Sandbox\'), ',7),(7961,'Dynamic Button Color','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_COLOR','gold','Color for Dynamic Button','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'multiOption(\'dropdown\', array(\'gold\', \'blue\', \'silver\', \'white\', \'black\'), ',7),(7962,'Dynamic Button Shape','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_SHAPE','pill','Shape for Dynamic Button','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'multiOption(\'dropdown\', array(\'pill\', \'rect\'), ',7),(7963,'Dynamic Button Size','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_SIZE','small','Size for Dynamic Button','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'multiOption(\'dropdown\', array(\'small\', \'medium\', \'large\', \'responsive\'), ',7),(7964,'Dynamic Button Label','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_LABEL','checkout','Label for Dynamic Button','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'multiOption(\'dropdown\', array(\'checkout\', \'pay\', \'buynow\', \'paypal\'), ',7),(7967,'Enable funding','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_FUNDING','--none--','Enable funding (other possible are disabled)','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,'multiOption(\'checkbox\', \\common\\modules\\orderPayment\\paypal_partner::possibleFundingArray(), ',7),(7968,'Debug E-Mail Address','MODULE_PAYMENT_PAYPAL_PARTNER_DEBUG_EMAIL','','All parameters of an invalid transaction will be sent to this email address.','6',0,'2022-07-18 14:32:27','2022-06-24 17:57:46',NULL,NULL,7),(7969,'Sort order of display','MODULE_PAYMENT_PAYPAL_PARTNER_SORT_ORDER','10','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:16:57','2022-06-24 17:57:46',NULL,NULL,7),(7970,'Enable PayPal Checkout v2','MODULE_PAYMENT_PAYPAL_PARTNER_STATUS','True','Do you want to accept PayPal Checkout payments?','6',0,NULL,'2022-06-24 17:58:08',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7971,'Show PayPal button on product','MODULE_PAYMENT_PAYPAL_PARTNER_BUY_IMMEDIATELLY','False','Allow to make PayPal purchase from product page','6',0,NULL,'2022-06-24 17:58:08',NULL,'multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',8),(7972,'Show PayPal Pay later info','MODULE_PAYMENT_PAYPAL_PARTNER_PAY_LATER','False','Displays Pay Later messaging for available offers. Restrictions apply. See terms and learn more on PayPal <a target=\'blank\' href=\'https://developer.paypal.com/docs/commerce-platforms/admin-panel/\'>PayPal</a>','6',0,NULL,'2022-06-24 17:58:08',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',8),(7973,'Transaction Method','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTION_METHOD','sale','The processing method to use for each transaction.','6',0,NULL,'2022-06-24 17:58:08',NULL,'tep_cfg_select_option(array(\'authorize\', \'sale\'), ',8),(7974,'Set Pending Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_ORDER_STATUS_ID','1','Set the status of pending orders made with this payment module to this value','6',0,NULL,'2022-06-24 17:58:08',NULL,'tep_cfg_pull_down_order_statuses(',8),(7975,'Set Paid Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTIONS_ORDER_STATUS_ID','100006','Set the paid status of orders made with this payment module to this value','6',0,NULL,'2022-06-24 17:58:08',NULL,'tep_cfg_pull_down_order_statuses(',8),(7976,'Set Cancelled Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_CANCEL_ORDER_STATUS_ID','5','Set the cancelled status of orders made with this payment module to this value','6',0,NULL,'2022-06-24 17:58:08',NULL,'tep_cfg_pull_down_order_statuses(',8),(7977,'Payment Zone','MODULE_PAYMENT_PAYPAL_PARTNER_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',0,NULL,'2022-06-24 17:58:08',NULL,'tep_cfg_pull_down_zone_classes(',8),(7978,'Transaction Server','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTION_SERVER','Sandbox','Use the live or testing (sandbox) gateway server to process transactions?','6',0,NULL,'2022-06-24 17:58:08',NULL,'tep_cfg_select_option(array(\'Live\', \'Sandbox\'), ',8),(7979,'Dynamic Button Color','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_COLOR','gold','Color for Dynamic Button','6',0,NULL,'2022-06-24 17:58:08',NULL,'multiOption(\'dropdown\', array(\'gold\', \'blue\', \'silver\', \'white\', \'black\'), ',8),(7980,'Dynamic Button Shape','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_SHAPE','pill','Shape for Dynamic Button','6',0,NULL,'2022-06-24 17:58:08',NULL,'multiOption(\'dropdown\', array(\'pill\', \'rect\'), ',8),(7981,'Dynamic Button Size','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_SIZE','small','Size for Dynamic Button','6',0,NULL,'2022-06-24 17:58:08',NULL,'multiOption(\'dropdown\', array(\'small\', \'medium\', \'large\', \'responsive\'), ',8),(7982,'Dynamic Button Label','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_LABEL','checkout','Label for Dynamic Button','6',0,NULL,'2022-06-24 17:58:08',NULL,'multiOption(\'dropdown\', array(\'checkout\', \'pay\', \'buynow\', \'paypal\'), ',8),(7985,'Enable funding','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_FUNDING','--none--','Enable funding (other possible are disabled)','6',0,NULL,'2022-06-24 17:58:08',NULL,'multiOption(\'checkbox\', \\common\\modules\\orderPayment\\paypal_partner::possibleFundingArray(), ',8),(7986,'Debug E-Mail Address','MODULE_PAYMENT_PAYPAL_PARTNER_DEBUG_EMAIL','','All parameters of an invalid transaction will be sent to this email address.','6',0,NULL,'2022-06-24 17:58:08',NULL,NULL,8),(7987,'Sort order of display','MODULE_PAYMENT_PAYPAL_PARTNER_SORT_ORDER','10','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:17:01','2022-06-24 17:58:08',NULL,NULL,8),(7988,'Enable PayPal Checkout v2','MODULE_PAYMENT_PAYPAL_PARTNER_STATUS','True','Do you want to accept PayPal Checkout payments?','6',0,NULL,'2022-06-24 17:58:31',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7989,'Show PayPal button on product','MODULE_PAYMENT_PAYPAL_PARTNER_BUY_IMMEDIATELLY','False','Allow to make PayPal purchase from product page','6',0,NULL,'2022-06-24 17:58:31',NULL,'multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',9),(7990,'Show PayPal Pay later info','MODULE_PAYMENT_PAYPAL_PARTNER_PAY_LATER','False','Displays Pay Later messaging for available offers. Restrictions apply. See terms and learn more on PayPal <a target=\'blank\' href=\'https://developer.paypal.com/docs/commerce-platforms/admin-panel/\'>PayPal</a>','6',0,NULL,'2022-06-24 17:58:31',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(7991,'Transaction Method','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTION_METHOD','sale','The processing method to use for each transaction.','6',0,NULL,'2022-06-24 17:58:31',NULL,'tep_cfg_select_option(array(\'authorize\', \'sale\'), ',9),(7992,'Set Pending Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_ORDER_STATUS_ID','1','Set the status of pending orders made with this payment module to this value','6',0,NULL,'2022-06-24 17:58:31',NULL,'tep_cfg_pull_down_order_statuses(',9),(7993,'Set Paid Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTIONS_ORDER_STATUS_ID','100006','Set the paid status of orders made with this payment module to this value','6',0,NULL,'2022-06-24 17:58:31',NULL,'tep_cfg_pull_down_order_statuses(',9),(7994,'Set Cancelled Order Status','MODULE_PAYMENT_PAYPAL_PARTNER_CANCEL_ORDER_STATUS_ID','5','Set the cancelled status of orders made with this payment module to this value','6',0,NULL,'2022-06-24 17:58:31',NULL,'tep_cfg_pull_down_order_statuses(',9),(7995,'Payment Zone','MODULE_PAYMENT_PAYPAL_PARTNER_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',0,NULL,'2022-06-24 17:58:31',NULL,'tep_cfg_pull_down_zone_classes(',9),(7996,'Transaction Server','MODULE_PAYMENT_PAYPAL_PARTNER_TRANSACTION_SERVER','Sandbox','Use the live or testing (sandbox) gateway server to process transactions?','6',0,NULL,'2022-06-24 17:58:31',NULL,'tep_cfg_select_option(array(\'Live\', \'Sandbox\'), ',9),(7997,'Dynamic Button Color','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_COLOR','gold','Color for Dynamic Button','6',0,NULL,'2022-06-24 17:58:31',NULL,'multiOption(\'dropdown\', array(\'gold\', \'blue\', \'silver\', \'white\', \'black\'), ',9),(7998,'Dynamic Button Shape','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_SHAPE','pill','Shape for Dynamic Button','6',0,NULL,'2022-06-24 17:58:31',NULL,'multiOption(\'dropdown\', array(\'pill\', \'rect\'), ',9),(7999,'Dynamic Button Size','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_SIZE','small','Size for Dynamic Button','6',0,NULL,'2022-06-24 17:58:31',NULL,'multiOption(\'dropdown\', array(\'small\', \'medium\', \'large\', \'responsive\'), ',9),(8000,'Dynamic Button Label','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_LABEL','checkout','Label for Dynamic Button','6',0,NULL,'2022-06-24 17:58:31',NULL,'multiOption(\'dropdown\', array(\'checkout\', \'pay\', \'buynow\', \'paypal\'), ',9),(8003,'Enable funding','MODULE_PAYMENT_PAYPAL_PARTNER_BUTTON_FUNDING','--none--','Enable funding (other possible are disabled)','6',0,NULL,'2022-06-24 17:58:31',NULL,'multiOption(\'checkbox\', \\common\\modules\\orderPayment\\paypal_partner::possibleFundingArray(), ',9),(8004,'Debug E-Mail Address','MODULE_PAYMENT_PAYPAL_PARTNER_DEBUG_EMAIL','','All parameters of an invalid transaction will be sent to this email address.','6',0,NULL,'2022-06-24 17:58:31',NULL,NULL,9),(8005,'Sort order of display','MODULE_PAYMENT_PAYPAL_PARTNER_SORT_ORDER','10','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:17:11','2022-06-24 17:58:31',NULL,NULL,9),(8006,'Gift Wrap cost for each product','MODULE_ORDER_TOTAL_GIFT_WRAP_EACH_PRODUCT','False','Multiply gift wrap cost on products quantity','6',3,NULL,'2022-07-18 15:58:00',NULL,'tep_cfg_select_option(array(\'True\', \'False\'),',1),(8007,'Osc Link status','OscLink_EXTENSION_STATUS','True','','6',0,NULL,'2022-07-20 18:52:48',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',0),(8008,'Enable Opayo Server Module','MODULE_PAYMENT_SAGE_PAY_SERVER_STATUS','True','Do you want to accept Opayo Server payments?','6',0,'2022-07-24 15:11:47','2022-07-24 15:05:43',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(8009,'Vendor Login Name','MODULE_PAYMENT_SAGE_PAY_SERVER_VENDOR_LOGIN_NAME','protx','The vendor login name to connect to the gateway with.','6',0,NULL,'2022-07-24 15:05:43',NULL,NULL,9),(8010,'Account login','MODULE_PAYMENT_SAGE_PAY_SERVER_ACCOUNT','','Account login to get transaction details','6',0,NULL,'2022-07-24 15:05:43','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',9),(8011,'Account Password','MODULE_PAYMENT_SAGE_PAY_SERVER_ACCOUNT_PASSWORD','','Account password to get transaction details','6',0,NULL,'2022-07-24 15:05:43','\\common\\modules\\orderPayment\\sage_pay_server::useConf','setConf(',9),(8012,'Profile Payment Page','MODULE_PAYMENT_SAGE_PAY_SERVER_PROFILE_PAGE','Normal','Profile page to use for the payment page.','6',0,NULL,'2022-07-24 15:05:43',NULL,'tep_cfg_select_option(array(\'Normal\', \'Low\'), ',9),(8013,'Transaction Method','MODULE_PAYMENT_SAGE_PAY_SERVER_TRANSACTION_METHOD','Payment','The processing method to use for each transaction.','6',0,NULL,'2022-07-24 15:05:43',NULL,'tep_cfg_select_option(array(\'Authenticate\', \'Deferred\', \'Payment\'), ',9),(8014,'Transaction Server','MODULE_PAYMENT_SAGE_PAY_SERVER_TRANSACTION_SERVER','Test','Perform transactions on the production server or on the testing server.','6',0,NULL,'2022-07-24 15:05:43',NULL,'tep_cfg_select_option(array(\'Live\', \'Test\', \'Simulator\'), ',9),(8015,'T3M verification','MODULE_PAYMENT_SAGE_PAY_SERVER_T3M_VERIFICATION','Info','Info - ignore if not available instantly, Optional - check for updates for up to 3 days, required - do not accept transaction if none t3m info available','6',0,NULL,'2022-07-24 15:05:43',NULL,'tep_cfg_select_option(array(\'Info\', \'Optional\', \'Required\'), ',9),(8016,'Allow tokens','MODULE_PAYMENT_SAGE_PAY_SERVER_USE_TOKENS','False','Allow to save tokens.','6',0,NULL,'2022-07-24 15:05:43',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',9),(8017,'Payment Zone','MODULE_PAYMENT_SAGE_PAY_SERVER_ZONE','0','If a zone is selected, only enable this payment method for that zone.','6',2,NULL,'2022-07-24 15:05:43','\\common\\helpers\\Zones::get_zone_class_title','tep_cfg_pull_down_zone_classes(',9),(8018,'Set Order Status','MODULE_PAYMENT_SAGE_PAY_SERVER_ORDER_STATUS_ID','100006','Set the status of orders made with this payment module to this value','6',0,NULL,'2022-07-24 15:05:43','\\common\\helpers\\Order::get_order_status_name','tep_cfg_pull_down_order_statuses(',9),(8019,'Save order before payment','MODULE_PAYMENT_SAGE_PAY_SERVER_ORDER_BEFORE_PAYMENT','False','Save order before redirect to payment gateway','6',0,NULL,'2022-07-24 15:05:43',NULL,'tep_cfg_select_option(array(\'True\', \'False\', \'Temp\'), ',9),(8020,'Skip 3D secure amount','MODULE_PAYMENT_SAGE_PAY_3DS_SKIP','','Skip 3D secure verification when paid by token on orders below','6',100,NULL,'2022-07-24 15:05:43',NULL,NULL,9),(8021,'Sort order of display.','MODULE_PAYMENT_SAGE_PAY_SERVER_SORT_ORDER','20','Sort order of display. Lowest is displayed first.','6',0,'2022-07-25 09:17:11','2022-07-24 15:05:43',NULL,NULL,9),(8039,'Product Stock History status','ProductStockHistory_EXTENSION_STATUS','True','','6',0,NULL,'2021-08-11 17:30:13',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',0),(8040,'Error Log Viewer status','ErrorLogViewer_EXTENSION_STATUS','True','','6',0,'2022-10-26 14:02:49','2022-10-26 14:02:49',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',0),(8041,'Stock Control status','StockControl_EXTENSION_STATUS','True','','6',0,NULL,'2022-10-26 14:04:14',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',0),(8042,'Product Templates status','ProductTemplates_EXTENSION_STATUS','True','','6',0,NULL,'2022-12-08 11:27:11',NULL,'tep_cfg_select_option(array(\'True\', \'False\'), ',0),(8043,'Show PayPal button(s) on Shopping Cart','MODULE_PAYMENT_PAYPAL_PARTNER_SHOPPING_CART','Vertical','Show PayPal buttons on Shopping Cart Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',1),(8044,'Show PayPal button on Checkout','MODULE_PAYMENT_PAYPAL_PARTNER_AT_CHECKOUT','Vertical','Show PayPal buttons on Checkout Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'Fields\', \'False\'), ',1),(8045,'Show PayPal button on Checkout Login','MODULE_PAYMENT_PAYPAL_PARTNER_AT_CHECKOUT_LOGIN','False','Show PayPal buttons on Checkout Login Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',1),(8046,'Show PayPal button(s) on Shopping Cart','MODULE_PAYMENT_PAYPAL_PARTNER_SHOPPING_CART','Vertical','Show PayPal buttons on Shopping Cart Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',10),(8047,'Show PayPal button on Checkout','MODULE_PAYMENT_PAYPAL_PARTNER_AT_CHECKOUT','Vertical','Show PayPal buttons on Checkout Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'Fields\', \'False\'), ',10),(8048,'Show PayPal button on Checkout Login','MODULE_PAYMENT_PAYPAL_PARTNER_AT_CHECKOUT_LOGIN','False','Show PayPal buttons on Checkout Login Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',10),(8049,'Show PayPal button(s) on Shopping Cart','MODULE_PAYMENT_PAYPAL_PARTNER_SHOPPING_CART','Vertical','Show PayPal buttons on Shopping Cart Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',7),(8050,'Show PayPal button on Checkout','MODULE_PAYMENT_PAYPAL_PARTNER_AT_CHECKOUT','Vertical','Show PayPal buttons on Checkout Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'Fields\', \'False\'), ',7),(8051,'Show PayPal button on Checkout Login','MODULE_PAYMENT_PAYPAL_PARTNER_AT_CHECKOUT_LOGIN','False','Show PayPal buttons on Checkout Login Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',7),(8052,'Show PayPal button(s) on Shopping Cart','MODULE_PAYMENT_PAYPAL_PARTNER_SHOPPING_CART','Vertical','Show PayPal buttons on Shopping Cart Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',8),(8053,'Show PayPal button on Checkout','MODULE_PAYMENT_PAYPAL_PARTNER_AT_CHECKOUT','Vertical','Show PayPal buttons on Checkout Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'Fields\', \'False\'), ',8),(8054,'Show PayPal button on Checkout Login','MODULE_PAYMENT_PAYPAL_PARTNER_AT_CHECKOUT_LOGIN','False','Show PayPal buttons on Checkout Login Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',8),(8055,'Show PayPal button(s) on Shopping Cart','MODULE_PAYMENT_PAYPAL_PARTNER_SHOPPING_CART','Vertical','Show PayPal buttons on Shopping Cart Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',9),(8056,'Show PayPal button on Checkout','MODULE_PAYMENT_PAYPAL_PARTNER_AT_CHECKOUT','Vertical','Show PayPal buttons on Checkout Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'Fields\', \'False\'), ',9),(8057,'Show PayPal button on Checkout Login','MODULE_PAYMENT_PAYPAL_PARTNER_AT_CHECKOUT_LOGIN','False','Show PayPal buttons on Checkout Login Page','BOX_CONFIGURATION_MODULE',1000,NULL,'2023-02-22 13:14:22','','multiOption(\'dropdown\', array(\'Horizontal\', \'Vertical\', \'False\'), ',9);
/*!40000 ALTER TABLE `platforms_configuration` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_countries`
--

DROP TABLE IF EXISTS `platforms_countries`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_countries` (
  `platform_id` int(11) NOT NULL,
  `countries_id` int(11) NOT NULL,
  PRIMARY KEY (`platform_id`,`countries_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_countries`
--

LOCK TABLES `platforms_countries` WRITE;
/*!40000 ALTER TABLE `platforms_countries` DISABLE KEYS */;
/*!40000 ALTER TABLE `platforms_countries` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_cut_off_times`
--

DROP TABLE IF EXISTS `platforms_cut_off_times`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_cut_off_times` (
  `platforms_cut_off_times_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `cut_off_times_days` varchar(32) NOT NULL DEFAULT '',
  `cut_off_times_today` varchar(10) NOT NULL DEFAULT '',
  `cut_off_times_next_day` varchar(10) NOT NULL DEFAULT '',
  PRIMARY KEY (`platforms_cut_off_times_id`)
) ENGINE=InnoDB AUTO_INCREMENT=36 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_cut_off_times`
--

LOCK TABLES `platforms_cut_off_times` WRITE;
/*!40000 ALTER TABLE `platforms_cut_off_times` DISABLE KEYS */;
INSERT INTO `platforms_cut_off_times` VALUES (31,1,'1,2,3,4,5','11:00 AM','6:00 PM'),(32,7,'1,2,3,4,5','11:00 AM','6:00 PM'),(33,8,'1,2,3,4,5','11:00 AM','6:00 PM'),(34,9,'','',''),(35,10,'','','');
/*!40000 ALTER TABLE `platforms_cut_off_times` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_formats`
--

DROP TABLE IF EXISTS `platforms_formats`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_formats` (
  `paltform_formats_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `configuration_key` varchar(64) NOT NULL DEFAULT '',
  `configuration_value` varchar(255) NOT NULL DEFAULT '',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`paltform_formats_id`),
  KEY `platform_id` (`platform_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_formats`
--

LOCK TABLES `platforms_formats` WRITE;
/*!40000 ALTER TABLE `platforms_formats` DISABLE KEYS */;
/*!40000 ALTER TABLE `platforms_formats` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_geo_zones`
--

DROP TABLE IF EXISTS `platforms_geo_zones`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_geo_zones` (
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `geo_zone_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`platform_id`,`geo_zone_id`),
  KEY `idx_geo_zone_id` (`geo_zone_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_geo_zones`
--

LOCK TABLES `platforms_geo_zones` WRITE;
/*!40000 ALTER TABLE `platforms_geo_zones` DISABLE KEYS */;
/*!40000 ALTER TABLE `platforms_geo_zones` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_holidays`
--

DROP TABLE IF EXISTS `platforms_holidays`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_holidays` (
  `platforms_holidays_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `holidate` datetime DEFAULT NULL,
  PRIMARY KEY (`platforms_holidays_id`),
  KEY `platform_id` (`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_holidays`
--

LOCK TABLES `platforms_holidays` WRITE;
/*!40000 ALTER TABLE `platforms_holidays` DISABLE KEYS */;
/*!40000 ALTER TABLE `platforms_holidays` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_locations`
--

DROP TABLE IF EXISTS `platforms_locations`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_locations` (
  `platforms_locations_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `country` int(11) NOT NULL DEFAULT '0',
  `language` varchar(8) NOT NULL DEFAULT '',
  `currency` varchar(8) NOT NULL DEFAULT '',
  PRIMARY KEY (`platforms_locations_id`),
  KEY `platform_id` (`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_locations`
--

LOCK TABLES `platforms_locations` WRITE;
/*!40000 ALTER TABLE `platforms_locations` DISABLE KEYS */;
/*!40000 ALTER TABLE `platforms_locations` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_open_hours`
--

DROP TABLE IF EXISTS `platforms_open_hours`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_open_hours` (
  `platforms_open_hours_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `open_days` varchar(32) NOT NULL DEFAULT '',
  `open_time_from` varchar(10) NOT NULL DEFAULT '',
  `open_time_to` varchar(10) NOT NULL DEFAULT '',
  PRIMARY KEY (`platforms_open_hours_id`)
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_open_hours`
--

LOCK TABLES `platforms_open_hours` WRITE;
/*!40000 ALTER TABLE `platforms_open_hours` DISABLE KEYS */;
INSERT INTO `platforms_open_hours` VALUES (1,1,'1,2,3,4,5','9:00 AM','6:00 PM'),(5,0,'1,2,3,4,5','11:00 AM','7:00 PM'),(6,7,'1,2,3,4,5','9:00 AM','6:00 PM'),(7,8,'1,2,3,4,5','9:00 AM','6:00 PM'),(8,10,'1,2,3,4,5','9:00 AM','5:00 PM'),(9,9,'1,2,3,4,5','9:00 AM','5:00 PM');
/*!40000 ALTER TABLE `platforms_open_hours` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_products`
--

DROP TABLE IF EXISTS `platforms_products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_products` (
  `platform_id` int(11) NOT NULL,
  `products_id` int(11) NOT NULL,
  PRIMARY KEY (`products_id`,`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_products`
--

LOCK TABLES `platforms_products` WRITE;
/*!40000 ALTER TABLE `platforms_products` DISABLE KEYS */;
INSERT INTO `platforms_products` VALUES (1,1),(8,1),(1,2),(8,2),(1,3),(8,3),(1,4),(8,4),(1,5),(8,5),(1,6),(8,6),(1,7),(8,7),(1,8),(8,8),(1,9),(8,9),(1,10),(8,10),(1,11),(8,11),(1,12),(8,12),(1,13),(8,13),(1,14),(8,14),(1,15),(8,15),(1,16),(8,16),(1,17),(8,17),(1,18),(8,18),(1,19),(8,19),(1,20),(8,20),(1,21),(8,21),(1,22),(8,22),(1,23),(8,23),(1,24),(8,24),(1,25),(8,25),(1,26),(8,26),(1,27),(8,27),(1,28),(8,28),(1,29),(8,29),(1,30),(9,30),(1,31),(9,31),(1,32),(9,32),(1,33),(9,33),(1,34),(9,34),(1,35),(9,35),(1,36),(9,36),(1,37),(9,37),(1,38),(10,38),(1,39),(10,39),(1,40),(10,40),(1,41),(10,41),(1,42),(10,42),(1,43),(10,43),(1,44),(10,44),(1,45),(10,45),(1,46),(10,46),(1,47),(10,47),(1,48),(10,48),(1,49),(10,49),(1,50),(7,50),(1,51),(7,51),(1,52),(7,52),(1,53),(7,53),(1,54),(7,54),(1,55),(7,55),(1,56),(7,56),(1,57),(7,57),(1,58),(7,58),(1,59),(7,59),(1,60),(7,60),(1,61),(7,61),(1,62),(7,62),(1,63),(7,63),(1,64),(7,64),(1,65),(7,65),(1,66),(7,66),(1,67),(7,67),(1,68),(7,68),(1,69),(7,69),(1,70),(7,70),(1,71),(7,71),(1,72),(7,72),(1,73),(7,73),(1,74),(7,74),(1,75),(7,75);
/*!40000 ALTER TABLE `platforms_products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_settings`
--

DROP TABLE IF EXISTS `platforms_settings`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_settings` (
  `platform_id` int(11) NOT NULL,
  `use_own_prices` int(1) DEFAULT '0',
  `use_owner_prices` int(11) DEFAULT '0',
  `use_own_descriptions` int(1) DEFAULT '0',
  `use_owner_descriptions` int(1) DEFAULT '0',
  PRIMARY KEY (`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_settings`
--

LOCK TABLES `platforms_settings` WRITE;
/*!40000 ALTER TABLE `platforms_settings` DISABLE KEYS */;
INSERT INTO `platforms_settings` VALUES (1,1,0,1,0),(4,0,1,0,1),(5,0,1,0,1),(6,0,1,0,1),(7,0,0,0,1),(8,0,0,1,0),(9,0,0,1,0),(10,0,0,1,0);
/*!40000 ALTER TABLE `platforms_settings` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_to_themes`
--

DROP TABLE IF EXISTS `platforms_to_themes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_to_themes` (
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `theme_id` int(11) NOT NULL DEFAULT '0',
  `is_default` tinyint(1) NOT NULL DEFAULT '0',
  UNIQUE KEY `platform_id` (`platform_id`,`theme_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_to_themes`
--

LOCK TABLES `platforms_to_themes` WRITE;
/*!40000 ALTER TABLE `platforms_to_themes` DISABLE KEYS */;
INSERT INTO `platforms_to_themes` VALUES (1,47,1),(7,3,1),(8,2,1),(9,9,1),(10,6,1);
/*!40000 ALTER TABLE `platforms_to_themes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_url`
--

DROP TABLE IF EXISTS `platforms_url`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_url` (
  `platforms_url_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `url_type` varchar(32) NOT NULL DEFAULT '',
  `status` tinyint(1) NOT NULL DEFAULT '0',
  `url` varchar(255) NOT NULL DEFAULT '',
  `ssl_enabled` tinyint(11) NOT NULL DEFAULT '0',
  `remote_server_config` varchar(2048) NOT NULL DEFAULT '',
  PRIMARY KEY (`platforms_url_id`),
  KEY `platform_id` (`platform_id`,`url_type`),
  KEY `url` (`url`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_url`
--

LOCK TABLES `platforms_url` WRITE;
/*!40000 ALTER TABLE `platforms_url` DISABLE KEYS */;
/*!40000 ALTER TABLE `platforms_url` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_watermark`
--

DROP TABLE IF EXISTS `platforms_watermark`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_watermark` (
  `platform_id` int(11) NOT NULL,
  `status` tinyint(1) NOT NULL DEFAULT '0',
  `watermark30` varchar(64) DEFAULT NULL,
  `watermark170` varchar(64) DEFAULT NULL,
  `watermark300` varchar(64) DEFAULT NULL,
  `top_watermark30` varchar(64) DEFAULT NULL,
  `top_watermark170` varchar(64) DEFAULT NULL,
  `top_watermark300` varchar(64) DEFAULT NULL,
  `bottom_watermark30` varchar(64) DEFAULT NULL,
  `bottom_watermark170` varchar(64) DEFAULT NULL,
  `bottom_watermark300` varchar(64) DEFAULT NULL,
  `left_watermark30` varchar(64) DEFAULT NULL,
  `left_watermark170` varchar(64) DEFAULT NULL,
  `left_watermark300` varchar(64) DEFAULT NULL,
  `right_watermark30` varchar(64) DEFAULT NULL,
  `right_watermark170` varchar(64) DEFAULT NULL,
  `right_watermark300` varchar(64) DEFAULT NULL,
  `top_left_watermark30` varchar(64) DEFAULT NULL,
  `top_left_watermark170` varchar(64) DEFAULT NULL,
  `top_left_watermark300` varchar(64) DEFAULT NULL,
  `top_right_watermark30` varchar(64) DEFAULT NULL,
  `top_right_watermark170` varchar(64) DEFAULT NULL,
  `top_right_watermark300` varchar(64) DEFAULT NULL,
  `bottom_left_watermark30` varchar(64) DEFAULT NULL,
  `bottom_left_watermark170` varchar(64) DEFAULT NULL,
  `bottom_left_watermark300` varchar(64) DEFAULT NULL,
  `bottom_right_watermark30` varchar(64) DEFAULT NULL,
  `bottom_right_watermark170` varchar(64) DEFAULT NULL,
  `bottom_right_watermark300` varchar(64) DEFAULT NULL,
  PRIMARY KEY (`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_watermark`
--

LOCK TABLES `platforms_watermark` WRITE;
/*!40000 ALTER TABLE `platforms_watermark` DISABLE KEYS */;
INSERT INTO `platforms_watermark` VALUES (1,0,'','','','','','','','','','','','','','','','','','','','','','','','','','',''),(7,0,'','','','','','','','','','','','','','','','','','','','','','','','','','',''),(8,0,'','','','','','','','','','','','','','','','','','','','','','','','','','',''),(9,0,'','','','','','','','','','','','','','','','','','','','','','','','','','',''),(10,0,'','','','','','','','','','','','','','','','','','','','','','','','','','','');
/*!40000 ALTER TABLE `platforms_watermark` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `platforms_zone_countries`
--

DROP TABLE IF EXISTS `platforms_zone_countries`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `platforms_zone_countries` (
  `platform_id` int(11) NOT NULL,
  `zone_country_id` int(11) NOT NULL,
  PRIMARY KEY (`platform_id`,`zone_country_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `platforms_zone_countries`
--

LOCK TABLES `platforms_zone_countries` WRITE;
/*!40000 ALTER TABLE `platforms_zone_countries` DISABLE KEYS */;
/*!40000 ALTER TABLE `platforms_zone_countries` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `postal_codes`
--

DROP TABLE IF EXISTS `postal_codes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `postal_codes` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `country_id` int(4) NOT NULL DEFAULT '0',
  `zone_id` int(4) NOT NULL DEFAULT '0',
  `city_id` int(4) NOT NULL DEFAULT '0',
  `postcode` varchar(10) NOT NULL DEFAULT '',
  `suburb` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`),
  KEY `postal_codes_postcode_idx` (`postcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `postal_codes`
--

LOCK TABLES `postal_codes` WRITE;
/*!40000 ALTER TABLE `postal_codes` DISABLE KEYS */;
/*!40000 ALTER TABLE `postal_codes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `product_price_index`
--

DROP TABLE IF EXISTS `product_price_index`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `product_price_index` (
  `products_id` int(11) NOT NULL DEFAULT '0',
  `uprid` varchar(255) NOT NULL DEFAULT '',
  `groups_id` int(11) NOT NULL DEFAULT '0',
  `currencies_id` int(11) NOT NULL DEFAULT '0',
  `flag_process` tinyint(1) NOT NULL DEFAULT '0',
  `products_last_modified` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `products_price_min` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `products_price_max` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `products_special_price_min` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `products_special_price_max` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `products_tax_class_id` int(11) NOT NULL DEFAULT '0',
  `products_status` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`groups_id`,`currencies_id`,`products_id`,`uprid`),
  KEY `idx_products_id` (`products_id`),
  KEY `idx_products_last_modified` (`products_last_modified`),
  KEY `idx_last_modified` (`last_modified`),
  KEY `idx_products_price_min` (`products_price_min`),
  KEY `idx_products_price_max` (`products_price_max`),
  KEY `products_special_price_min` (`products_special_price_min`),
  KEY `products_special_price_max` (`products_special_price_max`),
  KEY `idx_tax_class_pri` (`products_tax_class_id`,`products_status`,`groups_id`,`currencies_id`),
  KEY `idx_products_status` (`products_id`,`groups_id`,`currencies_id`,`products_status`,`products_price_min`),
  KEY `idx_products_id_prod_last_modified` (`products_id`,`products_last_modified`),
  KEY `idx_flag_status_last` (`flag_process`,`products_status`,`last_modified`),
  KEY `idx_id_flag_last` (`products_id`,`flag_process`,`products_last_modified`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `product_price_index`
--

LOCK TABLES `product_price_index` WRITE;
/*!40000 ALTER TABLE `product_price_index` DISABLE KEYS */;
INSERT INTO `product_price_index` VALUES (1,'',0,0,2,'2021-11-05 15:29:59','2021-12-21 17:08:00',111.900000,111.900000,0.000000,0.000000,3,1),(2,'',0,0,2,'2021-11-05 15:29:59','2021-12-21 17:08:00',87.540000,87.540000,0.000000,0.000000,3,1),(3,'',0,0,2,'2021-11-05 15:30:00','2021-12-21 17:08:00',180.000000,180.000000,0.000000,0.000000,3,1),(4,'',0,0,2,'2021-11-05 15:30:01','2021-12-21 17:08:00',37.450000,37.450000,0.000000,0.000000,3,1),(5,'',0,0,2,'2021-11-05 15:30:01','2021-12-21 17:08:00',55.833333,55.833333,0.000000,0.000000,3,1),(6,'',0,0,2,'2021-11-05 15:30:03','2021-12-21 17:08:00',150.000000,150.000000,0.000000,0.000000,3,1),(7,'',0,0,2,'2021-11-05 15:30:03','2021-12-21 17:08:00',28.940000,28.940000,0.000000,0.000000,3,1),(8,'',0,0,2,'2021-11-05 15:30:04','2021-12-21 17:08:00',61.280000,61.280000,0.000000,0.000000,3,1),(9,'',0,0,2,'2021-11-05 15:30:05','2021-12-21 17:08:00',49.360000,49.360000,0.000000,0.000000,3,1),(10,'',0,0,2,'2021-11-05 15:30:06','2021-12-21 17:08:00',109.841667,109.841667,0.000000,0.000000,3,1),(11,'',0,0,2,'2021-11-05 15:30:06','2021-12-21 17:08:00',217.490000,217.490000,0.000000,0.000000,3,1),(12,'',0,0,2,'2021-11-05 15:30:07','2021-12-21 17:08:00',47.660000,47.660000,0.000000,0.000000,3,1),(13,'',0,0,2,'2021-11-16 12:13:42','2021-11-16 12:13:42',44.200000,44.200000,0.000000,0.000000,3,1),(14,'',0,0,2,'2021-11-05 15:30:08','2021-12-21 17:08:00',180.000000,180.000000,0.000000,0.000000,3,1),(15,'',0,0,2,'2021-11-05 15:30:08','2021-12-21 17:08:00',40.040000,40.040000,0.000000,0.000000,3,1),(16,'',0,0,2,'2021-11-15 17:58:50','2021-11-15 17:58:50',38.300000,38.300000,0.000000,0.000000,3,1),(17,'',0,0,2,'2021-11-05 15:30:11','2021-12-21 17:08:00',56.170000,56.170000,0.000000,0.000000,3,1),(18,'',0,0,2,'2021-11-05 15:30:11','2021-12-21 17:08:00',51.670000,51.670000,0.000000,0.000000,3,1),(19,'',0,0,2,'2021-11-05 15:30:11','2021-12-21 17:08:00',42.970000,42.970000,0.000000,0.000000,3,1),(20,'',0,0,2,'2021-11-05 15:30:12','2021-12-21 17:08:00',150.000000,150.000000,0.000000,0.000000,3,1),(21,'',0,0,2,'2021-11-10 10:01:25','2021-11-10 10:01:26',11.510101,11.510101,0.000000,0.000000,3,1),(22,'',0,0,2,'2021-11-05 15:30:13','2021-12-21 17:08:00',211.670000,211.670000,0.000000,0.000000,3,1),(23,'',0,0,2,'2021-11-05 15:30:13','2021-12-21 17:08:00',264.170000,264.170000,0.000000,0.000000,3,1),(24,'',0,0,2,'2021-11-05 15:30:14','2021-12-21 17:08:00',145.000000,145.000000,0.000000,0.000000,3,1),(25,'',0,0,2,'2021-11-05 15:30:15','2021-12-21 17:08:00',189.170000,189.170000,0.000000,0.000000,3,1),(26,'',0,0,2,'2021-11-05 15:30:16','2021-12-21 17:08:00',35.000000,35.000000,0.000000,0.000000,3,1),(27,'',0,0,2,'2021-11-05 15:30:17','2021-12-21 17:08:00',39.150000,39.150000,0.000000,0.000000,0,1),(28,'',0,0,2,'2021-11-16 09:58:32','2021-11-16 09:58:32',50.000000,50.000000,0.000000,0.000000,3,1),(29,'',0,0,2,'2021-11-05 15:30:18','2021-12-21 17:08:00',157.500000,157.500000,0.000000,0.000000,3,1),(30,'',0,0,2,'2021-12-21 16:54:17','2021-12-21 17:08:00',346.956522,346.956522,0.000000,0.000000,0,1),(31,'',0,0,2,'2021-12-21 16:54:23','2021-12-21 17:08:00',303.478261,303.478261,0.000000,0.000000,0,1),(32,'',0,0,2,'2021-12-21 16:54:27','2021-12-21 17:08:00',2999.000000,2999.000000,0.000000,0.000000,0,1),(33,'',0,0,2,'2021-12-21 16:54:30','2021-12-21 17:08:00',1390.434783,1390.434783,0.000000,0.000000,0,1),(34,'',0,0,2,'2021-12-21 16:54:36','2021-12-21 17:08:00',1303.478261,1303.478261,0.000000,0.000000,0,1),(35,'',0,0,2,'2021-12-21 17:33:14','2021-12-21 17:33:15',2346.956522,2346.956522,0.000000,0.000000,0,1),(36,'',0,0,2,'2021-12-21 16:54:45','2021-12-21 17:08:00',78.217391,78.217391,0.000000,0.000000,0,1),(37,'',0,0,2,'2021-12-21 16:54:52','2021-12-21 17:08:00',69.521739,69.521739,0.000000,0.000000,0,1),(38,'',0,0,2,'2021-12-21 16:54:59','2021-12-21 17:08:00',49.000000,49.000000,0.000000,0.000000,0,1),(39,'',0,0,2,'2021-12-21 16:55:00','2021-12-21 17:08:00',39.000000,39.000000,0.000000,0.000000,0,1),(40,'',0,0,2,'2021-12-21 16:55:02','2021-12-21 17:08:00',49.000000,49.000000,0.000000,0.000000,0,1),(41,'',0,0,2,'2021-12-21 16:55:03','2021-12-21 17:08:00',49.000000,49.000000,0.000000,0.000000,0,1),(42,'',0,0,2,'2021-12-21 16:55:04','2021-12-21 17:08:00',799.000000,799.000000,0.000000,0.000000,0,1),(43,'',0,0,2,'2021-12-21 16:55:08','2021-12-21 17:08:00',1564.347826,1564.347826,0.000000,0.000000,0,1),(44,'',0,0,2,'2021-12-21 16:55:12','2021-12-21 17:08:00',1912.173913,1912.173913,0.000000,0.000000,0,1),(45,'',0,0,2,'2021-12-21 16:55:18','2021-12-21 17:08:00',1899.000000,1899.000000,0.000000,0.000000,0,1),(46,'',0,0,2,'2021-12-21 17:33:53','2021-12-21 17:33:53',546.956522,546.956522,0.000000,0.000000,0,1),(47,'',0,0,2,'2021-12-21 16:55:20','2021-12-21 17:08:00',699.000000,699.000000,0.000000,0.000000,0,1),(48,'',0,0,2,'2021-12-21 17:33:39','2021-12-21 17:33:39',999.000000,999.000000,0.000000,0.000000,0,1),(49,'',0,0,2,'2021-12-21 16:55:38','2021-12-21 17:08:00',868.695652,868.695652,0.000000,0.000000,0,1),(50,'',0,0,2,'2021-12-21 17:34:19','2021-12-21 17:34:20',520.869565,520.869565,0.000000,0.000000,0,1),(51,'',0,0,2,'2021-12-21 16:55:39','2021-12-21 17:08:00',260.000000,260.000000,0.000000,0.000000,0,1),(52,'',0,0,2,'2021-12-21 16:55:40','2021-12-21 17:08:00',868.695652,868.695652,0.000000,0.000000,0,1),(53,'',0,0,2,'2021-12-21 16:55:41','2021-12-21 17:08:00',799.000000,799.000000,0.000000,0.000000,0,1),(54,'',0,0,2,'2021-12-21 17:34:59','2021-12-21 17:35:00',694.782609,694.782609,0.000000,0.000000,0,1),(55,'',0,0,2,'2021-12-21 16:55:52','2021-12-21 17:08:00',399.000000,399.000000,0.000000,0.000000,0,1),(1,'',1,0,2,'2021-11-05 15:29:59','2021-12-21 17:08:00',111.900000,111.900000,0.000000,0.000000,3,1),(2,'',1,0,2,'2021-11-05 15:29:59','2021-12-21 17:08:00',87.540000,87.540000,0.000000,0.000000,3,1),(3,'',1,0,2,'2021-11-05 15:30:00','2021-12-21 17:08:00',180.000000,180.000000,0.000000,0.000000,3,1),(4,'',1,0,2,'2021-11-05 15:30:01','2021-12-21 17:08:00',37.450000,37.450000,0.000000,0.000000,3,1),(5,'',1,0,2,'2021-11-05 15:30:01','2021-12-21 17:08:00',55.833333,55.833333,0.000000,0.000000,3,1),(6,'',1,0,2,'2021-11-05 15:30:03','2021-12-21 17:08:00',150.000000,150.000000,0.000000,0.000000,3,1),(7,'',1,0,2,'2021-11-05 15:30:03','2021-12-21 17:08:00',28.940000,28.940000,0.000000,0.000000,3,1),(8,'',1,0,2,'2021-11-05 15:30:04','2021-12-21 17:08:00',61.280000,61.280000,0.000000,0.000000,3,1),(9,'',1,0,2,'2021-11-05 15:30:05','2021-12-21 17:08:00',49.360000,49.360000,0.000000,0.000000,3,1),(10,'',1,0,2,'2021-11-05 15:30:06','2021-12-21 17:08:00',109.841667,109.841667,0.000000,0.000000,3,1),(11,'',1,0,2,'2021-11-05 15:30:06','2021-12-21 17:08:00',217.490000,217.490000,0.000000,0.000000,3,1),(12,'',1,0,2,'2021-11-05 15:30:07','2021-12-21 17:08:00',47.660000,47.660000,0.000000,0.000000,3,1),(13,'',1,0,2,'2021-11-16 12:13:42','2021-11-16 12:13:42',44.200000,44.200000,0.000000,0.000000,3,1),(14,'',1,0,2,'2021-11-05 15:30:08','2021-12-21 17:08:00',180.000000,180.000000,0.000000,0.000000,3,1),(15,'',1,0,2,'2021-11-05 15:30:08','2021-12-21 17:08:00',40.040000,40.040000,0.000000,0.000000,3,1),(16,'',1,0,2,'2021-11-15 17:58:50','2021-11-15 17:58:50',38.300000,38.300000,0.000000,0.000000,3,1),(17,'',1,0,2,'2021-11-05 15:30:11','2021-12-21 17:08:00',56.170000,56.170000,0.000000,0.000000,3,1),(18,'',1,0,2,'2021-11-05 15:30:11','2021-12-21 17:08:00',51.670000,51.670000,0.000000,0.000000,3,1),(19,'',1,0,2,'2021-11-05 15:30:11','2021-12-21 17:08:00',42.970000,42.970000,0.000000,0.000000,3,1),(20,'',1,0,2,'2021-11-05 15:30:12','2021-12-21 17:08:00',150.000000,150.000000,0.000000,0.000000,3,1),(21,'',1,0,2,'2021-11-10 10:01:25','2021-11-10 10:01:26',11.510101,11.510101,0.000000,0.000000,3,1),(22,'',1,0,2,'2021-11-05 15:30:13','2021-12-21 17:08:00',211.670000,211.670000,0.000000,0.000000,3,1),(23,'',1,0,2,'2021-11-05 15:30:13','2021-12-21 17:08:00',264.170000,264.170000,0.000000,0.000000,3,1),(24,'',1,0,2,'2021-11-05 15:30:14','2021-12-21 17:08:00',145.000000,145.000000,0.000000,0.000000,3,1),(25,'',1,0,2,'2021-11-05 15:30:15','2021-12-21 17:08:00',189.170000,189.170000,0.000000,0.000000,3,1),(26,'',1,0,2,'2021-11-05 15:30:16','2021-12-21 17:08:00',35.000000,35.000000,0.000000,0.000000,3,1),(27,'',1,0,2,'2021-11-05 15:30:17','2021-12-21 17:08:00',39.150000,39.150000,0.000000,0.000000,0,1),(28,'',1,0,2,'2021-11-16 09:58:32','2021-11-16 09:58:32',50.000000,50.000000,0.000000,0.000000,3,1),(29,'',1,0,2,'2021-11-05 15:30:18','2021-12-21 17:08:00',157.500000,157.500000,0.000000,0.000000,3,1),(30,'',1,0,2,'2021-12-21 16:54:17','2021-12-21 17:08:00',346.956522,346.956522,0.000000,0.000000,0,1),(31,'',1,0,2,'2021-12-21 16:54:23','2021-12-21 17:08:00',303.478261,303.478261,0.000000,0.000000,0,1),(32,'',1,0,2,'2021-12-21 16:54:27','2021-12-21 17:08:00',2999.000000,2999.000000,0.000000,0.000000,0,1),(33,'',1,0,2,'2021-12-21 16:54:30','2021-12-21 17:08:00',1390.434783,1390.434783,0.000000,0.000000,0,1),(34,'',1,0,2,'2021-12-21 16:54:36','2021-12-21 17:08:00',1303.478261,1303.478261,0.000000,0.000000,0,1),(35,'',1,0,2,'2021-12-21 17:33:14','2021-12-21 17:33:15',2346.956522,2346.956522,0.000000,0.000000,0,1),(36,'',1,0,2,'2021-12-21 16:54:45','2021-12-21 17:08:00',78.217391,78.217391,0.000000,0.000000,0,1),(37,'',1,0,2,'2021-12-21 16:54:52','2021-12-21 17:08:00',69.521739,69.521739,0.000000,0.000000,0,1),(38,'',1,0,2,'2021-12-21 16:54:59','2021-12-21 17:08:00',49.000000,49.000000,0.000000,0.000000,0,1),(39,'',1,0,2,'2021-12-21 16:55:00','2021-12-21 17:08:00',39.000000,39.000000,0.000000,0.000000,0,1),(40,'',1,0,2,'2021-12-21 16:55:02','2021-12-21 17:08:00',49.000000,49.000000,0.000000,0.000000,0,1),(41,'',1,0,2,'2021-12-21 16:55:03','2021-12-21 17:08:00',49.000000,49.000000,0.000000,0.000000,0,1),(42,'',1,0,2,'2021-12-21 16:55:04','2021-12-21 17:08:00',799.000000,799.000000,0.000000,0.000000,0,1),(43,'',1,0,2,'2021-12-21 16:55:08','2021-12-21 17:08:00',1564.347826,1564.347826,0.000000,0.000000,0,1),(44,'',1,0,2,'2021-12-21 16:55:12','2021-12-21 17:08:00',1912.173913,1912.173913,0.000000,0.000000,0,1),(45,'',1,0,2,'2021-12-21 16:55:18','2021-12-21 17:08:00',1899.000000,1899.000000,0.000000,0.000000,0,1),(46,'',1,0,2,'2021-12-21 17:33:53','2021-12-21 17:33:53',546.956522,546.956522,0.000000,0.000000,0,1),(47,'',1,0,2,'2021-12-21 16:55:20','2021-12-21 17:08:00',699.000000,699.000000,0.000000,0.000000,0,1),(48,'',1,0,2,'2021-12-21 17:33:39','2021-12-21 17:33:39',999.000000,999.000000,0.000000,0.000000,0,1),(49,'',1,0,2,'2021-12-21 16:55:38','2021-12-21 17:08:00',868.695652,868.695652,0.000000,0.000000,0,1),(50,'',1,0,2,'2021-12-21 17:34:19','2021-12-21 17:34:20',520.869565,520.869565,0.000000,0.000000,0,1),(51,'',1,0,2,'2021-12-21 16:55:39','2021-12-21 17:08:00',260.000000,260.000000,0.000000,0.000000,0,1),(52,'',1,0,2,'2021-12-21 16:55:40','2021-12-21 17:08:00',868.695652,868.695652,0.000000,0.000000,0,1),(53,'',1,0,2,'2021-12-21 16:55:41','2021-12-21 17:08:00',799.000000,799.000000,0.000000,0.000000,0,1),(54,'',1,0,2,'2021-12-21 17:34:59','2021-12-21 17:35:00',694.782609,694.782609,0.000000,0.000000,0,1),(55,'',1,0,2,'2021-12-21 16:55:52','2021-12-21 17:08:00',399.000000,399.000000,0.000000,0.000000,0,1),(1,'',2,0,2,'2021-11-05 15:29:59','2021-12-21 17:08:00',100.710000,100.710000,0.000000,0.000000,3,1),(2,'',2,0,2,'2021-11-05 15:29:59','2021-12-21 17:08:00',78.786000,78.786000,0.000000,0.000000,3,1),(3,'',2,0,2,'2021-11-05 15:30:00','2021-12-21 17:08:00',162.000000,162.000000,0.000000,0.000000,3,1),(4,'',2,0,2,'2021-11-05 15:30:01','2021-12-21 17:08:00',33.705000,33.705000,0.000000,0.000000,3,1),(5,'',2,0,2,'2021-11-05 15:30:01','2021-12-21 17:08:00',50.250000,50.250000,0.000000,0.000000,3,1),(6,'',2,0,2,'2021-11-05 15:30:03','2021-12-21 17:08:00',135.000000,135.000000,0.000000,0.000000,3,1),(7,'',2,0,2,'2021-11-05 15:30:03','2021-12-21 17:08:00',26.046000,26.046000,0.000000,0.000000,3,1),(8,'',2,0,2,'2021-11-05 15:30:04','2021-12-21 17:08:00',55.152000,55.152000,0.000000,0.000000,3,1),(9,'',2,0,2,'2021-11-05 15:30:05','2021-12-21 17:08:00',44.430000,44.430000,0.000000,0.000000,3,1),(10,'',2,0,2,'2021-11-05 15:30:06','2021-12-21 17:08:00',10.000000,10.000000,0.000000,0.000000,3,1),(11,'',2,0,2,'2021-11-05 15:30:06','2021-12-21 17:08:00',195.741000,195.741000,0.000000,0.000000,3,1),(12,'',2,0,2,'2021-11-05 15:30:07','2021-12-21 17:08:00',42.894000,42.894000,0.000000,0.000000,3,1),(13,'',2,0,2,'2021-11-16 12:13:42','2021-11-16 12:13:42',39.780000,39.780000,0.000000,0.000000,3,1),(14,'',2,0,2,'2021-11-05 15:30:08','2021-12-21 17:08:00',162.000000,162.000000,0.000000,0.000000,3,1),(15,'',2,0,2,'2021-11-05 15:30:08','2021-12-21 17:08:00',36.036000,36.036000,0.000000,0.000000,3,1),(16,'',2,0,2,'2021-11-15 17:58:50','2021-11-15 17:58:50',34.470000,34.470000,0.000000,0.000000,3,1),(17,'',2,0,2,'2021-11-05 15:30:11','2021-12-21 17:08:00',50.550000,50.550000,0.000000,0.000000,3,1),(18,'',2,0,2,'2021-11-05 15:30:11','2021-12-21 17:08:00',46.503000,46.503000,0.000000,0.000000,3,1),(19,'',2,0,2,'2021-11-05 15:30:11','2021-12-21 17:08:00',38.673000,38.673000,0.000000,0.000000,3,1),(20,'',2,0,2,'2021-11-05 15:30:12','2021-12-21 17:08:00',135.000000,135.000000,0.000000,0.000000,3,1),(21,'',2,0,2,'2021-11-10 10:01:25','2021-11-10 10:01:26',10.000000,10.000000,0.000000,0.000000,3,1),(22,'',2,0,2,'2021-11-05 15:30:13','2021-12-21 17:08:00',190.503000,190.503000,0.000000,0.000000,3,1),(23,'',2,0,2,'2021-11-05 15:30:13','2021-12-21 17:08:00',237.753000,237.753000,0.000000,0.000000,3,1),(24,'',2,0,2,'2021-11-05 15:30:14','2021-12-21 17:08:00',130.500000,130.500000,0.000000,0.000000,3,1),(25,'',2,0,2,'2021-11-05 15:30:15','2021-12-21 17:08:00',170.253000,170.253000,0.000000,0.000000,3,1),(26,'',2,0,2,'2021-11-05 15:30:16','2021-12-21 17:08:00',31.500000,31.500000,0.000000,0.000000,3,1),(27,'',2,0,2,'2021-11-05 15:30:17','2021-12-21 17:08:00',35.235000,35.235000,0.000000,0.000000,0,1),(28,'',2,0,2,'2021-11-16 09:58:32','2021-11-16 09:58:32',45.000000,45.000000,0.000000,0.000000,3,1),(29,'',2,0,2,'2021-11-05 15:30:18','2021-12-21 17:08:00',141.750000,141.750000,0.000000,0.000000,3,1),(30,'',2,0,2,'2021-12-21 16:54:17','2021-12-21 17:08:00',312.260870,312.260870,0.000000,0.000000,0,1),(31,'',2,0,2,'2021-12-21 16:54:23','2021-12-21 17:08:00',273.130435,273.130435,0.000000,0.000000,0,1),(32,'',2,0,2,'2021-12-21 16:54:27','2021-12-21 17:08:00',2699.100000,2699.100000,0.000000,0.000000,0,1),(33,'',2,0,2,'2021-12-21 16:54:30','2021-12-21 17:08:00',1251.391305,1251.391305,0.000000,0.000000,0,1),(34,'',2,0,2,'2021-12-21 16:54:36','2021-12-21 17:08:00',1173.130435,1173.130435,0.000000,0.000000,0,1),(35,'',2,0,2,'2021-12-21 17:33:14','2021-12-21 17:33:15',2112.260870,2112.260870,0.000000,0.000000,0,1),(36,'',2,0,2,'2021-12-21 16:54:45','2021-12-21 17:08:00',70.395652,70.395652,0.000000,0.000000,0,1),(37,'',2,0,2,'2021-12-21 16:54:52','2021-12-21 17:08:00',62.569565,62.569565,0.000000,0.000000,0,1),(38,'',2,0,2,'2021-12-21 16:54:59','2021-12-21 17:08:00',44.100000,44.100000,0.000000,0.000000,0,1),(39,'',2,0,2,'2021-12-21 16:55:00','2021-12-21 17:08:00',35.100000,35.100000,0.000000,0.000000,0,1),(40,'',2,0,2,'2021-12-21 16:55:02','2021-12-21 17:08:00',44.100000,44.100000,0.000000,0.000000,0,1),(41,'',2,0,2,'2021-12-21 16:55:03','2021-12-21 17:08:00',44.100000,44.100000,0.000000,0.000000,0,1),(42,'',2,0,2,'2021-12-21 16:55:04','2021-12-21 17:08:00',719.100000,719.100000,0.000000,0.000000,0,1),(43,'',2,0,2,'2021-12-21 16:55:08','2021-12-21 17:08:00',1407.913043,1407.913043,0.000000,0.000000,0,1),(44,'',2,0,2,'2021-12-21 16:55:12','2021-12-21 17:08:00',1720.956522,1720.956522,0.000000,0.000000,0,1),(45,'',2,0,2,'2021-12-21 16:55:18','2021-12-21 17:08:00',1709.100000,1709.100000,0.000000,0.000000,0,1),(46,'',2,0,2,'2021-12-21 17:33:53','2021-12-21 17:33:53',492.260870,492.260870,0.000000,0.000000,0,1),(47,'',2,0,2,'2021-12-21 16:55:20','2021-12-21 17:08:00',629.100000,629.100000,0.000000,0.000000,0,1),(48,'',2,0,2,'2021-12-21 17:33:39','2021-12-21 17:33:39',899.100000,899.100000,0.000000,0.000000,0,1),(49,'',2,0,2,'2021-12-21 16:55:38','2021-12-21 17:08:00',781.826087,781.826087,0.000000,0.000000,0,1),(50,'',2,0,2,'2021-12-21 17:34:19','2021-12-21 17:34:20',468.782609,468.782609,0.000000,0.000000,0,1),(51,'',2,0,2,'2021-12-21 16:55:39','2021-12-21 17:08:00',234.000000,234.000000,0.000000,0.000000,0,1),(52,'',2,0,2,'2021-12-21 16:55:40','2021-12-21 17:08:00',781.826087,781.826087,0.000000,0.000000,0,1),(53,'',2,0,2,'2021-12-21 16:55:41','2021-12-21 17:08:00',719.100000,719.100000,0.000000,0.000000,0,1),(54,'',2,0,2,'2021-12-21 17:34:59','2021-12-21 17:35:00',625.304348,625.304348,0.000000,0.000000,0,1),(55,'',2,0,2,'2021-12-21 16:55:52','2021-12-21 17:08:00',359.100000,359.100000,0.000000,0.000000,0,1);
/*!40000 ALTER TABLE `product_price_index` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `product_to_template`
--

DROP TABLE IF EXISTS `product_to_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `product_to_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `theme_name` varchar(256) NOT NULL DEFAULT '',
  `template_name` varchar(256) NOT NULL DEFAULT '',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `product_to_template`
--

LOCK TABLES `product_to_template` WRITE;
/*!40000 ALTER TABLE `product_to_template` DISABLE KEYS */;
/*!40000 ALTER TABLE `product_to_template` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products`
--

DROP TABLE IF EXISTS `products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products` (
  `products_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_quantity` int(4) NOT NULL DEFAULT '0',
  `allocated_stock_quantity` int(11) NOT NULL DEFAULT '0',
  `temporary_stock_quantity` int(11) NOT NULL DEFAULT '0',
  `warehouse_stock_quantity` int(11) NOT NULL DEFAULT '0',
  `suppliers_stock_quantity` int(11) NOT NULL DEFAULT '0',
  `ordered_stock_quantity` int(11) NOT NULL DEFAULT '0',
  `products_model` varchar(255) DEFAULT NULL,
  `products_image` varchar(64) DEFAULT NULL,
  `products_image_med` varchar(64) DEFAULT NULL,
  `products_image_lrg` varchar(64) DEFAULT NULL,
  `products_image_sm_1` varchar(64) DEFAULT NULL,
  `products_image_xl_1` varchar(64) DEFAULT NULL,
  `products_image_sm_2` varchar(64) DEFAULT NULL,
  `products_image_xl_2` varchar(64) DEFAULT NULL,
  `products_image_sm_3` varchar(64) DEFAULT NULL,
  `products_image_xl_3` varchar(64) DEFAULT NULL,
  `products_image_sm_4` varchar(64) DEFAULT NULL,
  `products_image_xl_4` varchar(64) DEFAULT NULL,
  `products_image_sm_5` varchar(64) DEFAULT NULL,
  `products_image_xl_5` varchar(64) DEFAULT NULL,
  `products_image_sm_6` varchar(64) DEFAULT NULL,
  `products_image_xl_6` varchar(64) DEFAULT NULL,
  `products_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `products_price_rrp` decimal(15,2) NOT NULL DEFAULT '0.00',
  `products_date_added` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `products_last_modified` datetime DEFAULT NULL,
  `products_date_available` datetime DEFAULT NULL,
  `products_weight` decimal(6,3) NOT NULL DEFAULT '0.000',
  `products_status` tinyint(1) NOT NULL DEFAULT '0',
  `products_status_bundle` tinyint(1) NOT NULL DEFAULT '1',
  `manual_control_status` tinyint(1) NOT NULL DEFAULT '1',
  `products_tax_class_id` int(11) NOT NULL DEFAULT '0',
  `manufacturers_id` int(11) DEFAULT NULL,
  `products_ordered` int(11) NOT NULL DEFAULT '0',
  `products_seo_page_name` varchar(255) NOT NULL DEFAULT '',
  `products_old_seo_page_name` varchar(255) NOT NULL DEFAULT '',
  `products_image_alt_1` varchar(64) NOT NULL DEFAULT '',
  `products_image_alt_2` varchar(64) NOT NULL DEFAULT '',
  `products_image_alt_3` varchar(64) NOT NULL DEFAULT '',
  `products_image_alt_4` varchar(64) NOT NULL DEFAULT '',
  `products_image_alt_5` varchar(64) NOT NULL DEFAULT '',
  `products_image_alt_6` varchar(64) NOT NULL DEFAULT '',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `products_file` varchar(255) NOT NULL DEFAULT '',
  `products_price_discount` varchar(255) NOT NULL DEFAULT '',
  `vendor_id` int(11) NOT NULL DEFAULT '0',
  `previous_status` tinyint(4) DEFAULT NULL,
  `last_xml_import` datetime DEFAULT NULL,
  `last_xml_export` datetime DEFAULT NULL,
  `products_sets_discount` decimal(12,2) NOT NULL DEFAULT '0.00',
  `products_ean` varchar(13) NOT NULL DEFAULT '',
  `products_asin` varchar(10) NOT NULL DEFAULT '',
  `products_isbn` varchar(13) NOT NULL DEFAULT '',
  `bonus_points_price` decimal(12,2) NOT NULL DEFAULT '0.00',
  `bonus_points_cost` decimal(15,2) NOT NULL DEFAULT '0.00',
  `is_virtual` tinyint(1) NOT NULL DEFAULT '0',
  `dimensions_cm` varchar(32) NOT NULL DEFAULT '',
  `length_cm` decimal(5,2) NOT NULL DEFAULT '0.00',
  `width_cm` decimal(5,2) NOT NULL DEFAULT '0.00',
  `height_cm` decimal(5,2) NOT NULL DEFAULT '0.00',
  `weight_cm` decimal(6,3) NOT NULL DEFAULT '0.000',
  `dimensions_in` varchar(32) NOT NULL DEFAULT '',
  `length_in` decimal(5,2) NOT NULL DEFAULT '0.00',
  `width_in` decimal(5,2) NOT NULL DEFAULT '0.00',
  `height_in` decimal(5,2) NOT NULL DEFAULT '0.00',
  `weight_in` decimal(6,3) NOT NULL DEFAULT '0.000',
  `inner_carton_size` varchar(32) NOT NULL DEFAULT '',
  `inner_carton_dimensions_cm` varchar(32) NOT NULL DEFAULT '',
  `inner_length_cm` decimal(5,2) NOT NULL DEFAULT '0.00',
  `inner_width_cm` decimal(5,2) NOT NULL DEFAULT '0.00',
  `inner_height_cm` decimal(5,2) NOT NULL DEFAULT '0.00',
  `inner_weight_cm` decimal(6,3) NOT NULL DEFAULT '0.000',
  `inner_carton_dimensions_in` varchar(32) NOT NULL DEFAULT '',
  `inner_length_in` decimal(5,2) NOT NULL DEFAULT '0.00',
  `inner_width_in` decimal(5,2) NOT NULL DEFAULT '0.00',
  `inner_height_in` decimal(5,2) NOT NULL DEFAULT '0.00',
  `inner_weight_in` decimal(6,3) NOT NULL DEFAULT '0.000',
  `outer_carton_size` varchar(32) NOT NULL DEFAULT '',
  `outer_carton_dimensions_cm` varchar(32) NOT NULL DEFAULT '',
  `outer_length_cm` decimal(5,2) NOT NULL DEFAULT '0.00',
  `outer_width_cm` decimal(5,2) NOT NULL DEFAULT '0.00',
  `outer_height_cm` decimal(5,2) NOT NULL DEFAULT '0.00',
  `outer_weight_cm` decimal(6,3) NOT NULL DEFAULT '0.000',
  `outer_carton_dimensions_in` varchar(32) NOT NULL DEFAULT '',
  `outer_length_in` decimal(5,2) NOT NULL DEFAULT '0.00',
  `outer_width_in` decimal(5,2) NOT NULL DEFAULT '0.00',
  `outer_height_in` decimal(5,2) NOT NULL DEFAULT '0.00',
  `outer_weight_in` decimal(6,3) NOT NULL DEFAULT '0.000',
  `pack_unit` int(11) NOT NULL DEFAULT '0',
  `packaging` int(11) NOT NULL DEFAULT '0',
  `products_sets_price` decimal(11,2) NOT NULL DEFAULT '0.00',
  `shipping_surcharge_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `order_quantity_minimal` int(11) unsigned NOT NULL DEFAULT '1',
  `order_quantity_step` int(11) unsigned NOT NULL DEFAULT '1',
  `item_in_virtual_item_qty` int(11) unsigned NOT NULL DEFAULT '1',
  `item_in_virtual_item_step` varchar(250) NOT NULL DEFAULT ';1;',
  `products_upc` varchar(14) NOT NULL DEFAULT '',
  `subscription` tinyint(1) NOT NULL DEFAULT '0',
  `subscription_code` varchar(32) DEFAULT NULL,
  `products_price_full` tinyint(1) NOT NULL DEFAULT '0',
  `manual_stock_unlimited` tinyint(1) NOT NULL DEFAULT '0',
  `stock_indication_id` int(11) NOT NULL DEFAULT '0',
  `stock_delivery_terms_id` int(11) NOT NULL DEFAULT '0',
  `stock_reorder_level` int(11) NOT NULL DEFAULT '-1',
  `stock_reorder_quantity` int(11) NOT NULL DEFAULT '-1',
  `products_price_pack_unit` decimal(15,6) NOT NULL DEFAULT '-2.000000',
  `products_price_discount_pack_unit` varchar(255) NOT NULL DEFAULT '',
  `products_price_packaging` decimal(15,6) NOT NULL DEFAULT '-2.000000',
  `products_price_discount_packaging` varchar(255) NOT NULL DEFAULT '',
  `products_pctemplates_id` int(11) NOT NULL DEFAULT '0',
  `product_designer_template_id` int(11) DEFAULT '0',
  `component_only` tinyint(4) NOT NULL DEFAULT '0',
  `elements_included` tinyint(4) NOT NULL DEFAULT '0',
  `products_price_configurator` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `products_discount_configurator` decimal(12,2) NOT NULL DEFAULT '0.00',
  `products_groups_id` int(11) NOT NULL DEFAULT '0',
  `request_quote` tinyint(1) NOT NULL DEFAULT '0',
  `request_quote_out_stock` tinyint(1) NOT NULL DEFAULT '0',
  `ask_sample` tinyint(1) NOT NULL DEFAULT '0',
  `cart_button` tinyint(1) NOT NULL DEFAULT '1',
  `disable_discount` int(1) DEFAULT '0',
  `products_popularity` decimal(8,3) DEFAULT '0.000',
  `popularity_simple` decimal(8,3) DEFAULT '0.000',
  `popularity_bestseller` decimal(8,3) DEFAULT '0.000',
  `created_by_platform_id` int(11) NOT NULL DEFAULT '0',
  `use_sets_discount` int(1) NOT NULL DEFAULT '0',
  `maps_id` int(11) NOT NULL DEFAULT '0',
  `is_bundle` tinyint(1) NOT NULL DEFAULT '0',
  `products_sets_price_formula` varchar(1024) NOT NULL DEFAULT '',
  `supplier_price_manual` tinyint(1) DEFAULT NULL,
  `stock_control` int(4) NOT NULL DEFAULT '0',
  `disable_children_discount` tinyint(1) NOT NULL DEFAULT '0',
  `is_listing_product` int(11) NOT NULL DEFAULT '1',
  `sub_product_children_count` int(11) NOT NULL DEFAULT '0',
  `parent_products_id` int(11) NOT NULL DEFAULT '0',
  `products_id_stock` int(11) NOT NULL DEFAULT '0',
  `products_id_price` int(11) NOT NULL DEFAULT '0',
  `sub_product_prev_status` int(11) DEFAULT NULL,
  `source` varchar(32) NOT NULL DEFAULT '',
  `bundle_volume_calc` int(2) NOT NULL DEFAULT '0',
  `allow_backorder` int(2) NOT NULL DEFAULT '0',
  `reorder_auto` tinyint(1) NOT NULL DEFAULT '0',
  `without_inventory` int(1) NOT NULL DEFAULT '0',
  `volume_weight_cm` decimal(8,2) NOT NULL DEFAULT '0.00',
  `volume_weight_in` decimal(8,2) NOT NULL DEFAULT '0.00',
  `order_quantity_max` int(11) NOT NULL DEFAULT '0',
  `jsonld_product_type` int(2) DEFAULT '0',
  `products_new_until` datetime DEFAULT NULL,
  `product_unit_label` varchar(64) DEFAULT NULL,
  `products_groups_sort` int(4) NOT NULL DEFAULT '0',
  `stock_limit` int(11) NOT NULL DEFAULT '-1',
  `out_stock_action` int(1) NOT NULL DEFAULT '0',
  `is_demo` int(1) NOT NULL DEFAULT '0',
  `rma_allow_time` varchar(64) NOT NULL DEFAULT '',
  `auto_price_modified` datetime DEFAULT NULL,
  PRIMARY KEY (`products_id`),
  UNIQUE KEY `idx_id_status` (`products_id`,`products_status`),
  KEY `idx_products_date_added` (`products_date_added`),
  KEY `products_model` (`products_model`(16)),
  KEY `id_status` (`products_status`),
  KEY `idx_component_only` (`component_only`),
  KEY `idx_stock_indication_id` (`stock_indication_id`),
  KEY `idx_products_old_seo_page_name` (`products_old_seo_page_name`),
  KEY `products_seo_page_name` (`products_seo_page_name`),
  KEY `idx_price` (`products_price`),
  KEY `parent_product` (`parent_products_id`),
  KEY `parent_stock_product` (`products_id_stock`),
  KEY `parent_price_product` (`products_id_price`),
  KEY `idx_products_tax_class_status` (`products_tax_class_id`,`products_status`,`stock_indication_id`),
  KEY `idx_products_ordered_status` (`products_ordered`,`products_status`),
  KEY `products_source` (`source`),
  KEY `idx_products_new_until` (`products_new_until`),
  KEY `idx_products_last_modified_status` (`products_last_modified`,`products_status`),
  KEY `idx_status_last_modified` (`products_status`,`products_last_modified`),
  KEY `idx_manufacturers_pproducts_stockindication_id` (`manufacturers_id`,`products_id`,`stock_indication_id`),
  FULLTEXT KEY `idx_products_model` (`products_model`)
) ENGINE=InnoDB AUTO_INCREMENT=76 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products`
--

LOCK TABLES `products` WRITE;
/*!40000 ALTER TABLE `products` DISABLE KEYS */;
INSERT INTO `products` VALUES (1,99,0,0,99,0,0,'NY2146',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,111.900000,0.00,'2014-10-17 12:28:18','2022-07-23 13:58:28',NULL,0.000,1,1,1,3,1,0,'','','','','','','','',45,'','10:111.9;50:100;100:80;',0,NULL,NULL,NULL,0.00,'4053858190559','B00GN3PLU2','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.461,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,1,1,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(2,100,0,0,100,0,0,'PU102742005',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,87.540000,0.00,'2014-10-17 14:23:42','2022-07-23 15:21:48',NULL,0.000,1,1,1,3,2,0,'','','','','','','','',88,'','2:80;3:75;4:70;',0,NULL,NULL,NULL,0.00,'0716459 41497','B0097E9NGC','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.492,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,2,2,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(3,100,0,0,100,0,0,'PU102812003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,180.000000,0.00,'2014-10-17 14:36:49','2022-07-23 13:58:59',NULL,0.000,1,1,1,3,2,0,'','','','','','','','',86,'','3:16;5:14;10:10;',0,NULL,NULL,NULL,0.00,'0716459418920','B00BCQ7A0Y','',50.00,40.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.661,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,3,3,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(4,98,0,0,98,0,0,'U25004L1',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,37.450000,0.00,'2014-10-17 15:18:50','2022-07-23 14:01:06',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',41,'','',0,NULL,NULL,NULL,0.00,'91661370878','B002WJ2LTA','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.630,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,4,4,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(5,100,0,0,100,0,0,'11807012',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,55.833333,0.00,'2014-10-17 15:27:19','2022-07-23 14:01:32',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',107,'','4:54.166667;6:50;10:45.833333;',0,NULL,NULL,NULL,0.00,'0885997014687','B00BNY51TM','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.061,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,5,5,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(6,100,0,0,100,0,0,'1790708',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,150.000000,0.00,'2014-10-17 15:33:54','2022-07-23 14:01:22',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',105,'','',0,NULL,NULL,NULL,0.00,'8699031062112','B003CUYGDW','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.091,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,6,6,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(7,98,0,0,98,0,0,'1790853',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,28.940000,0.00,'2014-10-17 16:00:50','2022-07-23 14:01:27',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',106,'','',0,NULL,NULL,NULL,0.00,'4015573328303','B006G0F0TE','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.550,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,7,7,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(8,100,0,0,100,0,0,'YA126238',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,61.280000,0.00,'2014-10-17 16:11:24','2022-07-23 14:00:54',NULL,0.000,1,1,1,3,3,0,'','','','','','','','',38,'','10:60;20:50;30:40;',0,NULL,NULL,NULL,0.00,'0731903327535','B008B0K8JE','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,1,1,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.060,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,8,8,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(9,98,1,0,99,0,0,'NY8183',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,49.360000,0.00,'2014-10-17 16:57:27','2022-07-23 15:19:45',NULL,0.000,1,1,1,3,1,1,'','','','','','','','',44,'','',0,NULL,NULL,NULL,0.00,'4051432089015','B004MRIAK4','',20.00,10.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.663,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,9,9,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(10,100,0,0,100,0,0,'YA133504',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,109.841667,0.00,'2014-10-17 17:08:29','2022-07-23 13:58:47',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',89,'','2:10;3:9;4:8;5:7;',0,NULL,NULL,NULL,0.00,'5249787412353','B00CALV452','',150.00,45.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.341,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,10,10,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(11,100,0,0,100,0,0,'YA129444',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,217.490000,0.00,'2014-10-17 17:14:41','2022-07-23 15:21:23',NULL,0.000,1,1,1,3,2,0,'','','','','','','','',87,'','',0,NULL,NULL,NULL,0.00,'0731903349230','B00K0D88TW','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.421,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,11,11,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(12,100,0,0,100,0,0,'YA133202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,47.660000,0.00,'2014-10-20 09:42:51','2022-07-23 14:01:00',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',39,'','',0,NULL,NULL,NULL,0.00,'42429557413','B00B0CCU7I','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,2,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.060,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,12,12,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(13,100,0,0,100,0,0,'G100-1BV',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,44.200000,0.00,'2014-10-20 09:59:11','2022-07-25 12:08:47',NULL,0.000,1,1,1,3,4,0,'','','','','','','','',10,'','',0,NULL,NULL,NULL,0.00,'4971850739050','B000AR7S3A','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,1,0,0,0,1,0,0.340,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,13,13,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(14,100,0,0,100,0,0,'BG169G-7B',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,180.000000,0.00,'2014-10-20 10:03:06','2022-07-23 13:59:18',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',14,'','3:16;5:14;10:10;',0,NULL,NULL,NULL,0.00,'','B01ETNXGOK','',50.00,40.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,1,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.511,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,14,14,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(15,96,0,0,96,0,0,'MTP1192E-7A',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,40.040000,0.00,'2014-10-20 10:15:48','2022-07-25 12:27:22',NULL,0.000,1,1,1,3,4,0,'','','','','','','','',11,'','5:37.5;7:33.333333;10:31.666667;',0,NULL,NULL,NULL,0.00,'4971850775195','B009SAYZYU','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,1,0,0,0,1,0,0.440,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,15,15,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(16,100,0,0,100,0,0,'EFA121D-7AV',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,38.300000,0.00,'2014-10-20 10:33:50','2022-07-25 12:22:36',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',12,'','',0,NULL,NULL,NULL,0.00,'4971850873839','B001MDFVJ4','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,9,9,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.390,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,16,16,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(17,100,0,0,100,0,0,'W753-2AV',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,56.170000,0.00,'2014-10-20 10:43:29','2022-07-23 14:00:14',NULL,0.000,1,1,1,3,4,0,'','','','','','','','',13,'','',0,NULL,NULL,NULL,0.00,'4971850827740','B000AR7RZ4','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,3,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.640,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,17,17,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(18,99,0,0,99,0,0,'THR827N',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,51.670000,0.00,'2014-10-21 09:43:37','2022-07-23 15:20:51',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',70,'','3:51;5:50;',0,NULL,NULL,NULL,0.00,'','B004RTTFH4','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.402,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,18,18,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(19,100,0,0,100,0,0,'BBB516S',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,42.970000,0.00,'2014-10-21 09:48:42','2022-07-23 14:01:11',NULL,0.000,1,1,1,3,5,0,'','','','','','','','',71,'','',0,NULL,NULL,NULL,0.00,'0751744227344','B00AQ6U4RC','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.071,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,19,19,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(20,100,0,0,100,0,0,'TWXB078K',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,150.000000,0.00,'2014-10-21 09:52:35','2022-07-23 14:01:16',NULL,0.000,1,1,1,3,5,0,'','','','','','','','',69,'','',0,NULL,NULL,NULL,0.00,'0609788671077','B007VZ3XPG','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.090,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,20,20,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(21,100,0,0,100,0,0,'W20072X7',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,11.510101,9.00,'2014-10-21 09:56:15','2022-07-25 12:17:51',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',8,'','2:10;3:9;4:8;5:7;',0,NULL,NULL,NULL,0.00,'0761245625965','B000FTLNFM','',150.00,45.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,1,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,1,0,0,0,1,0,0.510,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,21,21,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(22,100,0,0,100,0,0,'85010-37J-AID',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,211.670000,0.00,'2014-10-21 10:02:29','2022-07-23 14:00:44',NULL,0.000,1,1,1,3,6,0,'','','','','','','','',48,'','',0,NULL,NULL,NULL,0.00,'7640156422757','B00KNTGLU6','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.442,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,22,22,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(23,100,0,0,100,0,0,'01112-3-BUIN',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,264.170000,0.00,'2014-10-21 10:05:54','2022-07-25 08:55:20',NULL,0.000,1,1,1,3,6,0,'','','','','','','','',49,'','',0,NULL,NULL,NULL,0.00,'7640156420012','B0089TDQ8C','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.530,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,23,23,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(24,100,0,0,100,0,0,'0311818',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,145.000000,0.00,'2014-10-21 10:12:58','2022-07-23 14:00:39',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',20,'','',0,NULL,NULL,NULL,0.00,'0885997087742','B00HERO10W','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.603,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,24,24,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(25,100,0,0,100,10,0,'AO9030-05E',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,189.170000,0.00,'2014-10-21 10:24:39','2022-07-23 14:00:19',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',17,'','',0,NULL,NULL,NULL,0.00,'13205101670','B00CB99Z5E','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,1,1,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.642,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,25,25,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(26,100,0,0,100,0,0,'CA0467-03E',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,35.000000,0.00,'2014-10-21 15:23:03','2022-07-23 14:00:23',NULL,0.000,1,1,1,3,7,0,'','','','','','','','',16,'','',0,NULL,NULL,NULL,0.00,'13205100048','B009G75M38','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.472,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,26,26,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(27,100,0,0,100,0,0,'AT2215-07E',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,39.150000,0.00,'2014-10-21 16:22:05','2022-07-23 14:00:33',NULL,0.000,1,1,1,0,0,0,'','','','','','','','',18,'','',0,NULL,NULL,NULL,0.00,'4562195133322','B00BNPIANK','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.491,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,27,27,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(28,100,0,0,100,0,0,'BJ8050-08E',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,50.000000,0.00,'2014-10-21 16:46:21','2022-07-23 14:00:28',NULL,0.000,1,1,1,3,7,0,'','','','','','','','',15,'','',0,NULL,NULL,NULL,0.00,'4003702659930','B000EQU15O','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.533,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,28,28,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(29,100,0,0,100,0,0,'Royal-41003-03',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,157.500000,0.00,'2017-01-26 11:24:24','2022-07-23 14:01:37',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'5051496065481','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.782,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,29,29,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(30,100,0,0,100,0,0,'79189',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,82.500000,0.00,'2022-02-21 09:55:59','2022-07-25 12:39:32',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.511,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,30,30,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(31,100,0,0,100,0,0,'MWT15',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,74.158333,0.00,'2022-02-21 10:30:49','2022-07-25 12:48:07',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.550,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,31,31,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(32,100,0,0,100,0,0,'MWT13',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,107.491667,0.00,'2022-02-21 10:32:25','2022-07-25 12:45:27',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.494,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,32,32,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(33,100,0,0,100,0,0,'39849',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,65.833333,0.00,'2022-02-21 10:47:12','2022-07-25 12:36:32',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.530,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,33,33,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(34,99,1,0,100,0,0,'8081101',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,262.500000,0.00,'2022-02-21 10:55:19','2022-07-25 13:04:06',NULL,0.000,1,1,1,3,0,1,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.600,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,34,34,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(35,100,0,0,100,0,0,'8081001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,274.100000,0.00,'2022-02-21 11:04:03','2022-07-25 13:02:21',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.540,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,35,35,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(36,100,0,0,100,0,0,'KF807537',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,180.200000,0.00,'2022-02-21 11:17:43','2022-07-25 12:58:38',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.430,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,36,36,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(37,100,0,0,100,0,0,'drawerside',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,54.166667,0.00,'2022-02-21 11:28:09','2022-07-25 12:53:54',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.450,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,37,37,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(38,100,0,0,100,0,0,'89502105',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,99.991667,0.00,'2022-02-21 08:17:16','2022-07-25 11:26:57',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.765,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,38,38,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(39,100,0,0,100,0,0,'89502103',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,74.991667,0.00,'2022-02-21 08:20:14','2022-07-25 11:20:19',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.430,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,39,39,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(40,100,0,0,100,0,0,'ECOTANK M2120',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,247.408333,0.00,'2022-02-21 08:57:12','2022-07-25 11:16:14',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.500,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,40,40,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(41,100,0,0,100,0,0,'ECOTANKM15140',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,832.483333,0.00,'2022-02-21 09:03:27','2022-07-25 11:22:59',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.591,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,41,41,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(42,100,0,0,100,0,0,'G3260',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,166.658333,0.00,'2022-02-21 09:09:00','2022-07-25 10:56:54',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.470,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,42,42,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(43,100,0,0,100,0,0,'DR-6010C',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2075.825000,0.00,'2022-02-21 09:13:17','2022-07-25 11:12:33',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.480,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,43,43,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(44,100,0,0,100,0,0,'629373',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,58.325000,0.00,'2022-02-21 09:19:31','2022-07-25 10:50:13',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.600,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,44,44,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(45,99,1,0,100,0,0,'780020',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,66.658333,0.00,'2022-02-21 09:21:34','2022-07-25 11:12:09',NULL,0.000,1,1,1,3,0,1,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.410,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,45,45,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(46,100,0,0,100,0,0,'789669',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,291.658333,0.00,'2022-02-21 09:26:56','2022-07-25 11:37:40',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.580,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,46,46,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(47,100,0,0,100,0,0,'236124',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,83.325000,0.00,'2022-02-21 09:28:17','2022-07-25 11:34:37',NULL,0.000,1,1,1,3,0,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.440,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,47,47,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(48,98,2,0,100,0,0,'131109',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,116.658333,0.00,'2022-02-21 09:29:41','2022-07-25 11:31:29',NULL,0.000,1,1,1,3,0,2,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.640,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,48,48,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(49,100,0,0,100,0,0,'245042',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,324.166667,0.00,'2022-02-21 09:31:13','2022-07-25 11:40:02',NULL,0.000,1,1,1,3,0,1,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.661,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,49,49,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(50,2356,0,0,2356,0,0,'00GM21-01Y014-Q',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,346.956522,0.00,'2017-11-16 17:11:58','2022-07-23 14:06:19',NULL,0.000,1,1,1,0,8,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.551,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,50,50,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(51,2000,0,0,2000,0,0,'00GM21-01Y014-D',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,303.478261,0.00,'2017-11-16 17:11:59','2022-07-23 14:06:13',NULL,0.000,1,1,1,0,8,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.540,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,51,51,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(52,1050,0,0,1050,0,0,'PCOU04-SMKGUM',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2999.000000,0.00,'2018-01-17 12:50:40','2022-07-23 14:25:18',NULL,0.000,1,1,1,0,9,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.461,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,52,52,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(53,2038,0,0,2038,0,0,'PJAC09-050093',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1390.434783,0.00,'2018-01-17 12:53:15','2022-07-23 14:46:33',NULL,0.000,1,1,1,0,10,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.810,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,53,53,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(54,2038,0,0,2038,0,0,'PJAC08-0400P3',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1303.478261,0.00,'2018-01-17 12:53:22','2022-07-23 14:43:56',NULL,0.000,1,1,1,0,10,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.541,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,54,54,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(55,2129,0,0,2129,0,0,'PHAM02-05A201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2346.956522,0.00,'2018-01-17 12:54:23','2022-07-23 14:04:43',NULL,0.000,1,1,1,0,11,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.721,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,55,55,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(56,1019,1,0,1020,0,0,'00MPKQ-010000-K',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,78.217391,0.00,'2018-01-17 13:05:01','2022-07-23 14:45:53',NULL,0.000,1,1,1,0,12,1,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,2,0,0,0,1,0,0.061,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,56,56,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(57,955,2,0,957,0,0,'00MPQQ-010000-Q',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,69.521739,0.00,'2018-01-17 13:05:03','2022-07-23 14:02:02',NULL,0.000,1,1,1,0,12,2,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,2,0,0,0,1,0,0.352,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,57,57,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(58,22464,0,0,22464,0,0,'22585C',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,49.000000,0.00,'2018-10-10 23:30:35','2022-07-23 14:02:30',NULL,0.000,1,1,1,0,13,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.190,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,58,58,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(59,1096,0,0,1096,0,0,'22898C',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,39.000000,0.00,'2018-10-10 23:30:35','2022-07-23 14:45:08',NULL,0.000,1,1,1,0,13,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.260,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,59,59,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(60,1100,0,0,1100,0,0,'23077T',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,49.000000,0.00,'2018-10-10 23:30:35','2022-07-23 15:18:44',NULL,0.000,1,1,1,0,13,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.220,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,60,60,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(61,2200,0,0,2200,0,0,'23078T',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,49.000000,0.00,'2018-10-10 23:30:35','2022-07-23 14:26:42',NULL,0.000,1,1,1,0,13,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.383,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,61,61,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(62,2000,0,0,2000,0,0,'OLIVIA-TB308DE-DT',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,799.000000,0.00,'2018-10-10 23:30:43','2022-07-23 14:06:00',NULL,0.000,1,1,1,0,14,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.200,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,62,62,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(63,2000,0,0,2000,0,0,'CLAYTON32-R8308-BROWN',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1564.347826,0.00,'2019-02-21 12:32:46','2022-07-25 08:54:01',NULL,0.000,1,1,1,0,15,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.210,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,63,63,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(64,998,1,0,999,0,0,'CLAYTON321-R8308-BROWN',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1912.173913,0.00,'2019-02-21 12:32:46','2022-07-23 14:05:38',NULL,0.000,1,1,1,0,15,1,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.321,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,64,64,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(65,2000,0,0,2000,0,0,'VERONICAQUEEN4-NEW',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1899.000000,0.00,'2019-02-21 12:32:50','2022-07-24 12:05:57',NULL,0.000,1,1,1,0,16,1,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.424,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,65,65,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(66,1000,0,0,1000,0,0,'MONA-1237-RED',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,546.956522,0.00,'2019-06-27 22:57:55','2022-07-23 14:05:55',NULL,0.000,1,1,1,0,17,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.250,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,66,66,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(67,2000,0,0,2000,0,0,'MICHAEL-150BLK-PACKAGE',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,699.000000,699.00,'2019-07-10 11:26:56','2022-07-23 14:05:49',NULL,0.000,1,1,1,0,18,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.250,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,67,67,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(68,997,0,0,997,0,0,'CASPERPACKAGE',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,999.000000,999.00,'2019-08-29 16:41:20','2022-07-23 14:44:33',NULL,0.000,1,1,1,0,19,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.311,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,68,68,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(69,2000,0,0,2000,0,0,'JONAS180PACKAGE',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,868.695652,0.00,'2019-09-25 21:10:26','2022-07-23 14:44:48',NULL,0.000,1,1,1,0,20,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.291,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,69,69,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(70,996,0,0,996,0,0,'JONASBARPACKAGE',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,520.869565,0.00,'2019-09-25 21:14:40','2022-07-23 14:06:50',NULL,0.000,1,1,1,0,20,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.272,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,70,70,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(71,2000,0,0,2000,0,0,'HUC25806',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,260.000000,0.00,'2019-09-25 21:27:42','2022-07-23 14:07:11',NULL,0.000,1,1,1,0,20,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.322,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,71,71,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(72,2000,0,0,2000,0,0,'JONASLOUNGE',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,868.695652,0.00,'2019-09-25 21:59:52','2022-07-23 14:06:44',NULL,0.000,1,1,1,0,20,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.281,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,72,72,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(73,2094,0,0,2094,0,0,'00TB03-NEWERIN-KS',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,799.000000,799.00,'2019-09-27 17:15:27','2022-07-23 14:06:25',NULL,0.000,1,1,1,0,21,0,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.221,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,73,73,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(74,999,1,0,1000,0,0,'199523-BERBEI-3S/C',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,694.782609,0.00,'2019-10-09 22:39:04','2022-07-23 14:05:25',NULL,0.000,1,1,1,0,22,1,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.332,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,74,74,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL),(75,2166,0,0,2166,0,0,'PR539-ZEDS QUASAR-Q',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,399.000000,0.00,'2020-01-03 15:07:49','2022-07-23 14:06:31',NULL,0.000,1,1,1,0,23,1,'','','','','','','','',0,'','',0,NULL,NULL,NULL,0.00,'','','',0.00,0.00,0,'',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,'','',0.00,0.00,0.00,0.000,'',0.00,0.00,0.00,0.000,0,0,0.00,0.000000,1,1,1,';1;','',0,NULL,0,0,0,0,-1,-1,-2.000000,'',-2.000000,'',0,NULL,0,0,0.000000,0.00,0,0,0,0,1,0,0.334,0.000,0.000,0,0,0,0,'',NULL,0,0,1,0,0,75,75,NULL,'',0,0,0,1,0.00,0.00,0,0,NULL,'',0,-1,0,1,'',NULL);
/*!40000 ALTER TABLE `products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_assets`
--

DROP TABLE IF EXISTS `products_assets`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_assets` (
  `products_assets_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` int(11) NOT NULL DEFAULT '0',
  `uprid` varchar(255) NOT NULL DEFAULT '',
  `warehouse_id` int(11) NOT NULL DEFAULT '0',
  `suppliers_id` int(11) NOT NULL DEFAULT '0',
  `orders_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`products_assets_id`),
  KEY `idx_products_id` (`products_id`),
  KEY `idx_uprid` (`uprid`),
  KEY `idx_warehouse_id` (`warehouse_id`),
  KEY `idx_suppliers_id` (`suppliers_id`),
  KEY `idx_orders_id` (`orders_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_assets`
--

LOCK TABLES `products_assets` WRITE;
/*!40000 ALTER TABLE `products_assets` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_assets` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_assets_fields`
--

DROP TABLE IF EXISTS `products_assets_fields`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_assets_fields` (
  `products_assets_fields_id` int(11) NOT NULL AUTO_INCREMENT,
  `language_id` int(11) NOT NULL DEFAULT '1',
  `products_assets_fields_name` varchar(64) DEFAULT NULL,
  `products_assets_fields_sortorder` int(11) DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  `date_last_modified` datetime DEFAULT NULL,
  PRIMARY KEY (`products_assets_fields_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_assets_fields`
--

LOCK TABLES `products_assets_fields` WRITE;
/*!40000 ALTER TABLE `products_assets_fields` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_assets_fields` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_assets_values`
--

DROP TABLE IF EXISTS `products_assets_values`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_assets_values` (
  `products_assets_id` int(11) NOT NULL DEFAULT '0',
  `products_assets_fields_id` int(11) NOT NULL DEFAULT '0',
  `products_assets_value` varchar(128) DEFAULT NULL,
  PRIMARY KEY (`products_assets_id`,`products_assets_fields_id`),
  KEY `idx_products_assets_id` (`products_assets_id`),
  KEY `idx_products_assets_fields_id` (`products_assets_fields_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_assets_values`
--

LOCK TABLES `products_assets_values` WRITE;
/*!40000 ALTER TABLE `products_assets_values` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_assets_values` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_attributes`
--

DROP TABLE IF EXISTS `products_attributes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_attributes` (
  `products_attributes_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` int(11) NOT NULL DEFAULT '0',
  `options_id` int(11) NOT NULL DEFAULT '0',
  `options_values_id` int(11) NOT NULL DEFAULT '0',
  `options_values_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `price_prefix` char(3) NOT NULL DEFAULT '+',
  `products_options_sort_order` int(6) NOT NULL DEFAULT '0',
  `product_attributes_one_time` tinyint(1) NOT NULL DEFAULT '0',
  `products_attributes_weight` decimal(6,3) NOT NULL DEFAULT '0.000',
  `products_attributes_weight_prefix` char(3) NOT NULL DEFAULT '+',
  `products_attributes_units` int(4) NOT NULL DEFAULT '0',
  `products_attributes_units_price` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `products_attributes_discount_price` varchar(255) NOT NULL DEFAULT '',
  `products_attributes_filename` varchar(255) NOT NULL DEFAULT '',
  `products_attributes_maxdays` int(11) DEFAULT NULL,
  `products_attributes_maxcount` int(11) DEFAULT NULL,
  `default_option_value` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`products_attributes_id`),
  KEY `products_id` (`products_id`,`options_id`,`options_values_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_attributes`
--

LOCK TABLES `products_attributes` WRITE;
/*!40000 ALTER TABLE `products_attributes` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_attributes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_attributes_download`
--

DROP TABLE IF EXISTS `products_attributes_download`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_attributes_download` (
  `products_attributes_id` int(11) NOT NULL DEFAULT '0',
  `products_attributes_filename` varchar(255) NOT NULL DEFAULT '',
  `products_attributes_maxdays` int(2) DEFAULT '0',
  `products_attributes_maxcount` int(2) DEFAULT '0',
  PRIMARY KEY (`products_attributes_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_attributes_download`
--

LOCK TABLES `products_attributes_download` WRITE;
/*!40000 ALTER TABLE `products_attributes_download` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_attributes_download` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_attributes_prices`
--

DROP TABLE IF EXISTS `products_attributes_prices`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_attributes_prices` (
  `products_attributes_id` int(11) NOT NULL DEFAULT '0',
  `groups_id` int(11) NOT NULL DEFAULT '0',
  `currencies_id` int(11) NOT NULL DEFAULT '0',
  `attributes_group_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `attributes_group_discount_price` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`products_attributes_id`,`groups_id`,`currencies_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_attributes_prices`
--

LOCK TABLES `products_attributes_prices` WRITE;
/*!40000 ALTER TABLE `products_attributes_prices` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_attributes_prices` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_comments`
--

DROP TABLE IF EXISTS `products_comments`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_comments` (
  `products_comments_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` varchar(255) NOT NULL DEFAULT '',
  `comments` text,
  PRIMARY KEY (`products_comments_id`),
  KEY `products_id` (`products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_comments`
--

LOCK TABLES `products_comments` WRITE;
/*!40000 ALTER TABLE `products_comments` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_comments` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_description`
--

DROP TABLE IF EXISTS `products_description`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_description` (
  `products_id` int(11) NOT NULL AUTO_INCREMENT,
  `language_id` int(11) NOT NULL DEFAULT '1',
  `products_name` varchar(255) NOT NULL DEFAULT '',
  `products_description` text,
  `products_url` varchar(255) DEFAULT NULL,
  `products_viewed` int(5) DEFAULT '0',
  `products_head_title_tag` varchar(80) DEFAULT NULL,
  `products_internal_name` varchar(255) DEFAULT NULL,
  `products_head_desc_tag` longtext NOT NULL,
  `products_head_keywords_tag` longtext NOT NULL,
  `products_description_short` varchar(255) NOT NULL DEFAULT '',
  `products_name_soundex` text,
  `products_description_soundex` text,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `department_id` int(11) NOT NULL DEFAULT '0',
  `products_seo_page_name` varchar(255) NOT NULL DEFAULT '',
  `products_self_service` text NOT NULL,
  `noindex_option` int(11) NOT NULL DEFAULT '0',
  `nofollow_option` int(11) NOT NULL DEFAULT '0',
  `rel_canonical` varchar(128) NOT NULL DEFAULT '',
  `products_h1_tag` varchar(255) NOT NULL DEFAULT '',
  `products_h2_tag` text NOT NULL,
  `products_h3_tag` text NOT NULL,
  `overwrite_head_title_tag` tinyint(1) NOT NULL DEFAULT '1',
  `overwrite_head_desc_tag` tinyint(1) NOT NULL DEFAULT '1',
  `products_image_alt_tag_mask` varchar(255) NOT NULL DEFAULT '',
  `products_image_title_tag_mask` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`products_id`,`language_id`,`platform_id`,`department_id`) USING BTREE,
  KEY `products_name` (`products_name`),
  KEY `idx_language_id` (`language_id`),
  KEY `products_seo_page_name` (`products_seo_page_name`),
  KEY `idx_affiliate_id` (`platform_id`),
  FULLTEXT KEY `idx_products_name` (`products_name`),
  FULLTEXT KEY `idx_products_description` (`products_description`)
) ENGINE=InnoDB AUTO_INCREMENT=76 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_description`
--

LOCK TABLES `products_description` WRITE;
/*!40000 ALTER TABLE `products_description` DISABLE KEYS */;
INSERT INTO `products_description` VALUES (1,1,'DKNY Women\'s NY2146 Soho Colored Chronograph Bracelet Watch','<p>A thoroughly modern DKNY watch from the Lexington collection.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 38 mm wide x 38 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 20 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 3 inches wide x 3 inches long x 3 inches high</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,S000,C463,C65261,B6243,W320','T624,M365,D250,W320,F650,T000,L25235,C4235,C000,M26532,M000,W300,L520,T200,B6243,I520,B200,H200',1,0,'dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch','',0,0,'','','','',1,1,'',''),(1,1,'DKNY Women\'s NY2146 Soho Colored Chronograph Bracelet Watch','<p>A thoroughly modern DKNY watch from the Lexington collection.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 38 mm wide x 38 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 20 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 3 inches wide x 3 inches long x 3 inches high</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,S000,C463,C65261,B6243,W320','T624,M365,D250,W320,F650,T000,L25235,C4235,C000,M26532,M000,W300,L520,T200,B6243,I520,B200,H200',4,0,'dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch','',0,0,'','','','',1,1,'',''),(1,1,'DKNY Women\'s NY2146 Soho Colored Chronograph Bracelet Watch','<p>A thoroughly modern DKNY watch from the Lexington collection.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 38 mm wide x 38 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 20 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 3 inches wide x 3 inches long x 3 inches high</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,S000,C463,C65261,B6243,W320','T624,M365,D250,W320,F650,T000,L25235,C4235,C000,M26532,M000,W300,L520,T200,B6243,I520,B200,H200',5,0,'dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch','',0,0,'','','','',1,1,'',''),(1,1,'DKNY Women\'s NY2146 Soho Colored Chronograph Bracelet Watch','<p>A thoroughly modern DKNY watch from the Lexington collection.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 38 mm wide x 38 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 20 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 3 inches wide x 3 inches long x 3 inches high</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,S000,C463,C65261,B6243,W320','T624,M365,D250,W320,F650,T000,L25235,C4235,C000,M26532,M000,W300,L520,T200,B6243,I520,B200,H200',6,0,'dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch','',0,0,'','','','',1,1,'',''),(1,1,'DKNY Women\'s NY2146 Soho Colored Chronograph Bracelet Watch','<p>A thoroughly modern DKNY watch from the Lexington collection.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 38 mm wide x 38 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 20 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 3 inches wide x 3 inches long x 3 inches high</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,S000,C463,C65261,B6243,W320','T624,M365,D250,W320,F650,T000,L25235,C4235,C000,M26532,M000,W300,L520,T200,B6243,I520,B200,H200',7,0,'dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch','',0,0,'','','','',1,1,'',''),(1,1,'DKNY Women\'s NY2146 Soho Colored Chronograph Bracelet Watch','<p>A thoroughly modern DKNY watch from the Lexington collection.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 38 mm wide x 38 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 20 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 3 inches wide x 3 inches long x 3 inches high</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,S000,C463,C65261,B6243,W320','T624,M365,D250,W320,F650,T000,L25235,C4235,C000,M26532,M000,W300,L520,T200,B6243,I520,B200,H200',8,0,'dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch','',0,0,'','','','',1,1,'',''),(1,1,'DKNY Women\'s NY2146 Soho Colored Chronograph Bracelet Watch','<p>A thoroughly modern DKNY watch from the Lexington collection.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 38 mm wide x 38 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 20 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 3 inches wide x 3 inches long x 3 inches high</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,S000,C463,C65261,B6243,W320','T624,M365,D250,W320,F650,T000,L25235,C4235,C000,M26532,M000,W300,L520,T200,B6243,I520,B200,H200',9,0,'dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch','',0,0,'','','','',1,1,'',''),(1,1,'DKNY Women\'s NY2146 Soho Colored Chronograph Bracelet Watch','<p>A thoroughly modern DKNY watch from the Lexington collection.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 38 mm wide x 38 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 20 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 3 inches wide x 3 inches long x 3 inches high</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,S000,C463,C65261,B6243,W320','T624,M365,D250,W320,F650,T000,L25235,C4235,C000,M26532,M000,W300,L520,T200,B6243,I520,B200,H200',10,0,'dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch','',0,0,'','','','',1,1,'',''),(2,1,'Puma Women\'s Motor White Polyurethane Quartz Watch with Black Dial','<p>This Puma Motor watch features a combination of sporty influences and classic style for a look that works well on and off the field. This watch features calendar subdials and easy to read hands for quick and accurate timekeeping.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,W300,P4635,Q632,W320,B420,D400','T200,P500,M360,W320,F362,C51535,O100,S163,I51452,A530,C420,S340,F600,L200,T000,W620,W400,O500,F430,C4536,S1342,E200,R300,H532,Q000,A263,T52152,C000,M26532,M000,W300,S361,I520,L520',1,0,'puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(2,1,'Puma Women\'s Motor White Polyurethane Quartz Watch with Black Dial','<p>This Puma Motor watch features a combination of sporty influences and classic style for a look that works well on and off the field. This watch features calendar subdials and easy to read hands for quick and accurate timekeeping.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,W300,P4635,Q632,W320,B420,D400','T200,P500,M360,W320,F362,C51535,O100,S163,I51452,A530,C420,S340,F600,L200,T000,W620,W400,O500,F430,C4536,S1342,E200,R300,H532,Q000,A263,T52152,C000,M26532,M000,W300,S361,I520,L520',4,0,'puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(2,1,'Puma Women\'s Motor White Polyurethane Quartz Watch with Black Dial','<p>This Puma Motor watch features a combination of sporty influences and classic style for a look that works well on and off the field. This watch features calendar subdials and easy to read hands for quick and accurate timekeeping.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,W300,P4635,Q632,W320,B420,D400','T200,P500,M360,W320,F362,C51535,O100,S163,I51452,A530,C420,S340,F600,L200,T000,W620,W400,O500,F430,C4536,S1342,E200,R300,H532,Q000,A263,T52152,C000,M26532,M000,W300,S361,I520,L520',5,0,'puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(2,1,'Puma Women\'s Motor White Polyurethane Quartz Watch with Black Dial','<p>This Puma Motor watch features a combination of sporty influences and classic style for a look that works well on and off the field. This watch features calendar subdials and easy to read hands for quick and accurate timekeeping.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,W300,P4635,Q632,W320,B420,D400','T200,P500,M360,W320,F362,C51535,O100,S163,I51452,A530,C420,S340,F600,L200,T000,W620,W400,O500,F430,C4536,S1342,E200,R300,H532,Q000,A263,T52152,C000,M26532,M000,W300,S361,I520,L520',6,0,'puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(2,1,'Puma Women\'s Motor White Polyurethane Quartz Watch with Black Dial','<p>This Puma Motor watch features a combination of sporty influences and classic style for a look that works well on and off the field. This watch features calendar subdials and easy to read hands for quick and accurate timekeeping.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,W300,P4635,Q632,W320,B420,D400','T200,P500,M360,W320,F362,C51535,O100,S163,I51452,A530,C420,S340,F600,L200,T000,W620,W400,O500,F430,C4536,S1342,E200,R300,H532,Q000,A263,T52152,C000,M26532,M000,W300,S361,I520,L520',7,0,'puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(2,1,'Puma Women\'s Motor White Polyurethane Quartz Watch with Black Dial','<p>This Puma Motor watch features a combination of sporty influences and classic style for a look that works well on and off the field. This watch features calendar subdials and easy to read hands for quick and accurate timekeeping.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,W300,P4635,Q632,W320,B420,D400','T200,P500,M360,W320,F362,C51535,O100,S163,I51452,A530,C420,S340,F600,L200,T000,W620,W400,O500,F430,C4536,S1342,E200,R300,H532,Q000,A263,T52152,C000,M26532,M000,W300,S361,I520,L520',8,0,'puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(2,1,'Puma Women\'s Motor White Polyurethane Quartz Watch with Black Dial','<p>This Puma Motor watch features a combination of sporty influences and classic style for a look that works well on and off the field. This watch features calendar subdials and easy to read hands for quick and accurate timekeeping.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,W300,P4635,Q632,W320,B420,D400','T200,P500,M360,W320,F362,C51535,O100,S163,I51452,A530,C420,S340,F600,L200,T000,W620,W400,O500,F430,C4536,S1342,E200,R300,H532,Q000,A263,T52152,C000,M26532,M000,W300,S361,I520,L520',9,0,'puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(2,1,'Puma Women\'s Motor White Polyurethane Quartz Watch with Black Dial','<p>This Puma Motor watch features a combination of sporty influences and classic style for a look that works well on and off the field. This watch features calendar subdials and easy to read hands for quick and accurate timekeeping.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,W300,P4635,Q632,W320,B420,D400','T200,P500,M360,W320,F362,C51535,O100,S163,I51452,A530,C420,S340,F600,L200,T000,W620,W400,O500,F430,C4536,S1342,E200,R300,H532,Q000,A263,T52152,C000,M26532,M000,W300,S361,I520,L520',10,0,'puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(3,1,'Puma Women\'s Motor Pink Polyurethane Analog Quartz Watch','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,P520,P4635,A542,Q632,W320','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',1,0,'puma-women-s-motor-pink-polyurethane-analog-quartz-watch','',0,0,'','','','',1,1,'',''),(3,1,'Puma Women\'s Motor Pink Polyurethane Analog Quartz Watch','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,P520,P4635,A542,Q632,W320','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',4,0,'puma-women-s-motor-pink-polyurethane-analog-quartz-watch','',0,0,'','','','',1,1,'',''),(3,1,'Puma Women\'s Motor Pink Polyurethane Analog Quartz Watch','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,P520,P4635,A542,Q632,W320','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',5,0,'puma-women-s-motor-pink-polyurethane-analog-quartz-watch','',0,0,'','','','',1,1,'',''),(3,1,'Puma Women\'s Motor Pink Polyurethane Analog Quartz Watch','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,P520,P4635,A542,Q632,W320','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',6,0,'puma-women-s-motor-pink-polyurethane-analog-quartz-watch','',0,0,'','','','',1,1,'',''),(3,1,'Puma Women\'s Motor Pink Polyurethane Analog Quartz Watch','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,P520,P4635,A542,Q632,W320','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',7,0,'puma-women-s-motor-pink-polyurethane-analog-quartz-watch','',0,0,'','','','',1,1,'',''),(3,1,'Puma Women\'s Motor Pink Polyurethane Analog Quartz Watch','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,P520,P4635,A542,Q632,W320','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',8,0,'puma-women-s-motor-pink-polyurethane-analog-quartz-watch','',0,0,'','','','',1,1,'',''),(3,1,'Puma Women\'s Motor Pink Polyurethane Analog Quartz Watch','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,P520,P4635,A542,Q632,W320','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',9,0,'puma-women-s-motor-pink-polyurethane-analog-quartz-watch','',0,0,'','','','',1,1,'',''),(3,1,'Puma Women\'s Motor Pink Polyurethane Analog Quartz Watch','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','P500,W520,M360,P520,P4635,A542,Q632,W320','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',10,0,'puma-women-s-motor-pink-polyurethane-analog-quartz-watch','',0,0,'','','','',1,1,'',''),(4,1,'Guess Men\'s U25004L1 Silver Stainless-Steel Quartz Watch with Silver Dial','<p>Make every moment count with this splendid timepiece by Guess. An intricate design and diamond detail adds class and sophistication to this versatile watch.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 48 mm wide x 15 mm thick</li>\r\n	<li>Bracelet measurements: 24 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,U400,S416,S354234,Q632,W320,W300,D400','M200,E160,M300,C530,W300,T200,S1453,T512,B000,G000,A500,I53623,D250,A530,D530,D400,A320,C420,S123235,T000,V6234,W320,C000,M26532,M000,B6243,I520,L520',1,0,'guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','',0,0,'','','','',1,1,'',''),(4,1,'Guess Men\'s U25004L1 Silver Stainless-Steel Quartz Watch with Silver Dial','<p>Make every moment count with this splendid timepiece by Guess. An intricate design and diamond detail adds class and sophistication to this versatile watch.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 48 mm wide x 15 mm thick</li>\r\n	<li>Bracelet measurements: 24 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,U400,S416,S354234,Q632,W320,W300,D400','M200,E160,M300,C530,W300,T200,S1453,T512,B000,G000,A500,I53623,D250,A530,D530,D400,A320,C420,S123235,T000,V6234,W320,C000,M26532,M000,B6243,I520,L520',4,0,'guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','',0,0,'','','','',1,1,'',''),(4,1,'Guess Men\'s U25004L1 Silver Stainless-Steel Quartz Watch with Silver Dial','<p>Make every moment count with this splendid timepiece by Guess. An intricate design and diamond detail adds class and sophistication to this versatile watch.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 48 mm wide x 15 mm thick</li>\r\n	<li>Bracelet measurements: 24 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,U400,S416,S354234,Q632,W320,W300,D400','M200,E160,M300,C530,W300,T200,S1453,T512,B000,G000,A500,I53623,D250,A530,D530,D400,A320,C420,S123235,T000,V6234,W320,C000,M26532,M000,B6243,I520,L520',5,0,'guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','',0,0,'','','','',1,1,'',''),(4,1,'Guess Men\'s U25004L1 Silver Stainless-Steel Quartz Watch with Silver Dial','<p>Make every moment count with this splendid timepiece by Guess. An intricate design and diamond detail adds class and sophistication to this versatile watch.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 48 mm wide x 15 mm thick</li>\r\n	<li>Bracelet measurements: 24 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,U400,S416,S354234,Q632,W320,W300,D400','M200,E160,M300,C530,W300,T200,S1453,T512,B000,G000,A500,I53623,D250,A530,D530,D400,A320,C420,S123235,T000,V6234,W320,C000,M26532,M000,B6243,I520,L520',6,0,'guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','',0,0,'','','','',1,1,'',''),(4,1,'Guess Men\'s U25004L1 Silver Stainless-Steel Quartz Watch with Silver Dial','<p>Make every moment count with this splendid timepiece by Guess. An intricate design and diamond detail adds class and sophistication to this versatile watch.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 48 mm wide x 15 mm thick</li>\r\n	<li>Bracelet measurements: 24 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,U400,S416,S354234,Q632,W320,W300,D400','M200,E160,M300,C530,W300,T200,S1453,T512,B000,G000,A500,I53623,D250,A530,D530,D400,A320,C420,S123235,T000,V6234,W320,C000,M26532,M000,B6243,I520,L520',7,0,'guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','',0,0,'','','','',1,1,'',''),(4,1,'Guess Men\'s U25004L1 Silver Stainless-Steel Quartz Watch with Silver Dial','<p>Make every moment count with this splendid timepiece by Guess. An intricate design and diamond detail adds class and sophistication to this versatile watch.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 48 mm wide x 15 mm thick</li>\r\n	<li>Bracelet measurements: 24 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,U400,S416,S354234,Q632,W320,W300,D400','M200,E160,M300,C530,W300,T200,S1453,T512,B000,G000,A500,I53623,D250,A530,D530,D400,A320,C420,S123235,T000,V6234,W320,C000,M26532,M000,B6243,I520,L520',8,0,'guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','',0,0,'','','','',1,1,'',''),(4,1,'Guess Men\'s U25004L1 Silver Stainless-Steel Quartz Watch with Silver Dial','<p>Make every moment count with this splendid timepiece by Guess. An intricate design and diamond detail adds class and sophistication to this versatile watch.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 48 mm wide x 15 mm thick</li>\r\n	<li>Bracelet measurements: 24 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,U400,S416,S354234,Q632,W320,W300,D400','M200,E160,M300,C530,W300,T200,S1453,T512,B000,G000,A500,I53623,D250,A530,D530,D400,A320,C420,S123235,T000,V6234,W320,C000,M26532,M000,B6243,I520,L520',9,0,'guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','',0,0,'','','','',1,1,'',''),(4,1,'Guess Men\'s U25004L1 Silver Stainless-Steel Quartz Watch with Silver Dial','<p>Make every moment count with this splendid timepiece by Guess. An intricate design and diamond detail adds class and sophistication to this versatile watch.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 48 mm wide x 15 mm thick</li>\r\n	<li>Bracelet measurements: 24 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,U400,S416,S354234,Q632,W320,W300,D400','M200,E160,M300,C530,W300,T200,S1453,T512,B000,G000,A500,I53623,D250,A530,D530,D400,A320,C420,S123235,T000,V6234,W320,C000,M26532,M000,B6243,I520,L520',10,0,'guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','',0,0,'','','','',1,1,'',''),(5,1,'Tommy Hilfiger Men\'s Skywinder Stainless Steel and Leather Strap Watch','<p style=\"margin-left:11.25pt\">This eye-catching timepiece by Tommy Hilfiger showcases a dark stainless steel case on a textured navy blue leather strap. The deep blue dial of this men&#39;s watch includes white Arabic numeral and stick hour markers with a date display at 3 o&#39;clock.</p>\r\n','',0,'','','','','','T500,H4126,M200,S536,S3542,S340,A530,L360,S361,W320','T200,E23252,T512,B000,T500,H4126,S000,D620,S3542,S340,C000,O500,T2363,N100,B400,L360,S361,T000,D100,D400,O100,M200,W320,I52432,W300,A612,N640,A530,S320,H600,M6262,D000,D214,A300,O242',1,0,'tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch','',0,0,'','','','',1,1,'',''),(5,1,'Tommy Hilfiger Men\'s Skywinder Stainless Steel and Leather Strap Watch','<p style=\"margin-left:11.25pt\">This eye-catching timepiece by Tommy Hilfiger showcases a dark stainless steel case on a textured navy blue leather strap. The deep blue dial of this men&#39;s watch includes white Arabic numeral and stick hour markers with a date display at 3 o&#39;clock.</p>\r\n','',0,'','','','','','T500,H4126,M200,S536,S3542,S340,A530,L360,S361,W320','T200,E23252,T512,B000,T500,H4126,S000,D620,S3542,S340,C000,O500,T2363,N100,B400,L360,S361,T000,D100,D400,O100,M200,W320,I52432,W300,A612,N640,A530,S320,H600,M6262,D000,D214,A300,O242',4,0,'tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch','',0,0,'','','','',1,1,'',''),(5,1,'Tommy Hilfiger Men\'s Skywinder Stainless Steel and Leather Strap Watch','<p style=\"margin-left:11.25pt\">This eye-catching timepiece by Tommy Hilfiger showcases a dark stainless steel case on a textured navy blue leather strap. The deep blue dial of this men&#39;s watch includes white Arabic numeral and stick hour markers with a date display at 3 o&#39;clock.</p>\r\n','',0,'','','','','','T500,H4126,M200,S536,S3542,S340,A530,L360,S361,W320','T200,E23252,T512,B000,T500,H4126,S000,D620,S3542,S340,C000,O500,T2363,N100,B400,L360,S361,T000,D100,D400,O100,M200,W320,I52432,W300,A612,N640,A530,S320,H600,M6262,D000,D214,A300,O242',5,0,'tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch','',0,0,'','','','',1,1,'',''),(5,1,'Tommy Hilfiger Men\'s Skywinder Stainless Steel and Leather Strap Watch','<p style=\"margin-left:11.25pt\">This eye-catching timepiece by Tommy Hilfiger showcases a dark stainless steel case on a textured navy blue leather strap. The deep blue dial of this men&#39;s watch includes white Arabic numeral and stick hour markers with a date display at 3 o&#39;clock.</p>\r\n','',0,'','','','','','T500,H4126,M200,S536,S3542,S340,A530,L360,S361,W320','T200,E23252,T512,B000,T500,H4126,S000,D620,S3542,S340,C000,O500,T2363,N100,B400,L360,S361,T000,D100,D400,O100,M200,W320,I52432,W300,A612,N640,A530,S320,H600,M6262,D000,D214,A300,O242',6,0,'tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch','',0,0,'','','','',1,1,'',''),(5,1,'Tommy Hilfiger Men\'s Skywinder Stainless Steel and Leather Strap Watch','<p style=\"margin-left:11.25pt\">This eye-catching timepiece by Tommy Hilfiger showcases a dark stainless steel case on a textured navy blue leather strap. The deep blue dial of this men&#39;s watch includes white Arabic numeral and stick hour markers with a date display at 3 o&#39;clock.</p>\r\n','',0,'','','','','','T500,H4126,M200,S536,S3542,S340,A530,L360,S361,W320','T200,E23252,T512,B000,T500,H4126,S000,D620,S3542,S340,C000,O500,T2363,N100,B400,L360,S361,T000,D100,D400,O100,M200,W320,I52432,W300,A612,N640,A530,S320,H600,M6262,D000,D214,A300,O242',7,0,'tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch','',0,0,'','','','',1,1,'',''),(5,1,'Tommy Hilfiger Men\'s Skywinder Stainless Steel and Leather Strap Watch','<p style=\"margin-left:11.25pt\">This eye-catching timepiece by Tommy Hilfiger showcases a dark stainless steel case on a textured navy blue leather strap. The deep blue dial of this men&#39;s watch includes white Arabic numeral and stick hour markers with a date display at 3 o&#39;clock.</p>\r\n','',0,'','','','','','T500,H4126,M200,S536,S3542,S340,A530,L360,S361,W320','T200,E23252,T512,B000,T500,H4126,S000,D620,S3542,S340,C000,O500,T2363,N100,B400,L360,S361,T000,D100,D400,O100,M200,W320,I52432,W300,A612,N640,A530,S320,H600,M6262,D000,D214,A300,O242',8,0,'tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch','',0,0,'','','','',1,1,'',''),(5,1,'Tommy Hilfiger Men\'s Skywinder Stainless Steel and Leather Strap Watch','<p style=\"margin-left:11.25pt\">This eye-catching timepiece by Tommy Hilfiger showcases a dark stainless steel case on a textured navy blue leather strap. The deep blue dial of this men&#39;s watch includes white Arabic numeral and stick hour markers with a date display at 3 o&#39;clock.</p>\r\n','',0,'','','','','','T500,H4126,M200,S536,S3542,S340,A530,L360,S361,W320','T200,E23252,T512,B000,T500,H4126,S000,D620,S3542,S340,C000,O500,T2363,N100,B400,L360,S361,T000,D100,D400,O100,M200,W320,I52432,W300,A612,N640,A530,S320,H600,M6262,D000,D214,A300,O242',9,0,'tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch','',0,0,'','','','',1,1,'',''),(5,1,'Tommy Hilfiger Men\'s Skywinder Stainless Steel and Leather Strap Watch','<p style=\"margin-left:11.25pt\">This eye-catching timepiece by Tommy Hilfiger showcases a dark stainless steel case on a textured navy blue leather strap. The deep blue dial of this men&#39;s watch includes white Arabic numeral and stick hour markers with a date display at 3 o&#39;clock.</p>\r\n','',0,'','','','','','T500,H4126,M200,S536,S3542,S340,A530,L360,S361,W320','T200,E23252,T512,B000,T500,H4126,S000,D620,S3542,S340,C000,O500,T2363,N100,B400,L360,S361,T000,D100,D400,O100,M200,W320,I52432,W300,A612,N640,A530,S320,H600,M6262,D000,D214,A300,O242',10,0,'tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch','',0,0,'','','','',1,1,'',''),(6,1,'Tommy Hilfiger Men\'s 1790708 Black Silicone Sport Watch','<p style=\"margin-left:11.25pt\">Tommy Hilfiger Men&#39;s Sport Watch This classic timepiece by Tommy Hilfiger features a Stainless steel case and Silicone Strap. A Black dial, precise quartz movement and a water-resistance level of up to 50 meters finish this fine timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 44 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 7 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,S163,W320','T500,H4126,M200,S163,W320,T200,C420,T512,B000,F362,S3542,S340,C000,A530,S425,S361,B420,D400,P620,Q632,M153,W362352,L140,O100,U100,T000,M362,F520,F500,M26532,M000,I500,D536,L520,B6243,W300,I520',1,0,'tommy-hilfiger-men-s-1790708-black-silicone-sport-watch','',0,0,'','','','',1,1,'',''),(6,1,'Tommy Hilfiger Men\'s 1790708 Black Silicone Sport Watch','<p style=\"margin-left:11.25pt\">Tommy Hilfiger Men&#39;s Sport Watch This classic timepiece by Tommy Hilfiger features a Stainless steel case and Silicone Strap. A Black dial, precise quartz movement and a water-resistance level of up to 50 meters finish this fine timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 44 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 7 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,S163,W320','T500,H4126,M200,S163,W320,T200,C420,T512,B000,F362,S3542,S340,C000,A530,S425,S361,B420,D400,P620,Q632,M153,W362352,L140,O100,U100,T000,M362,F520,F500,M26532,M000,I500,D536,L520,B6243,W300,I520',4,0,'tommy-hilfiger-men-s-1790708-black-silicone-sport-watch','',0,0,'','','','',1,1,'',''),(6,1,'Tommy Hilfiger Men\'s 1790708 Black Silicone Sport Watch','<p style=\"margin-left:11.25pt\">Tommy Hilfiger Men&#39;s Sport Watch This classic timepiece by Tommy Hilfiger features a Stainless steel case and Silicone Strap. A Black dial, precise quartz movement and a water-resistance level of up to 50 meters finish this fine timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 44 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 7 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,S163,W320','T500,H4126,M200,S163,W320,T200,C420,T512,B000,F362,S3542,S340,C000,A530,S425,S361,B420,D400,P620,Q632,M153,W362352,L140,O100,U100,T000,M362,F520,F500,M26532,M000,I500,D536,L520,B6243,W300,I520',5,0,'tommy-hilfiger-men-s-1790708-black-silicone-sport-watch','',0,0,'','','','',1,1,'',''),(6,1,'Tommy Hilfiger Men\'s 1790708 Black Silicone Sport Watch','<p style=\"margin-left:11.25pt\">Tommy Hilfiger Men&#39;s Sport Watch This classic timepiece by Tommy Hilfiger features a Stainless steel case and Silicone Strap. A Black dial, precise quartz movement and a water-resistance level of up to 50 meters finish this fine timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 44 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 7 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,S163,W320','T500,H4126,M200,S163,W320,T200,C420,T512,B000,F362,S3542,S340,C000,A530,S425,S361,B420,D400,P620,Q632,M153,W362352,L140,O100,U100,T000,M362,F520,F500,M26532,M000,I500,D536,L520,B6243,W300,I520',6,0,'tommy-hilfiger-men-s-1790708-black-silicone-sport-watch','',0,0,'','','','',1,1,'',''),(6,1,'Tommy Hilfiger Men\'s 1790708 Black Silicone Sport Watch','<p style=\"margin-left:11.25pt\">Tommy Hilfiger Men&#39;s Sport Watch This classic timepiece by Tommy Hilfiger features a Stainless steel case and Silicone Strap. A Black dial, precise quartz movement and a water-resistance level of up to 50 meters finish this fine timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 44 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 7 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,S163,W320','T500,H4126,M200,S163,W320,T200,C420,T512,B000,F362,S3542,S340,C000,A530,S425,S361,B420,D400,P620,Q632,M153,W362352,L140,O100,U100,T000,M362,F520,F500,M26532,M000,I500,D536,L520,B6243,W300,I520',7,0,'tommy-hilfiger-men-s-1790708-black-silicone-sport-watch','',0,0,'','','','',1,1,'',''),(6,1,'Tommy Hilfiger Men\'s 1790708 Black Silicone Sport Watch','<p style=\"margin-left:11.25pt\">Tommy Hilfiger Men&#39;s Sport Watch This classic timepiece by Tommy Hilfiger features a Stainless steel case and Silicone Strap. A Black dial, precise quartz movement and a water-resistance level of up to 50 meters finish this fine timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 44 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 7 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,S163,W320','T500,H4126,M200,S163,W320,T200,C420,T512,B000,F362,S3542,S340,C000,A530,S425,S361,B420,D400,P620,Q632,M153,W362352,L140,O100,U100,T000,M362,F520,F500,M26532,M000,I500,D536,L520,B6243,W300,I520',8,0,'tommy-hilfiger-men-s-1790708-black-silicone-sport-watch','',0,0,'','','','',1,1,'',''),(6,1,'Tommy Hilfiger Men\'s 1790708 Black Silicone Sport Watch','<p style=\"margin-left:11.25pt\">Tommy Hilfiger Men&#39;s Sport Watch This classic timepiece by Tommy Hilfiger features a Stainless steel case and Silicone Strap. A Black dial, precise quartz movement and a water-resistance level of up to 50 meters finish this fine timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 44 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 7 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,S163,W320','T500,H4126,M200,S163,W320,T200,C420,T512,B000,F362,S3542,S340,C000,A530,S425,S361,B420,D400,P620,Q632,M153,W362352,L140,O100,U100,T000,M362,F520,F500,M26532,M000,I500,D536,L520,B6243,W300,I520',9,0,'tommy-hilfiger-men-s-1790708-black-silicone-sport-watch','',0,0,'','','','',1,1,'',''),(6,1,'Tommy Hilfiger Men\'s 1790708 Black Silicone Sport Watch','<p style=\"margin-left:11.25pt\">Tommy Hilfiger Men&#39;s Sport Watch This classic timepiece by Tommy Hilfiger features a Stainless steel case and Silicone Strap. A Black dial, precise quartz movement and a water-resistance level of up to 50 meters finish this fine timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 44 mm long x 11 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 7 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,S163,W320','T500,H4126,M200,S163,W320,T200,C420,T512,B000,F362,S3542,S340,C000,A530,S425,S361,B420,D400,P620,Q632,M153,W362352,L140,O100,U100,T000,M362,F520,F500,M26532,M000,I500,D536,L520,B6243,W300,I520',10,0,'tommy-hilfiger-men-s-1790708-black-silicone-sport-watch','',0,0,'','','','',1,1,'',''),(7,1,'Tommy Hilfiger Men\'s Black Silicone Quartz Watch','<p>Show off your laid-back personality with this casual Tommy Hilfiger timepiece with a bold orange accent. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay in style and on time.</p>\r\n\r\n<ul>\r\n	<li>Hands: Silvertone / orange luminescen</li>\r\n	<li>Calendar: Date at 6 o&#39;clock</li>\r\n	<li>Case measurements: 46 mm wide x 14 mm thick</li>\r\n	<li>Strap measurements: 25 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,Q632,W320','S000,O100,Y600,L312,P62543,W300,T200,C400,T500,H4126,T512,B430,O652,A253,E2363,M6262,A530,C516314,S361,W320,I200,T000,P6123,W000,S300,I500,S340,O500,H532,S41635,L525,C4536,D000,A300,O242,C000,M26532,M000,I520,L520',1,0,'tommy-hilfiger-men-s-black-silicone-quartz-watch','',0,0,'','','','',1,1,'',''),(7,1,'Tommy Hilfiger Men\'s Black Silicone Quartz Watch','<p>Show off your laid-back personality with this casual Tommy Hilfiger timepiece with a bold orange accent. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay in style and on time.</p>\r\n\r\n<ul>\r\n	<li>Hands: Silvertone / orange luminescen</li>\r\n	<li>Calendar: Date at 6 o&#39;clock</li>\r\n	<li>Case measurements: 46 mm wide x 14 mm thick</li>\r\n	<li>Strap measurements: 25 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,Q632,W320','S000,O100,Y600,L312,P62543,W300,T200,C400,T500,H4126,T512,B430,O652,A253,E2363,M6262,A530,C516314,S361,W320,I200,T000,P6123,W000,S300,I500,S340,O500,H532,S41635,L525,C4536,D000,A300,O242,C000,M26532,M000,I520,L520',4,0,'tommy-hilfiger-men-s-black-silicone-quartz-watch','',0,0,'','','','',1,1,'',''),(7,1,'Tommy Hilfiger Men\'s Black Silicone Quartz Watch','<p>Show off your laid-back personality with this casual Tommy Hilfiger timepiece with a bold orange accent. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay in style and on time.</p>\r\n\r\n<ul>\r\n	<li>Hands: Silvertone / orange luminescen</li>\r\n	<li>Calendar: Date at 6 o&#39;clock</li>\r\n	<li>Case measurements: 46 mm wide x 14 mm thick</li>\r\n	<li>Strap measurements: 25 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,Q632,W320','S000,O100,Y600,L312,P62543,W300,T200,C400,T500,H4126,T512,B430,O652,A253,E2363,M6262,A530,C516314,S361,W320,I200,T000,P6123,W000,S300,I500,S340,O500,H532,S41635,L525,C4536,D000,A300,O242,C000,M26532,M000,I520,L520',5,0,'tommy-hilfiger-men-s-black-silicone-quartz-watch','',0,0,'','','','',1,1,'',''),(7,1,'Tommy Hilfiger Men\'s Black Silicone Quartz Watch','<p>Show off your laid-back personality with this casual Tommy Hilfiger timepiece with a bold orange accent. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay in style and on time.</p>\r\n\r\n<ul>\r\n	<li>Hands: Silvertone / orange luminescen</li>\r\n	<li>Calendar: Date at 6 o&#39;clock</li>\r\n	<li>Case measurements: 46 mm wide x 14 mm thick</li>\r\n	<li>Strap measurements: 25 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,Q632,W320','S000,O100,Y600,L312,P62543,W300,T200,C400,T500,H4126,T512,B430,O652,A253,E2363,M6262,A530,C516314,S361,W320,I200,T000,P6123,W000,S300,I500,S340,O500,H532,S41635,L525,C4536,D000,A300,O242,C000,M26532,M000,I520,L520',6,0,'tommy-hilfiger-men-s-black-silicone-quartz-watch','',0,0,'','','','',1,1,'',''),(7,1,'Tommy Hilfiger Men\'s Black Silicone Quartz Watch','<p>Show off your laid-back personality with this casual Tommy Hilfiger timepiece with a bold orange accent. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay in style and on time.</p>\r\n\r\n<ul>\r\n	<li>Hands: Silvertone / orange luminescen</li>\r\n	<li>Calendar: Date at 6 o&#39;clock</li>\r\n	<li>Case measurements: 46 mm wide x 14 mm thick</li>\r\n	<li>Strap measurements: 25 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,Q632,W320','S000,O100,Y600,L312,P62543,W300,T200,C400,T500,H4126,T512,B430,O652,A253,E2363,M6262,A530,C516314,S361,W320,I200,T000,P6123,W000,S300,I500,S340,O500,H532,S41635,L525,C4536,D000,A300,O242,C000,M26532,M000,I520,L520',7,0,'tommy-hilfiger-men-s-black-silicone-quartz-watch','',0,0,'','','','',1,1,'',''),(7,1,'Tommy Hilfiger Men\'s Black Silicone Quartz Watch','<p>Show off your laid-back personality with this casual Tommy Hilfiger timepiece with a bold orange accent. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay in style and on time.</p>\r\n\r\n<ul>\r\n	<li>Hands: Silvertone / orange luminescen</li>\r\n	<li>Calendar: Date at 6 o&#39;clock</li>\r\n	<li>Case measurements: 46 mm wide x 14 mm thick</li>\r\n	<li>Strap measurements: 25 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,Q632,W320','S000,O100,Y600,L312,P62543,W300,T200,C400,T500,H4126,T512,B430,O652,A253,E2363,M6262,A530,C516314,S361,W320,I200,T000,P6123,W000,S300,I500,S340,O500,H532,S41635,L525,C4536,D000,A300,O242,C000,M26532,M000,I520,L520',8,0,'tommy-hilfiger-men-s-black-silicone-quartz-watch','',0,0,'','','','',1,1,'',''),(7,1,'Tommy Hilfiger Men\'s Black Silicone Quartz Watch','<p>Show off your laid-back personality with this casual Tommy Hilfiger timepiece with a bold orange accent. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay in style and on time.</p>\r\n\r\n<ul>\r\n	<li>Hands: Silvertone / orange luminescen</li>\r\n	<li>Calendar: Date at 6 o&#39;clock</li>\r\n	<li>Case measurements: 46 mm wide x 14 mm thick</li>\r\n	<li>Strap measurements: 25 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,Q632,W320','S000,O100,Y600,L312,P62543,W300,T200,C400,T500,H4126,T512,B430,O652,A253,E2363,M6262,A530,C516314,S361,W320,I200,T000,P6123,W000,S300,I500,S340,O500,H532,S41635,L525,C4536,D000,A300,O242,C000,M26532,M000,I520,L520',9,0,'tommy-hilfiger-men-s-black-silicone-quartz-watch','',0,0,'','','','',1,1,'',''),(7,1,'Tommy Hilfiger Men\'s Black Silicone Quartz Watch','<p>Show off your laid-back personality with this casual Tommy Hilfiger timepiece with a bold orange accent. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay in style and on time.</p>\r\n\r\n<ul>\r\n	<li>Hands: Silvertone / orange luminescen</li>\r\n	<li>Calendar: Date at 6 o&#39;clock</li>\r\n	<li>Case measurements: 46 mm wide x 14 mm thick</li>\r\n	<li>Strap measurements: 25 mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','T500,H4126,M200,B420,S425,Q632,W320','S000,O100,Y600,L312,P62543,W300,T200,C400,T500,H4126,T512,B430,O652,A253,E2363,M6262,A530,C516314,S361,W320,I200,T000,P6123,W000,S300,I500,S340,O500,H532,S41635,L525,C4536,D000,A300,O242,C000,M26532,M000,I520,L520',10,0,'tommy-hilfiger-men-s-black-silicone-quartz-watch','',0,0,'','','','',1,1,'',''),(8,1,'Gucci Men\'s YA126238 \'Timeless\' Grey Dial Stainless Steel Chrono','<p style=\"margin-left:11.25pt\">Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces. This timepiece features a grey dial with chronograph functions.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 10 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 6 inches wide x 6 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,T542,G600,D400,S3542,S340,C650','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,T200,F362,G600,D400,W300,C65261,F52352,C000,M26532,M000,I500,D536,B6243,I520,L520,B200',1,0,'gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono','',0,0,'','','','',1,1,'',''),(8,1,'Gucci Men\'s YA126238 \'Timeless\' Grey Dial Stainless Steel Chrono','<p style=\"margin-left:11.25pt\">Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces. This timepiece features a grey dial with chronograph functions.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 10 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 6 inches wide x 6 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,T542,G600,D400,S3542,S340,C650','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,T200,F362,G600,D400,W300,C65261,F52352,C000,M26532,M000,I500,D536,B6243,I520,L520,B200',4,0,'gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono','',0,0,'','','','',1,1,'',''),(8,1,'Gucci Men\'s YA126238 \'Timeless\' Grey Dial Stainless Steel Chrono','<p style=\"margin-left:11.25pt\">Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces. This timepiece features a grey dial with chronograph functions.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 10 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 6 inches wide x 6 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,T542,G600,D400,S3542,S340,C650','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,T200,F362,G600,D400,W300,C65261,F52352,C000,M26532,M000,I500,D536,B6243,I520,L520,B200',5,0,'gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono','',0,0,'','','','',1,1,'',''),(8,1,'Gucci Men\'s YA126238 \'Timeless\' Grey Dial Stainless Steel Chrono','<p style=\"margin-left:11.25pt\">Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces. This timepiece features a grey dial with chronograph functions.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 10 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 6 inches wide x 6 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,T542,G600,D400,S3542,S340,C650','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,T200,F362,G600,D400,W300,C65261,F52352,C000,M26532,M000,I500,D536,B6243,I520,L520,B200',6,0,'gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono','',0,0,'','','','',1,1,'',''),(8,1,'Gucci Men\'s YA126238 \'Timeless\' Grey Dial Stainless Steel Chrono','<p style=\"margin-left:11.25pt\">Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces. This timepiece features a grey dial with chronograph functions.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 10 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 6 inches wide x 6 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,T542,G600,D400,S3542,S340,C650','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,T200,F362,G600,D400,W300,C65261,F52352,C000,M26532,M000,I500,D536,B6243,I520,L520,B200',7,0,'gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono','',0,0,'','','','',1,1,'',''),(8,1,'Gucci Men\'s YA126238 \'Timeless\' Grey Dial Stainless Steel Chrono','<p style=\"margin-left:11.25pt\">Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces. This timepiece features a grey dial with chronograph functions.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 10 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 6 inches wide x 6 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,T542,G600,D400,S3542,S340,C650','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,T200,F362,G600,D400,W300,C65261,F52352,C000,M26532,M000,I500,D536,B6243,I520,L520,B200',8,0,'gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono','',0,0,'','','','',1,1,'',''),(8,1,'Gucci Men\'s YA126238 \'Timeless\' Grey Dial Stainless Steel Chrono','<p style=\"margin-left:11.25pt\">Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces. This timepiece features a grey dial with chronograph functions.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 10 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 6 inches wide x 6 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,T542,G600,D400,S3542,S340,C650','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,T200,F362,G600,D400,W300,C65261,F52352,C000,M26532,M000,I500,D536,B6243,I520,L520,B200',9,0,'gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono','',0,0,'','','','',1,1,'',''),(8,1,'Gucci Men\'s YA126238 \'Timeless\' Grey Dial Stainless Steel Chrono','<p style=\"margin-left:11.25pt\">Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces. This timepiece features a grey dial with chronograph functions.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 44 mm in diameter x 10 mm thick</li>\r\n	<li>Bracelet measurements: 22 mm wide x 8 inches long</li>\r\n	<li>Box measurements: 6 inches wide x 6 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,T542,G600,D400,S3542,S340,C650','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,T200,F362,G600,D400,W300,C65261,F52352,C000,M26532,M000,I500,D536,B6243,I520,L520,B200',10,0,'gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono','',0,0,'','','','',1,1,'',''),(9,1,'DKNY Women\'s NY8183 Gold Stainless Steel Quartz Watch with White zusä','<ul>\r\n	<li>Case measurements: 42 wide 14 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 21mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,G430,S3542,S340,Q632,W320,W300,Z000','C000,M26532,W300,M000,T200,S3616243,I520,L520',1,0,'dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white','',0,0,'','','','',1,1,'',''),(9,1,'DKNY Women\'s NY8183 Gold Stainless Steel Quartz Watch with White zusä','<ul>\r\n	<li>Case measurements: 42 wide 14 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 21mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,G430,S3542,S340,Q632,W320,W300,Z000','C000,M26532,W300,M000,T200,S3616243,I520,L520',4,0,'dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white','',0,0,'','','','',1,1,'',''),(9,1,'DKNY Women\'s NY8183 Gold Stainless Steel Quartz Watch with White zusä','<ul>\r\n	<li>Case measurements: 42 wide 14 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 21mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,G430,S3542,S340,Q632,W320,W300,Z000','C000,M26532,W300,M000,T200,S3616243,I520,L520',5,0,'dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white','',0,0,'','','','',1,1,'',''),(9,1,'DKNY Women\'s NY8183 Gold Stainless Steel Quartz Watch with White zusä','<ul>\r\n	<li>Case measurements: 42 wide 14 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 21mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,G430,S3542,S340,Q632,W320,W300,Z000','C000,M26532,W300,M000,T200,S3616243,I520,L520',6,0,'dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white','',0,0,'','','','',1,1,'',''),(9,1,'DKNY Women\'s NY8183 Gold Stainless Steel Quartz Watch with White zusä','<ul>\r\n	<li>Case measurements: 42 wide 14 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 21mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,G430,S3542,S340,Q632,W320,W300,Z000','C000,M26532,W300,M000,T200,S3616243,I520,L520',7,0,'dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white','',0,0,'','','','',1,1,'',''),(9,1,'DKNY Women\'s NY8183 Gold Stainless Steel Quartz Watch with White zusä','<ul>\r\n	<li>Case measurements: 42 wide 14 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 21mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,G430,S3542,S340,Q632,W320,W300,Z000','C000,M26532,W300,M000,T200,S3616243,I520,L520',8,0,'dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white','',0,0,'','','','',1,1,'',''),(9,1,'DKNY Women\'s NY8183 Gold Stainless Steel Quartz Watch with White zusä','<ul>\r\n	<li>Case measurements: 42 wide 14 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 21mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,G430,S3542,S340,Q632,W320,W300,Z000','C000,M26532,W300,M000,T200,S3616243,I520,L520',9,0,'dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white','',0,0,'','','','',1,1,'',''),(9,1,'DKNY Women\'s NY8183 Gold Stainless Steel Quartz Watch with White zusä','<ul>\r\n	<li>Case measurements: 42 wide 14 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 21mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','D250,W520,N000,G430,S3542,S340,Q632,W320,W300,Z000','C000,M26532,W300,M000,T200,S3616243,I520,L520',10,0,'dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white','',0,0,'','','','',1,1,'',''),(10,1,'Interlocking G Small Brown Dial Ladies Watch','<ul>\r\n	<li>Subdials: Day, date, 24-hour</li>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','I5364252,S540,B650,D400,L320,W320','S1342,D000,H600,C000,M26532,M000,W300,T200,S361,I520,L520',1,0,'interlocking-g-small-brown-dial-ladies-watch','',0,0,'','','','',1,1,'',''),(10,1,'Interlocking G Small Brown Dial Ladies Watch','<ul>\r\n	<li>Subdials: Day, date, 24-hour</li>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','I5364252,S540,B650,D400,L320,W320','S1342,D000,H600,C000,M26532,M000,W300,T200,S361,I520,L520',4,0,'interlocking-g-small-brown-dial-ladies-watch','',0,0,'','','','',1,1,'',''),(10,1,'Interlocking G Small Brown Dial Ladies Watch','<ul>\r\n	<li>Subdials: Day, date, 24-hour</li>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','I5364252,S540,B650,D400,L320,W320','S1342,D000,H600,C000,M26532,M000,W300,T200,S361,I520,L520',5,0,'interlocking-g-small-brown-dial-ladies-watch','',0,0,'','','','',1,1,'',''),(10,1,'Interlocking G Small Brown Dial Ladies Watch','<ul>\r\n	<li>Subdials: Day, date, 24-hour</li>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','I5364252,S540,B650,D400,L320,W320','S1342,D000,H600,C000,M26532,M000,W300,T200,S361,I520,L520',6,0,'interlocking-g-small-brown-dial-ladies-watch','',0,0,'','','','',1,1,'',''),(10,1,'Interlocking G Small Brown Dial Ladies Watch','<ul>\r\n	<li>Subdials: Day, date, 24-hour</li>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','I5364252,S540,B650,D400,L320,W320','S1342,D000,H600,C000,M26532,M000,W300,T200,S361,I520,L520',7,0,'interlocking-g-small-brown-dial-ladies-watch','',0,0,'','','','',1,1,'',''),(10,1,'Interlocking G Small Brown Dial Ladies Watch','<ul>\r\n	<li>Subdials: Day, date, 24-hour</li>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','I5364252,S540,B650,D400,L320,W320','S1342,D000,H600,C000,M26532,M000,W300,T200,S361,I520,L520',8,0,'interlocking-g-small-brown-dial-ladies-watch','',0,0,'','','','',1,1,'',''),(10,1,'Interlocking G Small Brown Dial Ladies Watch','<ul>\r\n	<li>Subdials: Day, date, 24-hour</li>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','I5364252,S540,B650,D400,L320,W320','S1342,D000,H600,C000,M26532,M000,W300,T200,S361,I520,L520',9,0,'interlocking-g-small-brown-dial-ladies-watch','',0,0,'','','','',1,1,'',''),(10,1,'Interlocking G Small Brown Dial Ladies Watch','<ul>\r\n	<li>Subdials: Day, date, 24-hour</li>\r\n	<li>Case measurements: 45 mm wide x 12 mm thick</li>\r\n	<li>Strap measurements: 20 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','I5364252,S540,B650,D400,L320,W320','S1342,D000,H600,C000,M26532,M000,W300,T200,S361,I520,L520',10,0,'interlocking-g-small-brown-dial-ladies-watch','',0,0,'','','','',1,1,'',''),(11,1,'Gucci Women\'s YA129444 Gucci U Play Collection Stainless Steel Watch with Striped Nylon Band','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,W520,Y000,P400,C4235,S3542,S340,W320,W300,S3613,N450,B530','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',1,0,'gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','',0,0,'','','','',1,1,'',''),(11,1,'Gucci Women\'s YA129444 Gucci U Play Collection Stainless Steel Watch with Striped Nylon Band','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,W520,Y000,P400,C4235,S3542,S340,W320,W300,S3613,N450,B530','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',4,0,'gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','',0,0,'','','','',1,1,'',''),(11,1,'Gucci Women\'s YA129444 Gucci U Play Collection Stainless Steel Watch with Striped Nylon Band','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,W520,Y000,P400,C4235,S3542,S340,W320,W300,S3613,N450,B530','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',5,0,'gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','',0,0,'','','','',1,1,'',''),(11,1,'Gucci Women\'s YA129444 Gucci U Play Collection Stainless Steel Watch with Striped Nylon Band','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,W520,Y000,P400,C4235,S3542,S340,W320,W300,S3613,N450,B530','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',6,0,'gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','',0,0,'','','','',1,1,'',''),(11,1,'Gucci Women\'s YA129444 Gucci U Play Collection Stainless Steel Watch with Striped Nylon Band','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,W520,Y000,P400,C4235,S3542,S340,W320,W300,S3613,N450,B530','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',7,0,'gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','',0,0,'','','','',1,1,'',''),(11,1,'Gucci Women\'s YA129444 Gucci U Play Collection Stainless Steel Watch with Striped Nylon Band','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,W520,Y000,P400,C4235,S3542,S340,W320,W300,S3613,N450,B530','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',8,0,'gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','',0,0,'','','','',1,1,'',''),(11,1,'Gucci Women\'s YA129444 Gucci U Play Collection Stainless Steel Watch with Striped Nylon Band','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,W520,Y000,P400,C4235,S3542,S340,W320,W300,S3613,N450,B530','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',9,0,'gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','',0,0,'','','','',1,1,'',''),(11,1,'Gucci Women\'s YA129444 Gucci U Play Collection Stainless Steel Watch with Striped Nylon Band','<p>This sporty Puma watch is constructed with a comfortable pink polyurethane strap seemlessly attached to a lightweight plastic case. Its circular dial hosts grey hands and black indices with the Puma logo prominently displayed at 4 o&#39;clock.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 42 mm wide x 8 mm thick</li>\r\n	<li>Strap measurements: 11 mm wide x 7.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','G000,W520,Y000,P400,C4235,S3542,S340,W320,W300,S3613,N450,B530','T200,S163,P500,W320,I200,C523623,W300,C516314,P520,P4635,S361,S5424,A323,T000,L2323,P4232,C000,I320,C6246,D400,H232,G600,H532,A530,B420,I532,L200,P6534,D2143,A300,O242,M26532,M000,I520,L520',10,0,'gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','',0,0,'','','','',1,1,'',''),(12,1,'Gucci Men\'s YA133202 \'Grammy XL Interlocking\' Yellow Dial Black Leather Strap','<p>Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces.</p>\r\n\r\n<ul>\r\n	<li>Case: Brushed and polished black PVD coated stainless steel</li>\r\n	<li>Bezel: Brushed and polished black PVD coated stainless steel, double G</li>\r\n	<li>Strap: Black leather, with a goldtone Grammy logo pin at the 12 o&#39;clock position and a embossed Gucci logo at the 6 o&#39;clock position</li>\r\n	<li>Special Edition GRAMMY&reg; Watch</li>\r\n	<li>Case measurements: 42 mm in diameter x 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,G650,X400,I5364252,Y400,D400,B420,L360,S361','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,C000,B623,P423,B420,P300,C300,S3542,S340,B240,D140,S361,L360,W300,G435,G650,L200,P500,O242,P235,E5123,S124,E350,G6562,W320,M26532,M000,I500,D536,T200',1,0,'gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp','',0,0,'','','','',1,1,'',''),(12,1,'Gucci Men\'s YA133202 \'Grammy XL Interlocking\' Yellow Dial Black Leather Strap','<p>Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces.</p>\r\n\r\n<ul>\r\n	<li>Case: Brushed and polished black PVD coated stainless steel</li>\r\n	<li>Bezel: Brushed and polished black PVD coated stainless steel, double G</li>\r\n	<li>Strap: Black leather, with a goldtone Grammy logo pin at the 12 o&#39;clock position and a embossed Gucci logo at the 6 o&#39;clock position</li>\r\n	<li>Special Edition GRAMMY&reg; Watch</li>\r\n	<li>Case measurements: 42 mm in diameter x 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,G650,X400,I5364252,Y400,D400,B420,L360,S361','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,C000,B623,P423,B420,P300,C300,S3542,S340,B240,D140,S361,L360,W300,G435,G650,L200,P500,O242,P235,E5123,S124,E350,G6562,W320,M26532,M000,I500,D536,T200',4,0,'gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp','',0,0,'','','','',1,1,'',''),(12,1,'Gucci Men\'s YA133202 \'Grammy XL Interlocking\' Yellow Dial Black Leather Strap','<p>Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces.</p>\r\n\r\n<ul>\r\n	<li>Case: Brushed and polished black PVD coated stainless steel</li>\r\n	<li>Bezel: Brushed and polished black PVD coated stainless steel, double G</li>\r\n	<li>Strap: Black leather, with a goldtone Grammy logo pin at the 12 o&#39;clock position and a embossed Gucci logo at the 6 o&#39;clock position</li>\r\n	<li>Special Edition GRAMMY&reg; Watch</li>\r\n	<li>Case measurements: 42 mm in diameter x 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,G650,X400,I5364252,Y400,D400,B420,L360,S361','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,C000,B623,P423,B420,P300,C300,S3542,S340,B240,D140,S361,L360,W300,G435,G650,L200,P500,O242,P235,E5123,S124,E350,G6562,W320,M26532,M000,I500,D536,T200',5,0,'gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp','',0,0,'','','','',1,1,'',''),(12,1,'Gucci Men\'s YA133202 \'Grammy XL Interlocking\' Yellow Dial Black Leather Strap','<p>Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces.</p>\r\n\r\n<ul>\r\n	<li>Case: Brushed and polished black PVD coated stainless steel</li>\r\n	<li>Bezel: Brushed and polished black PVD coated stainless steel, double G</li>\r\n	<li>Strap: Black leather, with a goldtone Grammy logo pin at the 12 o&#39;clock position and a embossed Gucci logo at the 6 o&#39;clock position</li>\r\n	<li>Special Edition GRAMMY&reg; Watch</li>\r\n	<li>Case measurements: 42 mm in diameter x 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,G650,X400,I5364252,Y400,D400,B420,L360,S361','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,C000,B623,P423,B420,P300,C300,S3542,S340,B240,D140,S361,L360,W300,G435,G650,L200,P500,O242,P235,E5123,S124,E350,G6562,W320,M26532,M000,I500,D536,T200',6,0,'gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp','',0,0,'','','','',1,1,'',''),(12,1,'Gucci Men\'s YA133202 \'Grammy XL Interlocking\' Yellow Dial Black Leather Strap','<p>Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces.</p>\r\n\r\n<ul>\r\n	<li>Case: Brushed and polished black PVD coated stainless steel</li>\r\n	<li>Bezel: Brushed and polished black PVD coated stainless steel, double G</li>\r\n	<li>Strap: Black leather, with a goldtone Grammy logo pin at the 12 o&#39;clock position and a embossed Gucci logo at the 6 o&#39;clock position</li>\r\n	<li>Special Edition GRAMMY&reg; Watch</li>\r\n	<li>Case measurements: 42 mm in diameter x 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,G650,X400,I5364252,Y400,D400,B420,L360,S361','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,C000,B623,P423,B420,P300,C300,S3542,S340,B240,D140,S361,L360,W300,G435,G650,L200,P500,O242,P235,E5123,S124,E350,G6562,W320,M26532,M000,I500,D536,T200',7,0,'gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp','',0,0,'','','','',1,1,'',''),(12,1,'Gucci Men\'s YA133202 \'Grammy XL Interlocking\' Yellow Dial Black Leather Strap','<p>Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces.</p>\r\n\r\n<ul>\r\n	<li>Case: Brushed and polished black PVD coated stainless steel</li>\r\n	<li>Bezel: Brushed and polished black PVD coated stainless steel, double G</li>\r\n	<li>Strap: Black leather, with a goldtone Grammy logo pin at the 12 o&#39;clock position and a embossed Gucci logo at the 6 o&#39;clock position</li>\r\n	<li>Special Edition GRAMMY&reg; Watch</li>\r\n	<li>Case measurements: 42 mm in diameter x 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,G650,X400,I5364252,Y400,D400,B420,L360,S361','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,C000,B623,P423,B420,P300,C300,S3542,S340,B240,D140,S361,L360,W300,G435,G650,L200,P500,O242,P235,E5123,S124,E350,G6562,W320,M26532,M000,I500,D536,T200',8,0,'gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp','',0,0,'','','','',1,1,'',''),(12,1,'Gucci Men\'s YA133202 \'Grammy XL Interlocking\' Yellow Dial Black Leather Strap','<p>Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces.</p>\r\n\r\n<ul>\r\n	<li>Case: Brushed and polished black PVD coated stainless steel</li>\r\n	<li>Bezel: Brushed and polished black PVD coated stainless steel, double G</li>\r\n	<li>Strap: Black leather, with a goldtone Grammy logo pin at the 12 o&#39;clock position and a embossed Gucci logo at the 6 o&#39;clock position</li>\r\n	<li>Special Edition GRAMMY&reg; Watch</li>\r\n	<li>Case measurements: 42 mm in diameter x 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,G650,X400,I5364252,Y400,D400,B420,L360,S361','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,C000,B623,P423,B420,P300,C300,S3542,S340,B240,D140,S361,L360,W300,G435,G650,L200,P500,O242,P235,E5123,S124,E350,G6562,W320,M26532,M000,I500,D536,T200',9,0,'gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp','',0,0,'','','','',1,1,'',''),(12,1,'Gucci Men\'s YA133202 \'Grammy XL Interlocking\' Yellow Dial Black Leather Strap','<p>Since 1921, the house of Gucci has been at the forefront of fashion, manufacturing handbags, shoes, sneakers, sunglasses, wallets, belts, scarves, jewelry, and fashionable timepieces.</p>\r\n\r\n<ul>\r\n	<li>Case: Brushed and polished black PVD coated stainless steel</li>\r\n	<li>Bezel: Brushed and polished black PVD coated stainless steel, double G</li>\r\n	<li>Strap: Black leather, with a goldtone Grammy logo pin at the 12 o&#39;clock position and a embossed Gucci logo at the 6 o&#39;clock position</li>\r\n	<li>Special Edition GRAMMY&reg; Watch</li>\r\n	<li>Case measurements: 42 mm in diameter x 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','G000,M200,Y000,G650,X400,I5364252,Y400,D400,B420,L360,S361','S520,T000,H200,O100,G000,B500,A300,F61653,F250,M123652,H5312,S000,S5262,S5242,W432,B432,S612,J460,A530,F2514,T512,C000,B623,P423,B420,P300,C300,S3542,S340,B240,D140,S361,L360,W300,G435,G650,L200,P500,O242,P235,E5123,S124,E350,G6562,W320,M26532,M000,I500,D536,T200',10,0,'gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp','',0,0,'','','','',1,1,'',''),(13,1,'Casio G-SHOCK G100-1BV Wrist Watch PRICE- 1200','<p>Profile: Men<br />\r\nWatch Design: Round Face Chronograph<br />\r\nWatch Format: Anadigi<br />\r\nFace: 1 Digital Black Subdial<br />\r\nFace: 1 Analog Black Black Main Dial with EL Backlight<br />\r\nWatch Casing: Resin Black<br />\r\nWrist Band: Resin Black Strap with Buckle<br />\r\nFeatures: 12/24hr Format<br />\r\nFeatures: Stopwatch (1/100 Second)<br />\r\nFeatures: Calendar (Auto (pre-programmed until the year 2039))<br />\r\nWater Resistance: 656 ft<br />\r\nDurability: Water Resistant<br />\r\nDurability: Anti-magnetic<br />\r\nDurability: Shock Resistant</p>\r\n','',0,'','','','','','C000,G000,G100,W623,W320,P620','P614,M000,W320,D250,R530,F200,C65261,F653,A532,D234,B420,S134,A542,D400,W300,E400,B2423,C520,R250,W623,B530,S361,B240,F362,H600,S3132,S530,C4536,A300,P6162653,U534,T000,Y600,W360,R2352,F300,D6143,R2353,A5352532,S000',1,0,'casio-men-s-g100-1bv-g-shock-watch-in-black-resin','',0,0,'','','','',1,1,'',''),(13,1,'Casio G-SHOCK G100-1BV Wrist Watch PRICE- 1200','<p>Profile: Men<br />\r\nWatch Design: Round Face Chronograph<br />\r\nWatch Format: Anadigi<br />\r\nFace: 1 Digital Black Subdial<br />\r\nFace: 1 Analog Black Black Main Dial with EL Backlight<br />\r\nWatch Casing: Resin Black<br />\r\nWrist Band: Resin Black Strap with Buckle<br />\r\nFeatures: 12/24hr Format<br />\r\nFeatures: Stopwatch (1/100 Second)<br />\r\nFeatures: Calendar (Auto (pre-programmed until the year 2039))<br />\r\nWater Resistance: 656 ft<br />\r\nDurability: Water Resistant<br />\r\nDurability: Anti-magnetic<br />\r\nDurability: Shock Resistant</p>\r\n','',0,'','','','','','C000,G000,G100,W623,W320,P620','P614,M000,W320,D250,R530,F200,C65261,F653,A532,D234,B420,S134,A542,D400,W300,E400,B2423,C520,R250,W623,B530,S361,B240,F362,H600,S3132,S530,C4536,A300,P6162653,U534,T000,Y600,W360,R2352,F300,D6143,R2353,A5352532,S000',4,0,'casio-men-s-g100-1bv-g-shock-watch-in-black-resin','',0,0,'','','','',1,1,'',''),(13,1,'Casio G-SHOCK G100-1BV Wrist Watch PRICE- 1200','<p>Profile: Men<br />\r\nWatch Design: Round Face Chronograph<br />\r\nWatch Format: Anadigi<br />\r\nFace: 1 Digital Black Subdial<br />\r\nFace: 1 Analog Black Black Main Dial with EL Backlight<br />\r\nWatch Casing: Resin Black<br />\r\nWrist Band: Resin Black Strap with Buckle<br />\r\nFeatures: 12/24hr Format<br />\r\nFeatures: Stopwatch (1/100 Second)<br />\r\nFeatures: Calendar (Auto (pre-programmed until the year 2039))<br />\r\nWater Resistance: 656 ft<br />\r\nDurability: Water Resistant<br />\r\nDurability: Anti-magnetic<br />\r\nDurability: Shock Resistant</p>\r\n','',0,'','','','','','C000,G000,G100,W623,W320,P620','P614,M000,W320,D250,R530,F200,C65261,F653,A532,D234,B420,S134,A542,D400,W300,E400,B2423,C520,R250,W623,B530,S361,B240,F362,H600,S3132,S530,C4536,A300,P6162653,U534,T000,Y600,W360,R2352,F300,D6143,R2353,A5352532,S000',5,0,'casio-men-s-g100-1bv-g-shock-watch-in-black-resin','',0,0,'','','','',1,1,'',''),(13,1,'Casio G-SHOCK G100-1BV Wrist Watch PRICE- 1200','<p>Profile: Men<br />\r\nWatch Design: Round Face Chronograph<br />\r\nWatch Format: Anadigi<br />\r\nFace: 1 Digital Black Subdial<br />\r\nFace: 1 Analog Black Black Main Dial with EL Backlight<br />\r\nWatch Casing: Resin Black<br />\r\nWrist Band: Resin Black Strap with Buckle<br />\r\nFeatures: 12/24hr Format<br />\r\nFeatures: Stopwatch (1/100 Second)<br />\r\nFeatures: Calendar (Auto (pre-programmed until the year 2039))<br />\r\nWater Resistance: 656 ft<br />\r\nDurability: Water Resistant<br />\r\nDurability: Anti-magnetic<br />\r\nDurability: Shock Resistant</p>\r\n','',0,'','','','','','C000,G000,G100,W623,W320,P620','P614,M000,W320,D250,R530,F200,C65261,F653,A532,D234,B420,S134,A542,D400,W300,E400,B2423,C520,R250,W623,B530,S361,B240,F362,H600,S3132,S530,C4536,A300,P6162653,U534,T000,Y600,W360,R2352,F300,D6143,R2353,A5352532,S000',6,0,'casio-men-s-g100-1bv-g-shock-watch-in-black-resin','',0,0,'','','','',1,1,'',''),(13,1,'Casio G-SHOCK G100-1BV Wrist Watch PRICE- 1200','<p>Profile: Men<br />\r\nWatch Design: Round Face Chronograph<br />\r\nWatch Format: Anadigi<br />\r\nFace: 1 Digital Black Subdial<br />\r\nFace: 1 Analog Black Black Main Dial with EL Backlight<br />\r\nWatch Casing: Resin Black<br />\r\nWrist Band: Resin Black Strap with Buckle<br />\r\nFeatures: 12/24hr Format<br />\r\nFeatures: Stopwatch (1/100 Second)<br />\r\nFeatures: Calendar (Auto (pre-programmed until the year 2039))<br />\r\nWater Resistance: 656 ft<br />\r\nDurability: Water Resistant<br />\r\nDurability: Anti-magnetic<br />\r\nDurability: Shock Resistant</p>\r\n','',0,'','','','','','C000,G000,G100,W623,W320,P620','P614,M000,W320,D250,R530,F200,C65261,F653,A532,D234,B420,S134,A542,D400,W300,E400,B2423,C520,R250,W623,B530,S361,B240,F362,H600,S3132,S530,C4536,A300,P6162653,U534,T000,Y600,W360,R2352,F300,D6143,R2353,A5352532,S000',7,0,'casio-men-s-g100-1bv-g-shock-watch-in-black-resin','',0,0,'','','','',1,1,'',''),(13,1,'Casio G-SHOCK G100-1BV Wrist Watch PRICE- 1200','<p>Profile: Men<br />\r\nWatch Design: Round Face Chronograph<br />\r\nWatch Format: Anadigi<br />\r\nFace: 1 Digital Black Subdial<br />\r\nFace: 1 Analog Black Black Main Dial with EL Backlight<br />\r\nWatch Casing: Resin Black<br />\r\nWrist Band: Resin Black Strap with Buckle<br />\r\nFeatures: 12/24hr Format<br />\r\nFeatures: Stopwatch (1/100 Second)<br />\r\nFeatures: Calendar (Auto (pre-programmed until the year 2039))<br />\r\nWater Resistance: 656 ft<br />\r\nDurability: Water Resistant<br />\r\nDurability: Anti-magnetic<br />\r\nDurability: Shock Resistant</p>\r\n','',0,'','','','','','C000,G000,G100,W623,W320,P620','P614,M000,W320,D250,R530,F200,C65261,F653,A532,D234,B420,S134,A542,D400,W300,E400,B2423,C520,R250,W623,B530,S361,B240,F362,H600,S3132,S530,C4536,A300,P6162653,U534,T000,Y600,W360,R2352,F300,D6143,R2353,A5352532,S000',8,0,'casio-men-s-g100-1bv-g-shock-watch-in-black-resin','',0,0,'','','','',1,1,'',''),(13,1,'Casio G-SHOCK G100-1BV Wrist Watch PRICE- 1200','<p>Profile: Men<br />\r\nWatch Design: Round Face Chronograph<br />\r\nWatch Format: Anadigi<br />\r\nFace: 1 Digital Black Subdial<br />\r\nFace: 1 Analog Black Black Main Dial with EL Backlight<br />\r\nWatch Casing: Resin Black<br />\r\nWrist Band: Resin Black Strap with Buckle<br />\r\nFeatures: 12/24hr Format<br />\r\nFeatures: Stopwatch (1/100 Second)<br />\r\nFeatures: Calendar (Auto (pre-programmed until the year 2039))<br />\r\nWater Resistance: 656 ft<br />\r\nDurability: Water Resistant<br />\r\nDurability: Anti-magnetic<br />\r\nDurability: Shock Resistant</p>\r\n','',0,'','','','','','C000,G000,G100,W623,W320,P620','P614,M000,W320,D250,R530,F200,C65261,F653,A532,D234,B420,S134,A542,D400,W300,E400,B2423,C520,R250,W623,B530,S361,B240,F362,H600,S3132,S530,C4536,A300,P6162653,U534,T000,Y600,W360,R2352,F300,D6143,R2353,A5352532,S000',9,0,'casio-men-s-g100-1bv-g-shock-watch-in-black-resin','',0,0,'','','','',1,1,'',''),(13,1,'Casio G-SHOCK G100-1BV Wrist Watch PRICE- 1200','<p>Profile: Men<br />\r\nWatch Design: Round Face Chronograph<br />\r\nWatch Format: Anadigi<br />\r\nFace: 1 Digital Black Subdial<br />\r\nFace: 1 Analog Black Black Main Dial with EL Backlight<br />\r\nWatch Casing: Resin Black<br />\r\nWrist Band: Resin Black Strap with Buckle<br />\r\nFeatures: 12/24hr Format<br />\r\nFeatures: Stopwatch (1/100 Second)<br />\r\nFeatures: Calendar (Auto (pre-programmed until the year 2039))<br />\r\nWater Resistance: 656 ft<br />\r\nDurability: Water Resistant<br />\r\nDurability: Anti-magnetic<br />\r\nDurability: Shock Resistant</p>\r\n','',0,'','','','','','C000,G000,G100,W623,W320,P620','P614,M000,W320,D250,R530,F200,C65261,F653,A532,D234,B420,S134,A542,D400,W300,E400,B2423,C520,R250,W623,B530,S361,B240,F362,H600,S3132,S530,C4536,A300,P6162653,U534,T000,Y600,W360,R2352,F300,D6143,R2353,A5352532,S000',10,0,'casio-men-s-g100-1bv-g-shock-watch-in-black-resin','',0,0,'','','','',1,1,'',''),(14,1,'Casio Baby-G BG169G-7B Face Protector Ion-Plated Metal White Rose Gold Watch Digital1','<p>This Baby-G BLX from the Tide Graph series allows for maximum fun and function in the water. It features an attractive white finish with white accents as well as a stopwatch, 200M Water Resistance, and a Tide Graph (tide level for specific date and time).</p>\r\n\r\n<ul>\r\n	<li>Subdials: One Tide Graph</li>\r\n	<li>Calendar: Day, date and year display</li>\r\n	<li>Additional Features: Shock Resistant, Tide Graph, World Time (29 time zones), 2 Alarms, 1/100 second stopwatch, Full Auto-Calendar, 12/24 Hour Formats</li>\r\n	<li>One more thing: It can do world better</li>\r\n</ul>\r\n','',0,'','','','old model, old model 1, BG169G-7B','','C000,B200,B210,F200,P63236,I5143,M340,W300,R200,G430,W320,D234','T200,B200,B420,F650,T000,G610,S620,A420,F600,M250,F500,A530,F5235,I500,W360,I300,F362,A500,A36231,W300,F520,A2532,A200,W400,S3132,M000,R2352,L140,S1212,D000,T500,S1342,O500,C4536,Y600,D214,A354,S000,R2353,W643,Z520,A4652,S530,F400,A324536,H600,F6532,M600,T520,C500,B360',1,0,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital','',0,0,'','','','',1,1,'',''),(14,1,'Casio Baby-G BG169G-7B Face Protector Ion-Plated Metal White Rose Gold Watch Digital1','<p>This Baby-G BLX from the Tide Graph series allows for maximum fun and function in the water. It features an attractive white finish with white accents as well as a stopwatch, 200M Water Resistance, and a Tide Graph (tide level for specific date and time).</p>\r\n\r\n<ul>\r\n	<li>Subdials: One Tide Graph</li>\r\n	<li>Calendar: Day, date and year display</li>\r\n	<li>Additional Features: Shock Resistant, Tide Graph, World Time (29 time zones), 2 Alarms, 1/100 second stopwatch, Full Auto-Calendar, 12/24 Hour Formats</li>\r\n	<li>One more thing: It can do world better</li>\r\n</ul>\r\n','',0,'','','','old model, old model 1, BG169G-7B','','C000,B200,B210,F200,P63236,I5143,M340,W300,R200,G430,W320,D234','T200,B200,B420,F650,T000,G610,S620,A420,F600,M250,F500,A530,F5235,I500,W360,I300,F362,A500,A36231,W300,F520,A2532,A200,W400,S3132,M000,R2352,L140,S1212,D000,T500,S1342,O500,C4536,Y600,D214,A354,S000,R2353,W643,Z520,A4652,S530,F400,A324536,H600,F6532,M600,T520,C500,B360',4,0,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital','',0,0,'','','','',1,1,'',''),(14,1,'Casio Baby-G BG169G-7B Face Protector Ion-Plated Metal White Rose Gold Watch Digital1','<p>This Baby-G BLX from the Tide Graph series allows for maximum fun and function in the water. It features an attractive white finish with white accents as well as a stopwatch, 200M Water Resistance, and a Tide Graph (tide level for specific date and time).</p>\r\n\r\n<ul>\r\n	<li>Subdials: One Tide Graph</li>\r\n	<li>Calendar: Day, date and year display</li>\r\n	<li>Additional Features: Shock Resistant, Tide Graph, World Time (29 time zones), 2 Alarms, 1/100 second stopwatch, Full Auto-Calendar, 12/24 Hour Formats</li>\r\n	<li>One more thing: It can do world better</li>\r\n</ul>\r\n','',0,'','','','old model, old model 1, BG169G-7B','','C000,B200,B210,F200,P63236,I5143,M340,W300,R200,G430,W320,D234','T200,B200,B420,F650,T000,G610,S620,A420,F600,M250,F500,A530,F5235,I500,W360,I300,F362,A500,A36231,W300,F520,A2532,A200,W400,S3132,M000,R2352,L140,S1212,D000,T500,S1342,O500,C4536,Y600,D214,A354,S000,R2353,W643,Z520,A4652,S530,F400,A324536,H600,F6532,M600,T520,C500,B360',5,0,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital','',0,0,'','','','',1,1,'',''),(14,1,'Casio Baby-G BG169G-7B Face Protector Ion-Plated Metal White Rose Gold Watch Digital1','<p>This Baby-G BLX from the Tide Graph series allows for maximum fun and function in the water. It features an attractive white finish with white accents as well as a stopwatch, 200M Water Resistance, and a Tide Graph (tide level for specific date and time).</p>\r\n\r\n<ul>\r\n	<li>Subdials: One Tide Graph</li>\r\n	<li>Calendar: Day, date and year display</li>\r\n	<li>Additional Features: Shock Resistant, Tide Graph, World Time (29 time zones), 2 Alarms, 1/100 second stopwatch, Full Auto-Calendar, 12/24 Hour Formats</li>\r\n	<li>One more thing: It can do world better</li>\r\n</ul>\r\n','',0,'','','','old model, old model 1, BG169G-7B','','C000,B200,B210,F200,P63236,I5143,M340,W300,R200,G430,W320,D234','T200,B200,B420,F650,T000,G610,S620,A420,F600,M250,F500,A530,F5235,I500,W360,I300,F362,A500,A36231,W300,F520,A2532,A200,W400,S3132,M000,R2352,L140,S1212,D000,T500,S1342,O500,C4536,Y600,D214,A354,S000,R2353,W643,Z520,A4652,S530,F400,A324536,H600,F6532,M600,T520,C500,B360',6,0,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital','',0,0,'','','','',1,1,'',''),(14,1,'Casio Baby-G BG169G-7B Face Protector Ion-Plated Metal White Rose Gold Watch Digital1','<p>This Baby-G BLX from the Tide Graph series allows for maximum fun and function in the water. It features an attractive white finish with white accents as well as a stopwatch, 200M Water Resistance, and a Tide Graph (tide level for specific date and time).</p>\r\n\r\n<ul>\r\n	<li>Subdials: One Tide Graph</li>\r\n	<li>Calendar: Day, date and year display</li>\r\n	<li>Additional Features: Shock Resistant, Tide Graph, World Time (29 time zones), 2 Alarms, 1/100 second stopwatch, Full Auto-Calendar, 12/24 Hour Formats</li>\r\n	<li>One more thing: It can do world better</li>\r\n</ul>\r\n','',0,'','','','old model, old model 1, BG169G-7B','','C000,B200,B210,F200,P63236,I5143,M340,W300,R200,G430,W320,D234','T200,B200,B420,F650,T000,G610,S620,A420,F600,M250,F500,A530,F5235,I500,W360,I300,F362,A500,A36231,W300,F520,A2532,A200,W400,S3132,M000,R2352,L140,S1212,D000,T500,S1342,O500,C4536,Y600,D214,A354,S000,R2353,W643,Z520,A4652,S530,F400,A324536,H600,F6532,M600,T520,C500,B360',7,0,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital','',0,0,'','','','',1,1,'',''),(14,1,'Casio Baby-G BG169G-7B Face Protector Ion-Plated Metal White Rose Gold Watch Digital1','<p>This Baby-G BLX from the Tide Graph series allows for maximum fun and function in the water. It features an attractive white finish with white accents as well as a stopwatch, 200M Water Resistance, and a Tide Graph (tide level for specific date and time).</p>\r\n\r\n<ul>\r\n	<li>Subdials: One Tide Graph</li>\r\n	<li>Calendar: Day, date and year display</li>\r\n	<li>Additional Features: Shock Resistant, Tide Graph, World Time (29 time zones), 2 Alarms, 1/100 second stopwatch, Full Auto-Calendar, 12/24 Hour Formats</li>\r\n	<li>One more thing: It can do world better</li>\r\n</ul>\r\n','',0,'','','','old model, old model 1, BG169G-7B','','C000,B200,B210,F200,P63236,I5143,M340,W300,R200,G430,W320,D234','T200,B200,B420,F650,T000,G610,S620,A420,F600,M250,F500,A530,F5235,I500,W360,I300,F362,A500,A36231,W300,F520,A2532,A200,W400,S3132,M000,R2352,L140,S1212,D000,T500,S1342,O500,C4536,Y600,D214,A354,S000,R2353,W643,Z520,A4652,S530,F400,A324536,H600,F6532,M600,T520,C500,B360',8,0,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital','',0,0,'','','','',1,1,'',''),(14,1,'Casio Baby-G BG169G-7B Face Protector Ion-Plated Metal White Rose Gold Watch Digital1','<p>This Baby-G BLX from the Tide Graph series allows for maximum fun and function in the water. It features an attractive white finish with white accents as well as a stopwatch, 200M Water Resistance, and a Tide Graph (tide level for specific date and time).</p>\r\n\r\n<ul>\r\n	<li>Subdials: One Tide Graph</li>\r\n	<li>Calendar: Day, date and year display</li>\r\n	<li>Additional Features: Shock Resistant, Tide Graph, World Time (29 time zones), 2 Alarms, 1/100 second stopwatch, Full Auto-Calendar, 12/24 Hour Formats</li>\r\n	<li>One more thing: It can do world better</li>\r\n</ul>\r\n','',0,'','','','old model, old model 1, BG169G-7B','','C000,B200,B210,F200,P63236,I5143,M340,W300,R200,G430,W320,D234','T200,B200,B420,F650,T000,G610,S620,A420,F600,M250,F500,A530,F5235,I500,W360,I300,F362,A500,A36231,W300,F520,A2532,A200,W400,S3132,M000,R2352,L140,S1212,D000,T500,S1342,O500,C4536,Y600,D214,A354,S000,R2353,W643,Z520,A4652,S530,F400,A324536,H600,F6532,M600,T520,C500,B360',9,0,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital','',0,0,'','','','',1,1,'',''),(14,1,'Casio Baby-G BG169G-7B Face Protector Ion-Plated Metal White Rose Gold Watch Digital1','<p>This Baby-G BLX from the Tide Graph series allows for maximum fun and function in the water. It features an attractive white finish with white accents as well as a stopwatch, 200M Water Resistance, and a Tide Graph (tide level for specific date and time).</p>\r\n\r\n<ul>\r\n	<li>Subdials: One Tide Graph</li>\r\n	<li>Calendar: Day, date and year display</li>\r\n	<li>Additional Features: Shock Resistant, Tide Graph, World Time (29 time zones), 2 Alarms, 1/100 second stopwatch, Full Auto-Calendar, 12/24 Hour Formats</li>\r\n	<li>One more thing: It can do world better</li>\r\n</ul>\r\n','',0,'','','','old model, old model 1, BG169G-7B','','C000,B200,B210,F200,P63236,I5143,M340,W300,R200,G430,W320,D234','T200,B200,B420,F650,T000,G610,S620,A420,F600,M250,F500,A530,F5235,I500,W360,I300,F362,A500,A36231,W300,F520,A2532,A200,W400,S3132,M000,R2352,L140,S1212,D000,T500,S1342,O500,C4536,Y600,D214,A354,S000,R2353,W643,Z520,A4652,S530,F400,A324536,H600,F6532,M600,T520,C500,B360',10,0,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital','',0,0,'','','','',1,1,'',''),(15,1,'Casio Men\'s Core MTP1192E-7A Brown Leather Quartz Watch with White Dial','<ul>\r\n	<li>Calendar: Day and Date</li>\r\n	<li>Case measurements: 36 wide 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,C600,M310,B650,L360,Q632,W320,W300,D400','C4536,D000,A530,C000,M26532,W300,M000,T200',1,0,'casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','',0,0,'','','','',1,1,'',''),(15,1,'Casio Men\'s Core MTP1192E-7A Brown Leather Quartz Watch with White Dial','<ul>\r\n	<li>Calendar: Day and Date</li>\r\n	<li>Case measurements: 36 wide 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,C600,M310,B650,L360,Q632,W320,W300,D400','C4536,D000,A530,C000,M26532,W300,M000,T200',4,0,'casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','',0,0,'','','','',1,1,'',''),(15,1,'Casio Men\'s Core MTP1192E-7A Brown Leather Quartz Watch with White Dial','<ul>\r\n	<li>Calendar: Day and Date</li>\r\n	<li>Case measurements: 36 wide 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,C600,M310,B650,L360,Q632,W320,W300,D400','C4536,D000,A530,C000,M26532,W300,M000,T200',5,0,'casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','',0,0,'','','','',1,1,'',''),(15,1,'Casio Men\'s Core MTP1192E-7A Brown Leather Quartz Watch with White Dial','<ul>\r\n	<li>Calendar: Day and Date</li>\r\n	<li>Case measurements: 36 wide 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,C600,M310,B650,L360,Q632,W320,W300,D400','C4536,D000,A530,C000,M26532,W300,M000,T200',6,0,'casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','',0,0,'','','','',1,1,'',''),(15,1,'Casio Men\'s Core MTP1192E-7A Brown Leather Quartz Watch with White Dial','<ul>\r\n	<li>Calendar: Day and Date</li>\r\n	<li>Case measurements: 36 wide 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,C600,M310,B650,L360,Q632,W320,W300,D400','C4536,D000,A530,C000,M26532,W300,M000,T200',7,0,'casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','',0,0,'','','','',1,1,'',''),(15,1,'Casio Men\'s Core MTP1192E-7A Brown Leather Quartz Watch with White Dial','<ul>\r\n	<li>Calendar: Day and Date</li>\r\n	<li>Case measurements: 36 wide 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,C600,M310,B650,L360,Q632,W320,W300,D400','C4536,D000,A530,C000,M26532,W300,M000,T200',8,0,'casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','',0,0,'','','','',1,1,'',''),(15,1,'Casio Men\'s Core MTP1192E-7A Brown Leather Quartz Watch with White Dial','<ul>\r\n	<li>Calendar: Day and Date</li>\r\n	<li>Case measurements: 36 wide 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,C600,M310,B650,L360,Q632,W320,W300,D400','C4536,D000,A530,C000,M26532,W300,M000,T200',9,0,'casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','',0,0,'','','','',1,1,'',''),(15,1,'Casio Men\'s Core MTP1192E-7A Brown Leather Quartz Watch with White Dial','<ul>\r\n	<li>Calendar: Day and Date</li>\r\n	<li>Case measurements: 36 wide 9 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,C600,M310,B650,L360,Q632,W320,W300,D400','C4536,D000,A530,C000,M26532,W300,M000,T200',10,0,'casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','',0,0,'','','','',1,1,'',''),(16,1,'Casio General Men\'s Watches Edifice Digital-Analog Combination','<p>Upgrade to style and sophistication with this elegant Casio watch.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Date and Month</li>\r\n	<li>Case measurements: 45 wide 13 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,G564,M200,W320,E312,D234542,C51535','U1263,T000,S340,A530,S123235,W300,T200,E4253,C000,W320,C4536,D000,M300,M26532,M000',1,0,'casio-general-men-s-watches-edifice-digital-analog-combination','',0,0,'','','','',1,1,'',''),(16,1,'Casio General Men\'s Watches Edifice Digital-Analog Combination','<p>Upgrade to style and sophistication with this elegant Casio watch.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Date and Month</li>\r\n	<li>Case measurements: 45 wide 13 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,G564,M200,W320,E312,D234542,C51535','U1263,T000,S340,A530,S123235,W300,T200,E4253,C000,W320,C4536,D000,M300,M26532,M000',4,0,'casio-general-men-s-watches-edifice-digital-analog-combination','',0,0,'','','','',1,1,'',''),(16,1,'Casio General Men\'s Watches Edifice Digital-Analog Combination','<p>Upgrade to style and sophistication with this elegant Casio watch.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Date and Month</li>\r\n	<li>Case measurements: 45 wide 13 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,G564,M200,W320,E312,D234542,C51535','U1263,T000,S340,A530,S123235,W300,T200,E4253,C000,W320,C4536,D000,M300,M26532,M000',5,0,'casio-general-men-s-watches-edifice-digital-analog-combination','',0,0,'','','','',1,1,'',''),(16,1,'Casio General Men\'s Watches Edifice Digital-Analog Combination','<p>Upgrade to style and sophistication with this elegant Casio watch.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Date and Month</li>\r\n	<li>Case measurements: 45 wide 13 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,G564,M200,W320,E312,D234542,C51535','U1263,T000,S340,A530,S123235,W300,T200,E4253,C000,W320,C4536,D000,M300,M26532,M000',6,0,'casio-general-men-s-watches-edifice-digital-analog-combination','',0,0,'','','','',1,1,'',''),(16,1,'Casio General Men\'s Watches Edifice Digital-Analog Combination','<p>Upgrade to style and sophistication with this elegant Casio watch.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Date and Month</li>\r\n	<li>Case measurements: 45 wide 13 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,G564,M200,W320,E312,D234542,C51535','U1263,T000,S340,A530,S123235,W300,T200,E4253,C000,W320,C4536,D000,M300,M26532,M000',7,0,'casio-general-men-s-watches-edifice-digital-analog-combination','',0,0,'','','','',1,1,'',''),(16,1,'Casio General Men\'s Watches Edifice Digital-Analog Combination','<p>Upgrade to style and sophistication with this elegant Casio watch.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Date and Month</li>\r\n	<li>Case measurements: 45 wide 13 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,G564,M200,W320,E312,D234542,C51535','U1263,T000,S340,A530,S123235,W300,T200,E4253,C000,W320,C4536,D000,M300,M26532,M000',8,0,'casio-general-men-s-watches-edifice-digital-analog-combination','',0,0,'','','','',1,1,'',''),(16,1,'Casio General Men\'s Watches Edifice Digital-Analog Combination','<p>Upgrade to style and sophistication with this elegant Casio watch.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Date and Month</li>\r\n	<li>Case measurements: 45 wide 13 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,G564,M200,W320,E312,D234542,C51535','U1263,T000,S340,A530,S123235,W300,T200,E4253,C000,W320,C4536,D000,M300,M26532,M000',9,0,'casio-general-men-s-watches-edifice-digital-analog-combination','',0,0,'','','','',1,1,'',''),(16,1,'Casio General Men\'s Watches Edifice Digital-Analog Combination','<p>Upgrade to style and sophistication with this elegant Casio watch.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Date and Month</li>\r\n	<li>Case measurements: 45 wide 13 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,G564,M200,W320,E312,D234542,C51535','U1263,T000,S340,A530,S123235,W300,T200,E4253,C000,W320,C4536,D000,M300,M26532,M000',10,0,'casio-general-men-s-watches-edifice-digital-analog-combination','',0,0,'','','','',1,1,'',''),(17,1,'Casio Men\'s W753-2AV Blue Resin Quartz Watch with Digital Dial','<p>Perfect for the person that cant get enough technology, this watch will keep you looking great, while keeping you punctual, provided you dont lose track of time fiddling with this watchs nifty chronograph.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Day Date and Month</li>\r\n	<li>Case measurements: 40 wide 12 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,W100,B400,R250,Q632,W320,W300,D234,D400','P6123,F600,T000,P625,C530,G300,E520,T2542,T200,W320,W400,K100,Y000,L252,G630,K152,P5234,P613,D530,L200,T620,O100,T500,F3452,W300,N130,C65261,C4536,D000,A530,M300,C000,M26532,M000',1,0,'casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p','',0,0,'','','','',1,1,'',''),(17,1,'Casio Men\'s W753-2AV Blue Resin Quartz Watch with Digital Dial','<p>Perfect for the person that cant get enough technology, this watch will keep you looking great, while keeping you punctual, provided you dont lose track of time fiddling with this watchs nifty chronograph.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Day Date and Month</li>\r\n	<li>Case measurements: 40 wide 12 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,W100,B400,R250,Q632,W320,W300,D234,D400','P6123,F600,T000,P625,C530,G300,E520,T2542,T200,W320,W400,K100,Y000,L252,G630,K152,P5234,P613,D530,L200,T620,O100,T500,F3452,W300,N130,C65261,C4536,D000,A530,M300,C000,M26532,M000',4,0,'casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p','',0,0,'','','','',1,1,'',''),(17,1,'Casio Men\'s W753-2AV Blue Resin Quartz Watch with Digital Dial','<p>Perfect for the person that cant get enough technology, this watch will keep you looking great, while keeping you punctual, provided you dont lose track of time fiddling with this watchs nifty chronograph.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Day Date and Month</li>\r\n	<li>Case measurements: 40 wide 12 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,W100,B400,R250,Q632,W320,W300,D234,D400','P6123,F600,T000,P625,C530,G300,E520,T2542,T200,W320,W400,K100,Y000,L252,G630,K152,P5234,P613,D530,L200,T620,O100,T500,F3452,W300,N130,C65261,C4536,D000,A530,M300,C000,M26532,M000',5,0,'casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p','',0,0,'','','','',1,1,'',''),(17,1,'Casio Men\'s W753-2AV Blue Resin Quartz Watch with Digital Dial','<p>Perfect for the person that cant get enough technology, this watch will keep you looking great, while keeping you punctual, provided you dont lose track of time fiddling with this watchs nifty chronograph.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Day Date and Month</li>\r\n	<li>Case measurements: 40 wide 12 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,W100,B400,R250,Q632,W320,W300,D234,D400','P6123,F600,T000,P625,C530,G300,E520,T2542,T200,W320,W400,K100,Y000,L252,G630,K152,P5234,P613,D530,L200,T620,O100,T500,F3452,W300,N130,C65261,C4536,D000,A530,M300,C000,M26532,M000',6,0,'casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p','',0,0,'','','','',1,1,'',''),(17,1,'Casio Men\'s W753-2AV Blue Resin Quartz Watch with Digital Dial','<p>Perfect for the person that cant get enough technology, this watch will keep you looking great, while keeping you punctual, provided you dont lose track of time fiddling with this watchs nifty chronograph.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Day Date and Month</li>\r\n	<li>Case measurements: 40 wide 12 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,W100,B400,R250,Q632,W320,W300,D234,D400','P6123,F600,T000,P625,C530,G300,E520,T2542,T200,W320,W400,K100,Y000,L252,G630,K152,P5234,P613,D530,L200,T620,O100,T500,F3452,W300,N130,C65261,C4536,D000,A530,M300,C000,M26532,M000',7,0,'casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p','',0,0,'','','','',1,1,'',''),(17,1,'Casio Men\'s W753-2AV Blue Resin Quartz Watch with Digital Dial','<p>Perfect for the person that cant get enough technology, this watch will keep you looking great, while keeping you punctual, provided you dont lose track of time fiddling with this watchs nifty chronograph.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Day Date and Month</li>\r\n	<li>Case measurements: 40 wide 12 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,W100,B400,R250,Q632,W320,W300,D234,D400','P6123,F600,T000,P625,C530,G300,E520,T2542,T200,W320,W400,K100,Y000,L252,G630,K152,P5234,P613,D530,L200,T620,O100,T500,F3452,W300,N130,C65261,C4536,D000,A530,M300,C000,M26532,M000',8,0,'casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p','',0,0,'','','','',1,1,'',''),(17,1,'Casio Men\'s W753-2AV Blue Resin Quartz Watch with Digital Dial','<p>Perfect for the person that cant get enough technology, this watch will keep you looking great, while keeping you punctual, provided you dont lose track of time fiddling with this watchs nifty chronograph.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Day Date and Month</li>\r\n	<li>Case measurements: 40 wide 12 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,W100,B400,R250,Q632,W320,W300,D234,D400','P6123,F600,T000,P625,C530,G300,E520,T2542,T200,W320,W400,K100,Y000,L252,G630,K152,P5234,P613,D530,L200,T620,O100,T500,F3452,W300,N130,C65261,C4536,D000,A530,M300,C000,M26532,M000',9,0,'casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p','',0,0,'','','','',1,1,'',''),(17,1,'Casio Men\'s W753-2AV Blue Resin Quartz Watch with Digital Dial','<p>Perfect for the person that cant get enough technology, this watch will keep you looking great, while keeping you punctual, provided you dont lose track of time fiddling with this watchs nifty chronograph.</p>\r\n\r\n<ul>\r\n	<li>Calendar: Day Date and Month</li>\r\n	<li>Case measurements: 40 wide 12 mm thick</li>\r\n</ul>\r\n','',0,'','','','','','C000,M200,W100,B400,R250,Q632,W320,W300,D234,D400','P6123,F600,T000,P625,C530,G300,E520,T2542,T200,W320,W400,K100,Y000,L252,G630,K152,P5234,P613,D530,L200,T620,O100,T500,F3452,W300,N130,C65261,C4536,D000,A530,M300,C000,M26532,M000',10,0,'casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p','',0,0,'','','','',1,1,'',''),(18,1,'Nemesis Women\'s Classic Yellow Plant Art Leather Cuff Band Watch','<p style=\"margin-left:11.25pt\">This Nemesis Yellow Plant Art leather band watch features a round silvertone case with various floral designs on a white dial. This watch highlights a 100-percent USA made genuine black leather band with thorn designs on the side.</p>\r\n','',0,'','','','','','N200,W520,C420,Y400,P453,A630,L360,C100,B530,W320','T200,N200,Y400,P453,A630,L360,B530,W320,F362,R530,S41635,C000,W300,V620,F464,D252,O500,D400,H24232,P6253,U200,M300,G500,B420,T650,T000,S300',1,0,'nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','',0,0,'','','','',1,1,'',''),(18,1,'Nemesis Women\'s Classic Yellow Plant Art Leather Cuff Band Watch','<p style=\"margin-left:11.25pt\">This Nemesis Yellow Plant Art leather band watch features a round silvertone case with various floral designs on a white dial. This watch highlights a 100-percent USA made genuine black leather band with thorn designs on the side.</p>\r\n','',0,'','','','','','N200,W520,C420,Y400,P453,A630,L360,C100,B530,W320','T200,N200,Y400,P453,A630,L360,B530,W320,F362,R530,S41635,C000,W300,V620,F464,D252,O500,D400,H24232,P6253,U200,M300,G500,B420,T650,T000,S300',4,0,'nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','',0,0,'','','','',1,1,'',''),(18,1,'Nemesis Women\'s Classic Yellow Plant Art Leather Cuff Band Watch','<p style=\"margin-left:11.25pt\">This Nemesis Yellow Plant Art leather band watch features a round silvertone case with various floral designs on a white dial. This watch highlights a 100-percent USA made genuine black leather band with thorn designs on the side.</p>\r\n','',0,'','','','','','N200,W520,C420,Y400,P453,A630,L360,C100,B530,W320','T200,N200,Y400,P453,A630,L360,B530,W320,F362,R530,S41635,C000,W300,V620,F464,D252,O500,D400,H24232,P6253,U200,M300,G500,B420,T650,T000,S300',5,0,'nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','',0,0,'','','','',1,1,'',''),(18,1,'Nemesis Women\'s Classic Yellow Plant Art Leather Cuff Band Watch','<p style=\"margin-left:11.25pt\">This Nemesis Yellow Plant Art leather band watch features a round silvertone case with various floral designs on a white dial. This watch highlights a 100-percent USA made genuine black leather band with thorn designs on the side.</p>\r\n','',0,'','','','','','N200,W520,C420,Y400,P453,A630,L360,C100,B530,W320','T200,N200,Y400,P453,A630,L360,B530,W320,F362,R530,S41635,C000,W300,V620,F464,D252,O500,D400,H24232,P6253,U200,M300,G500,B420,T650,T000,S300',6,0,'nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','',0,0,'','','','',1,1,'',''),(18,1,'Nemesis Women\'s Classic Yellow Plant Art Leather Cuff Band Watch','<p style=\"margin-left:11.25pt\">This Nemesis Yellow Plant Art leather band watch features a round silvertone case with various floral designs on a white dial. This watch highlights a 100-percent USA made genuine black leather band with thorn designs on the side.</p>\r\n','',0,'','','','','','N200,W520,C420,Y400,P453,A630,L360,C100,B530,W320','T200,N200,Y400,P453,A630,L360,B530,W320,F362,R530,S41635,C000,W300,V620,F464,D252,O500,D400,H24232,P6253,U200,M300,G500,B420,T650,T000,S300',7,0,'nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','',0,0,'','','','',1,1,'',''),(18,1,'Nemesis Women\'s Classic Yellow Plant Art Leather Cuff Band Watch','<p style=\"margin-left:11.25pt\">This Nemesis Yellow Plant Art leather band watch features a round silvertone case with various floral designs on a white dial. This watch highlights a 100-percent USA made genuine black leather band with thorn designs on the side.</p>\r\n','',0,'','','','','','N200,W520,C420,Y400,P453,A630,L360,C100,B530,W320','T200,N200,Y400,P453,A630,L360,B530,W320,F362,R530,S41635,C000,W300,V620,F464,D252,O500,D400,H24232,P6253,U200,M300,G500,B420,T650,T000,S300',8,0,'nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','',0,0,'','','','',1,1,'',''),(18,1,'Nemesis Women\'s Classic Yellow Plant Art Leather Cuff Band Watch','<p style=\"margin-left:11.25pt\">This Nemesis Yellow Plant Art leather band watch features a round silvertone case with various floral designs on a white dial. This watch highlights a 100-percent USA made genuine black leather band with thorn designs on the side.</p>\r\n','',0,'','','','','','N200,W520,C420,Y400,P453,A630,L360,C100,B530,W320','T200,N200,Y400,P453,A630,L360,B530,W320,F362,R530,S41635,C000,W300,V620,F464,D252,O500,D400,H24232,P6253,U200,M300,G500,B420,T650,T000,S300',9,0,'nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','',0,0,'','','','',1,1,'',''),(18,1,'Nemesis Women\'s Classic Yellow Plant Art Leather Cuff Band Watch','<p style=\"margin-left:11.25pt\">This Nemesis Yellow Plant Art leather band watch features a round silvertone case with various floral designs on a white dial. This watch highlights a 100-percent USA made genuine black leather band with thorn designs on the side.</p>\r\n','',0,'','','','','','N200,W520,C420,Y400,P453,A630,L360,C100,B530,W320','T200,N200,Y400,P453,A630,L360,B530,W320,F362,R530,S41635,C000,W300,V620,F464,D252,O500,D400,H24232,P6253,U200,M300,G500,B420,T650,T000,S300',10,0,'nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','',0,0,'','','','',1,1,'',''),(19,1,'Nemesis Men\'s Brown Wide Leather Cuff Band Analog Brown Dial Watch','<p style=\"margin-left:11.25pt\">Simply stunning, this Nemesis Silver Small Triangle&nbsp; Watch features a stainless steel case. Run on precise Japanese Quartz movement technology, this Nemesis triangle watch features a leather strap.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,B650,W300,L360,C100,B530,A542,D400,W320','S514,S352,T200,N200,S416,S540,T65245121,W320,F362,S3542,S340,C000,R500,O500,P620,J152,Q632,M153,T2542,T6524,L360,S3615121',1,0,'nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch','',0,0,'','','','',1,1,'',''),(19,1,'Nemesis Men\'s Brown Wide Leather Cuff Band Analog Brown Dial Watch','<p style=\"margin-left:11.25pt\">Simply stunning, this Nemesis Silver Small Triangle&nbsp; Watch features a stainless steel case. Run on precise Japanese Quartz movement technology, this Nemesis triangle watch features a leather strap.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,B650,W300,L360,C100,B530,A542,D400,W320','S514,S352,T200,N200,S416,S540,T65245121,W320,F362,S3542,S340,C000,R500,O500,P620,J152,Q632,M153,T2542,T6524,L360,S3615121',4,0,'nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch','',0,0,'','','','',1,1,'',''),(19,1,'Nemesis Men\'s Brown Wide Leather Cuff Band Analog Brown Dial Watch','<p style=\"margin-left:11.25pt\">Simply stunning, this Nemesis Silver Small Triangle&nbsp; Watch features a stainless steel case. Run on precise Japanese Quartz movement technology, this Nemesis triangle watch features a leather strap.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,B650,W300,L360,C100,B530,A542,D400,W320','S514,S352,T200,N200,S416,S540,T65245121,W320,F362,S3542,S340,C000,R500,O500,P620,J152,Q632,M153,T2542,T6524,L360,S3615121',5,0,'nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch','',0,0,'','','','',1,1,'',''),(19,1,'Nemesis Men\'s Brown Wide Leather Cuff Band Analog Brown Dial Watch','<p style=\"margin-left:11.25pt\">Simply stunning, this Nemesis Silver Small Triangle&nbsp; Watch features a stainless steel case. Run on precise Japanese Quartz movement technology, this Nemesis triangle watch features a leather strap.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,B650,W300,L360,C100,B530,A542,D400,W320','S514,S352,T200,N200,S416,S540,T65245121,W320,F362,S3542,S340,C000,R500,O500,P620,J152,Q632,M153,T2542,T6524,L360,S3615121',6,0,'nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch','',0,0,'','','','',1,1,'',''),(19,1,'Nemesis Men\'s Brown Wide Leather Cuff Band Analog Brown Dial Watch','<p style=\"margin-left:11.25pt\">Simply stunning, this Nemesis Silver Small Triangle&nbsp; Watch features a stainless steel case. Run on precise Japanese Quartz movement technology, this Nemesis triangle watch features a leather strap.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,B650,W300,L360,C100,B530,A542,D400,W320','S514,S352,T200,N200,S416,S540,T65245121,W320,F362,S3542,S340,C000,R500,O500,P620,J152,Q632,M153,T2542,T6524,L360,S3615121',7,0,'nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch','',0,0,'','','','',1,1,'',''),(19,1,'Nemesis Men\'s Brown Wide Leather Cuff Band Analog Brown Dial Watch','<p style=\"margin-left:11.25pt\">Simply stunning, this Nemesis Silver Small Triangle&nbsp; Watch features a stainless steel case. Run on precise Japanese Quartz movement technology, this Nemesis triangle watch features a leather strap.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,B650,W300,L360,C100,B530,A542,D400,W320','S514,S352,T200,N200,S416,S540,T65245121,W320,F362,S3542,S340,C000,R500,O500,P620,J152,Q632,M153,T2542,T6524,L360,S3615121',8,0,'nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch','',0,0,'','','','',1,1,'',''),(19,1,'Nemesis Men\'s Brown Wide Leather Cuff Band Analog Brown Dial Watch','<p style=\"margin-left:11.25pt\">Simply stunning, this Nemesis Silver Small Triangle&nbsp; Watch features a stainless steel case. Run on precise Japanese Quartz movement technology, this Nemesis triangle watch features a leather strap.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,B650,W300,L360,C100,B530,A542,D400,W320','S514,S352,T200,N200,S416,S540,T65245121,W320,F362,S3542,S340,C000,R500,O500,P620,J152,Q632,M153,T2542,T6524,L360,S3615121',9,0,'nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch','',0,0,'','','','',1,1,'',''),(19,1,'Nemesis Men\'s Brown Wide Leather Cuff Band Analog Brown Dial Watch','<p style=\"margin-left:11.25pt\">Simply stunning, this Nemesis Silver Small Triangle&nbsp; Watch features a stainless steel case. Run on precise Japanese Quartz movement technology, this Nemesis triangle watch features a leather strap.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,B650,W300,L360,C100,B530,A542,D400,W320','S514,S352,T200,N200,S416,S540,T65245121,W320,F362,S3542,S340,C000,R500,O500,P620,J152,Q632,M153,T2542,T6524,L360,S3615121',10,0,'nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch','',0,0,'','','','',1,1,'',''),(20,1,'Nemesis Men\'s Wide Sunrise Black Leather Cuff Watch','<p style=\"margin-left:11.25pt\">A silver and black gradient dial sits in the polished alloy case of this casual watch from Nemesis. A wide black leather strap with silvertone rings and studs finishes the bold style of this timepiece.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,W300,S562,B420,L360,C100,W320','S416,A530,B420,G6353,D400,S320,I500,T000,P423,A400,C000,O100,T200,C400,W320,F650,N200,W300,L360,S361,S41635,R520,F520,B430,S340,T5125121',1,0,'nemesis-men-s-wide-sunrise-black-leather-cuff-watch','',0,0,'','','','',1,1,'',''),(20,1,'Nemesis Men\'s Wide Sunrise Black Leather Cuff Watch','<p style=\"margin-left:11.25pt\">A silver and black gradient dial sits in the polished alloy case of this casual watch from Nemesis. A wide black leather strap with silvertone rings and studs finishes the bold style of this timepiece.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,W300,S562,B420,L360,C100,W320','S416,A530,B420,G6353,D400,S320,I500,T000,P423,A400,C000,O100,T200,C400,W320,F650,N200,W300,L360,S361,S41635,R520,F520,B430,S340,T5125121',4,0,'nemesis-men-s-wide-sunrise-black-leather-cuff-watch','',0,0,'','','','',1,1,'',''),(20,1,'Nemesis Men\'s Wide Sunrise Black Leather Cuff Watch','<p style=\"margin-left:11.25pt\">A silver and black gradient dial sits in the polished alloy case of this casual watch from Nemesis. A wide black leather strap with silvertone rings and studs finishes the bold style of this timepiece.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,W300,S562,B420,L360,C100,W320','S416,A530,B420,G6353,D400,S320,I500,T000,P423,A400,C000,O100,T200,C400,W320,F650,N200,W300,L360,S361,S41635,R520,F520,B430,S340,T5125121',5,0,'nemesis-men-s-wide-sunrise-black-leather-cuff-watch','',0,0,'','','','',1,1,'',''),(20,1,'Nemesis Men\'s Wide Sunrise Black Leather Cuff Watch','<p style=\"margin-left:11.25pt\">A silver and black gradient dial sits in the polished alloy case of this casual watch from Nemesis. A wide black leather strap with silvertone rings and studs finishes the bold style of this timepiece.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,W300,S562,B420,L360,C100,W320','S416,A530,B420,G6353,D400,S320,I500,T000,P423,A400,C000,O100,T200,C400,W320,F650,N200,W300,L360,S361,S41635,R520,F520,B430,S340,T5125121',6,0,'nemesis-men-s-wide-sunrise-black-leather-cuff-watch','',0,0,'','','','',1,1,'',''),(20,1,'Nemesis Men\'s Wide Sunrise Black Leather Cuff Watch','<p style=\"margin-left:11.25pt\">A silver and black gradient dial sits in the polished alloy case of this casual watch from Nemesis. A wide black leather strap with silvertone rings and studs finishes the bold style of this timepiece.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,W300,S562,B420,L360,C100,W320','S416,A530,B420,G6353,D400,S320,I500,T000,P423,A400,C000,O100,T200,C400,W320,F650,N200,W300,L360,S361,S41635,R520,F520,B430,S340,T5125121',7,0,'nemesis-men-s-wide-sunrise-black-leather-cuff-watch','',0,0,'','','','',1,1,'',''),(20,1,'Nemesis Men\'s Wide Sunrise Black Leather Cuff Watch','<p style=\"margin-left:11.25pt\">A silver and black gradient dial sits in the polished alloy case of this casual watch from Nemesis. A wide black leather strap with silvertone rings and studs finishes the bold style of this timepiece.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,W300,S562,B420,L360,C100,W320','S416,A530,B420,G6353,D400,S320,I500,T000,P423,A400,C000,O100,T200,C400,W320,F650,N200,W300,L360,S361,S41635,R520,F520,B430,S340,T5125121',8,0,'nemesis-men-s-wide-sunrise-black-leather-cuff-watch','',0,0,'','','','',1,1,'',''),(20,1,'Nemesis Men\'s Wide Sunrise Black Leather Cuff Watch','<p style=\"margin-left:11.25pt\">A silver and black gradient dial sits in the polished alloy case of this casual watch from Nemesis. A wide black leather strap with silvertone rings and studs finishes the bold style of this timepiece.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,W300,S562,B420,L360,C100,W320','S416,A530,B420,G6353,D400,S320,I500,T000,P423,A400,C000,O100,T200,C400,W320,F650,N200,W300,L360,S361,S41635,R520,F520,B430,S340,T5125121',9,0,'nemesis-men-s-wide-sunrise-black-leather-cuff-watch','',0,0,'','','','',1,1,'',''),(20,1,'Nemesis Men\'s Wide Sunrise Black Leather Cuff Watch','<p style=\"margin-left:11.25pt\">A silver and black gradient dial sits in the polished alloy case of this casual watch from Nemesis. A wide black leather strap with silvertone rings and studs finishes the bold style of this timepiece.&nbsp;</p>\r\n','',0,'','','','','','N200,M200,W300,S562,B420,L360,C100,W320','S416,A530,B420,G6353,D400,S320,I500,T000,P423,A400,C000,O100,T200,C400,W320,F650,N200,W300,L360,S361,S41635,R520,F520,B430,S340,T5125121',10,0,'nemesis-men-s-wide-sunrise-black-leather-cuff-watch','',0,0,'','','','',1,1,'',''),(21,1,'Cartier Men\'s Santos 18k Gold and Steel Automatic Watch','<ul>\r\n	<li>This elegant wristwatch boasts a two-tone case with 18-karat yellow gold and steel</li>\r\n	<li>The Cartier men&#39;s watch is from the Santos collection</li>\r\n	<li>With a classic leather strap, this timepiece is truly timeless</li>\r\n	<li>Square stainless steel case</li>\r\n	<li>18-karat yellow gold bezel with rivet detailing</li>\r\n	<li>Silver dial</li>\r\n	<li>Luminescent black index-style hands</li>\r\n	<li>Black Roman numerals</li>\r\n	<li>Second sweep</li>\r\n	<li>Brown leather strap</li>\r\n	<li>Push-button deployment clasp</li>\r\n	<li>Sapphire crystal</li>\r\n	<li>Push/pull crown</li>\r\n	<li>Automatic movement</li>\r\n	<li>Water resistant to 100 meters</li>\r\n	<li>Case measures 38 mm wide x 10 mm thick</li>\r\n	<li>Strap measures 23 mm wide x 8 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C636,M200,S532,K000,G430,A530,S340,A3532,W320','T200,E4253,W6232,B232,T500,C000,W300,K630,Y400,G430,A530,S340,T000,C636,M200,W320,I200,F650,S532,C4235,C420,L360,S361,T512,T640,T542,S600,S3542,B240,R130,D452,S416,D400,L5253,B420,I53234,H532,R500,N642,S530,S100,B650,P2135,D1453,C421,S160,C6234,P214,C650,A3532,M153,W360,R2353,M362,M262,M000,I520,L520',1,0,'cartier-men-s-santos-18k-gold-and-steel-automatic-watch','',0,0,'','','','',1,1,'',''),(21,1,'Cartier Men\'s Santos 18k Gold and Steel Automatic Watch','<ul>\r\n	<li>This elegant wristwatch boasts a two-tone case with 18-karat yellow gold and steel</li>\r\n	<li>The Cartier men&#39;s watch is from the Santos collection</li>\r\n	<li>With a classic leather strap, this timepiece is truly timeless</li>\r\n	<li>Square stainless steel case</li>\r\n	<li>18-karat yellow gold bezel with rivet detailing</li>\r\n	<li>Silver dial</li>\r\n	<li>Luminescent black index-style hands</li>\r\n	<li>Black Roman numerals</li>\r\n	<li>Second sweep</li>\r\n	<li>Brown leather strap</li>\r\n	<li>Push-button deployment clasp</li>\r\n	<li>Sapphire crystal</li>\r\n	<li>Push/pull crown</li>\r\n	<li>Automatic movement</li>\r\n	<li>Water resistant to 100 meters</li>\r\n	<li>Case measures 38 mm wide x 10 mm thick</li>\r\n	<li>Strap measures 23 mm wide x 8 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C636,M200,S532,K000,G430,A530,S340,A3532,W320','T200,E4253,W6232,B232,T500,C000,W300,K630,Y400,G430,A530,S340,T000,C636,M200,W320,I200,F650,S532,C4235,C420,L360,S361,T512,T640,T542,S600,S3542,B240,R130,D452,S416,D400,L5253,B420,I53234,H532,R500,N642,S530,S100,B650,P2135,D1453,C421,S160,C6234,P214,C650,A3532,M153,W360,R2353,M362,M262,M000,I520,L520',4,0,'cartier-men-s-santos-18k-gold-and-steel-automatic-watch','',0,0,'','','','',1,1,'',''),(21,1,'Cartier Men\'s Santos 18k Gold and Steel Automatic Watch','<ul>\r\n	<li>This elegant wristwatch boasts a two-tone case with 18-karat yellow gold and steel</li>\r\n	<li>The Cartier men&#39;s watch is from the Santos collection</li>\r\n	<li>With a classic leather strap, this timepiece is truly timeless</li>\r\n	<li>Square stainless steel case</li>\r\n	<li>18-karat yellow gold bezel with rivet detailing</li>\r\n	<li>Silver dial</li>\r\n	<li>Luminescent black index-style hands</li>\r\n	<li>Black Roman numerals</li>\r\n	<li>Second sweep</li>\r\n	<li>Brown leather strap</li>\r\n	<li>Push-button deployment clasp</li>\r\n	<li>Sapphire crystal</li>\r\n	<li>Push/pull crown</li>\r\n	<li>Automatic movement</li>\r\n	<li>Water resistant to 100 meters</li>\r\n	<li>Case measures 38 mm wide x 10 mm thick</li>\r\n	<li>Strap measures 23 mm wide x 8 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C636,M200,S532,K000,G430,A530,S340,A3532,W320','T200,E4253,W6232,B232,T500,C000,W300,K630,Y400,G430,A530,S340,T000,C636,M200,W320,I200,F650,S532,C4235,C420,L360,S361,T512,T640,T542,S600,S3542,B240,R130,D452,S416,D400,L5253,B420,I53234,H532,R500,N642,S530,S100,B650,P2135,D1453,C421,S160,C6234,P214,C650,A3532,M153,W360,R2353,M362,M262,M000,I520,L520',5,0,'cartier-men-s-santos-18k-gold-and-steel-automatic-watch','',0,0,'','','','',1,1,'',''),(21,1,'Cartier Men\'s Santos 18k Gold and Steel Automatic Watch','<ul>\r\n	<li>This elegant wristwatch boasts a two-tone case with 18-karat yellow gold and steel</li>\r\n	<li>The Cartier men&#39;s watch is from the Santos collection</li>\r\n	<li>With a classic leather strap, this timepiece is truly timeless</li>\r\n	<li>Square stainless steel case</li>\r\n	<li>18-karat yellow gold bezel with rivet detailing</li>\r\n	<li>Silver dial</li>\r\n	<li>Luminescent black index-style hands</li>\r\n	<li>Black Roman numerals</li>\r\n	<li>Second sweep</li>\r\n	<li>Brown leather strap</li>\r\n	<li>Push-button deployment clasp</li>\r\n	<li>Sapphire crystal</li>\r\n	<li>Push/pull crown</li>\r\n	<li>Automatic movement</li>\r\n	<li>Water resistant to 100 meters</li>\r\n	<li>Case measures 38 mm wide x 10 mm thick</li>\r\n	<li>Strap measures 23 mm wide x 8 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C636,M200,S532,K000,G430,A530,S340,A3532,W320','T200,E4253,W6232,B232,T500,C000,W300,K630,Y400,G430,A530,S340,T000,C636,M200,W320,I200,F650,S532,C4235,C420,L360,S361,T512,T640,T542,S600,S3542,B240,R130,D452,S416,D400,L5253,B420,I53234,H532,R500,N642,S530,S100,B650,P2135,D1453,C421,S160,C6234,P214,C650,A3532,M153,W360,R2353,M362,M262,M000,I520,L520',6,0,'cartier-men-s-santos-18k-gold-and-steel-automatic-watch','',0,0,'','','','',1,1,'',''),(21,1,'Cartier Men\'s Santos 18k Gold and Steel Automatic Watch','<ul>\r\n	<li>This elegant wristwatch boasts a two-tone case with 18-karat yellow gold and steel</li>\r\n	<li>The Cartier men&#39;s watch is from the Santos collection</li>\r\n	<li>With a classic leather strap, this timepiece is truly timeless</li>\r\n	<li>Square stainless steel case</li>\r\n	<li>18-karat yellow gold bezel with rivet detailing</li>\r\n	<li>Silver dial</li>\r\n	<li>Luminescent black index-style hands</li>\r\n	<li>Black Roman numerals</li>\r\n	<li>Second sweep</li>\r\n	<li>Brown leather strap</li>\r\n	<li>Push-button deployment clasp</li>\r\n	<li>Sapphire crystal</li>\r\n	<li>Push/pull crown</li>\r\n	<li>Automatic movement</li>\r\n	<li>Water resistant to 100 meters</li>\r\n	<li>Case measures 38 mm wide x 10 mm thick</li>\r\n	<li>Strap measures 23 mm wide x 8 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C636,M200,S532,K000,G430,A530,S340,A3532,W320','T200,E4253,W6232,B232,T500,C000,W300,K630,Y400,G430,A530,S340,T000,C636,M200,W320,I200,F650,S532,C4235,C420,L360,S361,T512,T640,T542,S600,S3542,B240,R130,D452,S416,D400,L5253,B420,I53234,H532,R500,N642,S530,S100,B650,P2135,D1453,C421,S160,C6234,P214,C650,A3532,M153,W360,R2353,M362,M262,M000,I520,L520',7,0,'cartier-men-s-santos-18k-gold-and-steel-automatic-watch','',0,0,'','','','',1,1,'',''),(21,1,'Cartier Men\'s Santos 18k Gold and Steel Automatic Watch','<ul>\r\n	<li>This elegant wristwatch boasts a two-tone case with 18-karat yellow gold and steel</li>\r\n	<li>The Cartier men&#39;s watch is from the Santos collection</li>\r\n	<li>With a classic leather strap, this timepiece is truly timeless</li>\r\n	<li>Square stainless steel case</li>\r\n	<li>18-karat yellow gold bezel with rivet detailing</li>\r\n	<li>Silver dial</li>\r\n	<li>Luminescent black index-style hands</li>\r\n	<li>Black Roman numerals</li>\r\n	<li>Second sweep</li>\r\n	<li>Brown leather strap</li>\r\n	<li>Push-button deployment clasp</li>\r\n	<li>Sapphire crystal</li>\r\n	<li>Push/pull crown</li>\r\n	<li>Automatic movement</li>\r\n	<li>Water resistant to 100 meters</li>\r\n	<li>Case measures 38 mm wide x 10 mm thick</li>\r\n	<li>Strap measures 23 mm wide x 8 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C636,M200,S532,K000,G430,A530,S340,A3532,W320','T200,E4253,W6232,B232,T500,C000,W300,K630,Y400,G430,A530,S340,T000,C636,M200,W320,I200,F650,S532,C4235,C420,L360,S361,T512,T640,T542,S600,S3542,B240,R130,D452,S416,D400,L5253,B420,I53234,H532,R500,N642,S530,S100,B650,P2135,D1453,C421,S160,C6234,P214,C650,A3532,M153,W360,R2353,M362,M262,M000,I520,L520',8,0,'cartier-men-s-santos-18k-gold-and-steel-automatic-watch','',0,0,'','','','',1,1,'',''),(21,1,'Cartier Men\'s Santos 18k Gold and Steel Automatic Watch','<ul>\r\n	<li>This elegant wristwatch boasts a two-tone case with 18-karat yellow gold and steel</li>\r\n	<li>The Cartier men&#39;s watch is from the Santos collection</li>\r\n	<li>With a classic leather strap, this timepiece is truly timeless</li>\r\n	<li>Square stainless steel case</li>\r\n	<li>18-karat yellow gold bezel with rivet detailing</li>\r\n	<li>Silver dial</li>\r\n	<li>Luminescent black index-style hands</li>\r\n	<li>Black Roman numerals</li>\r\n	<li>Second sweep</li>\r\n	<li>Brown leather strap</li>\r\n	<li>Push-button deployment clasp</li>\r\n	<li>Sapphire crystal</li>\r\n	<li>Push/pull crown</li>\r\n	<li>Automatic movement</li>\r\n	<li>Water resistant to 100 meters</li>\r\n	<li>Case measures 38 mm wide x 10 mm thick</li>\r\n	<li>Strap measures 23 mm wide x 8 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C636,M200,S532,K000,G430,A530,S340,A3532,W320','T200,E4253,W6232,B232,T500,C000,W300,K630,Y400,G430,A530,S340,T000,C636,M200,W320,I200,F650,S532,C4235,C420,L360,S361,T512,T640,T542,S600,S3542,B240,R130,D452,S416,D400,L5253,B420,I53234,H532,R500,N642,S530,S100,B650,P2135,D1453,C421,S160,C6234,P214,C650,A3532,M153,W360,R2353,M362,M262,M000,I520,L520',9,0,'cartier-men-s-santos-18k-gold-and-steel-automatic-watch','',0,0,'','','','',1,1,'',''),(21,1,'Cartier Men\'s Santos 18k Gold and Steel Automatic Watch','<ul>\r\n	<li>This elegant wristwatch boasts a two-tone case with 18-karat yellow gold and steel</li>\r\n	<li>The Cartier men&#39;s watch is from the Santos collection</li>\r\n	<li>With a classic leather strap, this timepiece is truly timeless</li>\r\n	<li>Square stainless steel case</li>\r\n	<li>18-karat yellow gold bezel with rivet detailing</li>\r\n	<li>Silver dial</li>\r\n	<li>Luminescent black index-style hands</li>\r\n	<li>Black Roman numerals</li>\r\n	<li>Second sweep</li>\r\n	<li>Brown leather strap</li>\r\n	<li>Push-button deployment clasp</li>\r\n	<li>Sapphire crystal</li>\r\n	<li>Push/pull crown</li>\r\n	<li>Automatic movement</li>\r\n	<li>Water resistant to 100 meters</li>\r\n	<li>Case measures 38 mm wide x 10 mm thick</li>\r\n	<li>Strap measures 23 mm wide x 8 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C636,M200,S532,K000,G430,A530,S340,A3532,W320','T200,E4253,W6232,B232,T500,C000,W300,K630,Y400,G430,A530,S340,T000,C636,M200,W320,I200,F650,S532,C4235,C420,L360,S361,T512,T640,T542,S600,S3542,B240,R130,D452,S416,D400,L5253,B420,I53234,H532,R500,N642,S530,S100,B650,P2135,D1453,C421,S160,C6234,P214,C650,A3532,M153,W360,R2353,M362,M262,M000,I520,L520',10,0,'cartier-men-s-santos-18k-gold-and-steel-automatic-watch','',0,0,'','','','',1,1,'',''),(22,1,'Edox Men\'s \'Les Vauberts Automatic\' Yellow Goldtone Stainless Steel Mechanical A','<p style=\"margin-left:11.25pt\">The Edox men&#39;s &#39;Les Vauberts Automatic&#39; Swiss mechanical watch features a yellow goldplated case with a contrasting silvertone dial and warm yellow goldtone hands and indices. This handsome watch is finished on a dark brown leather strap.</p>\r\n','',0,'','','','','','E320,M200,L200,V632,A3532,Y400,G435,S3542,S340,M2524','T000,E320,M200,L200,V632,A3532,S000,M2524,W320,F362,Y400,G43143,C000,W300,C5362352,S41635,D400,A530,W650,G435,H532,I532,T200,H5325,I200,F523,O500,D620,B650,L360,S361',1,0,'edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','',0,0,'','','','',1,1,'',''),(22,1,'Edox Men\'s \'Les Vauberts Automatic\' Yellow Goldtone Stainless Steel Mechanical A','<p style=\"margin-left:11.25pt\">The Edox men&#39;s &#39;Les Vauberts Automatic&#39; Swiss mechanical watch features a yellow goldplated case with a contrasting silvertone dial and warm yellow goldtone hands and indices. This handsome watch is finished on a dark brown leather strap.</p>\r\n','',0,'','','','','','E320,M200,L200,V632,A3532,Y400,G435,S3542,S340,M2524','T000,E320,M200,L200,V632,A3532,S000,M2524,W320,F362,Y400,G43143,C000,W300,C5362352,S41635,D400,A530,W650,G435,H532,I532,T200,H5325,I200,F523,O500,D620,B650,L360,S361',4,0,'edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','',0,0,'','','','',1,1,'',''),(22,1,'Edox Men\'s \'Les Vauberts Automatic\' Yellow Goldtone Stainless Steel Mechanical A','<p style=\"margin-left:11.25pt\">The Edox men&#39;s &#39;Les Vauberts Automatic&#39; Swiss mechanical watch features a yellow goldplated case with a contrasting silvertone dial and warm yellow goldtone hands and indices. This handsome watch is finished on a dark brown leather strap.</p>\r\n','',0,'','','','','','E320,M200,L200,V632,A3532,Y400,G435,S3542,S340,M2524','T000,E320,M200,L200,V632,A3532,S000,M2524,W320,F362,Y400,G43143,C000,W300,C5362352,S41635,D400,A530,W650,G435,H532,I532,T200,H5325,I200,F523,O500,D620,B650,L360,S361',5,0,'edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','',0,0,'','','','',1,1,'',''),(22,1,'Edox Men\'s \'Les Vauberts Automatic\' Yellow Goldtone Stainless Steel Mechanical A','<p style=\"margin-left:11.25pt\">The Edox men&#39;s &#39;Les Vauberts Automatic&#39; Swiss mechanical watch features a yellow goldplated case with a contrasting silvertone dial and warm yellow goldtone hands and indices. This handsome watch is finished on a dark brown leather strap.</p>\r\n','',0,'','','','','','E320,M200,L200,V632,A3532,Y400,G435,S3542,S340,M2524','T000,E320,M200,L200,V632,A3532,S000,M2524,W320,F362,Y400,G43143,C000,W300,C5362352,S41635,D400,A530,W650,G435,H532,I532,T200,H5325,I200,F523,O500,D620,B650,L360,S361',6,0,'edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','',0,0,'','','','',1,1,'',''),(22,1,'Edox Men\'s \'Les Vauberts Automatic\' Yellow Goldtone Stainless Steel Mechanical A','<p style=\"margin-left:11.25pt\">The Edox men&#39;s &#39;Les Vauberts Automatic&#39; Swiss mechanical watch features a yellow goldplated case with a contrasting silvertone dial and warm yellow goldtone hands and indices. This handsome watch is finished on a dark brown leather strap.</p>\r\n','',0,'','','','','','E320,M200,L200,V632,A3532,Y400,G435,S3542,S340,M2524','T000,E320,M200,L200,V632,A3532,S000,M2524,W320,F362,Y400,G43143,C000,W300,C5362352,S41635,D400,A530,W650,G435,H532,I532,T200,H5325,I200,F523,O500,D620,B650,L360,S361',7,0,'edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','',0,0,'','','','',1,1,'',''),(22,1,'Edox Men\'s \'Les Vauberts Automatic\' Yellow Goldtone Stainless Steel Mechanical A','<p style=\"margin-left:11.25pt\">The Edox men&#39;s &#39;Les Vauberts Automatic&#39; Swiss mechanical watch features a yellow goldplated case with a contrasting silvertone dial and warm yellow goldtone hands and indices. This handsome watch is finished on a dark brown leather strap.</p>\r\n','',0,'','','','','','E320,M200,L200,V632,A3532,Y400,G435,S3542,S340,M2524','T000,E320,M200,L200,V632,A3532,S000,M2524,W320,F362,Y400,G43143,C000,W300,C5362352,S41635,D400,A530,W650,G435,H532,I532,T200,H5325,I200,F523,O500,D620,B650,L360,S361',8,0,'edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','',0,0,'','','','',1,1,'',''),(22,1,'Edox Men\'s \'Les Vauberts Automatic\' Yellow Goldtone Stainless Steel Mechanical A','<p style=\"margin-left:11.25pt\">The Edox men&#39;s &#39;Les Vauberts Automatic&#39; Swiss mechanical watch features a yellow goldplated case with a contrasting silvertone dial and warm yellow goldtone hands and indices. This handsome watch is finished on a dark brown leather strap.</p>\r\n','',0,'','','','','','E320,M200,L200,V632,A3532,Y400,G435,S3542,S340,M2524','T000,E320,M200,L200,V632,A3532,S000,M2524,W320,F362,Y400,G43143,C000,W300,C5362352,S41635,D400,A530,W650,G435,H532,I532,T200,H5325,I200,F523,O500,D620,B650,L360,S361',9,0,'edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','',0,0,'','','','',1,1,'',''),(22,1,'Edox Men\'s \'Les Vauberts Automatic\' Yellow Goldtone Stainless Steel Mechanical A','<p style=\"margin-left:11.25pt\">The Edox men&#39;s &#39;Les Vauberts Automatic&#39; Swiss mechanical watch features a yellow goldplated case with a contrasting silvertone dial and warm yellow goldtone hands and indices. This handsome watch is finished on a dark brown leather strap.</p>\r\n','',0,'','','','','','E320,M200,L200,V632,A3532,Y400,G435,S3542,S340,M2524','T000,E320,M200,L200,V632,A3532,S000,M2524,W320,F362,Y400,G43143,C000,W300,C5362352,S41635,D400,A530,W650,G435,H532,I532,T200,H5325,I200,F523,O500,D620,B650,L360,S361',10,0,'edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','',0,0,'','','','',1,1,'',''),(23,1,'Edox Men\'s \'WRC\' Stainless Steel Multifunction Chronograph Watch','<p style=\"margin-left:11.25pt\">Edox presents this gorgeous stainless steel watch which features several bells and whistles. With a beautiful blue face, three subdials and a sleek bracelet, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','E320,M200,W620,S3542,S340,M4315235,C65261,W320','E320,P62532,T200,G620,S3542,S340,W320,W200,F362,S164,B420,A530,W2342,W300,B314,B400,F200,T600,S1342,S420,B6243,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',1,0,'edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch','',0,0,'','','','',1,1,'',''),(23,1,'Edox Men\'s \'WRC\' Stainless Steel Multifunction Chronograph Watch','<p style=\"margin-left:11.25pt\">Edox presents this gorgeous stainless steel watch which features several bells and whistles. With a beautiful blue face, three subdials and a sleek bracelet, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','E320,M200,W620,S3542,S340,M4315235,C65261,W320','E320,P62532,T200,G620,S3542,S340,W320,W200,F362,S164,B420,A530,W2342,W300,B314,B400,F200,T600,S1342,S420,B6243,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',4,0,'edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch','',0,0,'','','','',1,1,'',''),(23,1,'Edox Men\'s \'WRC\' Stainless Steel Multifunction Chronograph Watch','<p style=\"margin-left:11.25pt\">Edox presents this gorgeous stainless steel watch which features several bells and whistles. With a beautiful blue face, three subdials and a sleek bracelet, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','E320,M200,W620,S3542,S340,M4315235,C65261,W320','E320,P62532,T200,G620,S3542,S340,W320,W200,F362,S164,B420,A530,W2342,W300,B314,B400,F200,T600,S1342,S420,B6243,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',5,0,'edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch','',0,0,'','','','',1,1,'',''),(23,1,'Edox Men\'s \'WRC\' Stainless Steel Multifunction Chronograph Watch','<p style=\"margin-left:11.25pt\">Edox presents this gorgeous stainless steel watch which features several bells and whistles. With a beautiful blue face, three subdials and a sleek bracelet, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','E320,M200,W620,S3542,S340,M4315235,C65261,W320','E320,P62532,T200,G620,S3542,S340,W320,W200,F362,S164,B420,A530,W2342,W300,B314,B400,F200,T600,S1342,S420,B6243,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',6,0,'edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch','',0,0,'','','','',1,1,'',''),(23,1,'Edox Men\'s \'WRC\' Stainless Steel Multifunction Chronograph Watch','<p style=\"margin-left:11.25pt\">Edox presents this gorgeous stainless steel watch which features several bells and whistles. With a beautiful blue face, three subdials and a sleek bracelet, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','E320,M200,W620,S3542,S340,M4315235,C65261,W320','E320,P62532,T200,G620,S3542,S340,W320,W200,F362,S164,B420,A530,W2342,W300,B314,B400,F200,T600,S1342,S420,B6243,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',7,0,'edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch','',0,0,'','','','',1,1,'',''),(23,1,'Edox Men\'s \'WRC\' Stainless Steel Multifunction Chronograph Watch','<p style=\"margin-left:11.25pt\">Edox presents this gorgeous stainless steel watch which features several bells and whistles. With a beautiful blue face, three subdials and a sleek bracelet, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','E320,M200,W620,S3542,S340,M4315235,C65261,W320','E320,P62532,T200,G620,S3542,S340,W320,W200,F362,S164,B420,A530,W2342,W300,B314,B400,F200,T600,S1342,S420,B6243,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',8,0,'edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch','',0,0,'','','','',1,1,'',''),(23,1,'Edox Men\'s \'WRC\' Stainless Steel Multifunction Chronograph Watch','<p style=\"margin-left:11.25pt\">Edox presents this gorgeous stainless steel watch which features several bells and whistles. With a beautiful blue face, three subdials and a sleek bracelet, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','E320,M200,W620,S3542,S340,M4315235,C65261,W320','E320,P62532,T200,G620,S3542,S340,W320,W200,F362,S164,B420,A530,W2342,W300,B314,B400,F200,T600,S1342,S420,B6243,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',9,0,'edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch','',0,0,'','','','',1,1,'',''),(23,1,'Edox Men\'s \'WRC\' Stainless Steel Multifunction Chronograph Watch','<p style=\"margin-left:11.25pt\">Edox presents this gorgeous stainless steel watch which features several bells and whistles. With a beautiful blue face, three subdials and a sleek bracelet, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','E320,M200,W620,S3542,S340,M4315235,C65261,W320','E320,P62532,T200,G620,S3542,S340,W320,W200,F362,S164,B420,A530,W2342,W300,B314,B400,F200,T600,S1342,S420,B6243,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',10,0,'edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch','',0,0,'','','','',1,1,'',''),(24,1,'Concord Men\'s \'Saratoga\' Black Stainless Steel Swiss Quartz Watch','<p style=\"margin-left:11.25pt\">Add a modern pop of style to your look with this sleek stainless steel watch from Concord. A smooth black dial, easy-to-read calendar date and comfortable two-tone bracelet makes this watch the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C5263,M200,S632,B420,S3542,S340,S000,Q632,W320','A300,M365,P000,O100,S340,T000,Y600,L200,W300,T200,S420,S3542,W320,F650,C5263,S530,B420,D400,E2363,C4536,D000,A530,C516314,T500,B6243,M200,P6123,W000,S300,O500,I500,S345121',1,0,'concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch','',0,0,'','','','',1,1,'',''),(24,1,'Concord Men\'s \'Saratoga\' Black Stainless Steel Swiss Quartz Watch','<p style=\"margin-left:11.25pt\">Add a modern pop of style to your look with this sleek stainless steel watch from Concord. A smooth black dial, easy-to-read calendar date and comfortable two-tone bracelet makes this watch the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C5263,M200,S632,B420,S3542,S340,S000,Q632,W320','A300,M365,P000,O100,S340,T000,Y600,L200,W300,T200,S420,S3542,W320,F650,C5263,S530,B420,D400,E2363,C4536,D000,A530,C516314,T500,B6243,M200,P6123,W000,S300,O500,I500,S345121',4,0,'concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch','',0,0,'','','','',1,1,'',''),(24,1,'Concord Men\'s \'Saratoga\' Black Stainless Steel Swiss Quartz Watch','<p style=\"margin-left:11.25pt\">Add a modern pop of style to your look with this sleek stainless steel watch from Concord. A smooth black dial, easy-to-read calendar date and comfortable two-tone bracelet makes this watch the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C5263,M200,S632,B420,S3542,S340,S000,Q632,W320','A300,M365,P000,O100,S340,T000,Y600,L200,W300,T200,S420,S3542,W320,F650,C5263,S530,B420,D400,E2363,C4536,D000,A530,C516314,T500,B6243,M200,P6123,W000,S300,O500,I500,S345121',5,0,'concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch','',0,0,'','','','',1,1,'',''),(24,1,'Concord Men\'s \'Saratoga\' Black Stainless Steel Swiss Quartz Watch','<p style=\"margin-left:11.25pt\">Add a modern pop of style to your look with this sleek stainless steel watch from Concord. A smooth black dial, easy-to-read calendar date and comfortable two-tone bracelet makes this watch the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C5263,M200,S632,B420,S3542,S340,S000,Q632,W320','A300,M365,P000,O100,S340,T000,Y600,L200,W300,T200,S420,S3542,W320,F650,C5263,S530,B420,D400,E2363,C4536,D000,A530,C516314,T500,B6243,M200,P6123,W000,S300,O500,I500,S345121',6,0,'concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch','',0,0,'','','','',1,1,'',''),(24,1,'Concord Men\'s \'Saratoga\' Black Stainless Steel Swiss Quartz Watch','<p style=\"margin-left:11.25pt\">Add a modern pop of style to your look with this sleek stainless steel watch from Concord. A smooth black dial, easy-to-read calendar date and comfortable two-tone bracelet makes this watch the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C5263,M200,S632,B420,S3542,S340,S000,Q632,W320','A300,M365,P000,O100,S340,T000,Y600,L200,W300,T200,S420,S3542,W320,F650,C5263,S530,B420,D400,E2363,C4536,D000,A530,C516314,T500,B6243,M200,P6123,W000,S300,O500,I500,S345121',7,0,'concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch','',0,0,'','','','',1,1,'',''),(24,1,'Concord Men\'s \'Saratoga\' Black Stainless Steel Swiss Quartz Watch','<p style=\"margin-left:11.25pt\">Add a modern pop of style to your look with this sleek stainless steel watch from Concord. A smooth black dial, easy-to-read calendar date and comfortable two-tone bracelet makes this watch the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C5263,M200,S632,B420,S3542,S340,S000,Q632,W320','A300,M365,P000,O100,S340,T000,Y600,L200,W300,T200,S420,S3542,W320,F650,C5263,S530,B420,D400,E2363,C4536,D000,A530,C516314,T500,B6243,M200,P6123,W000,S300,O500,I500,S345121',8,0,'concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch','',0,0,'','','','',1,1,'',''),(24,1,'Concord Men\'s \'Saratoga\' Black Stainless Steel Swiss Quartz Watch','<p style=\"margin-left:11.25pt\">Add a modern pop of style to your look with this sleek stainless steel watch from Concord. A smooth black dial, easy-to-read calendar date and comfortable two-tone bracelet makes this watch the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C5263,M200,S632,B420,S3542,S340,S000,Q632,W320','A300,M365,P000,O100,S340,T000,Y600,L200,W300,T200,S420,S3542,W320,F650,C5263,S530,B420,D400,E2363,C4536,D000,A530,C516314,T500,B6243,M200,P6123,W000,S300,O500,I500,S345121',9,0,'concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch','',0,0,'','','','',1,1,'',''),(24,1,'Concord Men\'s \'Saratoga\' Black Stainless Steel Swiss Quartz Watch','<p style=\"margin-left:11.25pt\">Add a modern pop of style to your look with this sleek stainless steel watch from Concord. A smooth black dial, easy-to-read calendar date and comfortable two-tone bracelet makes this watch the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C5263,M200,S632,B420,S3542,S340,S000,Q632,W320','A300,M365,P000,O100,S340,T000,Y600,L200,W300,T200,S420,S3542,W320,F650,C5263,S530,B420,D400,E2363,C4536,D000,A530,C516314,T500,B6243,M200,P6123,W000,S300,O500,I500,S345121',10,0,'concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch','',0,0,'','','','',1,1,'',''),(25,1,'Citizen Eco-Drive Silver Tone Men','<p style=\"margin-left:11.25pt\">Sport a sophisticated, classic look with this Citizen stainless steel watch. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C325,E2361,S416,T500,M000','S163,S12323,C420,L200,W300,T200,C325,S3542,S340,W320,E2363,M6262,A530,C516314,S361,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',1,0,'citizen-eco-drive-silver-tone-men','',0,0,'','','','',1,1,'',''),(25,1,'Citizen Eco-Drive Silver Tone Men','<p style=\"margin-left:11.25pt\">Sport a sophisticated, classic look with this Citizen stainless steel watch. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C325,E2361,S416,T500,M000','S163,S12323,C420,L200,W300,T200,C325,S3542,S340,W320,E2363,M6262,A530,C516314,S361,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',4,0,'citizen-eco-drive-silver-tone-men','',0,0,'','','','',1,1,'',''),(25,1,'Citizen Eco-Drive Silver Tone Men','<p style=\"margin-left:11.25pt\">Sport a sophisticated, classic look with this Citizen stainless steel watch. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C325,E2361,S416,T500,M000','S163,S12323,C420,L200,W300,T200,C325,S3542,S340,W320,E2363,M6262,A530,C516314,S361,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',5,0,'citizen-eco-drive-silver-tone-men','',0,0,'','','','',1,1,'',''),(25,1,'Citizen Eco-Drive Silver Tone Men','<p style=\"margin-left:11.25pt\">Sport a sophisticated, classic look with this Citizen stainless steel watch. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C325,E2361,S416,T500,M000','S163,S12323,C420,L200,W300,T200,C325,S3542,S340,W320,E2363,M6262,A530,C516314,S361,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',6,0,'citizen-eco-drive-silver-tone-men','',0,0,'','','','',1,1,'',''),(25,1,'Citizen Eco-Drive Silver Tone Men','<p style=\"margin-left:11.25pt\">Sport a sophisticated, classic look with this Citizen stainless steel watch. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C325,E2361,S416,T500,M000','S163,S12323,C420,L200,W300,T200,C325,S3542,S340,W320,E2363,M6262,A530,C516314,S361,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',7,0,'citizen-eco-drive-silver-tone-men','',0,0,'','','','',1,1,'',''),(25,1,'Citizen Eco-Drive Silver Tone Men','<p style=\"margin-left:11.25pt\">Sport a sophisticated, classic look with this Citizen stainless steel watch. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C325,E2361,S416,T500,M000','S163,S12323,C420,L200,W300,T200,C325,S3542,S340,W320,E2363,M6262,A530,C516314,S361,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',8,0,'citizen-eco-drive-silver-tone-men','',0,0,'','','','',1,1,'',''),(25,1,'Citizen Eco-Drive Silver Tone Men','<p style=\"margin-left:11.25pt\">Sport a sophisticated, classic look with this Citizen stainless steel watch. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C325,E2361,S416,T500,M000','S163,S12323,C420,L200,W300,T200,C325,S3542,S340,W320,E2363,M6262,A530,C516314,S361,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',9,0,'citizen-eco-drive-silver-tone-men','',0,0,'','','','',1,1,'',''),(25,1,'Citizen Eco-Drive Silver Tone Men','<p style=\"margin-left:11.25pt\">Sport a sophisticated, classic look with this Citizen stainless steel watch. With easy-to-read markers and a comfortable strap, this watch is the perfect way to stay on time and in style.&nbsp;</p>\r\n','',0,'','','','','','C325,E2361,S416,T500,M000','S163,S12323,C420,L200,W300,T200,C325,S3542,S340,W320,E2363,M6262,A530,C516314,S361,I200,T000,P6123,W000,S300,O500,T500,I500,S345121',10,0,'citizen-eco-drive-silver-tone-men','',0,0,'','','','',1,1,'',''),(26,1,'Citizen Men\'s \'Eco-Drive\' Primo Black/ Blue Chronograph Watch','<p>This stylish chronograph from citizen features a detailed dial with chronograph subdials and a calendar window for excellent timekeeping ability. This stainless steel watch is finished with a comfortable polyurethane strap with a pin buckle clasp.</p>\r\n\r\n<ul>\r\n	<li>Subdials: Standard chronograph</li>\r\n	<li>Calendar: Date window at 3 o&#39;clock</li>\r\n	<li>Power reserve: 180 Days</li>\r\n	<li>Case measurements: 45 mm wide x 45 mm long x 12 mm thick</li>\r\n	<li>Strap measurements: 23 mm wide x 8.5 inches long</li>\r\n	<li>Box measurements: 4 inches wide x 4 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,P650,B420,B400,C65261,W320','T200,S342,C65261,F650,C325,F362,D430,D400,W300,S1342,A530,C4536,W530,F600,E2453,T52152,A143,S3542,S340,W320,I200,F523,C516314,P4635,S361,P500,B240,C421,S35363,D000,A300,O242,P600,R261,D200,C000,M26532,M000,L520,I520,B200,H200',1,0,'citizen-men-s-eco-drive-primo-black-blue-chronograph-watch','',0,0,'','','','',1,1,'',''),(26,1,'Citizen Men\'s \'Eco-Drive\' Primo Black/ Blue Chronograph Watch','<p>This stylish chronograph from citizen features a detailed dial with chronograph subdials and a calendar window for excellent timekeeping ability. This stainless steel watch is finished with a comfortable polyurethane strap with a pin buckle clasp.</p>\r\n\r\n<ul>\r\n	<li>Subdials: Standard chronograph</li>\r\n	<li>Calendar: Date window at 3 o&#39;clock</li>\r\n	<li>Power reserve: 180 Days</li>\r\n	<li>Case measurements: 45 mm wide x 45 mm long x 12 mm thick</li>\r\n	<li>Strap measurements: 23 mm wide x 8.5 inches long</li>\r\n	<li>Box measurements: 4 inches wide x 4 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,P650,B420,B400,C65261,W320','T200,S342,C65261,F650,C325,F362,D430,D400,W300,S1342,A530,C4536,W530,F600,E2453,T52152,A143,S3542,S340,W320,I200,F523,C516314,P4635,S361,P500,B240,C421,S35363,D000,A300,O242,P600,R261,D200,C000,M26532,M000,L520,I520,B200,H200',4,0,'citizen-men-s-eco-drive-primo-black-blue-chronograph-watch','',0,0,'','','','',1,1,'',''),(26,1,'Citizen Men\'s \'Eco-Drive\' Primo Black/ Blue Chronograph Watch','<p>This stylish chronograph from citizen features a detailed dial with chronograph subdials and a calendar window for excellent timekeeping ability. This stainless steel watch is finished with a comfortable polyurethane strap with a pin buckle clasp.</p>\r\n\r\n<ul>\r\n	<li>Subdials: Standard chronograph</li>\r\n	<li>Calendar: Date window at 3 o&#39;clock</li>\r\n	<li>Power reserve: 180 Days</li>\r\n	<li>Case measurements: 45 mm wide x 45 mm long x 12 mm thick</li>\r\n	<li>Strap measurements: 23 mm wide x 8.5 inches long</li>\r\n	<li>Box measurements: 4 inches wide x 4 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,P650,B420,B400,C65261,W320','T200,S342,C65261,F650,C325,F362,D430,D400,W300,S1342,A530,C4536,W530,F600,E2453,T52152,A143,S3542,S340,W320,I200,F523,C516314,P4635,S361,P500,B240,C421,S35363,D000,A300,O242,P600,R261,D200,C000,M26532,M000,L520,I520,B200,H200',5,0,'citizen-men-s-eco-drive-primo-black-blue-chronograph-watch','',0,0,'','','','',1,1,'',''),(26,1,'Citizen Men\'s \'Eco-Drive\' Primo Black/ Blue Chronograph Watch','<p>This stylish chronograph from citizen features a detailed dial with chronograph subdials and a calendar window for excellent timekeeping ability. This stainless steel watch is finished with a comfortable polyurethane strap with a pin buckle clasp.</p>\r\n\r\n<ul>\r\n	<li>Subdials: Standard chronograph</li>\r\n	<li>Calendar: Date window at 3 o&#39;clock</li>\r\n	<li>Power reserve: 180 Days</li>\r\n	<li>Case measurements: 45 mm wide x 45 mm long x 12 mm thick</li>\r\n	<li>Strap measurements: 23 mm wide x 8.5 inches long</li>\r\n	<li>Box measurements: 4 inches wide x 4 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,P650,B420,B400,C65261,W320','T200,S342,C65261,F650,C325,F362,D430,D400,W300,S1342,A530,C4536,W530,F600,E2453,T52152,A143,S3542,S340,W320,I200,F523,C516314,P4635,S361,P500,B240,C421,S35363,D000,A300,O242,P600,R261,D200,C000,M26532,M000,L520,I520,B200,H200',6,0,'citizen-men-s-eco-drive-primo-black-blue-chronograph-watch','',0,0,'','','','',1,1,'',''),(26,1,'Citizen Men\'s \'Eco-Drive\' Primo Black/ Blue Chronograph Watch','<p>This stylish chronograph from citizen features a detailed dial with chronograph subdials and a calendar window for excellent timekeeping ability. This stainless steel watch is finished with a comfortable polyurethane strap with a pin buckle clasp.</p>\r\n\r\n<ul>\r\n	<li>Subdials: Standard chronograph</li>\r\n	<li>Calendar: Date window at 3 o&#39;clock</li>\r\n	<li>Power reserve: 180 Days</li>\r\n	<li>Case measurements: 45 mm wide x 45 mm long x 12 mm thick</li>\r\n	<li>Strap measurements: 23 mm wide x 8.5 inches long</li>\r\n	<li>Box measurements: 4 inches wide x 4 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,P650,B420,B400,C65261,W320','T200,S342,C65261,F650,C325,F362,D430,D400,W300,S1342,A530,C4536,W530,F600,E2453,T52152,A143,S3542,S340,W320,I200,F523,C516314,P4635,S361,P500,B240,C421,S35363,D000,A300,O242,P600,R261,D200,C000,M26532,M000,L520,I520,B200,H200',7,0,'citizen-men-s-eco-drive-primo-black-blue-chronograph-watch','',0,0,'','','','',1,1,'',''),(26,1,'Citizen Men\'s \'Eco-Drive\' Primo Black/ Blue Chronograph Watch','<p>This stylish chronograph from citizen features a detailed dial with chronograph subdials and a calendar window for excellent timekeeping ability. This stainless steel watch is finished with a comfortable polyurethane strap with a pin buckle clasp.</p>\r\n\r\n<ul>\r\n	<li>Subdials: Standard chronograph</li>\r\n	<li>Calendar: Date window at 3 o&#39;clock</li>\r\n	<li>Power reserve: 180 Days</li>\r\n	<li>Case measurements: 45 mm wide x 45 mm long x 12 mm thick</li>\r\n	<li>Strap measurements: 23 mm wide x 8.5 inches long</li>\r\n	<li>Box measurements: 4 inches wide x 4 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,P650,B420,B400,C65261,W320','T200,S342,C65261,F650,C325,F362,D430,D400,W300,S1342,A530,C4536,W530,F600,E2453,T52152,A143,S3542,S340,W320,I200,F523,C516314,P4635,S361,P500,B240,C421,S35363,D000,A300,O242,P600,R261,D200,C000,M26532,M000,L520,I520,B200,H200',8,0,'citizen-men-s-eco-drive-primo-black-blue-chronograph-watch','',0,0,'','','','',1,1,'',''),(26,1,'Citizen Men\'s \'Eco-Drive\' Primo Black/ Blue Chronograph Watch','<p>This stylish chronograph from citizen features a detailed dial with chronograph subdials and a calendar window for excellent timekeeping ability. This stainless steel watch is finished with a comfortable polyurethane strap with a pin buckle clasp.</p>\r\n\r\n<ul>\r\n	<li>Subdials: Standard chronograph</li>\r\n	<li>Calendar: Date window at 3 o&#39;clock</li>\r\n	<li>Power reserve: 180 Days</li>\r\n	<li>Case measurements: 45 mm wide x 45 mm long x 12 mm thick</li>\r\n	<li>Strap measurements: 23 mm wide x 8.5 inches long</li>\r\n	<li>Box measurements: 4 inches wide x 4 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,P650,B420,B400,C65261,W320','T200,S342,C65261,F650,C325,F362,D430,D400,W300,S1342,A530,C4536,W530,F600,E2453,T52152,A143,S3542,S340,W320,I200,F523,C516314,P4635,S361,P500,B240,C421,S35363,D000,A300,O242,P600,R261,D200,C000,M26532,M000,L520,I520,B200,H200',9,0,'citizen-men-s-eco-drive-primo-black-blue-chronograph-watch','',0,0,'','','','',1,1,'',''),(26,1,'Citizen Men\'s \'Eco-Drive\' Primo Black/ Blue Chronograph Watch','<p>This stylish chronograph from citizen features a detailed dial with chronograph subdials and a calendar window for excellent timekeeping ability. This stainless steel watch is finished with a comfortable polyurethane strap with a pin buckle clasp.</p>\r\n\r\n<ul>\r\n	<li>Subdials: Standard chronograph</li>\r\n	<li>Calendar: Date window at 3 o&#39;clock</li>\r\n	<li>Power reserve: 180 Days</li>\r\n	<li>Case measurements: 45 mm wide x 45 mm long x 12 mm thick</li>\r\n	<li>Strap measurements: 23 mm wide x 8.5 inches long</li>\r\n	<li>Box measurements: 4 inches wide x 4 inches long x 5 inches high</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,P650,B420,B400,C65261,W320','T200,S342,C65261,F650,C325,F362,D430,D400,W300,S1342,A530,C4536,W530,F600,E2453,T52152,A143,S3542,S340,W320,I200,F523,C516314,P4635,S361,P500,B240,C421,S35363,D000,A300,O242,P600,R261,D200,C000,M26532,M000,L520,I520,B200,H200',10,0,'citizen-men-s-eco-drive-primo-black-blue-chronograph-watch','',0,0,'','','','',1,1,'',''),(27,1,'Citizen Men\'s Eco-Drive AT2215-07E Black Leather Eco-Drive Watch with Black Dial','<p>Show off your laid-back personality with this casual Citizen timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 41 wide 12 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 25mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,A300,B420,L360,W320,W300,D400','S000,O100,Y600,L312,P62543,W300,T200,C400,C325,T512,C000,M26532,M000,S3616243,I520,L520',1,0,'citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(27,1,'Citizen Men\'s Eco-Drive AT2215-07E Black Leather Eco-Drive Watch with Black Dial','<p>Show off your laid-back personality with this casual Citizen timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 41 wide 12 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 25mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,A300,B420,L360,W320,W300,D400','S000,O100,Y600,L312,P62543,W300,T200,C400,C325,T512,C000,M26532,M000,S3616243,I520,L520',4,0,'citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(27,1,'Citizen Men\'s Eco-Drive AT2215-07E Black Leather Eco-Drive Watch with Black Dial','<p>Show off your laid-back personality with this casual Citizen timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 41 wide 12 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 25mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,A300,B420,L360,W320,W300,D400','S000,O100,Y600,L312,P62543,W300,T200,C400,C325,T512,C000,M26532,M000,S3616243,I520,L520',5,0,'citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(27,1,'Citizen Men\'s Eco-Drive AT2215-07E Black Leather Eco-Drive Watch with Black Dial','<p>Show off your laid-back personality with this casual Citizen timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 41 wide 12 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 25mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,A300,B420,L360,W320,W300,D400','S000,O100,Y600,L312,P62543,W300,T200,C400,C325,T512,C000,M26532,M000,S3616243,I520,L520',6,0,'citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(27,1,'Citizen Men\'s Eco-Drive AT2215-07E Black Leather Eco-Drive Watch with Black Dial','<p>Show off your laid-back personality with this casual Citizen timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 41 wide 12 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 25mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,A300,B420,L360,W320,W300,D400','S000,O100,Y600,L312,P62543,W300,T200,C400,C325,T512,C000,M26532,M000,S3616243,I520,L520',7,0,'citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(27,1,'Citizen Men\'s Eco-Drive AT2215-07E Black Leather Eco-Drive Watch with Black Dial','<p>Show off your laid-back personality with this casual Citizen timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 41 wide 12 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 25mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,A300,B420,L360,W320,W300,D400','S000,O100,Y600,L312,P62543,W300,T200,C400,C325,T512,C000,M26532,M000,S3616243,I520,L520',8,0,'citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(27,1,'Citizen Men\'s Eco-Drive AT2215-07E Black Leather Eco-Drive Watch with Black Dial','<p>Show off your laid-back personality with this casual Citizen timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 41 wide 12 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 25mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,A300,B420,L360,W320,W300,D400','S000,O100,Y600,L312,P62543,W300,T200,C400,C325,T512,C000,M26532,M000,S3616243,I520,L520',9,0,'citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(27,1,'Citizen Men\'s Eco-Drive AT2215-07E Black Leather Eco-Drive Watch with Black Dial','<p>Show off your laid-back personality with this casual Citizen timepiece.</p>\r\n\r\n<ul>\r\n	<li>Case measurements: 41 wide 12 mm thick</li>\r\n	<li>Strap/Bracelet measurements: 25mm wide x 8.5 inches long</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,E2361,A300,B420,L360,W320,W300,D400','S000,O100,Y600,L312,P62543,W300,T200,C400,C325,T512,C000,M26532,M000,S3616243,I520,L520',10,0,'citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','',0,0,'','','','',1,1,'',''),(28,1,'Citizen Men\'s BJ8050-08E Eco-Drive Professional Diver Black Sport Watch','<ul>\r\n	<li>Men&#39;s timepiece boasts a contemporary rubber strap</li>\r\n	<li>Citizen diver wristwatch is designed for mixed gas diving</li>\r\n	<li>With a bold design, men&#39;s casual watch is perfect for everyday wear</li>\r\n	<li>Round stainless steel case</li>\r\n	<li>Screw-down caseback</li>\r\n	<li>Black dial</li>\r\n	<li>Silvertone hands and hour markers</li>\r\n	<li>Black rubber strap</li>\r\n	<li>Pin buckle</li>\r\n	<li>6-mm non-reflective curved crystal glass</li>\r\n	<li>Screw-down crown</li>\r\n	<li>Water resistant to 300 meters</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,B200,E2361,P61254,D160,B420,S163,W320','M200,T512,B232,C53516,R160,S361,C325,D160,W6232,I200,D253,F600,M230,G000,D152,W300,B430,D250,C400,W320,P6123,E163,W600,R530,S3542,S340,C000,S635,C120,B420,D400,S41635,H532,A530,H600,M6262,P500,B240,M000,N614231,C613,C6234,G420,C650,W360,R2353,T000,M362',1,0,'citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','',0,0,'','','','',1,1,'',''),(28,1,'Citizen Men\'s BJ8050-08E Eco-Drive Professional Diver Black Sport Watch','<ul>\r\n	<li>Men&#39;s timepiece boasts a contemporary rubber strap</li>\r\n	<li>Citizen diver wristwatch is designed for mixed gas diving</li>\r\n	<li>With a bold design, men&#39;s casual watch is perfect for everyday wear</li>\r\n	<li>Round stainless steel case</li>\r\n	<li>Screw-down caseback</li>\r\n	<li>Black dial</li>\r\n	<li>Silvertone hands and hour markers</li>\r\n	<li>Black rubber strap</li>\r\n	<li>Pin buckle</li>\r\n	<li>6-mm non-reflective curved crystal glass</li>\r\n	<li>Screw-down crown</li>\r\n	<li>Water resistant to 300 meters</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,B200,E2361,P61254,D160,B420,S163,W320','M200,T512,B232,C53516,R160,S361,C325,D160,W6232,I200,D253,F600,M230,G000,D152,W300,B430,D250,C400,W320,P6123,E163,W600,R530,S3542,S340,C000,S635,C120,B420,D400,S41635,H532,A530,H600,M6262,P500,B240,M000,N614231,C613,C6234,G420,C650,W360,R2353,T000,M362',4,0,'citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','',0,0,'','','','',1,1,'',''),(28,1,'Citizen Men\'s BJ8050-08E Eco-Drive Professional Diver Black Sport Watch','<ul>\r\n	<li>Men&#39;s timepiece boasts a contemporary rubber strap</li>\r\n	<li>Citizen diver wristwatch is designed for mixed gas diving</li>\r\n	<li>With a bold design, men&#39;s casual watch is perfect for everyday wear</li>\r\n	<li>Round stainless steel case</li>\r\n	<li>Screw-down caseback</li>\r\n	<li>Black dial</li>\r\n	<li>Silvertone hands and hour markers</li>\r\n	<li>Black rubber strap</li>\r\n	<li>Pin buckle</li>\r\n	<li>6-mm non-reflective curved crystal glass</li>\r\n	<li>Screw-down crown</li>\r\n	<li>Water resistant to 300 meters</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,B200,E2361,P61254,D160,B420,S163,W320','M200,T512,B232,C53516,R160,S361,C325,D160,W6232,I200,D253,F600,M230,G000,D152,W300,B430,D250,C400,W320,P6123,E163,W600,R530,S3542,S340,C000,S635,C120,B420,D400,S41635,H532,A530,H600,M6262,P500,B240,M000,N614231,C613,C6234,G420,C650,W360,R2353,T000,M362',5,0,'citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','',0,0,'','','','',1,1,'',''),(28,1,'Citizen Men\'s BJ8050-08E Eco-Drive Professional Diver Black Sport Watch','<ul>\r\n	<li>Men&#39;s timepiece boasts a contemporary rubber strap</li>\r\n	<li>Citizen diver wristwatch is designed for mixed gas diving</li>\r\n	<li>With a bold design, men&#39;s casual watch is perfect for everyday wear</li>\r\n	<li>Round stainless steel case</li>\r\n	<li>Screw-down caseback</li>\r\n	<li>Black dial</li>\r\n	<li>Silvertone hands and hour markers</li>\r\n	<li>Black rubber strap</li>\r\n	<li>Pin buckle</li>\r\n	<li>6-mm non-reflective curved crystal glass</li>\r\n	<li>Screw-down crown</li>\r\n	<li>Water resistant to 300 meters</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,B200,E2361,P61254,D160,B420,S163,W320','M200,T512,B232,C53516,R160,S361,C325,D160,W6232,I200,D253,F600,M230,G000,D152,W300,B430,D250,C400,W320,P6123,E163,W600,R530,S3542,S340,C000,S635,C120,B420,D400,S41635,H532,A530,H600,M6262,P500,B240,M000,N614231,C613,C6234,G420,C650,W360,R2353,T000,M362',6,0,'citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','',0,0,'','','','',1,1,'',''),(28,1,'Citizen Men\'s BJ8050-08E Eco-Drive Professional Diver Black Sport Watch','<ul>\r\n	<li>Men&#39;s timepiece boasts a contemporary rubber strap</li>\r\n	<li>Citizen diver wristwatch is designed for mixed gas diving</li>\r\n	<li>With a bold design, men&#39;s casual watch is perfect for everyday wear</li>\r\n	<li>Round stainless steel case</li>\r\n	<li>Screw-down caseback</li>\r\n	<li>Black dial</li>\r\n	<li>Silvertone hands and hour markers</li>\r\n	<li>Black rubber strap</li>\r\n	<li>Pin buckle</li>\r\n	<li>6-mm non-reflective curved crystal glass</li>\r\n	<li>Screw-down crown</li>\r\n	<li>Water resistant to 300 meters</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,B200,E2361,P61254,D160,B420,S163,W320','M200,T512,B232,C53516,R160,S361,C325,D160,W6232,I200,D253,F600,M230,G000,D152,W300,B430,D250,C400,W320,P6123,E163,W600,R530,S3542,S340,C000,S635,C120,B420,D400,S41635,H532,A530,H600,M6262,P500,B240,M000,N614231,C613,C6234,G420,C650,W360,R2353,T000,M362',7,0,'citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','',0,0,'','','','',1,1,'',''),(28,1,'Citizen Men\'s BJ8050-08E Eco-Drive Professional Diver Black Sport Watch','<ul>\r\n	<li>Men&#39;s timepiece boasts a contemporary rubber strap</li>\r\n	<li>Citizen diver wristwatch is designed for mixed gas diving</li>\r\n	<li>With a bold design, men&#39;s casual watch is perfect for everyday wear</li>\r\n	<li>Round stainless steel case</li>\r\n	<li>Screw-down caseback</li>\r\n	<li>Black dial</li>\r\n	<li>Silvertone hands and hour markers</li>\r\n	<li>Black rubber strap</li>\r\n	<li>Pin buckle</li>\r\n	<li>6-mm non-reflective curved crystal glass</li>\r\n	<li>Screw-down crown</li>\r\n	<li>Water resistant to 300 meters</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,B200,E2361,P61254,D160,B420,S163,W320','M200,T512,B232,C53516,R160,S361,C325,D160,W6232,I200,D253,F600,M230,G000,D152,W300,B430,D250,C400,W320,P6123,E163,W600,R530,S3542,S340,C000,S635,C120,B420,D400,S41635,H532,A530,H600,M6262,P500,B240,M000,N614231,C613,C6234,G420,C650,W360,R2353,T000,M362',8,0,'citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','',0,0,'','','','',1,1,'',''),(28,1,'Citizen Men\'s BJ8050-08E Eco-Drive Professional Diver Black Sport Watch','<ul>\r\n	<li>Men&#39;s timepiece boasts a contemporary rubber strap</li>\r\n	<li>Citizen diver wristwatch is designed for mixed gas diving</li>\r\n	<li>With a bold design, men&#39;s casual watch is perfect for everyday wear</li>\r\n	<li>Round stainless steel case</li>\r\n	<li>Screw-down caseback</li>\r\n	<li>Black dial</li>\r\n	<li>Silvertone hands and hour markers</li>\r\n	<li>Black rubber strap</li>\r\n	<li>Pin buckle</li>\r\n	<li>6-mm non-reflective curved crystal glass</li>\r\n	<li>Screw-down crown</li>\r\n	<li>Water resistant to 300 meters</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,B200,E2361,P61254,D160,B420,S163,W320','M200,T512,B232,C53516,R160,S361,C325,D160,W6232,I200,D253,F600,M230,G000,D152,W300,B430,D250,C400,W320,P6123,E163,W600,R530,S3542,S340,C000,S635,C120,B420,D400,S41635,H532,A530,H600,M6262,P500,B240,M000,N614231,C613,C6234,G420,C650,W360,R2353,T000,M362',9,0,'citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','',0,0,'','','','',1,1,'',''),(28,1,'Citizen Men\'s BJ8050-08E Eco-Drive Professional Diver Black Sport Watch','<ul>\r\n	<li>Men&#39;s timepiece boasts a contemporary rubber strap</li>\r\n	<li>Citizen diver wristwatch is designed for mixed gas diving</li>\r\n	<li>With a bold design, men&#39;s casual watch is perfect for everyday wear</li>\r\n	<li>Round stainless steel case</li>\r\n	<li>Screw-down caseback</li>\r\n	<li>Black dial</li>\r\n	<li>Silvertone hands and hour markers</li>\r\n	<li>Black rubber strap</li>\r\n	<li>Pin buckle</li>\r\n	<li>6-mm non-reflective curved crystal glass</li>\r\n	<li>Screw-down crown</li>\r\n	<li>Water resistant to 300 meters</li>\r\n</ul>\r\n','',0,'','','','','','C325,M200,B200,E2361,P61254,D160,B420,S163,W320','M200,T512,B232,C53516,R160,S361,C325,D160,W6232,I200,D253,F600,M230,G000,D152,W300,B430,D250,C400,W320,P6123,E163,W600,R530,S3542,S340,C000,S635,C120,B420,D400,S41635,H532,A530,H600,M6262,P500,B240,M000,N614231,C613,C6234,G420,C650,W360,R2353,T000,M362',10,0,'citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','',0,0,'','','','',1,1,'',''),(29,1,'Royal London 41003-03','<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\">\r\n	<tbody>\r\n <tr>\r\n <td>Gender</td>\r\n <td>&nbsp;:&nbsp;Gents</td>\r\n </tr>\r\n <tr>\r\n <td>Movement</td>\r\n <td>&nbsp;:&nbsp;Date, Chronograph</td>\r\n </tr>\r\n <tr>\r\n <td>Dial colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Indication</td>\r\n <td>&nbsp;:&nbsp;Baton</td>\r\n </tr>\r\n <tr>\r\n <td>Case material</td>\r\n <td>&nbsp;:&nbsp;PVD Black</td>\r\n </tr>\r\n <tr>\r\n <td>ATM</td>\r\n <td>&nbsp;:&nbsp;100 metres</td>\r\n </tr>\r\n <tr>\r\n <td>Band material</td>\r\n <td>&nbsp;:&nbsp;Leather</td>\r\n </tr>\r\n <tr>\r\n <td>Band colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Case width (mm)</td>\r\n <td>&nbsp;:&nbsp;44.5</td>\r\n </tr>\r\n <tr>\r\n <td>Case height (mm)</td>\r\n <td>&nbsp;:&nbsp;44.0</td>\r\n </tr>\r\n <tr>\r\n <td>Case thickness (mm)</td>\r\n <td>&nbsp;:&nbsp;13.30</td>\r\n </tr>\r\n	</tbody>\r\n</table>\r\n','',0,'','','','','','R400,L535','G536,N12151212532,M153,N12151213,C65261,D400,C460,N121512142,I53235,N121512135,C000,M364,B420,A350,N1215121,M362,B530,N1215121436,W300,M000,H230,T252',1,0,'chasy-royal-london-41003-03','',0,0,'','','','',1,1,'',''),(29,1,'Royal London 41003-03','<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\">\r\n	<tbody>\r\n <tr>\r\n <td>Gender</td>\r\n <td>&nbsp;:&nbsp;Gents</td>\r\n </tr>\r\n <tr>\r\n <td>Movement</td>\r\n <td>&nbsp;:&nbsp;Date, Chronograph</td>\r\n </tr>\r\n <tr>\r\n <td>Dial colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Indication</td>\r\n <td>&nbsp;:&nbsp;Baton</td>\r\n </tr>\r\n <tr>\r\n <td>Case material</td>\r\n <td>&nbsp;:&nbsp;PVD Black</td>\r\n </tr>\r\n <tr>\r\n <td>ATM</td>\r\n <td>&nbsp;:&nbsp;100 metres</td>\r\n </tr>\r\n <tr>\r\n <td>Band material</td>\r\n <td>&nbsp;:&nbsp;Leather</td>\r\n </tr>\r\n <tr>\r\n <td>Band colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Case width (mm)</td>\r\n <td>&nbsp;:&nbsp;44.5</td>\r\n </tr>\r\n <tr>\r\n <td>Case height (mm)</td>\r\n <td>&nbsp;:&nbsp;44.0</td>\r\n </tr>\r\n <tr>\r\n <td>Case thickness (mm)</td>\r\n <td>&nbsp;:&nbsp;13.30</td>\r\n </tr>\r\n	</tbody>\r\n</table>\r\n','',0,'','','','','','R400,L535','G536,N12151212532,M153,N12151213,C65261,D400,C460,N121512142,I53235,N121512135,C000,M364,B420,A350,N1215121,M362,B530,N1215121436,W300,M000,H230,T252',4,0,'chasy-royal-london-41003-03','',0,0,'','','','',1,1,'',''),(29,1,'Royal London 41003-03','<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\">\r\n	<tbody>\r\n <tr>\r\n <td>Gender</td>\r\n <td>&nbsp;:&nbsp;Gents</td>\r\n </tr>\r\n <tr>\r\n <td>Movement</td>\r\n <td>&nbsp;:&nbsp;Date, Chronograph</td>\r\n </tr>\r\n <tr>\r\n <td>Dial colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Indication</td>\r\n <td>&nbsp;:&nbsp;Baton</td>\r\n </tr>\r\n <tr>\r\n <td>Case material</td>\r\n <td>&nbsp;:&nbsp;PVD Black</td>\r\n </tr>\r\n <tr>\r\n <td>ATM</td>\r\n <td>&nbsp;:&nbsp;100 metres</td>\r\n </tr>\r\n <tr>\r\n <td>Band material</td>\r\n <td>&nbsp;:&nbsp;Leather</td>\r\n </tr>\r\n <tr>\r\n <td>Band colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Case width (mm)</td>\r\n <td>&nbsp;:&nbsp;44.5</td>\r\n </tr>\r\n <tr>\r\n <td>Case height (mm)</td>\r\n <td>&nbsp;:&nbsp;44.0</td>\r\n </tr>\r\n <tr>\r\n <td>Case thickness (mm)</td>\r\n <td>&nbsp;:&nbsp;13.30</td>\r\n </tr>\r\n	</tbody>\r\n</table>\r\n','',0,'','','','','','R400,L535','G536,N12151212532,M153,N12151213,C65261,D400,C460,N121512142,I53235,N121512135,C000,M364,B420,A350,N1215121,M362,B530,N1215121436,W300,M000,H230,T252',5,0,'chasy-royal-london-41003-03','',0,0,'','','','',1,1,'',''),(29,1,'Royal London 41003-03','<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\">\r\n	<tbody>\r\n <tr>\r\n <td>Gender</td>\r\n <td>&nbsp;:&nbsp;Gents</td>\r\n </tr>\r\n <tr>\r\n <td>Movement</td>\r\n <td>&nbsp;:&nbsp;Date, Chronograph</td>\r\n </tr>\r\n <tr>\r\n <td>Dial colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Indication</td>\r\n <td>&nbsp;:&nbsp;Baton</td>\r\n </tr>\r\n <tr>\r\n <td>Case material</td>\r\n <td>&nbsp;:&nbsp;PVD Black</td>\r\n </tr>\r\n <tr>\r\n <td>ATM</td>\r\n <td>&nbsp;:&nbsp;100 metres</td>\r\n </tr>\r\n <tr>\r\n <td>Band material</td>\r\n <td>&nbsp;:&nbsp;Leather</td>\r\n </tr>\r\n <tr>\r\n <td>Band colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Case width (mm)</td>\r\n <td>&nbsp;:&nbsp;44.5</td>\r\n </tr>\r\n <tr>\r\n <td>Case height (mm)</td>\r\n <td>&nbsp;:&nbsp;44.0</td>\r\n </tr>\r\n <tr>\r\n <td>Case thickness (mm)</td>\r\n <td>&nbsp;:&nbsp;13.30</td>\r\n </tr>\r\n	</tbody>\r\n</table>\r\n','',0,'','','','','','R400,L535','G536,N12151212532,M153,N12151213,C65261,D400,C460,N121512142,I53235,N121512135,C000,M364,B420,A350,N1215121,M362,B530,N1215121436,W300,M000,H230,T252',6,0,'chasy-royal-london-41003-03','',0,0,'','','','',1,1,'',''),(29,1,'Royal London 41003-03','<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\">\r\n	<tbody>\r\n <tr>\r\n <td>Gender</td>\r\n <td>&nbsp;:&nbsp;Gents</td>\r\n </tr>\r\n <tr>\r\n <td>Movement</td>\r\n <td>&nbsp;:&nbsp;Date, Chronograph</td>\r\n </tr>\r\n <tr>\r\n <td>Dial colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Indication</td>\r\n <td>&nbsp;:&nbsp;Baton</td>\r\n </tr>\r\n <tr>\r\n <td>Case material</td>\r\n <td>&nbsp;:&nbsp;PVD Black</td>\r\n </tr>\r\n <tr>\r\n <td>ATM</td>\r\n <td>&nbsp;:&nbsp;100 metres</td>\r\n </tr>\r\n <tr>\r\n <td>Band material</td>\r\n <td>&nbsp;:&nbsp;Leather</td>\r\n </tr>\r\n <tr>\r\n <td>Band colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Case width (mm)</td>\r\n <td>&nbsp;:&nbsp;44.5</td>\r\n </tr>\r\n <tr>\r\n <td>Case height (mm)</td>\r\n <td>&nbsp;:&nbsp;44.0</td>\r\n </tr>\r\n <tr>\r\n <td>Case thickness (mm)</td>\r\n <td>&nbsp;:&nbsp;13.30</td>\r\n </tr>\r\n	</tbody>\r\n</table>\r\n','',0,'','','','','','R400,L535','G536,N12151212532,M153,N12151213,C65261,D400,C460,N121512142,I53235,N121512135,C000,M364,B420,A350,N1215121,M362,B530,N1215121436,W300,M000,H230,T252',7,0,'chasy-royal-london-41003-03','',0,0,'','','','',1,1,'',''),(29,1,'Royal London 41003-03','<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\">\r\n	<tbody>\r\n <tr>\r\n <td>Gender</td>\r\n <td>&nbsp;:&nbsp;Gents</td>\r\n </tr>\r\n <tr>\r\n <td>Movement</td>\r\n <td>&nbsp;:&nbsp;Date, Chronograph</td>\r\n </tr>\r\n <tr>\r\n <td>Dial colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Indication</td>\r\n <td>&nbsp;:&nbsp;Baton</td>\r\n </tr>\r\n <tr>\r\n <td>Case material</td>\r\n <td>&nbsp;:&nbsp;PVD Black</td>\r\n </tr>\r\n <tr>\r\n <td>ATM</td>\r\n <td>&nbsp;:&nbsp;100 metres</td>\r\n </tr>\r\n <tr>\r\n <td>Band material</td>\r\n <td>&nbsp;:&nbsp;Leather</td>\r\n </tr>\r\n <tr>\r\n <td>Band colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Case width (mm)</td>\r\n <td>&nbsp;:&nbsp;44.5</td>\r\n </tr>\r\n <tr>\r\n <td>Case height (mm)</td>\r\n <td>&nbsp;:&nbsp;44.0</td>\r\n </tr>\r\n <tr>\r\n <td>Case thickness (mm)</td>\r\n <td>&nbsp;:&nbsp;13.30</td>\r\n </tr>\r\n	</tbody>\r\n</table>\r\n','',0,'','','','','','R400,L535','G536,N12151212532,M153,N12151213,C65261,D400,C460,N121512142,I53235,N121512135,C000,M364,B420,A350,N1215121,M362,B530,N1215121436,W300,M000,H230,T252',8,0,'chasy-royal-london-41003-03','',0,0,'','','','',1,1,'',''),(29,1,'Royal London 41003-03','<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\">\r\n	<tbody>\r\n <tr>\r\n <td>Gender</td>\r\n <td>&nbsp;:&nbsp;Gents</td>\r\n </tr>\r\n <tr>\r\n <td>Movement</td>\r\n <td>&nbsp;:&nbsp;Date, Chronograph</td>\r\n </tr>\r\n <tr>\r\n <td>Dial colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Indication</td>\r\n <td>&nbsp;:&nbsp;Baton</td>\r\n </tr>\r\n <tr>\r\n <td>Case material</td>\r\n <td>&nbsp;:&nbsp;PVD Black</td>\r\n </tr>\r\n <tr>\r\n <td>ATM</td>\r\n <td>&nbsp;:&nbsp;100 metres</td>\r\n </tr>\r\n <tr>\r\n <td>Band material</td>\r\n <td>&nbsp;:&nbsp;Leather</td>\r\n </tr>\r\n <tr>\r\n <td>Band colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Case width (mm)</td>\r\n <td>&nbsp;:&nbsp;44.5</td>\r\n </tr>\r\n <tr>\r\n <td>Case height (mm)</td>\r\n <td>&nbsp;:&nbsp;44.0</td>\r\n </tr>\r\n <tr>\r\n <td>Case thickness (mm)</td>\r\n <td>&nbsp;:&nbsp;13.30</td>\r\n </tr>\r\n	</tbody>\r\n</table>\r\n','',0,'','','','','','R400,L535','G536,N12151212532,M153,N12151213,C65261,D400,C460,N121512142,I53235,N121512135,C000,M364,B420,A350,N1215121,M362,B530,N1215121436,W300,M000,H230,T252',9,0,'chasy-royal-london-41003-03','',0,0,'','','','',1,1,'',''),(29,1,'Royal London 41003-03','<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\">\r\n	<tbody>\r\n <tr>\r\n <td>Gender</td>\r\n <td>&nbsp;:&nbsp;Gents</td>\r\n </tr>\r\n <tr>\r\n <td>Movement</td>\r\n <td>&nbsp;:&nbsp;Date, Chronograph</td>\r\n </tr>\r\n <tr>\r\n <td>Dial colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Indication</td>\r\n <td>&nbsp;:&nbsp;Baton</td>\r\n </tr>\r\n <tr>\r\n <td>Case material</td>\r\n <td>&nbsp;:&nbsp;PVD Black</td>\r\n </tr>\r\n <tr>\r\n <td>ATM</td>\r\n <td>&nbsp;:&nbsp;100 metres</td>\r\n </tr>\r\n <tr>\r\n <td>Band material</td>\r\n <td>&nbsp;:&nbsp;Leather</td>\r\n </tr>\r\n <tr>\r\n <td>Band colour</td>\r\n <td>&nbsp;:&nbsp;Black</td>\r\n </tr>\r\n <tr>\r\n <td>Case width (mm)</td>\r\n <td>&nbsp;:&nbsp;44.5</td>\r\n </tr>\r\n <tr>\r\n <td>Case height (mm)</td>\r\n <td>&nbsp;:&nbsp;44.0</td>\r\n </tr>\r\n <tr>\r\n <td>Case thickness (mm)</td>\r\n <td>&nbsp;:&nbsp;13.30</td>\r\n </tr>\r\n	</tbody>\r\n</table>\r\n','',0,'','','','','','R400,L535','G536,N12151212532,M153,N12151213,C65261,D400,C460,N121512142,I53235,N121512135,C000,M364,B420,A350,N1215121,M362,B530,N1215121436,W300,M000,H230,T252',10,0,'chasy-royal-london-41003-03','',0,0,'','','','',1,1,'',''),(30,1,'Senator Task Mesh Back Chair, Fully Adjustable, Red & Black','<ul>\r\n	<li>Senator Mesh Office Chair</li>\r\n	<li>From quality British manufacturer&nbsp;Senator</li>\r\n	<li>Fully Adjustable</li>\r\n	<li>Operator / Task Chair</li>\r\n	<li>Red FabricSeat</li>\r\n	<li>Black mesh back</li>\r\n	<li>Adjustable armrests</li>\r\n	<li>Adjustable back height</li>\r\n	<li>Forward tilt</li>\r\n	<li>Adjustable seat height</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Suitable for home or office use</li>\r\n</ul>\r\n','',0,'','','','','','S536,T200,M200,B200,C600,F400,A32314,R300,B420','S536,M200,O120,C600,F650,Q430,B632,M123651212536,F400,A32314,O1636,T200,R300,F623,B420,B200,A656232,H230,F630,T430,S300,S140,O500,C360,W420,S314,F600,H500,O600,U200',1,0,'workwell-meeting-chair-4-star-fixed-mwt14','',0,0,'','','','',1,1,'',''),(30,1,'Senator Task Mesh Back Chair, Fully Adjustable, Red & Black','<ul>\r\n	<li>Senator Mesh Office Chair</li>\r\n	<li>From quality British manufacturer&nbsp;Senator</li>\r\n	<li>Fully Adjustable</li>\r\n	<li>Operator / Task Chair</li>\r\n	<li>Red FabricSeat</li>\r\n	<li>Black mesh back</li>\r\n	<li>Adjustable armrests</li>\r\n	<li>Adjustable back height</li>\r\n	<li>Forward tilt</li>\r\n	<li>Adjustable seat height</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Suitable for home or office use</li>\r\n</ul>\r\n','',0,'','','','','','S536,T200,M200,B200,C600,F400,A32314,R300,B420','S536,M200,O120,C600,F650,Q430,B632,M123651212536,F400,A32314,O1636,T200,R300,F623,B420,B200,A656232,H230,F630,T430,S300,S140,O500,C360,W420,S314,F600,H500,O600,U200',4,0,'workwell-meeting-chair-4-star-fixed-mwt14','',0,0,'','','','',1,1,'',''),(30,1,'Senator Task Mesh Back Chair, Fully Adjustable, Red & Black','<ul>\r\n	<li>Senator Mesh Office Chair</li>\r\n	<li>From quality British manufacturer&nbsp;Senator</li>\r\n	<li>Fully Adjustable</li>\r\n	<li>Operator / Task Chair</li>\r\n	<li>Red FabricSeat</li>\r\n	<li>Black mesh back</li>\r\n	<li>Adjustable armrests</li>\r\n	<li>Adjustable back height</li>\r\n	<li>Forward tilt</li>\r\n	<li>Adjustable seat height</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Suitable for home or office use</li>\r\n</ul>\r\n','',0,'','','','','','S536,T200,M200,B200,C600,F400,A32314,R300,B420','S536,M200,O120,C600,F650,Q430,B632,M123651212536,F400,A32314,O1636,T200,R300,F623,B420,B200,A656232,H230,F630,T430,S300,S140,O500,C360,W420,S314,F600,H500,O600,U200',5,0,'workwell-meeting-chair-4-star-fixed-mwt14','',0,0,'','','','',1,1,'',''),(30,1,'Senator Task Mesh Back Chair, Fully Adjustable, Red & Black','<ul>\r\n	<li>Senator Mesh Office Chair</li>\r\n	<li>From quality British manufacturer&nbsp;Senator</li>\r\n	<li>Fully Adjustable</li>\r\n	<li>Operator / Task Chair</li>\r\n	<li>Red FabricSeat</li>\r\n	<li>Black mesh back</li>\r\n	<li>Adjustable armrests</li>\r\n	<li>Adjustable back height</li>\r\n	<li>Forward tilt</li>\r\n	<li>Adjustable seat height</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Suitable for home or office use</li>\r\n</ul>\r\n','',0,'','','','','','S536,T200,M200,B200,C600,F400,A32314,R300,B420','S536,M200,O120,C600,F650,Q430,B632,M123651212536,F400,A32314,O1636,T200,R300,F623,B420,B200,A656232,H230,F630,T430,S300,S140,O500,C360,W420,S314,F600,H500,O600,U200',6,0,'workwell-meeting-chair-4-star-fixed-mwt14','',0,0,'','','','',1,1,'',''),(30,1,'Senator Task Mesh Back Chair, Fully Adjustable, Red & Black','<ul>\r\n	<li>Senator Mesh Office Chair</li>\r\n	<li>From quality British manufacturer&nbsp;Senator</li>\r\n	<li>Fully Adjustable</li>\r\n	<li>Operator / Task Chair</li>\r\n	<li>Red FabricSeat</li>\r\n	<li>Black mesh back</li>\r\n	<li>Adjustable armrests</li>\r\n	<li>Adjustable back height</li>\r\n	<li>Forward tilt</li>\r\n	<li>Adjustable seat height</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Suitable for home or office use</li>\r\n</ul>\r\n','',0,'','','','','','S536,T200,M200,B200,C600,F400,A32314,R300,B420','S536,M200,O120,C600,F650,Q430,B632,M123651212536,F400,A32314,O1636,T200,R300,F623,B420,B200,A656232,H230,F630,T430,S300,S140,O500,C360,W420,S314,F600,H500,O600,U200',7,0,'workwell-meeting-chair-4-star-fixed-mwt14','',0,0,'','','','',1,1,'',''),(30,1,'Senator Task Mesh Back Chair, Fully Adjustable, Red & Black','<ul>\r\n	<li>Senator Mesh Office Chair</li>\r\n	<li>From quality British manufacturer&nbsp;Senator</li>\r\n	<li>Fully Adjustable</li>\r\n	<li>Operator / Task Chair</li>\r\n	<li>Red FabricSeat</li>\r\n	<li>Black mesh back</li>\r\n	<li>Adjustable armrests</li>\r\n	<li>Adjustable back height</li>\r\n	<li>Forward tilt</li>\r\n	<li>Adjustable seat height</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Suitable for home or office use</li>\r\n</ul>\r\n','',0,'','','','','','S536,T200,M200,B200,C600,F400,A32314,R300,B420','S536,M200,O120,C600,F650,Q430,B632,M123651212536,F400,A32314,O1636,T200,R300,F623,B420,B200,A656232,H230,F630,T430,S300,S140,O500,C360,W420,S314,F600,H500,O600,U200',8,0,'workwell-meeting-chair-4-star-fixed-mwt14','',0,0,'','','','',1,1,'',''),(30,1,'Senator Task Mesh Back Chair, Fully Adjustable, Red & Black','<ul>\r\n	<li>Senator Mesh Office Chair</li>\r\n	<li>From quality British manufacturer&nbsp;Senator</li>\r\n	<li>Fully Adjustable</li>\r\n	<li>Operator / Task Chair</li>\r\n	<li>Red FabricSeat</li>\r\n	<li>Black mesh back</li>\r\n	<li>Adjustable armrests</li>\r\n	<li>Adjustable back height</li>\r\n	<li>Forward tilt</li>\r\n	<li>Adjustable seat height</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Suitable for home or office use</li>\r\n</ul>\r\n','',0,'','','','','','S536,T200,M200,B200,C600,F400,A32314,R300,B420','S536,M200,O120,C600,F650,Q430,B632,M123651212536,F400,A32314,O1636,T200,R300,F623,B420,B200,A656232,H230,F630,T430,S300,S140,O500,C360,W420,S314,F600,H500,O600,U200',9,0,'workwell-meeting-chair-4-star-fixed-mwt14','',0,0,'','','','',1,1,'',''),(30,1,'Senator Task Mesh Back Chair, Fully Adjustable, Red & Black','<ul>\r\n	<li>Senator Mesh Office Chair</li>\r\n	<li>From quality British manufacturer&nbsp;Senator</li>\r\n	<li>Fully Adjustable</li>\r\n	<li>Operator / Task Chair</li>\r\n	<li>Red FabricSeat</li>\r\n	<li>Black mesh back</li>\r\n	<li>Adjustable armrests</li>\r\n	<li>Adjustable back height</li>\r\n	<li>Forward tilt</li>\r\n	<li>Adjustable seat height</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Suitable for home or office use</li>\r\n</ul>\r\n','',0,'','','','','','S536,T200,M200,B200,C600,F400,A32314,R300,B420','S536,M200,O120,C600,F650,Q430,B632,M123651212536,F400,A32314,O1636,T200,R300,F623,B420,B200,A656232,H230,F630,T430,S300,S140,O500,C360,W420,S314,F600,H500,O600,U200',10,0,'workwell-meeting-chair-4-star-fixed-mwt14','',0,0,'','','','',1,1,'',''),(31,1,'WorkWell Meeting Chair Cantilever MWT15','<p><strong>Height:</strong>&nbsp;914mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;603mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;600mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;464mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;8.85kg</p>\r\n','',0,'','','','','','W624,M352,C600,C53416,M300','H2351215,W351215,D1351215,S300,W2351212',1,0,'workwell-meeting-chair-cantilever-mwt15','',0,0,'','','','',1,1,'',''),(31,1,'WorkWell Meeting Chair Cantilever MWT15','<p><strong>Height:</strong>&nbsp;914mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;603mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;600mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;464mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;8.85kg</p>\r\n','',0,'','','','','','W624,M352,C600,C53416,M300','H2351215,W351215,D1351215,S300,W2351212',4,0,'workwell-meeting-chair-cantilever-mwt15','',0,0,'','','','',1,1,'',''),(31,1,'WorkWell Meeting Chair Cantilever MWT15','<p><strong>Height:</strong>&nbsp;914mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;603mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;600mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;464mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;8.85kg</p>\r\n','',0,'','','','','','W624,M352,C600,C53416,M300','H2351215,W351215,D1351215,S300,W2351212',5,0,'workwell-meeting-chair-cantilever-mwt15','',0,0,'','','','',1,1,'',''),(31,1,'WorkWell Meeting Chair Cantilever MWT15','<p><strong>Height:</strong>&nbsp;914mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;603mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;600mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;464mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;8.85kg</p>\r\n','',0,'','','','','','W624,M352,C600,C53416,M300','H2351215,W351215,D1351215,S300,W2351212',6,0,'workwell-meeting-chair-cantilever-mwt15','',0,0,'','','','',1,1,'',''),(31,1,'WorkWell Meeting Chair Cantilever MWT15','<p><strong>Height:</strong>&nbsp;914mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;603mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;600mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;464mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;8.85kg</p>\r\n','',0,'','','','','','W624,M352,C600,C53416,M300','H2351215,W351215,D1351215,S300,W2351212',7,0,'workwell-meeting-chair-cantilever-mwt15','',0,0,'','','','',1,1,'',''),(31,1,'WorkWell Meeting Chair Cantilever MWT15','<p><strong>Height:</strong>&nbsp;914mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;603mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;600mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;464mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;8.85kg</p>\r\n','',0,'','','','','','W624,M352,C600,C53416,M300','H2351215,W351215,D1351215,S300,W2351212',8,0,'workwell-meeting-chair-cantilever-mwt15','',0,0,'','','','',1,1,'',''),(31,1,'WorkWell Meeting Chair Cantilever MWT15','<p><strong>Height:</strong>&nbsp;914mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;603mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;600mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;464mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;8.85kg</p>\r\n','',0,'','','','','','W624,M352,C600,C53416,M300','H2351215,W351215,D1351215,S300,W2351212',9,0,'workwell-meeting-chair-cantilever-mwt15','',0,0,'','','','',1,1,'',''),(31,1,'WorkWell Meeting Chair Cantilever MWT15','<p><strong>Height:</strong>&nbsp;914mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;603mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;600mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;464mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;8.85kg</p>\r\n','',0,'','','','','','W624,M352,C600,C53416,M300','H2351215,W351215,D1351215,S300,W2351212',10,0,'workwell-meeting-chair-cantilever-mwt15','',0,0,'','','','',1,1,'',''),(32,1,'WorkWell Meeting Chair 5-Star Castor Base MWT13','<p><strong>Height:</strong>&nbsp;867-997mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;430-560mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;10kg</p>\r\n','',0,'','','','','','W624,M352,C600,S360,C360,B200,M300','H2351215,W351215,D1351215,S300,W2351212',1,0,'workwell-meeting-chair-5-star-castor-base-mwt13','',0,0,'','','','',1,1,'',''),(32,1,'WorkWell Meeting Chair 5-Star Castor Base MWT13','<p><strong>Height:</strong>&nbsp;867-997mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;430-560mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;10kg</p>\r\n','',0,'','','','','','W624,M352,C600,S360,C360,B200,M300','H2351215,W351215,D1351215,S300,W2351212',4,0,'workwell-meeting-chair-5-star-castor-base-mwt13','',0,0,'','','','',1,1,'',''),(32,1,'WorkWell Meeting Chair 5-Star Castor Base MWT13','<p><strong>Height:</strong>&nbsp;867-997mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;430-560mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;10kg</p>\r\n','',0,'','','','','','W624,M352,C600,S360,C360,B200,M300','H2351215,W351215,D1351215,S300,W2351212',5,0,'workwell-meeting-chair-5-star-castor-base-mwt13','',0,0,'','','','',1,1,'',''),(32,1,'WorkWell Meeting Chair 5-Star Castor Base MWT13','<p><strong>Height:</strong>&nbsp;867-997mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;430-560mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;10kg</p>\r\n','',0,'','','','','','W624,M352,C600,S360,C360,B200,M300','H2351215,W351215,D1351215,S300,W2351212',6,0,'workwell-meeting-chair-5-star-castor-base-mwt13','',0,0,'','','','',1,1,'',''),(32,1,'WorkWell Meeting Chair 5-Star Castor Base MWT13','<p><strong>Height:</strong>&nbsp;867-997mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;430-560mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;10kg</p>\r\n','',0,'','','','','','W624,M352,C600,S360,C360,B200,M300','H2351215,W351215,D1351215,S300,W2351212',7,0,'workwell-meeting-chair-5-star-castor-base-mwt13','',0,0,'','','','',1,1,'',''),(32,1,'WorkWell Meeting Chair 5-Star Castor Base MWT13','<p><strong>Height:</strong>&nbsp;867-997mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;430-560mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;10kg</p>\r\n','',0,'','','','','','W624,M352,C600,S360,C360,B200,M300','H2351215,W351215,D1351215,S300,W2351212',8,0,'workwell-meeting-chair-5-star-castor-base-mwt13','',0,0,'','','','',1,1,'',''),(32,1,'WorkWell Meeting Chair 5-Star Castor Base MWT13','<p><strong>Height:</strong>&nbsp;867-997mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;430-560mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;10kg</p>\r\n','',0,'','','','','','W624,M352,C600,S360,C360,B200,M300','H2351215,W351215,D1351215,S300,W2351212',9,0,'workwell-meeting-chair-5-star-castor-base-mwt13','',0,0,'','','','',1,1,'',''),(32,1,'WorkWell Meeting Chair 5-Star Castor Base MWT13','<p><strong>Height:</strong>&nbsp;867-997mm</p>\r\n\r\n<p><strong>Width:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Depth:</strong>&nbsp;636mm</p>\r\n\r\n<p><strong>Seat Height:</strong>&nbsp;430-560mm</p>\r\n\r\n<p><strong>Seat Depth:</strong>&nbsp;472mm</p>\r\n\r\n<p><strong>Weight:</strong>&nbsp;10kg</p>\r\n','',0,'','','','','','W624,M352,C600,S360,C360,B200,M300','H2351215,W351215,D1351215,S300,W2351212',10,0,'workwell-meeting-chair-5-star-castor-base-mwt13','',0,0,'','','','',1,1,'',''),(33,1,'Executive Office Chair, High Back, Armrests, Real Leather, Black','<ul>\r\n	<li>Executive Office Chair</li>\r\n	<li>Black real leather</li>\r\n	<li>High back</li>\r\n	<li>Standard height adjustment</li>\r\n	<li>Armrests</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Ideal for home , office, meeting &amp; conference rooms</li>\r\n</ul>\r\n','',0,'','','','','','E231,O120,C600,H200,B200,A656232,R400,L360,B420','E231,O120,C600,B420,R400,L360,H200,B200,S35363,H230,A32353,A656232,S140,O500,C360,W420,I340,F600,H500,M352,A510,C51652,R520',1,0,'executive-office-chair-high-back-armrests-real-leather-black','',0,0,'','','','',1,1,'',''),(33,1,'Executive Office Chair, High Back, Armrests, Real Leather, Black','<ul>\r\n	<li>Executive Office Chair</li>\r\n	<li>Black real leather</li>\r\n	<li>High back</li>\r\n	<li>Standard height adjustment</li>\r\n	<li>Armrests</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Ideal for home , office, meeting &amp; conference rooms</li>\r\n</ul>\r\n','',0,'','','','','','E231,O120,C600,H200,B200,A656232,R400,L360,B420','E231,O120,C600,B420,R400,L360,H200,B200,S35363,H230,A32353,A656232,S140,O500,C360,W420,I340,F600,H500,M352,A510,C51652,R520',4,0,'executive-office-chair-high-back-armrests-real-leather-black','',0,0,'','','','',1,1,'',''),(33,1,'Executive Office Chair, High Back, Armrests, Real Leather, Black','<ul>\r\n	<li>Executive Office Chair</li>\r\n	<li>Black real leather</li>\r\n	<li>High back</li>\r\n	<li>Standard height adjustment</li>\r\n	<li>Armrests</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Ideal for home , office, meeting &amp; conference rooms</li>\r\n</ul>\r\n','',0,'','','','','','E231,O120,C600,H200,B200,A656232,R400,L360,B420','E231,O120,C600,B420,R400,L360,H200,B200,S35363,H230,A32353,A656232,S140,O500,C360,W420,I340,F600,H500,M352,A510,C51652,R520',5,0,'executive-office-chair-high-back-armrests-real-leather-black','',0,0,'','','','',1,1,'',''),(33,1,'Executive Office Chair, High Back, Armrests, Real Leather, Black','<ul>\r\n	<li>Executive Office Chair</li>\r\n	<li>Black real leather</li>\r\n	<li>High back</li>\r\n	<li>Standard height adjustment</li>\r\n	<li>Armrests</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Ideal for home , office, meeting &amp; conference rooms</li>\r\n</ul>\r\n','',0,'','','','','','E231,O120,C600,H200,B200,A656232,R400,L360,B420','E231,O120,C600,B420,R400,L360,H200,B200,S35363,H230,A32353,A656232,S140,O500,C360,W420,I340,F600,H500,M352,A510,C51652,R520',6,0,'executive-office-chair-high-back-armrests-real-leather-black','',0,0,'','','','',1,1,'',''),(33,1,'Executive Office Chair, High Back, Armrests, Real Leather, Black','<ul>\r\n	<li>Executive Office Chair</li>\r\n	<li>Black real leather</li>\r\n	<li>High back</li>\r\n	<li>Standard height adjustment</li>\r\n	<li>Armrests</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Ideal for home , office, meeting &amp; conference rooms</li>\r\n</ul>\r\n','',0,'','','','','','E231,O120,C600,H200,B200,A656232,R400,L360,B420','E231,O120,C600,B420,R400,L360,H200,B200,S35363,H230,A32353,A656232,S140,O500,C360,W420,I340,F600,H500,M352,A510,C51652,R520',7,0,'executive-office-chair-high-back-armrests-real-leather-black','',0,0,'','','','',1,1,'',''),(33,1,'Executive Office Chair, High Back, Armrests, Real Leather, Black','<ul>\r\n	<li>Executive Office Chair</li>\r\n	<li>Black real leather</li>\r\n	<li>High back</li>\r\n	<li>Standard height adjustment</li>\r\n	<li>Armrests</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Ideal for home , office, meeting &amp; conference rooms</li>\r\n</ul>\r\n','',0,'','','','','','E231,O120,C600,H200,B200,A656232,R400,L360,B420','E231,O120,C600,B420,R400,L360,H200,B200,S35363,H230,A32353,A656232,S140,O500,C360,W420,I340,F600,H500,M352,A510,C51652,R520',8,0,'executive-office-chair-high-back-armrests-real-leather-black','',0,0,'','','','',1,1,'',''),(33,1,'Executive Office Chair, High Back, Armrests, Real Leather, Black','<ul>\r\n	<li>Executive Office Chair</li>\r\n	<li>Black real leather</li>\r\n	<li>High back</li>\r\n	<li>Standard height adjustment</li>\r\n	<li>Armrests</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Ideal for home , office, meeting &amp; conference rooms</li>\r\n</ul>\r\n','',0,'','','','','','E231,O120,C600,H200,B200,A656232,R400,L360,B420','E231,O120,C600,B420,R400,L360,H200,B200,S35363,H230,A32353,A656232,S140,O500,C360,W420,I340,F600,H500,M352,A510,C51652,R520',9,0,'executive-office-chair-high-back-armrests-real-leather-black','',0,0,'','','','',1,1,'',''),(33,1,'Executive Office Chair, High Back, Armrests, Real Leather, Black','<ul>\r\n	<li>Executive Office Chair</li>\r\n	<li>Black real leather</li>\r\n	<li>High back</li>\r\n	<li>Standard height adjustment</li>\r\n	<li>Armrests</li>\r\n	<li>Swivel base on castor wheels</li>\r\n	<li>Ideal for home , office, meeting &amp; conference rooms</li>\r\n</ul>\r\n','',0,'','','','','','E231,O120,C600,H200,B200,A656232,R400,L360,B420','E231,O120,C600,B420,R400,L360,H200,B200,S35363,H230,A32353,A656232,S140,O500,C360,W420,I340,F600,H500,M352,A510,C51652,R520',10,0,'executive-office-chair-high-back-armrests-real-leather-black','',0,0,'','','','',1,1,'',''),(34,1,'Fellowes White Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in White</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes White Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081101&nbsp;</strong>workstation easily accommodates individual user heights and arrives fully assembled.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<ul>\r\n	<li>USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged</li>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,W300,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,W300,T512142,W623512132,Y600,W6212,T000,N230,L140,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,N121,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,B420,C51314,S524,D400,M360,A650,K320',1,0,'fellowes-white-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(34,1,'Fellowes White Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in White</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes White Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081101&nbsp;</strong>workstation easily accommodates individual user heights and arrives fully assembled.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<ul>\r\n	<li>USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged</li>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,W300,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,W300,T512142,W623512132,Y600,W6212,T000,N230,L140,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,N121,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,B420,C51314,S524,D400,M360,A650,K320',4,0,'fellowes-white-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(34,1,'Fellowes White Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in White</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes White Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081101&nbsp;</strong>workstation easily accommodates individual user heights and arrives fully assembled.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<ul>\r\n	<li>USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged</li>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,W300,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,W300,T512142,W623512132,Y600,W6212,T000,N230,L140,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,N121,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,B420,C51314,S524,D400,M360,A650,K320',5,0,'fellowes-white-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(34,1,'Fellowes White Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in White</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes White Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081101&nbsp;</strong>workstation easily accommodates individual user heights and arrives fully assembled.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<ul>\r\n	<li>USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged</li>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,W300,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,W300,T512142,W623512132,Y600,W6212,T000,N230,L140,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,N121,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,B420,C51314,S524,D400,M360,A650,K320',6,0,'fellowes-white-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(34,1,'Fellowes White Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in White</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes White Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081101&nbsp;</strong>workstation easily accommodates individual user heights and arrives fully assembled.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<ul>\r\n	<li>USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged</li>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,W300,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,W300,T512142,W623512132,Y600,W6212,T000,N230,L140,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,N121,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,B420,C51314,S524,D400,M360,A650,K320',7,0,'fellowes-white-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(34,1,'Fellowes White Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in White</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes White Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081101&nbsp;</strong>workstation easily accommodates individual user heights and arrives fully assembled.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<ul>\r\n	<li>USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged</li>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,W300,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,W300,T512142,W623512132,Y600,W6212,T000,N230,L140,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,N121,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,B420,C51314,S524,D400,M360,A650,K320',8,0,'fellowes-white-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(34,1,'Fellowes White Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in White</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes White Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081101&nbsp;</strong>workstation easily accommodates individual user heights and arrives fully assembled.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<ul>\r\n	<li>USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged</li>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,W300,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,W300,T512142,W623512132,Y600,W6212,T000,N230,L140,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,N121,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,B420,C51314,S524,D400,M360,A650,K320',9,0,'fellowes-white-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(34,1,'Fellowes White Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in White</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes White Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081101&nbsp;</strong>workstation easily accommodates individual user heights and arrives fully assembled.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<ul>\r\n	<li>USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged</li>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,W300,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,W300,T512142,W623512132,Y600,W6212,T000,N230,L140,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,N121,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,B420,C51314,S524,D400,M360,A650,K320',10,0,'fellowes-white-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(35,1,'Fellowes Black Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in Black</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes Black Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081001</strong>&nbsp;workstation easily accommodates individual user heights and arrives fully assembled. USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged.</p>\r\n\r\n<ul>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,B420,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,B420,T512142,W623512132,Y600,W6212,T000,N230,L140,W300,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,C51314,S524,D400,M360,A650,K320',1,0,'fellowes-black-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(35,1,'Fellowes Black Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in Black</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes Black Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081001</strong>&nbsp;workstation easily accommodates individual user heights and arrives fully assembled. USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged.</p>\r\n\r\n<ul>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,B420,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,B420,T512142,W623512132,Y600,W6212,T000,N230,L140,W300,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,C51314,S524,D400,M360,A650,K320',4,0,'fellowes-black-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(35,1,'Fellowes Black Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in Black</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes Black Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081001</strong>&nbsp;workstation easily accommodates individual user heights and arrives fully assembled. USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged.</p>\r\n\r\n<ul>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,B420,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,B420,T512142,W623512132,Y600,W6212,T000,N230,L140,W300,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,C51314,S524,D400,M360,A650,K320',5,0,'fellowes-black-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(35,1,'Fellowes Black Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in Black</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes Black Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081001</strong>&nbsp;workstation easily accommodates individual user heights and arrives fully assembled. USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged.</p>\r\n\r\n<ul>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,B420,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,B420,T512142,W623512132,Y600,W6212,T000,N230,L140,W300,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,C51314,S524,D400,M360,A650,K320',6,0,'fellowes-black-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(35,1,'Fellowes Black Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in Black</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes Black Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081001</strong>&nbsp;workstation easily accommodates individual user heights and arrives fully assembled. USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged.</p>\r\n\r\n<ul>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,B420,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,B420,T512142,W623512132,Y600,W6212,T000,N230,L140,W300,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,C51314,S524,D400,M360,A650,K320',7,0,'fellowes-black-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(35,1,'Fellowes Black Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in Black</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes Black Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081001</strong>&nbsp;workstation easily accommodates individual user heights and arrives fully assembled. USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged.</p>\r\n\r\n<ul>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,B420,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,B420,T512142,W623512132,Y600,W6212,T000,N230,L140,W300,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,C51314,S524,D400,M360,A650,K320',8,0,'fellowes-black-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(35,1,'Fellowes Black Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in Black</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes Black Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081001</strong>&nbsp;workstation easily accommodates individual user heights and arrives fully assembled. USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged.</p>\r\n\r\n<ul>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,B420,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,B420,T512142,W623512132,Y600,W6212,T000,N230,L140,W300,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,C51314,S524,D400,M360,A650,K320',9,0,'fellowes-black-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(35,1,'Fellowes Black Lotus DX Sit-Stand Workstation','<h2>Fellowes Lotus DX Sit-Stand Workstation in Black</h2>\r\n\r\n<p>The&nbsp;<strong>Fellowes Black Lotus DX Sit-Stand Workstation</strong>&nbsp;takes your workspace to the next level with a built in charging station featuring wireless charging capabilities to allow effortless productivity.</p>\r\n\r\n<p>Featuring 22 height settings this&nbsp;<strong>8081001</strong>&nbsp;workstation easily accommodates individual user heights and arrives fully assembled. USB ports and wireless charging support the built-in device channel to allow easy access to keep devices fully charged.</p>\r\n\r\n<ul>\r\n	<li>Microban Protection for added protection against bacteria, mould and mildew</li>\r\n	<li>Patent Pending Smooth Lift Technology keeps the workstation stable and allows effortless changing of positions</li>\r\n	<li>Arrives fully assembled</li>\r\n	<li>22 height settings to accommodate individual user heights</li>\r\n	<li>Cable management system allows the entire workspace to move freely with the user</li>\r\n	<li>Available in black and white</li>\r\n	<li>Compatible with the Lotus Single and Dual monitor arm kits</li>\r\n</ul>\r\n','',0,'','','','','','F420,B420,L320,D200,S32353,W6235','F420,L320,D200,S32353,W6235,I500,B420,T512142,W623512132,Y600,W6212,T000,N230,L140,W300,B430,C6252,S350,F3652,W642,C1432,A400,E16342,P632313,H230,S352,T2512151216235,E240,A2532,I53134,U260,H232,A530,A612,F400,A25143,U210,P632,S163,B435,D120,C540,E200,A200,K100,C623,M2615,P63235,F600,A300,A2523,B236,M430,P353,P5352,S530,L130,T2542,K120,S314,A420,C5252,O100,P2352,A253,C140,M253,E536,M100,F640,A1414,C51314,S524,D400,M360,A650,K320',10,0,'fellowes-black-lotus-dx-sit-stand-workstation','',0,0,'','','','',1,1,'',''),(36,1,'Jemini 1600mm Grey Oak/Silver Cantilever Left Hand Radial Desk','<p>Jemini W1600 x D600/800 x H730mm Cantilever Left Hand Radial Desk in Grey Oak and Silver<br />\r\nJemini Radial Left Hand Cantilever Desk 1600x1200x730mm Grey Oak/Silver KF807537</p>\r\n\r\n<p>Suitable for use in a variety of office environments. This Jemini Cantilever Desk features double upright legs for improved stability, with height adjustable feet up to 10mm. The radial design offers easy working access to your computer, as well as ample additional desktop space. The 25mm thick MFC desktop features 2mm edge banding and 80mm dual cable management ports. The desk includes a modesty panel as standard and is suitable for use with Jemini Fixed Pedestals on the 800mm end.</p>\r\n\r\n<p>Cantilever desk with double upright legs for stability<br />\r\nHeight adjustable feet up to 10mm<br />\r\n25mm thick MFC desktop with 2mm edge banding<br />\r\n80mm dual cable management ports<br />\r\nSuitable for use with fixed pedestals on the 800mm end<br />\r\nLeg Colour: Silver<br />\r\nFinish: Grey Oak<br />\r\nDimensions (WxDxH): 1600x1200x730mm</p>\r\n','',0,'','','','','','J500,M000,G600,O2416,C53416,L130,H530,R340,D200','J500,W000,D000,H500,C53416,L130,H530,R340,D200,I500,G600,O200,A530,S416,X500,O2416,K100,S314,F600,U200,V630,O100,O120,E516532,T200,F362,D140,U1623,L200,I51613,S3143,W300,H230,A32314,F300,U100,T000,M000,D250,O162,E200,W6252,A200,Y600,C5136,W400,A514,A354,D231,S120,M120,E320,B5352,D400,C140,M253,P632,I52432,M323,P540,S35363,I200,F230,P32342,O500,E530,C460,F520,D5252,W232',1,0,'jemini-1600mm-grey-oaksilver-cantilever-left-hand-radial-desk','',0,0,'','','','',1,1,'',''),(36,1,'Jemini 1600mm Grey Oak/Silver Cantilever Left Hand Radial Desk','<p>Jemini W1600 x D600/800 x H730mm Cantilever Left Hand Radial Desk in Grey Oak and Silver<br />\r\nJemini Radial Left Hand Cantilever Desk 1600x1200x730mm Grey Oak/Silver KF807537</p>\r\n\r\n<p>Suitable for use in a variety of office environments. This Jemini Cantilever Desk features double upright legs for improved stability, with height adjustable feet up to 10mm. The radial design offers easy working access to your computer, as well as ample additional desktop space. The 25mm thick MFC desktop features 2mm edge banding and 80mm dual cable management ports. The desk includes a modesty panel as standard and is suitable for use with Jemini Fixed Pedestals on the 800mm end.</p>\r\n\r\n<p>Cantilever desk with double upright legs for stability<br />\r\nHeight adjustable feet up to 10mm<br />\r\n25mm thick MFC desktop with 2mm edge banding<br />\r\n80mm dual cable management ports<br />\r\nSuitable for use with fixed pedestals on the 800mm end<br />\r\nLeg Colour: Silver<br />\r\nFinish: Grey Oak<br />\r\nDimensions (WxDxH): 1600x1200x730mm</p>\r\n','',0,'','','','','','J500,M000,G600,O2416,C53416,L130,H530,R340,D200','J500,W000,D000,H500,C53416,L130,H530,R340,D200,I500,G600,O200,A530,S416,X500,O2416,K100,S314,F600,U200,V630,O100,O120,E516532,T200,F362,D140,U1623,L200,I51613,S3143,W300,H230,A32314,F300,U100,T000,M000,D250,O162,E200,W6252,A200,Y600,C5136,W400,A514,A354,D231,S120,M120,E320,B5352,D400,C140,M253,P632,I52432,M323,P540,S35363,I200,F230,P32342,O500,E530,C460,F520,D5252,W232',4,0,'jemini-1600mm-grey-oaksilver-cantilever-left-hand-radial-desk','',0,0,'','','','',1,1,'',''),(36,1,'Jemini 1600mm Grey Oak/Silver Cantilever Left Hand Radial Desk','<p>Jemini W1600 x D600/800 x H730mm Cantilever Left Hand Radial Desk in Grey Oak and Silver<br />\r\nJemini Radial Left Hand Cantilever Desk 1600x1200x730mm Grey Oak/Silver KF807537</p>\r\n\r\n<p>Suitable for use in a variety of office environments. This Jemini Cantilever Desk features double upright legs for improved stability, with height adjustable feet up to 10mm. The radial design offers easy working access to your computer, as well as ample additional desktop space. The 25mm thick MFC desktop features 2mm edge banding and 80mm dual cable management ports. The desk includes a modesty panel as standard and is suitable for use with Jemini Fixed Pedestals on the 800mm end.</p>\r\n\r\n<p>Cantilever desk with double upright legs for stability<br />\r\nHeight adjustable feet up to 10mm<br />\r\n25mm thick MFC desktop with 2mm edge banding<br />\r\n80mm dual cable management ports<br />\r\nSuitable for use with fixed pedestals on the 800mm end<br />\r\nLeg Colour: Silver<br />\r\nFinish: Grey Oak<br />\r\nDimensions (WxDxH): 1600x1200x730mm</p>\r\n','',0,'','','','','','J500,M000,G600,O2416,C53416,L130,H530,R340,D200','J500,W000,D000,H500,C53416,L130,H530,R340,D200,I500,G600,O200,A530,S416,X500,O2416,K100,S314,F600,U200,V630,O100,O120,E516532,T200,F362,D140,U1623,L200,I51613,S3143,W300,H230,A32314,F300,U100,T000,M000,D250,O162,E200,W6252,A200,Y600,C5136,W400,A514,A354,D231,S120,M120,E320,B5352,D400,C140,M253,P632,I52432,M323,P540,S35363,I200,F230,P32342,O500,E530,C460,F520,D5252,W232',5,0,'jemini-1600mm-grey-oaksilver-cantilever-left-hand-radial-desk','',0,0,'','','','',1,1,'',''),(36,1,'Jemini 1600mm Grey Oak/Silver Cantilever Left Hand Radial Desk','<p>Jemini W1600 x D600/800 x H730mm Cantilever Left Hand Radial Desk in Grey Oak and Silver<br />\r\nJemini Radial Left Hand Cantilever Desk 1600x1200x730mm Grey Oak/Silver KF807537</p>\r\n\r\n<p>Suitable for use in a variety of office environments. This Jemini Cantilever Desk features double upright legs for improved stability, with height adjustable feet up to 10mm. The radial design offers easy working access to your computer, as well as ample additional desktop space. The 25mm thick MFC desktop features 2mm edge banding and 80mm dual cable management ports. The desk includes a modesty panel as standard and is suitable for use with Jemini Fixed Pedestals on the 800mm end.</p>\r\n\r\n<p>Cantilever desk with double upright legs for stability<br />\r\nHeight adjustable feet up to 10mm<br />\r\n25mm thick MFC desktop with 2mm edge banding<br />\r\n80mm dual cable management ports<br />\r\nSuitable for use with fixed pedestals on the 800mm end<br />\r\nLeg Colour: Silver<br />\r\nFinish: Grey Oak<br />\r\nDimensions (WxDxH): 1600x1200x730mm</p>\r\n','',0,'','','','','','J500,M000,G600,O2416,C53416,L130,H530,R340,D200','J500,W000,D000,H500,C53416,L130,H530,R340,D200,I500,G600,O200,A530,S416,X500,O2416,K100,S314,F600,U200,V630,O100,O120,E516532,T200,F362,D140,U1623,L200,I51613,S3143,W300,H230,A32314,F300,U100,T000,M000,D250,O162,E200,W6252,A200,Y600,C5136,W400,A514,A354,D231,S120,M120,E320,B5352,D400,C140,M253,P632,I52432,M323,P540,S35363,I200,F230,P32342,O500,E530,C460,F520,D5252,W232',6,0,'jemini-1600mm-grey-oaksilver-cantilever-left-hand-radial-desk','',0,0,'','','','',1,1,'',''),(36,1,'Jemini 1600mm Grey Oak/Silver Cantilever Left Hand Radial Desk','<p>Jemini W1600 x D600/800 x H730mm Cantilever Left Hand Radial Desk in Grey Oak and Silver<br />\r\nJemini Radial Left Hand Cantilever Desk 1600x1200x730mm Grey Oak/Silver KF807537</p>\r\n\r\n<p>Suitable for use in a variety of office environments. This Jemini Cantilever Desk features double upright legs for improved stability, with height adjustable feet up to 10mm. The radial design offers easy working access to your computer, as well as ample additional desktop space. The 25mm thick MFC desktop features 2mm edge banding and 80mm dual cable management ports. The desk includes a modesty panel as standard and is suitable for use with Jemini Fixed Pedestals on the 800mm end.</p>\r\n\r\n<p>Cantilever desk with double upright legs for stability<br />\r\nHeight adjustable feet up to 10mm<br />\r\n25mm thick MFC desktop with 2mm edge banding<br />\r\n80mm dual cable management ports<br />\r\nSuitable for use with fixed pedestals on the 800mm end<br />\r\nLeg Colour: Silver<br />\r\nFinish: Grey Oak<br />\r\nDimensions (WxDxH): 1600x1200x730mm</p>\r\n','',0,'','','','','','J500,M000,G600,O2416,C53416,L130,H530,R340,D200','J500,W000,D000,H500,C53416,L130,H530,R340,D200,I500,G600,O200,A530,S416,X500,O2416,K100,S314,F600,U200,V630,O100,O120,E516532,T200,F362,D140,U1623,L200,I51613,S3143,W300,H230,A32314,F300,U100,T000,M000,D250,O162,E200,W6252,A200,Y600,C5136,W400,A514,A354,D231,S120,M120,E320,B5352,D400,C140,M253,P632,I52432,M323,P540,S35363,I200,F230,P32342,O500,E530,C460,F520,D5252,W232',7,0,'jemini-1600mm-grey-oaksilver-cantilever-left-hand-radial-desk','',0,0,'','','','',1,1,'',''),(36,1,'Jemini 1600mm Grey Oak/Silver Cantilever Left Hand Radial Desk','<p>Jemini W1600 x D600/800 x H730mm Cantilever Left Hand Radial Desk in Grey Oak and Silver<br />\r\nJemini Radial Left Hand Cantilever Desk 1600x1200x730mm Grey Oak/Silver KF807537</p>\r\n\r\n<p>Suitable for use in a variety of office environments. This Jemini Cantilever Desk features double upright legs for improved stability, with height adjustable feet up to 10mm. The radial design offers easy working access to your computer, as well as ample additional desktop space. The 25mm thick MFC desktop features 2mm edge banding and 80mm dual cable management ports. The desk includes a modesty panel as standard and is suitable for use with Jemini Fixed Pedestals on the 800mm end.</p>\r\n\r\n<p>Cantilever desk with double upright legs for stability<br />\r\nHeight adjustable feet up to 10mm<br />\r\n25mm thick MFC desktop with 2mm edge banding<br />\r\n80mm dual cable management ports<br />\r\nSuitable for use with fixed pedestals on the 800mm end<br />\r\nLeg Colour: Silver<br />\r\nFinish: Grey Oak<br />\r\nDimensions (WxDxH): 1600x1200x730mm</p>\r\n','',0,'','','','','','J500,M000,G600,O2416,C53416,L130,H530,R340,D200','J500,W000,D000,H500,C53416,L130,H530,R340,D200,I500,G600,O200,A530,S416,X500,O2416,K100,S314,F600,U200,V630,O100,O120,E516532,T200,F362,D140,U1623,L200,I51613,S3143,W300,H230,A32314,F300,U100,T000,M000,D250,O162,E200,W6252,A200,Y600,C5136,W400,A514,A354,D231,S120,M120,E320,B5352,D400,C140,M253,P632,I52432,M323,P540,S35363,I200,F230,P32342,O500,E530,C460,F520,D5252,W232',8,0,'jemini-1600mm-grey-oaksilver-cantilever-left-hand-radial-desk','',0,0,'','','','',1,1,'',''),(36,1,'Jemini 1600mm Grey Oak/Silver Cantilever Left Hand Radial Desk','<p>Jemini W1600 x D600/800 x H730mm Cantilever Left Hand Radial Desk in Grey Oak and Silver<br />\r\nJemini Radial Left Hand Cantilever Desk 1600x1200x730mm Grey Oak/Silver KF807537</p>\r\n\r\n<p>Suitable for use in a variety of office environments. This Jemini Cantilever Desk features double upright legs for improved stability, with height adjustable feet up to 10mm. The radial design offers easy working access to your computer, as well as ample additional desktop space. The 25mm thick MFC desktop features 2mm edge banding and 80mm dual cable management ports. The desk includes a modesty panel as standard and is suitable for use with Jemini Fixed Pedestals on the 800mm end.</p>\r\n\r\n<p>Cantilever desk with double upright legs for stability<br />\r\nHeight adjustable feet up to 10mm<br />\r\n25mm thick MFC desktop with 2mm edge banding<br />\r\n80mm dual cable management ports<br />\r\nSuitable for use with fixed pedestals on the 800mm end<br />\r\nLeg Colour: Silver<br />\r\nFinish: Grey Oak<br />\r\nDimensions (WxDxH): 1600x1200x730mm</p>\r\n','',0,'','','','','','J500,M000,G600,O2416,C53416,L130,H530,R340,D200','J500,W000,D000,H500,C53416,L130,H530,R340,D200,I500,G600,O200,A530,S416,X500,O2416,K100,S314,F600,U200,V630,O100,O120,E516532,T200,F362,D140,U1623,L200,I51613,S3143,W300,H230,A32314,F300,U100,T000,M000,D250,O162,E200,W6252,A200,Y600,C5136,W400,A514,A354,D231,S120,M120,E320,B5352,D400,C140,M253,P632,I52432,M323,P540,S35363,I200,F230,P32342,O500,E530,C460,F520,D5252,W232',9,0,'jemini-1600mm-grey-oaksilver-cantilever-left-hand-radial-desk','',0,0,'','','','',1,1,'',''),(36,1,'Jemini 1600mm Grey Oak/Silver Cantilever Left Hand Radial Desk','<p>Jemini W1600 x D600/800 x H730mm Cantilever Left Hand Radial Desk in Grey Oak and Silver<br />\r\nJemini Radial Left Hand Cantilever Desk 1600x1200x730mm Grey Oak/Silver KF807537</p>\r\n\r\n<p>Suitable for use in a variety of office environments. This Jemini Cantilever Desk features double upright legs for improved stability, with height adjustable feet up to 10mm. The radial design offers easy working access to your computer, as well as ample additional desktop space. The 25mm thick MFC desktop features 2mm edge banding and 80mm dual cable management ports. The desk includes a modesty panel as standard and is suitable for use with Jemini Fixed Pedestals on the 800mm end.</p>\r\n\r\n<p>Cantilever desk with double upright legs for stability<br />\r\nHeight adjustable feet up to 10mm<br />\r\n25mm thick MFC desktop with 2mm edge banding<br />\r\n80mm dual cable management ports<br />\r\nSuitable for use with fixed pedestals on the 800mm end<br />\r\nLeg Colour: Silver<br />\r\nFinish: Grey Oak<br />\r\nDimensions (WxDxH): 1600x1200x730mm</p>\r\n','',0,'','','','','','J500,M000,G600,O2416,C53416,L130,H530,R340,D200','J500,W000,D000,H500,C53416,L130,H530,R340,D200,I500,G600,O200,A530,S416,X500,O2416,K100,S314,F600,U200,V630,O100,O120,E516532,T200,F362,D140,U1623,L200,I51613,S3143,W300,H230,A32314,F300,U100,T000,M000,D250,O162,E200,W6252,A200,Y600,C5136,W400,A514,A354,D231,S120,M120,E320,B5352,D400,C140,M253,P632,I52432,M323,P540,S35363,I200,F230,P32342,O500,E530,C460,F520,D5252,W232',10,0,'jemini-1600mm-grey-oaksilver-cantilever-left-hand-radial-desk','',0,0,'','','','',1,1,'',''),(37,1,'2 Drawer Side Filing Office Cabinet','2 Drawer Side Filing Office Cabinet. Size: W900 x D600 x H730. Available In 2 Finishes: American Black Walnut and Crown Cut Oak.','',0,'','','','','','D600,S300,F452,O120,C153','D600,S300,F452,O120,C153,S000,W000,D000,H000,A1414,I500,F520,A5625,B420,W453,A530,C650,C300,O200',1,0,'2-drawer-side-filing-office-cabinet','',0,0,'','','','',1,1,'',''),(37,1,'2 Drawer Side Filing Office Cabinet','2 Drawer Side Filing Office Cabinet. Size: W900 x D600 x H730. Available In 2 Finishes: American Black Walnut and Crown Cut Oak.','',0,'','','','','','D600,S300,F452,O120,C153','D600,S300,F452,O120,C153,S000,W000,D000,H000,A1414,I500,F520,A5625,B420,W453,A530,C650,C300,O200',4,0,'2-drawer-side-filing-office-cabinet','',0,0,'','','','',1,1,'',''),(37,1,'2 Drawer Side Filing Office Cabinet','2 Drawer Side Filing Office Cabinet. Size: W900 x D600 x H730. Available In 2 Finishes: American Black Walnut and Crown Cut Oak.','',0,'','','','','','D600,S300,F452,O120,C153','D600,S300,F452,O120,C153,S000,W000,D000,H000,A1414,I500,F520,A5625,B420,W453,A530,C650,C300,O200',5,0,'2-drawer-side-filing-office-cabinet','',0,0,'','','','',1,1,'',''),(37,1,'2 Drawer Side Filing Office Cabinet','2 Drawer Side Filing Office Cabinet. Size: W900 x D600 x H730. Available In 2 Finishes: American Black Walnut and Crown Cut Oak.','',0,'','','','','','D600,S300,F452,O120,C153','D600,S300,F452,O120,C153,S000,W000,D000,H000,A1414,I500,F520,A5625,B420,W453,A530,C650,C300,O200',6,0,'2-drawer-side-filing-office-cabinet','',0,0,'','','','',1,1,'',''),(37,1,'2 Drawer Side Filing Office Cabinet','2 Drawer Side Filing Office Cabinet. Size: W900 x D600 x H730. Available In 2 Finishes: American Black Walnut and Crown Cut Oak.','',0,'','','','','','D600,S300,F452,O120,C153','D600,S300,F452,O120,C153,S000,W000,D000,H000,A1414,I500,F520,A5625,B420,W453,A530,C650,C300,O200',7,0,'2-drawer-side-filing-office-cabinet','',0,0,'','','','',1,1,'',''),(37,1,'2 Drawer Side Filing Office Cabinet','2 Drawer Side Filing Office Cabinet. Size: W900 x D600 x H730. Available In 2 Finishes: American Black Walnut and Crown Cut Oak.','',0,'','','','','','D600,S300,F452,O120,C153','D600,S300,F452,O120,C153,S000,W000,D000,H000,A1414,I500,F520,A5625,B420,W453,A530,C650,C300,O200',8,0,'2-drawer-side-filing-office-cabinet','',0,0,'','','','',1,1,'',''),(37,1,'2 Drawer Side Filing Office Cabinet','2 Drawer Side Filing Office Cabinet. Size: W900 x D600 x H730. Available In 2 Finishes: American Black Walnut and Crown Cut Oak.','',0,'','','','','','D600,S300,F452,O120,C153','D600,S300,F452,O120,C153,S000,W000,D000,H000,A1414,I500,F520,A5625,B420,W453,A530,C650,C300,O200',9,0,'2-drawer-side-filing-office-cabinet','',0,0,'','','','',1,1,'',''),(37,1,'2 Drawer Side Filing Office Cabinet','2 Drawer Side Filing Office Cabinet. Size: W900 x D600 x H730. Available In 2 Finishes: American Black Walnut and Crown Cut Oak.','',0,'','','','','','D600,S300,F452,O120,C153','D600,S300,F452,O120,C153,S000,W000,D000,H000,A1414,I500,F520,A5625,B420,W453,A530,C650,C300,O200',10,0,'2-drawer-side-filing-office-cabinet','',0,0,'','','','',1,1,'',''),(38,1,'Epson WorkForce Pro WF-3820DWF All-In-One Wireless Printer','<p>Epson&#39;s WF-3820DWF is a high-quality A4 multifunction printer with double-sided print and single-sided scan, as well as copy and fax functions. Print wirelessly with ease with built-in Wi-Fi, Epson&#39;s range of mobile printing apps for your smart devices, and the Scan-to-Cloud feature. It runs a cost-effective ink system, and, finished with a 6.8cm colour touch screen, this compact printer effortlessly handles all your home printing needs.</p>\r\n\r\n<p><strong>High speed &amp; high quality</strong><br />\r\nAt speeds of 21ppm for monochrome and 10ppm for colour, you get fast, business-quality printing. Epson&rsquo;s PrecisionCore print-head delivers laser-like prints at 4800 x 2400 resolution. A 35-sheet automatic document feeder and paper-saving duplex functionality increase efficiency too.</p>\r\n\r\n<p><strong>Wireless printing</strong><br />\r\nUse a host of Wireless printing options for easy convenience (or still connect in traditional wired fashion by high-speed USB). Use Epson Connect to print content from your smart device, as well as Scan-to-Cloud. It&rsquo;s also Apple AirPrint and Wi-Fi Direct compatible.</p>\r\n\r\n<p><strong>DURABrite Ultra ink compatibility</strong><br />\r\nDURABrite Ultra Ink is water, smudge and highlighter resistant, so your prints are resilient. Furthermore, it has a 50% lower cost-per-page than competitive lasers.</p>\r\n','',0,'','','','','','E125,W62162,P600,W131,A450,W642,P6536','E1252,W131,I200,H243,A000,M4315235,P6536,W300,D1423,P653,A530,S52423,S500,A200,W400,C100,F200,F52352,W6424,E200,B435,W100,R520,O100,M140,P65352,A120,F600,Y600,S563,D120,T000,S53243,F360,I300,C31231,I520,S350,F523,C500,C460,T200,S650,C5123,E163424,H5342,A400,H500,N320,H200,S130,A510,Q430,A300,S132,P500,M265,Y000,G300,F230,B25243,E12562,P62526,D4162,L2642,P6532,R2435,S300,A3532,D253,P62152,D142,F523543,I5262,W642,U200,H230,O1352,C5152,O600,S340,C523,I500,T6354,W630,F250,B000,H213,U210,E125,C5353,F650,I362,A420,A140,A61653,D623,C51314,D6163,U436,C513143,W360,S532,H24236,R2353,S000,A600,R2453,F63656,L600,C31612,T500,C5131,L262',1,0,'epson-workforce-pro-wf-3820dwf-all-in-one-wireless-printer-black','',0,0,'','','','',1,1,'',''),(38,1,'Epson WorkForce Pro WF-3820DWF All-In-One Wireless Printer','<p>Epson&#39;s WF-3820DWF is a high-quality A4 multifunction printer with double-sided print and single-sided scan, as well as copy and fax functions. Print wirelessly with ease with built-in Wi-Fi, Epson&#39;s range of mobile printing apps for your smart devices, and the Scan-to-Cloud feature. It runs a cost-effective ink system, and, finished with a 6.8cm colour touch screen, this compact printer effortlessly handles all your home printing needs.</p>\r\n\r\n<p><strong>High speed &amp; high quality</strong><br />\r\nAt speeds of 21ppm for monochrome and 10ppm for colour, you get fast, business-quality printing. Epson&rsquo;s PrecisionCore print-head delivers laser-like prints at 4800 x 2400 resolution. A 35-sheet automatic document feeder and paper-saving duplex functionality increase efficiency too.</p>\r\n\r\n<p><strong>Wireless printing</strong><br />\r\nUse a host of Wireless printing options for easy convenience (or still connect in traditional wired fashion by high-speed USB). Use Epson Connect to print content from your smart device, as well as Scan-to-Cloud. It&rsquo;s also Apple AirPrint and Wi-Fi Direct compatible.</p>\r\n\r\n<p><strong>DURABrite Ultra ink compatibility</strong><br />\r\nDURABrite Ultra Ink is water, smudge and highlighter resistant, so your prints are resilient. Furthermore, it has a 50% lower cost-per-page than competitive lasers.</p>\r\n','',0,'','','','','','E125,W62162,P600,W131,A450,W642,P6536','E1252,W131,I200,H243,A000,M4315235,P6536,W300,D1423,P653,A530,S52423,S500,A200,W400,C100,F200,F52352,W6424,E200,B435,W100,R520,O100,M140,P65352,A120,F600,Y600,S563,D120,T000,S53243,F360,I300,C31231,I520,S350,F523,C500,C460,T200,S650,C5123,E163424,H5342,A400,H500,N320,H200,S130,A510,Q430,A300,S132,P500,M265,Y000,G300,F230,B25243,E12562,P62526,D4162,L2642,P6532,R2435,S300,A3532,D253,P62152,D142,F523543,I5262,W642,U200,H230,O1352,C5152,O600,S340,C523,I500,T6354,W630,F250,B000,H213,U210,E125,C5353,F650,I362,A420,A140,A61653,D623,C51314,D6163,U436,C513143,W360,S532,H24236,R2353,S000,A600,R2453,F63656,L600,C31612,T500,C5131,L262',4,0,'epson-workforce-pro-wf-3820dwf-all-in-one-wireless-printer-black','',0,0,'','','','',1,1,'',''),(38,1,'Epson WorkForce Pro WF-3820DWF All-In-One Wireless Printer','<p>Epson&#39;s WF-3820DWF is a high-quality A4 multifunction printer with double-sided print and single-sided scan, as well as copy and fax functions. Print wirelessly with ease with built-in Wi-Fi, Epson&#39;s range of mobile printing apps for your smart devices, and the Scan-to-Cloud feature. It runs a cost-effective ink system, and, finished with a 6.8cm colour touch screen, this compact printer effortlessly handles all your home printing needs.</p>\r\n\r\n<p><strong>High speed &amp; high quality</strong><br />\r\nAt speeds of 21ppm for monochrome and 10ppm for colour, you get fast, business-quality printing. Epson&rsquo;s PrecisionCore print-head delivers laser-like prints at 4800 x 2400 resolution. A 35-sheet automatic document feeder and paper-saving duplex functionality increase efficiency too.</p>\r\n\r\n<p><strong>Wireless printing</strong><br />\r\nUse a host of Wireless printing options for easy convenience (or still connect in traditional wired fashion by high-speed USB). Use Epson Connect to print content from your smart device, as well as Scan-to-Cloud. It&rsquo;s also Apple AirPrint and Wi-Fi Direct compatible.</p>\r\n\r\n<p><strong>DURABrite Ultra ink compatibility</strong><br />\r\nDURABrite Ultra Ink is water, smudge and highlighter resistant, so your prints are resilient. Furthermore, it has a 50% lower cost-per-page than competitive lasers.</p>\r\n','',0,'','','','','','E125,W62162,P600,W131,A450,W642,P6536','E1252,W131,I200,H243,A000,M4315235,P6536,W300,D1423,P653,A530,S52423,S500,A200,W400,C100,F200,F52352,W6424,E200,B435,W100,R520,O100,M140,P65352,A120,F600,Y600,S563,D120,T000,S53243,F360,I300,C31231,I520,S350,F523,C500,C460,T200,S650,C5123,E163424,H5342,A400,H500,N320,H200,S130,A510,Q430,A300,S132,P500,M265,Y000,G300,F230,B25243,E12562,P62526,D4162,L2642,P6532,R2435,S300,A3532,D253,P62152,D142,F523543,I5262,W642,U200,H230,O1352,C5152,O600,S340,C523,I500,T6354,W630,F250,B000,H213,U210,E125,C5353,F650,I362,A420,A140,A61653,D623,C51314,D6163,U436,C513143,W360,S532,H24236,R2353,S000,A600,R2453,F63656,L600,C31612,T500,C5131,L262',5,0,'epson-workforce-pro-wf-3820dwf-all-in-one-wireless-printer-black','',0,0,'','','','',1,1,'',''),(38,1,'Epson WorkForce Pro WF-3820DWF All-In-One Wireless Printer','<p>Epson&#39;s WF-3820DWF is a high-quality A4 multifunction printer with double-sided print and single-sided scan, as well as copy and fax functions. Print wirelessly with ease with built-in Wi-Fi, Epson&#39;s range of mobile printing apps for your smart devices, and the Scan-to-Cloud feature. It runs a cost-effective ink system, and, finished with a 6.8cm colour touch screen, this compact printer effortlessly handles all your home printing needs.</p>\r\n\r\n<p><strong>High speed &amp; high quality</strong><br />\r\nAt speeds of 21ppm for monochrome and 10ppm for colour, you get fast, business-quality printing. Epson&rsquo;s PrecisionCore print-head delivers laser-like prints at 4800 x 2400 resolution. A 35-sheet automatic document feeder and paper-saving duplex functionality increase efficiency too.</p>\r\n\r\n<p><strong>Wireless printing</strong><br />\r\nUse a host of Wireless printing options for easy convenience (or still connect in traditional wired fashion by high-speed USB). Use Epson Connect to print content from your smart device, as well as Scan-to-Cloud. It&rsquo;s also Apple AirPrint and Wi-Fi Direct compatible.</p>\r\n\r\n<p><strong>DURABrite Ultra ink compatibility</strong><br />\r\nDURABrite Ultra Ink is water, smudge and highlighter resistant, so your prints are resilient. Furthermore, it has a 50% lower cost-per-page than competitive lasers.</p>\r\n','',0,'','','','','','E125,W62162,P600,W131,A450,W642,P6536','E1252,W131,I200,H243,A000,M4315235,P6536,W300,D1423,P653,A530,S52423,S500,A200,W400,C100,F200,F52352,W6424,E200,B435,W100,R520,O100,M140,P65352,A120,F600,Y600,S563,D120,T000,S53243,F360,I300,C31231,I520,S350,F523,C500,C460,T200,S650,C5123,E163424,H5342,A400,H500,N320,H200,S130,A510,Q430,A300,S132,P500,M265,Y000,G300,F230,B25243,E12562,P62526,D4162,L2642,P6532,R2435,S300,A3532,D253,P62152,D142,F523543,I5262,W642,U200,H230,O1352,C5152,O600,S340,C523,I500,T6354,W630,F250,B000,H213,U210,E125,C5353,F650,I362,A420,A140,A61653,D623,C51314,D6163,U436,C513143,W360,S532,H24236,R2353,S000,A600,R2453,F63656,L600,C31612,T500,C5131,L262',6,0,'epson-workforce-pro-wf-3820dwf-all-in-one-wireless-printer-black','',0,0,'','','','',1,1,'',''),(38,1,'Epson WorkForce Pro WF-3820DWF All-In-One Wireless Printer','<p>Epson&#39;s WF-3820DWF is a high-quality A4 multifunction printer with double-sided print and single-sided scan, as well as copy and fax functions. Print wirelessly with ease with built-in Wi-Fi, Epson&#39;s range of mobile printing apps for your smart devices, and the Scan-to-Cloud feature. It runs a cost-effective ink system, and, finished with a 6.8cm colour touch screen, this compact printer effortlessly handles all your home printing needs.</p>\r\n\r\n<p><strong>High speed &amp; high quality</strong><br />\r\nAt speeds of 21ppm for monochrome and 10ppm for colour, you get fast, business-quality printing. Epson&rsquo;s PrecisionCore print-head delivers laser-like prints at 4800 x 2400 resolution. A 35-sheet automatic document feeder and paper-saving duplex functionality increase efficiency too.</p>\r\n\r\n<p><strong>Wireless printing</strong><br />\r\nUse a host of Wireless printing options for easy convenience (or still connect in traditional wired fashion by high-speed USB). Use Epson Connect to print content from your smart device, as well as Scan-to-Cloud. It&rsquo;s also Apple AirPrint and Wi-Fi Direct compatible.</p>\r\n\r\n<p><strong>DURABrite Ultra ink compatibility</strong><br />\r\nDURABrite Ultra Ink is water, smudge and highlighter resistant, so your prints are resilient. Furthermore, it has a 50% lower cost-per-page than competitive lasers.</p>\r\n','',0,'','','','','','E125,W62162,P600,W131,A450,W642,P6536','E1252,W131,I200,H243,A000,M4315235,P6536,W300,D1423,P653,A530,S52423,S500,A200,W400,C100,F200,F52352,W6424,E200,B435,W100,R520,O100,M140,P65352,A120,F600,Y600,S563,D120,T000,S53243,F360,I300,C31231,I520,S350,F523,C500,C460,T200,S650,C5123,E163424,H5342,A400,H500,N320,H200,S130,A510,Q430,A300,S132,P500,M265,Y000,G300,F230,B25243,E12562,P62526,D4162,L2642,P6532,R2435,S300,A3532,D253,P62152,D142,F523543,I5262,W642,U200,H230,O1352,C5152,O600,S340,C523,I500,T6354,W630,F250,B000,H213,U210,E125,C5353,F650,I362,A420,A140,A61653,D623,C51314,D6163,U436,C513143,W360,S532,H24236,R2353,S000,A600,R2453,F63656,L600,C31612,T500,C5131,L262',7,0,'epson-workforce-pro-wf-3820dwf-all-in-one-wireless-printer-black','',0,0,'','','','',1,1,'',''),(38,1,'Epson WorkForce Pro WF-3820DWF All-In-One Wireless Printer','<p>Epson&#39;s WF-3820DWF is a high-quality A4 multifunction printer with double-sided print and single-sided scan, as well as copy and fax functions. Print wirelessly with ease with built-in Wi-Fi, Epson&#39;s range of mobile printing apps for your smart devices, and the Scan-to-Cloud feature. It runs a cost-effective ink system, and, finished with a 6.8cm colour touch screen, this compact printer effortlessly handles all your home printing needs.</p>\r\n\r\n<p><strong>High speed &amp; high quality</strong><br />\r\nAt speeds of 21ppm for monochrome and 10ppm for colour, you get fast, business-quality printing. Epson&rsquo;s PrecisionCore print-head delivers laser-like prints at 4800 x 2400 resolution. A 35-sheet automatic document feeder and paper-saving duplex functionality increase efficiency too.</p>\r\n\r\n<p><strong>Wireless printing</strong><br />\r\nUse a host of Wireless printing options for easy convenience (or still connect in traditional wired fashion by high-speed USB). Use Epson Connect to print content from your smart device, as well as Scan-to-Cloud. It&rsquo;s also Apple AirPrint and Wi-Fi Direct compatible.</p>\r\n\r\n<p><strong>DURABrite Ultra ink compatibility</strong><br />\r\nDURABrite Ultra Ink is water, smudge and highlighter resistant, so your prints are resilient. Furthermore, it has a 50% lower cost-per-page than competitive lasers.</p>\r\n','',0,'','','','','','E125,W62162,P600,W131,A450,W642,P6536','E1252,W131,I200,H243,A000,M4315235,P6536,W300,D1423,P653,A530,S52423,S500,A200,W400,C100,F200,F52352,W6424,E200,B435,W100,R520,O100,M140,P65352,A120,F600,Y600,S563,D120,T000,S53243,F360,I300,C31231,I520,S350,F523,C500,C460,T200,S650,C5123,E163424,H5342,A400,H500,N320,H200,S130,A510,Q430,A300,S132,P500,M265,Y000,G300,F230,B25243,E12562,P62526,D4162,L2642,P6532,R2435,S300,A3532,D253,P62152,D142,F523543,I5262,W642,U200,H230,O1352,C5152,O600,S340,C523,I500,T6354,W630,F250,B000,H213,U210,E125,C5353,F650,I362,A420,A140,A61653,D623,C51314,D6163,U436,C513143,W360,S532,H24236,R2353,S000,A600,R2453,F63656,L600,C31612,T500,C5131,L262',8,0,'epson-workforce-pro-wf-3820dwf-all-in-one-wireless-printer-black','',0,0,'','','','',1,1,'',''),(38,1,'Epson WorkForce Pro WF-3820DWF All-In-One Wireless Printer','<p>Epson&#39;s WF-3820DWF is a high-quality A4 multifunction printer with double-sided print and single-sided scan, as well as copy and fax functions. Print wirelessly with ease with built-in Wi-Fi, Epson&#39;s range of mobile printing apps for your smart devices, and the Scan-to-Cloud feature. It runs a cost-effective ink system, and, finished with a 6.8cm colour touch screen, this compact printer effortlessly handles all your home printing needs.</p>\r\n\r\n<p><strong>High speed &amp; high quality</strong><br />\r\nAt speeds of 21ppm for monochrome and 10ppm for colour, you get fast, business-quality printing. Epson&rsquo;s PrecisionCore print-head delivers laser-like prints at 4800 x 2400 resolution. A 35-sheet automatic document feeder and paper-saving duplex functionality increase efficiency too.</p>\r\n\r\n<p><strong>Wireless printing</strong><br />\r\nUse a host of Wireless printing options for easy convenience (or still connect in traditional wired fashion by high-speed USB). Use Epson Connect to print content from your smart device, as well as Scan-to-Cloud. It&rsquo;s also Apple AirPrint and Wi-Fi Direct compatible.</p>\r\n\r\n<p><strong>DURABrite Ultra ink compatibility</strong><br />\r\nDURABrite Ultra Ink is water, smudge and highlighter resistant, so your prints are resilient. Furthermore, it has a 50% lower cost-per-page than competitive lasers.</p>\r\n','',0,'','','','','','E125,W62162,P600,W131,A450,W642,P6536','E1252,W131,I200,H243,A000,M4315235,P6536,W300,D1423,P653,A530,S52423,S500,A200,W400,C100,F200,F52352,W6424,E200,B435,W100,R520,O100,M140,P65352,A120,F600,Y600,S563,D120,T000,S53243,F360,I300,C31231,I520,S350,F523,C500,C460,T200,S650,C5123,E163424,H5342,A400,H500,N320,H200,S130,A510,Q430,A300,S132,P500,M265,Y000,G300,F230,B25243,E12562,P62526,D4162,L2642,P6532,R2435,S300,A3532,D253,P62152,D142,F523543,I5262,W642,U200,H230,O1352,C5152,O600,S340,C523,I500,T6354,W630,F250,B000,H213,U210,E125,C5353,F650,I362,A420,A140,A61653,D623,C51314,D6163,U436,C513143,W360,S532,H24236,R2353,S000,A600,R2453,F63656,L600,C31612,T500,C5131,L262',9,0,'epson-workforce-pro-wf-3820dwf-all-in-one-wireless-printer-black','',0,0,'','','','',1,1,'',''),(38,1,'Epson WorkForce Pro WF-3820DWF All-In-One Wireless Printer','<p>Epson&#39;s WF-3820DWF is a high-quality A4 multifunction printer with double-sided print and single-sided scan, as well as copy and fax functions. Print wirelessly with ease with built-in Wi-Fi, Epson&#39;s range of mobile printing apps for your smart devices, and the Scan-to-Cloud feature. It runs a cost-effective ink system, and, finished with a 6.8cm colour touch screen, this compact printer effortlessly handles all your home printing needs.</p>\r\n\r\n<p><strong>High speed &amp; high quality</strong><br />\r\nAt speeds of 21ppm for monochrome and 10ppm for colour, you get fast, business-quality printing. Epson&rsquo;s PrecisionCore print-head delivers laser-like prints at 4800 x 2400 resolution. A 35-sheet automatic document feeder and paper-saving duplex functionality increase efficiency too.</p>\r\n\r\n<p><strong>Wireless printing</strong><br />\r\nUse a host of Wireless printing options for easy convenience (or still connect in traditional wired fashion by high-speed USB). Use Epson Connect to print content from your smart device, as well as Scan-to-Cloud. It&rsquo;s also Apple AirPrint and Wi-Fi Direct compatible.</p>\r\n\r\n<p><strong>DURABrite Ultra ink compatibility</strong><br />\r\nDURABrite Ultra Ink is water, smudge and highlighter resistant, so your prints are resilient. Furthermore, it has a 50% lower cost-per-page than competitive lasers.</p>\r\n','',0,'','','','','','E125,W62162,P600,W131,A450,W642,P6536','E1252,W131,I200,H243,A000,M4315235,P6536,W300,D1423,P653,A530,S52423,S500,A200,W400,C100,F200,F52352,W6424,E200,B435,W100,R520,O100,M140,P65352,A120,F600,Y600,S563,D120,T000,S53243,F360,I300,C31231,I520,S350,F523,C500,C460,T200,S650,C5123,E163424,H5342,A400,H500,N320,H200,S130,A510,Q430,A300,S132,P500,M265,Y000,G300,F230,B25243,E12562,P62526,D4162,L2642,P6532,R2435,S300,A3532,D253,P62152,D142,F523543,I5262,W642,U200,H230,O1352,C5152,O600,S340,C523,I500,T6354,W630,F250,B000,H213,U210,E125,C5353,F650,I362,A420,A140,A61653,D623,C51314,D6163,U436,C513143,W360,S532,H24236,R2353,S000,A600,R2453,F63656,L600,C31612,T500,C5131,L262',10,0,'epson-workforce-pro-wf-3820dwf-all-in-one-wireless-printer-black','',0,0,'','','','',1,1,'',''),(39,1,'Epson Expression Premium XP-6100 Wi-Fi All-In-One Printer','<p>Vibrant photos and crisp, clear copy is produced time and again with Epson&#39;s Expression Premium XP-6100 all-in-one printer. Individual inks save you money as you&#39;ll only have to replace the pigment that runs out. Wirelessly print with ease with built-in Wi-Fi and Epson&#39;s easy to use mobile apps. This compact and stylish printer has a modest footprint so it&#39;ll fit neatly into your set up.</p>\r\n\r\n<p><strong>Wireless printing at home</strong><br />\r\nBuilt-in Wi-Fi gives you seamless wireless printing from your smart phone, tablet, PC or Wi-Fi enabled camera. Download the iPrint app (iOS and Android) to your device or use Wi-Fi Direct to print straight from a compatible wireless device. For more creative results use the Creative Print app to access Facebook photos or design custom greeting cards. With support for Apple Airprint too, you&rsquo;ll always be able to find the most convenient way to run off your documents.</p>\r\n\r\n<p><strong>Wireless printing on the go</strong><br />\r\nPrinting when you&#39;re miles away is possible as the Epson XP-6100 machine comes with its own email address. All you have to do is email the documents and photos you need a copy of to the printer&#39;s email address and they&#39;ll be ready for you to pick up when you get home.</p>\r\n\r\n<p><strong>Smart design</strong><br />\r\nThe control panel and 6.1cm LCD touch screen can be tilted to ensure you get the best viewing angle. The XP-6100&#39;s dual paper trays allow you to fill one with plain A4 paper for documents and the other with photo paper. Or you can print directly from the USB port or memory card using the SD card slot. Double-sided printing saves on paper, and you can print directly onto CDs and DVDs too.</p>\r\n','',0,'','','','','','E125,E21625,P650,X100,W100,A450,P6536','V653,P320,A530,C621,C460,C100,I200,P6323,T500,A250,W300,E1252,E21625,P650,X100,A450,P6536,I53134,I520,S100,Y000,M000,A200,Y400,O540,H100,T000,R142,P253,R520,O300,W6424,P653,E200,B435,W100,U200,M140,A120,T200,C5123,S342,H200,M323,F31653,S000,I340,F300,N340,I530,Y600,S300,U100,W642,P65352,A300,H500,G120,S542,F650,S563,P500,T143,P200,O600,E5143,C560,D543,I1653,A100,A5363,D120,D623,S3623,C51314,F600,M600,C631,R2432,F212,D250,C350,G6352,C632,S163,A140,A61653,Y624,A420,B000,F530,M230,C5153,W000,R500,O100,D2532,O500,G000,W500,M420,A000,P214,E125,M250,C520,I320,E540,A362,A400,D000,N300,P65362,T400,R300,G300,C5364,P540,C500,L230,S650,T430,E526,B230,V520,A524,X120,D400,P600,T620,F400,P450,O360,P300,D6234,U210,P630,C630,U252,S430,D1423,S120,O530,C320,D132',1,0,'epson-expression-premium-xp-6100-wi-fi-all-in-one-printer-black','',0,0,'','','','',1,1,'',''),(39,1,'Epson Expression Premium XP-6100 Wi-Fi All-In-One Printer','<p>Vibrant photos and crisp, clear copy is produced time and again with Epson&#39;s Expression Premium XP-6100 all-in-one printer. Individual inks save you money as you&#39;ll only have to replace the pigment that runs out. Wirelessly print with ease with built-in Wi-Fi and Epson&#39;s easy to use mobile apps. This compact and stylish printer has a modest footprint so it&#39;ll fit neatly into your set up.</p>\r\n\r\n<p><strong>Wireless printing at home</strong><br />\r\nBuilt-in Wi-Fi gives you seamless wireless printing from your smart phone, tablet, PC or Wi-Fi enabled camera. Download the iPrint app (iOS and Android) to your device or use Wi-Fi Direct to print straight from a compatible wireless device. For more creative results use the Creative Print app to access Facebook photos or design custom greeting cards. With support for Apple Airprint too, you&rsquo;ll always be able to find the most convenient way to run off your documents.</p>\r\n\r\n<p><strong>Wireless printing on the go</strong><br />\r\nPrinting when you&#39;re miles away is possible as the Epson XP-6100 machine comes with its own email address. All you have to do is email the documents and photos you need a copy of to the printer&#39;s email address and they&#39;ll be ready for you to pick up when you get home.</p>\r\n\r\n<p><strong>Smart design</strong><br />\r\nThe control panel and 6.1cm LCD touch screen can be tilted to ensure you get the best viewing angle. The XP-6100&#39;s dual paper trays allow you to fill one with plain A4 paper for documents and the other with photo paper. Or you can print directly from the USB port or memory card using the SD card slot. Double-sided printing saves on paper, and you can print directly onto CDs and DVDs too.</p>\r\n','',0,'','','','','','E125,E21625,P650,X100,W100,A450,P6536','V653,P320,A530,C621,C460,C100,I200,P6323,T500,A250,W300,E1252,E21625,P650,X100,A450,P6536,I53134,I520,S100,Y000,M000,A200,Y400,O540,H100,T000,R142,P253,R520,O300,W6424,P653,E200,B435,W100,U200,M140,A120,T200,C5123,S342,H200,M323,F31653,S000,I340,F300,N340,I530,Y600,S300,U100,W642,P65352,A300,H500,G120,S542,F650,S563,P500,T143,P200,O600,E5143,C560,D543,I1653,A100,A5363,D120,D623,S3623,C51314,F600,M600,C631,R2432,F212,D250,C350,G6352,C632,S163,A140,A61653,Y624,A420,B000,F530,M230,C5153,W000,R500,O100,D2532,O500,G000,W500,M420,A000,P214,E125,M250,C520,I320,E540,A362,A400,D000,N300,P65362,T400,R300,G300,C5364,P540,C500,L230,S650,T430,E526,B230,V520,A524,X120,D400,P600,T620,F400,P450,O360,P300,D6234,U210,P630,C630,U252,S430,D1423,S120,O530,C320,D132',4,0,'epson-expression-premium-xp-6100-wi-fi-all-in-one-printer-black','',0,0,'','','','',1,1,'',''),(39,1,'Epson Expression Premium XP-6100 Wi-Fi All-In-One Printer','<p>Vibrant photos and crisp, clear copy is produced time and again with Epson&#39;s Expression Premium XP-6100 all-in-one printer. Individual inks save you money as you&#39;ll only have to replace the pigment that runs out. Wirelessly print with ease with built-in Wi-Fi and Epson&#39;s easy to use mobile apps. This compact and stylish printer has a modest footprint so it&#39;ll fit neatly into your set up.</p>\r\n\r\n<p><strong>Wireless printing at home</strong><br />\r\nBuilt-in Wi-Fi gives you seamless wireless printing from your smart phone, tablet, PC or Wi-Fi enabled camera. Download the iPrint app (iOS and Android) to your device or use Wi-Fi Direct to print straight from a compatible wireless device. For more creative results use the Creative Print app to access Facebook photos or design custom greeting cards. With support for Apple Airprint too, you&rsquo;ll always be able to find the most convenient way to run off your documents.</p>\r\n\r\n<p><strong>Wireless printing on the go</strong><br />\r\nPrinting when you&#39;re miles away is possible as the Epson XP-6100 machine comes with its own email address. All you have to do is email the documents and photos you need a copy of to the printer&#39;s email address and they&#39;ll be ready for you to pick up when you get home.</p>\r\n\r\n<p><strong>Smart design</strong><br />\r\nThe control panel and 6.1cm LCD touch screen can be tilted to ensure you get the best viewing angle. The XP-6100&#39;s dual paper trays allow you to fill one with plain A4 paper for documents and the other with photo paper. Or you can print directly from the USB port or memory card using the SD card slot. Double-sided printing saves on paper, and you can print directly onto CDs and DVDs too.</p>\r\n','',0,'','','','','','E125,E21625,P650,X100,W100,A450,P6536','V653,P320,A530,C621,C460,C100,I200,P6323,T500,A250,W300,E1252,E21625,P650,X100,A450,P6536,I53134,I520,S100,Y000,M000,A200,Y400,O540,H100,T000,R142,P253,R520,O300,W6424,P653,E200,B435,W100,U200,M140,A120,T200,C5123,S342,H200,M323,F31653,S000,I340,F300,N340,I530,Y600,S300,U100,W642,P65352,A300,H500,G120,S542,F650,S563,P500,T143,P200,O600,E5143,C560,D543,I1653,A100,A5363,D120,D623,S3623,C51314,F600,M600,C631,R2432,F212,D250,C350,G6352,C632,S163,A140,A61653,Y624,A420,B000,F530,M230,C5153,W000,R500,O100,D2532,O500,G000,W500,M420,A000,P214,E125,M250,C520,I320,E540,A362,A400,D000,N300,P65362,T400,R300,G300,C5364,P540,C500,L230,S650,T430,E526,B230,V520,A524,X120,D400,P600,T620,F400,P450,O360,P300,D6234,U210,P630,C630,U252,S430,D1423,S120,O530,C320,D132',5,0,'epson-expression-premium-xp-6100-wi-fi-all-in-one-printer-black','',0,0,'','','','',1,1,'',''),(39,1,'Epson Expression Premium XP-6100 Wi-Fi All-In-One Printer','<p>Vibrant photos and crisp, clear copy is produced time and again with Epson&#39;s Expression Premium XP-6100 all-in-one printer. Individual inks save you money as you&#39;ll only have to replace the pigment that runs out. Wirelessly print with ease with built-in Wi-Fi and Epson&#39;s easy to use mobile apps. This compact and stylish printer has a modest footprint so it&#39;ll fit neatly into your set up.</p>\r\n\r\n<p><strong>Wireless printing at home</strong><br />\r\nBuilt-in Wi-Fi gives you seamless wireless printing from your smart phone, tablet, PC or Wi-Fi enabled camera. Download the iPrint app (iOS and Android) to your device or use Wi-Fi Direct to print straight from a compatible wireless device. For more creative results use the Creative Print app to access Facebook photos or design custom greeting cards. With support for Apple Airprint too, you&rsquo;ll always be able to find the most convenient way to run off your documents.</p>\r\n\r\n<p><strong>Wireless printing on the go</strong><br />\r\nPrinting when you&#39;re miles away is possible as the Epson XP-6100 machine comes with its own email address. All you have to do is email the documents and photos you need a copy of to the printer&#39;s email address and they&#39;ll be ready for you to pick up when you get home.</p>\r\n\r\n<p><strong>Smart design</strong><br />\r\nThe control panel and 6.1cm LCD touch screen can be tilted to ensure you get the best viewing angle. The XP-6100&#39;s dual paper trays allow you to fill one with plain A4 paper for documents and the other with photo paper. Or you can print directly from the USB port or memory card using the SD card slot. Double-sided printing saves on paper, and you can print directly onto CDs and DVDs too.</p>\r\n','',0,'','','','','','E125,E21625,P650,X100,W100,A450,P6536','V653,P320,A530,C621,C460,C100,I200,P6323,T500,A250,W300,E1252,E21625,P650,X100,A450,P6536,I53134,I520,S100,Y000,M000,A200,Y400,O540,H100,T000,R142,P253,R520,O300,W6424,P653,E200,B435,W100,U200,M140,A120,T200,C5123,S342,H200,M323,F31653,S000,I340,F300,N340,I530,Y600,S300,U100,W642,P65352,A300,H500,G120,S542,F650,S563,P500,T143,P200,O600,E5143,C560,D543,I1653,A100,A5363,D120,D623,S3623,C51314,F600,M600,C631,R2432,F212,D250,C350,G6352,C632,S163,A140,A61653,Y624,A420,B000,F530,M230,C5153,W000,R500,O100,D2532,O500,G000,W500,M420,A000,P214,E125,M250,C520,I320,E540,A362,A400,D000,N300,P65362,T400,R300,G300,C5364,P540,C500,L230,S650,T430,E526,B230,V520,A524,X120,D400,P600,T620,F400,P450,O360,P300,D6234,U210,P630,C630,U252,S430,D1423,S120,O530,C320,D132',6,0,'epson-expression-premium-xp-6100-wi-fi-all-in-one-printer-black','',0,0,'','','','',1,1,'',''),(39,1,'Epson Expression Premium XP-6100 Wi-Fi All-In-One Printer','<p>Vibrant photos and crisp, clear copy is produced time and again with Epson&#39;s Expression Premium XP-6100 all-in-one printer. Individual inks save you money as you&#39;ll only have to replace the pigment that runs out. Wirelessly print with ease with built-in Wi-Fi and Epson&#39;s easy to use mobile apps. This compact and stylish printer has a modest footprint so it&#39;ll fit neatly into your set up.</p>\r\n\r\n<p><strong>Wireless printing at home</strong><br />\r\nBuilt-in Wi-Fi gives you seamless wireless printing from your smart phone, tablet, PC or Wi-Fi enabled camera. Download the iPrint app (iOS and Android) to your device or use Wi-Fi Direct to print straight from a compatible wireless device. For more creative results use the Creative Print app to access Facebook photos or design custom greeting cards. With support for Apple Airprint too, you&rsquo;ll always be able to find the most convenient way to run off your documents.</p>\r\n\r\n<p><strong>Wireless printing on the go</strong><br />\r\nPrinting when you&#39;re miles away is possible as the Epson XP-6100 machine comes with its own email address. All you have to do is email the documents and photos you need a copy of to the printer&#39;s email address and they&#39;ll be ready for you to pick up when you get home.</p>\r\n\r\n<p><strong>Smart design</strong><br />\r\nThe control panel and 6.1cm LCD touch screen can be tilted to ensure you get the best viewing angle. The XP-6100&#39;s dual paper trays allow you to fill one with plain A4 paper for documents and the other with photo paper. Or you can print directly from the USB port or memory card using the SD card slot. Double-sided printing saves on paper, and you can print directly onto CDs and DVDs too.</p>\r\n','',0,'','','','','','E125,E21625,P650,X100,W100,A450,P6536','V653,P320,A530,C621,C460,C100,I200,P6323,T500,A250,W300,E1252,E21625,P650,X100,A450,P6536,I53134,I520,S100,Y000,M000,A200,Y400,O540,H100,T000,R142,P253,R520,O300,W6424,P653,E200,B435,W100,U200,M140,A120,T200,C5123,S342,H200,M323,F31653,S000,I340,F300,N340,I530,Y600,S300,U100,W642,P65352,A300,H500,G120,S542,F650,S563,P500,T143,P200,O600,E5143,C560,D543,I1653,A100,A5363,D120,D623,S3623,C51314,F600,M600,C631,R2432,F212,D250,C350,G6352,C632,S163,A140,A61653,Y624,A420,B000,F530,M230,C5153,W000,R500,O100,D2532,O500,G000,W500,M420,A000,P214,E125,M250,C520,I320,E540,A362,A400,D000,N300,P65362,T400,R300,G300,C5364,P540,C500,L230,S650,T430,E526,B230,V520,A524,X120,D400,P600,T620,F400,P450,O360,P300,D6234,U210,P630,C630,U252,S430,D1423,S120,O530,C320,D132',7,0,'epson-expression-premium-xp-6100-wi-fi-all-in-one-printer-black','',0,0,'','','','',1,1,'',''),(39,1,'Epson Expression Premium XP-6100 Wi-Fi All-In-One Printer','<p>Vibrant photos and crisp, clear copy is produced time and again with Epson&#39;s Expression Premium XP-6100 all-in-one printer. Individual inks save you money as you&#39;ll only have to replace the pigment that runs out. Wirelessly print with ease with built-in Wi-Fi and Epson&#39;s easy to use mobile apps. This compact and stylish printer has a modest footprint so it&#39;ll fit neatly into your set up.</p>\r\n\r\n<p><strong>Wireless printing at home</strong><br />\r\nBuilt-in Wi-Fi gives you seamless wireless printing from your smart phone, tablet, PC or Wi-Fi enabled camera. Download the iPrint app (iOS and Android) to your device or use Wi-Fi Direct to print straight from a compatible wireless device. For more creative results use the Creative Print app to access Facebook photos or design custom greeting cards. With support for Apple Airprint too, you&rsquo;ll always be able to find the most convenient way to run off your documents.</p>\r\n\r\n<p><strong>Wireless printing on the go</strong><br />\r\nPrinting when you&#39;re miles away is possible as the Epson XP-6100 machine comes with its own email address. All you have to do is email the documents and photos you need a copy of to the printer&#39;s email address and they&#39;ll be ready for you to pick up when you get home.</p>\r\n\r\n<p><strong>Smart design</strong><br />\r\nThe control panel and 6.1cm LCD touch screen can be tilted to ensure you get the best viewing angle. The XP-6100&#39;s dual paper trays allow you to fill one with plain A4 paper for documents and the other with photo paper. Or you can print directly from the USB port or memory card using the SD card slot. Double-sided printing saves on paper, and you can print directly onto CDs and DVDs too.</p>\r\n','',0,'','','','','','E125,E21625,P650,X100,W100,A450,P6536','V653,P320,A530,C621,C460,C100,I200,P6323,T500,A250,W300,E1252,E21625,P650,X100,A450,P6536,I53134,I520,S100,Y000,M000,A200,Y400,O540,H100,T000,R142,P253,R520,O300,W6424,P653,E200,B435,W100,U200,M140,A120,T200,C5123,S342,H200,M323,F31653,S000,I340,F300,N340,I530,Y600,S300,U100,W642,P65352,A300,H500,G120,S542,F650,S563,P500,T143,P200,O600,E5143,C560,D543,I1653,A100,A5363,D120,D623,S3623,C51314,F600,M600,C631,R2432,F212,D250,C350,G6352,C632,S163,A140,A61653,Y624,A420,B000,F530,M230,C5153,W000,R500,O100,D2532,O500,G000,W500,M420,A000,P214,E125,M250,C520,I320,E540,A362,A400,D000,N300,P65362,T400,R300,G300,C5364,P540,C500,L230,S650,T430,E526,B230,V520,A524,X120,D400,P600,T620,F400,P450,O360,P300,D6234,U210,P630,C630,U252,S430,D1423,S120,O530,C320,D132',8,0,'epson-expression-premium-xp-6100-wi-fi-all-in-one-printer-black','',0,0,'','','','',1,1,'',''),(39,1,'Epson Expression Premium XP-6100 Wi-Fi All-In-One Printer','<p>Vibrant photos and crisp, clear copy is produced time and again with Epson&#39;s Expression Premium XP-6100 all-in-one printer. Individual inks save you money as you&#39;ll only have to replace the pigment that runs out. Wirelessly print with ease with built-in Wi-Fi and Epson&#39;s easy to use mobile apps. This compact and stylish printer has a modest footprint so it&#39;ll fit neatly into your set up.</p>\r\n\r\n<p><strong>Wireless printing at home</strong><br />\r\nBuilt-in Wi-Fi gives you seamless wireless printing from your smart phone, tablet, PC or Wi-Fi enabled camera. Download the iPrint app (iOS and Android) to your device or use Wi-Fi Direct to print straight from a compatible wireless device. For more creative results use the Creative Print app to access Facebook photos or design custom greeting cards. With support for Apple Airprint too, you&rsquo;ll always be able to find the most convenient way to run off your documents.</p>\r\n\r\n<p><strong>Wireless printing on the go</strong><br />\r\nPrinting when you&#39;re miles away is possible as the Epson XP-6100 machine comes with its own email address. All you have to do is email the documents and photos you need a copy of to the printer&#39;s email address and they&#39;ll be ready for you to pick up when you get home.</p>\r\n\r\n<p><strong>Smart design</strong><br />\r\nThe control panel and 6.1cm LCD touch screen can be tilted to ensure you get the best viewing angle. The XP-6100&#39;s dual paper trays allow you to fill one with plain A4 paper for documents and the other with photo paper. Or you can print directly from the USB port or memory card using the SD card slot. Double-sided printing saves on paper, and you can print directly onto CDs and DVDs too.</p>\r\n','',0,'','','','','','E125,E21625,P650,X100,W100,A450,P6536','V653,P320,A530,C621,C460,C100,I200,P6323,T500,A250,W300,E1252,E21625,P650,X100,A450,P6536,I53134,I520,S100,Y000,M000,A200,Y400,O540,H100,T000,R142,P253,R520,O300,W6424,P653,E200,B435,W100,U200,M140,A120,T200,C5123,S342,H200,M323,F31653,S000,I340,F300,N340,I530,Y600,S300,U100,W642,P65352,A300,H500,G120,S542,F650,S563,P500,T143,P200,O600,E5143,C560,D543,I1653,A100,A5363,D120,D623,S3623,C51314,F600,M600,C631,R2432,F212,D250,C350,G6352,C632,S163,A140,A61653,Y624,A420,B000,F530,M230,C5153,W000,R500,O100,D2532,O500,G000,W500,M420,A000,P214,E125,M250,C520,I320,E540,A362,A400,D000,N300,P65362,T400,R300,G300,C5364,P540,C500,L230,S650,T430,E526,B230,V520,A524,X120,D400,P600,T620,F400,P450,O360,P300,D6234,U210,P630,C630,U252,S430,D1423,S120,O530,C320,D132',9,0,'epson-expression-premium-xp-6100-wi-fi-all-in-one-printer-black','',0,0,'','','','',1,1,'',''),(39,1,'Epson Expression Premium XP-6100 Wi-Fi All-In-One Printer','<p>Vibrant photos and crisp, clear copy is produced time and again with Epson&#39;s Expression Premium XP-6100 all-in-one printer. Individual inks save you money as you&#39;ll only have to replace the pigment that runs out. Wirelessly print with ease with built-in Wi-Fi and Epson&#39;s easy to use mobile apps. This compact and stylish printer has a modest footprint so it&#39;ll fit neatly into your set up.</p>\r\n\r\n<p><strong>Wireless printing at home</strong><br />\r\nBuilt-in Wi-Fi gives you seamless wireless printing from your smart phone, tablet, PC or Wi-Fi enabled camera. Download the iPrint app (iOS and Android) to your device or use Wi-Fi Direct to print straight from a compatible wireless device. For more creative results use the Creative Print app to access Facebook photos or design custom greeting cards. With support for Apple Airprint too, you&rsquo;ll always be able to find the most convenient way to run off your documents.</p>\r\n\r\n<p><strong>Wireless printing on the go</strong><br />\r\nPrinting when you&#39;re miles away is possible as the Epson XP-6100 machine comes with its own email address. All you have to do is email the documents and photos you need a copy of to the printer&#39;s email address and they&#39;ll be ready for you to pick up when you get home.</p>\r\n\r\n<p><strong>Smart design</strong><br />\r\nThe control panel and 6.1cm LCD touch screen can be tilted to ensure you get the best viewing angle. The XP-6100&#39;s dual paper trays allow you to fill one with plain A4 paper for documents and the other with photo paper. Or you can print directly from the USB port or memory card using the SD card slot. Double-sided printing saves on paper, and you can print directly onto CDs and DVDs too.</p>\r\n','',0,'','','','','','E125,E21625,P650,X100,W100,A450,P6536','V653,P320,A530,C621,C460,C100,I200,P6323,T500,A250,W300,E1252,E21625,P650,X100,A450,P6536,I53134,I520,S100,Y000,M000,A200,Y400,O540,H100,T000,R142,P253,R520,O300,W6424,P653,E200,B435,W100,U200,M140,A120,T200,C5123,S342,H200,M323,F31653,S000,I340,F300,N340,I530,Y600,S300,U100,W642,P65352,A300,H500,G120,S542,F650,S563,P500,T143,P200,O600,E5143,C560,D543,I1653,A100,A5363,D120,D623,S3623,C51314,F600,M600,C631,R2432,F212,D250,C350,G6352,C632,S163,A140,A61653,Y624,A420,B000,F530,M230,C5153,W000,R500,O100,D2532,O500,G000,W500,M420,A000,P214,E125,M250,C520,I320,E540,A362,A400,D000,N300,P65362,T400,R300,G300,C5364,P540,C500,L230,S650,T430,E526,B230,V520,A524,X120,D400,P600,T620,F400,P450,O360,P300,D6234,U210,P630,C630,U252,S430,D1423,S120,O530,C320,D132',10,0,'epson-expression-premium-xp-6100-wi-fi-all-in-one-printer-black','',0,0,'','','','',1,1,'',''),(40,1,'Epson EcoTank ET-M2120','You can print, copy and scan, all the while making big savings with this durable, fast and energy-efficient EcoTank with refillable ink tank. A cost-efficient solution, print up to 5,000 pages with the included black ink<sup>1</sup>. You&#39;ll get prints quickly as there&#39;s no warm up time and print speeds of 15ppm<sup>2</sup>. Connect easily via Wi-Fi and use Epson&#39;s range of mobile printing apps.','',0,'','','','','','E125,E2352,E350','Y000,C500,P653,C100,A530,S500,A400,T000,W400,M252,B200,S152,W300,T200,D614,F230,E5621253,E2352,R1414,I520,T520,C31253,S435,U100,P200,I5243,B420,Y400,G300,P6532,Q400,A200,T620,N000,W650,T500,S132,O100,P500,C523,E240,V000,W100,U200,E1252,R520,M140,P65352,A120',1,0,'epson-ecotank-et-m2120','',0,0,'','','','',1,1,'',''),(40,1,'Epson EcoTank ET-M2120','You can print, copy and scan, all the while making big savings with this durable, fast and energy-efficient EcoTank with refillable ink tank. A cost-efficient solution, print up to 5,000 pages with the included black ink<sup>1</sup>. You&#39;ll get prints quickly as there&#39;s no warm up time and print speeds of 15ppm<sup>2</sup>. Connect easily via Wi-Fi and use Epson&#39;s range of mobile printing apps.','',0,'','','','','','E125,E2352,E350','Y000,C500,P653,C100,A530,S500,A400,T000,W400,M252,B200,S152,W300,T200,D614,F230,E5621253,E2352,R1414,I520,T520,C31253,S435,U100,P200,I5243,B420,Y400,G300,P6532,Q400,A200,T620,N000,W650,T500,S132,O100,P500,C523,E240,V000,W100,U200,E1252,R520,M140,P65352,A120',4,0,'epson-ecotank-et-m2120','',0,0,'','','','',1,1,'',''),(40,1,'Epson EcoTank ET-M2120','You can print, copy and scan, all the while making big savings with this durable, fast and energy-efficient EcoTank with refillable ink tank. A cost-efficient solution, print up to 5,000 pages with the included black ink<sup>1</sup>. You&#39;ll get prints quickly as there&#39;s no warm up time and print speeds of 15ppm<sup>2</sup>. Connect easily via Wi-Fi and use Epson&#39;s range of mobile printing apps.','',0,'','','','','','E125,E2352,E350','Y000,C500,P653,C100,A530,S500,A400,T000,W400,M252,B200,S152,W300,T200,D614,F230,E5621253,E2352,R1414,I520,T520,C31253,S435,U100,P200,I5243,B420,Y400,G300,P6532,Q400,A200,T620,N000,W650,T500,S132,O100,P500,C523,E240,V000,W100,U200,E1252,R520,M140,P65352,A120',5,0,'epson-ecotank-et-m2120','',0,0,'','','','',1,1,'',''),(40,1,'Epson EcoTank ET-M2120','You can print, copy and scan, all the while making big savings with this durable, fast and energy-efficient EcoTank with refillable ink tank. A cost-efficient solution, print up to 5,000 pages with the included black ink<sup>1</sup>. You&#39;ll get prints quickly as there&#39;s no warm up time and print speeds of 15ppm<sup>2</sup>. Connect easily via Wi-Fi and use Epson&#39;s range of mobile printing apps.','',0,'','','','','','E125,E2352,E350','Y000,C500,P653,C100,A530,S500,A400,T000,W400,M252,B200,S152,W300,T200,D614,F230,E5621253,E2352,R1414,I520,T520,C31253,S435,U100,P200,I5243,B420,Y400,G300,P6532,Q400,A200,T620,N000,W650,T500,S132,O100,P500,C523,E240,V000,W100,U200,E1252,R520,M140,P65352,A120',6,0,'epson-ecotank-et-m2120','',0,0,'','','','',1,1,'',''),(40,1,'Epson EcoTank ET-M2120','You can print, copy and scan, all the while making big savings with this durable, fast and energy-efficient EcoTank with refillable ink tank. A cost-efficient solution, print up to 5,000 pages with the included black ink<sup>1</sup>. You&#39;ll get prints quickly as there&#39;s no warm up time and print speeds of 15ppm<sup>2</sup>. Connect easily via Wi-Fi and use Epson&#39;s range of mobile printing apps.','',0,'','','','','','E125,E2352,E350','Y000,C500,P653,C100,A530,S500,A400,T000,W400,M252,B200,S152,W300,T200,D614,F230,E5621253,E2352,R1414,I520,T520,C31253,S435,U100,P200,I5243,B420,Y400,G300,P6532,Q400,A200,T620,N000,W650,T500,S132,O100,P500,C523,E240,V000,W100,U200,E1252,R520,M140,P65352,A120',7,0,'epson-ecotank-et-m2120','',0,0,'','','','',1,1,'',''),(40,1,'Epson EcoTank ET-M2120','You can print, copy and scan, all the while making big savings with this durable, fast and energy-efficient EcoTank with refillable ink tank. A cost-efficient solution, print up to 5,000 pages with the included black ink<sup>1</sup>. You&#39;ll get prints quickly as there&#39;s no warm up time and print speeds of 15ppm<sup>2</sup>. Connect easily via Wi-Fi and use Epson&#39;s range of mobile printing apps.','',0,'','','','','','E125,E2352,E350','Y000,C500,P653,C100,A530,S500,A400,T000,W400,M252,B200,S152,W300,T200,D614,F230,E5621253,E2352,R1414,I520,T520,C31253,S435,U100,P200,I5243,B420,Y400,G300,P6532,Q400,A200,T620,N000,W650,T500,S132,O100,P500,C523,E240,V000,W100,U200,E1252,R520,M140,P65352,A120',8,0,'epson-ecotank-et-m2120','',0,0,'','','','',1,1,'',''),(40,1,'Epson EcoTank ET-M2120','You can print, copy and scan, all the while making big savings with this durable, fast and energy-efficient EcoTank with refillable ink tank. A cost-efficient solution, print up to 5,000 pages with the included black ink<sup>1</sup>. You&#39;ll get prints quickly as there&#39;s no warm up time and print speeds of 15ppm<sup>2</sup>. Connect easily via Wi-Fi and use Epson&#39;s range of mobile printing apps.','',0,'','','','','','E125,E2352,E350','Y000,C500,P653,C100,A530,S500,A400,T000,W400,M252,B200,S152,W300,T200,D614,F230,E5621253,E2352,R1414,I520,T520,C31253,S435,U100,P200,I5243,B420,Y400,G300,P6532,Q400,A200,T620,N000,W650,T500,S132,O100,P500,C523,E240,V000,W100,U200,E1252,R520,M140,P65352,A120',9,0,'epson-ecotank-et-m2120','',0,0,'','','','',1,1,'',''),(40,1,'Epson EcoTank ET-M2120','You can print, copy and scan, all the while making big savings with this durable, fast and energy-efficient EcoTank with refillable ink tank. A cost-efficient solution, print up to 5,000 pages with the included black ink<sup>1</sup>. You&#39;ll get prints quickly as there&#39;s no warm up time and print speeds of 15ppm<sup>2</sup>. Connect easily via Wi-Fi and use Epson&#39;s range of mobile printing apps.','',0,'','','','','','E125,E2352,E350','Y000,C500,P653,C100,A530,S500,A400,T000,W400,M252,B200,S152,W300,T200,D614,F230,E5621253,E2352,R1414,I520,T520,C31253,S435,U100,P200,I5243,B420,Y400,G300,P6532,Q400,A200,T620,N000,W650,T500,S132,O100,P500,C523,E240,V000,W100,U200,E1252,R520,M140,P65352,A120',10,0,'epson-ecotank-et-m2120','',0,0,'','','','',1,1,'',''),(41,1,'EPSON M15140 WI-FI (C11CJ41404)','This feature-rich monochrome EcoTank for small office and business users makes light of A3+ tasks, while offering a low cost per page. A3+ jobs can be accomplished quickly thanks to fast print and scan speeds, two 250-sheet A3 front trays, a 50-sheet A3 rear feed, and a 50-sheet A3 ADF. Print how you like with mobile printing, Ethernet and a 6.8cm LCD touchscreen.','',0,'','','','','','E125,M000,W100,C000','T200,F362,M265,E2352,F600,S540,O120,A530,B252,U262,M200,L230,O100,A000,W400,O1652,L000,C300,P600,P200,J120,C500,B000,A251423,Q400,T520,T000,F230,P653,S500,S132,S300,F653,T620,R000,F300,A310,H000,Y000,L200,W300,M140,P65352,E3653,T265',1,0,'epson-m15140-wi-fi-c11cj41404','',0,0,'','','','',1,1,'',''),(41,1,'EPSON M15140 WI-FI (C11CJ41404)','This feature-rich monochrome EcoTank for small office and business users makes light of A3+ tasks, while offering a low cost per page. A3+ jobs can be accomplished quickly thanks to fast print and scan speeds, two 250-sheet A3 front trays, a 50-sheet A3 rear feed, and a 50-sheet A3 ADF. Print how you like with mobile printing, Ethernet and a 6.8cm LCD touchscreen.','',0,'','','','','','E125,M000,W100,C000','T200,F362,M265,E2352,F600,S540,O120,A530,B252,U262,M200,L230,O100,A000,W400,O1652,L000,C300,P600,P200,J120,C500,B000,A251423,Q400,T520,T000,F230,P653,S500,S132,S300,F653,T620,R000,F300,A310,H000,Y000,L200,W300,M140,P65352,E3653,T265',4,0,'epson-m15140-wi-fi-c11cj41404','',0,0,'','','','',1,1,'',''),(41,1,'EPSON M15140 WI-FI (C11CJ41404)','This feature-rich monochrome EcoTank for small office and business users makes light of A3+ tasks, while offering a low cost per page. A3+ jobs can be accomplished quickly thanks to fast print and scan speeds, two 250-sheet A3 front trays, a 50-sheet A3 rear feed, and a 50-sheet A3 ADF. Print how you like with mobile printing, Ethernet and a 6.8cm LCD touchscreen.','',0,'','','','','','E125,M000,W100,C000','T200,F362,M265,E2352,F600,S540,O120,A530,B252,U262,M200,L230,O100,A000,W400,O1652,L000,C300,P600,P200,J120,C500,B000,A251423,Q400,T520,T000,F230,P653,S500,S132,S300,F653,T620,R000,F300,A310,H000,Y000,L200,W300,M140,P65352,E3653,T265',5,0,'epson-m15140-wi-fi-c11cj41404','',0,0,'','','','',1,1,'',''),(41,1,'EPSON M15140 WI-FI (C11CJ41404)','This feature-rich monochrome EcoTank for small office and business users makes light of A3+ tasks, while offering a low cost per page. A3+ jobs can be accomplished quickly thanks to fast print and scan speeds, two 250-sheet A3 front trays, a 50-sheet A3 rear feed, and a 50-sheet A3 ADF. Print how you like with mobile printing, Ethernet and a 6.8cm LCD touchscreen.','',0,'','','','','','E125,M000,W100,C000','T200,F362,M265,E2352,F600,S540,O120,A530,B252,U262,M200,L230,O100,A000,W400,O1652,L000,C300,P600,P200,J120,C500,B000,A251423,Q400,T520,T000,F230,P653,S500,S132,S300,F653,T620,R000,F300,A310,H000,Y000,L200,W300,M140,P65352,E3653,T265',6,0,'epson-m15140-wi-fi-c11cj41404','',0,0,'','','','',1,1,'',''),(41,1,'EPSON M15140 WI-FI (C11CJ41404)','This feature-rich monochrome EcoTank for small office and business users makes light of A3+ tasks, while offering a low cost per page. A3+ jobs can be accomplished quickly thanks to fast print and scan speeds, two 250-sheet A3 front trays, a 50-sheet A3 rear feed, and a 50-sheet A3 ADF. Print how you like with mobile printing, Ethernet and a 6.8cm LCD touchscreen.','',0,'','','','','','E125,M000,W100,C000','T200,F362,M265,E2352,F600,S540,O120,A530,B252,U262,M200,L230,O100,A000,W400,O1652,L000,C300,P600,P200,J120,C500,B000,A251423,Q400,T520,T000,F230,P653,S500,S132,S300,F653,T620,R000,F300,A310,H000,Y000,L200,W300,M140,P65352,E3653,T265',7,0,'epson-m15140-wi-fi-c11cj41404','',0,0,'','','','',1,1,'',''),(41,1,'EPSON M15140 WI-FI (C11CJ41404)','This feature-rich monochrome EcoTank for small office and business users makes light of A3+ tasks, while offering a low cost per page. A3+ jobs can be accomplished quickly thanks to fast print and scan speeds, two 250-sheet A3 front trays, a 50-sheet A3 rear feed, and a 50-sheet A3 ADF. Print how you like with mobile printing, Ethernet and a 6.8cm LCD touchscreen.','',0,'','','','','','E125,M000,W100,C000','T200,F362,M265,E2352,F600,S540,O120,A530,B252,U262,M200,L230,O100,A000,W400,O1652,L000,C300,P600,P200,J120,C500,B000,A251423,Q400,T520,T000,F230,P653,S500,S132,S300,F653,T620,R000,F300,A310,H000,Y000,L200,W300,M140,P65352,E3653,T265',8,0,'epson-m15140-wi-fi-c11cj41404','',0,0,'','','','',1,1,'',''),(41,1,'EPSON M15140 WI-FI (C11CJ41404)','This feature-rich monochrome EcoTank for small office and business users makes light of A3+ tasks, while offering a low cost per page. A3+ jobs can be accomplished quickly thanks to fast print and scan speeds, two 250-sheet A3 front trays, a 50-sheet A3 rear feed, and a 50-sheet A3 ADF. Print how you like with mobile printing, Ethernet and a 6.8cm LCD touchscreen.','',0,'','','','','','E125,M000,W100,C000','T200,F362,M265,E2352,F600,S540,O120,A530,B252,U262,M200,L230,O100,A000,W400,O1652,L000,C300,P600,P200,J120,C500,B000,A251423,Q400,T520,T000,F230,P653,S500,S132,S300,F653,T620,R000,F300,A310,H000,Y000,L200,W300,M140,P65352,E3653,T265',9,0,'epson-m15140-wi-fi-c11cj41404','',0,0,'','','','',1,1,'',''),(41,1,'EPSON M15140 WI-FI (C11CJ41404)','This feature-rich monochrome EcoTank for small office and business users makes light of A3+ tasks, while offering a low cost per page. A3+ jobs can be accomplished quickly thanks to fast print and scan speeds, two 250-sheet A3 front trays, a 50-sheet A3 rear feed, and a 50-sheet A3 ADF. Print how you like with mobile printing, Ethernet and a 6.8cm LCD touchscreen.','',0,'','','','','','E125,M000,W100,C000','T200,F362,M265,E2352,F600,S540,O120,A530,B252,U262,M200,L230,O100,A000,W400,O1652,L000,C300,P600,P200,J120,C500,B000,A251423,Q400,T520,T000,F230,P653,S500,S132,S300,F653,T620,R000,F300,A310,H000,Y000,L200,W300,M140,P65352,E3653,T265',10,0,'epson-m15140-wi-fi-c11cj41404','',0,0,'','','','',1,1,'',''),(42,1,'Canon - PIXMA Wireless Inkjet Printer - G3260','HIGH VOLUME, LOW COST PRINTING WITH WIRELESS CONNECTIVITYThe Canon PIXMA G3260 Wireless MegaTank All-In-One Printer is designed for productivity&mdash; delivering high-volume, low-cost printing. Its refillable MegaTank ink system prints up to 6,000 black / 7,700 color pages from one set of ink bottles1&mdash; that&rsquo;s 30 times1 what you can print with a conventional ink cartridge set! Print, copy, and scan with ease and enjoy great versatility. Print documents, borderless3 photos, and more on a variety of media types and sizes with hybrid inks for crisp blacks and vivid colors. Plus, you can print on the go wirelessly from your favorite mobile devices2. Print more for less with the Canon PIXMA G3260 Wireless MegaTank All-In-One Printer.','',0,'','','','','','C500,P250,W642,I523,P6536,G000','H200,V450,L000,C300,P65352,W300,W642,C52313,C500,P250,G000,M2352,A450,P6536,I200,D253,F600,P632313532,D41652,H2145,L230,I320,R1414,I520,S350,P6532,U100,T000,B420,C460,P200,F650,O500,S300,O100,B342532,T620,T520,Y000,P653,C515354,C63632,C100,A530,S500,E200,E520,G630,V62343,D2532,B63642,P320,M600,V630,M300,T120,S000,H163,C621,V300,C462,P420,W6424,Y600,F630,M140,D120,L200',1,0,'canon-pixma-wireless-inkjet-printer-g3260','',0,0,'','','','',1,1,'',''),(42,1,'Canon - PIXMA Wireless Inkjet Printer - G3260','HIGH VOLUME, LOW COST PRINTING WITH WIRELESS CONNECTIVITYThe Canon PIXMA G3260 Wireless MegaTank All-In-One Printer is designed for productivity&mdash; delivering high-volume, low-cost printing. Its refillable MegaTank ink system prints up to 6,000 black / 7,700 color pages from one set of ink bottles1&mdash; that&rsquo;s 30 times1 what you can print with a conventional ink cartridge set! Print, copy, and scan with ease and enjoy great versatility. Print documents, borderless3 photos, and more on a variety of media types and sizes with hybrid inks for crisp blacks and vivid colors. Plus, you can print on the go wirelessly from your favorite mobile devices2. Print more for less with the Canon PIXMA G3260 Wireless MegaTank All-In-One Printer.','',0,'','','','','','C500,P250,W642,I523,P6536,G000','H200,V450,L000,C300,P65352,W300,W642,C52313,C500,P250,G000,M2352,A450,P6536,I200,D253,F600,P632313532,D41652,H2145,L230,I320,R1414,I520,S350,P6532,U100,T000,B420,C460,P200,F650,O500,S300,O100,B342532,T620,T520,Y000,P653,C515354,C63632,C100,A530,S500,E200,E520,G630,V62343,D2532,B63642,P320,M600,V630,M300,T120,S000,H163,C621,V300,C462,P420,W6424,Y600,F630,M140,D120,L200',4,0,'canon-pixma-wireless-inkjet-printer-g3260','',0,0,'','','','',1,1,'',''),(42,1,'Canon - PIXMA Wireless Inkjet Printer - G3260','HIGH VOLUME, LOW COST PRINTING WITH WIRELESS CONNECTIVITYThe Canon PIXMA G3260 Wireless MegaTank All-In-One Printer is designed for productivity&mdash; delivering high-volume, low-cost printing. Its refillable MegaTank ink system prints up to 6,000 black / 7,700 color pages from one set of ink bottles1&mdash; that&rsquo;s 30 times1 what you can print with a conventional ink cartridge set! Print, copy, and scan with ease and enjoy great versatility. Print documents, borderless3 photos, and more on a variety of media types and sizes with hybrid inks for crisp blacks and vivid colors. Plus, you can print on the go wirelessly from your favorite mobile devices2. Print more for less with the Canon PIXMA G3260 Wireless MegaTank All-In-One Printer.','',0,'','','','','','C500,P250,W642,I523,P6536,G000','H200,V450,L000,C300,P65352,W300,W642,C52313,C500,P250,G000,M2352,A450,P6536,I200,D253,F600,P632313532,D41652,H2145,L230,I320,R1414,I520,S350,P6532,U100,T000,B420,C460,P200,F650,O500,S300,O100,B342532,T620,T520,Y000,P653,C515354,C63632,C100,A530,S500,E200,E520,G630,V62343,D2532,B63642,P320,M600,V630,M300,T120,S000,H163,C621,V300,C462,P420,W6424,Y600,F630,M140,D120,L200',5,0,'canon-pixma-wireless-inkjet-printer-g3260','',0,0,'','','','',1,1,'',''),(42,1,'Canon - PIXMA Wireless Inkjet Printer - G3260','HIGH VOLUME, LOW COST PRINTING WITH WIRELESS CONNECTIVITYThe Canon PIXMA G3260 Wireless MegaTank All-In-One Printer is designed for productivity&mdash; delivering high-volume, low-cost printing. Its refillable MegaTank ink system prints up to 6,000 black / 7,700 color pages from one set of ink bottles1&mdash; that&rsquo;s 30 times1 what you can print with a conventional ink cartridge set! Print, copy, and scan with ease and enjoy great versatility. Print documents, borderless3 photos, and more on a variety of media types and sizes with hybrid inks for crisp blacks and vivid colors. Plus, you can print on the go wirelessly from your favorite mobile devices2. Print more for less with the Canon PIXMA G3260 Wireless MegaTank All-In-One Printer.','',0,'','','','','','C500,P250,W642,I523,P6536,G000','H200,V450,L000,C300,P65352,W300,W642,C52313,C500,P250,G000,M2352,A450,P6536,I200,D253,F600,P632313532,D41652,H2145,L230,I320,R1414,I520,S350,P6532,U100,T000,B420,C460,P200,F650,O500,S300,O100,B342532,T620,T520,Y000,P653,C515354,C63632,C100,A530,S500,E200,E520,G630,V62343,D2532,B63642,P320,M600,V630,M300,T120,S000,H163,C621,V300,C462,P420,W6424,Y600,F630,M140,D120,L200',6,0,'canon-pixma-wireless-inkjet-printer-g3260','',0,0,'','','','',1,1,'',''),(42,1,'Canon - PIXMA Wireless Inkjet Printer - G3260','HIGH VOLUME, LOW COST PRINTING WITH WIRELESS CONNECTIVITYThe Canon PIXMA G3260 Wireless MegaTank All-In-One Printer is designed for productivity&mdash; delivering high-volume, low-cost printing. Its refillable MegaTank ink system prints up to 6,000 black / 7,700 color pages from one set of ink bottles1&mdash; that&rsquo;s 30 times1 what you can print with a conventional ink cartridge set! Print, copy, and scan with ease and enjoy great versatility. Print documents, borderless3 photos, and more on a variety of media types and sizes with hybrid inks for crisp blacks and vivid colors. Plus, you can print on the go wirelessly from your favorite mobile devices2. Print more for less with the Canon PIXMA G3260 Wireless MegaTank All-In-One Printer.','',0,'','','','','','C500,P250,W642,I523,P6536,G000','H200,V450,L000,C300,P65352,W300,W642,C52313,C500,P250,G000,M2352,A450,P6536,I200,D253,F600,P632313532,D41652,H2145,L230,I320,R1414,I520,S350,P6532,U100,T000,B420,C460,P200,F650,O500,S300,O100,B342532,T620,T520,Y000,P653,C515354,C63632,C100,A530,S500,E200,E520,G630,V62343,D2532,B63642,P320,M600,V630,M300,T120,S000,H163,C621,V300,C462,P420,W6424,Y600,F630,M140,D120,L200',7,0,'canon-pixma-wireless-inkjet-printer-g3260','',0,0,'','','','',1,1,'',''),(42,1,'Canon - PIXMA Wireless Inkjet Printer - G3260','HIGH VOLUME, LOW COST PRINTING WITH WIRELESS CONNECTIVITYThe Canon PIXMA G3260 Wireless MegaTank All-In-One Printer is designed for productivity&mdash; delivering high-volume, low-cost printing. Its refillable MegaTank ink system prints up to 6,000 black / 7,700 color pages from one set of ink bottles1&mdash; that&rsquo;s 30 times1 what you can print with a conventional ink cartridge set! Print, copy, and scan with ease and enjoy great versatility. Print documents, borderless3 photos, and more on a variety of media types and sizes with hybrid inks for crisp blacks and vivid colors. Plus, you can print on the go wirelessly from your favorite mobile devices2. Print more for less with the Canon PIXMA G3260 Wireless MegaTank All-In-One Printer.','',0,'','','','','','C500,P250,W642,I523,P6536,G000','H200,V450,L000,C300,P65352,W300,W642,C52313,C500,P250,G000,M2352,A450,P6536,I200,D253,F600,P632313532,D41652,H2145,L230,I320,R1414,I520,S350,P6532,U100,T000,B420,C460,P200,F650,O500,S300,O100,B342532,T620,T520,Y000,P653,C515354,C63632,C100,A530,S500,E200,E520,G630,V62343,D2532,B63642,P320,M600,V630,M300,T120,S000,H163,C621,V300,C462,P420,W6424,Y600,F630,M140,D120,L200',8,0,'canon-pixma-wireless-inkjet-printer-g3260','',0,0,'','','','',1,1,'',''),(42,1,'Canon - PIXMA Wireless Inkjet Printer - G3260','HIGH VOLUME, LOW COST PRINTING WITH WIRELESS CONNECTIVITYThe Canon PIXMA G3260 Wireless MegaTank All-In-One Printer is designed for productivity&mdash; delivering high-volume, low-cost printing. Its refillable MegaTank ink system prints up to 6,000 black / 7,700 color pages from one set of ink bottles1&mdash; that&rsquo;s 30 times1 what you can print with a conventional ink cartridge set! Print, copy, and scan with ease and enjoy great versatility. Print documents, borderless3 photos, and more on a variety of media types and sizes with hybrid inks for crisp blacks and vivid colors. Plus, you can print on the go wirelessly from your favorite mobile devices2. Print more for less with the Canon PIXMA G3260 Wireless MegaTank All-In-One Printer.','',0,'','','','','','C500,P250,W642,I523,P6536,G000','H200,V450,L000,C300,P65352,W300,W642,C52313,C500,P250,G000,M2352,A450,P6536,I200,D253,F600,P632313532,D41652,H2145,L230,I320,R1414,I520,S350,P6532,U100,T000,B420,C460,P200,F650,O500,S300,O100,B342532,T620,T520,Y000,P653,C515354,C63632,C100,A530,S500,E200,E520,G630,V62343,D2532,B63642,P320,M600,V630,M300,T120,S000,H163,C621,V300,C462,P420,W6424,Y600,F630,M140,D120,L200',9,0,'canon-pixma-wireless-inkjet-printer-g3260','',0,0,'','','','',1,1,'',''),(42,1,'Canon - PIXMA Wireless Inkjet Printer - G3260','HIGH VOLUME, LOW COST PRINTING WITH WIRELESS CONNECTIVITYThe Canon PIXMA G3260 Wireless MegaTank All-In-One Printer is designed for productivity&mdash; delivering high-volume, low-cost printing. Its refillable MegaTank ink system prints up to 6,000 black / 7,700 color pages from one set of ink bottles1&mdash; that&rsquo;s 30 times1 what you can print with a conventional ink cartridge set! Print, copy, and scan with ease and enjoy great versatility. Print documents, borderless3 photos, and more on a variety of media types and sizes with hybrid inks for crisp blacks and vivid colors. Plus, you can print on the go wirelessly from your favorite mobile devices2. Print more for less with the Canon PIXMA G3260 Wireless MegaTank All-In-One Printer.','',0,'','','','','','C500,P250,W642,I523,P6536,G000','H200,V450,L000,C300,P65352,W300,W642,C52313,C500,P250,G000,M2352,A450,P6536,I200,D253,F600,P632313532,D41652,H2145,L230,I320,R1414,I520,S350,P6532,U100,T000,B420,C460,P200,F650,O500,S300,O100,B342532,T620,T520,Y000,P653,C515354,C63632,C100,A530,S500,E200,E520,G630,V62343,D2532,B63642,P320,M600,V630,M300,T120,S000,H163,C621,V300,C462,P420,W6424,Y600,F630,M140,D120,L200',10,0,'canon-pixma-wireless-inkjet-printer-g3260','',0,0,'','','','',1,1,'',''),(43,1,'Canon imageFORMULA DR-6010C Sheetfed Scanner - 24 bit Color - 8 bit Grayscale - USB, SCSI','The imageFORMULA DR-6010C departmental scanner delivers high-speed, reliable document handling and high-quality images in a small package. Flexibility, rich features, and ease-of-use help maximize return on investment at all levels of the business system. Employees in paper-intensive environments find themselves looking for standards to alleviate the document conversion process. The DR-6010C scanner employs technologies such as an advanced three-line CIS sensor and onboard file compression capabilities, enabling prompt transition of hardcopy documents into electronic files at fast speeds.','',0,'','','','','','C500,I521654,D620,S313,S560,B300,C460,G624,U210,S000','T000,I521654,D620,D163534,S560,D4162,H213,R414,D253,H53452,A530,H243,I520,I500,S540,P200,F42143,R200,F362,E212,H410,M252,R365,O500,I512353,A300,A400,L142,O100,B252,S350,E5142,P653521,E516532,F530,T52412,L252,F600,S353632,A413,C51625,P620,T2542,S000,A200,A500,A31523,T645,C000,S526,O5163,F400,C1432,E51452,P6513,T65235,H6321,D2532,I530,E423652,F420,F230,S132',1,0,'canon-imageformula-dr-6010c-sheetfed-scanner-24-bit-color-8-bit-grayscale-usb-scsi','',0,0,'','','','',1,1,'',''),(43,1,'Canon imageFORMULA DR-6010C Sheetfed Scanner - 24 bit Color - 8 bit Grayscale - USB, SCSI','The imageFORMULA DR-6010C departmental scanner delivers high-speed, reliable document handling and high-quality images in a small package. Flexibility, rich features, and ease-of-use help maximize return on investment at all levels of the business system. Employees in paper-intensive environments find themselves looking for standards to alleviate the document conversion process. The DR-6010C scanner employs technologies such as an advanced three-line CIS sensor and onboard file compression capabilities, enabling prompt transition of hardcopy documents into electronic files at fast speeds.','',0,'','','','','','C500,I521654,D620,S313,S560,B300,C460,G624,U210,S000','T000,I521654,D620,D163534,S560,D4162,H213,R414,D253,H53452,A530,H243,I520,I500,S540,P200,F42143,R200,F362,E212,H410,M252,R365,O500,I512353,A300,A400,L142,O100,B252,S350,E5142,P653521,E516532,F530,T52412,L252,F600,S353632,A413,C51625,P620,T2542,S000,A200,A500,A31523,T645,C000,S526,O5163,F400,C1432,E51452,P6513,T65235,H6321,D2532,I530,E423652,F420,F230,S132',4,0,'canon-imageformula-dr-6010c-sheetfed-scanner-24-bit-color-8-bit-grayscale-usb-scsi','',0,0,'','','','',1,1,'',''),(43,1,'Canon imageFORMULA DR-6010C Sheetfed Scanner - 24 bit Color - 8 bit Grayscale - USB, SCSI','The imageFORMULA DR-6010C departmental scanner delivers high-speed, reliable document handling and high-quality images in a small package. Flexibility, rich features, and ease-of-use help maximize return on investment at all levels of the business system. Employees in paper-intensive environments find themselves looking for standards to alleviate the document conversion process. The DR-6010C scanner employs technologies such as an advanced three-line CIS sensor and onboard file compression capabilities, enabling prompt transition of hardcopy documents into electronic files at fast speeds.','',0,'','','','','','C500,I521654,D620,S313,S560,B300,C460,G624,U210,S000','T000,I521654,D620,D163534,S560,D4162,H213,R414,D253,H53452,A530,H243,I520,I500,S540,P200,F42143,R200,F362,E212,H410,M252,R365,O500,I512353,A300,A400,L142,O100,B252,S350,E5142,P653521,E516532,F530,T52412,L252,F600,S353632,A413,C51625,P620,T2542,S000,A200,A500,A31523,T645,C000,S526,O5163,F400,C1432,E51452,P6513,T65235,H6321,D2532,I530,E423652,F420,F230,S132',5,0,'canon-imageformula-dr-6010c-sheetfed-scanner-24-bit-color-8-bit-grayscale-usb-scsi','',0,0,'','','','',1,1,'',''),(43,1,'Canon imageFORMULA DR-6010C Sheetfed Scanner - 24 bit Color - 8 bit Grayscale - USB, SCSI','The imageFORMULA DR-6010C departmental scanner delivers high-speed, reliable document handling and high-quality images in a small package. Flexibility, rich features, and ease-of-use help maximize return on investment at all levels of the business system. Employees in paper-intensive environments find themselves looking for standards to alleviate the document conversion process. The DR-6010C scanner employs technologies such as an advanced three-line CIS sensor and onboard file compression capabilities, enabling prompt transition of hardcopy documents into electronic files at fast speeds.','',0,'','','','','','C500,I521654,D620,S313,S560,B300,C460,G624,U210,S000','T000,I521654,D620,D163534,S560,D4162,H213,R414,D253,H53452,A530,H243,I520,I500,S540,P200,F42143,R200,F362,E212,H410,M252,R365,O500,I512353,A300,A400,L142,O100,B252,S350,E5142,P653521,E516532,F530,T52412,L252,F600,S353632,A413,C51625,P620,T2542,S000,A200,A500,A31523,T645,C000,S526,O5163,F400,C1432,E51452,P6513,T65235,H6321,D2532,I530,E423652,F420,F230,S132',6,0,'canon-imageformula-dr-6010c-sheetfed-scanner-24-bit-color-8-bit-grayscale-usb-scsi','',0,0,'','','','',1,1,'',''),(43,1,'Canon imageFORMULA DR-6010C Sheetfed Scanner - 24 bit Color - 8 bit Grayscale - USB, SCSI','The imageFORMULA DR-6010C departmental scanner delivers high-speed, reliable document handling and high-quality images in a small package. Flexibility, rich features, and ease-of-use help maximize return on investment at all levels of the business system. Employees in paper-intensive environments find themselves looking for standards to alleviate the document conversion process. The DR-6010C scanner employs technologies such as an advanced three-line CIS sensor and onboard file compression capabilities, enabling prompt transition of hardcopy documents into electronic files at fast speeds.','',0,'','','','','','C500,I521654,D620,S313,S560,B300,C460,G624,U210,S000','T000,I521654,D620,D163534,S560,D4162,H213,R414,D253,H53452,A530,H243,I520,I500,S540,P200,F42143,R200,F362,E212,H410,M252,R365,O500,I512353,A300,A400,L142,O100,B252,S350,E5142,P653521,E516532,F530,T52412,L252,F600,S353632,A413,C51625,P620,T2542,S000,A200,A500,A31523,T645,C000,S526,O5163,F400,C1432,E51452,P6513,T65235,H6321,D2532,I530,E423652,F420,F230,S132',7,0,'canon-imageformula-dr-6010c-sheetfed-scanner-24-bit-color-8-bit-grayscale-usb-scsi','',0,0,'','','','',1,1,'',''),(43,1,'Canon imageFORMULA DR-6010C Sheetfed Scanner - 24 bit Color - 8 bit Grayscale - USB, SCSI','The imageFORMULA DR-6010C departmental scanner delivers high-speed, reliable document handling and high-quality images in a small package. Flexibility, rich features, and ease-of-use help maximize return on investment at all levels of the business system. Employees in paper-intensive environments find themselves looking for standards to alleviate the document conversion process. The DR-6010C scanner employs technologies such as an advanced three-line CIS sensor and onboard file compression capabilities, enabling prompt transition of hardcopy documents into electronic files at fast speeds.','',0,'','','','','','C500,I521654,D620,S313,S560,B300,C460,G624,U210,S000','T000,I521654,D620,D163534,S560,D4162,H213,R414,D253,H53452,A530,H243,I520,I500,S540,P200,F42143,R200,F362,E212,H410,M252,R365,O500,I512353,A300,A400,L142,O100,B252,S350,E5142,P653521,E516532,F530,T52412,L252,F600,S353632,A413,C51625,P620,T2542,S000,A200,A500,A31523,T645,C000,S526,O5163,F400,C1432,E51452,P6513,T65235,H6321,D2532,I530,E423652,F420,F230,S132',8,0,'canon-imageformula-dr-6010c-sheetfed-scanner-24-bit-color-8-bit-grayscale-usb-scsi','',0,0,'','','','',1,1,'',''),(43,1,'Canon imageFORMULA DR-6010C Sheetfed Scanner - 24 bit Color - 8 bit Grayscale - USB, SCSI','The imageFORMULA DR-6010C departmental scanner delivers high-speed, reliable document handling and high-quality images in a small package. Flexibility, rich features, and ease-of-use help maximize return on investment at all levels of the business system. Employees in paper-intensive environments find themselves looking for standards to alleviate the document conversion process. The DR-6010C scanner employs technologies such as an advanced three-line CIS sensor and onboard file compression capabilities, enabling prompt transition of hardcopy documents into electronic files at fast speeds.','',0,'','','','','','C500,I521654,D620,S313,S560,B300,C460,G624,U210,S000','T000,I521654,D620,D163534,S560,D4162,H213,R414,D253,H53452,A530,H243,I520,I500,S540,P200,F42143,R200,F362,E212,H410,M252,R365,O500,I512353,A300,A400,L142,O100,B252,S350,E5142,P653521,E516532,F530,T52412,L252,F600,S353632,A413,C51625,P620,T2542,S000,A200,A500,A31523,T645,C000,S526,O5163,F400,C1432,E51452,P6513,T65235,H6321,D2532,I530,E423652,F420,F230,S132',9,0,'canon-imageformula-dr-6010c-sheetfed-scanner-24-bit-color-8-bit-grayscale-usb-scsi','',0,0,'','','','',1,1,'',''),(43,1,'Canon imageFORMULA DR-6010C Sheetfed Scanner - 24 bit Color - 8 bit Grayscale - USB, SCSI','The imageFORMULA DR-6010C departmental scanner delivers high-speed, reliable document handling and high-quality images in a small package. Flexibility, rich features, and ease-of-use help maximize return on investment at all levels of the business system. Employees in paper-intensive environments find themselves looking for standards to alleviate the document conversion process. The DR-6010C scanner employs technologies such as an advanced three-line CIS sensor and onboard file compression capabilities, enabling prompt transition of hardcopy documents into electronic files at fast speeds.','',0,'','','','','','C500,I521654,D620,S313,S560,B300,C460,G624,U210,S000','T000,I521654,D620,D163534,S560,D4162,H213,R414,D253,H53452,A530,H243,I520,I500,S540,P200,F42143,R200,F362,E212,H410,M252,R365,O500,I512353,A300,A400,L142,O100,B252,S350,E5142,P653521,E516532,F530,T52412,L252,F600,S353632,A413,C51625,P620,T2542,S000,A200,A500,A31523,T645,C000,S526,O5163,F400,C1432,E51452,P6513,T65235,H6321,D2532,I530,E423652,F420,F230,S132',10,0,'canon-imageformula-dr-6010c-sheetfed-scanner-24-bit-color-8-bit-grayscale-usb-scsi','',0,0,'','','','',1,1,'',''),(44,1,'CANON PIXMA TS5350 AllinOne Wireless Inkjet Printer','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS5350 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer.&nbsp;Simply download&nbsp;the Canon PRINT app to enjoy a range of connectivity options using WiFi. Or print app free with&nbsp;the Apple&nbsp;AirPrint or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as two Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing. And you can print more pages cost effectively with XL ink cartridges (sold separately), for up to 400 pages a cartridge.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with Easy-PhotoPrint&nbsp;Editor, Creative Park and Message In Print apps. You can print to iron-on transfer media or stickers and make your next project&nbsp;stand out.<br />\r\n<br />\r\n<strong>Easy to control</strong><br />\r\n<br />\r\nHandy access buttons and an OLED display make the&nbsp;<strong>PIXMA TS5350</strong>&nbsp;easy to control. And the manual-tilt panel and intuitive interface match the Canon PRINT app.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P653651212514,D54351213,C500,A100,E520,R520,O100,O1352,U252,W100,O600,F600,W351213,A14512161653,M610,O500,A5363,P500,F500,C63632,G300,P65352,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,Q000,S514,M600,C300,E12314,W300,X400,I520,S430,S1634,C631,P21432,A63232,A162,P6232,E2131653512136,P620,M200,A120,I650,T65216,M300,S3262,N230,P62351212353,O300,C5364,H530,B352,A500,O430,D214,T512125,T251212,M4343,P540,I531,I53612,M320',1,0,'canon-pixma-ts5350-allinone-wireless-inkjet-printer','',0,0,'','','','',1,1,'',''),(44,1,'CANON PIXMA TS5350 AllinOne Wireless Inkjet Printer','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS5350 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer.&nbsp;Simply download&nbsp;the Canon PRINT app to enjoy a range of connectivity options using WiFi. Or print app free with&nbsp;the Apple&nbsp;AirPrint or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as two Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing. And you can print more pages cost effectively with XL ink cartridges (sold separately), for up to 400 pages a cartridge.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with Easy-PhotoPrint&nbsp;Editor, Creative Park and Message In Print apps. You can print to iron-on transfer media or stickers and make your next project&nbsp;stand out.<br />\r\n<br />\r\n<strong>Easy to control</strong><br />\r\n<br />\r\nHandy access buttons and an OLED display make the&nbsp;<strong>PIXMA TS5350</strong>&nbsp;easy to control. And the manual-tilt panel and intuitive interface match the Canon PRINT app.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P653651212514,D54351213,C500,A100,E520,R520,O100,O1352,U252,W100,O600,F600,W351213,A14512161653,M610,O500,A5363,P500,F500,C63632,G300,P65352,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,Q000,S514,M600,C300,E12314,W300,X400,I520,S430,S1634,C631,P21432,A63232,A162,P6232,E2131653512136,P620,M200,A120,I650,T65216,M300,S3262,N230,P62351212353,O300,C5364,H530,B352,A500,O430,D214,T512125,T251212,M4343,P540,I531,I53612,M320',4,0,'canon-pixma-ts5350-allinone-wireless-inkjet-printer','',0,0,'','','','',1,1,'',''),(44,1,'CANON PIXMA TS5350 AllinOne Wireless Inkjet Printer','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS5350 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer.&nbsp;Simply download&nbsp;the Canon PRINT app to enjoy a range of connectivity options using WiFi. Or print app free with&nbsp;the Apple&nbsp;AirPrint or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as two Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing. And you can print more pages cost effectively with XL ink cartridges (sold separately), for up to 400 pages a cartridge.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with Easy-PhotoPrint&nbsp;Editor, Creative Park and Message In Print apps. You can print to iron-on transfer media or stickers and make your next project&nbsp;stand out.<br />\r\n<br />\r\n<strong>Easy to control</strong><br />\r\n<br />\r\nHandy access buttons and an OLED display make the&nbsp;<strong>PIXMA TS5350</strong>&nbsp;easy to control. And the manual-tilt panel and intuitive interface match the Canon PRINT app.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P653651212514,D54351213,C500,A100,E520,R520,O100,O1352,U252,W100,O600,F600,W351213,A14512161653,M610,O500,A5363,P500,F500,C63632,G300,P65352,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,Q000,S514,M600,C300,E12314,W300,X400,I520,S430,S1634,C631,P21432,A63232,A162,P6232,E2131653512136,P620,M200,A120,I650,T65216,M300,S3262,N230,P62351212353,O300,C5364,H530,B352,A500,O430,D214,T512125,T251212,M4343,P540,I531,I53612,M320',5,0,'canon-pixma-ts5350-allinone-wireless-inkjet-printer','',0,0,'','','','',1,1,'',''),(44,1,'CANON PIXMA TS5350 AllinOne Wireless Inkjet Printer','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS5350 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer.&nbsp;Simply download&nbsp;the Canon PRINT app to enjoy a range of connectivity options using WiFi. Or print app free with&nbsp;the Apple&nbsp;AirPrint or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as two Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing. And you can print more pages cost effectively with XL ink cartridges (sold separately), for up to 400 pages a cartridge.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with Easy-PhotoPrint&nbsp;Editor, Creative Park and Message In Print apps. You can print to iron-on transfer media or stickers and make your next project&nbsp;stand out.<br />\r\n<br />\r\n<strong>Easy to control</strong><br />\r\n<br />\r\nHandy access buttons and an OLED display make the&nbsp;<strong>PIXMA TS5350</strong>&nbsp;easy to control. And the manual-tilt panel and intuitive interface match the Canon PRINT app.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P653651212514,D54351213,C500,A100,E520,R520,O100,O1352,U252,W100,O600,F600,W351213,A14512161653,M610,O500,A5363,P500,F500,C63632,G300,P65352,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,Q000,S514,M600,C300,E12314,W300,X400,I520,S430,S1634,C631,P21432,A63232,A162,P6232,E2131653512136,P620,M200,A120,I650,T65216,M300,S3262,N230,P62351212353,O300,C5364,H530,B352,A500,O430,D214,T512125,T251212,M4343,P540,I531,I53612,M320',6,0,'canon-pixma-ts5350-allinone-wireless-inkjet-printer','',0,0,'','','','',1,1,'',''),(44,1,'CANON PIXMA TS5350 AllinOne Wireless Inkjet Printer','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS5350 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer.&nbsp;Simply download&nbsp;the Canon PRINT app to enjoy a range of connectivity options using WiFi. Or print app free with&nbsp;the Apple&nbsp;AirPrint or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as two Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing. And you can print more pages cost effectively with XL ink cartridges (sold separately), for up to 400 pages a cartridge.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with Easy-PhotoPrint&nbsp;Editor, Creative Park and Message In Print apps. You can print to iron-on transfer media or stickers and make your next project&nbsp;stand out.<br />\r\n<br />\r\n<strong>Easy to control</strong><br />\r\n<br />\r\nHandy access buttons and an OLED display make the&nbsp;<strong>PIXMA TS5350</strong>&nbsp;easy to control. And the manual-tilt panel and intuitive interface match the Canon PRINT app.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P653651212514,D54351213,C500,A100,E520,R520,O100,O1352,U252,W100,O600,F600,W351213,A14512161653,M610,O500,A5363,P500,F500,C63632,G300,P65352,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,Q000,S514,M600,C300,E12314,W300,X400,I520,S430,S1634,C631,P21432,A63232,A162,P6232,E2131653512136,P620,M200,A120,I650,T65216,M300,S3262,N230,P62351212353,O300,C5364,H530,B352,A500,O430,D214,T512125,T251212,M4343,P540,I531,I53612,M320',7,0,'canon-pixma-ts5350-allinone-wireless-inkjet-printer','',0,0,'','','','',1,1,'',''),(44,1,'CANON PIXMA TS5350 AllinOne Wireless Inkjet Printer','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS5350 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer.&nbsp;Simply download&nbsp;the Canon PRINT app to enjoy a range of connectivity options using WiFi. Or print app free with&nbsp;the Apple&nbsp;AirPrint or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as two Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing. And you can print more pages cost effectively with XL ink cartridges (sold separately), for up to 400 pages a cartridge.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with Easy-PhotoPrint&nbsp;Editor, Creative Park and Message In Print apps. You can print to iron-on transfer media or stickers and make your next project&nbsp;stand out.<br />\r\n<br />\r\n<strong>Easy to control</strong><br />\r\n<br />\r\nHandy access buttons and an OLED display make the&nbsp;<strong>PIXMA TS5350</strong>&nbsp;easy to control. And the manual-tilt panel and intuitive interface match the Canon PRINT app.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P653651212514,D54351213,C500,A100,E520,R520,O100,O1352,U252,W100,O600,F600,W351213,A14512161653,M610,O500,A5363,P500,F500,C63632,G300,P65352,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,Q000,S514,M600,C300,E12314,W300,X400,I520,S430,S1634,C631,P21432,A63232,A162,P6232,E2131653512136,P620,M200,A120,I650,T65216,M300,S3262,N230,P62351212353,O300,C5364,H530,B352,A500,O430,D214,T512125,T251212,M4343,P540,I531,I53612,M320',8,0,'canon-pixma-ts5350-allinone-wireless-inkjet-printer','',0,0,'','','','',1,1,'',''),(44,1,'CANON PIXMA TS5350 AllinOne Wireless Inkjet Printer','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS5350 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer.&nbsp;Simply download&nbsp;the Canon PRINT app to enjoy a range of connectivity options using WiFi. Or print app free with&nbsp;the Apple&nbsp;AirPrint or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as two Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing. And you can print more pages cost effectively with XL ink cartridges (sold separately), for up to 400 pages a cartridge.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with Easy-PhotoPrint&nbsp;Editor, Creative Park and Message In Print apps. You can print to iron-on transfer media or stickers and make your next project&nbsp;stand out.<br />\r\n<br />\r\n<strong>Easy to control</strong><br />\r\n<br />\r\nHandy access buttons and an OLED display make the&nbsp;<strong>PIXMA TS5350</strong>&nbsp;easy to control. And the manual-tilt panel and intuitive interface match the Canon PRINT app.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P653651212514,D54351213,C500,A100,E520,R520,O100,O1352,U252,W100,O600,F600,W351213,A14512161653,M610,O500,A5363,P500,F500,C63632,G300,P65352,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,Q000,S514,M600,C300,E12314,W300,X400,I520,S430,S1634,C631,P21432,A63232,A162,P6232,E2131653512136,P620,M200,A120,I650,T65216,M300,S3262,N230,P62351212353,O300,C5364,H530,B352,A500,O430,D214,T512125,T251212,M4343,P540,I531,I53612,M320',9,0,'canon-pixma-ts5350-allinone-wireless-inkjet-printer','',0,0,'','','','',1,1,'',''),(44,1,'CANON PIXMA TS5350 AllinOne Wireless Inkjet Printer','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS5350 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer.&nbsp;Simply download&nbsp;the Canon PRINT app to enjoy a range of connectivity options using WiFi. Or print app free with&nbsp;the Apple&nbsp;AirPrint or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as two Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing. And you can print more pages cost effectively with XL ink cartridges (sold separately), for up to 400 pages a cartridge.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with Easy-PhotoPrint&nbsp;Editor, Creative Park and Message In Print apps. You can print to iron-on transfer media or stickers and make your next project&nbsp;stand out.<br />\r\n<br />\r\n<strong>Easy to control</strong><br />\r\n<br />\r\nHandy access buttons and an OLED display make the&nbsp;<strong>PIXMA TS5350</strong>&nbsp;easy to control. And the manual-tilt panel and intuitive interface match the Canon PRINT app.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P653651212514,D54351213,C500,A100,E520,R520,O100,O1352,U252,W100,O600,F600,W351213,A14512161653,M610,O500,A5363,P500,F500,C63632,G300,P65352,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,Q000,S514,M600,C300,E12314,W300,X400,I520,S430,S1634,C631,P21432,A63232,A162,P6232,E2131653512136,P620,M200,A120,I650,T65216,M300,S3262,N230,P62351212353,O300,C5364,H530,B352,A500,O430,D214,T512125,T251212,M4343,P540,I531,I53612,M320',10,0,'canon-pixma-ts5350-allinone-wireless-inkjet-printer','',0,0,'','','','',1,1,'',''),(45,1,'CANON PIXMA TS7451 AllinOne Wireless Inkjet Printer White','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS7451 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer. Simply download the Canon PRINT Inkjet/SELPHY app to enjoy a range of WiFi connectivity options. Or print app-free with Apple AirPrint, Cloud Printing or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as 2 Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with the Easy-PhotoPrint Editor, Canon Print Service Plugin for Android and PIXMA Cloud Link apps. You can also print to iron-on transfer media or stickers and make your next project stand out.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536,W300','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P6536,S514,D543,C500,I523241,A100,E520,R520,O100,W100,O1352,O600,A160,W300,A140,A61653,C430,P65352,M610,O500,A5363,P500,F500,C63632,G300,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,F600,Q000,C631,P21432,A63232,A162,P6232,E2131653,E360,S612,P425,P250,L520,A120,A420,I650,T65216,M300,S3262,M200,N230,P623,S353,O300',1,0,'canon-pixma-ts7451-allinone-wireless-inkjet-printer-white','',0,0,'','','','',1,1,'',''),(45,1,'CANON PIXMA TS7451 AllinOne Wireless Inkjet Printer White','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS7451 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer. Simply download the Canon PRINT Inkjet/SELPHY app to enjoy a range of WiFi connectivity options. Or print app-free with Apple AirPrint, Cloud Printing or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as 2 Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with the Easy-PhotoPrint Editor, Canon Print Service Plugin for Android and PIXMA Cloud Link apps. You can also print to iron-on transfer media or stickers and make your next project stand out.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536,W300','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P6536,S514,D543,C500,I523241,A100,E520,R520,O100,W100,O1352,O600,A160,W300,A140,A61653,C430,P65352,M610,O500,A5363,P500,F500,C63632,G300,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,F600,Q000,C631,P21432,A63232,A162,P6232,E2131653,E360,S612,P425,P250,L520,A120,A420,I650,T65216,M300,S3262,M200,N230,P623,S353,O300',4,0,'canon-pixma-ts7451-allinone-wireless-inkjet-printer-white','',0,0,'','','','',1,1,'',''),(45,1,'CANON PIXMA TS7451 AllinOne Wireless Inkjet Printer White','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS7451 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer. Simply download the Canon PRINT Inkjet/SELPHY app to enjoy a range of WiFi connectivity options. Or print app-free with Apple AirPrint, Cloud Printing or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as 2 Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with the Easy-PhotoPrint Editor, Canon Print Service Plugin for Android and PIXMA Cloud Link apps. You can also print to iron-on transfer media or stickers and make your next project stand out.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536,W300','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P6536,S514,D543,C500,I523241,A100,E520,R520,O100,W100,O1352,O600,A160,W300,A140,A61653,C430,P65352,M610,O500,A5363,P500,F500,C63632,G300,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,F600,Q000,C631,P21432,A63232,A162,P6232,E2131653,E360,S612,P425,P250,L520,A120,A420,I650,T65216,M300,S3262,M200,N230,P623,S353,O300',5,0,'canon-pixma-ts7451-allinone-wireless-inkjet-printer-white','',0,0,'','','','',1,1,'',''),(45,1,'CANON PIXMA TS7451 AllinOne Wireless Inkjet Printer White','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS7451 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer. Simply download the Canon PRINT Inkjet/SELPHY app to enjoy a range of WiFi connectivity options. Or print app-free with Apple AirPrint, Cloud Printing or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as 2 Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with the Easy-PhotoPrint Editor, Canon Print Service Plugin for Android and PIXMA Cloud Link apps. You can also print to iron-on transfer media or stickers and make your next project stand out.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536,W300','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P6536,S514,D543,C500,I523241,A100,E520,R520,O100,W100,O1352,O600,A160,W300,A140,A61653,C430,P65352,M610,O500,A5363,P500,F500,C63632,G300,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,F600,Q000,C631,P21432,A63232,A162,P6232,E2131653,E360,S612,P425,P250,L520,A120,A420,I650,T65216,M300,S3262,M200,N230,P623,S353,O300',6,0,'canon-pixma-ts7451-allinone-wireless-inkjet-printer-white','',0,0,'','','','',1,1,'',''),(45,1,'CANON PIXMA TS7451 AllinOne Wireless Inkjet Printer White','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS7451 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer. Simply download the Canon PRINT Inkjet/SELPHY app to enjoy a range of WiFi connectivity options. Or print app-free with Apple AirPrint, Cloud Printing or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as 2 Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with the Easy-PhotoPrint Editor, Canon Print Service Plugin for Android and PIXMA Cloud Link apps. You can also print to iron-on transfer media or stickers and make your next project stand out.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536,W300','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P6536,S514,D543,C500,I523241,A100,E520,R520,O100,W100,O1352,O600,A160,W300,A140,A61653,C430,P65352,M610,O500,A5363,P500,F500,C63632,G300,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,F600,Q000,C631,P21432,A63232,A162,P6232,E2131653,E360,S612,P425,P250,L520,A120,A420,I650,T65216,M300,S3262,M200,N230,P623,S353,O300',7,0,'canon-pixma-ts7451-allinone-wireless-inkjet-printer-white','',0,0,'','','','',1,1,'',''),(45,1,'CANON PIXMA TS7451 AllinOne Wireless Inkjet Printer White','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS7451 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer. Simply download the Canon PRINT Inkjet/SELPHY app to enjoy a range of WiFi connectivity options. Or print app-free with Apple AirPrint, Cloud Printing or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as 2 Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with the Easy-PhotoPrint Editor, Canon Print Service Plugin for Android and PIXMA Cloud Link apps. You can also print to iron-on transfer media or stickers and make your next project stand out.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536,W300','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P6536,S514,D543,C500,I523241,A100,E520,R520,O100,W100,O1352,O600,A160,W300,A140,A61653,C430,P65352,M610,O500,A5363,P500,F500,C63632,G300,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,F600,Q000,C631,P21432,A63232,A162,P6232,E2131653,E360,S612,P425,P250,L520,A120,A420,I650,T65216,M300,S3262,M200,N230,P623,S353,O300',8,0,'canon-pixma-ts7451-allinone-wireless-inkjet-printer-white','',0,0,'','','','',1,1,'',''),(45,1,'CANON PIXMA TS7451 AllinOne Wireless Inkjet Printer White','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS7451 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer. Simply download the Canon PRINT Inkjet/SELPHY app to enjoy a range of WiFi connectivity options. Or print app-free with Apple AirPrint, Cloud Printing or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as 2 Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with the Easy-PhotoPrint Editor, Canon Print Service Plugin for Android and PIXMA Cloud Link apps. You can also print to iron-on transfer media or stickers and make your next project stand out.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536,W300','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P6536,S514,D543,C500,I523241,A100,E520,R520,O100,W100,O1352,O600,A160,W300,A140,A61653,C430,P65352,M610,O500,A5363,P500,F500,C63632,G300,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,F600,Q000,C631,P21432,A63232,A162,P6232,E2131653,E360,S612,P425,P250,L520,A120,A420,I650,T65216,M300,S3262,M200,N230,P623,S353,O300',9,0,'canon-pixma-ts7451-allinone-wireless-inkjet-printer-white','',0,0,'','','','',1,1,'',''),(45,1,'CANON PIXMA TS7451 AllinOne Wireless Inkjet Printer White','<strong>Smart connectivity</strong><br />\r\n<br />\r\nThe Canon&nbsp;<strong>PIXMA TS7451 All-in-One Wireless Inkjet Printer</strong>&nbsp;makes it possible to print and scan wirelessly from your smart device, so you&#39;re no longer tethered to the printer. Simply download the Canon PRINT Inkjet/SELPHY app to enjoy a range of WiFi connectivity options. Or print app-free with Apple AirPrint, Cloud Printing or Morphia on your Android phone.<br />\r\n<br />\r\n<strong>Canon FINE cartridges</strong><br />\r\n<br />\r\nGet printing straight away as 2 Canon FINE cartridges are included in the box. You can print up to 180 pages from a single cartridge. Plus, they&#39;re durable and easy to replace &ndash; ideal for quick and simple printing.<br />\r\n<br />\r\n<strong>Creative possibilities</strong><br />\r\n<br />\r\nTry new artistic approaches to your projects with the Easy-PhotoPrint Editor, Canon Print Service Plugin for Android and PIXMA Cloud Link apps. You can also print to iron-on transfer media or stickers and make your next project stand out.','',0,'','','','','','C500,P250,T200,A450,W642,I523,P6536,W300','S563,C52313,T000,C512125,T200,A450,W642,I523,P6536512152,I300,P214,P653,A530,S500,W6424,F650,Y600,D120,S000,N000,L526,T630,P6536,S514,D543,C500,I523241,A100,E520,R520,O100,W100,O1352,O600,A160,W300,A140,A61653,C430,P65352,M610,O500,A5363,P500,F500,C63632,G300,S3623,A000,A200,A600,I5243,I500,B200,Y000,U100,P200,S524,P420,T600,D614,E200,R142,N320,I340,F600,Q000,C631,P21432,A63232,A162,P6232,E2131653,E360,S612,P425,P250,L520,A120,A420,I650,T65216,M300,S3262,M200,N230,P623,S353,O300',10,0,'canon-pixma-ts7451-allinone-wireless-inkjet-printer-white','',0,0,'','','','',1,1,'',''),(46,1,'BROTHER MFCL3750CDW AllinOne Laser Printer with Fax','Whether you want to print, copy, scan or fax, the Brother&nbsp;<strong>MFCL3750CDW All-in-One Laser Printer with Fax</strong>&nbsp;has got you covered.<br />\r\n<br />\r\nWhatever the print job, you&#39;ll be able to get it done quickly and in high quality. You can even print wirelessly from your smart devices via WiFi or Apple AirPrint.<br />\r\n<br />\r\nTry automatic 2-sided printing to save paper. Or scan to popular cloud apps directly from the easy-to-read colour touchscreen.<br />\r\n<br />\r\nAnd with a 250 sheet capacity, you won&#39;t have to keep restocking the paper tray.','',0,'','','','','','B636,M12423,A450,L260,P6536,W300,F200','W360,Y000,W530,T000,P653,C100,S500,O600,F200,B6365121512423,A450,L260,P6536,W300,F251212,G300,C163,W316,J100,Y400,B000,A140,I300,D500,Q400,A530,I500,H200,Q430,C500,E150,W6424,F650,Y600,S563,D120,V000,W100,A61653,T600,A3532,S300,P65352,S100,P600,P460,C430,A120,D6234,E2363,C460,T265,C123,H100,K100,R23252',1,0,'brother-mfcl3750cdw-allinone-laser-printer-with-fax','',0,0,'','','','',1,1,'',''),(46,1,'BROTHER MFCL3750CDW AllinOne Laser Printer with Fax','Whether you want to print, copy, scan or fax, the Brother&nbsp;<strong>MFCL3750CDW All-in-One Laser Printer with Fax</strong>&nbsp;has got you covered.<br />\r\n<br />\r\nWhatever the print job, you&#39;ll be able to get it done quickly and in high quality. You can even print wirelessly from your smart devices via WiFi or Apple AirPrint.<br />\r\n<br />\r\nTry automatic 2-sided printing to save paper. Or scan to popular cloud apps directly from the easy-to-read colour touchscreen.<br />\r\n<br />\r\nAnd with a 250 sheet capacity, you won&#39;t have to keep restocking the paper tray.','',0,'','','','','','B636,M12423,A450,L260,P6536,W300,F200','W360,Y000,W530,T000,P653,C100,S500,O600,F200,B6365121512423,A450,L260,P6536,W300,F251212,G300,C163,W316,J100,Y400,B000,A140,I300,D500,Q400,A530,I500,H200,Q430,C500,E150,W6424,F650,Y600,S563,D120,V000,W100,A61653,T600,A3532,S300,P65352,S100,P600,P460,C430,A120,D6234,E2363,C460,T265,C123,H100,K100,R23252',4,0,'brother-mfcl3750cdw-allinone-laser-printer-with-fax','',0,0,'','','','',1,1,'',''),(46,1,'BROTHER MFCL3750CDW AllinOne Laser Printer with Fax','Whether you want to print, copy, scan or fax, the Brother&nbsp;<strong>MFCL3750CDW All-in-One Laser Printer with Fax</strong>&nbsp;has got you covered.<br />\r\n<br />\r\nWhatever the print job, you&#39;ll be able to get it done quickly and in high quality. You can even print wirelessly from your smart devices via WiFi or Apple AirPrint.<br />\r\n<br />\r\nTry automatic 2-sided printing to save paper. Or scan to popular cloud apps directly from the easy-to-read colour touchscreen.<br />\r\n<br />\r\nAnd with a 250 sheet capacity, you won&#39;t have to keep restocking the paper tray.','',0,'','','','','','B636,M12423,A450,L260,P6536,W300,F200','W360,Y000,W530,T000,P653,C100,S500,O600,F200,B6365121512423,A450,L260,P6536,W300,F251212,G300,C163,W316,J100,Y400,B000,A140,I300,D500,Q400,A530,I500,H200,Q430,C500,E150,W6424,F650,Y600,S563,D120,V000,W100,A61653,T600,A3532,S300,P65352,S100,P600,P460,C430,A120,D6234,E2363,C460,T265,C123,H100,K100,R23252',5,0,'brother-mfcl3750cdw-allinone-laser-printer-with-fax','',0,0,'','','','',1,1,'',''),(46,1,'BROTHER MFCL3750CDW AllinOne Laser Printer with Fax','Whether you want to print, copy, scan or fax, the Brother&nbsp;<strong>MFCL3750CDW All-in-One Laser Printer with Fax</strong>&nbsp;has got you covered.<br />\r\n<br />\r\nWhatever the print job, you&#39;ll be able to get it done quickly and in high quality. You can even print wirelessly from your smart devices via WiFi or Apple AirPrint.<br />\r\n<br />\r\nTry automatic 2-sided printing to save paper. Or scan to popular cloud apps directly from the easy-to-read colour touchscreen.<br />\r\n<br />\r\nAnd with a 250 sheet capacity, you won&#39;t have to keep restocking the paper tray.','',0,'','','','','','B636,M12423,A450,L260,P6536,W300,F200','W360,Y000,W530,T000,P653,C100,S500,O600,F200,B6365121512423,A450,L260,P6536,W300,F251212,G300,C163,W316,J100,Y400,B000,A140,I300,D500,Q400,A530,I500,H200,Q430,C500,E150,W6424,F650,Y600,S563,D120,V000,W100,A61653,T600,A3532,S300,P65352,S100,P600,P460,C430,A120,D6234,E2363,C460,T265,C123,H100,K100,R23252',6,0,'brother-mfcl3750cdw-allinone-laser-printer-with-fax','',0,0,'','','','',1,1,'',''),(46,1,'BROTHER MFCL3750CDW AllinOne Laser Printer with Fax','Whether you want to print, copy, scan or fax, the Brother&nbsp;<strong>MFCL3750CDW All-in-One Laser Printer with Fax</strong>&nbsp;has got you covered.<br />\r\n<br />\r\nWhatever the print job, you&#39;ll be able to get it done quickly and in high quality. You can even print wirelessly from your smart devices via WiFi or Apple AirPrint.<br />\r\n<br />\r\nTry automatic 2-sided printing to save paper. Or scan to popular cloud apps directly from the easy-to-read colour touchscreen.<br />\r\n<br />\r\nAnd with a 250 sheet capacity, you won&#39;t have to keep restocking the paper tray.','',0,'','','','','','B636,M12423,A450,L260,P6536,W300,F200','W360,Y000,W530,T000,P653,C100,S500,O600,F200,B6365121512423,A450,L260,P6536,W300,F251212,G300,C163,W316,J100,Y400,B000,A140,I300,D500,Q400,A530,I500,H200,Q430,C500,E150,W6424,F650,Y600,S563,D120,V000,W100,A61653,T600,A3532,S300,P65352,S100,P600,P460,C430,A120,D6234,E2363,C460,T265,C123,H100,K100,R23252',7,0,'brother-mfcl3750cdw-allinone-laser-printer-with-fax','',0,0,'','','','',1,1,'',''),(46,1,'BROTHER MFCL3750CDW AllinOne Laser Printer with Fax','Whether you want to print, copy, scan or fax, the Brother&nbsp;<strong>MFCL3750CDW All-in-One Laser Printer with Fax</strong>&nbsp;has got you covered.<br />\r\n<br />\r\nWhatever the print job, you&#39;ll be able to get it done quickly and in high quality. You can even print wirelessly from your smart devices via WiFi or Apple AirPrint.<br />\r\n<br />\r\nTry automatic 2-sided printing to save paper. Or scan to popular cloud apps directly from the easy-to-read colour touchscreen.<br />\r\n<br />\r\nAnd with a 250 sheet capacity, you won&#39;t have to keep restocking the paper tray.','',0,'','','','','','B636,M12423,A450,L260,P6536,W300,F200','W360,Y000,W530,T000,P653,C100,S500,O600,F200,B6365121512423,A450,L260,P6536,W300,F251212,G300,C163,W316,J100,Y400,B000,A140,I300,D500,Q400,A530,I500,H200,Q430,C500,E150,W6424,F650,Y600,S563,D120,V000,W100,A61653,T600,A3532,S300,P65352,S100,P600,P460,C430,A120,D6234,E2363,C460,T265,C123,H100,K100,R23252',8,0,'brother-mfcl3750cdw-allinone-laser-printer-with-fax','',0,0,'','','','',1,1,'',''),(46,1,'BROTHER MFCL3750CDW AllinOne Laser Printer with Fax','Whether you want to print, copy, scan or fax, the Brother&nbsp;<strong>MFCL3750CDW All-in-One Laser Printer with Fax</strong>&nbsp;has got you covered.<br />\r\n<br />\r\nWhatever the print job, you&#39;ll be able to get it done quickly and in high quality. You can even print wirelessly from your smart devices via WiFi or Apple AirPrint.<br />\r\n<br />\r\nTry automatic 2-sided printing to save paper. Or scan to popular cloud apps directly from the easy-to-read colour touchscreen.<br />\r\n<br />\r\nAnd with a 250 sheet capacity, you won&#39;t have to keep restocking the paper tray.','',0,'','','','','','B636,M12423,A450,L260,P6536,W300,F200','W360,Y000,W530,T000,P653,C100,S500,O600,F200,B6365121512423,A450,L260,P6536,W300,F251212,G300,C163,W316,J100,Y400,B000,A140,I300,D500,Q400,A530,I500,H200,Q430,C500,E150,W6424,F650,Y600,S563,D120,V000,W100,A61653,T600,A3532,S300,P65352,S100,P600,P460,C430,A120,D6234,E2363,C460,T265,C123,H100,K100,R23252',9,0,'brother-mfcl3750cdw-allinone-laser-printer-with-fax','',0,0,'','','','',1,1,'',''),(46,1,'BROTHER MFCL3750CDW AllinOne Laser Printer with Fax','Whether you want to print, copy, scan or fax, the Brother&nbsp;<strong>MFCL3750CDW All-in-One Laser Printer with Fax</strong>&nbsp;has got you covered.<br />\r\n<br />\r\nWhatever the print job, you&#39;ll be able to get it done quickly and in high quality. You can even print wirelessly from your smart devices via WiFi or Apple AirPrint.<br />\r\n<br />\r\nTry automatic 2-sided printing to save paper. Or scan to popular cloud apps directly from the easy-to-read colour touchscreen.<br />\r\n<br />\r\nAnd with a 250 sheet capacity, you won&#39;t have to keep restocking the paper tray.','',0,'','','','','','B636,M12423,A450,L260,P6536,W300,F200','W360,Y000,W530,T000,P653,C100,S500,O600,F200,B6365121512423,A450,L260,P6536,W300,F251212,G300,C163,W316,J100,Y400,B000,A140,I300,D500,Q400,A530,I500,H200,Q430,C500,E150,W6424,F650,Y600,S563,D120,V000,W100,A61653,T600,A3532,S300,P65352,S100,P600,P460,C430,A120,D6234,E2363,C460,T265,C123,H100,K100,R23252',10,0,'brother-mfcl3750cdw-allinone-laser-printer-with-fax','',0,0,'','','','',1,1,'',''),(47,1,'BROTHER HLL2310D Monochrome Laser Printer','Save space in your home office with the Brother&nbsp;<strong>HLL2310D Monochrome Laser Printer</strong>. It&#39;ll fit on your desk right alongside a monitor, keeping all your essentials in one place.<br />\r\n<br />\r\nYou won&#39;t waste time waiting for printing anymore, as the Brother&nbsp;<strong>HLL2310D&nbsp;</strong>can churn out 30 pages a minute. You&#39;ll have hard copies of your documents&nbsp;in no time.<br />\r\n<br />\r\nWith automatic double-sided printing, and a tray that holds 250 sheets of paper, you won&#39;t have to worry about topping up the paper all the time.','',0,'','','','','','B636,H430,M265,L260,P6536','S100,S120,I500,Y600,H500,O120,W300,T000,B636512143,M265,L260,P6536,I340,F300,O500,D200,R230,A4523,M360,K152,A400,E25342,P420,Y000,W530,W230,T500,W352,F600,P65352,A560,A200,B636512143512125,C650,O300,P200,M300,Y400,H100,H630,C120,O100,D253251215,N000,A3532,D1423,A530,T600,H432,S320,P600,W600,A130,T152,U100',1,0,'brother-hll2310d-monochrome-laser-printer','',0,0,'','','','',1,1,'',''),(47,1,'BROTHER HLL2310D Monochrome Laser Printer','Save space in your home office with the Brother&nbsp;<strong>HLL2310D Monochrome Laser Printer</strong>. It&#39;ll fit on your desk right alongside a monitor, keeping all your essentials in one place.<br />\r\n<br />\r\nYou won&#39;t waste time waiting for printing anymore, as the Brother&nbsp;<strong>HLL2310D&nbsp;</strong>can churn out 30 pages a minute. You&#39;ll have hard copies of your documents&nbsp;in no time.<br />\r\n<br />\r\nWith automatic double-sided printing, and a tray that holds 250 sheets of paper, you won&#39;t have to worry about topping up the paper all the time.','',0,'','','','','','B636,H430,M265,L260,P6536','S100,S120,I500,Y600,H500,O120,W300,T000,B636512143,M265,L260,P6536,I340,F300,O500,D200,R230,A4523,M360,K152,A400,E25342,P420,Y000,W530,W230,T500,W352,F600,P65352,A560,A200,B636512143512125,C650,O300,P200,M300,Y400,H100,H630,C120,O100,D253251215,N000,A3532,D1423,A530,T600,H432,S320,P600,W600,A130,T152,U100',4,0,'brother-hll2310d-monochrome-laser-printer','',0,0,'','','','',1,1,'',''),(47,1,'BROTHER HLL2310D Monochrome Laser Printer','Save space in your home office with the Brother&nbsp;<strong>HLL2310D Monochrome Laser Printer</strong>. It&#39;ll fit on your desk right alongside a monitor, keeping all your essentials in one place.<br />\r\n<br />\r\nYou won&#39;t waste time waiting for printing anymore, as the Brother&nbsp;<strong>HLL2310D&nbsp;</strong>can churn out 30 pages a minute. You&#39;ll have hard copies of your documents&nbsp;in no time.<br />\r\n<br />\r\nWith automatic double-sided printing, and a tray that holds 250 sheets of paper, you won&#39;t have to worry about topping up the paper all the time.','',0,'','','','','','B636,H430,M265,L260,P6536','S100,S120,I500,Y600,H500,O120,W300,T000,B636512143,M265,L260,P6536,I340,F300,O500,D200,R230,A4523,M360,K152,A400,E25342,P420,Y000,W530,W230,T500,W352,F600,P65352,A560,A200,B636512143512125,C650,O300,P200,M300,Y400,H100,H630,C120,O100,D253251215,N000,A3532,D1423,A530,T600,H432,S320,P600,W600,A130,T152,U100',5,0,'brother-hll2310d-monochrome-laser-printer','',0,0,'','','','',1,1,'',''),(47,1,'BROTHER HLL2310D Monochrome Laser Printer','Save space in your home office with the Brother&nbsp;<strong>HLL2310D Monochrome Laser Printer</strong>. It&#39;ll fit on your desk right alongside a monitor, keeping all your essentials in one place.<br />\r\n<br />\r\nYou won&#39;t waste time waiting for printing anymore, as the Brother&nbsp;<strong>HLL2310D&nbsp;</strong>can churn out 30 pages a minute. You&#39;ll have hard copies of your documents&nbsp;in no time.<br />\r\n<br />\r\nWith automatic double-sided printing, and a tray that holds 250 sheets of paper, you won&#39;t have to worry about topping up the paper all the time.','',0,'','','','','','B636,H430,M265,L260,P6536','S100,S120,I500,Y600,H500,O120,W300,T000,B636512143,M265,L260,P6536,I340,F300,O500,D200,R230,A4523,M360,K152,A400,E25342,P420,Y000,W530,W230,T500,W352,F600,P65352,A560,A200,B636512143512125,C650,O300,P200,M300,Y400,H100,H630,C120,O100,D253251215,N000,A3532,D1423,A530,T600,H432,S320,P600,W600,A130,T152,U100',6,0,'brother-hll2310d-monochrome-laser-printer','',0,0,'','','','',1,1,'',''),(47,1,'BROTHER HLL2310D Monochrome Laser Printer','Save space in your home office with the Brother&nbsp;<strong>HLL2310D Monochrome Laser Printer</strong>. It&#39;ll fit on your desk right alongside a monitor, keeping all your essentials in one place.<br />\r\n<br />\r\nYou won&#39;t waste time waiting for printing anymore, as the Brother&nbsp;<strong>HLL2310D&nbsp;</strong>can churn out 30 pages a minute. You&#39;ll have hard copies of your documents&nbsp;in no time.<br />\r\n<br />\r\nWith automatic double-sided printing, and a tray that holds 250 sheets of paper, you won&#39;t have to worry about topping up the paper all the time.','',0,'','','','','','B636,H430,M265,L260,P6536','S100,S120,I500,Y600,H500,O120,W300,T000,B636512143,M265,L260,P6536,I340,F300,O500,D200,R230,A4523,M360,K152,A400,E25342,P420,Y000,W530,W230,T500,W352,F600,P65352,A560,A200,B636512143512125,C650,O300,P200,M300,Y400,H100,H630,C120,O100,D253251215,N000,A3532,D1423,A530,T600,H432,S320,P600,W600,A130,T152,U100',7,0,'brother-hll2310d-monochrome-laser-printer','',0,0,'','','','',1,1,'',''),(47,1,'BROTHER HLL2310D Monochrome Laser Printer','Save space in your home office with the Brother&nbsp;<strong>HLL2310D Monochrome Laser Printer</strong>. It&#39;ll fit on your desk right alongside a monitor, keeping all your essentials in one place.<br />\r\n<br />\r\nYou won&#39;t waste time waiting for printing anymore, as the Brother&nbsp;<strong>HLL2310D&nbsp;</strong>can churn out 30 pages a minute. You&#39;ll have hard copies of your documents&nbsp;in no time.<br />\r\n<br />\r\nWith automatic double-sided printing, and a tray that holds 250 sheets of paper, you won&#39;t have to worry about topping up the paper all the time.','',0,'','','','','','B636,H430,M265,L260,P6536','S100,S120,I500,Y600,H500,O120,W300,T000,B636512143,M265,L260,P6536,I340,F300,O500,D200,R230,A4523,M360,K152,A400,E25342,P420,Y000,W530,W230,T500,W352,F600,P65352,A560,A200,B636512143512125,C650,O300,P200,M300,Y400,H100,H630,C120,O100,D253251215,N000,A3532,D1423,A530,T600,H432,S320,P600,W600,A130,T152,U100',8,0,'brother-hll2310d-monochrome-laser-printer','',0,0,'','','','',1,1,'',''),(47,1,'BROTHER HLL2310D Monochrome Laser Printer','Save space in your home office with the Brother&nbsp;<strong>HLL2310D Monochrome Laser Printer</strong>. It&#39;ll fit on your desk right alongside a monitor, keeping all your essentials in one place.<br />\r\n<br />\r\nYou won&#39;t waste time waiting for printing anymore, as the Brother&nbsp;<strong>HLL2310D&nbsp;</strong>can churn out 30 pages a minute. You&#39;ll have hard copies of your documents&nbsp;in no time.<br />\r\n<br />\r\nWith automatic double-sided printing, and a tray that holds 250 sheets of paper, you won&#39;t have to worry about topping up the paper all the time.','',0,'','','','','','B636,H430,M265,L260,P6536','S100,S120,I500,Y600,H500,O120,W300,T000,B636512143,M265,L260,P6536,I340,F300,O500,D200,R230,A4523,M360,K152,A400,E25342,P420,Y000,W530,W230,T500,W352,F600,P65352,A560,A200,B636512143512125,C650,O300,P200,M300,Y400,H100,H630,C120,O100,D253251215,N000,A3532,D1423,A530,T600,H432,S320,P600,W600,A130,T152,U100',9,0,'brother-hll2310d-monochrome-laser-printer','',0,0,'','','','',1,1,'',''),(47,1,'BROTHER HLL2310D Monochrome Laser Printer','Save space in your home office with the Brother&nbsp;<strong>HLL2310D Monochrome Laser Printer</strong>. It&#39;ll fit on your desk right alongside a monitor, keeping all your essentials in one place.<br />\r\n<br />\r\nYou won&#39;t waste time waiting for printing anymore, as the Brother&nbsp;<strong>HLL2310D&nbsp;</strong>can churn out 30 pages a minute. You&#39;ll have hard copies of your documents&nbsp;in no time.<br />\r\n<br />\r\nWith automatic double-sided printing, and a tray that holds 250 sheets of paper, you won&#39;t have to worry about topping up the paper all the time.','',0,'','','','','','B636,H430,M265,L260,P6536','S100,S120,I500,Y600,H500,O120,W300,T000,B636512143,M265,L260,P6536,I340,F300,O500,D200,R230,A4523,M360,K152,A400,E25342,P420,Y000,W530,W230,T500,W352,F600,P65352,A560,A200,B636512143512125,C650,O300,P200,M300,Y400,H100,H630,C120,O100,D253251215,N000,A3532,D1423,A530,T600,H432,S320,P600,W600,A130,T152,U100',10,0,'brother-hll2310d-monochrome-laser-printer','',0,0,'','','','',1,1,'',''),(48,1,'BROTHER DCP1612W Monochrome AllinOne Wireless Laser Printer','Boost your productivity and take advantage of wireless printing with the Brother&nbsp;<strong>DCP1612W Monochrome All-in-One Wireless Laser Printer.</strong><br />\r\n<br />\r\n<strong>Fast wireless printing</strong><br />\r\n<br />\r\nWith speeds of up to 20 pages per minute, keep on top of projects without worrying about your printer slowing you down. The&nbsp;<strong>Compact&nbsp;</strong>features built-in wireless so you can print cable-free from anywhere in the office or at home. Download the Brother iPrint &amp; Scan app and you can also print straight from your smartphone or tablet remotely, anytime and anywhere.<br />\r\n<br />\r\n<strong>Get more done</strong><br />\r\n<br />\r\nWith a 150 sheet paper tray and easy replacement 1,000 page toner cartridges, the&nbsp;<strong>DCP1612W&nbsp;</strong>lets you print, copy and scan until your heart&#39;s content. Designed to fit a variety of page sizes and with a high print and scan resolution &ndash; the Brother Laser printer suits a variety of printing tasks.<br />\r\n<br />\r\nEasy to use and highly efficient, the Brother&nbsp;<strong>Compact DCP1612W Monochrome All-in-One Wireless Laser Printer&nbsp;</strong>gives you convenient wireless printing at home or in the office.','',0,'','','','','','B636,D210,M265,A450,W642,L260,P6536','B230,Y600,P632313,A530,T200,A31532,O100,W642,P65352,W300,T000,B6365121321,M265,A450,L260,P6536,F230,S132,U100,P200,P600,M300,K100,O500,T100,P6232,W652,A130,S452,Y000,D500,T5121251235121362,B435,S000,C500,P653,C1416,F650,A560,I500,O120,O600,A300,H500,D543,B636,I1653,A510,S500,A100,A420,S3623,S56315,T143,R534,A535,G300,M600,S300,T600,E200,R14253,T560,C63632,T51213215121432,C100,U534,H632,C5353,D253,F300,V630,H200,R2435,N320,S320,U200,H240,E1253,B636512125123,D210,P65365121212,C5153',1,0,'brother-dcp1612w-monochrome-allinone-wireless-laser-printer','',0,0,'','','','',1,1,'',''),(48,1,'BROTHER DCP1612W Monochrome AllinOne Wireless Laser Printer','Boost your productivity and take advantage of wireless printing with the Brother&nbsp;<strong>DCP1612W Monochrome All-in-One Wireless Laser Printer.</strong><br />\r\n<br />\r\n<strong>Fast wireless printing</strong><br />\r\n<br />\r\nWith speeds of up to 20 pages per minute, keep on top of projects without worrying about your printer slowing you down. The&nbsp;<strong>Compact&nbsp;</strong>features built-in wireless so you can print cable-free from anywhere in the office or at home. Download the Brother iPrint &amp; Scan app and you can also print straight from your smartphone or tablet remotely, anytime and anywhere.<br />\r\n<br />\r\n<strong>Get more done</strong><br />\r\n<br />\r\nWith a 150 sheet paper tray and easy replacement 1,000 page toner cartridges, the&nbsp;<strong>DCP1612W&nbsp;</strong>lets you print, copy and scan until your heart&#39;s content. Designed to fit a variety of page sizes and with a high print and scan resolution &ndash; the Brother Laser printer suits a variety of printing tasks.<br />\r\n<br />\r\nEasy to use and highly efficient, the Brother&nbsp;<strong>Compact DCP1612W Monochrome All-in-One Wireless Laser Printer&nbsp;</strong>gives you convenient wireless printing at home or in the office.','',0,'','','','','','B636,D210,M265,A450,W642,L260,P6536','B230,Y600,P632313,A530,T200,A31532,O100,W642,P65352,W300,T000,B6365121321,M265,A450,L260,P6536,F230,S132,U100,P200,P600,M300,K100,O500,T100,P6232,W652,A130,S452,Y000,D500,T5121251235121362,B435,S000,C500,P653,C1416,F650,A560,I500,O120,O600,A300,H500,D543,B636,I1653,A510,S500,A100,A420,S3623,S56315,T143,R534,A535,G300,M600,S300,T600,E200,R14253,T560,C63632,T51213215121432,C100,U534,H632,C5353,D253,F300,V630,H200,R2435,N320,S320,U200,H240,E1253,B636512125123,D210,P65365121212,C5153',4,0,'brother-dcp1612w-monochrome-allinone-wireless-laser-printer','',0,0,'','','','',1,1,'',''),(48,1,'BROTHER DCP1612W Monochrome AllinOne Wireless Laser Printer','Boost your productivity and take advantage of wireless printing with the Brother&nbsp;<strong>DCP1612W Monochrome All-in-One Wireless Laser Printer.</strong><br />\r\n<br />\r\n<strong>Fast wireless printing</strong><br />\r\n<br />\r\nWith speeds of up to 20 pages per minute, keep on top of projects without worrying about your printer slowing you down. The&nbsp;<strong>Compact&nbsp;</strong>features built-in wireless so you can print cable-free from anywhere in the office or at home. Download the Brother iPrint &amp; Scan app and you can also print straight from your smartphone or tablet remotely, anytime and anywhere.<br />\r\n<br />\r\n<strong>Get more done</strong><br />\r\n<br />\r\nWith a 150 sheet paper tray and easy replacement 1,000 page toner cartridges, the&nbsp;<strong>DCP1612W&nbsp;</strong>lets you print, copy and scan until your heart&#39;s content. Designed to fit a variety of page sizes and with a high print and scan resolution &ndash; the Brother Laser printer suits a variety of printing tasks.<br />\r\n<br />\r\nEasy to use and highly efficient, the Brother&nbsp;<strong>Compact DCP1612W Monochrome All-in-One Wireless Laser Printer&nbsp;</strong>gives you convenient wireless printing at home or in the office.','',0,'','','','','','B636,D210,M265,A450,W642,L260,P6536','B230,Y600,P632313,A530,T200,A31532,O100,W642,P65352,W300,T000,B6365121321,M265,A450,L260,P6536,F230,S132,U100,P200,P600,M300,K100,O500,T100,P6232,W652,A130,S452,Y000,D500,T5121251235121362,B435,S000,C500,P653,C1416,F650,A560,I500,O120,O600,A300,H500,D543,B636,I1653,A510,S500,A100,A420,S3623,S56315,T143,R534,A535,G300,M600,S300,T600,E200,R14253,T560,C63632,T51213215121432,C100,U534,H632,C5353,D253,F300,V630,H200,R2435,N320,S320,U200,H240,E1253,B636512125123,D210,P65365121212,C5153',5,0,'brother-dcp1612w-monochrome-allinone-wireless-laser-printer','',0,0,'','','','',1,1,'',''),(48,1,'BROTHER DCP1612W Monochrome AllinOne Wireless Laser Printer','Boost your productivity and take advantage of wireless printing with the Brother&nbsp;<strong>DCP1612W Monochrome All-in-One Wireless Laser Printer.</strong><br />\r\n<br />\r\n<strong>Fast wireless printing</strong><br />\r\n<br />\r\nWith speeds of up to 20 pages per minute, keep on top of projects without worrying about your printer slowing you down. The&nbsp;<strong>Compact&nbsp;</strong>features built-in wireless so you can print cable-free from anywhere in the office or at home. Download the Brother iPrint &amp; Scan app and you can also print straight from your smartphone or tablet remotely, anytime and anywhere.<br />\r\n<br />\r\n<strong>Get more done</strong><br />\r\n<br />\r\nWith a 150 sheet paper tray and easy replacement 1,000 page toner cartridges, the&nbsp;<strong>DCP1612W&nbsp;</strong>lets you print, copy and scan until your heart&#39;s content. Designed to fit a variety of page sizes and with a high print and scan resolution &ndash; the Brother Laser printer suits a variety of printing tasks.<br />\r\n<br />\r\nEasy to use and highly efficient, the Brother&nbsp;<strong>Compact DCP1612W Monochrome All-in-One Wireless Laser Printer&nbsp;</strong>gives you convenient wireless printing at home or in the office.','',0,'','','','','','B636,D210,M265,A450,W642,L260,P6536','B230,Y600,P632313,A530,T200,A31532,O100,W642,P65352,W300,T000,B6365121321,M265,A450,L260,P6536,F230,S132,U100,P200,P600,M300,K100,O500,T100,P6232,W652,A130,S452,Y000,D500,T5121251235121362,B435,S000,C500,P653,C1416,F650,A560,I500,O120,O600,A300,H500,D543,B636,I1653,A510,S500,A100,A420,S3623,S56315,T143,R534,A535,G300,M600,S300,T600,E200,R14253,T560,C63632,T51213215121432,C100,U534,H632,C5353,D253,F300,V630,H200,R2435,N320,S320,U200,H240,E1253,B636512125123,D210,P65365121212,C5153',6,0,'brother-dcp1612w-monochrome-allinone-wireless-laser-printer','',0,0,'','','','',1,1,'',''),(48,1,'BROTHER DCP1612W Monochrome AllinOne Wireless Laser Printer','Boost your productivity and take advantage of wireless printing with the Brother&nbsp;<strong>DCP1612W Monochrome All-in-One Wireless Laser Printer.</strong><br />\r\n<br />\r\n<strong>Fast wireless printing</strong><br />\r\n<br />\r\nWith speeds of up to 20 pages per minute, keep on top of projects without worrying about your printer slowing you down. The&nbsp;<strong>Compact&nbsp;</strong>features built-in wireless so you can print cable-free from anywhere in the office or at home. Download the Brother iPrint &amp; Scan app and you can also print straight from your smartphone or tablet remotely, anytime and anywhere.<br />\r\n<br />\r\n<strong>Get more done</strong><br />\r\n<br />\r\nWith a 150 sheet paper tray and easy replacement 1,000 page toner cartridges, the&nbsp;<strong>DCP1612W&nbsp;</strong>lets you print, copy and scan until your heart&#39;s content. Designed to fit a variety of page sizes and with a high print and scan resolution &ndash; the Brother Laser printer suits a variety of printing tasks.<br />\r\n<br />\r\nEasy to use and highly efficient, the Brother&nbsp;<strong>Compact DCP1612W Monochrome All-in-One Wireless Laser Printer&nbsp;</strong>gives you convenient wireless printing at home or in the office.','',0,'','','','','','B636,D210,M265,A450,W642,L260,P6536','B230,Y600,P632313,A530,T200,A31532,O100,W642,P65352,W300,T000,B6365121321,M265,A450,L260,P6536,F230,S132,U100,P200,P600,M300,K100,O500,T100,P6232,W652,A130,S452,Y000,D500,T5121251235121362,B435,S000,C500,P653,C1416,F650,A560,I500,O120,O600,A300,H500,D543,B636,I1653,A510,S500,A100,A420,S3623,S56315,T143,R534,A535,G300,M600,S300,T600,E200,R14253,T560,C63632,T51213215121432,C100,U534,H632,C5353,D253,F300,V630,H200,R2435,N320,S320,U200,H240,E1253,B636512125123,D210,P65365121212,C5153',7,0,'brother-dcp1612w-monochrome-allinone-wireless-laser-printer','',0,0,'','','','',1,1,'',''),(48,1,'BROTHER DCP1612W Monochrome AllinOne Wireless Laser Printer','Boost your productivity and take advantage of wireless printing with the Brother&nbsp;<strong>DCP1612W Monochrome All-in-One Wireless Laser Printer.</strong><br />\r\n<br />\r\n<strong>Fast wireless printing</strong><br />\r\n<br />\r\nWith speeds of up to 20 pages per minute, keep on top of projects without worrying about your printer slowing you down. The&nbsp;<strong>Compact&nbsp;</strong>features built-in wireless so you can print cable-free from anywhere in the office or at home. Download the Brother iPrint &amp; Scan app and you can also print straight from your smartphone or tablet remotely, anytime and anywhere.<br />\r\n<br />\r\n<strong>Get more done</strong><br />\r\n<br />\r\nWith a 150 sheet paper tray and easy replacement 1,000 page toner cartridges, the&nbsp;<strong>DCP1612W&nbsp;</strong>lets you print, copy and scan until your heart&#39;s content. Designed to fit a variety of page sizes and with a high print and scan resolution &ndash; the Brother Laser printer suits a variety of printing tasks.<br />\r\n<br />\r\nEasy to use and highly efficient, the Brother&nbsp;<strong>Compact DCP1612W Monochrome All-in-One Wireless Laser Printer&nbsp;</strong>gives you convenient wireless printing at home or in the office.','',0,'','','','','','B636,D210,M265,A450,W642,L260,P6536','B230,Y600,P632313,A530,T200,A31532,O100,W642,P65352,W300,T000,B6365121321,M265,A450,L260,P6536,F230,S132,U100,P200,P600,M300,K100,O500,T100,P6232,W652,A130,S452,Y000,D500,T5121251235121362,B435,S000,C500,P653,C1416,F650,A560,I500,O120,O600,A300,H500,D543,B636,I1653,A510,S500,A100,A420,S3623,S56315,T143,R534,A535,G300,M600,S300,T600,E200,R14253,T560,C63632,T51213215121432,C100,U534,H632,C5353,D253,F300,V630,H200,R2435,N320,S320,U200,H240,E1253,B636512125123,D210,P65365121212,C5153',8,0,'brother-dcp1612w-monochrome-allinone-wireless-laser-printer','',0,0,'','','','',1,1,'',''),(48,1,'BROTHER DCP1612W Monochrome AllinOne Wireless Laser Printer','Boost your productivity and take advantage of wireless printing with the Brother&nbsp;<strong>DCP1612W Monochrome All-in-One Wireless Laser Printer.</strong><br />\r\n<br />\r\n<strong>Fast wireless printing</strong><br />\r\n<br />\r\nWith speeds of up to 20 pages per minute, keep on top of projects without worrying about your printer slowing you down. The&nbsp;<strong>Compact&nbsp;</strong>features built-in wireless so you can print cable-free from anywhere in the office or at home. Download the Brother iPrint &amp; Scan app and you can also print straight from your smartphone or tablet remotely, anytime and anywhere.<br />\r\n<br />\r\n<strong>Get more done</strong><br />\r\n<br />\r\nWith a 150 sheet paper tray and easy replacement 1,000 page toner cartridges, the&nbsp;<strong>DCP1612W&nbsp;</strong>lets you print, copy and scan until your heart&#39;s content. Designed to fit a variety of page sizes and with a high print and scan resolution &ndash; the Brother Laser printer suits a variety of printing tasks.<br />\r\n<br />\r\nEasy to use and highly efficient, the Brother&nbsp;<strong>Compact DCP1612W Monochrome All-in-One Wireless Laser Printer&nbsp;</strong>gives you convenient wireless printing at home or in the office.','',0,'','','','','','B636,D210,M265,A450,W642,L260,P6536','B230,Y600,P632313,A530,T200,A31532,O100,W642,P65352,W300,T000,B6365121321,M265,A450,L260,P6536,F230,S132,U100,P200,P600,M300,K100,O500,T100,P6232,W652,A130,S452,Y000,D500,T5121251235121362,B435,S000,C500,P653,C1416,F650,A560,I500,O120,O600,A300,H500,D543,B636,I1653,A510,S500,A100,A420,S3623,S56315,T143,R534,A535,G300,M600,S300,T600,E200,R14253,T560,C63632,T51213215121432,C100,U534,H632,C5353,D253,F300,V630,H200,R2435,N320,S320,U200,H240,E1253,B636512125123,D210,P65365121212,C5153',9,0,'brother-dcp1612w-monochrome-allinone-wireless-laser-printer','',0,0,'','','','',1,1,'',''),(48,1,'BROTHER DCP1612W Monochrome AllinOne Wireless Laser Printer','Boost your productivity and take advantage of wireless printing with the Brother&nbsp;<strong>DCP1612W Monochrome All-in-One Wireless Laser Printer.</strong><br />\r\n<br />\r\n<strong>Fast wireless printing</strong><br />\r\n<br />\r\nWith speeds of up to 20 pages per minute, keep on top of projects without worrying about your printer slowing you down. The&nbsp;<strong>Compact&nbsp;</strong>features built-in wireless so you can print cable-free from anywhere in the office or at home. Download the Brother iPrint &amp; Scan app and you can also print straight from your smartphone or tablet remotely, anytime and anywhere.<br />\r\n<br />\r\n<strong>Get more done</strong><br />\r\n<br />\r\nWith a 150 sheet paper tray and easy replacement 1,000 page toner cartridges, the&nbsp;<strong>DCP1612W&nbsp;</strong>lets you print, copy and scan until your heart&#39;s content. Designed to fit a variety of page sizes and with a high print and scan resolution &ndash; the Brother Laser printer suits a variety of printing tasks.<br />\r\n<br />\r\nEasy to use and highly efficient, the Brother&nbsp;<strong>Compact DCP1612W Monochrome All-in-One Wireless Laser Printer&nbsp;</strong>gives you convenient wireless printing at home or in the office.','',0,'','','','','','B636,D210,M265,A450,W642,L260,P6536','B230,Y600,P632313,A530,T200,A31532,O100,W642,P65352,W300,T000,B6365121321,M265,A450,L260,P6536,F230,S132,U100,P200,P600,M300,K100,O500,T100,P6232,W652,A130,S452,Y000,D500,T5121251235121362,B435,S000,C500,P653,C1416,F650,A560,I500,O120,O600,A300,H500,D543,B636,I1653,A510,S500,A100,A420,S3623,S56315,T143,R534,A535,G300,M600,S300,T600,E200,R14253,T560,C63632,T51213215121432,C100,U534,H632,C5353,D253,F300,V630,H200,R2435,N320,S320,U200,H240,E1253,B636512125123,D210,P65365121212,C5153',10,0,'brother-dcp1612w-monochrome-allinone-wireless-laser-printer','',0,0,'','','','',1,1,'',''),(49,1,'BROTHER MFCL8690CDW AllinOne Wireless Laser Colour Printer with Fax','<strong>All-in-One printer</strong><br />\r\n<br />\r\nThe Brother&nbsp;<strong>MFC-L8690CDW All-in-One Wireless Laser Printer with Fax&nbsp;</strong>does just about everything. You can print, copy, scan, fax &ndash; and this can all be done wirelessly. Perfect for a small office that doesn&#39;t have space for multiple machines, you can print from or scan to PCs, smartphones, and tablets.<br />\r\n<br />\r\n<strong>Fast printing</strong><br />\r\n<br />\r\nYou can print a whole stack of documents in no time, with a print speed of 31 pages per minute. That means the Brother&nbsp;<strong>MFC-L8690CDW Laser Printer&nbsp;</strong>takes less than two seconds to print each page, even in full colour.<br />\r\n<br />\r\n<strong>Computer-less scanning</strong><br />\r\n<br />\r\nYou don&#39;t even need to turn on a computer to print something out. You can scan files and send them directly to OneNote, Dropbox, email, or SharePoint. You can even post photos directly from the Brother&nbsp;<strong>MFC-L8690CDW&nbsp;</strong>to your Facebook.<br />\r\n<br />\r\n<strong>Touchscreen controls</strong><br />\r\n<br />\r\nWith so many options, easy controls are a must. The sizable 3.7&quot; touchscreen provides a simple way to select the functions you need.','',0,'','','','','','B636,M12423,A450,W642,L260,C460,P6536,W300,F200','A450,P6536,T000,B6365121512423,W642,L260,W300,F2512132,J300,A130,E16352,Y000,C500,P653,C100,S500,F200,N320,A530,T200,A400,B000,D500,W6424,P6123,F600,S540,O120,D253,H100,S120,M4314,M252,F650,O600,P200,S563152,T1432,F230,P65352,W400,S320,O100,D2532,I500,N000,T500,S130,P600,M300,M200,P6536512132,L200,S532,E200,E150,F400,C460,C513642,S520,D530,N300,T650,O500,C5136,S5352,O300,F420,S530,D6234,O530,D612,E540,S6153,P230,P320,B636512151242351213,Y600,F212,T265,C53642,S000,M000,O1352,A600,M230,S140,Q300,P6132,S514,W000,S423,F52352',1,0,'brother-mfcl8690cdw-allinone-wireless-laser-colour-printer-with-fax','',0,0,'','','','',1,1,'',''),(49,1,'BROTHER MFCL8690CDW AllinOne Wireless Laser Colour Printer with Fax','<strong>All-in-One printer</strong><br />\r\n<br />\r\nThe Brother&nbsp;<strong>MFC-L8690CDW All-in-One Wireless Laser Printer with Fax&nbsp;</strong>does just about everything. You can print, copy, scan, fax &ndash; and this can all be done wirelessly. Perfect for a small office that doesn&#39;t have space for multiple machines, you can print from or scan to PCs, smartphones, and tablets.<br />\r\n<br />\r\n<strong>Fast printing</strong><br />\r\n<br />\r\nYou can print a whole stack of documents in no time, with a print speed of 31 pages per minute. That means the Brother&nbsp;<strong>MFC-L8690CDW Laser Printer&nbsp;</strong>takes less than two seconds to print each page, even in full colour.<br />\r\n<br />\r\n<strong>Computer-less scanning</strong><br />\r\n<br />\r\nYou don&#39;t even need to turn on a computer to print something out. You can scan files and send them directly to OneNote, Dropbox, email, or SharePoint. You can even post photos directly from the Brother&nbsp;<strong>MFC-L8690CDW&nbsp;</strong>to your Facebook.<br />\r\n<br />\r\n<strong>Touchscreen controls</strong><br />\r\n<br />\r\nWith so many options, easy controls are a must. The sizable 3.7&quot; touchscreen provides a simple way to select the functions you need.','',0,'','','','','','B636,M12423,A450,W642,L260,C460,P6536,W300,F200','A450,P6536,T000,B6365121512423,W642,L260,W300,F2512132,J300,A130,E16352,Y000,C500,P653,C100,S500,F200,N320,A530,T200,A400,B000,D500,W6424,P6123,F600,S540,O120,D253,H100,S120,M4314,M252,F650,O600,P200,S563152,T1432,F230,P65352,W400,S320,O100,D2532,I500,N000,T500,S130,P600,M300,M200,P6536512132,L200,S532,E200,E150,F400,C460,C513642,S520,D530,N300,T650,O500,C5136,S5352,O300,F420,S530,D6234,O530,D612,E540,S6153,P230,P320,B636512151242351213,Y600,F212,T265,C53642,S000,M000,O1352,A600,M230,S140,Q300,P6132,S514,W000,S423,F52352',4,0,'brother-mfcl8690cdw-allinone-wireless-laser-colour-printer-with-fax','',0,0,'','','','',1,1,'',''),(49,1,'BROTHER MFCL8690CDW AllinOne Wireless Laser Colour Printer with Fax','<strong>All-in-One printer</strong><br />\r\n<br />\r\nThe Brother&nbsp;<strong>MFC-L8690CDW All-in-One Wireless Laser Printer with Fax&nbsp;</strong>does just about everything. You can print, copy, scan, fax &ndash; and this can all be done wirelessly. Perfect for a small office that doesn&#39;t have space for multiple machines, you can print from or scan to PCs, smartphones, and tablets.<br />\r\n<br />\r\n<strong>Fast printing</strong><br />\r\n<br />\r\nYou can print a whole stack of documents in no time, with a print speed of 31 pages per minute. That means the Brother&nbsp;<strong>MFC-L8690CDW Laser Printer&nbsp;</strong>takes less than two seconds to print each page, even in full colour.<br />\r\n<br />\r\n<strong>Computer-less scanning</strong><br />\r\n<br />\r\nYou don&#39;t even need to turn on a computer to print something out. You can scan files and send them directly to OneNote, Dropbox, email, or SharePoint. You can even post photos directly from the Brother&nbsp;<strong>MFC-L8690CDW&nbsp;</strong>to your Facebook.<br />\r\n<br />\r\n<strong>Touchscreen controls</strong><br />\r\n<br />\r\nWith so many options, easy controls are a must. The sizable 3.7&quot; touchscreen provides a simple way to select the functions you need.','',0,'','','','','','B636,M12423,A450,W642,L260,C460,P6536,W300,F200','A450,P6536,T000,B6365121512423,W642,L260,W300,F2512132,J300,A130,E16352,Y000,C500,P653,C100,S500,F200,N320,A530,T200,A400,B000,D500,W6424,P6123,F600,S540,O120,D253,H100,S120,M4314,M252,F650,O600,P200,S563152,T1432,F230,P65352,W400,S320,O100,D2532,I500,N000,T500,S130,P600,M300,M200,P6536512132,L200,S532,E200,E150,F400,C460,C513642,S520,D530,N300,T650,O500,C5136,S5352,O300,F420,S530,D6234,O530,D612,E540,S6153,P230,P320,B636512151242351213,Y600,F212,T265,C53642,S000,M000,O1352,A600,M230,S140,Q300,P6132,S514,W000,S423,F52352',5,0,'brother-mfcl8690cdw-allinone-wireless-laser-colour-printer-with-fax','',0,0,'','','','',1,1,'',''),(49,1,'BROTHER MFCL8690CDW AllinOne Wireless Laser Colour Printer with Fax','<strong>All-in-One printer</strong><br />\r\n<br />\r\nThe Brother&nbsp;<strong>MFC-L8690CDW All-in-One Wireless Laser Printer with Fax&nbsp;</strong>does just about everything. You can print, copy, scan, fax &ndash; and this can all be done wirelessly. Perfect for a small office that doesn&#39;t have space for multiple machines, you can print from or scan to PCs, smartphones, and tablets.<br />\r\n<br />\r\n<strong>Fast printing</strong><br />\r\n<br />\r\nYou can print a whole stack of documents in no time, with a print speed of 31 pages per minute. That means the Brother&nbsp;<strong>MFC-L8690CDW Laser Printer&nbsp;</strong>takes less than two seconds to print each page, even in full colour.<br />\r\n<br />\r\n<strong>Computer-less scanning</strong><br />\r\n<br />\r\nYou don&#39;t even need to turn on a computer to print something out. You can scan files and send them directly to OneNote, Dropbox, email, or SharePoint. You can even post photos directly from the Brother&nbsp;<strong>MFC-L8690CDW&nbsp;</strong>to your Facebook.<br />\r\n<br />\r\n<strong>Touchscreen controls</strong><br />\r\n<br />\r\nWith so many options, easy controls are a must. The sizable 3.7&quot; touchscreen provides a simple way to select the functions you need.','',0,'','','','','','B636,M12423,A450,W642,L260,C460,P6536,W300,F200','A450,P6536,T000,B6365121512423,W642,L260,W300,F2512132,J300,A130,E16352,Y000,C500,P653,C100,S500,F200,N320,A530,T200,A400,B000,D500,W6424,P6123,F600,S540,O120,D253,H100,S120,M4314,M252,F650,O600,P200,S563152,T1432,F230,P65352,W400,S320,O100,D2532,I500,N000,T500,S130,P600,M300,M200,P6536512132,L200,S532,E200,E150,F400,C460,C513642,S520,D530,N300,T650,O500,C5136,S5352,O300,F420,S530,D6234,O530,D612,E540,S6153,P230,P320,B636512151242351213,Y600,F212,T265,C53642,S000,M000,O1352,A600,M230,S140,Q300,P6132,S514,W000,S423,F52352',6,0,'brother-mfcl8690cdw-allinone-wireless-laser-colour-printer-with-fax','',0,0,'','','','',1,1,'',''),(49,1,'BROTHER MFCL8690CDW AllinOne Wireless Laser Colour Printer with Fax','<strong>All-in-One printer</strong><br />\r\n<br />\r\nThe Brother&nbsp;<strong>MFC-L8690CDW All-in-One Wireless Laser Printer with Fax&nbsp;</strong>does just about everything. You can print, copy, scan, fax &ndash; and this can all be done wirelessly. Perfect for a small office that doesn&#39;t have space for multiple machines, you can print from or scan to PCs, smartphones, and tablets.<br />\r\n<br />\r\n<strong>Fast printing</strong><br />\r\n<br />\r\nYou can print a whole stack of documents in no time, with a print speed of 31 pages per minute. That means the Brother&nbsp;<strong>MFC-L8690CDW Laser Printer&nbsp;</strong>takes less than two seconds to print each page, even in full colour.<br />\r\n<br />\r\n<strong>Computer-less scanning</strong><br />\r\n<br />\r\nYou don&#39;t even need to turn on a computer to print something out. You can scan files and send them directly to OneNote, Dropbox, email, or SharePoint. You can even post photos directly from the Brother&nbsp;<strong>MFC-L8690CDW&nbsp;</strong>to your Facebook.<br />\r\n<br />\r\n<strong>Touchscreen controls</strong><br />\r\n<br />\r\nWith so many options, easy controls are a must. The sizable 3.7&quot; touchscreen provides a simple way to select the functions you need.','',0,'','','','','','B636,M12423,A450,W642,L260,C460,P6536,W300,F200','A450,P6536,T000,B6365121512423,W642,L260,W300,F2512132,J300,A130,E16352,Y000,C500,P653,C100,S500,F200,N320,A530,T200,A400,B000,D500,W6424,P6123,F600,S540,O120,D253,H100,S120,M4314,M252,F650,O600,P200,S563152,T1432,F230,P65352,W400,S320,O100,D2532,I500,N000,T500,S130,P600,M300,M200,P6536512132,L200,S532,E200,E150,F400,C460,C513642,S520,D530,N300,T650,O500,C5136,S5352,O300,F420,S530,D6234,O530,D612,E540,S6153,P230,P320,B636512151242351213,Y600,F212,T265,C53642,S000,M000,O1352,A600,M230,S140,Q300,P6132,S514,W000,S423,F52352',7,0,'brother-mfcl8690cdw-allinone-wireless-laser-colour-printer-with-fax','',0,0,'','','','',1,1,'',''),(49,1,'BROTHER MFCL8690CDW AllinOne Wireless Laser Colour Printer with Fax','<strong>All-in-One printer</strong><br />\r\n<br />\r\nThe Brother&nbsp;<strong>MFC-L8690CDW All-in-One Wireless Laser Printer with Fax&nbsp;</strong>does just about everything. You can print, copy, scan, fax &ndash; and this can all be done wirelessly. Perfect for a small office that doesn&#39;t have space for multiple machines, you can print from or scan to PCs, smartphones, and tablets.<br />\r\n<br />\r\n<strong>Fast printing</strong><br />\r\n<br />\r\nYou can print a whole stack of documents in no time, with a print speed of 31 pages per minute. That means the Brother&nbsp;<strong>MFC-L8690CDW Laser Printer&nbsp;</strong>takes less than two seconds to print each page, even in full colour.<br />\r\n<br />\r\n<strong>Computer-less scanning</strong><br />\r\n<br />\r\nYou don&#39;t even need to turn on a computer to print something out. You can scan files and send them directly to OneNote, Dropbox, email, or SharePoint. You can even post photos directly from the Brother&nbsp;<strong>MFC-L8690CDW&nbsp;</strong>to your Facebook.<br />\r\n<br />\r\n<strong>Touchscreen controls</strong><br />\r\n<br />\r\nWith so many options, easy controls are a must. The sizable 3.7&quot; touchscreen provides a simple way to select the functions you need.','',0,'','','','','','B636,M12423,A450,W642,L260,C460,P6536,W300,F200','A450,P6536,T000,B6365121512423,W642,L260,W300,F2512132,J300,A130,E16352,Y000,C500,P653,C100,S500,F200,N320,A530,T200,A400,B000,D500,W6424,P6123,F600,S540,O120,D253,H100,S120,M4314,M252,F650,O600,P200,S563152,T1432,F230,P65352,W400,S320,O100,D2532,I500,N000,T500,S130,P600,M300,M200,P6536512132,L200,S532,E200,E150,F400,C460,C513642,S520,D530,N300,T650,O500,C5136,S5352,O300,F420,S530,D6234,O530,D612,E540,S6153,P230,P320,B636512151242351213,Y600,F212,T265,C53642,S000,M000,O1352,A600,M230,S140,Q300,P6132,S514,W000,S423,F52352',8,0,'brother-mfcl8690cdw-allinone-wireless-laser-colour-printer-with-fax','',0,0,'','','','',1,1,'',''),(49,1,'BROTHER MFCL8690CDW AllinOne Wireless Laser Colour Printer with Fax','<strong>All-in-One printer</strong><br />\r\n<br />\r\nThe Brother&nbsp;<strong>MFC-L8690CDW All-in-One Wireless Laser Printer with Fax&nbsp;</strong>does just about everything. You can print, copy, scan, fax &ndash; and this can all be done wirelessly. Perfect for a small office that doesn&#39;t have space for multiple machines, you can print from or scan to PCs, smartphones, and tablets.<br />\r\n<br />\r\n<strong>Fast printing</strong><br />\r\n<br />\r\nYou can print a whole stack of documents in no time, with a print speed of 31 pages per minute. That means the Brother&nbsp;<strong>MFC-L8690CDW Laser Printer&nbsp;</strong>takes less than two seconds to print each page, even in full colour.<br />\r\n<br />\r\n<strong>Computer-less scanning</strong><br />\r\n<br />\r\nYou don&#39;t even need to turn on a computer to print something out. You can scan files and send them directly to OneNote, Dropbox, email, or SharePoint. You can even post photos directly from the Brother&nbsp;<strong>MFC-L8690CDW&nbsp;</strong>to your Facebook.<br />\r\n<br />\r\n<strong>Touchscreen controls</strong><br />\r\n<br />\r\nWith so many options, easy controls are a must. The sizable 3.7&quot; touchscreen provides a simple way to select the functions you need.','',0,'','','','','','B636,M12423,A450,W642,L260,C460,P6536,W300,F200','A450,P6536,T000,B6365121512423,W642,L260,W300,F2512132,J300,A130,E16352,Y000,C500,P653,C100,S500,F200,N320,A530,T200,A400,B000,D500,W6424,P6123,F600,S540,O120,D253,H100,S120,M4314,M252,F650,O600,P200,S563152,T1432,F230,P65352,W400,S320,O100,D2532,I500,N000,T500,S130,P600,M300,M200,P6536512132,L200,S532,E200,E150,F400,C460,C513642,S520,D530,N300,T650,O500,C5136,S5352,O300,F420,S530,D6234,O530,D612,E540,S6153,P230,P320,B636512151242351213,Y600,F212,T265,C53642,S000,M000,O1352,A600,M230,S140,Q300,P6132,S514,W000,S423,F52352',9,0,'brother-mfcl8690cdw-allinone-wireless-laser-colour-printer-with-fax','',0,0,'','','','',1,1,'',''),(49,1,'BROTHER MFCL8690CDW AllinOne Wireless Laser Colour Printer with Fax','<strong>All-in-One printer</strong><br />\r\n<br />\r\nThe Brother&nbsp;<strong>MFC-L8690CDW All-in-One Wireless Laser Printer with Fax&nbsp;</strong>does just about everything. You can print, copy, scan, fax &ndash; and this can all be done wirelessly. Perfect for a small office that doesn&#39;t have space for multiple machines, you can print from or scan to PCs, smartphones, and tablets.<br />\r\n<br />\r\n<strong>Fast printing</strong><br />\r\n<br />\r\nYou can print a whole stack of documents in no time, with a print speed of 31 pages per minute. That means the Brother&nbsp;<strong>MFC-L8690CDW Laser Printer&nbsp;</strong>takes less than two seconds to print each page, even in full colour.<br />\r\n<br />\r\n<strong>Computer-less scanning</strong><br />\r\n<br />\r\nYou don&#39;t even need to turn on a computer to print something out. You can scan files and send them directly to OneNote, Dropbox, email, or SharePoint. You can even post photos directly from the Brother&nbsp;<strong>MFC-L8690CDW&nbsp;</strong>to your Facebook.<br />\r\n<br />\r\n<strong>Touchscreen controls</strong><br />\r\n<br />\r\nWith so many options, easy controls are a must. The sizable 3.7&quot; touchscreen provides a simple way to select the functions you need.','',0,'','','','','','B636,M12423,A450,W642,L260,C460,P6536,W300,F200','A450,P6536,T000,B6365121512423,W642,L260,W300,F2512132,J300,A130,E16352,Y000,C500,P653,C100,S500,F200,N320,A530,T200,A400,B000,D500,W6424,P6123,F600,S540,O120,D253,H100,S120,M4314,M252,F650,O600,P200,S563152,T1432,F230,P65352,W400,S320,O100,D2532,I500,N000,T500,S130,P600,M300,M200,P6536512132,L200,S532,E200,E150,F400,C460,C513642,S520,D530,N300,T650,O500,C5136,S5352,O300,F420,S530,D6234,O530,D612,E540,S6153,P230,P320,B636512151242351213,Y600,F212,T265,C53642,S000,M000,O1352,A600,M230,S140,Q300,P6132,S514,W000,S423,F52352',10,0,'brother-mfcl8690cdw-allinone-wireless-laser-colour-printer-with-fax','',0,0,'','','','',1,1,'',''),(50,1,'COZY SLEEP QUEEN MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:153 x D:203 CM</p>\r\n&nbsp;\r\n\r\n<p><strong><em>Why We Love It:</em></strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Queen Mattress | PK Furniture','','Buy queen mattress online now at PK Furniture','','BEST DEAL COZY SLEEP QUEEN MATTRESS WARRANTY: 1 YEAR','C000,S410,Q500,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',1,0,'cozy-sleep-queen-mattress','',0,0,'','QUEEN MATTRESS','COZY SLEEP','',1,1,'',''),(50,1,'COZY SLEEP QUEEN MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:153 x D:203 CM</p>\r\n&nbsp;\r\n\r\n<p><strong><em>Why We Love It:</em></strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Queen Mattress | PK Furniture','','Buy queen mattress online now at PK Furniture','','BEST DEAL COZY SLEEP QUEEN MATTRESS WARRANTY: 1 YEAR','C000,S410,Q500,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',4,0,'cozy-sleep-queen-mattress','',0,0,'','QUEEN MATTRESS','COZY SLEEP','',1,1,'',''),(50,1,'COZY SLEEP QUEEN MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:153 x D:203 CM</p>\r\n&nbsp;\r\n\r\n<p><strong><em>Why We Love It:</em></strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Queen Mattress | PK Furniture','','Buy queen mattress online now at PK Furniture','','BEST DEAL COZY SLEEP QUEEN MATTRESS WARRANTY: 1 YEAR','C000,S410,Q500,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',5,0,'cozy-sleep-queen-mattress','',0,0,'','QUEEN MATTRESS','COZY SLEEP','',1,1,'',''),(50,1,'COZY SLEEP QUEEN MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:153 x D:203 CM</p>\r\n&nbsp;\r\n\r\n<p><strong><em>Why We Love It:</em></strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Queen Mattress | PK Furniture','','Buy queen mattress online now at PK Furniture','','BEST DEAL COZY SLEEP QUEEN MATTRESS WARRANTY: 1 YEAR','C000,S410,Q500,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',6,0,'cozy-sleep-queen-mattress','',0,0,'','QUEEN MATTRESS','COZY SLEEP','',1,1,'',''),(50,1,'COZY SLEEP QUEEN MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:153 x D:203 CM</p>\r\n&nbsp;\r\n\r\n<p><strong><em>Why We Love It:</em></strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Queen Mattress | PK Furniture','','Buy queen mattress online now at PK Furniture','','BEST DEAL COZY SLEEP QUEEN MATTRESS WARRANTY: 1 YEAR','C000,S410,Q500,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',7,0,'cozy-sleep-queen-mattress','',0,0,'','QUEEN MATTRESS','COZY SLEEP','',1,1,'',''),(50,1,'COZY SLEEP QUEEN MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:153 x D:203 CM</p>\r\n&nbsp;\r\n\r\n<p><strong><em>Why We Love It:</em></strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Queen Mattress | PK Furniture','','Buy queen mattress online now at PK Furniture','','BEST DEAL COZY SLEEP QUEEN MATTRESS WARRANTY: 1 YEAR','C000,S410,Q500,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',8,0,'cozy-sleep-queen-mattress','',0,0,'','QUEEN MATTRESS','COZY SLEEP','',1,1,'',''),(50,1,'COZY SLEEP QUEEN MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:153 x D:203 CM</p>\r\n&nbsp;\r\n\r\n<p><strong><em>Why We Love It:</em></strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Queen Mattress | PK Furniture','','Buy queen mattress online now at PK Furniture','','BEST DEAL COZY SLEEP QUEEN MATTRESS WARRANTY: 1 YEAR','C000,S410,Q500,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',9,0,'cozy-sleep-queen-mattress','',0,0,'','QUEEN MATTRESS','COZY SLEEP','',1,1,'',''),(50,1,'COZY SLEEP QUEEN MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:153 x D:203 CM</p>\r\n&nbsp;\r\n\r\n<p><strong><em>Why We Love It:</em></strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Queen Mattress | PK Furniture','','Buy queen mattress online now at PK Furniture','','BEST DEAL COZY SLEEP QUEEN MATTRESS WARRANTY: 1 YEAR','C000,S410,Q500,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',10,0,'cozy-sleep-queen-mattress','',0,0,'','QUEEN MATTRESS','COZY SLEEP','',1,1,'',''),(51,1,'COZY SLEEP DOUBLE MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:137 x D:188 CM</p>\r\n&nbsp;\r\n\r\n<p><strong>Why We Love It:</strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Double Mattress | PK Furniture','','Buy double mattress online now at PK Furniture','','COZY SLEEP BEST DEAL COZY SLEEP DOUBLE MATTRESS WARRANTY: 1 YEAR','C000,S410,D140,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',1,0,'cozy-sleep-double-mattress','',0,0,'','DOUBLE MATTRESS','COZY SLEEP','',1,1,'',''),(51,1,'COZY SLEEP DOUBLE MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:137 x D:188 CM</p>\r\n&nbsp;\r\n\r\n<p><strong>Why We Love It:</strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Double Mattress | PK Furniture','','Buy double mattress online now at PK Furniture','','COZY SLEEP BEST DEAL COZY SLEEP DOUBLE MATTRESS WARRANTY: 1 YEAR','C000,S410,D140,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',4,0,'cozy-sleep-double-mattress','',0,0,'','DOUBLE MATTRESS','COZY SLEEP','',1,1,'',''),(51,1,'COZY SLEEP DOUBLE MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:137 x D:188 CM</p>\r\n&nbsp;\r\n\r\n<p><strong>Why We Love It:</strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Double Mattress | PK Furniture','','Buy double mattress online now at PK Furniture','','COZY SLEEP BEST DEAL COZY SLEEP DOUBLE MATTRESS WARRANTY: 1 YEAR','C000,S410,D140,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',5,0,'cozy-sleep-double-mattress','',0,0,'','DOUBLE MATTRESS','COZY SLEEP','',1,1,'',''),(51,1,'COZY SLEEP DOUBLE MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:137 x D:188 CM</p>\r\n&nbsp;\r\n\r\n<p><strong>Why We Love It:</strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Double Mattress | PK Furniture','','Buy double mattress online now at PK Furniture','','COZY SLEEP BEST DEAL COZY SLEEP DOUBLE MATTRESS WARRANTY: 1 YEAR','C000,S410,D140,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',6,0,'cozy-sleep-double-mattress','',0,0,'','DOUBLE MATTRESS','COZY SLEEP','',1,1,'',''),(51,1,'COZY SLEEP DOUBLE MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:137 x D:188 CM</p>\r\n&nbsp;\r\n\r\n<p><strong>Why We Love It:</strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Double Mattress | PK Furniture','','Buy double mattress online now at PK Furniture','','COZY SLEEP BEST DEAL COZY SLEEP DOUBLE MATTRESS WARRANTY: 1 YEAR','C000,S410,D140,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',7,0,'cozy-sleep-double-mattress','',0,0,'','DOUBLE MATTRESS','COZY SLEEP','',1,1,'',''),(51,1,'COZY SLEEP DOUBLE MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:137 x D:188 CM</p>\r\n&nbsp;\r\n\r\n<p><strong>Why We Love It:</strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Double Mattress | PK Furniture','','Buy double mattress online now at PK Furniture','','COZY SLEEP BEST DEAL COZY SLEEP DOUBLE MATTRESS WARRANTY: 1 YEAR','C000,S410,D140,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',8,0,'cozy-sleep-double-mattress','',0,0,'','DOUBLE MATTRESS','COZY SLEEP','',1,1,'',''),(51,1,'COZY SLEEP DOUBLE MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:137 x D:188 CM</p>\r\n&nbsp;\r\n\r\n<p><strong>Why We Love It:</strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Double Mattress | PK Furniture','','Buy double mattress online now at PK Furniture','','COZY SLEEP BEST DEAL COZY SLEEP DOUBLE MATTRESS WARRANTY: 1 YEAR','C000,S410,D140,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',9,0,'cozy-sleep-double-mattress','',0,0,'','DOUBLE MATTRESS','COZY SLEEP','',1,1,'',''),(51,1,'COZY SLEEP DOUBLE MATTRESS','<p><strong>The Cozy Sleep mattress doesn&#39;t compromise on quality. High quality knitted fabric gives you a firm feel, 4cm comfort foam provides cushioning feel for your body, and 16cm continous spring supports your body ensuring you have a good night&#39;s sleep.</strong></p>\r\n&nbsp;\r\n\r\n<p><strong>Construction:</strong></p>\r\n\r\n<ul>\r\n	<li>High quality knitted fabric</li>\r\n	<li>4 cm comfort foam</li>\r\n	<li>16cm continous spring</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Warranty:</strong>&nbsp;1 year</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:24 x W:137 x D:188 CM</p>\r\n&nbsp;\r\n\r\n<p><strong>Why We Love It:</strong></p>\r\n\r\n<p><em>This is a fantastically priced mattress for the level of quality, support and freedom that it provides.</em></p>\r\n','',0,'Double Mattress | PK Furniture','','Buy double mattress online now at PK Furniture','','COZY SLEEP BEST DEAL COZY SLEEP DOUBLE MATTRESS WARRANTY: 1 YEAR','C000,S410,D140,M362','T000,C000,S410,M362,D253,C51652,O500,Q430,H200,K530,F620,G120,Y000,F650,F400,C500,C5163,F500,P6132,C520,F600,Y600,B300,A530,C5352,S1652,S1632,E52652,H100,G300,N232,N121,C5236235,W6535121,D52525121,W000,D000,L100,I300,T200,I200,F532324,P623,L140,O100,S163,F635',10,0,'cozy-sleep-double-mattress','',0,0,'','DOUBLE MATTRESS','COZY SLEEP','',1,1,'',''),(52,1,'Country 6PCS Package 1Xqb+2Xbs+1Xtb+1Xdt+1Xdm','<p>Material:</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Dimension:H: X W: X D:CM</p>\r\n','',0,'','','','','BEST DEAL COUNTRY 6PCS PACKAGE 1XQB+2XBS+1XTB+1XDT+1XDM','C536,P200,X12123123235','M364,W653,Y600,D525,W000,D250',1,0,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462','',0,0,'','','','',1,1,'',''),(52,1,'Country 6PCS Package 1Xqb+2Xbs+1Xtb+1Xdt+1Xdm','<p>Material:</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Dimension:H: X W: X D:CM</p>\r\n','',0,'','','','','BEST DEAL COUNTRY 6PCS PACKAGE 1XQB+2XBS+1XTB+1XDT+1XDM','C536,P200,X12123123235','M364,W653,Y600,D525,W000,D250',4,0,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462','',0,0,'','','','',1,1,'',''),(52,1,'Country 6PCS Package 1Xqb+2Xbs+1Xtb+1Xdt+1Xdm','<p>Material:</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Dimension:H: X W: X D:CM</p>\r\n','',0,'','','','','BEST DEAL COUNTRY 6PCS PACKAGE 1XQB+2XBS+1XTB+1XDT+1XDM','C536,P200,X12123123235','M364,W653,Y600,D525,W000,D250',5,0,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462','',0,0,'','','','',1,1,'',''),(52,1,'Country 6PCS Package 1Xqb+2Xbs+1Xtb+1Xdt+1Xdm','<p>Material:</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Dimension:H: X W: X D:CM</p>\r\n','',0,'','','','','BEST DEAL COUNTRY 6PCS PACKAGE 1XQB+2XBS+1XTB+1XDT+1XDM','C536,P200,X12123123235','M364,W653,Y600,D525,W000,D250',6,0,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462','',0,0,'','','','',1,1,'',''),(52,1,'Country 6PCS Package 1Xqb+2Xbs+1Xtb+1Xdt+1Xdm','<p>Material:</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Dimension:H: X W: X D:CM</p>\r\n','',0,'','','','','BEST DEAL COUNTRY 6PCS PACKAGE 1XQB+2XBS+1XTB+1XDT+1XDM','C536,P200,X12123123235','M364,W653,Y600,D525,W000,D250',7,0,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462','',0,0,'','','','',1,1,'',''),(52,1,'Country 6PCS Package 1Xqb+2Xbs+1Xtb+1Xdt+1Xdm','<p>Material:</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Dimension:H: X W: X D:CM</p>\r\n','',0,'','','','','BEST DEAL COUNTRY 6PCS PACKAGE 1XQB+2XBS+1XTB+1XDT+1XDM','C536,P200,X12123123235','M364,W653,Y600,D525,W000,D250',8,0,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462','',0,0,'','','','',1,1,'',''),(52,1,'Country 6PCS Package 1Xqb+2Xbs+1Xtb+1Xdt+1Xdm','<p>Material:</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Dimension:H: X W: X D:CM</p>\r\n','',0,'','','','','BEST DEAL COUNTRY 6PCS PACKAGE 1XQB+2XBS+1XTB+1XDT+1XDM','C536,P200,X12123123235','M364,W653,Y600,D525,W000,D250',9,0,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462','',0,0,'','','','',1,1,'',''),(52,1,'Country 6PCS Package 1Xqb+2Xbs+1Xtb+1Xdt+1Xdm','<p>Material:</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Dimension:H: X W: X D:CM</p>\r\n','',0,'','','','','BEST DEAL COUNTRY 6PCS PACKAGE 1XQB+2XBS+1XTB+1XDT+1XDM','C536,P200,X12123123235','M364,W653,Y600,D525,W000,D250',10,0,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462','',0,0,'','','','',1,1,'',''),(53,1,'JACK 5 PIECE KING BEDROOM SUITE','<p>1 x&nbsp;Jack<span>&nbsp;</span>King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table</p>\r\n\r\n<p>1 x Jack Dressing Table</p>\r\n\r\n<p>1 x&nbsp;Jack<span>&nbsp;</span>Dressing&nbsp;Mirror</p>\r\n\r\n<p>&nbsp;</p>\r\n','',0,'','','','','BEST DEAL JACK 5PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XDT+1XDM','J000,P200,K520,B365,S300','X512125121252,B300,J000,B323,T140,D6252,X51212512136252512156,N121',1,0,'jack-5-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(53,1,'JACK 5 PIECE KING BEDROOM SUITE','<p>1 x&nbsp;Jack<span>&nbsp;</span>King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table</p>\r\n\r\n<p>1 x Jack Dressing Table</p>\r\n\r\n<p>1 x&nbsp;Jack<span>&nbsp;</span>Dressing&nbsp;Mirror</p>\r\n\r\n<p>&nbsp;</p>\r\n','',0,'','','','','BEST DEAL JACK 5PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XDT+1XDM','J000,P200,K520,B365,S300','X512125121252,B300,J000,B323,T140,D6252,X51212512136252512156,N121',4,0,'jack-5-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(53,1,'JACK 5 PIECE KING BEDROOM SUITE','<p>1 x&nbsp;Jack<span>&nbsp;</span>King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table</p>\r\n\r\n<p>1 x Jack Dressing Table</p>\r\n\r\n<p>1 x&nbsp;Jack<span>&nbsp;</span>Dressing&nbsp;Mirror</p>\r\n\r\n<p>&nbsp;</p>\r\n','',0,'','','','','BEST DEAL JACK 5PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XDT+1XDM','J000,P200,K520,B365,S300','X512125121252,B300,J000,B323,T140,D6252,X51212512136252512156,N121',5,0,'jack-5-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(53,1,'JACK 5 PIECE KING BEDROOM SUITE','<p>1 x&nbsp;Jack<span>&nbsp;</span>King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table</p>\r\n\r\n<p>1 x Jack Dressing Table</p>\r\n\r\n<p>1 x&nbsp;Jack<span>&nbsp;</span>Dressing&nbsp;Mirror</p>\r\n\r\n<p>&nbsp;</p>\r\n','',0,'','','','','BEST DEAL JACK 5PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XDT+1XDM','J000,P200,K520,B365,S300','X512125121252,B300,J000,B323,T140,D6252,X51212512136252512156,N121',6,0,'jack-5-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(53,1,'JACK 5 PIECE KING BEDROOM SUITE','<p>1 x&nbsp;Jack<span>&nbsp;</span>King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table</p>\r\n\r\n<p>1 x Jack Dressing Table</p>\r\n\r\n<p>1 x&nbsp;Jack<span>&nbsp;</span>Dressing&nbsp;Mirror</p>\r\n\r\n<p>&nbsp;</p>\r\n','',0,'','','','','BEST DEAL JACK 5PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XDT+1XDM','J000,P200,K520,B365,S300','X512125121252,B300,J000,B323,T140,D6252,X51212512136252512156,N121',7,0,'jack-5-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(53,1,'JACK 5 PIECE KING BEDROOM SUITE','<p>1 x&nbsp;Jack<span>&nbsp;</span>King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table</p>\r\n\r\n<p>1 x Jack Dressing Table</p>\r\n\r\n<p>1 x&nbsp;Jack<span>&nbsp;</span>Dressing&nbsp;Mirror</p>\r\n\r\n<p>&nbsp;</p>\r\n','',0,'','','','','BEST DEAL JACK 5PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XDT+1XDM','J000,P200,K520,B365,S300','X512125121252,B300,J000,B323,T140,D6252,X51212512136252512156,N121',8,0,'jack-5-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(53,1,'JACK 5 PIECE KING BEDROOM SUITE','<p>1 x&nbsp;Jack<span>&nbsp;</span>King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table</p>\r\n\r\n<p>1 x Jack Dressing Table</p>\r\n\r\n<p>1 x&nbsp;Jack<span>&nbsp;</span>Dressing&nbsp;Mirror</p>\r\n\r\n<p>&nbsp;</p>\r\n','',0,'','','','','BEST DEAL JACK 5PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XDT+1XDM','J000,P200,K520,B365,S300','X512125121252,B300,J000,B323,T140,D6252,X51212512136252512156,N121',9,0,'jack-5-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(53,1,'JACK 5 PIECE KING BEDROOM SUITE','<p>1 x&nbsp;Jack<span>&nbsp;</span>King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table</p>\r\n\r\n<p>1 x Jack Dressing Table</p>\r\n\r\n<p>1 x&nbsp;Jack<span>&nbsp;</span>Dressing&nbsp;Mirror</p>\r\n\r\n<p>&nbsp;</p>\r\n','',0,'','','','','BEST DEAL JACK 5PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XDT+1XDM','J000,P200,K520,B365,S300','X512125121252,B300,J000,B323,T140,D6252,X51212512136252512156,N121',10,0,'jack-5-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(54,1,'JACK 4 PIECE KING BEDROOM SUITE','<p><span>The rustic Jack super king bed frame is completed with a dark wood finish, giving a robust yet modern look, making your bedroom distinctive.</span></p>\r\n\r\n<p>1 x&nbsp;Jack King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table&nbsp;</p>\r\n\r\n<p>1 x Jack Tallboy</p>\r\n\r\n<p>Material: Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p><span>Bed Frame Dimension: H:120 X W:171 X D:207 CM</span></p>\r\n\r\n<p><span>Bedside Dimension: H:55 X W:54 X D:45 CM</span></p>\r\n\r\n<p><span>Tallboy Dimension: H:110 X W:95 X D:46 CM</span></p>\r\n','',0,'','','','','BEST DEAL JACK 4PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XTB','J000,P200,K520,B365,S300','T000,R232,J000,S160,K520,B300,F650,I200,C5143,W300,D620,F520,G152,R123,Y300,M365,L200,M252,Y600,B365,D235231,X51212,B323,T145121,T410,M364,V560,W653,D525,H000,W000,D000,C500',1,0,'jack-4-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(54,1,'JACK 4 PIECE KING BEDROOM SUITE','<p><span>The rustic Jack super king bed frame is completed with a dark wood finish, giving a robust yet modern look, making your bedroom distinctive.</span></p>\r\n\r\n<p>1 x&nbsp;Jack King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table&nbsp;</p>\r\n\r\n<p>1 x Jack Tallboy</p>\r\n\r\n<p>Material: Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p><span>Bed Frame Dimension: H:120 X W:171 X D:207 CM</span></p>\r\n\r\n<p><span>Bedside Dimension: H:55 X W:54 X D:45 CM</span></p>\r\n\r\n<p><span>Tallboy Dimension: H:110 X W:95 X D:46 CM</span></p>\r\n','',0,'','','','','BEST DEAL JACK 4PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XTB','J000,P200,K520,B365,S300','T000,R232,J000,S160,K520,B300,F650,I200,C5143,W300,D620,F520,G152,R123,Y300,M365,L200,M252,Y600,B365,D235231,X51212,B323,T145121,T410,M364,V560,W653,D525,H000,W000,D000,C500',4,0,'jack-4-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(54,1,'JACK 4 PIECE KING BEDROOM SUITE','<p><span>The rustic Jack super king bed frame is completed with a dark wood finish, giving a robust yet modern look, making your bedroom distinctive.</span></p>\r\n\r\n<p>1 x&nbsp;Jack King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table&nbsp;</p>\r\n\r\n<p>1 x Jack Tallboy</p>\r\n\r\n<p>Material: Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p><span>Bed Frame Dimension: H:120 X W:171 X D:207 CM</span></p>\r\n\r\n<p><span>Bedside Dimension: H:55 X W:54 X D:45 CM</span></p>\r\n\r\n<p><span>Tallboy Dimension: H:110 X W:95 X D:46 CM</span></p>\r\n','',0,'','','','','BEST DEAL JACK 4PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XTB','J000,P200,K520,B365,S300','T000,R232,J000,S160,K520,B300,F650,I200,C5143,W300,D620,F520,G152,R123,Y300,M365,L200,M252,Y600,B365,D235231,X51212,B323,T145121,T410,M364,V560,W653,D525,H000,W000,D000,C500',5,0,'jack-4-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(54,1,'JACK 4 PIECE KING BEDROOM SUITE','<p><span>The rustic Jack super king bed frame is completed with a dark wood finish, giving a robust yet modern look, making your bedroom distinctive.</span></p>\r\n\r\n<p>1 x&nbsp;Jack King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table&nbsp;</p>\r\n\r\n<p>1 x Jack Tallboy</p>\r\n\r\n<p>Material: Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p><span>Bed Frame Dimension: H:120 X W:171 X D:207 CM</span></p>\r\n\r\n<p><span>Bedside Dimension: H:55 X W:54 X D:45 CM</span></p>\r\n\r\n<p><span>Tallboy Dimension: H:110 X W:95 X D:46 CM</span></p>\r\n','',0,'','','','','BEST DEAL JACK 4PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XTB','J000,P200,K520,B365,S300','T000,R232,J000,S160,K520,B300,F650,I200,C5143,W300,D620,F520,G152,R123,Y300,M365,L200,M252,Y600,B365,D235231,X51212,B323,T145121,T410,M364,V560,W653,D525,H000,W000,D000,C500',6,0,'jack-4-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(54,1,'JACK 4 PIECE KING BEDROOM SUITE','<p><span>The rustic Jack super king bed frame is completed with a dark wood finish, giving a robust yet modern look, making your bedroom distinctive.</span></p>\r\n\r\n<p>1 x&nbsp;Jack King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table&nbsp;</p>\r\n\r\n<p>1 x Jack Tallboy</p>\r\n\r\n<p>Material: Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p><span>Bed Frame Dimension: H:120 X W:171 X D:207 CM</span></p>\r\n\r\n<p><span>Bedside Dimension: H:55 X W:54 X D:45 CM</span></p>\r\n\r\n<p><span>Tallboy Dimension: H:110 X W:95 X D:46 CM</span></p>\r\n','',0,'','','','','BEST DEAL JACK 4PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XTB','J000,P200,K520,B365,S300','T000,R232,J000,S160,K520,B300,F650,I200,C5143,W300,D620,F520,G152,R123,Y300,M365,L200,M252,Y600,B365,D235231,X51212,B323,T145121,T410,M364,V560,W653,D525,H000,W000,D000,C500',7,0,'jack-4-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(54,1,'JACK 4 PIECE KING BEDROOM SUITE','<p><span>The rustic Jack super king bed frame is completed with a dark wood finish, giving a robust yet modern look, making your bedroom distinctive.</span></p>\r\n\r\n<p>1 x&nbsp;Jack King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table&nbsp;</p>\r\n\r\n<p>1 x Jack Tallboy</p>\r\n\r\n<p>Material: Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p><span>Bed Frame Dimension: H:120 X W:171 X D:207 CM</span></p>\r\n\r\n<p><span>Bedside Dimension: H:55 X W:54 X D:45 CM</span></p>\r\n\r\n<p><span>Tallboy Dimension: H:110 X W:95 X D:46 CM</span></p>\r\n','',0,'','','','','BEST DEAL JACK 4PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XTB','J000,P200,K520,B365,S300','T000,R232,J000,S160,K520,B300,F650,I200,C5143,W300,D620,F520,G152,R123,Y300,M365,L200,M252,Y600,B365,D235231,X51212,B323,T145121,T410,M364,V560,W653,D525,H000,W000,D000,C500',8,0,'jack-4-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(54,1,'JACK 4 PIECE KING BEDROOM SUITE','<p><span>The rustic Jack super king bed frame is completed with a dark wood finish, giving a robust yet modern look, making your bedroom distinctive.</span></p>\r\n\r\n<p>1 x&nbsp;Jack King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table&nbsp;</p>\r\n\r\n<p>1 x Jack Tallboy</p>\r\n\r\n<p>Material: Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p><span>Bed Frame Dimension: H:120 X W:171 X D:207 CM</span></p>\r\n\r\n<p><span>Bedside Dimension: H:55 X W:54 X D:45 CM</span></p>\r\n\r\n<p><span>Tallboy Dimension: H:110 X W:95 X D:46 CM</span></p>\r\n','',0,'','','','','BEST DEAL JACK 4PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XTB','J000,P200,K520,B365,S300','T000,R232,J000,S160,K520,B300,F650,I200,C5143,W300,D620,F520,G152,R123,Y300,M365,L200,M252,Y600,B365,D235231,X51212,B323,T145121,T410,M364,V560,W653,D525,H000,W000,D000,C500',9,0,'jack-4-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(54,1,'JACK 4 PIECE KING BEDROOM SUITE','<p><span>The rustic Jack super king bed frame is completed with a dark wood finish, giving a robust yet modern look, making your bedroom distinctive.</span></p>\r\n\r\n<p>1 x&nbsp;Jack King Bed</p>\r\n\r\n<p>2 x Jack Bedside Table&nbsp;</p>\r\n\r\n<p>1 x Jack Tallboy</p>\r\n\r\n<p>Material: Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p><span>Bed Frame Dimension: H:120 X W:171 X D:207 CM</span></p>\r\n\r\n<p><span>Bedside Dimension: H:55 X W:54 X D:45 CM</span></p>\r\n\r\n<p><span>Tallboy Dimension: H:110 X W:95 X D:46 CM</span></p>\r\n','',0,'','','','','BEST DEAL JACK 4PCE KING BEDROOM PACKAGE 1XKB+2XBS+1XTB','J000,P200,K520,B365,S300','T000,R232,J000,S160,K520,B300,F650,I200,C5143,W300,D620,F520,G152,R123,Y300,M365,L200,M252,Y600,B365,D235231,X51212,B323,T145121,T410,M364,V560,W653,D525,H000,W000,D000,C500',10,0,'jack-4-piece-king-bedroom-suites','',0,0,'','','','',1,1,'',''),(55,1,'HAMPTONS 5 PIECE QUEEN BEDROOM SUITE','<p><span>With a bold, contrasting wood grain and natural protective qualities, the Hamptons range is perfect for connecting a modern lifestyle with the characteristic flavor&nbsp;of a simple country style.</span></p>\r\n\r\n<p>1 x Hampton Queen Bed Frame</p>\r\n\r\n<p>2 x Hampton Bedside Tables</p>\r\n\r\n<p>1 x Hampton Dressing Table</p>\r\n\r\n<p>1 x Hampton Dressing Mirror</p>\r\n\r\n<p>Material: Acacia Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Bed Frame&nbsp;<span>Dimension: H:120 X W:165 X D:218 CM</span></p>\r\n\r\n<p><span>Bed Side Dimension: H:115 X W:100 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Table Dimension: H: 85 X W:135 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Mirror Dimension: H:80 X W:112 X D:2 CM</span></p>\r\n','',0,'','','','','BEST DEAL HAMPTONS 5PCS PACKAGE 1XQB+2XBS+1XDT+1XDM','H51352,P200,Q500,B365,S300','W300,B430,C5362352,G650,A530,N364,P63231,Q432,T000,H51352,R520,I200,P6123,F600,C52352,M365,L1234,C6236232,F4165121,S514,C536,S340,H5135,Q500,B300,F650,B323,T142,D6252,T140,M600,M364,A200,V560,W653,Y600,F651213525,H000,W000,D000,C500,S300,D525',1,0,'hamptons-5-piece-queen-bedroom-suites','',0,0,'','','','',1,1,'',''),(55,1,'HAMPTONS 5 PIECE QUEEN BEDROOM SUITE','<p><span>With a bold, contrasting wood grain and natural protective qualities, the Hamptons range is perfect for connecting a modern lifestyle with the characteristic flavor&nbsp;of a simple country style.</span></p>\r\n\r\n<p>1 x Hampton Queen Bed Frame</p>\r\n\r\n<p>2 x Hampton Bedside Tables</p>\r\n\r\n<p>1 x Hampton Dressing Table</p>\r\n\r\n<p>1 x Hampton Dressing Mirror</p>\r\n\r\n<p>Material: Acacia Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Bed Frame&nbsp;<span>Dimension: H:120 X W:165 X D:218 CM</span></p>\r\n\r\n<p><span>Bed Side Dimension: H:115 X W:100 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Table Dimension: H: 85 X W:135 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Mirror Dimension: H:80 X W:112 X D:2 CM</span></p>\r\n','',0,'','','','','BEST DEAL HAMPTONS 5PCS PACKAGE 1XQB+2XBS+1XDT+1XDM','H51352,P200,Q500,B365,S300','W300,B430,C5362352,G650,A530,N364,P63231,Q432,T000,H51352,R520,I200,P6123,F600,C52352,M365,L1234,C6236232,F4165121,S514,C536,S340,H5135,Q500,B300,F650,B323,T142,D6252,T140,M600,M364,A200,V560,W653,Y600,F651213525,H000,W000,D000,C500,S300,D525',4,0,'hamptons-5-piece-queen-bedroom-suites','',0,0,'','','','',1,1,'',''),(55,1,'HAMPTONS 5 PIECE QUEEN BEDROOM SUITE','<p><span>With a bold, contrasting wood grain and natural protective qualities, the Hamptons range is perfect for connecting a modern lifestyle with the characteristic flavor&nbsp;of a simple country style.</span></p>\r\n\r\n<p>1 x Hampton Queen Bed Frame</p>\r\n\r\n<p>2 x Hampton Bedside Tables</p>\r\n\r\n<p>1 x Hampton Dressing Table</p>\r\n\r\n<p>1 x Hampton Dressing Mirror</p>\r\n\r\n<p>Material: Acacia Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Bed Frame&nbsp;<span>Dimension: H:120 X W:165 X D:218 CM</span></p>\r\n\r\n<p><span>Bed Side Dimension: H:115 X W:100 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Table Dimension: H: 85 X W:135 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Mirror Dimension: H:80 X W:112 X D:2 CM</span></p>\r\n','',0,'','','','','BEST DEAL HAMPTONS 5PCS PACKAGE 1XQB+2XBS+1XDT+1XDM','H51352,P200,Q500,B365,S300','W300,B430,C5362352,G650,A530,N364,P63231,Q432,T000,H51352,R520,I200,P6123,F600,C52352,M365,L1234,C6236232,F4165121,S514,C536,S340,H5135,Q500,B300,F650,B323,T142,D6252,T140,M600,M364,A200,V560,W653,Y600,F651213525,H000,W000,D000,C500,S300,D525',5,0,'hamptons-5-piece-queen-bedroom-suites','',0,0,'','','','',1,1,'',''),(55,1,'HAMPTONS 5 PIECE QUEEN BEDROOM SUITE','<p><span>With a bold, contrasting wood grain and natural protective qualities, the Hamptons range is perfect for connecting a modern lifestyle with the characteristic flavor&nbsp;of a simple country style.</span></p>\r\n\r\n<p>1 x Hampton Queen Bed Frame</p>\r\n\r\n<p>2 x Hampton Bedside Tables</p>\r\n\r\n<p>1 x Hampton Dressing Table</p>\r\n\r\n<p>1 x Hampton Dressing Mirror</p>\r\n\r\n<p>Material: Acacia Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Bed Frame&nbsp;<span>Dimension: H:120 X W:165 X D:218 CM</span></p>\r\n\r\n<p><span>Bed Side Dimension: H:115 X W:100 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Table Dimension: H: 85 X W:135 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Mirror Dimension: H:80 X W:112 X D:2 CM</span></p>\r\n','',0,'','','','','BEST DEAL HAMPTONS 5PCS PACKAGE 1XQB+2XBS+1XDT+1XDM','H51352,P200,Q500,B365,S300','W300,B430,C5362352,G650,A530,N364,P63231,Q432,T000,H51352,R520,I200,P6123,F600,C52352,M365,L1234,C6236232,F4165121,S514,C536,S340,H5135,Q500,B300,F650,B323,T142,D6252,T140,M600,M364,A200,V560,W653,Y600,F651213525,H000,W000,D000,C500,S300,D525',6,0,'hamptons-5-piece-queen-bedroom-suites','',0,0,'','','','',1,1,'',''),(55,1,'HAMPTONS 5 PIECE QUEEN BEDROOM SUITE','<p><span>With a bold, contrasting wood grain and natural protective qualities, the Hamptons range is perfect for connecting a modern lifestyle with the characteristic flavor&nbsp;of a simple country style.</span></p>\r\n\r\n<p>1 x Hampton Queen Bed Frame</p>\r\n\r\n<p>2 x Hampton Bedside Tables</p>\r\n\r\n<p>1 x Hampton Dressing Table</p>\r\n\r\n<p>1 x Hampton Dressing Mirror</p>\r\n\r\n<p>Material: Acacia Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Bed Frame&nbsp;<span>Dimension: H:120 X W:165 X D:218 CM</span></p>\r\n\r\n<p><span>Bed Side Dimension: H:115 X W:100 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Table Dimension: H: 85 X W:135 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Mirror Dimension: H:80 X W:112 X D:2 CM</span></p>\r\n','',0,'','','','','BEST DEAL HAMPTONS 5PCS PACKAGE 1XQB+2XBS+1XDT+1XDM','H51352,P200,Q500,B365,S300','W300,B430,C5362352,G650,A530,N364,P63231,Q432,T000,H51352,R520,I200,P6123,F600,C52352,M365,L1234,C6236232,F4165121,S514,C536,S340,H5135,Q500,B300,F650,B323,T142,D6252,T140,M600,M364,A200,V560,W653,Y600,F651213525,H000,W000,D000,C500,S300,D525',7,0,'hamptons-5-piece-queen-bedroom-suites','',0,0,'','','','',1,1,'',''),(55,1,'HAMPTONS 5 PIECE QUEEN BEDROOM SUITE','<p><span>With a bold, contrasting wood grain and natural protective qualities, the Hamptons range is perfect for connecting a modern lifestyle with the characteristic flavor&nbsp;of a simple country style.</span></p>\r\n\r\n<p>1 x Hampton Queen Bed Frame</p>\r\n\r\n<p>2 x Hampton Bedside Tables</p>\r\n\r\n<p>1 x Hampton Dressing Table</p>\r\n\r\n<p>1 x Hampton Dressing Mirror</p>\r\n\r\n<p>Material: Acacia Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Bed Frame&nbsp;<span>Dimension: H:120 X W:165 X D:218 CM</span></p>\r\n\r\n<p><span>Bed Side Dimension: H:115 X W:100 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Table Dimension: H: 85 X W:135 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Mirror Dimension: H:80 X W:112 X D:2 CM</span></p>\r\n','',0,'','','','','BEST DEAL HAMPTONS 5PCS PACKAGE 1XQB+2XBS+1XDT+1XDM','H51352,P200,Q500,B365,S300','W300,B430,C5362352,G650,A530,N364,P63231,Q432,T000,H51352,R520,I200,P6123,F600,C52352,M365,L1234,C6236232,F4165121,S514,C536,S340,H5135,Q500,B300,F650,B323,T142,D6252,T140,M600,M364,A200,V560,W653,Y600,F651213525,H000,W000,D000,C500,S300,D525',8,0,'hamptons-5-piece-queen-bedroom-suites','',0,0,'','','','',1,1,'',''),(55,1,'HAMPTONS 5 PIECE QUEEN BEDROOM SUITE','<p><span>With a bold, contrasting wood grain and natural protective qualities, the Hamptons range is perfect for connecting a modern lifestyle with the characteristic flavor&nbsp;of a simple country style.</span></p>\r\n\r\n<p>1 x Hampton Queen Bed Frame</p>\r\n\r\n<p>2 x Hampton Bedside Tables</p>\r\n\r\n<p>1 x Hampton Dressing Table</p>\r\n\r\n<p>1 x Hampton Dressing Mirror</p>\r\n\r\n<p>Material: Acacia Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Bed Frame&nbsp;<span>Dimension: H:120 X W:165 X D:218 CM</span></p>\r\n\r\n<p><span>Bed Side Dimension: H:115 X W:100 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Table Dimension: H: 85 X W:135 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Mirror Dimension: H:80 X W:112 X D:2 CM</span></p>\r\n','',0,'','','','','BEST DEAL HAMPTONS 5PCS PACKAGE 1XQB+2XBS+1XDT+1XDM','H51352,P200,Q500,B365,S300','W300,B430,C5362352,G650,A530,N364,P63231,Q432,T000,H51352,R520,I200,P6123,F600,C52352,M365,L1234,C6236232,F4165121,S514,C536,S340,H5135,Q500,B300,F650,B323,T142,D6252,T140,M600,M364,A200,V560,W653,Y600,F651213525,H000,W000,D000,C500,S300,D525',9,0,'hamptons-5-piece-queen-bedroom-suites','',0,0,'','','','',1,1,'',''),(55,1,'HAMPTONS 5 PIECE QUEEN BEDROOM SUITE','<p><span>With a bold, contrasting wood grain and natural protective qualities, the Hamptons range is perfect for connecting a modern lifestyle with the characteristic flavor&nbsp;of a simple country style.</span></p>\r\n\r\n<p>1 x Hampton Queen Bed Frame</p>\r\n\r\n<p>2 x Hampton Bedside Tables</p>\r\n\r\n<p>1 x Hampton Dressing Table</p>\r\n\r\n<p>1 x Hampton Dressing Mirror</p>\r\n\r\n<p>Material: Acacia Veneer</p>\r\n\r\n<p>Warranty: 1 Year</p>\r\n\r\n<p>Bed Frame&nbsp;<span>Dimension: H:120 X W:165 X D:218 CM</span></p>\r\n\r\n<p><span>Bed Side Dimension: H:115 X W:100 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Table Dimension: H: 85 X W:135 X D:48 CM</span></p>\r\n\r\n<p><span>Dressing Mirror Dimension: H:80 X W:112 X D:2 CM</span></p>\r\n','',0,'','','','','BEST DEAL HAMPTONS 5PCS PACKAGE 1XQB+2XBS+1XDT+1XDM','H51352,P200,Q500,B365,S300','W300,B430,C5362352,G650,A530,N364,P63231,Q432,T000,H51352,R520,I200,P6123,F600,C52352,M365,L1234,C6236232,F4165121,S514,C536,S340,H5135,Q500,B300,F650,B323,T142,D6252,T140,M600,M364,A200,V560,W653,Y600,F651213525,H000,W000,D000,C500,S300,D525',10,0,'hamptons-5-piece-queen-bedroom-suites','',0,0,'','','','',1,1,'',''),(56,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','B640,Q430,F300,M362,P63236,K520',NULL,1,0,'brolly-quilted-fitted-mattress-protector-king','',0,0,'','','','',1,1,'',''),(56,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','B640,Q430,F300,M362,P63236,K520',NULL,4,0,'brolly-quilted-fitted-mattress-protector-king','',0,0,'','','','',1,1,'',''),(56,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','B640,Q430,F300,M362,P63236,K520',NULL,5,0,'brolly-quilted-fitted-mattress-protector-king','',0,0,'','','','',1,1,'',''),(56,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','B640,Q430,F300,M362,P63236,K520',NULL,6,0,'brolly-quilted-fitted-mattress-protector-king','',0,0,'','','','',1,1,'',''),(56,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','B640,Q430,F300,M362,P63236,K520',NULL,7,0,'brolly-quilted-fitted-mattress-protector-king','',0,0,'','','','',1,1,'',''),(56,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','B640,Q430,F300,M362,P63236,K520',NULL,8,0,'brolly-quilted-fitted-mattress-protector-king','',0,0,'','','','',1,1,'',''),(56,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','B640,Q430,F300,M362,P63236,K520',NULL,9,0,'brolly-quilted-fitted-mattress-protector-king','',0,0,'','','','',1,1,'',''),(56,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, KING','B640,Q430,F300,M362,P63236,K520',NULL,10,0,'brolly-quilted-fitted-mattress-protector-king','',0,0,'','','','',1,1,'',''),(57,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','B640,Q430,F300,M362,P63236,Q500',NULL,1,0,'brolly-quilted-fitted-mattress-protector-queen','',0,0,'','','','',1,1,'',''),(57,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','B640,Q430,F300,M362,P63236,Q500',NULL,4,0,'brolly-quilted-fitted-mattress-protector-queen','',0,0,'','','','',1,1,'',''),(57,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','B640,Q430,F300,M362,P63236,Q500',NULL,5,0,'brolly-quilted-fitted-mattress-protector-queen','',0,0,'','','','',1,1,'',''),(57,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','B640,Q430,F300,M362,P63236,Q500',NULL,6,0,'brolly-quilted-fitted-mattress-protector-queen','',0,0,'','','','',1,1,'',''),(57,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','B640,Q430,F300,M362,P63236,Q500',NULL,7,0,'brolly-quilted-fitted-mattress-protector-queen','',0,0,'','','','',1,1,'',''),(57,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','B640,Q430,F300,M362,P63236,Q500',NULL,8,0,'brolly-quilted-fitted-mattress-protector-queen','',0,0,'','','','',1,1,'',''),(57,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','B640,Q430,F300,M362,P63236,Q500',NULL,9,0,'brolly-quilted-fitted-mattress-protector-queen','',0,0,'','','','',1,1,'',''),(57,1,'BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','','',0,'','','','','BEST DEAL BROLLY QUILTED FITTED MATTRESS PROTECTOR, QUEEN','B640,Q430,F300,M362,P63236,Q500',NULL,10,0,'brolly-quilted-fitted-mattress-protector-queen','',0,0,'','','','',1,1,'',''),(58,1,'FURTEX ','','',0,'','','','','MESSINA CUSHION, TURQUORISE','F632',NULL,1,0,'messina-cushion-turquorise','',0,0,'','','','',1,1,'',''),(58,1,'FURTEX ','','',0,'','','','','MESSINA CUSHION, TURQUORISE','F632',NULL,4,0,'messina-cushion-turquorise','',0,0,'','','','',1,1,'',''),(58,1,'FURTEX ','','',0,'','','','','MESSINA CUSHION, TURQUORISE','F632',NULL,5,0,'messina-cushion-turquorise','',0,0,'','','','',1,1,'',''),(58,1,'FURTEX ','','',0,'','','','','MESSINA CUSHION, TURQUORISE','F632',NULL,6,0,'messina-cushion-turquorise','',0,0,'','','','',1,1,'',''),(58,1,'FURTEX ','','',0,'','','','','MESSINA CUSHION, TURQUORISE','F632',NULL,7,0,'messina-cushion-turquorise','',0,0,'','','','',1,1,'',''),(58,1,'FURTEX ','','',0,'','','','','MESSINA CUSHION, TURQUORISE','F632',NULL,8,0,'messina-cushion-turquorise','',0,0,'','','','',1,1,'',''),(58,1,'FURTEX ','','',0,'','','','','MESSINA CUSHION, TURQUORISE','F632',NULL,9,0,'messina-cushion-turquorise','',0,0,'','','','',1,1,'',''),(58,1,'FURTEX ','','',0,'','','','','MESSINA CUSHION, TURQUORISE','F632',NULL,10,0,'messina-cushion-turquorise','',0,0,'','','','',1,1,'',''),(59,1,'FURTEX ','','',0,'Metrix Cushion, Orange | PK Furniture','','Buy metrix cushion, orange online now at PK Furniture','','METRIX CUSHION, ORANGE','F632',NULL,1,0,'metrix-cushion-orange','',0,0,'','METRIX CUSHION, ORANGE','FURTEX','',1,1,'',''),(59,1,'FURTEX ','','',0,'Metrix Cushion, Orange | PK Furniture','','Buy metrix cushion, orange online now at PK Furniture','','METRIX CUSHION, ORANGE','F632',NULL,4,0,'metrix-cushion-orange','',0,0,'','METRIX CUSHION, ORANGE','FURTEX','',1,1,'',''),(59,1,'FURTEX ','','',0,'Metrix Cushion, Orange | PK Furniture','','Buy metrix cushion, orange online now at PK Furniture','','METRIX CUSHION, ORANGE','F632',NULL,5,0,'metrix-cushion-orange','',0,0,'','METRIX CUSHION, ORANGE','FURTEX','',1,1,'',''),(59,1,'FURTEX ','','',0,'Metrix Cushion, Orange | PK Furniture','','Buy metrix cushion, orange online now at PK Furniture','','METRIX CUSHION, ORANGE','F632',NULL,6,0,'metrix-cushion-orange','',0,0,'','METRIX CUSHION, ORANGE','FURTEX','',1,1,'',''),(59,1,'FURTEX ','','',0,'Metrix Cushion, Orange | PK Furniture','','Buy metrix cushion, orange online now at PK Furniture','','METRIX CUSHION, ORANGE','F632',NULL,7,0,'metrix-cushion-orange','',0,0,'','METRIX CUSHION, ORANGE','FURTEX','',1,1,'',''),(59,1,'FURTEX ','','',0,'Metrix Cushion, Orange | PK Furniture','','Buy metrix cushion, orange online now at PK Furniture','','METRIX CUSHION, ORANGE','F632',NULL,8,0,'metrix-cushion-orange','',0,0,'','METRIX CUSHION, ORANGE','FURTEX','',1,1,'',''),(59,1,'FURTEX ','','',0,'Metrix Cushion, Orange | PK Furniture','','Buy metrix cushion, orange online now at PK Furniture','','METRIX CUSHION, ORANGE','F632',NULL,9,0,'metrix-cushion-orange','',0,0,'','METRIX CUSHION, ORANGE','FURTEX','',1,1,'',''),(59,1,'FURTEX ','','',0,'Metrix Cushion, Orange | PK Furniture','','Buy metrix cushion, orange online now at PK Furniture','','METRIX CUSHION, ORANGE','F632',NULL,10,0,'metrix-cushion-orange','',0,0,'','METRIX CUSHION, ORANGE','FURTEX','',1,1,'',''),(60,1,'FURTEX ','','',0,'','','','','CLARA THROW, LIME','F632',NULL,1,0,'clara-throw-lime','',0,0,'','','','',1,1,'',''),(60,1,'FURTEX ','','',0,'','','','','CLARA THROW, LIME','F632',NULL,4,0,'clara-throw-lime','',0,0,'','','','',1,1,'',''),(60,1,'FURTEX ','','',0,'','','','','CLARA THROW, LIME','F632',NULL,5,0,'clara-throw-lime','',0,0,'','','','',1,1,'',''),(60,1,'FURTEX ','','',0,'','','','','CLARA THROW, LIME','F632',NULL,6,0,'clara-throw-lime','',0,0,'','','','',1,1,'',''),(60,1,'FURTEX ','','',0,'','','','','CLARA THROW, LIME','F632',NULL,7,0,'clara-throw-lime','',0,0,'','','','',1,1,'',''),(60,1,'FURTEX ','','',0,'','','','','CLARA THROW, LIME','F632',NULL,8,0,'clara-throw-lime','',0,0,'','','','',1,1,'',''),(60,1,'FURTEX ','','',0,'','','','','CLARA THROW, LIME','F632',NULL,9,0,'clara-throw-lime','',0,0,'','','','',1,1,'',''),(60,1,'FURTEX ','','',0,'','','','','CLARA THROW, LIME','F632',NULL,10,0,'clara-throw-lime','',0,0,'','','','',1,1,'',''),(61,1,'FURTEX ','','',0,'','','','','CLARA THROW, PEACOCK','F632',NULL,1,0,'clara-throw-peacock','',0,0,'','','','',1,1,'',''),(61,1,'FURTEX ','','',0,'','','','','CLARA THROW, PEACOCK','F632',NULL,4,0,'clara-throw-peacock','',0,0,'','','','',1,1,'',''),(61,1,'FURTEX ','','',0,'','','','','CLARA THROW, PEACOCK','F632',NULL,5,0,'clara-throw-peacock','',0,0,'','','','',1,1,'',''),(61,1,'FURTEX ','','',0,'','','','','CLARA THROW, PEACOCK','F632',NULL,6,0,'clara-throw-peacock','',0,0,'','','','',1,1,'',''),(61,1,'FURTEX ','','',0,'','','','','CLARA THROW, PEACOCK','F632',NULL,7,0,'clara-throw-peacock','',0,0,'','','','',1,1,'',''),(61,1,'FURTEX ','','',0,'','','','','CLARA THROW, PEACOCK','F632',NULL,8,0,'clara-throw-peacock','',0,0,'','','','',1,1,'',''),(61,1,'FURTEX ','','',0,'','','','','CLARA THROW, PEACOCK','F632',NULL,9,0,'clara-throw-peacock','',0,0,'','','','',1,1,'',''),(61,1,'FURTEX ','','',0,'','','','','CLARA THROW, PEACOCK','F632',NULL,10,0,'clara-throw-peacock','',0,0,'','','','',1,1,'',''),(62,1,'OLIVIA 3 DRAWER DRESSING TABLE','<p><strong><span 2=\"\" data-sheets-userformat=\"{\">This easy-to-love style takes the best of the past and updates it with a modern eye. Whether it&rsquo;s part of a master bedroom set or an eclectic living room arrangement, this dresser is sure to draw attention.</span></strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong><span>Material:</span></strong><span>&nbsp;</span>MDF</p>\r\n\r\n<p><strong><span>Dimension:</span></strong>&nbsp;&nbsp;W<span>:99.5 X D:47.5 X H:76 CM</span></p>\r\n','',0,'3 Drawer Dressing Table | PK Furniture','','Buy 3 drawer dressing table online now at PK Furniture','','OLIVIA 3 DRAWER DRESSING TABLE','O410,D600,D6252,T140','T200,E2341,S340,T000,B230,O100,P230,A530,U132,I300,W300,M365,E000,W360,I362,P630,M236,B365,S300,O600,A500,E24232,L152,R500,A65253,D626,I200,S600,D600,A3535,N121,M3645121531,D5251215121,D000,H000,C500',1,0,'olivia-3-drawer-dressing-table','',0,0,'','3 DRAWER DRESSING TABLE','OLIVIA','',1,1,'',''),(62,1,'OLIVIA 3 DRAWER DRESSING TABLE','<p><strong><span 2=\"\" data-sheets-userformat=\"{\">This easy-to-love style takes the best of the past and updates it with a modern eye. Whether it&rsquo;s part of a master bedroom set or an eclectic living room arrangement, this dresser is sure to draw attention.</span></strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong><span>Material:</span></strong><span>&nbsp;</span>MDF</p>\r\n\r\n<p><strong><span>Dimension:</span></strong>&nbsp;&nbsp;W<span>:99.5 X D:47.5 X H:76 CM</span></p>\r\n','',0,'3 Drawer Dressing Table | PK Furniture','','Buy 3 drawer dressing table online now at PK Furniture','','OLIVIA 3 DRAWER DRESSING TABLE','O410,D600,D6252,T140','T200,E2341,S340,T000,B230,O100,P230,A530,U132,I300,W300,M365,E000,W360,I362,P630,M236,B365,S300,O600,A500,E24232,L152,R500,A65253,D626,I200,S600,D600,A3535,N121,M3645121531,D5251215121,D000,H000,C500',4,0,'olivia-3-drawer-dressing-table','',0,0,'','3 DRAWER DRESSING TABLE','OLIVIA','',1,1,'',''),(62,1,'OLIVIA 3 DRAWER DRESSING TABLE','<p><strong><span 2=\"\" data-sheets-userformat=\"{\">This easy-to-love style takes the best of the past and updates it with a modern eye. Whether it&rsquo;s part of a master bedroom set or an eclectic living room arrangement, this dresser is sure to draw attention.</span></strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong><span>Material:</span></strong><span>&nbsp;</span>MDF</p>\r\n\r\n<p><strong><span>Dimension:</span></strong>&nbsp;&nbsp;W<span>:99.5 X D:47.5 X H:76 CM</span></p>\r\n','',0,'3 Drawer Dressing Table | PK Furniture','','Buy 3 drawer dressing table online now at PK Furniture','','OLIVIA 3 DRAWER DRESSING TABLE','O410,D600,D6252,T140','T200,E2341,S340,T000,B230,O100,P230,A530,U132,I300,W300,M365,E000,W360,I362,P630,M236,B365,S300,O600,A500,E24232,L152,R500,A65253,D626,I200,S600,D600,A3535,N121,M3645121531,D5251215121,D000,H000,C500',5,0,'olivia-3-drawer-dressing-table','',0,0,'','3 DRAWER DRESSING TABLE','OLIVIA','',1,1,'',''),(62,1,'OLIVIA 3 DRAWER DRESSING TABLE','<p><strong><span 2=\"\" data-sheets-userformat=\"{\">This easy-to-love style takes the best of the past and updates it with a modern eye. Whether it&rsquo;s part of a master bedroom set or an eclectic living room arrangement, this dresser is sure to draw attention.</span></strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong><span>Material:</span></strong><span>&nbsp;</span>MDF</p>\r\n\r\n<p><strong><span>Dimension:</span></strong>&nbsp;&nbsp;W<span>:99.5 X D:47.5 X H:76 CM</span></p>\r\n','',0,'3 Drawer Dressing Table | PK Furniture','','Buy 3 drawer dressing table online now at PK Furniture','','OLIVIA 3 DRAWER DRESSING TABLE','O410,D600,D6252,T140','T200,E2341,S340,T000,B230,O100,P230,A530,U132,I300,W300,M365,E000,W360,I362,P630,M236,B365,S300,O600,A500,E24232,L152,R500,A65253,D626,I200,S600,D600,A3535,N121,M3645121531,D5251215121,D000,H000,C500',6,0,'olivia-3-drawer-dressing-table','',0,0,'','3 DRAWER DRESSING TABLE','OLIVIA','',1,1,'',''),(62,1,'OLIVIA 3 DRAWER DRESSING TABLE','<p><strong><span 2=\"\" data-sheets-userformat=\"{\">This easy-to-love style takes the best of the past and updates it with a modern eye. Whether it&rsquo;s part of a master bedroom set or an eclectic living room arrangement, this dresser is sure to draw attention.</span></strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong><span>Material:</span></strong><span>&nbsp;</span>MDF</p>\r\n\r\n<p><strong><span>Dimension:</span></strong>&nbsp;&nbsp;W<span>:99.5 X D:47.5 X H:76 CM</span></p>\r\n','',0,'3 Drawer Dressing Table | PK Furniture','','Buy 3 drawer dressing table online now at PK Furniture','','OLIVIA 3 DRAWER DRESSING TABLE','O410,D600,D6252,T140','T200,E2341,S340,T000,B230,O100,P230,A530,U132,I300,W300,M365,E000,W360,I362,P630,M236,B365,S300,O600,A500,E24232,L152,R500,A65253,D626,I200,S600,D600,A3535,N121,M3645121531,D5251215121,D000,H000,C500',7,0,'olivia-3-drawer-dressing-table','',0,0,'','3 DRAWER DRESSING TABLE','OLIVIA','',1,1,'',''),(62,1,'OLIVIA 3 DRAWER DRESSING TABLE','<p><strong><span 2=\"\" data-sheets-userformat=\"{\">This easy-to-love style takes the best of the past and updates it with a modern eye. Whether it&rsquo;s part of a master bedroom set or an eclectic living room arrangement, this dresser is sure to draw attention.</span></strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong><span>Material:</span></strong><span>&nbsp;</span>MDF</p>\r\n\r\n<p><strong><span>Dimension:</span></strong>&nbsp;&nbsp;W<span>:99.5 X D:47.5 X H:76 CM</span></p>\r\n','',0,'3 Drawer Dressing Table | PK Furniture','','Buy 3 drawer dressing table online now at PK Furniture','','OLIVIA 3 DRAWER DRESSING TABLE','O410,D600,D6252,T140','T200,E2341,S340,T000,B230,O100,P230,A530,U132,I300,W300,M365,E000,W360,I362,P630,M236,B365,S300,O600,A500,E24232,L152,R500,A65253,D626,I200,S600,D600,A3535,N121,M3645121531,D5251215121,D000,H000,C500',8,0,'olivia-3-drawer-dressing-table','',0,0,'','3 DRAWER DRESSING TABLE','OLIVIA','',1,1,'',''),(62,1,'OLIVIA 3 DRAWER DRESSING TABLE','<p><strong><span 2=\"\" data-sheets-userformat=\"{\">This easy-to-love style takes the best of the past and updates it with a modern eye. Whether it&rsquo;s part of a master bedroom set or an eclectic living room arrangement, this dresser is sure to draw attention.</span></strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong><span>Material:</span></strong><span>&nbsp;</span>MDF</p>\r\n\r\n<p><strong><span>Dimension:</span></strong>&nbsp;&nbsp;W<span>:99.5 X D:47.5 X H:76 CM</span></p>\r\n','',0,'3 Drawer Dressing Table | PK Furniture','','Buy 3 drawer dressing table online now at PK Furniture','','OLIVIA 3 DRAWER DRESSING TABLE','O410,D600,D6252,T140','T200,E2341,S340,T000,B230,O100,P230,A530,U132,I300,W300,M365,E000,W360,I362,P630,M236,B365,S300,O600,A500,E24232,L152,R500,A65253,D626,I200,S600,D600,A3535,N121,M3645121531,D5251215121,D000,H000,C500',9,0,'olivia-3-drawer-dressing-table','',0,0,'','3 DRAWER DRESSING TABLE','OLIVIA','',1,1,'',''),(62,1,'OLIVIA 3 DRAWER DRESSING TABLE','<p><strong><span 2=\"\" data-sheets-userformat=\"{\">This easy-to-love style takes the best of the past and updates it with a modern eye. Whether it&rsquo;s part of a master bedroom set or an eclectic living room arrangement, this dresser is sure to draw attention.</span></strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong><span>Material:</span></strong><span>&nbsp;</span>MDF</p>\r\n\r\n<p><strong><span>Dimension:</span></strong>&nbsp;&nbsp;W<span>:99.5 X D:47.5 X H:76 CM</span></p>\r\n','',0,'3 Drawer Dressing Table | PK Furniture','','Buy 3 drawer dressing table online now at PK Furniture','','OLIVIA 3 DRAWER DRESSING TABLE','O410,D600,D6252,T140','T200,E2341,S340,T000,B230,O100,P230,A530,U132,I300,W300,M365,E000,W360,I362,P630,M236,B365,S300,O600,A500,E24232,L152,R500,A65253,D626,I200,S600,D600,A3535,N121,M3645121531,D5251215121,D000,H000,C500',10,0,'olivia-3-drawer-dressing-table','',0,0,'','3 DRAWER DRESSING TABLE','OLIVIA','',1,1,'',''),(63,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong> Air Leather and Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong> Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>3 Seater : H:100 X W:216 X D:100 CM<br />\r\n2 Seater : H:100 X W:106 X D:100 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR, BROWN','C435,R2456,L520,S300','M364,A600,L360,A530,P430,F650,C462,A1414,B650,B200,D525,S360,H000,W000,D000,C500',1,0,'clayton-3rr-2rr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(63,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong> Air Leather and Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong> Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>3 Seater : H:100 X W:216 X D:100 CM<br />\r\n2 Seater : H:100 X W:106 X D:100 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR, BROWN','C435,R2456,L520,S300','M364,A600,L360,A530,P430,F650,C462,A1414,B650,B200,D525,S360,H000,W000,D000,C500',4,0,'clayton-3rr-2rr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(63,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong> Air Leather and Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong> Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>3 Seater : H:100 X W:216 X D:100 CM<br />\r\n2 Seater : H:100 X W:106 X D:100 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR, BROWN','C435,R2456,L520,S300','M364,A600,L360,A530,P430,F650,C462,A1414,B650,B200,D525,S360,H000,W000,D000,C500',5,0,'clayton-3rr-2rr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(63,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong> Air Leather and Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong> Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>3 Seater : H:100 X W:216 X D:100 CM<br />\r\n2 Seater : H:100 X W:106 X D:100 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR, BROWN','C435,R2456,L520,S300','M364,A600,L360,A530,P430,F650,C462,A1414,B650,B200,D525,S360,H000,W000,D000,C500',6,0,'clayton-3rr-2rr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(63,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong> Air Leather and Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong> Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>3 Seater : H:100 X W:216 X D:100 CM<br />\r\n2 Seater : H:100 X W:106 X D:100 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR, BROWN','C435,R2456,L520,S300','M364,A600,L360,A530,P430,F650,C462,A1414,B650,B200,D525,S360,H000,W000,D000,C500',7,0,'clayton-3rr-2rr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(63,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong> Air Leather and Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong> Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>3 Seater : H:100 X W:216 X D:100 CM<br />\r\n2 Seater : H:100 X W:106 X D:100 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR, BROWN','C435,R2456,L520,S300','M364,A600,L360,A530,P430,F650,C462,A1414,B650,B200,D525,S360,H000,W000,D000,C500',8,0,'clayton-3rr-2rr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(63,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong> Air Leather and Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong> Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>3 Seater : H:100 X W:216 X D:100 CM<br />\r\n2 Seater : H:100 X W:106 X D:100 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR, BROWN','C435,R2456,L520,S300','M364,A600,L360,A530,P430,F650,C462,A1414,B650,B200,D525,S360,H000,W000,D000,C500',9,0,'clayton-3rr-2rr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(63,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong> Air Leather and Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong> Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>3 Seater : H:100 X W:216 X D:100 CM<br />\r\n2 Seater : H:100 X W:106 X D:100 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR, BROWN','C435,R2456,L520,S300','M364,A600,L360,A530,P430,F650,C462,A1414,B650,B200,D525,S360,H000,W000,D000,C500',10,0,'clayton-3rr-2rr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(64,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong>&nbsp;Air Leather, Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;</p>\r\n\r\n<p>3 Seater: H:100 X W:216 X D:100 CM</p>\r\n\r\n<p>2 Seater: H:100 X W:106 X D:100 CM</p>\r\n\r\n<p>Single Seater: H:100 X W:103 X D:96 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR+SR, BROWN','C435,R2456,L520,S300','M36451216,L360,P430,F650,C462,A1414512165,A530,B200,D525121,S360,H000,W000,D000,C500,S524',1,0,'clayton-3rr-2rr-sr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(64,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong>&nbsp;Air Leather, Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;</p>\r\n\r\n<p>3 Seater: H:100 X W:216 X D:100 CM</p>\r\n\r\n<p>2 Seater: H:100 X W:106 X D:100 CM</p>\r\n\r\n<p>Single Seater: H:100 X W:103 X D:96 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR+SR, BROWN','C435,R2456,L520,S300','M36451216,L360,P430,F650,C462,A1414512165,A530,B200,D525121,S360,H000,W000,D000,C500,S524',4,0,'clayton-3rr-2rr-sr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(64,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong>&nbsp;Air Leather, Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;</p>\r\n\r\n<p>3 Seater: H:100 X W:216 X D:100 CM</p>\r\n\r\n<p>2 Seater: H:100 X W:106 X D:100 CM</p>\r\n\r\n<p>Single Seater: H:100 X W:103 X D:96 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR+SR, BROWN','C435,R2456,L520,S300','M36451216,L360,P430,F650,C462,A1414512165,A530,B200,D525121,S360,H000,W000,D000,C500,S524',5,0,'clayton-3rr-2rr-sr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(64,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong>&nbsp;Air Leather, Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;</p>\r\n\r\n<p>3 Seater: H:100 X W:216 X D:100 CM</p>\r\n\r\n<p>2 Seater: H:100 X W:106 X D:100 CM</p>\r\n\r\n<p>Single Seater: H:100 X W:103 X D:96 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR+SR, BROWN','C435,R2456,L520,S300','M36451216,L360,P430,F650,C462,A1414512165,A530,B200,D525121,S360,H000,W000,D000,C500,S524',6,0,'clayton-3rr-2rr-sr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(64,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong>&nbsp;Air Leather, Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;</p>\r\n\r\n<p>3 Seater: H:100 X W:216 X D:100 CM</p>\r\n\r\n<p>2 Seater: H:100 X W:106 X D:100 CM</p>\r\n\r\n<p>Single Seater: H:100 X W:103 X D:96 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR+SR, BROWN','C435,R2456,L520,S300','M36451216,L360,P430,F650,C462,A1414512165,A530,B200,D525121,S360,H000,W000,D000,C500,S524',7,0,'clayton-3rr-2rr-sr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(64,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong>&nbsp;Air Leather, Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;</p>\r\n\r\n<p>3 Seater: H:100 X W:216 X D:100 CM</p>\r\n\r\n<p>2 Seater: H:100 X W:106 X D:100 CM</p>\r\n\r\n<p>Single Seater: H:100 X W:103 X D:96 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR+SR, BROWN','C435,R2456,L520,S300','M36451216,L360,P430,F650,C462,A1414512165,A530,B200,D525121,S360,H000,W000,D000,C500,S524',8,0,'clayton-3rr-2rr-sr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(64,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong>&nbsp;Air Leather, Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;</p>\r\n\r\n<p>3 Seater: H:100 X W:216 X D:100 CM</p>\r\n\r\n<p>2 Seater: H:100 X W:106 X D:100 CM</p>\r\n\r\n<p>Single Seater: H:100 X W:103 X D:96 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR+SR, BROWN','C435,R2456,L520,S300','M36451216,L360,P430,F650,C462,A1414512165,A530,B200,D525121,S360,H000,W000,D000,C500,S524',9,0,'clayton-3rr-2rr-sr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(64,1,'CLAYTON RECLINER LOUNGE SUITE','<p><strong>Material:</strong>&nbsp;Air Leather, Plywood Frame</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Brown and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;</p>\r\n\r\n<p>3 Seater: H:100 X W:216 X D:100 CM</p>\r\n\r\n<p>2 Seater: H:100 X W:106 X D:100 CM</p>\r\n\r\n<p>Single Seater: H:100 X W:103 X D:96 CM</p>\r\n','',0,'Recliner Lounge Suite, Brown | PK Furniture','','Buy recliner lounge suite, brown online now at PK Furniture','','BEST DEAL CLAYTON 3RR+2RR+SR, BROWN','C435,R2456,L520,S300','M36451216,L360,P430,F650,C462,A1414512165,A530,B200,D525121,S360,H000,W000,D000,C500,S524',10,0,'clayton-3rr-2rr-sr-brown','',0,0,'','RECLINER LOUNGE SUITE, BROWN','CLAYTON','',1,1,'',''),(65,1,'VERONICA 4 PIECE QUEEN BEDROOM SUITE','<p>Ready for a new look in your restful retreat? Go for a simply stylish display with this bedroom suite. Crafted from pine wood, it showcases a clean-lined frame with an espresso finish and high slatted headrest.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Pine</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Queen Bed:&nbsp;H:118 X W:167 X D:225 CM</p>\r\n\r\n<p>Bedside:&nbsp;H:63 X W:48 X D:40 CM</p>\r\n\r\n<p>Tallboy:&nbsp;H:120 X W:90 X D:43&nbsp;CM</p>\r\n\r\n<p><strong>Set Includes</strong>:</p>\r\n\r\n<ul>\r\n	<li>1 x Veronica&nbsp;Queen Bed Frame</li>\r\n	<li>2 x Veronica Bedside Tables</li>\r\n	<li>1 x Veronica&nbsp;Tallboy</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL NEW VERONICA 4PCS PACKAGE 1XQB+2XBS+1XTB','V652,P200,Q500,B365,S300','R300,F600,N000,L200,I500,Y600,R2314,R363,G000,S514,S342,D214,W300,T200,B365,S300,C613,F650,P500,I300,S000,C45453,A500,E2162,F520,A530,H200,S430,H3623,N121,M36451215,D525,Q500,B35121,W000,D000,C500,B3235121,T415121,D512125,I52432,V652512125,B300,V652,B323,T142,V6525121341',1,0,'new-veronica-4pcs-package-1xqb-2xbs-1xtb','',0,0,'','','','',1,1,'',''),(65,1,'VERONICA 4 PIECE QUEEN BEDROOM SUITE','<p>Ready for a new look in your restful retreat? Go for a simply stylish display with this bedroom suite. Crafted from pine wood, it showcases a clean-lined frame with an espresso finish and high slatted headrest.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Pine</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Queen Bed:&nbsp;H:118 X W:167 X D:225 CM</p>\r\n\r\n<p>Bedside:&nbsp;H:63 X W:48 X D:40 CM</p>\r\n\r\n<p>Tallboy:&nbsp;H:120 X W:90 X D:43&nbsp;CM</p>\r\n\r\n<p><strong>Set Includes</strong>:</p>\r\n\r\n<ul>\r\n	<li>1 x Veronica&nbsp;Queen Bed Frame</li>\r\n	<li>2 x Veronica Bedside Tables</li>\r\n	<li>1 x Veronica&nbsp;Tallboy</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL NEW VERONICA 4PCS PACKAGE 1XQB+2XBS+1XTB','V652,P200,Q500,B365,S300','R300,F600,N000,L200,I500,Y600,R2314,R363,G000,S514,S342,D214,W300,T200,B365,S300,C613,F650,P500,I300,S000,C45453,A500,E2162,F520,A530,H200,S430,H3623,N121,M36451215,D525,Q500,B35121,W000,D000,C500,B3235121,T415121,D512125,I52432,V652512125,B300,V652,B323,T142,V6525121341',4,0,'new-veronica-4pcs-package-1xqb-2xbs-1xtb','',0,0,'','','','',1,1,'',''),(65,1,'VERONICA 4 PIECE QUEEN BEDROOM SUITE','<p>Ready for a new look in your restful retreat? Go for a simply stylish display with this bedroom suite. Crafted from pine wood, it showcases a clean-lined frame with an espresso finish and high slatted headrest.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Pine</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Queen Bed:&nbsp;H:118 X W:167 X D:225 CM</p>\r\n\r\n<p>Bedside:&nbsp;H:63 X W:48 X D:40 CM</p>\r\n\r\n<p>Tallboy:&nbsp;H:120 X W:90 X D:43&nbsp;CM</p>\r\n\r\n<p><strong>Set Includes</strong>:</p>\r\n\r\n<ul>\r\n	<li>1 x Veronica&nbsp;Queen Bed Frame</li>\r\n	<li>2 x Veronica Bedside Tables</li>\r\n	<li>1 x Veronica&nbsp;Tallboy</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL NEW VERONICA 4PCS PACKAGE 1XQB+2XBS+1XTB','V652,P200,Q500,B365,S300','R300,F600,N000,L200,I500,Y600,R2314,R363,G000,S514,S342,D214,W300,T200,B365,S300,C613,F650,P500,I300,S000,C45453,A500,E2162,F520,A530,H200,S430,H3623,N121,M36451215,D525,Q500,B35121,W000,D000,C500,B3235121,T415121,D512125,I52432,V652512125,B300,V652,B323,T142,V6525121341',5,0,'new-veronica-4pcs-package-1xqb-2xbs-1xtb','',0,0,'','','','',1,1,'',''),(65,1,'VERONICA 4 PIECE QUEEN BEDROOM SUITE','<p>Ready for a new look in your restful retreat? Go for a simply stylish display with this bedroom suite. Crafted from pine wood, it showcases a clean-lined frame with an espresso finish and high slatted headrest.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Pine</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Queen Bed:&nbsp;H:118 X W:167 X D:225 CM</p>\r\n\r\n<p>Bedside:&nbsp;H:63 X W:48 X D:40 CM</p>\r\n\r\n<p>Tallboy:&nbsp;H:120 X W:90 X D:43&nbsp;CM</p>\r\n\r\n<p><strong>Set Includes</strong>:</p>\r\n\r\n<ul>\r\n	<li>1 x Veronica&nbsp;Queen Bed Frame</li>\r\n	<li>2 x Veronica Bedside Tables</li>\r\n	<li>1 x Veronica&nbsp;Tallboy</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL NEW VERONICA 4PCS PACKAGE 1XQB+2XBS+1XTB','V652,P200,Q500,B365,S300','R300,F600,N000,L200,I500,Y600,R2314,R363,G000,S514,S342,D214,W300,T200,B365,S300,C613,F650,P500,I300,S000,C45453,A500,E2162,F520,A530,H200,S430,H3623,N121,M36451215,D525,Q500,B35121,W000,D000,C500,B3235121,T415121,D512125,I52432,V652512125,B300,V652,B323,T142,V6525121341',6,0,'new-veronica-4pcs-package-1xqb-2xbs-1xtb','',0,0,'','','','',1,1,'',''),(65,1,'VERONICA 4 PIECE QUEEN BEDROOM SUITE','<p>Ready for a new look in your restful retreat? Go for a simply stylish display with this bedroom suite. Crafted from pine wood, it showcases a clean-lined frame with an espresso finish and high slatted headrest.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Pine</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Queen Bed:&nbsp;H:118 X W:167 X D:225 CM</p>\r\n\r\n<p>Bedside:&nbsp;H:63 X W:48 X D:40 CM</p>\r\n\r\n<p>Tallboy:&nbsp;H:120 X W:90 X D:43&nbsp;CM</p>\r\n\r\n<p><strong>Set Includes</strong>:</p>\r\n\r\n<ul>\r\n	<li>1 x Veronica&nbsp;Queen Bed Frame</li>\r\n	<li>2 x Veronica Bedside Tables</li>\r\n	<li>1 x Veronica&nbsp;Tallboy</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL NEW VERONICA 4PCS PACKAGE 1XQB+2XBS+1XTB','V652,P200,Q500,B365,S300','R300,F600,N000,L200,I500,Y600,R2314,R363,G000,S514,S342,D214,W300,T200,B365,S300,C613,F650,P500,I300,S000,C45453,A500,E2162,F520,A530,H200,S430,H3623,N121,M36451215,D525,Q500,B35121,W000,D000,C500,B3235121,T415121,D512125,I52432,V652512125,B300,V652,B323,T142,V6525121341',7,0,'new-veronica-4pcs-package-1xqb-2xbs-1xtb','',0,0,'','','','',1,1,'',''),(65,1,'VERONICA 4 PIECE QUEEN BEDROOM SUITE','<p>Ready for a new look in your restful retreat? Go for a simply stylish display with this bedroom suite. Crafted from pine wood, it showcases a clean-lined frame with an espresso finish and high slatted headrest.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Pine</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Queen Bed:&nbsp;H:118 X W:167 X D:225 CM</p>\r\n\r\n<p>Bedside:&nbsp;H:63 X W:48 X D:40 CM</p>\r\n\r\n<p>Tallboy:&nbsp;H:120 X W:90 X D:43&nbsp;CM</p>\r\n\r\n<p><strong>Set Includes</strong>:</p>\r\n\r\n<ul>\r\n	<li>1 x Veronica&nbsp;Queen Bed Frame</li>\r\n	<li>2 x Veronica Bedside Tables</li>\r\n	<li>1 x Veronica&nbsp;Tallboy</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL NEW VERONICA 4PCS PACKAGE 1XQB+2XBS+1XTB','V652,P200,Q500,B365,S300','R300,F600,N000,L200,I500,Y600,R2314,R363,G000,S514,S342,D214,W300,T200,B365,S300,C613,F650,P500,I300,S000,C45453,A500,E2162,F520,A530,H200,S430,H3623,N121,M36451215,D525,Q500,B35121,W000,D000,C500,B3235121,T415121,D512125,I52432,V652512125,B300,V652,B323,T142,V6525121341',8,0,'new-veronica-4pcs-package-1xqb-2xbs-1xtb','',0,0,'','','','',1,1,'',''),(65,1,'VERONICA 4 PIECE QUEEN BEDROOM SUITE','<p>Ready for a new look in your restful retreat? Go for a simply stylish display with this bedroom suite. Crafted from pine wood, it showcases a clean-lined frame with an espresso finish and high slatted headrest.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Pine</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Queen Bed:&nbsp;H:118 X W:167 X D:225 CM</p>\r\n\r\n<p>Bedside:&nbsp;H:63 X W:48 X D:40 CM</p>\r\n\r\n<p>Tallboy:&nbsp;H:120 X W:90 X D:43&nbsp;CM</p>\r\n\r\n<p><strong>Set Includes</strong>:</p>\r\n\r\n<ul>\r\n	<li>1 x Veronica&nbsp;Queen Bed Frame</li>\r\n	<li>2 x Veronica Bedside Tables</li>\r\n	<li>1 x Veronica&nbsp;Tallboy</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL NEW VERONICA 4PCS PACKAGE 1XQB+2XBS+1XTB','V652,P200,Q500,B365,S300','R300,F600,N000,L200,I500,Y600,R2314,R363,G000,S514,S342,D214,W300,T200,B365,S300,C613,F650,P500,I300,S000,C45453,A500,E2162,F520,A530,H200,S430,H3623,N121,M36451215,D525,Q500,B35121,W000,D000,C500,B3235121,T415121,D512125,I52432,V652512125,B300,V652,B323,T142,V6525121341',9,0,'new-veronica-4pcs-package-1xqb-2xbs-1xtb','',0,0,'','','','',1,1,'',''),(65,1,'VERONICA 4 PIECE QUEEN BEDROOM SUITE','<p>Ready for a new look in your restful retreat? Go for a simply stylish display with this bedroom suite. Crafted from pine wood, it showcases a clean-lined frame with an espresso finish and high slatted headrest.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Pine</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Queen Bed:&nbsp;H:118 X W:167 X D:225 CM</p>\r\n\r\n<p>Bedside:&nbsp;H:63 X W:48 X D:40 CM</p>\r\n\r\n<p>Tallboy:&nbsp;H:120 X W:90 X D:43&nbsp;CM</p>\r\n\r\n<p><strong>Set Includes</strong>:</p>\r\n\r\n<ul>\r\n	<li>1 x Veronica&nbsp;Queen Bed Frame</li>\r\n	<li>2 x Veronica Bedside Tables</li>\r\n	<li>1 x Veronica&nbsp;Tallboy</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL NEW VERONICA 4PCS PACKAGE 1XQB+2XBS+1XTB','V652,P200,Q500,B365,S300','R300,F600,N000,L200,I500,Y600,R2314,R363,G000,S514,S342,D214,W300,T200,B365,S300,C613,F650,P500,I300,S000,C45453,A500,E2162,F520,A530,H200,S430,H3623,N121,M36451215,D525,Q500,B35121,W000,D000,C500,B3235121,T415121,D512125,I52432,V652512125,B300,V652,B323,T142,V6525121341',10,0,'new-veronica-4pcs-package-1xqb-2xbs-1xtb','',0,0,'','','','',1,1,'',''),(66,1,'MONA 2 SEATER SOFA','<p><strong>The latest European style Mona Sofa looks great and sits well. Well made with dark coloured wooden legs and a webbed seat system providing lasting comfort and quality. The sofa is available in four fabric options, and would look&nbsp;great wherever it is placed and would definitely make the room look enhancing.</strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Velvet Fabric and Wooden Legs</p>\r\n\r\n<p><strong>Colours Available:</strong> Merlot Red, Royal Blue, Forest Green and Stone Grey</p>\r\n\r\n<p><strong>Dimension:</strong> H:94 X W:125 X D:78 CM</p>\r\n','',0,'','','','','','M000,S360,S100','T000,L323,E615,S340,M000,S100,L200,G630,A530,S320,W400,M300,W300,D620,C463,W350,W130,S300,S350,P61352,L2352,C5163,Q430,I200,A1414,I500,F600,F620,O1352,W430,L25121263,W616,I300,P423,D1534,M200,R500,E5252,N121,M364,V413,C462,M643,R300,R400,B400,F623,G650,G600,D525,H000,W000,D000,C500',1,0,'mona-1237-red','',0,0,'','','','',1,1,'',''),(66,1,'MONA 2 SEATER SOFA','<p><strong>The latest European style Mona Sofa looks great and sits well. Well made with dark coloured wooden legs and a webbed seat system providing lasting comfort and quality. The sofa is available in four fabric options, and would look&nbsp;great wherever it is placed and would definitely make the room look enhancing.</strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Velvet Fabric and Wooden Legs</p>\r\n\r\n<p><strong>Colours Available:</strong> Merlot Red, Royal Blue, Forest Green and Stone Grey</p>\r\n\r\n<p><strong>Dimension:</strong> H:94 X W:125 X D:78 CM</p>\r\n','',0,'','','','','','M000,S360,S100','T000,L323,E615,S340,M000,S100,L200,G630,A530,S320,W400,M300,W300,D620,C463,W350,W130,S300,S350,P61352,L2352,C5163,Q430,I200,A1414,I500,F600,F620,O1352,W430,L25121263,W616,I300,P423,D1534,M200,R500,E5252,N121,M364,V413,C462,M643,R300,R400,B400,F623,G650,G600,D525,H000,W000,D000,C500',4,0,'mona-1237-red','',0,0,'','','','',1,1,'',''),(66,1,'MONA 2 SEATER SOFA','<p><strong>The latest European style Mona Sofa looks great and sits well. Well made with dark coloured wooden legs and a webbed seat system providing lasting comfort and quality. The sofa is available in four fabric options, and would look&nbsp;great wherever it is placed and would definitely make the room look enhancing.</strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Velvet Fabric and Wooden Legs</p>\r\n\r\n<p><strong>Colours Available:</strong> Merlot Red, Royal Blue, Forest Green and Stone Grey</p>\r\n\r\n<p><strong>Dimension:</strong> H:94 X W:125 X D:78 CM</p>\r\n','',0,'','','','','','M000,S360,S100','T000,L323,E615,S340,M000,S100,L200,G630,A530,S320,W400,M300,W300,D620,C463,W350,W130,S300,S350,P61352,L2352,C5163,Q430,I200,A1414,I500,F600,F620,O1352,W430,L25121263,W616,I300,P423,D1534,M200,R500,E5252,N121,M364,V413,C462,M643,R300,R400,B400,F623,G650,G600,D525,H000,W000,D000,C500',5,0,'mona-1237-red','',0,0,'','','','',1,1,'',''),(66,1,'MONA 2 SEATER SOFA','<p><strong>The latest European style Mona Sofa looks great and sits well. Well made with dark coloured wooden legs and a webbed seat system providing lasting comfort and quality. The sofa is available in four fabric options, and would look&nbsp;great wherever it is placed and would definitely make the room look enhancing.</strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Velvet Fabric and Wooden Legs</p>\r\n\r\n<p><strong>Colours Available:</strong> Merlot Red, Royal Blue, Forest Green and Stone Grey</p>\r\n\r\n<p><strong>Dimension:</strong> H:94 X W:125 X D:78 CM</p>\r\n','',0,'','','','','','M000,S360,S100','T000,L323,E615,S340,M000,S100,L200,G630,A530,S320,W400,M300,W300,D620,C463,W350,W130,S300,S350,P61352,L2352,C5163,Q430,I200,A1414,I500,F600,F620,O1352,W430,L25121263,W616,I300,P423,D1534,M200,R500,E5252,N121,M364,V413,C462,M643,R300,R400,B400,F623,G650,G600,D525,H000,W000,D000,C500',6,0,'mona-1237-red','',0,0,'','','','',1,1,'',''),(66,1,'MONA 2 SEATER SOFA','<p><strong>The latest European style Mona Sofa looks great and sits well. Well made with dark coloured wooden legs and a webbed seat system providing lasting comfort and quality. The sofa is available in four fabric options, and would look&nbsp;great wherever it is placed and would definitely make the room look enhancing.</strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Velvet Fabric and Wooden Legs</p>\r\n\r\n<p><strong>Colours Available:</strong> Merlot Red, Royal Blue, Forest Green and Stone Grey</p>\r\n\r\n<p><strong>Dimension:</strong> H:94 X W:125 X D:78 CM</p>\r\n','',0,'','','','','','M000,S360,S100','T000,L323,E615,S340,M000,S100,L200,G630,A530,S320,W400,M300,W300,D620,C463,W350,W130,S300,S350,P61352,L2352,C5163,Q430,I200,A1414,I500,F600,F620,O1352,W430,L25121263,W616,I300,P423,D1534,M200,R500,E5252,N121,M364,V413,C462,M643,R300,R400,B400,F623,G650,G600,D525,H000,W000,D000,C500',7,0,'mona-1237-red','',0,0,'','','','',1,1,'',''),(66,1,'MONA 2 SEATER SOFA','<p><strong>The latest European style Mona Sofa looks great and sits well. Well made with dark coloured wooden legs and a webbed seat system providing lasting comfort and quality. The sofa is available in four fabric options, and would look&nbsp;great wherever it is placed and would definitely make the room look enhancing.</strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Velvet Fabric and Wooden Legs</p>\r\n\r\n<p><strong>Colours Available:</strong> Merlot Red, Royal Blue, Forest Green and Stone Grey</p>\r\n\r\n<p><strong>Dimension:</strong> H:94 X W:125 X D:78 CM</p>\r\n','',0,'','','','','','M000,S360,S100','T000,L323,E615,S340,M000,S100,L200,G630,A530,S320,W400,M300,W300,D620,C463,W350,W130,S300,S350,P61352,L2352,C5163,Q430,I200,A1414,I500,F600,F620,O1352,W430,L25121263,W616,I300,P423,D1534,M200,R500,E5252,N121,M364,V413,C462,M643,R300,R400,B400,F623,G650,G600,D525,H000,W000,D000,C500',8,0,'mona-1237-red','',0,0,'','','','',1,1,'',''),(66,1,'MONA 2 SEATER SOFA','<p><strong>The latest European style Mona Sofa looks great and sits well. Well made with dark coloured wooden legs and a webbed seat system providing lasting comfort and quality. The sofa is available in four fabric options, and would look&nbsp;great wherever it is placed and would definitely make the room look enhancing.</strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Velvet Fabric and Wooden Legs</p>\r\n\r\n<p><strong>Colours Available:</strong> Merlot Red, Royal Blue, Forest Green and Stone Grey</p>\r\n\r\n<p><strong>Dimension:</strong> H:94 X W:125 X D:78 CM</p>\r\n','',0,'','','','','','M000,S360,S100','T000,L323,E615,S340,M000,S100,L200,G630,A530,S320,W400,M300,W300,D620,C463,W350,W130,S300,S350,P61352,L2352,C5163,Q430,I200,A1414,I500,F600,F620,O1352,W430,L25121263,W616,I300,P423,D1534,M200,R500,E5252,N121,M364,V413,C462,M643,R300,R400,B400,F623,G650,G600,D525,H000,W000,D000,C500',9,0,'mona-1237-red','',0,0,'','','','',1,1,'',''),(66,1,'MONA 2 SEATER SOFA','<p><strong>The latest European style Mona Sofa looks great and sits well. Well made with dark coloured wooden legs and a webbed seat system providing lasting comfort and quality. The sofa is available in four fabric options, and would look&nbsp;great wherever it is placed and would definitely make the room look enhancing.</strong></p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Velvet Fabric and Wooden Legs</p>\r\n\r\n<p><strong>Colours Available:</strong> Merlot Red, Royal Blue, Forest Green and Stone Grey</p>\r\n\r\n<p><strong>Dimension:</strong> H:94 X W:125 X D:78 CM</p>\r\n','',0,'','','','','','M000,S360,S100','T000,L323,E615,S340,M000,S100,L200,G630,A530,S320,W400,M300,W300,D620,C463,W350,W130,S300,S350,P61352,L2352,C5163,Q430,I200,A1414,I500,F600,F620,O1352,W430,L25121263,W616,I300,P423,D1534,M200,R500,E5252,N121,M364,V413,C462,M643,R300,R400,B400,F623,G650,G600,D525,H000,W000,D000,C500',10,0,'mona-1237-red','',0,0,'','','','',1,1,'',''),(67,1,'MICHAEL 7 PIECE 150 DINING SUITE','<p>The combination of glass and solid timber legs gives this dining suite a contemporary look that is perfect for everyday living.&nbsp;</p>\r\n\r\n<p>The Michael Dining Table comes in Grey or&nbsp;Black tempered glass top, and two sizes (150CM or 180CM) that you can choose from that is suitable&nbsp;for&nbsp;your dining room.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material: </strong>Tempered Glass Top, Solid Beech Legs</p>\r\n\r\n<p><strong>Colours Available:&nbsp;</strong>Grey and&nbsp;Black</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Table Dimension: H: 72.8 X W:150 X D:90 CM<br />\r\nChair Dimension: H:87 X W:48 X D:57 CM<br />\r\n<strong>Suite includes:</strong></p>\r\n\r\n<p>1 x Michael 150 Dining Table&nbsp;<br />\r\n6 x Michael Dining Chair</p>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>MICHAEL</b>&nbsp;150 DINING PACKAGE, BLACK 1 TABLE + 6 BLUE CHAIRS','M240,P200,D520,S300','T000,C51535,O100,G420,A530,S430,T516,L200,G120,T200,D520,S300,C53516,I200,P6123,F600,E163,L1525121,M240,T140,C520,I500,G600,O6512142,T5163,T100,S000,C500,O600,Y000,C000,F650,S3145121651216,R51215121,N121,M364,B200,C462,A1414512126,A53512142,D525,H000,W000,D000,C600,I52432,T145121',1,0,'michael-150-dining-package-black-1-table-6-blue-chairs','',0,0,'','','','',1,1,'',''),(67,1,'MICHAEL 7 PIECE 150 DINING SUITE','<p>The combination of glass and solid timber legs gives this dining suite a contemporary look that is perfect for everyday living.&nbsp;</p>\r\n\r\n<p>The Michael Dining Table comes in Grey or&nbsp;Black tempered glass top, and two sizes (150CM or 180CM) that you can choose from that is suitable&nbsp;for&nbsp;your dining room.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material: </strong>Tempered Glass Top, Solid Beech Legs</p>\r\n\r\n<p><strong>Colours Available:&nbsp;</strong>Grey and&nbsp;Black</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Table Dimension: H: 72.8 X W:150 X D:90 CM<br />\r\nChair Dimension: H:87 X W:48 X D:57 CM<br />\r\n<strong>Suite includes:</strong></p>\r\n\r\n<p>1 x Michael 150 Dining Table&nbsp;<br />\r\n6 x Michael Dining Chair</p>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>MICHAEL</b>&nbsp;150 DINING PACKAGE, BLACK 1 TABLE + 6 BLUE CHAIRS','M240,P200,D520,S300','T000,C51535,O100,G420,A530,S430,T516,L200,G120,T200,D520,S300,C53516,I200,P6123,F600,E163,L1525121,M240,T140,C520,I500,G600,O6512142,T5163,T100,S000,C500,O600,Y000,C000,F650,S3145121651216,R51215121,N121,M364,B200,C462,A1414512126,A53512142,D525,H000,W000,D000,C600,I52432,T145121',4,0,'michael-150-dining-package-black-1-table-6-blue-chairs','',0,0,'','','','',1,1,'',''),(67,1,'MICHAEL 7 PIECE 150 DINING SUITE','<p>The combination of glass and solid timber legs gives this dining suite a contemporary look that is perfect for everyday living.&nbsp;</p>\r\n\r\n<p>The Michael Dining Table comes in Grey or&nbsp;Black tempered glass top, and two sizes (150CM or 180CM) that you can choose from that is suitable&nbsp;for&nbsp;your dining room.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material: </strong>Tempered Glass Top, Solid Beech Legs</p>\r\n\r\n<p><strong>Colours Available:&nbsp;</strong>Grey and&nbsp;Black</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Table Dimension: H: 72.8 X W:150 X D:90 CM<br />\r\nChair Dimension: H:87 X W:48 X D:57 CM<br />\r\n<strong>Suite includes:</strong></p>\r\n\r\n<p>1 x Michael 150 Dining Table&nbsp;<br />\r\n6 x Michael Dining Chair</p>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>MICHAEL</b>&nbsp;150 DINING PACKAGE, BLACK 1 TABLE + 6 BLUE CHAIRS','M240,P200,D520,S300','T000,C51535,O100,G420,A530,S430,T516,L200,G120,T200,D520,S300,C53516,I200,P6123,F600,E163,L1525121,M240,T140,C520,I500,G600,O6512142,T5163,T100,S000,C500,O600,Y000,C000,F650,S3145121651216,R51215121,N121,M364,B200,C462,A1414512126,A53512142,D525,H000,W000,D000,C600,I52432,T145121',5,0,'michael-150-dining-package-black-1-table-6-blue-chairs','',0,0,'','','','',1,1,'',''),(67,1,'MICHAEL 7 PIECE 150 DINING SUITE','<p>The combination of glass and solid timber legs gives this dining suite a contemporary look that is perfect for everyday living.&nbsp;</p>\r\n\r\n<p>The Michael Dining Table comes in Grey or&nbsp;Black tempered glass top, and two sizes (150CM or 180CM) that you can choose from that is suitable&nbsp;for&nbsp;your dining room.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material: </strong>Tempered Glass Top, Solid Beech Legs</p>\r\n\r\n<p><strong>Colours Available:&nbsp;</strong>Grey and&nbsp;Black</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Table Dimension: H: 72.8 X W:150 X D:90 CM<br />\r\nChair Dimension: H:87 X W:48 X D:57 CM<br />\r\n<strong>Suite includes:</strong></p>\r\n\r\n<p>1 x Michael 150 Dining Table&nbsp;<br />\r\n6 x Michael Dining Chair</p>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>MICHAEL</b>&nbsp;150 DINING PACKAGE, BLACK 1 TABLE + 6 BLUE CHAIRS','M240,P200,D520,S300','T000,C51535,O100,G420,A530,S430,T516,L200,G120,T200,D520,S300,C53516,I200,P6123,F600,E163,L1525121,M240,T140,C520,I500,G600,O6512142,T5163,T100,S000,C500,O600,Y000,C000,F650,S3145121651216,R51215121,N121,M364,B200,C462,A1414512126,A53512142,D525,H000,W000,D000,C600,I52432,T145121',6,0,'michael-150-dining-package-black-1-table-6-blue-chairs','',0,0,'','','','',1,1,'',''),(67,1,'MICHAEL 7 PIECE 150 DINING SUITE','<p>The combination of glass and solid timber legs gives this dining suite a contemporary look that is perfect for everyday living.&nbsp;</p>\r\n\r\n<p>The Michael Dining Table comes in Grey or&nbsp;Black tempered glass top, and two sizes (150CM or 180CM) that you can choose from that is suitable&nbsp;for&nbsp;your dining room.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material: </strong>Tempered Glass Top, Solid Beech Legs</p>\r\n\r\n<p><strong>Colours Available:&nbsp;</strong>Grey and&nbsp;Black</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Table Dimension: H: 72.8 X W:150 X D:90 CM<br />\r\nChair Dimension: H:87 X W:48 X D:57 CM<br />\r\n<strong>Suite includes:</strong></p>\r\n\r\n<p>1 x Michael 150 Dining Table&nbsp;<br />\r\n6 x Michael Dining Chair</p>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>MICHAEL</b>&nbsp;150 DINING PACKAGE, BLACK 1 TABLE + 6 BLUE CHAIRS','M240,P200,D520,S300','T000,C51535,O100,G420,A530,S430,T516,L200,G120,T200,D520,S300,C53516,I200,P6123,F600,E163,L1525121,M240,T140,C520,I500,G600,O6512142,T5163,T100,S000,C500,O600,Y000,C000,F650,S3145121651216,R51215121,N121,M364,B200,C462,A1414512126,A53512142,D525,H000,W000,D000,C600,I52432,T145121',7,0,'michael-150-dining-package-black-1-table-6-blue-chairs','',0,0,'','','','',1,1,'',''),(67,1,'MICHAEL 7 PIECE 150 DINING SUITE','<p>The combination of glass and solid timber legs gives this dining suite a contemporary look that is perfect for everyday living.&nbsp;</p>\r\n\r\n<p>The Michael Dining Table comes in Grey or&nbsp;Black tempered glass top, and two sizes (150CM or 180CM) that you can choose from that is suitable&nbsp;for&nbsp;your dining room.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material: </strong>Tempered Glass Top, Solid Beech Legs</p>\r\n\r\n<p><strong>Colours Available:&nbsp;</strong>Grey and&nbsp;Black</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Table Dimension: H: 72.8 X W:150 X D:90 CM<br />\r\nChair Dimension: H:87 X W:48 X D:57 CM<br />\r\n<strong>Suite includes:</strong></p>\r\n\r\n<p>1 x Michael 150 Dining Table&nbsp;<br />\r\n6 x Michael Dining Chair</p>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>MICHAEL</b>&nbsp;150 DINING PACKAGE, BLACK 1 TABLE + 6 BLUE CHAIRS','M240,P200,D520,S300','T000,C51535,O100,G420,A530,S430,T516,L200,G120,T200,D520,S300,C53516,I200,P6123,F600,E163,L1525121,M240,T140,C520,I500,G600,O6512142,T5163,T100,S000,C500,O600,Y000,C000,F650,S3145121651216,R51215121,N121,M364,B200,C462,A1414512126,A53512142,D525,H000,W000,D000,C600,I52432,T145121',8,0,'michael-150-dining-package-black-1-table-6-blue-chairs','',0,0,'','','','',1,1,'',''),(67,1,'MICHAEL 7 PIECE 150 DINING SUITE','<p>The combination of glass and solid timber legs gives this dining suite a contemporary look that is perfect for everyday living.&nbsp;</p>\r\n\r\n<p>The Michael Dining Table comes in Grey or&nbsp;Black tempered glass top, and two sizes (150CM or 180CM) that you can choose from that is suitable&nbsp;for&nbsp;your dining room.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material: </strong>Tempered Glass Top, Solid Beech Legs</p>\r\n\r\n<p><strong>Colours Available:&nbsp;</strong>Grey and&nbsp;Black</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Table Dimension: H: 72.8 X W:150 X D:90 CM<br />\r\nChair Dimension: H:87 X W:48 X D:57 CM<br />\r\n<strong>Suite includes:</strong></p>\r\n\r\n<p>1 x Michael 150 Dining Table&nbsp;<br />\r\n6 x Michael Dining Chair</p>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>MICHAEL</b>&nbsp;150 DINING PACKAGE, BLACK 1 TABLE + 6 BLUE CHAIRS','M240,P200,D520,S300','T000,C51535,O100,G420,A530,S430,T516,L200,G120,T200,D520,S300,C53516,I200,P6123,F600,E163,L1525121,M240,T140,C520,I500,G600,O6512142,T5163,T100,S000,C500,O600,Y000,C000,F650,S3145121651216,R51215121,N121,M364,B200,C462,A1414512126,A53512142,D525,H000,W000,D000,C600,I52432,T145121',9,0,'michael-150-dining-package-black-1-table-6-blue-chairs','',0,0,'','','','',1,1,'',''),(67,1,'MICHAEL 7 PIECE 150 DINING SUITE','<p>The combination of glass and solid timber legs gives this dining suite a contemporary look that is perfect for everyday living.&nbsp;</p>\r\n\r\n<p>The Michael Dining Table comes in Grey or&nbsp;Black tempered glass top, and two sizes (150CM or 180CM) that you can choose from that is suitable&nbsp;for&nbsp;your dining room.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material: </strong>Tempered Glass Top, Solid Beech Legs</p>\r\n\r\n<p><strong>Colours Available:&nbsp;</strong>Grey and&nbsp;Black</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<p>Table Dimension: H: 72.8 X W:150 X D:90 CM<br />\r\nChair Dimension: H:87 X W:48 X D:57 CM<br />\r\n<strong>Suite includes:</strong></p>\r\n\r\n<p>1 x Michael 150 Dining Table&nbsp;<br />\r\n6 x Michael Dining Chair</p>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>MICHAEL</b>&nbsp;150 DINING PACKAGE, BLACK 1 TABLE + 6 BLUE CHAIRS','M240,P200,D520,S300','T000,C51535,O100,G420,A530,S430,T516,L200,G120,T200,D520,S300,C53516,I200,P6123,F600,E163,L1525121,M240,T140,C520,I500,G600,O6512142,T5163,T100,S000,C500,O600,Y000,C000,F650,S3145121651216,R51215121,N121,M364,B200,C462,A1414512126,A53512142,D525,H000,W000,D000,C600,I52432,T145121',10,0,'michael-150-dining-package-black-1-table-6-blue-chairs','',0,0,'','','','',1,1,'',''),(68,1,'CASPER 5 PIECE 120 DINING SUITE','<p>Give your home a designer flair with this stylish dining set.&nbsp;&nbsp;The&nbsp;unique design&nbsp;provides a characterful look that will go well&nbsp;in&nbsp;any living and dining room setting.&nbsp;&nbsp;Creating an uplifting new look for your home has never been easier with this beautiful&nbsp;Casper range.&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Solid Rubberwood / MDF /&nbsp; Walnut Veneer</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<ul>\r\n	<li>Table Dimension:&nbsp;H:75 X W:120 X D:120 CM</li>\r\n	<li>Chair Dimension:&nbsp;H:77.5 X W:56.5 X D:63.5 CM</li>\r\n</ul>\r\n\r\n<p><strong>Suite includes:</strong></p>\r\n\r\n<ul>\r\n	<li>1 x Casper 120 Dining Table</li>\r\n	<li>4 x Casper Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>CASPER</b>&nbsp;120 DINING PACKAGE 1 X TABLE + 4 CHAIRS','C160,P200,D520,S300','G100,Y600,H500,D256,F460,W300,T200,S342,D520,S3512151213512152,D251216132,C623614,L200,T000,W400,G000,W4512151215,L152,A530,R500,S3525121512126352,A500,U141352,N000,F600,H200,N160,B500,E260,B3145121216,R525121,N121,M3645121243,R163,M310,W453,V560,D525,T140,D525121,W000,D000,C500,C600,S300,I52432,C160',1,0,'casper-120-dining-package-1-x-table-4-chairs','',0,0,'','','','',1,1,'',''),(68,1,'CASPER 5 PIECE 120 DINING SUITE','<p>Give your home a designer flair with this stylish dining set.&nbsp;&nbsp;The&nbsp;unique design&nbsp;provides a characterful look that will go well&nbsp;in&nbsp;any living and dining room setting.&nbsp;&nbsp;Creating an uplifting new look for your home has never been easier with this beautiful&nbsp;Casper range.&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Solid Rubberwood / MDF /&nbsp; Walnut Veneer</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<ul>\r\n	<li>Table Dimension:&nbsp;H:75 X W:120 X D:120 CM</li>\r\n	<li>Chair Dimension:&nbsp;H:77.5 X W:56.5 X D:63.5 CM</li>\r\n</ul>\r\n\r\n<p><strong>Suite includes:</strong></p>\r\n\r\n<ul>\r\n	<li>1 x Casper 120 Dining Table</li>\r\n	<li>4 x Casper Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>CASPER</b>&nbsp;120 DINING PACKAGE 1 X TABLE + 4 CHAIRS','C160,P200,D520,S300','G100,Y600,H500,D256,F460,W300,T200,S342,D520,S3512151213512152,D251216132,C623614,L200,T000,W400,G000,W4512151215,L152,A530,R500,S3525121512126352,A500,U141352,N000,F600,H200,N160,B500,E260,B3145121216,R525121,N121,M3645121243,R163,M310,W453,V560,D525,T140,D525121,W000,D000,C500,C600,S300,I52432,C160',4,0,'casper-120-dining-package-1-x-table-4-chairs','',0,0,'','','','',1,1,'',''),(68,1,'CASPER 5 PIECE 120 DINING SUITE','<p>Give your home a designer flair with this stylish dining set.&nbsp;&nbsp;The&nbsp;unique design&nbsp;provides a characterful look that will go well&nbsp;in&nbsp;any living and dining room setting.&nbsp;&nbsp;Creating an uplifting new look for your home has never been easier with this beautiful&nbsp;Casper range.&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Solid Rubberwood / MDF /&nbsp; Walnut Veneer</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<ul>\r\n	<li>Table Dimension:&nbsp;H:75 X W:120 X D:120 CM</li>\r\n	<li>Chair Dimension:&nbsp;H:77.5 X W:56.5 X D:63.5 CM</li>\r\n</ul>\r\n\r\n<p><strong>Suite includes:</strong></p>\r\n\r\n<ul>\r\n	<li>1 x Casper 120 Dining Table</li>\r\n	<li>4 x Casper Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>CASPER</b>&nbsp;120 DINING PACKAGE 1 X TABLE + 4 CHAIRS','C160,P200,D520,S300','G100,Y600,H500,D256,F460,W300,T200,S342,D520,S3512151213512152,D251216132,C623614,L200,T000,W400,G000,W4512151215,L152,A530,R500,S3525121512126352,A500,U141352,N000,F600,H200,N160,B500,E260,B3145121216,R525121,N121,M3645121243,R163,M310,W453,V560,D525,T140,D525121,W000,D000,C500,C600,S300,I52432,C160',5,0,'casper-120-dining-package-1-x-table-4-chairs','',0,0,'','','','',1,1,'',''),(68,1,'CASPER 5 PIECE 120 DINING SUITE','<p>Give your home a designer flair with this stylish dining set.&nbsp;&nbsp;The&nbsp;unique design&nbsp;provides a characterful look that will go well&nbsp;in&nbsp;any living and dining room setting.&nbsp;&nbsp;Creating an uplifting new look for your home has never been easier with this beautiful&nbsp;Casper range.&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Solid Rubberwood / MDF /&nbsp; Walnut Veneer</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<ul>\r\n	<li>Table Dimension:&nbsp;H:75 X W:120 X D:120 CM</li>\r\n	<li>Chair Dimension:&nbsp;H:77.5 X W:56.5 X D:63.5 CM</li>\r\n</ul>\r\n\r\n<p><strong>Suite includes:</strong></p>\r\n\r\n<ul>\r\n	<li>1 x Casper 120 Dining Table</li>\r\n	<li>4 x Casper Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>CASPER</b>&nbsp;120 DINING PACKAGE 1 X TABLE + 4 CHAIRS','C160,P200,D520,S300','G100,Y600,H500,D256,F460,W300,T200,S342,D520,S3512151213512152,D251216132,C623614,L200,T000,W400,G000,W4512151215,L152,A530,R500,S3525121512126352,A500,U141352,N000,F600,H200,N160,B500,E260,B3145121216,R525121,N121,M3645121243,R163,M310,W453,V560,D525,T140,D525121,W000,D000,C500,C600,S300,I52432,C160',6,0,'casper-120-dining-package-1-x-table-4-chairs','',0,0,'','','','',1,1,'',''),(68,1,'CASPER 5 PIECE 120 DINING SUITE','<p>Give your home a designer flair with this stylish dining set.&nbsp;&nbsp;The&nbsp;unique design&nbsp;provides a characterful look that will go well&nbsp;in&nbsp;any living and dining room setting.&nbsp;&nbsp;Creating an uplifting new look for your home has never been easier with this beautiful&nbsp;Casper range.&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Solid Rubberwood / MDF /&nbsp; Walnut Veneer</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<ul>\r\n	<li>Table Dimension:&nbsp;H:75 X W:120 X D:120 CM</li>\r\n	<li>Chair Dimension:&nbsp;H:77.5 X W:56.5 X D:63.5 CM</li>\r\n</ul>\r\n\r\n<p><strong>Suite includes:</strong></p>\r\n\r\n<ul>\r\n	<li>1 x Casper 120 Dining Table</li>\r\n	<li>4 x Casper Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>CASPER</b>&nbsp;120 DINING PACKAGE 1 X TABLE + 4 CHAIRS','C160,P200,D520,S300','G100,Y600,H500,D256,F460,W300,T200,S342,D520,S3512151213512152,D251216132,C623614,L200,T000,W400,G000,W4512151215,L152,A530,R500,S3525121512126352,A500,U141352,N000,F600,H200,N160,B500,E260,B3145121216,R525121,N121,M3645121243,R163,M310,W453,V560,D525,T140,D525121,W000,D000,C500,C600,S300,I52432,C160',7,0,'casper-120-dining-package-1-x-table-4-chairs','',0,0,'','','','',1,1,'',''),(68,1,'CASPER 5 PIECE 120 DINING SUITE','<p>Give your home a designer flair with this stylish dining set.&nbsp;&nbsp;The&nbsp;unique design&nbsp;provides a characterful look that will go well&nbsp;in&nbsp;any living and dining room setting.&nbsp;&nbsp;Creating an uplifting new look for your home has never been easier with this beautiful&nbsp;Casper range.&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Solid Rubberwood / MDF /&nbsp; Walnut Veneer</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<ul>\r\n	<li>Table Dimension:&nbsp;H:75 X W:120 X D:120 CM</li>\r\n	<li>Chair Dimension:&nbsp;H:77.5 X W:56.5 X D:63.5 CM</li>\r\n</ul>\r\n\r\n<p><strong>Suite includes:</strong></p>\r\n\r\n<ul>\r\n	<li>1 x Casper 120 Dining Table</li>\r\n	<li>4 x Casper Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>CASPER</b>&nbsp;120 DINING PACKAGE 1 X TABLE + 4 CHAIRS','C160,P200,D520,S300','G100,Y600,H500,D256,F460,W300,T200,S342,D520,S3512151213512152,D251216132,C623614,L200,T000,W400,G000,W4512151215,L152,A530,R500,S3525121512126352,A500,U141352,N000,F600,H200,N160,B500,E260,B3145121216,R525121,N121,M3645121243,R163,M310,W453,V560,D525,T140,D525121,W000,D000,C500,C600,S300,I52432,C160',8,0,'casper-120-dining-package-1-x-table-4-chairs','',0,0,'','','','',1,1,'',''),(68,1,'CASPER 5 PIECE 120 DINING SUITE','<p>Give your home a designer flair with this stylish dining set.&nbsp;&nbsp;The&nbsp;unique design&nbsp;provides a characterful look that will go well&nbsp;in&nbsp;any living and dining room setting.&nbsp;&nbsp;Creating an uplifting new look for your home has never been easier with this beautiful&nbsp;Casper range.&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Solid Rubberwood / MDF /&nbsp; Walnut Veneer</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<ul>\r\n	<li>Table Dimension:&nbsp;H:75 X W:120 X D:120 CM</li>\r\n	<li>Chair Dimension:&nbsp;H:77.5 X W:56.5 X D:63.5 CM</li>\r\n</ul>\r\n\r\n<p><strong>Suite includes:</strong></p>\r\n\r\n<ul>\r\n	<li>1 x Casper 120 Dining Table</li>\r\n	<li>4 x Casper Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>CASPER</b>&nbsp;120 DINING PACKAGE 1 X TABLE + 4 CHAIRS','C160,P200,D520,S300','G100,Y600,H500,D256,F460,W300,T200,S342,D520,S3512151213512152,D251216132,C623614,L200,T000,W400,G000,W4512151215,L152,A530,R500,S3525121512126352,A500,U141352,N000,F600,H200,N160,B500,E260,B3145121216,R525121,N121,M3645121243,R163,M310,W453,V560,D525,T140,D525121,W000,D000,C500,C600,S300,I52432,C160',9,0,'casper-120-dining-package-1-x-table-4-chairs','',0,0,'','','','',1,1,'',''),(68,1,'CASPER 5 PIECE 120 DINING SUITE','<p>Give your home a designer flair with this stylish dining set.&nbsp;&nbsp;The&nbsp;unique design&nbsp;provides a characterful look that will go well&nbsp;in&nbsp;any living and dining room setting.&nbsp;&nbsp;Creating an uplifting new look for your home has never been easier with this beautiful&nbsp;Casper range.&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Solid Rubberwood / MDF /&nbsp; Walnut Veneer</p>\r\n\r\n<p><strong>Dimension:</strong></p>\r\n\r\n<ul>\r\n	<li>Table Dimension:&nbsp;H:75 X W:120 X D:120 CM</li>\r\n	<li>Chair Dimension:&nbsp;H:77.5 X W:56.5 X D:63.5 CM</li>\r\n</ul>\r\n\r\n<p><strong>Suite includes:</strong></p>\r\n\r\n<ul>\r\n	<li>1 x Casper 120 Dining Table</li>\r\n	<li>4 x Casper Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL&nbsp;<b>CASPER</b>&nbsp;120 DINING PACKAGE 1 X TABLE + 4 CHAIRS','C160,P200,D520,S300','G100,Y600,H500,D256,F460,W300,T200,S342,D520,S3512151213512152,D251216132,C623614,L200,T000,W400,G000,W4512151215,L152,A530,R500,S3525121512126352,A500,U141352,N000,F600,H200,N160,B500,E260,B3145121216,R525121,N121,M3645121243,R163,M310,W453,V560,D525,T140,D525121,W000,D000,C500,C600,S300,I52432,C160',10,0,'casper-120-dining-package-1-x-table-4-chairs','',0,0,'','','','',1,1,'',''),(69,1,'JONAS 7 PIECE OUTDOOR DINING SET','A timeless classic, the Jonas 7 Piece Outdoor Dining Set is a flawless little entertainer.\r\n<p>Comprised of 1 x 180 Outdoor Table and&nbsp;6&nbsp;x Outdoor Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Table: H:76&nbsp;X W:180 X D:90 CM</li>\r\n	<li>Outdoor Chair: H:86&nbsp;X W:60 X D:55&nbsp;CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Dining Table</li>\r\n	<li>6 x Jonas Outdoor Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,D520,S300','T542,C420,T000,J520,P200,O360,D520,S300,I200,F420,L340,E536356,C51623,O100,T140,A53512151212,C6251213,S352,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,C500,F600,M250,C516351215121,Y600,W653,A530,R300,A2514,N121,M36451212,D525,H51212,W000,D000,C600,D512125,I52432',1,0,'jonas180package','',0,0,'','','','',1,1,'',''),(69,1,'JONAS 7 PIECE OUTDOOR DINING SET','A timeless classic, the Jonas 7 Piece Outdoor Dining Set is a flawless little entertainer.\r\n<p>Comprised of 1 x 180 Outdoor Table and&nbsp;6&nbsp;x Outdoor Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Table: H:76&nbsp;X W:180 X D:90 CM</li>\r\n	<li>Outdoor Chair: H:86&nbsp;X W:60 X D:55&nbsp;CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Dining Table</li>\r\n	<li>6 x Jonas Outdoor Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,D520,S300','T542,C420,T000,J520,P200,O360,D520,S300,I200,F420,L340,E536356,C51623,O100,T140,A53512151212,C6251213,S352,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,C500,F600,M250,C516351215121,Y600,W653,A530,R300,A2514,N121,M36451212,D525,H51212,W000,D000,C600,D512125,I52432',4,0,'jonas180package','',0,0,'','','','',1,1,'',''),(69,1,'JONAS 7 PIECE OUTDOOR DINING SET','A timeless classic, the Jonas 7 Piece Outdoor Dining Set is a flawless little entertainer.\r\n<p>Comprised of 1 x 180 Outdoor Table and&nbsp;6&nbsp;x Outdoor Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Table: H:76&nbsp;X W:180 X D:90 CM</li>\r\n	<li>Outdoor Chair: H:86&nbsp;X W:60 X D:55&nbsp;CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Dining Table</li>\r\n	<li>6 x Jonas Outdoor Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,D520,S300','T542,C420,T000,J520,P200,O360,D520,S300,I200,F420,L340,E536356,C51623,O100,T140,A53512151212,C6251213,S352,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,C500,F600,M250,C516351215121,Y600,W653,A530,R300,A2514,N121,M36451212,D525,H51212,W000,D000,C600,D512125,I52432',5,0,'jonas180package','',0,0,'','','','',1,1,'',''),(69,1,'JONAS 7 PIECE OUTDOOR DINING SET','A timeless classic, the Jonas 7 Piece Outdoor Dining Set is a flawless little entertainer.\r\n<p>Comprised of 1 x 180 Outdoor Table and&nbsp;6&nbsp;x Outdoor Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Table: H:76&nbsp;X W:180 X D:90 CM</li>\r\n	<li>Outdoor Chair: H:86&nbsp;X W:60 X D:55&nbsp;CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Dining Table</li>\r\n	<li>6 x Jonas Outdoor Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,D520,S300','T542,C420,T000,J520,P200,O360,D520,S300,I200,F420,L340,E536356,C51623,O100,T140,A53512151212,C6251213,S352,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,C500,F600,M250,C516351215121,Y600,W653,A530,R300,A2514,N121,M36451212,D525,H51212,W000,D000,C600,D512125,I52432',6,0,'jonas180package','',0,0,'','','','',1,1,'',''),(69,1,'JONAS 7 PIECE OUTDOOR DINING SET','A timeless classic, the Jonas 7 Piece Outdoor Dining Set is a flawless little entertainer.\r\n<p>Comprised of 1 x 180 Outdoor Table and&nbsp;6&nbsp;x Outdoor Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Table: H:76&nbsp;X W:180 X D:90 CM</li>\r\n	<li>Outdoor Chair: H:86&nbsp;X W:60 X D:55&nbsp;CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Dining Table</li>\r\n	<li>6 x Jonas Outdoor Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,D520,S300','T542,C420,T000,J520,P200,O360,D520,S300,I200,F420,L340,E536356,C51623,O100,T140,A53512151212,C6251213,S352,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,C500,F600,M250,C516351215121,Y600,W653,A530,R300,A2514,N121,M36451212,D525,H51212,W000,D000,C600,D512125,I52432',7,0,'jonas180package','',0,0,'','','','',1,1,'',''),(69,1,'JONAS 7 PIECE OUTDOOR DINING SET','A timeless classic, the Jonas 7 Piece Outdoor Dining Set is a flawless little entertainer.\r\n<p>Comprised of 1 x 180 Outdoor Table and&nbsp;6&nbsp;x Outdoor Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Table: H:76&nbsp;X W:180 X D:90 CM</li>\r\n	<li>Outdoor Chair: H:86&nbsp;X W:60 X D:55&nbsp;CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Dining Table</li>\r\n	<li>6 x Jonas Outdoor Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,D520,S300','T542,C420,T000,J520,P200,O360,D520,S300,I200,F420,L340,E536356,C51623,O100,T140,A53512151212,C6251213,S352,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,C500,F600,M250,C516351215121,Y600,W653,A530,R300,A2514,N121,M36451212,D525,H51212,W000,D000,C600,D512125,I52432',8,0,'jonas180package','',0,0,'','','','',1,1,'',''),(69,1,'JONAS 7 PIECE OUTDOOR DINING SET','A timeless classic, the Jonas 7 Piece Outdoor Dining Set is a flawless little entertainer.\r\n<p>Comprised of 1 x 180 Outdoor Table and&nbsp;6&nbsp;x Outdoor Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Table: H:76&nbsp;X W:180 X D:90 CM</li>\r\n	<li>Outdoor Chair: H:86&nbsp;X W:60 X D:55&nbsp;CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Dining Table</li>\r\n	<li>6 x Jonas Outdoor Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,D520,S300','T542,C420,T000,J520,P200,O360,D520,S300,I200,F420,L340,E536356,C51623,O100,T140,A53512151212,C6251213,S352,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,C500,F600,M250,C516351215121,Y600,W653,A530,R300,A2514,N121,M36451212,D525,H51212,W000,D000,C600,D512125,I52432',9,0,'jonas180package','',0,0,'','','','',1,1,'',''),(69,1,'JONAS 7 PIECE OUTDOOR DINING SET','A timeless classic, the Jonas 7 Piece Outdoor Dining Set is a flawless little entertainer.\r\n<p>Comprised of 1 x 180 Outdoor Table and&nbsp;6&nbsp;x Outdoor Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Table: H:76&nbsp;X W:180 X D:90 CM</li>\r\n	<li>Outdoor Chair: H:86&nbsp;X W:60 X D:55&nbsp;CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Dining Table</li>\r\n	<li>6 x Jonas Outdoor Dining Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,D520,S300','T542,C420,T000,J520,P200,O360,D520,S300,I200,F420,L340,E536356,C51623,O100,T140,A53512151212,C6251213,S352,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,C500,F600,M250,C516351215121,Y600,W653,A530,R300,A2514,N121,M36451212,D525,H51212,W000,D000,C600,D512125,I52432',10,0,'jonas180package','',0,0,'','','','',1,1,'',''),(70,1,'JONAS 5 PIECE OUTDOOR BAR SETTING','A timeless classic, the Jonas 5 Piece Outdoor Bar Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 120 Outdoor Bar Table and 4&nbsp;x Outdoor Bar Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Bar Table: H:90 X W:120 X D:60 CM</li>\r\n	<li>Outdoor Bar Chair: H:65 X W:42 X D:38 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Bar Table</li>\r\n	<li>4 x Jonas Outdoor Bar Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,B600,S352','T542,C420,T000,J520,P200,O360,B600,S352,I200,F420,L340,E536356,C51623,O100,T140,A530,N1212,C6251213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W000,D000,C600,I52432',1,0,'jonasbarpackage','',0,0,'','','','',1,1,'',''),(70,1,'JONAS 5 PIECE OUTDOOR BAR SETTING','A timeless classic, the Jonas 5 Piece Outdoor Bar Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 120 Outdoor Bar Table and 4&nbsp;x Outdoor Bar Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Bar Table: H:90 X W:120 X D:60 CM</li>\r\n	<li>Outdoor Bar Chair: H:65 X W:42 X D:38 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Bar Table</li>\r\n	<li>4 x Jonas Outdoor Bar Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,B600,S352','T542,C420,T000,J520,P200,O360,B600,S352,I200,F420,L340,E536356,C51623,O100,T140,A530,N1212,C6251213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W000,D000,C600,I52432',4,0,'jonasbarpackage','',0,0,'','','','',1,1,'',''),(70,1,'JONAS 5 PIECE OUTDOOR BAR SETTING','A timeless classic, the Jonas 5 Piece Outdoor Bar Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 120 Outdoor Bar Table and 4&nbsp;x Outdoor Bar Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Bar Table: H:90 X W:120 X D:60 CM</li>\r\n	<li>Outdoor Bar Chair: H:65 X W:42 X D:38 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Bar Table</li>\r\n	<li>4 x Jonas Outdoor Bar Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,B600,S352','T542,C420,T000,J520,P200,O360,B600,S352,I200,F420,L340,E536356,C51623,O100,T140,A530,N1212,C6251213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W000,D000,C600,I52432',5,0,'jonasbarpackage','',0,0,'','','','',1,1,'',''),(70,1,'JONAS 5 PIECE OUTDOOR BAR SETTING','A timeless classic, the Jonas 5 Piece Outdoor Bar Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 120 Outdoor Bar Table and 4&nbsp;x Outdoor Bar Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Bar Table: H:90 X W:120 X D:60 CM</li>\r\n	<li>Outdoor Bar Chair: H:65 X W:42 X D:38 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Bar Table</li>\r\n	<li>4 x Jonas Outdoor Bar Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,B600,S352','T542,C420,T000,J520,P200,O360,B600,S352,I200,F420,L340,E536356,C51623,O100,T140,A530,N1212,C6251213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W000,D000,C600,I52432',6,0,'jonasbarpackage','',0,0,'','','','',1,1,'',''),(70,1,'JONAS 5 PIECE OUTDOOR BAR SETTING','A timeless classic, the Jonas 5 Piece Outdoor Bar Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 120 Outdoor Bar Table and 4&nbsp;x Outdoor Bar Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Bar Table: H:90 X W:120 X D:60 CM</li>\r\n	<li>Outdoor Bar Chair: H:65 X W:42 X D:38 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Bar Table</li>\r\n	<li>4 x Jonas Outdoor Bar Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,B600,S352','T542,C420,T000,J520,P200,O360,B600,S352,I200,F420,L340,E536356,C51623,O100,T140,A530,N1212,C6251213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W000,D000,C600,I52432',7,0,'jonasbarpackage','',0,0,'','','','',1,1,'',''),(70,1,'JONAS 5 PIECE OUTDOOR BAR SETTING','A timeless classic, the Jonas 5 Piece Outdoor Bar Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 120 Outdoor Bar Table and 4&nbsp;x Outdoor Bar Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Bar Table: H:90 X W:120 X D:60 CM</li>\r\n	<li>Outdoor Bar Chair: H:65 X W:42 X D:38 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Bar Table</li>\r\n	<li>4 x Jonas Outdoor Bar Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,B600,S352','T542,C420,T000,J520,P200,O360,B600,S352,I200,F420,L340,E536356,C51623,O100,T140,A530,N1212,C6251213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W000,D000,C600,I52432',8,0,'jonasbarpackage','',0,0,'','','','',1,1,'',''),(70,1,'JONAS 5 PIECE OUTDOOR BAR SETTING','A timeless classic, the Jonas 5 Piece Outdoor Bar Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 120 Outdoor Bar Table and 4&nbsp;x Outdoor Bar Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Bar Table: H:90 X W:120 X D:60 CM</li>\r\n	<li>Outdoor Bar Chair: H:65 X W:42 X D:38 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Bar Table</li>\r\n	<li>4 x Jonas Outdoor Bar Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,B600,S352','T542,C420,T000,J520,P200,O360,B600,S352,I200,F420,L340,E536356,C51623,O100,T140,A530,N1212,C6251213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W000,D000,C600,I52432',9,0,'jonasbarpackage','',0,0,'','','','',1,1,'',''),(70,1,'JONAS 5 PIECE OUTDOOR BAR SETTING','A timeless classic, the Jonas 5 Piece Outdoor Bar Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 120 Outdoor Bar Table and 4&nbsp;x Outdoor Bar Chairs,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor Bar Table: H:90 X W:120 X D:60 CM</li>\r\n	<li>Outdoor Bar Chair: H:65 X W:42 X D:38 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor Bar Table</li>\r\n	<li>4 x Jonas Outdoor Bar Chair</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,B600,S352','T542,C420,T000,J520,P200,O360,B600,S352,I200,F420,L340,E536356,C51623,O100,T140,A530,N1212,C6251213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W000,D000,C600,I52432',10,0,'jonasbarpackage','',0,0,'','','','',1,1,'',''),(71,1,'JONAS JACK AND JILL OUTDOOR SETTING','A timeless classic, the Jonas Jack and Jill Setting is a flawless little entertainer.\r\n<p>Comprised of 2 armchairs joined by a tray table,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and&nbsp;ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u>&nbsp;H:86 X W:154 X D:56 CM</p>\r\n','',0,'','','','','BEST DEAL','J520,J000,A530,J400,O360,S352','T542,C420,T000,J520,J000,A530,J400,S352,I200,F420,L340,E536356,C51623,O100,A65262,J530,B000,T600,T1451213,O360,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,A53512163,A2514,N121,M36451212,D525121,W000,D000',1,0,'huc25806','',0,0,'','','','',1,1,'',''),(71,1,'JONAS JACK AND JILL OUTDOOR SETTING','A timeless classic, the Jonas Jack and Jill Setting is a flawless little entertainer.\r\n<p>Comprised of 2 armchairs joined by a tray table,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and&nbsp;ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u>&nbsp;H:86 X W:154 X D:56 CM</p>\r\n','',0,'','','','','BEST DEAL','J520,J000,A530,J400,O360,S352','T542,C420,T000,J520,J000,A530,J400,S352,I200,F420,L340,E536356,C51623,O100,A65262,J530,B000,T600,T1451213,O360,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,A53512163,A2514,N121,M36451212,D525121,W000,D000',4,0,'huc25806','',0,0,'','','','',1,1,'',''),(71,1,'JONAS JACK AND JILL OUTDOOR SETTING','A timeless classic, the Jonas Jack and Jill Setting is a flawless little entertainer.\r\n<p>Comprised of 2 armchairs joined by a tray table,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and&nbsp;ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u>&nbsp;H:86 X W:154 X D:56 CM</p>\r\n','',0,'','','','','BEST DEAL','J520,J000,A530,J400,O360,S352','T542,C420,T000,J520,J000,A530,J400,S352,I200,F420,L340,E536356,C51623,O100,A65262,J530,B000,T600,T1451213,O360,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,A53512163,A2514,N121,M36451212,D525121,W000,D000',5,0,'huc25806','',0,0,'','','','',1,1,'',''),(71,1,'JONAS JACK AND JILL OUTDOOR SETTING','A timeless classic, the Jonas Jack and Jill Setting is a flawless little entertainer.\r\n<p>Comprised of 2 armchairs joined by a tray table,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and&nbsp;ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u>&nbsp;H:86 X W:154 X D:56 CM</p>\r\n','',0,'','','','','BEST DEAL','J520,J000,A530,J400,O360,S352','T542,C420,T000,J520,J000,A530,J400,S352,I200,F420,L340,E536356,C51623,O100,A65262,J530,B000,T600,T1451213,O360,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,A53512163,A2514,N121,M36451212,D525121,W000,D000',6,0,'huc25806','',0,0,'','','','',1,1,'',''),(71,1,'JONAS JACK AND JILL OUTDOOR SETTING','A timeless classic, the Jonas Jack and Jill Setting is a flawless little entertainer.\r\n<p>Comprised of 2 armchairs joined by a tray table,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and&nbsp;ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u>&nbsp;H:86 X W:154 X D:56 CM</p>\r\n','',0,'','','','','BEST DEAL','J520,J000,A530,J400,O360,S352','T542,C420,T000,J520,J000,A530,J400,S352,I200,F420,L340,E536356,C51623,O100,A65262,J530,B000,T600,T1451213,O360,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,A53512163,A2514,N121,M36451212,D525121,W000,D000',7,0,'huc25806','',0,0,'','','','',1,1,'',''),(71,1,'JONAS JACK AND JILL OUTDOOR SETTING','A timeless classic, the Jonas Jack and Jill Setting is a flawless little entertainer.\r\n<p>Comprised of 2 armchairs joined by a tray table,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and&nbsp;ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u>&nbsp;H:86 X W:154 X D:56 CM</p>\r\n','',0,'','','','','BEST DEAL','J520,J000,A530,J400,O360,S352','T542,C420,T000,J520,J000,A530,J400,S352,I200,F420,L340,E536356,C51623,O100,A65262,J530,B000,T600,T1451213,O360,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,A53512163,A2514,N121,M36451212,D525121,W000,D000',8,0,'huc25806','',0,0,'','','','',1,1,'',''),(71,1,'JONAS JACK AND JILL OUTDOOR SETTING','A timeless classic, the Jonas Jack and Jill Setting is a flawless little entertainer.\r\n<p>Comprised of 2 armchairs joined by a tray table,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and&nbsp;ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u>&nbsp;H:86 X W:154 X D:56 CM</p>\r\n','',0,'','','','','BEST DEAL','J520,J000,A530,J400,O360,S352','T542,C420,T000,J520,J000,A530,J400,S352,I200,F420,L340,E536356,C51623,O100,A65262,J530,B000,T600,T1451213,O360,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,A53512163,A2514,N121,M36451212,D525121,W000,D000',9,0,'huc25806','',0,0,'','','','',1,1,'',''),(71,1,'JONAS JACK AND JILL OUTDOOR SETTING','A timeless classic, the Jonas Jack and Jill Setting is a flawless little entertainer.\r\n<p>Comprised of 2 armchairs joined by a tray table,&nbsp;the Jonas Outdoor Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and&nbsp;ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u>&nbsp;H:86 X W:154 X D:56 CM</p>\r\n','',0,'','','','','BEST DEAL','J520,J000,A530,J400,O360,S352','T542,C420,T000,J520,J000,A530,J400,S352,I200,F420,L340,E536356,C51623,O100,A65262,J530,B000,T600,T1451213,O360,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,A53512163,A2514,N121,M36451212,D525121,W000,D000',10,0,'huc25806','',0,0,'','','','',1,1,'',''),(72,1,'JONAS 4 PIECE OUTDOOR LOUNGE SETTING','A timeless classic, the Jonas 4 Piece Outdoor Lounge Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 2 Seater, 2&nbsp;x Single Armchairs and 1 x Coffee Table,&nbsp;the Jonas Outdoor Lounge Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor 2 Seater: H:80 X W:151&nbsp;X D:81&nbsp;CM</li>\r\n	<li>Outdoor Armchair: H:80 X W:76&nbsp;X D:81 CM</li>\r\n	<li>Outdoor Coffee Table: H:50 X W:110 X D:60 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor 2 Seater</li>\r\n	<li>2 x Jonas Outdoor Armchair</li>\r\n	<li>1 x Jonas Outdoor Coffee Table</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,L520,S352','T542,C420,T000,J520,P200,O360,L520,S352,I200,F420,L340,E536356,C51623,O100,S360,N1212,S524,A65262,A530,C100,T1451213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W51212,D512125,A6526,D000,T140,W000,I52432',1,0,'jonaslounge','',0,0,'','','','',1,1,'',''),(72,1,'JONAS 4 PIECE OUTDOOR LOUNGE SETTING','A timeless classic, the Jonas 4 Piece Outdoor Lounge Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 2 Seater, 2&nbsp;x Single Armchairs and 1 x Coffee Table,&nbsp;the Jonas Outdoor Lounge Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor 2 Seater: H:80 X W:151&nbsp;X D:81&nbsp;CM</li>\r\n	<li>Outdoor Armchair: H:80 X W:76&nbsp;X D:81 CM</li>\r\n	<li>Outdoor Coffee Table: H:50 X W:110 X D:60 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor 2 Seater</li>\r\n	<li>2 x Jonas Outdoor Armchair</li>\r\n	<li>1 x Jonas Outdoor Coffee Table</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,L520,S352','T542,C420,T000,J520,P200,O360,L520,S352,I200,F420,L340,E536356,C51623,O100,S360,N1212,S524,A65262,A530,C100,T1451213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W51212,D512125,A6526,D000,T140,W000,I52432',4,0,'jonaslounge','',0,0,'','','','',1,1,'',''),(72,1,'JONAS 4 PIECE OUTDOOR LOUNGE SETTING','A timeless classic, the Jonas 4 Piece Outdoor Lounge Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 2 Seater, 2&nbsp;x Single Armchairs and 1 x Coffee Table,&nbsp;the Jonas Outdoor Lounge Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor 2 Seater: H:80 X W:151&nbsp;X D:81&nbsp;CM</li>\r\n	<li>Outdoor Armchair: H:80 X W:76&nbsp;X D:81 CM</li>\r\n	<li>Outdoor Coffee Table: H:50 X W:110 X D:60 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor 2 Seater</li>\r\n	<li>2 x Jonas Outdoor Armchair</li>\r\n	<li>1 x Jonas Outdoor Coffee Table</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,L520,S352','T542,C420,T000,J520,P200,O360,L520,S352,I200,F420,L340,E536356,C51623,O100,S360,N1212,S524,A65262,A530,C100,T1451213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W51212,D512125,A6526,D000,T140,W000,I52432',5,0,'jonaslounge','',0,0,'','','','',1,1,'',''),(72,1,'JONAS 4 PIECE OUTDOOR LOUNGE SETTING','A timeless classic, the Jonas 4 Piece Outdoor Lounge Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 2 Seater, 2&nbsp;x Single Armchairs and 1 x Coffee Table,&nbsp;the Jonas Outdoor Lounge Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor 2 Seater: H:80 X W:151&nbsp;X D:81&nbsp;CM</li>\r\n	<li>Outdoor Armchair: H:80 X W:76&nbsp;X D:81 CM</li>\r\n	<li>Outdoor Coffee Table: H:50 X W:110 X D:60 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor 2 Seater</li>\r\n	<li>2 x Jonas Outdoor Armchair</li>\r\n	<li>1 x Jonas Outdoor Coffee Table</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,L520,S352','T542,C420,T000,J520,P200,O360,L520,S352,I200,F420,L340,E536356,C51623,O100,S360,N1212,S524,A65262,A530,C100,T1451213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W51212,D512125,A6526,D000,T140,W000,I52432',6,0,'jonaslounge','',0,0,'','','','',1,1,'',''),(72,1,'JONAS 4 PIECE OUTDOOR LOUNGE SETTING','A timeless classic, the Jonas 4 Piece Outdoor Lounge Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 2 Seater, 2&nbsp;x Single Armchairs and 1 x Coffee Table,&nbsp;the Jonas Outdoor Lounge Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor 2 Seater: H:80 X W:151&nbsp;X D:81&nbsp;CM</li>\r\n	<li>Outdoor Armchair: H:80 X W:76&nbsp;X D:81 CM</li>\r\n	<li>Outdoor Coffee Table: H:50 X W:110 X D:60 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor 2 Seater</li>\r\n	<li>2 x Jonas Outdoor Armchair</li>\r\n	<li>1 x Jonas Outdoor Coffee Table</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,L520,S352','T542,C420,T000,J520,P200,O360,L520,S352,I200,F420,L340,E536356,C51623,O100,S360,N1212,S524,A65262,A530,C100,T1451213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W51212,D512125,A6526,D000,T140,W000,I52432',7,0,'jonaslounge','',0,0,'','','','',1,1,'',''),(72,1,'JONAS 4 PIECE OUTDOOR LOUNGE SETTING','A timeless classic, the Jonas 4 Piece Outdoor Lounge Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 2 Seater, 2&nbsp;x Single Armchairs and 1 x Coffee Table,&nbsp;the Jonas Outdoor Lounge Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor 2 Seater: H:80 X W:151&nbsp;X D:81&nbsp;CM</li>\r\n	<li>Outdoor Armchair: H:80 X W:76&nbsp;X D:81 CM</li>\r\n	<li>Outdoor Coffee Table: H:50 X W:110 X D:60 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor 2 Seater</li>\r\n	<li>2 x Jonas Outdoor Armchair</li>\r\n	<li>1 x Jonas Outdoor Coffee Table</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,L520,S352','T542,C420,T000,J520,P200,O360,L520,S352,I200,F420,L340,E536356,C51623,O100,S360,N1212,S524,A65262,A530,C100,T1451213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W51212,D512125,A6526,D000,T140,W000,I52432',8,0,'jonaslounge','',0,0,'','','','',1,1,'',''),(72,1,'JONAS 4 PIECE OUTDOOR LOUNGE SETTING','A timeless classic, the Jonas 4 Piece Outdoor Lounge Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 2 Seater, 2&nbsp;x Single Armchairs and 1 x Coffee Table,&nbsp;the Jonas Outdoor Lounge Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor 2 Seater: H:80 X W:151&nbsp;X D:81&nbsp;CM</li>\r\n	<li>Outdoor Armchair: H:80 X W:76&nbsp;X D:81 CM</li>\r\n	<li>Outdoor Coffee Table: H:50 X W:110 X D:60 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor 2 Seater</li>\r\n	<li>2 x Jonas Outdoor Armchair</li>\r\n	<li>1 x Jonas Outdoor Coffee Table</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,L520,S352','T542,C420,T000,J520,P200,O360,L520,S352,I200,F420,L340,E536356,C51623,O100,S360,N1212,S524,A65262,A530,C100,T1451213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W51212,D512125,A6526,D000,T140,W000,I52432',9,0,'jonaslounge','',0,0,'','','','',1,1,'',''),(72,1,'JONAS 4 PIECE OUTDOOR LOUNGE SETTING','A timeless classic, the Jonas 4 Piece Outdoor Lounge Setting is a flawless little entertainer.\r\n<p>Comprised of 1 x 2 Seater, 2&nbsp;x Single Armchairs and 1 x Coffee Table,&nbsp;the Jonas Outdoor Lounge Setting has a solid wooden frame, constructed using FSC certified Eucalyptus hardwood&nbsp;and comes with water resistance seat cushion for maximum comfort.&nbsp;&nbsp;</p>\r\n\r\n<p>Comes with 1 year warranty and ready to assemble.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><u><strong>Material:</strong></u>&nbsp;FSC Certified Eucalyptus</p>\r\n\r\n<p><u><strong>Dimension:</strong></u></p>\r\n\r\n<ul>\r\n	<li>Outdoor 2 Seater: H:80 X W:151&nbsp;X D:81&nbsp;CM</li>\r\n	<li>Outdoor Armchair: H:80 X W:76&nbsp;X D:81 CM</li>\r\n	<li>Outdoor Coffee Table: H:50 X W:110 X D:60 CM</li>\r\n</ul>\r\n\r\n<p><u><strong>Suite includes:</strong></u></p>\r\n\r\n<ul>\r\n	<li>1 x Jonas Outdoor 2 Seater</li>\r\n	<li>2 x Jonas Outdoor Armchair</li>\r\n	<li>1 x Jonas Outdoor Coffee Table</li>\r\n</ul>\r\n','',0,'','','','','BEST DEAL','J520,P200,O360,L520,S352','T542,C420,T000,J520,P200,O360,L520,S352,I200,F420,L340,E536356,C51623,O100,S360,N1212,S524,A65262,A530,C100,T1451213,H200,S430,W350,F650,C523623,U252,F200,C6313,E24132,H63512153,C520,W300,W360,R2352,S300,C500,F600,M250,C516351215121,Y600,W653,R300,A2514,N121,M36451212,D525,H000,W51212,D512125,A6526,D000,T140,W000,I52432',10,0,'jonaslounge','',0,0,'','','','',1,1,'',''),(73,1,'ERIN TRUNDLE BED WITH POCKET SPRING MATTRESSES','<p>Add versatility and convenience to your bedroom, or guest room, with the Erin trundle bed. The underbed rolls out easily with spacious underbed drawers for convenient storage.<br />\r\nConsisting of one king single bed and matching single trundle bed with mattresses, the Erin will help you get the most out of your bedroom&#39;s space, coming in handy for kids sleepovers, or unexpected visits from guests. It&#39;s a great way to maintain a neat bedroom space.</p>\r\n\r\n<p>You can also upgrade the mattresses from Erin Mattresses to Cozy Sleep Mattresses and Ultra Sleep Mattresses based on your requirements.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Fabric, Wooden Frame</p>\r\n\r\n<p><strong>Dimension:</strong> H:61 X W:107 X D:203 CM</p>\r\n','',0,'','','','','BEST DEAL','E650,T6534,B300,W300,P230,S1652,M362','A300,V62343,A530,C5152,T000,Y600,B365,O600,G300,R500,W300,E650,T6534,B300,U53613,R420,O300,E240,S120,D620,F600,C5153,S362,C52352,O100,O500,K520,S524,M3252,M362,W400,H410,Y000,M230,B3652,C520,I500,H530,K320,S4162,U52123,V232,F650,G320,I320,G630,W000,M350,N300,C500,A420,U1263,C000,S410,U436,B230,R2653251215121,N121,M364,F620,W350,D525,H000,D000',1,0,'erin-trundle-bed-with-mattresses','',0,0,'','','','',1,1,'',''),(73,1,'ERIN TRUNDLE BED WITH POCKET SPRING MATTRESSES','<p>Add versatility and convenience to your bedroom, or guest room, with the Erin trundle bed. The underbed rolls out easily with spacious underbed drawers for convenient storage.<br />\r\nConsisting of one king single bed and matching single trundle bed with mattresses, the Erin will help you get the most out of your bedroom&#39;s space, coming in handy for kids sleepovers, or unexpected visits from guests. It&#39;s a great way to maintain a neat bedroom space.</p>\r\n\r\n<p>You can also upgrade the mattresses from Erin Mattresses to Cozy Sleep Mattresses and Ultra Sleep Mattresses based on your requirements.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Fabric, Wooden Frame</p>\r\n\r\n<p><strong>Dimension:</strong> H:61 X W:107 X D:203 CM</p>\r\n','',0,'','','','','BEST DEAL','E650,T6534,B300,W300,P230,S1652,M362','A300,V62343,A530,C5152,T000,Y600,B365,O600,G300,R500,W300,E650,T6534,B300,U53613,R420,O300,E240,S120,D620,F600,C5153,S362,C52352,O100,O500,K520,S524,M3252,M362,W400,H410,Y000,M230,B3652,C520,I500,H530,K320,S4162,U52123,V232,F650,G320,I320,G630,W000,M350,N300,C500,A420,U1263,C000,S410,U436,B230,R2653251215121,N121,M364,F620,W350,D525,H000,D000',4,0,'erin-trundle-bed-with-mattresses','',0,0,'','','','',1,1,'',''),(73,1,'ERIN TRUNDLE BED WITH POCKET SPRING MATTRESSES','<p>Add versatility and convenience to your bedroom, or guest room, with the Erin trundle bed. The underbed rolls out easily with spacious underbed drawers for convenient storage.<br />\r\nConsisting of one king single bed and matching single trundle bed with mattresses, the Erin will help you get the most out of your bedroom&#39;s space, coming in handy for kids sleepovers, or unexpected visits from guests. It&#39;s a great way to maintain a neat bedroom space.</p>\r\n\r\n<p>You can also upgrade the mattresses from Erin Mattresses to Cozy Sleep Mattresses and Ultra Sleep Mattresses based on your requirements.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Fabric, Wooden Frame</p>\r\n\r\n<p><strong>Dimension:</strong> H:61 X W:107 X D:203 CM</p>\r\n','',0,'','','','','BEST DEAL','E650,T6534,B300,W300,P230,S1652,M362','A300,V62343,A530,C5152,T000,Y600,B365,O600,G300,R500,W300,E650,T6534,B300,U53613,R420,O300,E240,S120,D620,F600,C5153,S362,C52352,O100,O500,K520,S524,M3252,M362,W400,H410,Y000,M230,B3652,C520,I500,H530,K320,S4162,U52123,V232,F650,G320,I320,G630,W000,M350,N300,C500,A420,U1263,C000,S410,U436,B230,R2653251215121,N121,M364,F620,W350,D525,H000,D000',5,0,'erin-trundle-bed-with-mattresses','',0,0,'','','','',1,1,'',''),(73,1,'ERIN TRUNDLE BED WITH POCKET SPRING MATTRESSES','<p>Add versatility and convenience to your bedroom, or guest room, with the Erin trundle bed. The underbed rolls out easily with spacious underbed drawers for convenient storage.<br />\r\nConsisting of one king single bed and matching single trundle bed with mattresses, the Erin will help you get the most out of your bedroom&#39;s space, coming in handy for kids sleepovers, or unexpected visits from guests. It&#39;s a great way to maintain a neat bedroom space.</p>\r\n\r\n<p>You can also upgrade the mattresses from Erin Mattresses to Cozy Sleep Mattresses and Ultra Sleep Mattresses based on your requirements.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Fabric, Wooden Frame</p>\r\n\r\n<p><strong>Dimension:</strong> H:61 X W:107 X D:203 CM</p>\r\n','',0,'','','','','BEST DEAL','E650,T6534,B300,W300,P230,S1652,M362','A300,V62343,A530,C5152,T000,Y600,B365,O600,G300,R500,W300,E650,T6534,B300,U53613,R420,O300,E240,S120,D620,F600,C5153,S362,C52352,O100,O500,K520,S524,M3252,M362,W400,H410,Y000,M230,B3652,C520,I500,H530,K320,S4162,U52123,V232,F650,G320,I320,G630,W000,M350,N300,C500,A420,U1263,C000,S410,U436,B230,R2653251215121,N121,M364,F620,W350,D525,H000,D000',6,0,'erin-trundle-bed-with-mattresses','',0,0,'','','','',1,1,'',''),(73,1,'ERIN TRUNDLE BED WITH POCKET SPRING MATTRESSES','<p>Add versatility and convenience to your bedroom, or guest room, with the Erin trundle bed. The underbed rolls out easily with spacious underbed drawers for convenient storage.<br />\r\nConsisting of one king single bed and matching single trundle bed with mattresses, the Erin will help you get the most out of your bedroom&#39;s space, coming in handy for kids sleepovers, or unexpected visits from guests. It&#39;s a great way to maintain a neat bedroom space.</p>\r\n\r\n<p>You can also upgrade the mattresses from Erin Mattresses to Cozy Sleep Mattresses and Ultra Sleep Mattresses based on your requirements.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Fabric, Wooden Frame</p>\r\n\r\n<p><strong>Dimension:</strong> H:61 X W:107 X D:203 CM</p>\r\n','',0,'','','','','BEST DEAL','E650,T6534,B300,W300,P230,S1652,M362','A300,V62343,A530,C5152,T000,Y600,B365,O600,G300,R500,W300,E650,T6534,B300,U53613,R420,O300,E240,S120,D620,F600,C5153,S362,C52352,O100,O500,K520,S524,M3252,M362,W400,H410,Y000,M230,B3652,C520,I500,H530,K320,S4162,U52123,V232,F650,G320,I320,G630,W000,M350,N300,C500,A420,U1263,C000,S410,U436,B230,R2653251215121,N121,M364,F620,W350,D525,H000,D000',7,0,'erin-trundle-bed-with-mattresses','',0,0,'','','','',1,1,'',''),(73,1,'ERIN TRUNDLE BED WITH POCKET SPRING MATTRESSES','<p>Add versatility and convenience to your bedroom, or guest room, with the Erin trundle bed. The underbed rolls out easily with spacious underbed drawers for convenient storage.<br />\r\nConsisting of one king single bed and matching single trundle bed with mattresses, the Erin will help you get the most out of your bedroom&#39;s space, coming in handy for kids sleepovers, or unexpected visits from guests. It&#39;s a great way to maintain a neat bedroom space.</p>\r\n\r\n<p>You can also upgrade the mattresses from Erin Mattresses to Cozy Sleep Mattresses and Ultra Sleep Mattresses based on your requirements.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Fabric, Wooden Frame</p>\r\n\r\n<p><strong>Dimension:</strong> H:61 X W:107 X D:203 CM</p>\r\n','',0,'','','','','BEST DEAL','E650,T6534,B300,W300,P230,S1652,M362','A300,V62343,A530,C5152,T000,Y600,B365,O600,G300,R500,W300,E650,T6534,B300,U53613,R420,O300,E240,S120,D620,F600,C5153,S362,C52352,O100,O500,K520,S524,M3252,M362,W400,H410,Y000,M230,B3652,C520,I500,H530,K320,S4162,U52123,V232,F650,G320,I320,G630,W000,M350,N300,C500,A420,U1263,C000,S410,U436,B230,R2653251215121,N121,M364,F620,W350,D525,H000,D000',8,0,'erin-trundle-bed-with-mattresses','',0,0,'','','','',1,1,'',''),(73,1,'ERIN TRUNDLE BED WITH POCKET SPRING MATTRESSES','<p>Add versatility and convenience to your bedroom, or guest room, with the Erin trundle bed. The underbed rolls out easily with spacious underbed drawers for convenient storage.<br />\r\nConsisting of one king single bed and matching single trundle bed with mattresses, the Erin will help you get the most out of your bedroom&#39;s space, coming in handy for kids sleepovers, or unexpected visits from guests. It&#39;s a great way to maintain a neat bedroom space.</p>\r\n\r\n<p>You can also upgrade the mattresses from Erin Mattresses to Cozy Sleep Mattresses and Ultra Sleep Mattresses based on your requirements.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Fabric, Wooden Frame</p>\r\n\r\n<p><strong>Dimension:</strong> H:61 X W:107 X D:203 CM</p>\r\n','',0,'','','','','BEST DEAL','E650,T6534,B300,W300,P230,S1652,M362','A300,V62343,A530,C5152,T000,Y600,B365,O600,G300,R500,W300,E650,T6534,B300,U53613,R420,O300,E240,S120,D620,F600,C5153,S362,C52352,O100,O500,K520,S524,M3252,M362,W400,H410,Y000,M230,B3652,C520,I500,H530,K320,S4162,U52123,V232,F650,G320,I320,G630,W000,M350,N300,C500,A420,U1263,C000,S410,U436,B230,R2653251215121,N121,M364,F620,W350,D525,H000,D000',9,0,'erin-trundle-bed-with-mattresses','',0,0,'','','','',1,1,'',''),(73,1,'ERIN TRUNDLE BED WITH POCKET SPRING MATTRESSES','<p>Add versatility and convenience to your bedroom, or guest room, with the Erin trundle bed. The underbed rolls out easily with spacious underbed drawers for convenient storage.<br />\r\nConsisting of one king single bed and matching single trundle bed with mattresses, the Erin will help you get the most out of your bedroom&#39;s space, coming in handy for kids sleepovers, or unexpected visits from guests. It&#39;s a great way to maintain a neat bedroom space.</p>\r\n\r\n<p>You can also upgrade the mattresses from Erin Mattresses to Cozy Sleep Mattresses and Ultra Sleep Mattresses based on your requirements.&nbsp;&nbsp;</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong> Fabric, Wooden Frame</p>\r\n\r\n<p><strong>Dimension:</strong> H:61 X W:107 X D:203 CM</p>\r\n','',0,'','','','','BEST DEAL','E650,T6534,B300,W300,P230,S1652,M362','A300,V62343,A530,C5152,T000,Y600,B365,O600,G300,R500,W300,E650,T6534,B300,U53613,R420,O300,E240,S120,D620,F600,C5153,S362,C52352,O100,O500,K520,S524,M3252,M362,W400,H410,Y000,M230,B3652,C520,I500,H530,K320,S4162,U52123,V232,F650,G320,I320,G630,W000,M350,N300,C500,A420,U1263,C000,S410,U436,B230,R2653251215121,N121,M364,F620,W350,D525,H000,D000',10,0,'erin-trundle-bed-with-mattresses','',0,0,'','','','',1,1,'',''),(74,1,'BERRY 3 SEATER WITH CHAISE','<p>You don&#39;t need to sacrifice comfort for style with the Berry sofa. Available in two sophisticated colours, the Berry comes in a 3 seater, 2 seater and sofa with chaise.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Fabric</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Cream,&nbsp;Steel&nbsp;Grey, Dark Grey and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;H:85 X W:235 X D:150 CM</p>\r\n','',0,'','','','','BEST DEAL','B600,S360,W300,C000','Y000,D530,N300,T000,S612,C5163,F600,S340,W300,B600,S100,A1414,I500,S12323,C462,C520,S360,A530,C000,N121,M364512162,A14145121265121234512126,D620,G600,B200,D525121,W000,D000,C500',1,0,'199523-berbei-3sc','',0,0,'','','','',1,1,'',''),(74,1,'BERRY 3 SEATER WITH CHAISE','<p>You don&#39;t need to sacrifice comfort for style with the Berry sofa. Available in two sophisticated colours, the Berry comes in a 3 seater, 2 seater and sofa with chaise.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Fabric</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Cream,&nbsp;Steel&nbsp;Grey, Dark Grey and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;H:85 X W:235 X D:150 CM</p>\r\n','',0,'','','','','BEST DEAL','B600,S360,W300,C000','Y000,D530,N300,T000,S612,C5163,F600,S340,W300,B600,S100,A1414,I500,S12323,C462,C520,S360,A530,C000,N121,M364512162,A14145121265121234512126,D620,G600,B200,D525121,W000,D000,C500',4,0,'199523-berbei-3sc','',0,0,'','','','',1,1,'',''),(74,1,'BERRY 3 SEATER WITH CHAISE','<p>You don&#39;t need to sacrifice comfort for style with the Berry sofa. Available in two sophisticated colours, the Berry comes in a 3 seater, 2 seater and sofa with chaise.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Fabric</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Cream,&nbsp;Steel&nbsp;Grey, Dark Grey and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;H:85 X W:235 X D:150 CM</p>\r\n','',0,'','','','','BEST DEAL','B600,S360,W300,C000','Y000,D530,N300,T000,S612,C5163,F600,S340,W300,B600,S100,A1414,I500,S12323,C462,C520,S360,A530,C000,N121,M364512162,A14145121265121234512126,D620,G600,B200,D525121,W000,D000,C500',5,0,'199523-berbei-3sc','',0,0,'','','','',1,1,'',''),(74,1,'BERRY 3 SEATER WITH CHAISE','<p>You don&#39;t need to sacrifice comfort for style with the Berry sofa. Available in two sophisticated colours, the Berry comes in a 3 seater, 2 seater and sofa with chaise.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Fabric</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Cream,&nbsp;Steel&nbsp;Grey, Dark Grey and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;H:85 X W:235 X D:150 CM</p>\r\n','',0,'','','','','BEST DEAL','B600,S360,W300,C000','Y000,D530,N300,T000,S612,C5163,F600,S340,W300,B600,S100,A1414,I500,S12323,C462,C520,S360,A530,C000,N121,M364512162,A14145121265121234512126,D620,G600,B200,D525121,W000,D000,C500',6,0,'199523-berbei-3sc','',0,0,'','','','',1,1,'',''),(74,1,'BERRY 3 SEATER WITH CHAISE','<p>You don&#39;t need to sacrifice comfort for style with the Berry sofa. Available in two sophisticated colours, the Berry comes in a 3 seater, 2 seater and sofa with chaise.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Fabric</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Cream,&nbsp;Steel&nbsp;Grey, Dark Grey and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;H:85 X W:235 X D:150 CM</p>\r\n','',0,'','','','','BEST DEAL','B600,S360,W300,C000','Y000,D530,N300,T000,S612,C5163,F600,S340,W300,B600,S100,A1414,I500,S12323,C462,C520,S360,A530,C000,N121,M364512162,A14145121265121234512126,D620,G600,B200,D525121,W000,D000,C500',7,0,'199523-berbei-3sc','',0,0,'','','','',1,1,'',''),(74,1,'BERRY 3 SEATER WITH CHAISE','<p>You don&#39;t need to sacrifice comfort for style with the Berry sofa. Available in two sophisticated colours, the Berry comes in a 3 seater, 2 seater and sofa with chaise.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Fabric</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Cream,&nbsp;Steel&nbsp;Grey, Dark Grey and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;H:85 X W:235 X D:150 CM</p>\r\n','',0,'','','','','BEST DEAL','B600,S360,W300,C000','Y000,D530,N300,T000,S612,C5163,F600,S340,W300,B600,S100,A1414,I500,S12323,C462,C520,S360,A530,C000,N121,M364512162,A14145121265121234512126,D620,G600,B200,D525121,W000,D000,C500',8,0,'199523-berbei-3sc','',0,0,'','','','',1,1,'',''),(74,1,'BERRY 3 SEATER WITH CHAISE','<p>You don&#39;t need to sacrifice comfort for style with the Berry sofa. Available in two sophisticated colours, the Berry comes in a 3 seater, 2 seater and sofa with chaise.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Fabric</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Cream,&nbsp;Steel&nbsp;Grey, Dark Grey and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;H:85 X W:235 X D:150 CM</p>\r\n','',0,'','','','','BEST DEAL','B600,S360,W300,C000','Y000,D530,N300,T000,S612,C5163,F600,S340,W300,B600,S100,A1414,I500,S12323,C462,C520,S360,A530,C000,N121,M364512162,A14145121265121234512126,D620,G600,B200,D525121,W000,D000,C500',9,0,'199523-berbei-3sc','',0,0,'','','','',1,1,'',''),(74,1,'BERRY 3 SEATER WITH CHAISE','<p>You don&#39;t need to sacrifice comfort for style with the Berry sofa. Available in two sophisticated colours, the Berry comes in a 3 seater, 2 seater and sofa with chaise.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Material:</strong>&nbsp;Fabric</p>\r\n\r\n<p><strong>Colours Available:</strong>&nbsp;Cream,&nbsp;Steel&nbsp;Grey, Dark Grey and Beige</p>\r\n\r\n<p><strong>Dimension:</strong>&nbsp;H:85 X W:235 X D:150 CM</p>\r\n','',0,'','','','','BEST DEAL','B600,S360,W300,C000','Y000,D530,N300,T000,S612,C5163,F600,S340,W300,B600,S100,A1414,I500,S12323,C462,C520,S360,A530,C000,N121,M364512162,A14145121265121234512126,D620,G600,B200,D525121,W000,D000,C500',10,0,'199523-berbei-3sc','',0,0,'','','','',1,1,'',''),(75,1,'ZEDS QUASAR QUEEN MATTRESS IN A BOX','<p>The Zeds Quasar Mattress in a Box strikes the perfect balance between comfort and convenience. This Pillow Top mattress features a traditional&nbsp; Pocket spring construction that will provide comfort and all over body support. With a generous layer of soft fillings and foam, you can rest soundly all night long. Packaged in a box, this mattress is easy to transport and even easier to set up; simply open the box, cut the plastic seal and roll the mattress out.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Product Features:</strong></p>\r\n\r\n<ul>\r\n	<li>Generous layer of soft fillings provides comfort and support&nbsp;</li>\r\n	<li>Pillow Top&nbsp;</li>\r\n	<li>Pocket Spring</li>\r\n	<li>Easy to transport</li>\r\n	<li>Comes rolled up in box</li>\r\n	<li>Easy to transport - Carton comes with handle and wheels</li>\r\n	<li>Note: Once mattress is decompressed it can not be put back into the box</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:26 x W:153 x D:203 CM</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Deliver to anywhere in North Island or to Christchurch for $95 only!</strong></p>\r\n','',0,'','','','','<b>BEST ZEDS</b>&nbsp;QUASAR&nbsp;<b>QUEEN</b>&nbsp;MATTRESS IN A BOX WARRANTY: 3 YEARS','Z320,Q600,Q500,M362,I500,B200','T000,Z320,Q600,M362,I500,B200,S362,P6123,B452,B350,C5163,A530,C5152,T200,P400,T100,F362,T63545121,P230,S1652,C5236235,W400,P613,A400,O160,B300,S163,W300,G562,L600,O100,S130,F452,F500,Y000,C500,R230,S534,N230,L520,I200,E200,T652163,E150,E260,S300,U100,S514,O150,C300,P4232,S400,R400,O300,N121,P6323,P6132,S1635121,T15121,C520,R430,C635,H534,W420,N300,O520,D251623,I300,B000,P300,I530,D52525121,W000,D000,D416,A560,N630,I2453,O600,C623262,F600,O540',1,0,'r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box','',0,0,'','','','',1,1,'',''),(75,1,'ZEDS QUASAR QUEEN MATTRESS IN A BOX','<p>The Zeds Quasar Mattress in a Box strikes the perfect balance between comfort and convenience. This Pillow Top mattress features a traditional&nbsp; Pocket spring construction that will provide comfort and all over body support. With a generous layer of soft fillings and foam, you can rest soundly all night long. Packaged in a box, this mattress is easy to transport and even easier to set up; simply open the box, cut the plastic seal and roll the mattress out.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Product Features:</strong></p>\r\n\r\n<ul>\r\n	<li>Generous layer of soft fillings provides comfort and support&nbsp;</li>\r\n	<li>Pillow Top&nbsp;</li>\r\n	<li>Pocket Spring</li>\r\n	<li>Easy to transport</li>\r\n	<li>Comes rolled up in box</li>\r\n	<li>Easy to transport - Carton comes with handle and wheels</li>\r\n	<li>Note: Once mattress is decompressed it can not be put back into the box</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:26 x W:153 x D:203 CM</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Deliver to anywhere in North Island or to Christchurch for $95 only!</strong></p>\r\n','',0,'','','','','<b>BEST ZEDS</b>&nbsp;QUASAR&nbsp;<b>QUEEN</b>&nbsp;MATTRESS IN A BOX WARRANTY: 3 YEARS','Z320,Q600,Q500,M362,I500,B200','T000,Z320,Q600,M362,I500,B200,S362,P6123,B452,B350,C5163,A530,C5152,T200,P400,T100,F362,T63545121,P230,S1652,C5236235,W400,P613,A400,O160,B300,S163,W300,G562,L600,O100,S130,F452,F500,Y000,C500,R230,S534,N230,L520,I200,E200,T652163,E150,E260,S300,U100,S514,O150,C300,P4232,S400,R400,O300,N121,P6323,P6132,S1635121,T15121,C520,R430,C635,H534,W420,N300,O520,D251623,I300,B000,P300,I530,D52525121,W000,D000,D416,A560,N630,I2453,O600,C623262,F600,O540',4,0,'r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box','',0,0,'','','','',1,1,'',''),(75,1,'ZEDS QUASAR QUEEN MATTRESS IN A BOX','<p>The Zeds Quasar Mattress in a Box strikes the perfect balance between comfort and convenience. This Pillow Top mattress features a traditional&nbsp; Pocket spring construction that will provide comfort and all over body support. With a generous layer of soft fillings and foam, you can rest soundly all night long. Packaged in a box, this mattress is easy to transport and even easier to set up; simply open the box, cut the plastic seal and roll the mattress out.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Product Features:</strong></p>\r\n\r\n<ul>\r\n	<li>Generous layer of soft fillings provides comfort and support&nbsp;</li>\r\n	<li>Pillow Top&nbsp;</li>\r\n	<li>Pocket Spring</li>\r\n	<li>Easy to transport</li>\r\n	<li>Comes rolled up in box</li>\r\n	<li>Easy to transport - Carton comes with handle and wheels</li>\r\n	<li>Note: Once mattress is decompressed it can not be put back into the box</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:26 x W:153 x D:203 CM</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Deliver to anywhere in North Island or to Christchurch for $95 only!</strong></p>\r\n','',0,'','','','','<b>BEST ZEDS</b>&nbsp;QUASAR&nbsp;<b>QUEEN</b>&nbsp;MATTRESS IN A BOX WARRANTY: 3 YEARS','Z320,Q600,Q500,M362,I500,B200','T000,Z320,Q600,M362,I500,B200,S362,P6123,B452,B350,C5163,A530,C5152,T200,P400,T100,F362,T63545121,P230,S1652,C5236235,W400,P613,A400,O160,B300,S163,W300,G562,L600,O100,S130,F452,F500,Y000,C500,R230,S534,N230,L520,I200,E200,T652163,E150,E260,S300,U100,S514,O150,C300,P4232,S400,R400,O300,N121,P6323,P6132,S1635121,T15121,C520,R430,C635,H534,W420,N300,O520,D251623,I300,B000,P300,I530,D52525121,W000,D000,D416,A560,N630,I2453,O600,C623262,F600,O540',5,0,'r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box','',0,0,'','','','',1,1,'',''),(75,1,'ZEDS QUASAR QUEEN MATTRESS IN A BOX','<p>The Zeds Quasar Mattress in a Box strikes the perfect balance between comfort and convenience. This Pillow Top mattress features a traditional&nbsp; Pocket spring construction that will provide comfort and all over body support. With a generous layer of soft fillings and foam, you can rest soundly all night long. Packaged in a box, this mattress is easy to transport and even easier to set up; simply open the box, cut the plastic seal and roll the mattress out.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Product Features:</strong></p>\r\n\r\n<ul>\r\n	<li>Generous layer of soft fillings provides comfort and support&nbsp;</li>\r\n	<li>Pillow Top&nbsp;</li>\r\n	<li>Pocket Spring</li>\r\n	<li>Easy to transport</li>\r\n	<li>Comes rolled up in box</li>\r\n	<li>Easy to transport - Carton comes with handle and wheels</li>\r\n	<li>Note: Once mattress is decompressed it can not be put back into the box</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:26 x W:153 x D:203 CM</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Deliver to anywhere in North Island or to Christchurch for $95 only!</strong></p>\r\n','',0,'','','','','<b>BEST ZEDS</b>&nbsp;QUASAR&nbsp;<b>QUEEN</b>&nbsp;MATTRESS IN A BOX WARRANTY: 3 YEARS','Z320,Q600,Q500,M362,I500,B200','T000,Z320,Q600,M362,I500,B200,S362,P6123,B452,B350,C5163,A530,C5152,T200,P400,T100,F362,T63545121,P230,S1652,C5236235,W400,P613,A400,O160,B300,S163,W300,G562,L600,O100,S130,F452,F500,Y000,C500,R230,S534,N230,L520,I200,E200,T652163,E150,E260,S300,U100,S514,O150,C300,P4232,S400,R400,O300,N121,P6323,P6132,S1635121,T15121,C520,R430,C635,H534,W420,N300,O520,D251623,I300,B000,P300,I530,D52525121,W000,D000,D416,A560,N630,I2453,O600,C623262,F600,O540',6,0,'r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box','',0,0,'','','','',1,1,'',''),(75,1,'ZEDS QUASAR QUEEN MATTRESS IN A BOX','<p>The Zeds Quasar Mattress in a Box strikes the perfect balance between comfort and convenience. This Pillow Top mattress features a traditional&nbsp; Pocket spring construction that will provide comfort and all over body support. With a generous layer of soft fillings and foam, you can rest soundly all night long. Packaged in a box, this mattress is easy to transport and even easier to set up; simply open the box, cut the plastic seal and roll the mattress out.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Product Features:</strong></p>\r\n\r\n<ul>\r\n	<li>Generous layer of soft fillings provides comfort and support&nbsp;</li>\r\n	<li>Pillow Top&nbsp;</li>\r\n	<li>Pocket Spring</li>\r\n	<li>Easy to transport</li>\r\n	<li>Comes rolled up in box</li>\r\n	<li>Easy to transport - Carton comes with handle and wheels</li>\r\n	<li>Note: Once mattress is decompressed it can not be put back into the box</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:26 x W:153 x D:203 CM</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Deliver to anywhere in North Island or to Christchurch for $95 only!</strong></p>\r\n','',0,'','','','','<b>BEST ZEDS</b>&nbsp;QUASAR&nbsp;<b>QUEEN</b>&nbsp;MATTRESS IN A BOX WARRANTY: 3 YEARS','Z320,Q600,Q500,M362,I500,B200','T000,Z320,Q600,M362,I500,B200,S362,P6123,B452,B350,C5163,A530,C5152,T200,P400,T100,F362,T63545121,P230,S1652,C5236235,W400,P613,A400,O160,B300,S163,W300,G562,L600,O100,S130,F452,F500,Y000,C500,R230,S534,N230,L520,I200,E200,T652163,E150,E260,S300,U100,S514,O150,C300,P4232,S400,R400,O300,N121,P6323,P6132,S1635121,T15121,C520,R430,C635,H534,W420,N300,O520,D251623,I300,B000,P300,I530,D52525121,W000,D000,D416,A560,N630,I2453,O600,C623262,F600,O540',7,0,'r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box','',0,0,'','','','',1,1,'',''),(75,1,'ZEDS QUASAR QUEEN MATTRESS IN A BOX','<p>The Zeds Quasar Mattress in a Box strikes the perfect balance between comfort and convenience. This Pillow Top mattress features a traditional&nbsp; Pocket spring construction that will provide comfort and all over body support. With a generous layer of soft fillings and foam, you can rest soundly all night long. Packaged in a box, this mattress is easy to transport and even easier to set up; simply open the box, cut the plastic seal and roll the mattress out.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Product Features:</strong></p>\r\n\r\n<ul>\r\n	<li>Generous layer of soft fillings provides comfort and support&nbsp;</li>\r\n	<li>Pillow Top&nbsp;</li>\r\n	<li>Pocket Spring</li>\r\n	<li>Easy to transport</li>\r\n	<li>Comes rolled up in box</li>\r\n	<li>Easy to transport - Carton comes with handle and wheels</li>\r\n	<li>Note: Once mattress is decompressed it can not be put back into the box</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:26 x W:153 x D:203 CM</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Deliver to anywhere in North Island or to Christchurch for $95 only!</strong></p>\r\n','',0,'','','','','<b>BEST ZEDS</b>&nbsp;QUASAR&nbsp;<b>QUEEN</b>&nbsp;MATTRESS IN A BOX WARRANTY: 3 YEARS','Z320,Q600,Q500,M362,I500,B200','T000,Z320,Q600,M362,I500,B200,S362,P6123,B452,B350,C5163,A530,C5152,T200,P400,T100,F362,T63545121,P230,S1652,C5236235,W400,P613,A400,O160,B300,S163,W300,G562,L600,O100,S130,F452,F500,Y000,C500,R230,S534,N230,L520,I200,E200,T652163,E150,E260,S300,U100,S514,O150,C300,P4232,S400,R400,O300,N121,P6323,P6132,S1635121,T15121,C520,R430,C635,H534,W420,N300,O520,D251623,I300,B000,P300,I530,D52525121,W000,D000,D416,A560,N630,I2453,O600,C623262,F600,O540',8,0,'r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box','',0,0,'','','','',1,1,'',''),(75,1,'ZEDS QUASAR QUEEN MATTRESS IN A BOX','<p>The Zeds Quasar Mattress in a Box strikes the perfect balance between comfort and convenience. This Pillow Top mattress features a traditional&nbsp; Pocket spring construction that will provide comfort and all over body support. With a generous layer of soft fillings and foam, you can rest soundly all night long. Packaged in a box, this mattress is easy to transport and even easier to set up; simply open the box, cut the plastic seal and roll the mattress out.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Product Features:</strong></p>\r\n\r\n<ul>\r\n	<li>Generous layer of soft fillings provides comfort and support&nbsp;</li>\r\n	<li>Pillow Top&nbsp;</li>\r\n	<li>Pocket Spring</li>\r\n	<li>Easy to transport</li>\r\n	<li>Comes rolled up in box</li>\r\n	<li>Easy to transport - Carton comes with handle and wheels</li>\r\n	<li>Note: Once mattress is decompressed it can not be put back into the box</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:26 x W:153 x D:203 CM</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Deliver to anywhere in North Island or to Christchurch for $95 only!</strong></p>\r\n','',0,'','','','','<b>BEST ZEDS</b>&nbsp;QUASAR&nbsp;<b>QUEEN</b>&nbsp;MATTRESS IN A BOX WARRANTY: 3 YEARS','Z320,Q600,Q500,M362,I500,B200','T000,Z320,Q600,M362,I500,B200,S362,P6123,B452,B350,C5163,A530,C5152,T200,P400,T100,F362,T63545121,P230,S1652,C5236235,W400,P613,A400,O160,B300,S163,W300,G562,L600,O100,S130,F452,F500,Y000,C500,R230,S534,N230,L520,I200,E200,T652163,E150,E260,S300,U100,S514,O150,C300,P4232,S400,R400,O300,N121,P6323,P6132,S1635121,T15121,C520,R430,C635,H534,W420,N300,O520,D251623,I300,B000,P300,I530,D52525121,W000,D000,D416,A560,N630,I2453,O600,C623262,F600,O540',9,0,'r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box','',0,0,'','','','',1,1,'',''),(75,1,'ZEDS QUASAR QUEEN MATTRESS IN A BOX','<p>The Zeds Quasar Mattress in a Box strikes the perfect balance between comfort and convenience. This Pillow Top mattress features a traditional&nbsp; Pocket spring construction that will provide comfort and all over body support. With a generous layer of soft fillings and foam, you can rest soundly all night long. Packaged in a box, this mattress is easy to transport and even easier to set up; simply open the box, cut the plastic seal and roll the mattress out.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Product Features:</strong></p>\r\n\r\n<ul>\r\n	<li>Generous layer of soft fillings provides comfort and support&nbsp;</li>\r\n	<li>Pillow Top&nbsp;</li>\r\n	<li>Pocket Spring</li>\r\n	<li>Easy to transport</li>\r\n	<li>Comes rolled up in box</li>\r\n	<li>Easy to transport - Carton comes with handle and wheels</li>\r\n	<li>Note: Once mattress is decompressed it can not be put back into the box</li>\r\n</ul>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Dimensions:</strong>&nbsp;H:26 x W:153 x D:203 CM</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<p><strong>Deliver to anywhere in North Island or to Christchurch for $95 only!</strong></p>\r\n','',0,'','','','','<b>BEST ZEDS</b>&nbsp;QUASAR&nbsp;<b>QUEEN</b>&nbsp;MATTRESS IN A BOX WARRANTY: 3 YEARS','Z320,Q600,Q500,M362,I500,B200','T000,Z320,Q600,M362,I500,B200,S362,P6123,B452,B350,C5163,A530,C5152,T200,P400,T100,F362,T63545121,P230,S1652,C5236235,W400,P613,A400,O160,B300,S163,W300,G562,L600,O100,S130,F452,F500,Y000,C500,R230,S534,N230,L520,I200,E200,T652163,E150,E260,S300,U100,S514,O150,C300,P4232,S400,R400,O300,N121,P6323,P6132,S1635121,T15121,C520,R430,C635,H534,W420,N300,O520,D251623,I300,B000,P300,I530,D52525121,W000,D000,D416,A560,N630,I2453,O600,C623262,F600,O540',10,0,'r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box','',0,0,'','','','',1,1,'','');
/*!40000 ALTER TABLE `products_description` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_documents`
--

DROP TABLE IF EXISTS `products_documents`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_documents` (
  `products_documents_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` int(11) NOT NULL DEFAULT '0',
  `document_types_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `filename` varchar(255) CHARACTER SET utf8 DEFAULT NULL,
  `is_link` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`products_documents_id`),
  KEY `products_id` (`products_id`),
  KEY `document_types_id` (`document_types_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_documents`
--

LOCK TABLES `products_documents` WRITE;
/*!40000 ALTER TABLE `products_documents` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_documents` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_documents_titles`
--

DROP TABLE IF EXISTS `products_documents_titles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_documents_titles` (
  `products_documents_id` int(11) NOT NULL,
  `language_id` int(11) NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`products_documents_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_documents_titles`
--

LOCK TABLES `products_documents_titles` WRITE;
/*!40000 ALTER TABLE `products_documents_titles` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_documents_titles` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_fixed_shipping`
--

DROP TABLE IF EXISTS `products_fixed_shipping`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_fixed_shipping` (
  `products_id` int(11) NOT NULL DEFAULT '0',
  `is_enabled` int(1) NOT NULL DEFAULT '0',
  `domestic_shipping` decimal(12,4) NOT NULL DEFAULT '0.0000',
  `domestic_shipping_addl` decimal(12,4) NOT NULL DEFAULT '0.0000',
  `global_shipping` decimal(12,4) NOT NULL DEFAULT '0.0000',
  `global_shipping_addl` decimal(12,4) NOT NULL DEFAULT '0.0000',
  PRIMARY KEY (`products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_fixed_shipping`
--

LOCK TABLES `products_fixed_shipping` WRITE;
/*!40000 ALTER TABLE `products_fixed_shipping` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_fixed_shipping` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_global_sort`
--

DROP TABLE IF EXISTS `products_global_sort`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_global_sort` (
  `products_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`platform_id`,`products_id`,`sort_order`),
  KEY `idx_products_id` (`products_id`,`sort_order`),
  KEY `idx_sort_id` (`sort_order`,`products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_global_sort`
--

LOCK TABLES `products_global_sort` WRITE;
/*!40000 ALTER TABLE `products_global_sort` DISABLE KEYS */;
INSERT INTO `products_global_sort` VALUES (1,1,23),(1,8,24),(2,1,25),(2,8,26),(3,1,27),(3,8,28),(4,1,29),(4,8,30),(5,1,31),(5,8,32),(6,1,33),(6,8,34),(7,1,35),(7,8,36),(8,1,37),(8,8,38),(9,1,39),(9,8,40),(10,1,41),(10,8,42),(11,1,43),(11,8,44),(12,1,45),(12,8,46),(13,1,2),(13,8,47),(14,1,48),(14,8,49),(15,1,50),(15,8,51),(16,1,3),(16,8,52),(17,1,53),(17,8,54),(18,1,55),(18,8,56),(19,1,57),(19,8,58),(20,1,59),(20,8,60),(21,1,1),(21,8,61),(22,1,62),(22,8,63),(23,1,64),(23,8,65),(24,1,66),(24,8,67),(25,1,68),(25,8,69),(26,1,70),(26,8,71),(27,1,72),(27,8,73),(28,1,4),(28,8,74),(29,1,75),(29,8,76),(30,1,77),(30,7,78),(30,9,238),(31,1,79),(31,7,80),(31,9,239),(32,1,81),(32,7,82),(32,9,240),(33,1,83),(33,7,84),(33,9,241),(34,1,85),(34,7,86),(34,9,242),(35,7,5),(35,1,87),(35,9,243),(36,7,10),(36,1,88),(36,9,244),(37,1,89),(37,7,90),(37,9,245),(38,1,91),(38,7,92),(38,10,246),(39,1,93),(39,7,94),(39,10,247),(40,1,95),(40,7,96),(40,10,248),(41,1,97),(41,7,98),(41,10,249),(42,1,99),(42,7,100),(42,10,250),(43,1,101),(43,7,102),(43,10,251),(44,1,103),(44,7,104),(44,10,252),(45,1,105),(45,7,106),(45,10,253),(46,7,7),(46,1,107),(46,10,254),(47,1,108),(47,7,109),(47,10,255),(48,7,6),(48,1,110),(48,10,256),(49,1,111),(49,7,112),(49,10,257),(50,7,8),(50,1,113),(51,1,114),(51,7,115),(52,1,116),(52,7,117),(53,1,118),(53,7,119),(54,7,9),(54,1,120),(55,1,121),(55,7,122),(56,1,123),(56,7,124),(56,8,125),(57,1,11),(57,7,12),(57,8,13),(57,10,126),(58,1,14),(58,7,15),(58,8,16),(58,10,127),(59,1,17),(59,7,18),(59,8,19),(59,10,128),(60,1,20),(60,7,21),(60,8,22),(60,10,129),(61,10,130),(61,1,258),(61,7,259),(62,10,131),(62,1,260),(62,7,261),(63,10,132),(63,1,262),(63,7,263),(64,10,133),(64,1,264),(64,7,265),(65,10,134),(65,1,266),(65,7,267),(66,10,135),(66,1,268),(66,7,269),(67,10,136),(67,1,270),(67,7,271),(68,10,137),(68,1,272),(68,7,273),(69,9,138),(69,1,274),(69,7,275),(70,9,139),(70,1,145),(70,7,276),(71,9,140),(71,1,144),(71,7,277),(72,9,141),(72,1,150),(72,7,278),(73,9,142),(73,1,147),(73,7,279),(74,9,143),(74,1,146),(74,7,280),(75,1,148),(75,9,149),(75,7,281),(76,1,151),(76,9,152),(77,1,153),(77,7,154),(77,8,155),(77,9,156),(77,10,157),(78,1,158),(78,7,159),(78,8,160),(78,9,161),(78,10,162),(80,1,163),(80,7,164),(80,8,165),(80,9,166),(80,10,167),(81,1,168),(81,7,169),(81,8,170),(81,9,171),(81,10,172),(82,1,173),(82,7,174),(82,8,175),(82,9,176),(82,10,177),(83,1,178),(83,7,179),(83,8,180),(83,9,181),(83,10,182),(84,1,183),(84,7,184),(84,8,185),(84,9,186),(84,10,187),(85,1,188),(85,7,189),(85,8,190),(85,9,191),(85,10,192),(86,1,193),(86,7,194),(86,8,195),(86,9,196),(86,10,197),(87,1,198),(87,7,199),(87,8,200),(87,9,201),(87,10,202),(88,1,203),(88,7,204),(88,8,205),(88,9,206),(88,10,207),(89,1,208),(89,7,209),(89,8,210),(89,9,211),(89,10,212),(90,1,213),(90,7,214),(90,8,215),(90,9,216),(90,10,217),(91,1,218),(91,7,219),(91,8,220),(91,9,221),(91,10,222),(92,1,223),(92,7,224),(92,8,225),(92,9,226),(92,10,227),(93,1,228),(93,7,229),(93,8,230),(93,9,231),(93,10,232),(123,1,233),(123,7,234),(123,8,235),(123,9,236),(123,10,237);
/*!40000 ALTER TABLE `products_global_sort` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_groups`
--

DROP TABLE IF EXISTS `products_groups`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_groups` (
  `products_groups_id` int(11) NOT NULL AUTO_INCREMENT,
  `language_id` int(11) NOT NULL DEFAULT '1',
  `products_groups_name` varchar(255) DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  `date_last_modified` datetime DEFAULT NULL,
  PRIMARY KEY (`products_groups_id`,`language_id`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_groups`
--

LOCK TABLES `products_groups` WRITE;
/*!40000 ALTER TABLE `products_groups` DISABLE KEYS */;
INSERT INTO `products_groups` VALUES (1,1,'Casio','2022-07-22 21:06:48',NULL),(2,1,'brolly-quilted-fitted-mattress-protector','2022-07-22 21:07:01',NULL);
/*!40000 ALTER TABLE `products_groups` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_images`
--

DROP TABLE IF EXISTS `products_images`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_images` (
  `products_images_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` int(11) NOT NULL DEFAULT '0',
  `default_image` tinyint(1) NOT NULL DEFAULT '0',
  `image_status` tinyint(1) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`products_images_id`),
  KEY `products_id` (`products_id`,`image_status`)
) ENGINE=InnoDB AUTO_INCREMENT=165 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_images`
--

LOCK TABLES `products_images` WRITE;
/*!40000 ALTER TABLE `products_images` DISABLE KEYS */;
INSERT INTO `products_images` VALUES (1,1,1,1,0),(2,2,1,1,0),(3,3,1,1,0),(4,30,1,1,0),(5,4,1,1,0),(6,30,0,1,1),(7,5,1,1,0),(8,30,0,1,2),(9,30,0,1,3),(10,31,1,1,0),(11,6,1,1,0),(12,32,1,1,0),(13,7,1,1,0),(14,33,1,1,0),(15,8,1,1,0),(16,33,0,1,1),(17,33,0,1,2),(18,8,0,1,1),(19,34,1,1,0),(20,9,1,1,0),(21,35,1,1,0),(22,10,1,1,0),(23,11,1,1,0),(24,36,1,1,0),(25,38,1,1,0),(26,12,1,1,0),(27,36,0,1,1),(28,13,1,1,0),(29,38,0,1,1),(30,36,0,1,2),(31,37,1,1,0),(32,14,1,1,0),(33,39,1,1,0),(34,15,1,1,0),(35,37,0,1,1),(36,39,0,1,1),(37,16,1,1,0),(38,39,0,1,2),(39,40,1,1,0),(40,17,1,1,0),(41,18,1,1,0),(42,40,0,1,1),(43,40,0,1,2),(44,19,1,1,0),(45,41,1,1,0),(46,41,0,1,1),(47,20,1,1,0),(48,41,0,1,2),(49,21,1,1,0),(50,42,1,1,0),(51,42,0,1,1),(52,21,0,1,1),(53,42,0,1,2),(54,22,1,1,0),(55,43,1,1,0),(56,23,1,1,0),(57,43,0,1,1),(58,24,0,1,0),(59,50,1,1,0),(60,44,1,1,0),(61,24,1,1,1),(62,44,0,1,1),(63,44,0,1,2),(64,25,1,1,0),(65,50,0,1,1),(66,44,0,1,3),(67,45,1,1,0),(68,26,1,1,0),(69,50,0,1,2),(70,45,0,1,1),(71,45,0,1,2),(72,27,1,1,0),(73,50,0,1,3),(74,46,1,1,0),(75,28,1,1,0),(76,46,0,1,1),(77,50,0,1,4),(78,29,1,1,0),(79,46,0,1,2),(80,47,1,1,0),(81,51,1,1,0),(82,47,0,1,1),(83,48,1,1,0),(84,48,0,1,1),(85,51,0,1,1),(86,48,0,1,2),(87,49,1,1,0),(88,51,0,1,2),(89,49,0,1,1),(90,49,0,1,2),(91,51,0,1,3),(92,49,0,1,3),(93,52,1,1,0),(94,52,0,1,1),(95,52,0,1,2),(96,52,0,1,3),(97,52,0,1,4),(98,53,1,1,0),(99,53,0,1,1),(100,53,0,1,2),(101,53,0,1,3),(102,53,0,1,4),(103,54,1,1,0),(104,54,0,1,1),(105,54,0,1,2),(106,54,0,1,3),(107,55,1,1,0),(108,55,0,1,1),(109,55,0,1,2),(110,55,0,1,3),(111,55,0,1,4),(112,56,1,1,0),(113,56,0,1,1),(114,57,1,1,0),(115,57,0,1,1),(116,58,1,1,0),(117,59,1,1,0),(118,60,1,1,0),(119,61,1,1,0),(120,62,1,1,0),(121,62,0,1,1),(122,62,0,1,2),(123,63,1,1,0),(124,63,0,1,1),(125,63,0,1,2),(126,64,1,1,0),(127,64,0,1,1),(128,64,0,1,2),(129,64,0,1,3),(130,65,1,1,0),(131,65,0,1,1),(132,65,0,1,2),(133,65,0,1,3),(134,66,1,1,0),(135,66,0,1,1),(136,67,1,1,0),(137,67,0,1,1),(138,67,0,1,2),(139,67,0,1,3),(140,67,0,1,4),(141,68,1,1,0),(142,68,0,1,1),(143,68,0,1,2),(144,68,0,1,3),(145,68,0,1,4),(146,68,0,1,5),(147,69,1,1,0),(148,70,1,1,0),(149,71,1,1,0),(150,72,1,1,0),(151,72,0,1,1),(152,72,0,1,2),(153,73,1,1,0),(154,73,0,1,1),(155,73,0,1,2),(156,73,0,1,3),(157,74,1,1,0),(158,74,0,1,1),(159,75,1,1,0),(160,75,0,1,1),(161,75,0,1,2),(162,75,0,1,3),(163,75,0,1,4),(164,75,0,1,5);
/*!40000 ALTER TABLE `products_images` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_images_attributes`
--

DROP TABLE IF EXISTS `products_images_attributes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_images_attributes` (
  `products_images_id` int(11) NOT NULL,
  `products_options_id` int(11) NOT NULL,
  `products_options_values_id` int(11) NOT NULL,
  PRIMARY KEY (`products_images_id`,`products_options_id`,`products_options_values_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_images_attributes`
--

LOCK TABLES `products_images_attributes` WRITE;
/*!40000 ALTER TABLE `products_images_attributes` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_images_attributes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_images_description`
--

DROP TABLE IF EXISTS `products_images_description`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_images_description` (
  `products_images_id` int(11) NOT NULL,
  `language_id` int(11) NOT NULL,
  `image_title` varchar(255) NOT NULL DEFAULT '',
  `image_alt` varchar(255) NOT NULL DEFAULT '',
  `orig_file_name` varchar(255) NOT NULL DEFAULT '',
  `hash_file_name` varchar(32) NOT NULL DEFAULT '',
  `file_name` varchar(255) NOT NULL DEFAULT '',
  `alt_file_name` varchar(255) NOT NULL DEFAULT '',
  `no_watermark` tinyint(1) NOT NULL DEFAULT '0',
  `use_origin_image_name` tinyint(1) NOT NULL DEFAULT '0',
  `use_external_images` tinyint(11) NOT NULL DEFAULT '0',
  `external_image_original` varchar(1024) NOT NULL DEFAULT '',
  `link_video_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`products_images_id`,`language_id`),
  KEY `orig_file_name` (`orig_file_name`(8))
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_images_description`
--

LOCK TABLES `products_images_description` WRITE;
/*!40000 ALTER TABLE `products_images_description` DISABLE KEYS */;
INSERT INTO `products_images_description` VALUES (1,0,'','','1030636.jpg','81e733742fce8ac07f42f2a86a6ecd8e','NY2146.jpg','',0,0,0,'',0),(1,1,'','','','','','',0,0,0,'',0),(2,0,'','','puma-women-s-motor-pu102742005-white-polyurethane-quartz-watch-with-black-dial.jpg','8cb4b621eb5d312266b30bf1cdf4296b','PU102742005.jpg','',0,0,0,'',0),(2,1,'','','','','','',0,0,0,'',0),(3,0,'','','a1bc3edd-9a21-4d7b-ba14-50af20523dc6_1.b53fe275d0eff058737ff2d5f08e48a8.jpeg','04514af2d3864990e28a7e5c3f9ae9aa','PU102812003.jpg','',0,0,0,'',0),(3,1,'','','','','','',0,0,0,'',0),(4,0,'','','IMG-20220218-WA0020-1.jpg','c2239b2365bc607e081dfe8e76e7568d','79189.jpg','',0,0,0,'',0),(4,1,'','','','','','',0,0,0,'',0),(5,0,'','','6.jpg','42ad50a5648aafafbed860201b04034a','U25004L1.jpg','',0,0,0,'',0),(5,1,'','','','','','',0,0,0,'',0),(6,0,'','','IMG-20220218-WA0033.jpg','ac117e78187dd5aa8ff79715cbff5125','79189.jpg','',0,0,0,'',0),(6,1,'','','','','','',0,0,0,'',0),(7,0,'','','TOMMY HILFIGER MEN\'S SKYWINDER STAINLESS STEEL AND LEATHER STRAP WATCH.jpg','deb6f4b07bb5558f7932f0f6ea65d5a6','11807012.jpg','',0,0,0,'',0),(7,1,'','','','','','',0,0,0,'',0),(8,0,'','','IMG-20220218-WA0032.jpg','102a976212161cb92f64183590a6bc43','79189.jpg','',0,0,0,'',0),(8,1,'','','','','','',0,0,0,'',0),(9,0,'','','IMG-20220218-WA0030.jpg','de63f2899e98cd75618da3711bf1fa4e','79189.jpg','',0,0,0,'',0),(9,1,'','','','','','',0,0,0,'',0),(10,0,'','','Connection_WorkWell_MWT15_blk_front-450x450.png','40bd2e34965e75f17be360d989673c76','MWT15.png','',0,0,0,'',0),(10,1,'','','','','','',0,0,0,'',0),(11,0,'','','8.jpg','b1237935bbc51d6fdacb12abeb6d827e','1790708.jpg','',0,0,0,'',0),(11,1,'','','','','','',0,0,0,'',0),(12,0,'','','K277JUNO_F_fronte-450x450.png','66b65a4178b3b10e4e4a3491ef93e56d','MWT13.png','',0,0,0,'',0),(12,1,'','','','','','',0,0,0,'',0),(13,0,'','','TOMMY HILFIGER MEN\'S BLACK SILICONE QUARTZ WATCH.jpg','38bd38dc20776e7b07b758af4704da61','1790853.jpg','',0,0,0,'',0),(13,1,'','','','','','',0,0,0,'',0),(14,0,'','','IMG-20220218-WA0028.jpg','ef65762d61cf59cbdddf5e33f2c53c0f','39849.jpg','',0,0,0,'',0),(14,1,'','','','','','',0,0,0,'',0),(15,0,'','','1.jpg','e6e59017dbc364f4f9f81efe89a3139d','YA126238.jpg','',0,0,0,'',0),(15,1,'','','','','','',0,0,0,'',0),(16,0,'','','IMG-20220218-WA0023.jpg','c34cd209108212d8221ec537b694cc0a','39849.jpg','',0,0,0,'',0),(16,1,'','','','','','',0,0,0,'',0),(17,0,'','','IMG-20220218-WA0035.jpg','32ca643957f3cf73fe0814bc32b8388c','39849.jpg','',0,0,0,'',0),(17,1,'','','','','','',0,0,0,'',0),(18,0,'','','496e23a316e38e42f239efa660addbbe.jpeg','eb2571fbaed677cdbc22ebd9b817fb7f','YA126238.jpg','',0,0,0,'',0),(18,1,'','','','','','',0,0,0,'',0),(19,0,'','','BB73082_01.jpg','0dd48a225cefab635c7c06f3e46958f8','8081101.jpg','',0,0,0,'',0),(19,1,'','','','','','',0,0,0,'',0),(20,0,'','','DKNY WOMEN\'S NY8183 GOLD STAINLESS STEEL QUARTZ WATCH WITH WHITE ZUSÄ.jpg','e164c03a09d71201834cca6f2dabf0c1','NY8183.jpg','',0,0,0,'',0),(20,1,'','','','','','',0,0,0,'',0),(21,0,'','','BB73081_01.jpg','9608c5b292df933bcca405e6e36fff3a','8081001.jpg','',0,0,0,'',0),(21,1,'','','','','','',0,0,0,'',0),(22,0,'','','INTERLOCKING G SMALL BROWN DIAL LADIES WATCH.jpg','fa55bd8820078e5147e5fef286efe74a','YA133504.jpg','',0,0,0,'',0),(22,1,'','','','','','',0,0,0,'',0),(23,0,'','','w4.jpg','2b0a66d8546f8da0a23fee0c37a33b44','YA129444.jpg','',0,0,0,'',0),(23,1,'','','','','','',0,0,0,'',0),(24,0,'','','KF807537_01.jpg','84c28dc538184a75e1ba6c006db485c8','KF807537.jpg','',0,0,0,'',0),(24,1,'','','','','','',0,0,0,'',0),(25,0,'','','epson-wf-4830-1024x883.jpg','2026463871290499681a6d1b6d21314d','89502105.jpg','',0,0,0,'',0),(25,1,'','','','','','',0,0,0,'',0),(26,0,'','','GUCCI MEN\'S YA133202 \'GRAMMY XL INTERLOCKING\' YELLOW DIAL BLACK LEATHER STRAP SP.jpg','22f5f881dc9b48ee6ab4102c6203a098','YA133202.jpg','',0,0,0,'',0),(26,1,'','','','','','',0,0,0,'',0),(27,0,'','','KF807537_03.jpg','63f82492b88e44e3a40e7ca66161f96c','KF807537.jpg','',0,0,0,'',0),(27,1,'','','','','','',0,0,0,'',0),(28,0,'','','CASIO G-SHOCK G100-1BV WRIST WATCH PRICE- 1200.jpg','0680122ff55da81280ae5eaf26687e76','G100-1BV.jpg','',0,0,0,'',0),(28,1,'','','','','','',0,0,0,'',0),(29,0,'','','WF-3820DWF.jpg','6ddd8a87f48f23ef905fd7258fa4c762','89502105.jpg','',0,0,0,'',0),(29,1,'','','','','','',0,0,0,'',0),(30,0,'','','KF807537_05.jpg','dd8bee6dd349a7121a92efe2da98f8fd','KF807537.jpg','',0,0,0,'',0),(30,1,'','','','','','',0,0,0,'',0),(31,0,'','','EXEC-2DSF-ABW-1.jpg','71718558b102248281093eabe7276fb5','drawerside.jpg','',0,0,0,'',0),(31,1,'','','','','','',0,0,0,'',0),(32,0,'','','CASIO BABY-G BG169G-7B FACE PROTECTOR ION-PLATED METAL WHITE ROSE GOLD WATCH DIGITAL.jpg','d1b23b9362a1162398642f913460a5b0','BG169G-7B.jpg','',0,0,0,'',0),(32,1,'','','','','','',0,0,0,'',0),(33,0,'','','epson-expression-premium-xp-6100-inkjet-printer-500x500 (2).jpg','19660ed1e1a9bae9de0c8bf55640a135','89502103.jpg','',0,0,0,'',0),(33,1,'','','','','','',0,0,0,'',0),(34,0,'','','w8.jpg','0da231d223c44e76c377f358192bb820','MTP1192E-7A.jpg','',0,0,0,'',0),(34,1,'','','','','','',0,0,0,'',0),(35,0,'','','EXEC-2DSF-CCO-1.jpg','6833eec1556e76dcd332b2204ad88412','drawerside.jpg','',0,0,0,'',0),(35,1,'','','','','','',0,0,0,'',0),(36,0,'','','epson-expression-premium-xp-6100-inkjet-printer-500x500 (1).jpg','de76577d3ed58a10919c5c8855c67a04','89502103.jpg','',0,0,0,'',0),(36,1,'','','','','','',0,0,0,'',0),(37,0,'','','CASIO GENERAL MEN\'S WATCHES EDIFICE DIGITAL-ANALOG COMBINATION.jpg','09c0e355a993496d1bbcc166911d2050','EFA121D-7AV.jpg','',0,0,0,'',0),(37,1,'','','','','','',0,0,0,'',0),(38,0,'','','epson-expression-premium-xp-6100-inkjet-printer-500x500.jpg','573adeb1a52688f20a6702caf930da8c','89502103.jpg','',0,0,0,'',0),(38,1,'','','','','','',0,0,0,'',0),(39,0,'','','44333304.jpg','1596a7e8e4d8df5e98c9edd2b32a9bcb','ECOTANK M2120.jpg','',0,0,0,'',0),(39,1,'','','','','','',0,0,0,'',0),(40,0,'','','Casio-W753-2AV-Blue-Digital-Casual-Tide-Graph-Alarm.jpg','d4111ebdaf3fd611a598ad21c02feee5','W753-2AV.jpg','',0,0,0,'',0),(40,1,'','','','','','',0,0,0,'',0),(41,0,'','','NEMESIS WOMEN\'S CLASSIC YELLOW PLANT ART LEATHER CUFF BAND WATCH.jpg','8a1f197b6e882148dd28e9473ae3e051','THR827N.jpg','',0,0,0,'',0),(41,1,'','','','','','',0,0,0,'',0),(42,0,'','','44333307.jpg','431bf659a879c3b812184ed48b45d778','ECOTANK M2120.jpg','',0,0,0,'',0),(42,1,'','','','','','',0,0,0,'',0),(43,0,'','','44333308.jpg','183150e51b0c5fe5176db865d42a5e2d','ECOTANK M2120.jpg','',0,0,0,'',0),(43,1,'','','','','','',0,0,0,'',0),(44,0,'','','71EYpZZ4d-L._UY879_.jpg','2786bffb1ca459fd09436a7fc58e6ea6','BBB516S.jpg','',0,0,0,'',0),(44,1,'','','','','','',0,0,0,'',0),(45,0,'','','epon-m15140-500x500.jpg','d4f730e5604785c2d800104ee57516ad','ECOTANKM15140.jpg','',0,0,0,'',0),(45,1,'','','','','','',0,0,0,'',0),(46,0,'','','epson-ecotank-m15140-a3-wi-fi-duplex-printer-500x500.jpg','a6a798b0652232f198b449c3edc45238','ECOTANKM15140.jpg','',0,0,0,'',0),(46,1,'','','','','','',0,0,0,'',0),(47,0,'','','43.jpg','c9f555c47b792f9bb3f1e4ef97dac6f2','TWXB078K.jpg','',0,0,0,'',0),(47,1,'','','','','','',0,0,0,'',0),(48,0,'','','Epson_C11CJ41402_1.jpg','b64b7208eeab7eb24e2ed07a8d49e094','ECOTANKM15140.jpg','',0,0,0,'',0),(48,1,'','','','','','',0,0,0,'',0),(49,0,'','','Cartier-Mens-Santos-18k-Gold-and-Steel-Automatic-Watch-L12282706a.jpg','c784411dc5b12206fb504ec150582256','Cartier-Mens-Santos-18k-Gold-and-Steel-Automatic-Watch-L12282706a.jpg','Cartier-Mens-Santos-18k-Gold-and-Steel-Automatic-Watch-L12282706a.jpg',0,1,0,'',0),(49,1,'','','','','','',0,0,0,'',0),(50,0,'','','canon-imageclass-lbp2900b-single-function-laser-monochrome-printer-black--500x500.jpg','ac091faeb8a16cffbe66a0633ad6ac62','G3260.jpg','',0,0,0,'',0),(50,1,'','','','','','',0,0,0,'',0),(51,0,'','','canon-pixma-g3800-all-in-one-wireless-inkjet-printer-2-500x500.jpg','fb760d757d6a22d845e1bccc2e14e092','G3260.jpg','',0,0,0,'',0),(51,1,'','','','','','',0,0,0,'',0),(52,0,'','','1-img.jpg','8addf847afc8dfe46786b04b6fcb065d','W20072X7.jpg','',0,0,0,'',0),(52,1,'','','','','','',0,0,0,'',0),(53,0,'','','9f6012da-7b1b-4091-a4fb-36e163c27417.d022a3e6b376962d6701981304ce5a91.jpeg','4ccee44fc24f7865fa50809b56460e7e','G3260.jpg','',0,0,0,'',0),(53,1,'','','','','','',0,0,0,'',0),(54,0,'','','51gIiqrVuJL.jpg','97a896249308519334ae43fb3809aec5','85010-37J-AID.jpg','',0,0,0,'',0),(54,1,'','','','','','',0,0,0,'',0),(55,0,'','','39_600.jpg','2f0003b06263880d1c2f1270ff4ed5e1','DR-6010C.jpg','',0,0,0,'',0),(55,1,'','','','','','',0,0,0,'',0),(56,0,'','','39.jpg','84c2bc0203d62eb77713907f36b8edc7','01112-3-BUIN.jpg','',0,0,0,'',0),(56,1,'','','','','','',0,0,0,'',0),(57,0,'','','727691_middle.jpg','0ab04d44d2ac6c9ef8ba1fb8f4ef7fd5','DR-6010C.jpg','',0,0,0,'',0),(57,1,'','','','','','',0,0,0,'',0),(58,0,'','','2266720201as.jpg','51df9dac704fceb5554f9f99a9167826','0311818.jpg','',0,0,0,'',0),(58,1,'','','','','','',0,0,0,'',0),(59,0,'Cozy Sleep Queen Mattress','Cozy Sleep Queen Mattress','Untitled-2_92b3a510-3402-40b5-8d7a-eeeed4b1ff28.jpg','d0cdccdab621dd3144b401b919f83406','cozy-sleep-queen-mattress.jpg','cozy-sleep-queen-mattress.jpg',0,0,0,'',0),(59,1,'','','','','','',0,0,0,'',0),(60,0,'','','10205060.jpg','fd6d6c2f8fcf7ae640333e4efff519f8','629373.jpg','',0,0,0,'',0),(60,1,'','','','','','',0,0,0,'',0),(61,0,'','','CONCORD MEN\'S \'SARATOGA\' BLACK STAINLESS STEEL SWISS QUARTZ WATCH.jpg','9137ff3fdb5061c3f2a9062fb832a597','0311818.jpg','',0,0,0,'',0),(61,1,'','','','','','',0,0,0,'',0),(62,0,'','','10205060_002.jpg','988b1bbba3aeb29640fc5b20426460d9','629373.jpg','',0,0,0,'',0),(62,1,'','','','','','',0,0,0,'',0),(63,0,'','','10205060_001.jpg','97e817295d5d6f9bc8c34b6fd4415718','629373.jpg','',0,0,0,'',0),(63,1,'','','','','','',0,0,0,'',0),(64,0,'','','CITIZEN ECO-DRIVE SILVER TONE MEN.jpg','a66ac64c279026cdce2e1e51a8bd0cd0','AO9030-05E.jpg','',0,0,0,'',0),(64,1,'','','','','','',0,0,0,'',0),(65,0,'Cozy Sleep Queen Mattress','Cozy Sleep Queen Mattress','Cozy_Mattress2_7b59d35b-a712-41d4-bbaa-40bc7b45fdf6.jpg','53209eb1f6a60911b044c6bbdb8ff710','cozy-sleep-queen-mattress.jpg','cozy-sleep-queen-mattress.jpg',0,0,0,'',0),(65,1,'','','','','','',0,0,0,'',0),(66,0,'','','10205060_003.jpg','9d62bdc2a99c23eb232fd5f80f66fa77','629373.jpg','',0,0,0,'',0),(66,1,'','','','','','',0,0,0,'',0),(67,0,'','','10218735.jpg','c4734186bb2b345eb26c8acc1c1407a6','780020.jpg','',0,0,0,'',0),(67,1,'','','','','','',0,0,0,'',0),(68,0,'','','w34.jpg','e051b529fea790a1021f930d2fee62e9','CA0467-03E.jpg','',0,0,0,'',0),(68,1,'','','','','','',0,0,0,'',0),(69,0,'Cozy Sleep Queen Mattress','Cozy Sleep Queen Mattress','Cozy_Mattress3_6f6ed632-f63b-4c84-9355-b06e3b3c9d2c.jpg','fdf0ffc32162b64d0c10bb7fe214af91','cozy-sleep-queen-mattress.jpg','cozy-sleep-queen-mattress.jpg',0,0,0,'',0),(69,1,'','','','','','',0,0,0,'',0),(70,0,'','','10218735_002.jpg','61a945275a2a632a0f6252d75c1719bc','780020.jpg','',0,0,0,'',0),(70,1,'','','','','','',0,0,0,'',0),(71,0,'','','10218735_004.jpg','01c297c7b5b7e777ee46cb1ae755ebf9','780020.jpg','',0,0,0,'',0),(71,1,'','','','','','',0,0,0,'',0),(72,0,'','','CITIZEN MEN\'S ECO-DRIVE AT2215-07E BLACK LEATHER ECO-DRIVE WATCH WITH BLACK DIAL.jpg','ce26df2562f5e54716d35ef0b9ebc59a','AT2215-07E.jpg','',0,0,0,'',0),(72,1,'','','','','','',0,0,0,'',0),(73,0,'Cozy Sleep Queen Mattress','Cozy Sleep Queen Mattress','Cozy_Mattress_with_Base_aaa8d001-80d4-4c89-bfb4-e743ae5b46aa.jpg','abdd6efdedc26c34466a10b0a878798b','cozy-sleep-queen-mattress.jpg','cozy-sleep-queen-mattress.jpg',0,0,0,'',0),(73,1,'','','','','','',0,0,0,'',0),(74,0,'','','10204798.jpg','7fe3e41d2293078546d68ad039db5ec1','789669.jpg','',0,0,0,'',0),(74,1,'','','','','','',0,0,0,'',0),(75,0,'','','w32.jpg','73030ceaec21fef2b9e27015822c7fe0','BJ8050-08E.jpg','',0,0,0,'',0),(75,1,'','','','','','',0,0,0,'',0),(76,0,'','','10204798_001.jpg','ac2754f67ff2139072988aaa2f4c72db','789669.jpg','',0,0,0,'',0),(76,1,'','','','','','',0,0,0,'',0),(77,0,'Cozy Sleep Queen Mattress','Cozy Sleep Queen Mattress','FN0012_BED_MATRESSES_COSY_SLEEP-CMYK.jpg','da09a856a7784a1f00bfd38e6912131b','cozy-sleep-queen-mattress.jpg','cozy-sleep-queen-mattress.jpg',0,0,0,'',0),(77,1,'','','','','','',0,0,0,'',0),(78,0,'','','ROYAL LONDON 41003-03.jpg','a210dcdb6090441701f89d983e8ae2b7','Royal-41003-03.jpg','',0,0,0,'',0),(78,1,'','','','','','',0,0,0,'',0),(79,0,'','','10204798_003.jpg','d6ee6ca1caa24a919703b6c4dd6351b6','789669.jpg','',0,0,0,'',0),(79,1,'','','','','','',0,0,0,'',0),(80,0,'','','10178981.jpg','d99f56a9a096cdbe75b9b71c6d2986e7','236124.jpg','',0,0,0,'',0),(80,1,'','','','','','',0,0,0,'',0),(81,0,'Cozy Sleep Double Mattress','Cozy Sleep Double Mattress','cozy.jpg','2897be513f66cf7096322c8675e2ede7','cozy-sleep-double-mattress.jpg','cozy-sleep-double-mattress.jpg',0,0,0,'',0),(81,1,'','','','','','',0,0,0,'',0),(82,0,'','','10178981_001.jpg','e03e601badbda47afb1df012768e017a','236124.jpg','',0,0,0,'',0),(82,1,'','','','','','',0,0,0,'',0),(83,0,'','','10124890.jpg','75854b53228a0de04a66522b5e3296a1','131109.jpg','',0,0,0,'',0),(83,1,'','','','','','',0,0,0,'',0),(84,0,'','','10124890_002.jpg','2dfcdbee8607a99a2bb279453428b9fe','131109.jpg','',0,0,0,'',0),(84,1,'','','','','','',0,0,0,'',0),(85,0,'Cozy Sleep Double Mattress','Cozy Sleep Double Mattress','Cozy_Mattress2.jpg','5b32f3c24981ad6216ed10cba3c47d67','cozy-sleep-double-mattress.jpg','cozy-sleep-double-mattress.jpg',0,0,0,'',0),(85,1,'','','','','','',0,0,0,'',0),(86,0,'','','10124890_007.jpg','18831d4bcc86d83ba01e2fecd4a51f5f','131109.jpg','',0,0,0,'',0),(86,1,'','','','','','',0,0,0,'',0),(87,0,'','','10182581.jpg','fcbf6496de0e8463e83fa268e70a4292','245042.jpg','',0,0,0,'',0),(87,1,'','','','','','',0,0,0,'',0),(88,0,'Cozy Sleep Double Mattress','Cozy Sleep Double Mattress','Cozy_Mattress3.jpg','f802c48a3836f676a3ec55ff3d4923c4','cozy-sleep-double-mattress.jpg','cozy-sleep-double-mattress.jpg',0,0,0,'',0),(88,1,'','','','','','',0,0,0,'',0),(89,0,'','','10182581_001.jpg','e9b89a5262948de4206408b14096c43c','245042.jpg','',0,0,0,'',0),(89,1,'','','','','','',0,0,0,'',0),(90,0,'','','10182581_002.jpg','f2d6e8e32b51ab30b03aaf7e798edcf5','245042.jpg','',0,0,0,'',0),(90,1,'','','','','','',0,0,0,'',0),(91,0,'Cozy Sleep Double Mattress','Cozy Sleep Double Mattress','Cozy_Mattress_with_Base.jpg','60793954a2b6e93f37a5cd35c5475285','cozy-sleep-double-mattress.jpg','cozy-sleep-double-mattress.jpg',0,0,0,'',0),(91,1,'','','','','','',0,0,0,'',0),(92,0,'','','10182581_003.jpg','4402ad080f2b323df3f3cabf0f6d6ff5','245042.jpg','',0,0,0,'',0),(92,1,'','','','','','',0,0,0,'',0),(93,0,'Country ','Country ','Country_Bed_Frame01_474de2c5-71cd-4595-823d-8029daad6025.jpg','c4a6d2f7ae4c5e4cdc86130f70210d38','country-.jpg','country-.jpg',0,0,0,'',0),(93,1,'','','','','','',0,0,0,'',0),(94,0,'Country ','Country ','country_bedside_08bde4a5-6ce5-4f89-9cc7-b8b4e4056298.jpg','09b88309b000ac31981809bf8dd6e4de','country-.jpg','country-.jpg',0,0,0,'',0),(94,1,'','','','','','',0,0,0,'',0),(95,0,'Country ','Country ','Country_Dressing_Mirror_53479ff1-daa0-4ae7-907c-8b3fca37f751.jpg','793d4aa2c333d8d8eccee9e037a5efd5','country-.jpg','country-.jpg',0,0,0,'',0),(95,1,'','','','','','',0,0,0,'',0),(96,0,'Country ','Country ','Country_Dressing_Table01_0296b903-b118-40fd-af4a-0150a60eeace.jpg','f2fdf4dc913215c6ba84c228c0259f0b','country-.jpg','country-.jpg',0,0,0,'',0),(96,1,'','','','','','',0,0,0,'',0),(97,0,'Country ','Country ','Country_Tallboy01.jpg','575053bfa94a443227089084347b174b','country-.jpg','country-.jpg',0,0,0,'',0),(97,1,'','','','','','',0,0,0,'',0),(98,0,'','','Jack__6PC_Bedroom_Suite copy dark.jpg','5504c2ac372f145cec5f6c841bc752ea','PJAC09-050093.jpg','',0,0,0,'',0),(98,1,'','','','','','',0,0,0,'',0),(99,0,'Jack 5 Piece King Dresser Bedroom Suite','Jack 5 Piece King Dresser Bedroom Suite','Jack_Bed_01_8801c7e9-1b30-45c1-94d1-b9968a94130d.jpg','4f7c59ecd58c71e26f55a724122e1a54','jack-5-piece-king-dresser-bedroom-suite.jpg','jack-5-piece-king-dresser-bedroom-suite.jpg',0,0,0,'',0),(99,1,'','','','','','',0,0,0,'',0),(100,0,'Jack 5 Piece King Dresser Bedroom Suite','Jack 5 Piece King Dresser Bedroom Suite','Jack_Bedside_Table_02_0ae01eeb-0f16-45f7-862e-c05b1fdbf06a.jpg','53e3051a0b9e08fd997cffbe695f9cd9','jack-5-piece-king-dresser-bedroom-suite.jpg','jack-5-piece-king-dresser-bedroom-suite.jpg',0,0,0,'',0),(100,1,'','','','','','',0,0,0,'',0),(101,0,'Jack 5 Piece King Dresser Bedroom Suite','Jack 5 Piece King Dresser Bedroom Suite','Dresser.jpg','74e44e11759eea89699dd4fcb96bdd34','jack-5-piece-king-dresser-bedroom-suite.jpg','jack-5-piece-king-dresser-bedroom-suite.jpg',0,0,0,'',0),(101,1,'','','','','','',0,0,0,'',0),(102,0,'Jack 5 Piece King Dresser Bedroom Suite','Jack 5 Piece King Dresser Bedroom Suite','Jack_Mirror.jpg','5390c994b7cee565e31d9a0fe8b8ffb1','jack-5-piece-king-dresser-bedroom-suite.jpg','jack-5-piece-king-dresser-bedroom-suite.jpg',0,0,0,'',0),(102,1,'','','','','','',0,0,0,'',0),(103,0,'','','Jack_Ogilvy_PKFurniture_5834 R.jpg','e4dab973f5908da4ef298d52f99c7a0b','PJAC08-0400P3.jpg','',0,0,0,'',0),(103,1,'','','','','','',0,0,0,'',0),(104,0,'Jack 4 Piece King Tallboy Bedroom Suite','Jack 4 Piece King Tallboy Bedroom Suite','Jack_Bed_02_d91ccd18-7884-46d4-ac4e-8141116a7406.jpg','bd11ca3856b90be19e35663a6c99786b','jack-4-piece-king-tallboy-bedroom-suite.jpg','jack-4-piece-king-tallboy-bedroom-suite.jpg',0,0,0,'',0),(104,1,'','','','','','',0,0,0,'',0),(105,0,'Jack 4 Piece King Tallboy Bedroom Suite','Jack 4 Piece King Tallboy Bedroom Suite','Jack_Tallboy_02_9bff4801-79ee-4e5c-a977-7b5bb39f0550.jpg','f3ac21daf1222ab6e3b03cc1bf3c9f80','jack-4-piece-king-tallboy-bedroom-suite.jpg','jack-4-piece-king-tallboy-bedroom-suite.jpg',0,0,0,'',0),(105,1,'','','','','','',0,0,0,'',0),(106,0,'Jack 4 Piece King Tallboy Bedroom Suite','Jack 4 Piece King Tallboy Bedroom Suite','Jack_Bedside_Table_02_7556d8b9-602b-4f30-a569-c895a20e7e93.jpg','c498900b258fb2802659d02b381914ef','jack-4-piece-king-tallboy-bedroom-suite.jpg','jack-4-piece-king-tallboy-bedroom-suite.jpg',0,0,0,'',0),(106,1,'','','','','','',0,0,0,'',0),(107,0,'Hamptons 5 Piece Queen Bedroom Suite','Hamptons 5 Piece Queen Bedroom Suite','5_3367cd3b-9623-4d95-a3e6-7e1b03217907.jpg','10c20f3be4df133d1d9aa17457e3609a','hamptons-5-piece-queen-bedroom-suite.jpg','hamptons-5-piece-queen-bedroom-suite.jpg',0,0,0,'',0),(107,1,'','','','','','',0,0,0,'',0),(108,0,'Hamptons 5 Piece Queen Dresser Bedroom Suite','Hamptons 5 Piece Queen Dresser Bedroom Suite','Hamptons_Queen_Bed_Frame_02_fe9458e1-acd7-4fb5-929a-9e2f57f45bfb.jpg','9b422757503e5e6dfa78b528e92543e6','hamptons-5-piece-queen-dresser-bedroom-suite.jpg','hamptons-5-piece-queen-dresser-bedroom-suite.jpg',0,0,0,'',0),(108,1,'','','','','','',0,0,0,'',0),(109,0,'Hamptons 5 Piece Queen Dresser Bedroom Suite','Hamptons 5 Piece Queen Dresser Bedroom Suite','Hamptons_Bedside_02_f8ff733b-5c8d-4588-ae41-da7440c15bca.jpg','664d04a0e49740c8966247e3f5e01e90','hamptons-5-piece-queen-dresser-bedroom-suite.jpg','hamptons-5-piece-queen-dresser-bedroom-suite.jpg',0,0,0,'',0),(109,1,'','','','','','',0,0,0,'',0),(110,0,'Hamptons 5 Piece Queen Dresser Bedroom Suite','Hamptons 5 Piece Queen Dresser Bedroom Suite','Hamptons_Dressing_Table_02_b9062cde-a69b-4e67-af63-6c722b0a566d.jpg','f0d5d3d44cbca8dd7264438645ca7f73','hamptons-5-piece-queen-dresser-bedroom-suite.jpg','hamptons-5-piece-queen-dresser-bedroom-suite.jpg',0,0,0,'',0),(110,1,'','','','','','',0,0,0,'',0),(111,0,'Hamptons 5 Piece Queen Dresser Bedroom Suite','Hamptons 5 Piece Queen Dresser Bedroom Suite','Hamptons_Dressing_Mirror_01_f8481dd3-6645-4588-bc98-54fce08cf841.jpg','11b0728d909bede471837258239167af','hamptons-5-piece-queen-dresser-bedroom-suite.jpg','hamptons-5-piece-queen-dresser-bedroom-suite.jpg',0,0,0,'',0),(111,1,'','','','','','',0,0,0,'',0),(112,0,'Brolly Quilted Fitted Mattress Protector King','Brolly Quilted Fitted Mattress Protector King','Torin_Dresser_1f7814f9-f1c3-4fce-9c1d-69d6c9659241.jpg','92ce67fe3d45bbcb7884647e26aa6677','brolly-quilted-fitted-mattress-protector-king.jpg','brolly-quilted-fitted-mattress-protector-king.jpg',0,0,0,'',0),(112,1,'','','','','','',0,0,0,'',0),(113,0,'Brolly Quilted Fitted Mattress Protector King','Brolly Quilted Fitted Mattress Protector King','BrollySheet_Quilted_Mattress_protector_37.JPG','7e0b42b9cf5841d112ed18e10c724d1b','brolly-quilted-fitted-mattress-protector-king.jpg','brolly-quilted-fitted-mattress-protector-king.jpg',0,0,0,'',0),(113,1,'','','','','','',0,0,0,'',0),(114,0,'Brolly Quilted Fitted Mattress Protector Queen','Brolly Quilted Fitted Mattress Protector Queen','Torin_Dresser_1f7814f9-f1c3-4fce-9c1d-69d6c9659241.jpg','887a2faeb092c610841c43c20bb5ad2e','brolly-quilted-fitted-mattress-protector-queen.jpg','brolly-quilted-fitted-mattress-protector-queen.jpg',0,0,0,'',0),(114,1,'','','','','','',0,0,0,'',0),(115,0,'Brolly Quilted Fitted Mattress Protector Queen','Brolly Quilted Fitted Mattress Protector Queen','BrollySheet_Quilted_Mattress_protector_37.JPG','34e0010af1fa59d3114fae2ab64cca4e','brolly-quilted-fitted-mattress-protector-queen.jpg','brolly-quilted-fitted-mattress-protector-queen.jpg',0,0,0,'',0),(115,1,'','','','','','',0,0,0,'',0),(116,0,'Furtex ','Furtex ','22585C-Messina---Turquoise-White_800px.jpg','c20697b5fd9adba016ae8123eca31671','furtex-.jpg','furtex-.jpg',0,0,0,'',0),(116,1,'','','','','','',0,0,0,'',0),(117,0,'Furtex ','Furtex ','22898C-Metrix-Back_Orange_Mango-WEB1.jpg','2837bb3af2a0fc90d12c4b320e8bb804','furtex-.jpg','furtex-.jpg',0,0,0,'',0),(117,1,'','','','','','',0,0,0,'',0),(118,0,'Furtex ','Furtex ','23077T-Clara---Lime_800px.jpg','0ba372ba9b043db0ab0ad158ef4fb68c','furtex-.jpg','furtex-.jpg',0,0,0,'',0),(118,1,'','','','','','',0,0,0,'',0),(119,0,'Furtex ','Furtex ','23078T-Clara---Peacock_800px.jpg','cb3869f6bcfc35c494af3329c6b3956c','furtex-.jpg','furtex-.jpg',0,0,0,'',0),(119,1,'','','','','','',0,0,0,'',0),(120,0,'Olivia 3 Drawer Dressing Table','Olivia 3 Drawer Dressing Table','olivia_50de65b0-7c99-483f-b1f8-69fbd09c8d6a.jpg','c07c00d4ce91f00760458f589f9009d0','olivia-3-drawer-dressing-table.jpg','olivia-3-drawer-dressing-table.jpg',0,0,0,'',0),(120,1,'','','','','','',0,0,0,'',0),(121,0,'','','dressing table and dressing mirror.jpg','b897686002a4021a928893172ca00e8f','OLIVIA-TB308DE-DT.jpg','',0,0,0,'',0),(121,1,'','','','','','',0,0,0,'',0),(122,0,'','','5 piece.jpg','a124a7aa25db73efb0deed31c6497aa5','OLIVIA-TB308DE-DT.jpg','',0,0,0,'',0),(122,1,'','','','','','',0,0,0,'',0),(123,0,'','','3+2 Brown.jpg','c1346e1d4434d7fbddf72e3ff20c4570','CLAYTON32-R8308-BROWN.jpg','',0,0,0,'',0),(123,1,'','','','','','',0,0,0,'',0),(124,0,'','','3+2 Brown.png','12cc281e91d705dc764f5b641e386582','CLAYTON32-R8308-BROWN.png','',0,0,0,'',0),(124,1,'','','','','','',0,0,0,'',0),(125,0,'','','5_grande_3caf7e98-1e6f-4bd1-a857-a91e651d1f93_1024x1024.jpg','7566f37c4d42e733e9c528ccd21406a4','CLAYTON32-R8308-BROWN.jpg','',0,0,0,'',0),(125,1,'','','','','','',0,0,0,'',0),(126,0,'','','3+2+1 Brown.jpg','8f468ab4907ee22dd8f3ae69a6de3c58','CLAYTON321-R8308-BROWN.jpg','',0,0,0,'',0),(126,1,'','','','','','',0,0,0,'',0),(127,0,'','','3+2 Brown.png','7eb8d90cf9a2cd464d9dd2691b2a8f76','CLAYTON321-R8308-BROWN.png','',0,0,0,'',0),(127,1,'','','','','','',0,0,0,'',0),(128,0,'','','5_grande_3caf7e98-1e6f-4bd1-a857-a91e651d1f93_1024x1024.jpg','fb3e6ef191e5c5a5a0baffb3948c16cd','CLAYTON321-R8308-BROWN.jpg','',0,0,0,'',0),(128,1,'','','','','','',0,0,0,'',0),(129,0,'','','3_34eb3100-2de1-4b79-9f7e-32ba58648bf2_grande.jpg','32b6b072eabdadd5c13821e5531317e8','CLAYTON321-R8308-BROWN.jpg','',0,0,0,'',0),(129,1,'','','','','','',0,0,0,'',0),(130,0,'','','capture_636474987618731953.jpg','9748091457742eb83aebe1ffb59b0479','VERONICAQUEEN4-NEW.jpg','',0,0,0,'',0),(130,1,'','','','','','',0,0,0,'',0),(131,0,'','','ARIZONA-1012AFQ-FEDERATION_QUEEN_BED_large.jpg','70fc12c6ed809c0084ec821ceeb2d1cc','VERONICAQUEEN4-NEW.jpg','',0,0,0,'',0),(131,1,'','','','','','',0,0,0,'',0),(132,0,'','','Veronica_Bedside_large.png','7018bacfeedcefd9558441d3d80747d5','VERONICAQUEEN4-NEW.png','',0,0,0,'',0),(132,1,'','','','','','',0,0,0,'',0),(133,0,'','','veronica_tallboy_large.jpg','4f20a2c5d681a4daaccade9263093191','VERONICAQUEEN4-NEW.jpg','',0,0,0,'',0),(133,1,'','','','','','',0,0,0,'',0),(134,0,'','',' IMG_1015 (9).png','0a31e3671ce00cbbc4427a369d5d7667','MONA-1237-RED.png','',0,0,0,'',0),(134,1,'','','','','','',0,0,0,'',0),(135,0,'','','Astana (6).jpg','8a279a1ef12596f7c5ef42b730e096ab','MONA-1237-RED.jpg','',0,0,0,'',0),(135,1,'','','','','','',0,0,0,'',0),(136,0,'','','M-Package-2.png','09f7d77ce06a1ea577c278b9355ff5f1','MICHAEL-150BLK-PACKAGE.png','',0,0,0,'',0),(136,1,'','','','','','',0,0,0,'',0),(137,0,'','','M-Package-1.png','c0cb465ba212e381e119ee7ee5d3b520','MICHAEL-150BLK-PACKAGE.png','',0,0,0,'',0),(137,1,'','','','','','',0,0,0,'',0),(138,0,'','','Black.png','a66ac0a5b0033b2e81bd86e86186157c','MICHAEL-150BLK-PACKAGE.png','',0,0,0,'',0),(138,1,'','','','','','',0,0,0,'',0),(139,0,'','','Michael Chair 1.png','3c8e8bde2abca4a7718d9bc98b9610a3','MICHAEL-150BLK-PACKAGE.png','',0,0,0,'',0),(139,1,'','','','','','',0,0,0,'',0),(140,0,'','','Michael Chair 2.png','5e0a266b4c39c4d9aa713a9d5e334c14','MICHAEL-150BLK-PACKAGE.png','',0,0,0,'',0),(140,1,'','','','','','',0,0,0,'',0),(141,0,'','','7696.png','c569596e635f3a4d5f2483846fc5779d','CASPERPACKAGE.png','',0,0,0,'',0),(141,1,'','','','','','',0,0,0,'',0),(142,0,'','','7693.png','67b195e8d286e91a07b99ff308ba9de9','CASPERPACKAGE.png','',0,0,0,'',0),(142,1,'','','','','','',0,0,0,'',0),(143,0,'','','7694.png','67dd16886aa682dccc67cba6305b2b3e','CASPERPACKAGE.png','',0,0,0,'',0),(143,1,'','','','','','',0,0,0,'',0),(144,0,'','','Casper-DINING TABLE.jpg','f51c43de4cc2b96c390d2eca8f669b9a','CASPERPACKAGE.jpg','',0,0,0,'',0),(144,1,'','','','','','',0,0,0,'',0),(145,0,'','','Casper-DINING CHAIR.jpg','01d6a86f5561d6cec9d34bb183a7349d','CASPERPACKAGE.jpg','',0,0,0,'',0),(145,1,'','','','','','',0,0,0,'',0),(146,0,'','','CASPER-SKT1167-LT.jpg','2c5e66201232f29a5852a8842700769a','CASPERPACKAGE.jpg','',0,0,0,'',0),(146,1,'','','','','','',0,0,0,'',0),(147,0,'','','IMG_6312_ACE_Dining_Setting_7Pce___HUC37336_-_HUC23807_large.png','eec745ed32ce251a9610944aa7ecd5e3','JONAS180PACKAGE.png','',0,0,0,'',0),(147,1,'','','','','','',0,0,0,'',0),(148,0,'','','image2_637043178903589141.png','d9dbf7715014c6c95357069d494fd0dc','JONASBARPACKAGE.png','',0,0,0,'',0),(148,1,'','','','','','',0,0,0,'',0),(149,0,'','','huc25806acejackjillhuc25806cut_637020042982791563.jpg','ba3ca95cc2e6650c5b55365f7afb43db','HUC25806.png','',0,0,0,'',0),(149,1,'','','','','','',0,0,0,'',0),(150,0,'','','huc23826huc23825huc37170_637020047257430234.jpg','2b506a107237d3f56df0e673ec1232a7','JONASLOUNGE.png','',0,0,0,'',0),(150,1,'','','','','','',0,0,0,'',0),(151,0,'','','huc23825acedoubleloungehuc23826_637020047487029844.jpg','7791a968d233410ec6b0e44cbf78e33c','JONASLOUNGE.png','',0,0,0,'',0),(151,1,'','','','','','',0,0,0,'',0),(152,0,'','','huc23825acesinglelounge_637020047353338438.jpg','89bf6220867a012227e88b22731e3701','JONASLOUNGE.png','',0,0,0,'',0),(152,1,'','','','','','',0,0,0,'',0),(153,0,'','','7581.png','770da476aff281741e9fb32266a7374c','00TB03-NEWERIN-KS.png','',0,0,0,'',0),(153,1,'','','','','','',0,0,0,'',0),(154,0,'','','7856.png','7cf86d2103094540bd7c59847708975d','00TB03-NEWERIN-KS.png','',0,0,0,'',0),(154,1,'','','','','','',0,0,0,'',0),(155,0,'','','7854.png','b56aac1bfab32f54feaae84fc8afb348','00TB03-NEWERIN-KS.png','',0,0,0,'',0),(155,1,'','','','','','',0,0,0,'',0),(156,0,'','','7850.png','1e627592576033cb9972fd919d36b5b8','00TB03-NEWERIN-KS.png','',0,0,0,'',0),(156,1,'','','','','','',0,0,0,'',0),(157,0,'','','barry_3s_wchaise_beige_with_chocolate_piping_01_la_636472007789690704.jpg','febf0aa26fdea862054651667de618cd','199523-BERBEI-3S%2FC.png','',0,0,0,'',0),(157,1,'','','','','','',0,0,0,'',0),(158,0,'','','barry_3s_wchaise_beige_with_chocolate_piping_02_la_636472008074173125.jpg','ac8fc7b616226195e1dc0f198e2547e1','199523-BERBEI-3S%2FC.jpg','',0,0,0,'',0),(158,1,'','','','','','',0,0,0,'',0),(159,0,'','','Zeds.png','150fb3ce95da643d9053aae180ab9fd9','PR539-ZEDS QUASAR-Q.png','',0,0,0,'',0),(159,1,'','','','','','',0,0,0,'',0),(160,0,'','','8874.png','5cecb71d003bb31b143eb40a3d80da34','PR539-ZEDS QUASAR-Q.png','',0,0,0,'',0),(160,1,'','','','','','',0,0,0,'',0),(161,0,'','','8875.png','d249f52f8fa80972d5d01e4b5e9a084b','PR539-ZEDS QUASAR-Q.png','',0,0,0,'',0),(161,1,'','','','','','',0,0,0,'',0),(162,0,'','','8878.png','93c2c87c747026ee3755afd11f5d9402','PR539-ZEDS QUASAR-Q.png','',0,0,0,'',0),(162,1,'','','','','','',0,0,0,'',0),(163,0,'','','PR535-ZEDS+QUASAR-S.png','7852b7f7f8095200b450228c8746a2c5','PR539-ZEDS QUASAR-Q.png','',0,0,0,'',0),(163,1,'','','','','','',0,0,0,'',0),(164,0,'','','PR535-ZEDS+QUASAR-S (1).png','e1325b0eaa38d1c13f2a8d00a5fbfa25','PR539-ZEDS QUASAR-Q.png','',0,0,0,'',0),(164,1,'','','','','','',0,0,0,'',0);
/*!40000 ALTER TABLE `products_images_description` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_images_external_url`
--

DROP TABLE IF EXISTS `products_images_external_url`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_images_external_url` (
  `products_images_id` int(11) NOT NULL,
  `image_types_id` int(11) NOT NULL,
  `language_id` int(11) NOT NULL,
  `image_url` varchar(1024) NOT NULL DEFAULT '',
  PRIMARY KEY (`products_images_id`,`image_types_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_images_external_url`
--

LOCK TABLES `products_images_external_url` WRITE;
/*!40000 ALTER TABLE `products_images_external_url` DISABLE KEYS */;
INSERT INTO `products_images_external_url` VALUES (1,1,0,''),(1,1,1,''),(1,2,0,''),(1,2,1,''),(1,3,0,''),(1,3,1,''),(1,4,0,''),(1,4,1,''),(1,5,0,''),(1,5,1,''),(1,6,0,''),(1,6,1,''),(1,7,0,''),(1,7,1,''),(1,8,0,''),(1,8,1,''),(1,9,0,''),(1,9,1,''),(1,10,0,''),(1,10,1,''),(1,11,0,''),(1,11,1,''),(2,1,0,''),(2,1,1,''),(2,2,0,''),(2,2,1,''),(2,3,0,''),(2,3,1,''),(2,4,0,''),(2,4,1,''),(2,5,0,''),(2,5,1,''),(2,6,0,''),(2,6,1,''),(2,7,0,''),(2,7,1,''),(2,8,0,''),(2,8,1,''),(2,9,0,''),(2,9,1,''),(2,10,0,''),(2,10,1,''),(2,11,0,''),(2,11,1,''),(3,1,0,''),(3,1,1,''),(3,2,0,''),(3,2,1,''),(3,3,0,''),(3,3,1,''),(3,4,0,''),(3,4,1,''),(3,5,0,''),(3,5,1,''),(3,6,0,''),(3,6,1,''),(3,7,0,''),(3,7,1,''),(3,8,0,''),(3,8,1,''),(3,9,0,''),(3,9,1,''),(3,10,0,''),(3,10,1,''),(3,11,0,''),(3,11,1,''),(4,1,0,''),(4,1,1,''),(4,2,0,''),(4,2,1,''),(4,3,0,''),(4,3,1,''),(4,4,0,''),(4,4,1,''),(4,5,0,''),(4,5,1,''),(4,6,0,''),(4,6,1,''),(4,7,0,''),(4,7,1,''),(4,8,0,''),(4,8,1,''),(4,9,0,''),(4,9,1,''),(4,10,0,''),(4,10,1,''),(4,11,0,''),(4,11,1,''),(5,1,0,''),(5,1,1,''),(5,2,0,''),(5,2,1,''),(5,3,0,''),(5,3,1,''),(5,4,0,''),(5,4,1,''),(5,5,0,''),(5,5,1,''),(5,6,0,''),(5,6,1,''),(5,7,0,''),(5,7,1,''),(5,8,0,''),(5,8,1,''),(5,9,0,''),(5,9,1,''),(5,10,0,''),(5,10,1,''),(5,11,0,''),(5,11,1,''),(6,1,0,''),(6,1,1,''),(6,2,0,''),(6,2,1,''),(6,3,0,''),(6,3,1,''),(6,4,0,''),(6,4,1,''),(6,5,0,''),(6,5,1,''),(6,6,0,''),(6,6,1,''),(6,7,0,''),(6,7,1,''),(6,8,0,''),(6,8,1,''),(6,9,0,''),(6,9,1,''),(6,10,0,''),(6,10,1,''),(6,11,0,''),(6,11,1,''),(7,1,0,''),(7,1,1,''),(7,2,0,''),(7,2,1,''),(7,3,0,''),(7,3,1,''),(7,4,0,''),(7,4,1,''),(7,5,0,''),(7,5,1,''),(7,6,0,''),(7,6,1,''),(7,7,0,''),(7,7,1,''),(7,8,0,''),(7,8,1,''),(7,9,0,''),(7,9,1,''),(7,10,0,''),(7,10,1,''),(7,11,0,''),(7,11,1,''),(8,1,0,''),(8,1,1,''),(8,2,0,''),(8,2,1,''),(8,3,0,''),(8,3,1,''),(8,4,0,''),(8,4,1,''),(8,5,0,''),(8,5,1,''),(8,6,0,''),(8,6,1,''),(8,7,0,''),(8,7,1,''),(8,8,0,''),(8,8,1,''),(8,9,0,''),(8,9,1,''),(8,10,0,''),(8,10,1,''),(8,11,0,''),(8,11,1,''),(9,1,0,''),(9,1,1,''),(9,2,0,''),(9,2,1,''),(9,3,0,''),(9,3,1,''),(9,4,0,''),(9,4,1,''),(9,5,0,''),(9,5,1,''),(9,6,0,''),(9,6,1,''),(9,7,0,''),(9,7,1,''),(9,8,0,''),(9,8,1,''),(9,9,0,''),(9,9,1,''),(9,10,0,''),(9,10,1,''),(9,11,0,''),(9,11,1,''),(10,1,0,''),(10,1,1,''),(10,2,0,''),(10,2,1,''),(10,3,0,''),(10,3,1,''),(10,4,0,''),(10,4,1,''),(10,5,0,''),(10,5,1,''),(10,6,0,''),(10,6,1,''),(10,7,0,''),(10,7,1,''),(10,8,0,''),(10,8,1,''),(10,9,0,''),(10,9,1,''),(10,10,0,''),(10,10,1,''),(10,11,0,''),(10,11,1,''),(11,1,0,''),(11,1,1,''),(11,2,0,''),(11,2,1,''),(11,3,0,''),(11,3,1,''),(11,4,0,''),(11,4,1,''),(11,5,0,''),(11,5,1,''),(11,6,0,''),(11,6,1,''),(11,7,0,''),(11,7,1,''),(11,8,0,''),(11,8,1,''),(11,9,0,''),(11,9,1,''),(11,10,0,''),(11,10,1,''),(11,11,0,''),(11,11,1,''),(12,1,0,''),(12,1,1,''),(12,2,0,''),(12,2,1,''),(12,3,0,''),(12,3,1,''),(12,4,0,''),(12,4,1,''),(12,5,0,''),(12,5,1,''),(12,6,0,''),(12,6,1,''),(12,7,0,''),(12,7,1,''),(12,8,0,''),(12,8,1,''),(12,9,0,''),(12,9,1,''),(12,10,0,''),(12,10,1,''),(12,11,0,''),(12,11,1,''),(13,1,0,''),(13,1,1,''),(13,2,0,''),(13,2,1,''),(13,3,0,''),(13,3,1,''),(13,4,0,''),(13,4,1,''),(13,5,0,''),(13,5,1,''),(13,6,0,''),(13,6,1,''),(13,7,0,''),(13,7,1,''),(13,8,0,''),(13,8,1,''),(13,9,0,''),(13,9,1,''),(13,10,0,''),(13,10,1,''),(13,11,0,''),(13,11,1,''),(14,1,0,''),(14,1,1,''),(14,2,0,''),(14,2,1,''),(14,3,0,''),(14,3,1,''),(14,4,0,''),(14,4,1,''),(14,5,0,''),(14,5,1,''),(14,6,0,''),(14,6,1,''),(14,7,0,''),(14,7,1,''),(14,8,0,''),(14,8,1,''),(14,9,0,''),(14,9,1,''),(14,10,0,''),(14,10,1,''),(14,11,0,''),(14,11,1,''),(15,1,0,''),(15,1,1,''),(15,2,0,''),(15,2,1,''),(15,3,0,''),(15,3,1,''),(15,4,0,''),(15,4,1,''),(15,5,0,''),(15,5,1,''),(15,6,0,''),(15,6,1,''),(15,7,0,''),(15,7,1,''),(15,8,0,''),(15,8,1,''),(15,9,0,''),(15,9,1,''),(15,10,0,''),(15,10,1,''),(15,11,0,''),(15,11,1,''),(16,1,0,''),(16,1,1,''),(16,2,0,''),(16,2,1,''),(16,3,0,''),(16,3,1,''),(16,4,0,''),(16,4,1,''),(16,5,0,''),(16,5,1,''),(16,6,0,''),(16,6,1,''),(16,7,0,''),(16,7,1,''),(16,8,0,''),(16,8,1,''),(16,9,0,''),(16,9,1,''),(16,10,0,''),(16,10,1,''),(16,11,0,''),(16,11,1,''),(17,1,0,''),(17,1,1,''),(17,2,0,''),(17,2,1,''),(17,3,0,''),(17,3,1,''),(17,4,0,''),(17,4,1,''),(17,5,0,''),(17,5,1,''),(17,6,0,''),(17,6,1,''),(17,7,0,''),(17,7,1,''),(17,8,0,''),(17,8,1,''),(17,9,0,''),(17,9,1,''),(17,10,0,''),(17,10,1,''),(17,11,0,''),(17,11,1,''),(18,1,0,''),(18,1,1,''),(18,2,0,''),(18,2,1,''),(18,3,0,''),(18,3,1,''),(18,4,0,''),(18,4,1,''),(18,5,0,''),(18,5,1,''),(18,6,0,''),(18,6,1,''),(18,7,0,''),(18,7,1,''),(18,8,0,''),(18,8,1,''),(18,9,0,''),(18,9,1,''),(18,10,0,''),(18,10,1,''),(18,11,0,''),(18,11,1,''),(19,1,0,''),(19,1,1,''),(19,2,0,''),(19,2,1,''),(19,3,0,''),(19,3,1,''),(19,4,0,''),(19,4,1,''),(19,5,0,''),(19,5,1,''),(19,6,0,''),(19,6,1,''),(19,7,0,''),(19,7,1,''),(19,8,0,''),(19,8,1,''),(19,9,0,''),(19,9,1,''),(19,10,0,''),(19,10,1,''),(19,11,0,''),(19,11,1,''),(20,1,0,''),(20,1,1,''),(20,2,0,''),(20,2,1,''),(20,3,0,''),(20,3,1,''),(20,4,0,''),(20,4,1,''),(20,5,0,''),(20,5,1,''),(20,6,0,''),(20,6,1,''),(20,7,0,''),(20,7,1,''),(20,8,0,''),(20,8,1,''),(20,9,0,''),(20,9,1,''),(20,10,0,''),(20,10,1,''),(20,11,0,''),(20,11,1,''),(21,1,0,''),(21,1,1,''),(21,2,0,''),(21,2,1,''),(21,3,0,''),(21,3,1,''),(21,4,0,''),(21,4,1,''),(21,5,0,''),(21,5,1,''),(21,6,0,''),(21,6,1,''),(21,7,0,''),(21,7,1,''),(21,8,0,''),(21,8,1,''),(21,9,0,''),(21,9,1,''),(21,10,0,''),(21,10,1,''),(21,11,0,''),(21,11,1,''),(22,1,0,''),(22,1,1,''),(22,2,0,''),(22,2,1,''),(22,3,0,''),(22,3,1,''),(22,4,0,''),(22,4,1,''),(22,5,0,''),(22,5,1,''),(22,6,0,''),(22,6,1,''),(22,7,0,''),(22,7,1,''),(22,8,0,''),(22,8,1,''),(22,9,0,''),(22,9,1,''),(22,10,0,''),(22,10,1,''),(22,11,0,''),(22,11,1,''),(23,1,0,''),(23,1,1,''),(23,2,0,''),(23,2,1,''),(23,3,0,''),(23,3,1,''),(23,4,0,''),(23,4,1,''),(23,5,0,''),(23,5,1,''),(23,6,0,''),(23,6,1,''),(23,7,0,''),(23,7,1,''),(23,8,0,''),(23,8,1,''),(23,9,0,''),(23,9,1,''),(23,10,0,''),(23,10,1,''),(23,11,0,''),(23,11,1,''),(24,1,0,''),(24,1,1,''),(24,2,0,''),(24,2,1,''),(24,3,0,''),(24,3,1,''),(24,4,0,''),(24,4,1,''),(24,5,0,''),(24,5,1,''),(24,6,0,''),(24,6,1,''),(24,7,0,''),(24,7,1,''),(24,8,0,''),(24,8,1,''),(24,9,0,''),(24,9,1,''),(24,10,0,''),(24,10,1,''),(24,11,0,''),(24,11,1,''),(25,1,0,''),(25,1,1,''),(25,2,0,''),(25,2,1,''),(25,3,0,''),(25,3,1,''),(25,4,0,''),(25,4,1,''),(25,5,0,''),(25,5,1,''),(25,6,0,''),(25,6,1,''),(25,7,0,''),(25,7,1,''),(25,8,0,''),(25,8,1,''),(25,9,0,''),(25,9,1,''),(25,10,0,''),(25,10,1,''),(25,11,0,''),(25,11,1,''),(26,1,0,''),(26,1,1,''),(26,2,0,''),(26,2,1,''),(26,3,0,''),(26,3,1,''),(26,4,0,''),(26,4,1,''),(26,5,0,''),(26,5,1,''),(26,6,0,''),(26,6,1,''),(26,7,0,''),(26,7,1,''),(26,8,0,''),(26,8,1,''),(26,9,0,''),(26,9,1,''),(26,10,0,''),(26,10,1,''),(26,11,0,''),(26,11,1,''),(27,1,0,''),(27,1,1,''),(27,2,0,''),(27,2,1,''),(27,3,0,''),(27,3,1,''),(27,4,0,''),(27,4,1,''),(27,5,0,''),(27,5,1,''),(27,6,0,''),(27,6,1,''),(27,7,0,''),(27,7,1,''),(27,8,0,''),(27,8,1,''),(27,9,0,''),(27,9,1,''),(27,10,0,''),(27,10,1,''),(27,11,0,''),(27,11,1,''),(28,1,0,''),(28,1,1,''),(28,2,0,''),(28,2,1,''),(28,3,0,''),(28,3,1,''),(28,4,0,''),(28,4,1,''),(28,5,0,''),(28,5,1,''),(28,6,0,''),(28,6,1,''),(28,7,0,''),(28,7,1,''),(28,8,0,''),(28,8,1,''),(28,9,0,''),(28,9,1,''),(28,10,0,''),(28,10,1,''),(28,11,0,''),(28,11,1,''),(29,1,0,''),(29,1,1,''),(29,2,0,''),(29,2,1,''),(29,3,0,''),(29,3,1,''),(29,4,0,''),(29,4,1,''),(29,5,0,''),(29,5,1,''),(29,6,0,''),(29,6,1,''),(29,7,0,''),(29,7,1,''),(29,8,0,''),(29,8,1,''),(29,9,0,''),(29,9,1,''),(29,10,0,''),(29,10,1,''),(29,11,0,''),(29,11,1,''),(30,1,0,''),(30,1,1,''),(30,2,0,''),(30,2,1,''),(30,3,0,''),(30,3,1,''),(30,4,0,''),(30,4,1,''),(30,5,0,''),(30,5,1,''),(30,6,0,''),(30,6,1,''),(30,7,0,''),(30,7,1,''),(30,8,0,''),(30,8,1,''),(30,9,0,''),(30,9,1,''),(30,10,0,''),(30,10,1,''),(30,11,0,''),(30,11,1,''),(31,1,0,''),(31,1,1,''),(31,2,0,''),(31,2,1,''),(31,3,0,''),(31,3,1,''),(31,4,0,''),(31,4,1,''),(31,5,0,''),(31,5,1,''),(31,6,0,''),(31,6,1,''),(31,7,0,''),(31,7,1,''),(31,8,0,''),(31,8,1,''),(31,9,0,''),(31,9,1,''),(31,10,0,''),(31,10,1,''),(31,11,0,''),(31,11,1,''),(32,1,0,''),(32,1,1,''),(32,2,0,''),(32,2,1,''),(32,3,0,''),(32,3,1,''),(32,4,0,''),(32,4,1,''),(32,5,0,''),(32,5,1,''),(32,6,0,''),(32,6,1,''),(32,7,0,''),(32,7,1,''),(32,8,0,''),(32,8,1,''),(32,9,0,''),(32,9,1,''),(32,10,0,''),(32,10,1,''),(32,11,0,''),(32,11,1,''),(33,1,0,''),(33,1,1,''),(33,2,0,''),(33,2,1,''),(33,3,0,''),(33,3,1,''),(33,4,0,''),(33,4,1,''),(33,5,0,''),(33,5,1,''),(33,6,0,''),(33,6,1,''),(33,7,0,''),(33,7,1,''),(33,8,0,''),(33,8,1,''),(33,9,0,''),(33,9,1,''),(33,10,0,''),(33,10,1,''),(33,11,0,''),(33,11,1,''),(34,1,0,''),(34,1,1,''),(34,2,0,''),(34,2,1,''),(34,3,0,''),(34,3,1,''),(34,4,0,''),(34,4,1,''),(34,5,0,''),(34,5,1,''),(34,6,0,''),(34,6,1,''),(34,7,0,''),(34,7,1,''),(34,8,0,''),(34,8,1,''),(34,9,0,''),(34,9,1,''),(34,10,0,''),(34,10,1,''),(34,11,0,''),(34,11,1,''),(35,1,0,''),(35,1,1,''),(35,2,0,''),(35,2,1,''),(35,3,0,''),(35,3,1,''),(35,4,0,''),(35,4,1,''),(35,5,0,''),(35,5,1,''),(35,6,0,''),(35,6,1,''),(35,7,0,''),(35,7,1,''),(35,8,0,''),(35,8,1,''),(35,9,0,''),(35,9,1,''),(35,10,0,''),(35,10,1,''),(35,11,0,''),(35,11,1,''),(36,1,0,''),(36,1,1,''),(36,2,0,''),(36,2,1,''),(36,3,0,''),(36,3,1,''),(36,4,0,''),(36,4,1,''),(36,5,0,''),(36,5,1,''),(36,6,0,''),(36,6,1,''),(36,7,0,''),(36,7,1,''),(36,8,0,''),(36,8,1,''),(36,9,0,''),(36,9,1,''),(36,10,0,''),(36,10,1,''),(36,11,0,''),(36,11,1,''),(37,1,0,''),(37,1,1,''),(37,2,0,''),(37,2,1,''),(37,3,0,''),(37,3,1,''),(37,4,0,''),(37,4,1,''),(37,5,0,''),(37,5,1,''),(37,6,0,''),(37,6,1,''),(37,7,0,''),(37,7,1,''),(37,8,0,''),(37,8,1,''),(37,9,0,''),(37,9,1,''),(37,10,0,''),(37,10,1,''),(37,11,0,''),(37,11,1,''),(38,1,0,''),(38,1,1,''),(38,2,0,''),(38,2,1,''),(38,3,0,''),(38,3,1,''),(38,4,0,''),(38,4,1,''),(38,5,0,''),(38,5,1,''),(38,6,0,''),(38,6,1,''),(38,7,0,''),(38,7,1,''),(38,8,0,''),(38,8,1,''),(38,9,0,''),(38,9,1,''),(38,10,0,''),(38,10,1,''),(38,11,0,''),(38,11,1,''),(39,1,0,''),(39,1,1,''),(39,2,0,''),(39,2,1,''),(39,3,0,''),(39,3,1,''),(39,4,0,''),(39,4,1,''),(39,5,0,''),(39,5,1,''),(39,6,0,''),(39,6,1,''),(39,7,0,''),(39,7,1,''),(39,8,0,''),(39,8,1,''),(39,9,0,''),(39,9,1,''),(39,10,0,''),(39,10,1,''),(39,11,0,''),(39,11,1,''),(40,1,0,''),(40,1,1,''),(40,2,0,''),(40,2,1,''),(40,3,0,''),(40,3,1,''),(40,4,0,''),(40,4,1,''),(40,5,0,''),(40,5,1,''),(40,6,0,''),(40,6,1,''),(40,7,0,''),(40,7,1,''),(40,8,0,''),(40,8,1,''),(40,9,0,''),(40,9,1,''),(40,10,0,''),(40,10,1,''),(40,11,0,''),(40,11,1,''),(41,1,0,''),(41,1,1,''),(41,2,0,''),(41,2,1,''),(41,3,0,''),(41,3,1,''),(41,4,0,''),(41,4,1,''),(41,5,0,''),(41,5,1,''),(41,6,0,''),(41,6,1,''),(41,7,0,''),(41,7,1,''),(41,8,0,''),(41,8,1,''),(41,9,0,''),(41,9,1,''),(41,10,0,''),(41,10,1,''),(41,11,0,''),(41,11,1,''),(42,1,0,''),(42,1,1,''),(42,2,0,''),(42,2,1,''),(42,3,0,''),(42,3,1,''),(42,4,0,''),(42,4,1,''),(42,5,0,''),(42,5,1,''),(42,6,0,''),(42,6,1,''),(42,7,0,''),(42,7,1,''),(42,8,0,''),(42,8,1,''),(42,9,0,''),(42,9,1,''),(42,10,0,''),(42,10,1,''),(42,11,0,''),(42,11,1,''),(43,1,0,''),(43,1,1,''),(43,2,0,''),(43,2,1,''),(43,3,0,''),(43,3,1,''),(43,4,0,''),(43,4,1,''),(43,5,0,''),(43,5,1,''),(43,6,0,''),(43,6,1,''),(43,7,0,''),(43,7,1,''),(43,8,0,''),(43,8,1,''),(43,9,0,''),(43,9,1,''),(43,10,0,''),(43,10,1,''),(43,11,0,''),(43,11,1,''),(44,1,0,''),(44,1,1,''),(44,2,0,''),(44,2,1,''),(44,3,0,''),(44,3,1,''),(44,4,0,''),(44,4,1,''),(44,5,0,''),(44,5,1,''),(44,6,0,''),(44,6,1,''),(44,7,0,''),(44,7,1,''),(44,8,0,''),(44,8,1,''),(44,9,0,''),(44,9,1,''),(44,10,0,''),(44,10,1,''),(44,11,0,''),(44,11,1,''),(45,1,0,''),(45,1,1,''),(45,2,0,''),(45,2,1,''),(45,3,0,''),(45,3,1,''),(45,4,0,''),(45,4,1,''),(45,5,0,''),(45,5,1,''),(45,6,0,''),(45,6,1,''),(45,7,0,''),(45,7,1,''),(45,8,0,''),(45,8,1,''),(45,9,0,''),(45,9,1,''),(45,10,0,''),(45,10,1,''),(45,11,0,''),(45,11,1,''),(46,1,0,''),(46,1,1,''),(46,2,0,''),(46,2,1,''),(46,3,0,''),(46,3,1,''),(46,4,0,''),(46,4,1,''),(46,5,0,''),(46,5,1,''),(46,6,0,''),(46,6,1,''),(46,7,0,''),(46,7,1,''),(46,8,0,''),(46,8,1,''),(46,9,0,''),(46,9,1,''),(46,10,0,''),(46,10,1,''),(46,11,0,''),(46,11,1,''),(47,1,0,''),(47,1,1,''),(47,2,0,''),(47,2,1,''),(47,3,0,''),(47,3,1,''),(47,4,0,''),(47,4,1,''),(47,5,0,''),(47,5,1,''),(47,6,0,''),(47,6,1,''),(47,7,0,''),(47,7,1,''),(47,8,0,''),(47,8,1,''),(47,9,0,''),(47,9,1,''),(47,10,0,''),(47,10,1,''),(47,11,0,''),(47,11,1,''),(48,1,0,''),(48,1,1,''),(48,2,0,''),(48,2,1,''),(48,3,0,''),(48,3,1,''),(48,4,0,''),(48,4,1,''),(48,5,0,''),(48,5,1,''),(48,6,0,''),(48,6,1,''),(48,7,0,''),(48,7,1,''),(48,8,0,''),(48,8,1,''),(48,9,0,''),(48,9,1,''),(48,10,0,''),(48,10,1,''),(48,11,0,''),(48,11,1,''),(49,1,0,''),(49,1,1,''),(49,2,0,''),(49,2,1,''),(49,3,0,''),(49,3,1,''),(49,4,0,''),(49,4,1,''),(49,5,0,''),(49,5,1,''),(49,6,0,''),(49,6,1,''),(49,7,0,''),(49,7,1,''),(49,8,0,''),(49,8,1,''),(49,9,0,''),(49,9,1,''),(49,10,0,''),(49,10,1,''),(49,11,0,''),(49,11,1,''),(50,1,0,''),(50,1,1,''),(50,2,0,''),(50,2,1,''),(50,3,0,''),(50,3,1,''),(50,4,0,''),(50,4,1,''),(50,5,0,''),(50,5,1,''),(50,6,0,''),(50,6,1,''),(50,7,0,''),(50,7,1,''),(50,8,0,''),(50,8,1,''),(50,9,0,''),(50,9,1,''),(50,10,0,''),(50,10,1,''),(50,11,0,''),(50,11,1,''),(51,1,0,''),(51,1,1,''),(51,2,0,''),(51,2,1,''),(51,3,0,''),(51,3,1,''),(51,4,0,''),(51,4,1,''),(51,5,0,''),(51,5,1,''),(51,6,0,''),(51,6,1,''),(51,7,0,''),(51,7,1,''),(51,8,0,''),(51,8,1,''),(51,9,0,''),(51,9,1,''),(51,10,0,''),(51,10,1,''),(51,11,0,''),(51,11,1,''),(52,1,0,''),(52,1,1,''),(52,2,0,''),(52,2,1,''),(52,3,0,''),(52,3,1,''),(52,4,0,''),(52,4,1,''),(52,5,0,''),(52,5,1,''),(52,6,0,''),(52,6,1,''),(52,7,0,''),(52,7,1,''),(52,8,0,''),(52,8,1,''),(52,9,0,''),(52,9,1,''),(52,10,0,''),(52,10,1,''),(52,11,0,''),(52,11,1,''),(53,1,0,''),(53,1,1,''),(53,2,0,''),(53,2,1,''),(53,3,0,''),(53,3,1,''),(53,4,0,''),(53,4,1,''),(53,5,0,''),(53,5,1,''),(53,6,0,''),(53,6,1,''),(53,7,0,''),(53,7,1,''),(53,8,0,''),(53,8,1,''),(53,9,0,''),(53,9,1,''),(53,10,0,''),(53,10,1,''),(53,11,0,''),(53,11,1,''),(54,1,0,''),(54,1,1,''),(54,2,0,''),(54,2,1,''),(54,3,0,''),(54,3,1,''),(54,4,0,''),(54,4,1,''),(54,5,0,''),(54,5,1,''),(54,6,0,''),(54,6,1,''),(54,7,0,''),(54,7,1,''),(54,8,0,''),(54,8,1,''),(54,9,0,''),(54,9,1,''),(54,10,0,''),(54,10,1,''),(54,11,0,''),(54,11,1,''),(55,1,0,''),(55,1,1,''),(55,2,0,''),(55,2,1,''),(55,3,0,''),(55,3,1,''),(55,4,0,''),(55,4,1,''),(55,5,0,''),(55,5,1,''),(55,6,0,''),(55,6,1,''),(55,7,0,''),(55,7,1,''),(55,8,0,''),(55,8,1,''),(55,9,0,''),(55,9,1,''),(55,10,0,''),(55,10,1,''),(55,11,0,''),(55,11,1,''),(56,1,0,''),(56,1,1,''),(56,2,0,''),(56,2,1,''),(56,3,0,''),(56,3,1,''),(56,4,0,''),(56,4,1,''),(56,5,0,''),(56,5,1,''),(56,6,0,''),(56,6,1,''),(56,7,0,''),(56,7,1,''),(56,8,0,''),(56,8,1,''),(56,9,0,''),(56,9,1,''),(56,10,0,''),(56,10,1,''),(56,11,0,''),(56,11,1,''),(57,1,0,''),(57,1,1,''),(57,2,0,''),(57,2,1,''),(57,3,0,''),(57,3,1,''),(57,4,0,''),(57,4,1,''),(57,5,0,''),(57,5,1,''),(57,6,0,''),(57,6,1,''),(57,7,0,''),(57,7,1,''),(57,8,0,''),(57,8,1,''),(57,9,0,''),(57,9,1,''),(57,10,0,''),(57,10,1,''),(57,11,0,''),(57,11,1,''),(58,1,0,''),(58,1,1,''),(58,2,0,''),(58,2,1,''),(58,3,0,''),(58,3,1,''),(58,4,0,''),(58,4,1,''),(58,5,0,''),(58,5,1,''),(58,6,0,''),(58,6,1,''),(58,7,0,''),(58,7,1,''),(58,8,0,''),(58,8,1,''),(58,9,0,''),(58,9,1,''),(58,10,0,''),(58,10,1,''),(58,11,0,''),(58,11,1,''),(59,1,0,''),(59,1,1,''),(59,2,0,''),(59,2,1,''),(59,3,0,''),(59,3,1,''),(59,4,0,''),(59,4,1,''),(59,5,0,''),(59,5,1,''),(59,6,0,''),(59,6,1,''),(59,7,0,''),(59,7,1,''),(59,8,0,''),(59,8,1,''),(59,9,0,''),(59,9,1,''),(59,10,0,''),(59,10,1,''),(59,11,0,''),(59,11,1,''),(60,1,0,''),(60,1,1,''),(60,2,0,''),(60,2,1,''),(60,3,0,''),(60,3,1,''),(60,4,0,''),(60,4,1,''),(60,5,0,''),(60,5,1,''),(60,6,0,''),(60,6,1,''),(60,7,0,''),(60,7,1,''),(60,8,0,''),(60,8,1,''),(60,9,0,''),(60,9,1,''),(60,10,0,''),(60,10,1,''),(60,11,0,''),(60,11,1,''),(61,1,0,''),(61,1,1,''),(61,2,0,''),(61,2,1,''),(61,3,0,''),(61,3,1,''),(61,4,0,''),(61,4,1,''),(61,5,0,''),(61,5,1,''),(61,6,0,''),(61,6,1,''),(61,7,0,''),(61,7,1,''),(61,8,0,''),(61,8,1,''),(61,9,0,''),(61,9,1,''),(61,10,0,''),(61,10,1,''),(61,11,0,''),(61,11,1,''),(62,1,0,''),(62,1,1,''),(62,2,0,''),(62,2,1,''),(62,3,0,''),(62,3,1,''),(62,4,0,''),(62,4,1,''),(62,5,0,''),(62,5,1,''),(62,6,0,''),(62,6,1,''),(62,7,0,''),(62,7,1,''),(62,8,0,''),(62,8,1,''),(62,9,0,''),(62,9,1,''),(62,10,0,''),(62,10,1,''),(62,11,0,''),(62,11,1,''),(63,1,0,''),(63,1,1,''),(63,2,0,''),(63,2,1,''),(63,3,0,''),(63,3,1,''),(63,4,0,''),(63,4,1,''),(63,5,0,''),(63,5,1,''),(63,6,0,''),(63,6,1,''),(63,7,0,''),(63,7,1,''),(63,8,0,''),(63,8,1,''),(63,9,0,''),(63,9,1,''),(63,10,0,''),(63,10,1,''),(63,11,0,''),(63,11,1,''),(64,1,0,''),(64,1,1,''),(64,2,0,''),(64,2,1,''),(64,3,0,''),(64,3,1,''),(64,4,0,''),(64,4,1,''),(64,5,0,''),(64,5,1,''),(64,6,0,''),(64,6,1,''),(64,7,0,''),(64,7,1,''),(64,8,0,''),(64,8,1,''),(64,9,0,''),(64,9,1,''),(64,10,0,''),(64,10,1,''),(64,11,0,''),(64,11,1,''),(65,1,0,''),(65,1,1,''),(65,2,0,''),(65,2,1,''),(65,3,0,''),(65,3,1,''),(65,4,0,''),(65,4,1,''),(65,5,0,''),(65,5,1,''),(65,6,0,''),(65,6,1,''),(65,7,0,''),(65,7,1,''),(65,8,0,''),(65,8,1,''),(65,9,0,''),(65,9,1,''),(65,10,0,''),(65,10,1,''),(65,11,0,''),(65,11,1,''),(66,1,0,''),(66,1,1,''),(66,2,0,''),(66,2,1,''),(66,3,0,''),(66,3,1,''),(66,4,0,''),(66,4,1,''),(66,5,0,''),(66,5,1,''),(66,6,0,''),(66,6,1,''),(66,7,0,''),(66,7,1,''),(66,8,0,''),(66,8,1,''),(66,9,0,''),(66,9,1,''),(66,10,0,''),(66,10,1,''),(66,11,0,''),(66,11,1,''),(67,1,0,''),(67,1,1,''),(67,2,0,''),(67,2,1,''),(67,3,0,''),(67,3,1,''),(67,4,0,''),(67,4,1,''),(67,5,0,''),(67,5,1,''),(67,6,0,''),(67,6,1,''),(67,7,0,''),(67,7,1,''),(67,8,0,''),(67,8,1,''),(67,9,0,''),(67,9,1,''),(67,10,0,''),(67,10,1,''),(67,11,0,''),(67,11,1,''),(68,1,0,''),(68,1,1,''),(68,2,0,''),(68,2,1,''),(68,3,0,''),(68,3,1,''),(68,4,0,''),(68,4,1,''),(68,5,0,''),(68,5,1,''),(68,6,0,''),(68,6,1,''),(68,7,0,''),(68,7,1,''),(68,8,0,''),(68,8,1,''),(68,9,0,''),(68,9,1,''),(68,10,0,''),(68,10,1,''),(68,11,0,''),(68,11,1,''),(69,1,0,''),(69,1,1,''),(69,2,0,''),(69,2,1,''),(69,3,0,''),(69,3,1,''),(69,4,0,''),(69,4,1,''),(69,5,0,''),(69,5,1,''),(69,6,0,''),(69,6,1,''),(69,7,0,''),(69,7,1,''),(69,8,0,''),(69,8,1,''),(69,9,0,''),(69,9,1,''),(69,10,0,''),(69,10,1,''),(69,11,0,''),(69,11,1,''),(70,1,0,''),(70,1,1,''),(70,2,0,''),(70,2,1,''),(70,3,0,''),(70,3,1,''),(70,4,0,''),(70,4,1,''),(70,5,0,''),(70,5,1,''),(70,6,0,''),(70,6,1,''),(70,7,0,''),(70,7,1,''),(70,8,0,''),(70,8,1,''),(70,9,0,''),(70,9,1,''),(70,10,0,''),(70,10,1,''),(70,11,0,''),(70,11,1,''),(71,1,0,''),(71,1,1,''),(71,2,0,''),(71,2,1,''),(71,3,0,''),(71,3,1,''),(71,4,0,''),(71,4,1,''),(71,5,0,''),(71,5,1,''),(71,6,0,''),(71,6,1,''),(71,7,0,''),(71,7,1,''),(71,8,0,''),(71,8,1,''),(71,9,0,''),(71,9,1,''),(71,10,0,''),(71,10,1,''),(71,11,0,''),(71,11,1,''),(72,1,0,''),(72,1,1,''),(72,2,0,''),(72,2,1,''),(72,3,0,''),(72,3,1,''),(72,4,0,''),(72,4,1,''),(72,5,0,''),(72,5,1,''),(72,6,0,''),(72,6,1,''),(72,7,0,''),(72,7,1,''),(72,8,0,''),(72,8,1,''),(72,9,0,''),(72,9,1,''),(72,10,0,''),(72,10,1,''),(72,11,0,''),(72,11,1,''),(73,1,0,''),(73,1,1,''),(73,2,0,''),(73,2,1,''),(73,3,0,''),(73,3,1,''),(73,4,0,''),(73,4,1,''),(73,5,0,''),(73,5,1,''),(73,6,0,''),(73,6,1,''),(73,7,0,''),(73,7,1,''),(73,8,0,''),(73,8,1,''),(73,9,0,''),(73,9,1,''),(73,10,0,''),(73,10,1,''),(73,11,0,''),(73,11,1,''),(74,1,0,''),(74,1,1,''),(74,2,0,''),(74,2,1,''),(74,3,0,''),(74,3,1,''),(74,4,0,''),(74,4,1,''),(74,5,0,''),(74,5,1,''),(74,6,0,''),(74,6,1,''),(74,7,0,''),(74,7,1,''),(74,8,0,''),(74,8,1,''),(74,9,0,''),(74,9,1,''),(74,10,0,''),(74,10,1,''),(74,11,0,''),(74,11,1,''),(75,1,0,''),(75,1,1,''),(75,2,0,''),(75,2,1,''),(75,3,0,''),(75,3,1,''),(75,4,0,''),(75,4,1,''),(75,5,0,''),(75,5,1,''),(75,6,0,''),(75,6,1,''),(75,7,0,''),(75,7,1,''),(75,8,0,''),(75,8,1,''),(75,9,0,''),(75,9,1,''),(75,10,0,''),(75,10,1,''),(75,11,0,''),(75,11,1,''),(76,1,0,''),(76,1,1,''),(76,2,0,''),(76,2,1,''),(76,3,0,''),(76,3,1,''),(76,4,0,''),(76,4,1,''),(76,5,0,''),(76,5,1,''),(76,6,0,''),(76,6,1,''),(76,7,0,''),(76,7,1,''),(76,8,0,''),(76,8,1,''),(76,9,0,''),(76,9,1,''),(76,10,0,''),(76,10,1,''),(76,11,0,''),(76,11,1,''),(77,1,0,''),(77,1,1,''),(77,2,0,''),(77,2,1,''),(77,3,0,''),(77,3,1,''),(77,4,0,''),(77,4,1,''),(77,5,0,''),(77,5,1,''),(77,6,0,''),(77,6,1,''),(77,7,0,''),(77,7,1,''),(77,8,0,''),(77,8,1,''),(77,9,0,''),(77,9,1,''),(77,10,0,''),(77,10,1,''),(77,11,0,''),(77,11,1,''),(78,1,0,''),(78,1,1,''),(78,2,0,''),(78,2,1,''),(78,3,0,''),(78,3,1,''),(78,4,0,''),(78,4,1,''),(78,5,0,''),(78,5,1,''),(78,6,0,''),(78,6,1,''),(78,7,0,''),(78,7,1,''),(78,8,0,''),(78,8,1,''),(78,9,0,''),(78,9,1,''),(78,10,0,''),(78,10,1,''),(78,11,0,''),(78,11,1,''),(79,1,0,''),(79,1,1,''),(79,2,0,''),(79,2,1,''),(79,3,0,''),(79,3,1,''),(79,4,0,''),(79,4,1,''),(79,5,0,''),(79,5,1,''),(79,6,0,''),(79,6,1,''),(79,7,0,''),(79,7,1,''),(79,8,0,''),(79,8,1,''),(79,9,0,''),(79,9,1,''),(79,10,0,''),(79,10,1,''),(79,11,0,''),(79,11,1,''),(80,1,0,''),(80,1,1,''),(80,2,0,''),(80,2,1,''),(80,3,0,''),(80,3,1,''),(80,4,0,''),(80,4,1,''),(80,5,0,''),(80,5,1,''),(80,6,0,''),(80,6,1,''),(80,7,0,''),(80,7,1,''),(80,8,0,''),(80,8,1,''),(80,9,0,''),(80,9,1,''),(80,10,0,''),(80,10,1,''),(80,11,0,''),(80,11,1,''),(81,1,0,''),(81,1,1,''),(81,2,0,''),(81,2,1,''),(81,3,0,''),(81,3,1,''),(81,4,0,''),(81,4,1,''),(81,5,0,''),(81,5,1,''),(81,6,0,''),(81,6,1,''),(81,7,0,''),(81,7,1,''),(81,8,0,''),(81,8,1,''),(81,9,0,''),(81,9,1,''),(81,10,0,''),(81,10,1,''),(81,11,0,''),(81,11,1,''),(82,1,0,''),(82,1,1,''),(82,2,0,''),(82,2,1,''),(82,3,0,''),(82,3,1,''),(82,4,0,''),(82,4,1,''),(82,5,0,''),(82,5,1,''),(82,6,0,''),(82,6,1,''),(82,7,0,''),(82,7,1,''),(82,8,0,''),(82,8,1,''),(82,9,0,''),(82,9,1,''),(82,10,0,''),(82,10,1,''),(82,11,0,''),(82,11,1,''),(83,1,0,''),(83,1,1,''),(83,2,0,''),(83,2,1,''),(83,3,0,''),(83,3,1,''),(83,4,0,''),(83,4,1,''),(83,5,0,''),(83,5,1,''),(83,6,0,''),(83,6,1,''),(83,7,0,''),(83,7,1,''),(83,8,0,''),(83,8,1,''),(83,9,0,''),(83,9,1,''),(83,10,0,''),(83,10,1,''),(83,11,0,''),(83,11,1,''),(84,1,0,''),(84,1,1,''),(84,2,0,''),(84,2,1,''),(84,3,0,''),(84,3,1,''),(84,4,0,''),(84,4,1,''),(84,5,0,''),(84,5,1,''),(84,6,0,''),(84,6,1,''),(84,7,0,''),(84,7,1,''),(84,8,0,''),(84,8,1,''),(84,9,0,''),(84,9,1,''),(84,10,0,''),(84,10,1,''),(84,11,0,''),(84,11,1,''),(85,1,0,''),(85,1,1,''),(85,2,0,''),(85,2,1,''),(85,3,0,''),(85,3,1,''),(85,4,0,''),(85,4,1,''),(85,5,0,''),(85,5,1,''),(85,6,0,''),(85,6,1,''),(85,7,0,''),(85,7,1,''),(85,8,0,''),(85,8,1,''),(85,9,0,''),(85,9,1,''),(85,10,0,''),(85,10,1,''),(85,11,0,''),(85,11,1,''),(86,1,0,''),(86,1,1,''),(86,2,0,''),(86,2,1,''),(86,3,0,''),(86,3,1,''),(86,4,0,''),(86,4,1,''),(86,5,0,''),(86,5,1,''),(86,6,0,''),(86,6,1,''),(86,7,0,''),(86,7,1,''),(86,8,0,''),(86,8,1,''),(86,9,0,''),(86,9,1,''),(86,10,0,''),(86,10,1,''),(86,11,0,''),(86,11,1,''),(87,1,0,''),(87,1,1,''),(87,2,0,''),(87,2,1,''),(87,3,0,''),(87,3,1,''),(87,4,0,''),(87,4,1,''),(87,5,0,''),(87,5,1,''),(87,6,0,''),(87,6,1,''),(87,7,0,''),(87,7,1,''),(87,8,0,''),(87,8,1,''),(87,9,0,''),(87,9,1,''),(87,10,0,''),(87,10,1,''),(87,11,0,''),(87,11,1,''),(88,1,0,''),(88,1,1,''),(88,2,0,''),(88,2,1,''),(88,3,0,''),(88,3,1,''),(88,4,0,''),(88,4,1,''),(88,5,0,''),(88,5,1,''),(88,6,0,''),(88,6,1,''),(88,7,0,''),(88,7,1,''),(88,8,0,''),(88,8,1,''),(88,9,0,''),(88,9,1,''),(88,10,0,''),(88,10,1,''),(88,11,0,''),(88,11,1,''),(89,1,0,''),(89,1,1,''),(89,2,0,''),(89,2,1,''),(89,3,0,''),(89,3,1,''),(89,4,0,''),(89,4,1,''),(89,5,0,''),(89,5,1,''),(89,6,0,''),(89,6,1,''),(89,7,0,''),(89,7,1,''),(89,8,0,''),(89,8,1,''),(89,9,0,''),(89,9,1,''),(89,10,0,''),(89,10,1,''),(89,11,0,''),(89,11,1,''),(90,1,0,''),(90,1,1,''),(90,2,0,''),(90,2,1,''),(90,3,0,''),(90,3,1,''),(90,4,0,''),(90,4,1,''),(90,5,0,''),(90,5,1,''),(90,6,0,''),(90,6,1,''),(90,7,0,''),(90,7,1,''),(90,8,0,''),(90,8,1,''),(90,9,0,''),(90,9,1,''),(90,10,0,''),(90,10,1,''),(90,11,0,''),(90,11,1,''),(91,1,0,''),(91,1,1,''),(91,2,0,''),(91,2,1,''),(91,3,0,''),(91,3,1,''),(91,4,0,''),(91,4,1,''),(91,5,0,''),(91,5,1,''),(91,6,0,''),(91,6,1,''),(91,7,0,''),(91,7,1,''),(91,8,0,''),(91,8,1,''),(91,9,0,''),(91,9,1,''),(91,10,0,''),(91,10,1,''),(91,11,0,''),(91,11,1,''),(92,1,0,''),(92,1,1,''),(92,2,0,''),(92,2,1,''),(92,3,0,''),(92,3,1,''),(92,4,0,''),(92,4,1,''),(92,5,0,''),(92,5,1,''),(92,6,0,''),(92,6,1,''),(92,7,0,''),(92,7,1,''),(92,8,0,''),(92,8,1,''),(92,9,0,''),(92,9,1,''),(92,10,0,''),(92,10,1,''),(92,11,0,''),(92,11,1,''),(93,1,0,''),(93,1,1,''),(93,2,0,''),(93,2,1,''),(93,3,0,''),(93,3,1,''),(93,4,0,''),(93,4,1,''),(93,5,0,''),(93,5,1,''),(93,6,0,''),(93,6,1,''),(93,7,0,''),(93,7,1,''),(93,8,0,''),(93,8,1,''),(93,9,0,''),(93,9,1,''),(93,10,0,''),(93,10,1,''),(93,11,0,''),(93,11,1,''),(94,1,0,''),(94,1,1,''),(94,2,0,''),(94,2,1,''),(94,3,0,''),(94,3,1,''),(94,4,0,''),(94,4,1,''),(94,5,0,''),(94,5,1,''),(94,6,0,''),(94,6,1,''),(94,7,0,''),(94,7,1,''),(94,8,0,''),(94,8,1,''),(94,9,0,''),(94,9,1,''),(94,10,0,''),(94,10,1,''),(94,11,0,''),(94,11,1,''),(95,1,0,''),(95,1,1,''),(95,2,0,''),(95,2,1,''),(95,3,0,''),(95,3,1,''),(95,4,0,''),(95,4,1,''),(95,5,0,''),(95,5,1,''),(95,6,0,''),(95,6,1,''),(95,7,0,''),(95,7,1,''),(95,8,0,''),(95,8,1,''),(95,9,0,''),(95,9,1,''),(95,10,0,''),(95,10,1,''),(95,11,0,''),(95,11,1,''),(96,1,0,''),(96,1,1,''),(96,2,0,''),(96,2,1,''),(96,3,0,''),(96,3,1,''),(96,4,0,''),(96,4,1,''),(96,5,0,''),(96,5,1,''),(96,6,0,''),(96,6,1,''),(96,7,0,''),(96,7,1,''),(96,8,0,''),(96,8,1,''),(96,9,0,''),(96,9,1,''),(96,10,0,''),(96,10,1,''),(96,11,0,''),(96,11,1,''),(97,1,0,''),(97,1,1,''),(97,2,0,''),(97,2,1,''),(97,3,0,''),(97,3,1,''),(97,4,0,''),(97,4,1,''),(97,5,0,''),(97,5,1,''),(97,6,0,''),(97,6,1,''),(97,7,0,''),(97,7,1,''),(97,8,0,''),(97,8,1,''),(97,9,0,''),(97,9,1,''),(97,10,0,''),(97,10,1,''),(97,11,0,''),(97,11,1,''),(98,1,0,''),(98,1,1,''),(98,2,0,''),(98,2,1,''),(98,3,0,''),(98,3,1,''),(98,4,0,''),(98,4,1,''),(98,5,0,''),(98,5,1,''),(98,6,0,''),(98,6,1,''),(98,7,0,''),(98,7,1,''),(98,8,0,''),(98,8,1,''),(98,9,0,''),(98,9,1,''),(98,10,0,''),(98,10,1,''),(98,11,0,''),(98,11,1,''),(99,1,0,''),(99,1,1,''),(99,2,0,''),(99,2,1,''),(99,3,0,''),(99,3,1,''),(99,4,0,''),(99,4,1,''),(99,5,0,''),(99,5,1,''),(99,6,0,''),(99,6,1,''),(99,7,0,''),(99,7,1,''),(99,8,0,''),(99,8,1,''),(99,9,0,''),(99,9,1,''),(99,10,0,''),(99,10,1,''),(99,11,0,''),(99,11,1,''),(100,1,0,''),(100,1,1,''),(100,2,0,''),(100,2,1,''),(100,3,0,''),(100,3,1,''),(100,4,0,''),(100,4,1,''),(100,5,0,''),(100,5,1,''),(100,6,0,''),(100,6,1,''),(100,7,0,''),(100,7,1,''),(100,8,0,''),(100,8,1,''),(100,9,0,''),(100,9,1,''),(100,10,0,''),(100,10,1,''),(100,11,0,''),(100,11,1,''),(101,1,0,''),(101,1,1,''),(101,2,0,''),(101,2,1,''),(101,3,0,''),(101,3,1,''),(101,4,0,''),(101,4,1,''),(101,5,0,''),(101,5,1,''),(101,6,0,''),(101,6,1,''),(101,7,0,''),(101,7,1,''),(101,8,0,''),(101,8,1,''),(101,9,0,''),(101,9,1,''),(101,10,0,''),(101,10,1,''),(101,11,0,''),(101,11,1,''),(102,1,0,''),(102,1,1,''),(102,2,0,''),(102,2,1,''),(102,3,0,''),(102,3,1,''),(102,4,0,''),(102,4,1,''),(102,5,0,''),(102,5,1,''),(102,6,0,''),(102,6,1,''),(102,7,0,''),(102,7,1,''),(102,8,0,''),(102,8,1,''),(102,9,0,''),(102,9,1,''),(102,10,0,''),(102,10,1,''),(102,11,0,''),(102,11,1,''),(103,1,0,''),(103,1,1,''),(103,2,0,''),(103,2,1,''),(103,3,0,''),(103,3,1,''),(103,4,0,''),(103,4,1,''),(103,5,0,''),(103,5,1,''),(103,6,0,''),(103,6,1,''),(103,7,0,''),(103,7,1,''),(103,8,0,''),(103,8,1,''),(103,9,0,''),(103,9,1,''),(103,10,0,''),(103,10,1,''),(103,11,0,''),(103,11,1,''),(104,1,0,''),(104,1,1,''),(104,2,0,''),(104,2,1,''),(104,3,0,''),(104,3,1,''),(104,4,0,''),(104,4,1,''),(104,5,0,''),(104,5,1,''),(104,6,0,''),(104,6,1,''),(104,7,0,''),(104,7,1,''),(104,8,0,''),(104,8,1,''),(104,9,0,''),(104,9,1,''),(104,10,0,''),(104,10,1,''),(104,11,0,''),(104,11,1,''),(105,1,0,''),(105,1,1,''),(105,2,0,''),(105,2,1,''),(105,3,0,''),(105,3,1,''),(105,4,0,''),(105,4,1,''),(105,5,0,''),(105,5,1,''),(105,6,0,''),(105,6,1,''),(105,7,0,''),(105,7,1,''),(105,8,0,''),(105,8,1,''),(105,9,0,''),(105,9,1,''),(105,10,0,''),(105,10,1,''),(105,11,0,''),(105,11,1,''),(106,1,0,''),(106,1,1,''),(106,2,0,''),(106,2,1,''),(106,3,0,''),(106,3,1,''),(106,4,0,''),(106,4,1,''),(106,5,0,''),(106,5,1,''),(106,6,0,''),(106,6,1,''),(106,7,0,''),(106,7,1,''),(106,8,0,''),(106,8,1,''),(106,9,0,''),(106,9,1,''),(106,10,0,''),(106,10,1,''),(106,11,0,''),(106,11,1,''),(107,1,0,''),(107,1,1,''),(107,2,0,''),(107,2,1,''),(107,3,0,''),(107,3,1,''),(107,4,0,''),(107,4,1,''),(107,5,0,''),(107,5,1,''),(107,6,0,''),(107,6,1,''),(107,7,0,''),(107,7,1,''),(107,8,0,''),(107,8,1,''),(107,9,0,''),(107,9,1,''),(107,10,0,''),(107,10,1,''),(107,11,0,''),(107,11,1,''),(108,1,0,''),(108,1,1,''),(108,2,0,''),(108,2,1,''),(108,3,0,''),(108,3,1,''),(108,4,0,''),(108,4,1,''),(108,5,0,''),(108,5,1,''),(108,6,0,''),(108,6,1,''),(108,7,0,''),(108,7,1,''),(108,8,0,''),(108,8,1,''),(108,9,0,''),(108,9,1,''),(108,10,0,''),(108,10,1,''),(108,11,0,''),(108,11,1,''),(109,1,0,''),(109,1,1,''),(109,2,0,''),(109,2,1,''),(109,3,0,''),(109,3,1,''),(109,4,0,''),(109,4,1,''),(109,5,0,''),(109,5,1,''),(109,6,0,''),(109,6,1,''),(109,7,0,''),(109,7,1,''),(109,8,0,''),(109,8,1,''),(109,9,0,''),(109,9,1,''),(109,10,0,''),(109,10,1,''),(109,11,0,''),(109,11,1,''),(110,1,0,''),(110,1,1,''),(110,2,0,''),(110,2,1,''),(110,3,0,''),(110,3,1,''),(110,4,0,''),(110,4,1,''),(110,5,0,''),(110,5,1,''),(110,6,0,''),(110,6,1,''),(110,7,0,''),(110,7,1,''),(110,8,0,''),(110,8,1,''),(110,9,0,''),(110,9,1,''),(110,10,0,''),(110,10,1,''),(110,11,0,''),(110,11,1,''),(111,1,0,''),(111,1,1,''),(111,2,0,''),(111,2,1,''),(111,3,0,''),(111,3,1,''),(111,4,0,''),(111,4,1,''),(111,5,0,''),(111,5,1,''),(111,6,0,''),(111,6,1,''),(111,7,0,''),(111,7,1,''),(111,8,0,''),(111,8,1,''),(111,9,0,''),(111,9,1,''),(111,10,0,''),(111,10,1,''),(111,11,0,''),(111,11,1,''),(112,1,0,''),(112,1,1,''),(112,2,0,''),(112,2,1,''),(112,3,0,''),(112,3,1,''),(112,4,0,''),(112,4,1,''),(112,5,0,''),(112,5,1,''),(112,6,0,''),(112,6,1,''),(112,7,0,''),(112,7,1,''),(112,8,0,''),(112,8,1,''),(112,9,0,''),(112,9,1,''),(112,10,0,''),(112,10,1,''),(112,11,0,''),(112,11,1,''),(113,1,0,''),(113,1,1,''),(113,2,0,''),(113,2,1,''),(113,3,0,''),(113,3,1,''),(113,4,0,''),(113,4,1,''),(113,5,0,''),(113,5,1,''),(113,6,0,''),(113,6,1,''),(113,7,0,''),(113,7,1,''),(113,8,0,''),(113,8,1,''),(113,9,0,''),(113,9,1,''),(113,10,0,''),(113,10,1,''),(113,11,0,''),(113,11,1,''),(114,1,0,''),(114,1,1,''),(114,2,0,''),(114,2,1,''),(114,3,0,''),(114,3,1,''),(114,4,0,''),(114,4,1,''),(114,5,0,''),(114,5,1,''),(114,6,0,''),(114,6,1,''),(114,7,0,''),(114,7,1,''),(114,8,0,''),(114,8,1,''),(114,9,0,''),(114,9,1,''),(114,10,0,''),(114,10,1,''),(114,11,0,''),(114,11,1,''),(115,1,0,''),(115,1,1,''),(115,2,0,''),(115,2,1,''),(115,3,0,''),(115,3,1,''),(115,4,0,''),(115,4,1,''),(115,5,0,''),(115,5,1,''),(115,6,0,''),(115,6,1,''),(115,7,0,''),(115,7,1,''),(115,8,0,''),(115,8,1,''),(115,9,0,''),(115,9,1,''),(115,10,0,''),(115,10,1,''),(115,11,0,''),(115,11,1,''),(116,1,0,''),(116,1,1,''),(116,2,0,''),(116,2,1,''),(116,3,0,''),(116,3,1,''),(116,4,0,''),(116,4,1,''),(116,5,0,''),(116,5,1,''),(116,6,0,''),(116,6,1,''),(116,7,0,''),(116,7,1,''),(116,8,0,''),(116,8,1,''),(116,9,0,''),(116,9,1,''),(116,10,0,''),(116,10,1,''),(116,11,0,''),(116,11,1,''),(117,1,0,''),(117,1,1,''),(117,2,0,''),(117,2,1,''),(117,3,0,''),(117,3,1,''),(117,4,0,''),(117,4,1,''),(117,5,0,''),(117,5,1,''),(117,6,0,''),(117,6,1,''),(117,7,0,''),(117,7,1,''),(117,8,0,''),(117,8,1,''),(117,9,0,''),(117,9,1,''),(117,10,0,''),(117,10,1,''),(117,11,0,''),(117,11,1,''),(118,1,0,''),(118,1,1,''),(118,2,0,''),(118,2,1,''),(118,3,0,''),(118,3,1,''),(118,4,0,''),(118,4,1,''),(118,5,0,''),(118,5,1,''),(118,6,0,''),(118,6,1,''),(118,7,0,''),(118,7,1,''),(118,8,0,''),(118,8,1,''),(118,9,0,''),(118,9,1,''),(118,10,0,''),(118,10,1,''),(118,11,0,''),(118,11,1,''),(119,1,0,''),(119,1,1,''),(119,2,0,''),(119,2,1,''),(119,3,0,''),(119,3,1,''),(119,4,0,''),(119,4,1,''),(119,5,0,''),(119,5,1,''),(119,6,0,''),(119,6,1,''),(119,7,0,''),(119,7,1,''),(119,8,0,''),(119,8,1,''),(119,9,0,''),(119,9,1,''),(119,10,0,''),(119,10,1,''),(119,11,0,''),(119,11,1,''),(120,1,0,''),(120,1,1,''),(120,2,0,''),(120,2,1,''),(120,3,0,''),(120,3,1,''),(120,4,0,''),(120,4,1,''),(120,5,0,''),(120,5,1,''),(120,6,0,''),(120,6,1,''),(120,7,0,''),(120,7,1,''),(120,8,0,''),(120,8,1,''),(120,9,0,''),(120,9,1,''),(120,10,0,''),(120,10,1,''),(120,11,0,''),(120,11,1,''),(121,1,0,''),(121,1,1,''),(121,2,0,''),(121,2,1,''),(121,3,0,''),(121,3,1,''),(121,4,0,''),(121,4,1,''),(121,5,0,''),(121,5,1,''),(121,6,0,''),(121,6,1,''),(121,7,0,''),(121,7,1,''),(121,8,0,''),(121,8,1,''),(121,9,0,''),(121,9,1,''),(121,10,0,''),(121,10,1,''),(121,11,0,''),(121,11,1,''),(122,1,0,''),(122,1,1,''),(122,2,0,''),(122,2,1,''),(122,3,0,''),(122,3,1,''),(122,4,0,''),(122,4,1,''),(122,5,0,''),(122,5,1,''),(122,6,0,''),(122,6,1,''),(122,7,0,''),(122,7,1,''),(122,8,0,''),(122,8,1,''),(122,9,0,''),(122,9,1,''),(122,10,0,''),(122,10,1,''),(122,11,0,''),(122,11,1,''),(123,1,0,''),(123,1,1,''),(123,2,0,''),(123,2,1,''),(123,3,0,''),(123,3,1,''),(123,4,0,''),(123,4,1,''),(123,5,0,''),(123,5,1,''),(123,6,0,''),(123,6,1,''),(123,7,0,''),(123,7,1,''),(123,8,0,''),(123,8,1,''),(123,9,0,''),(123,9,1,''),(123,10,0,''),(123,10,1,''),(123,11,0,''),(123,11,1,''),(124,1,0,''),(124,1,1,''),(124,2,0,''),(124,2,1,''),(124,3,0,''),(124,3,1,''),(124,4,0,''),(124,4,1,''),(124,5,0,''),(124,5,1,''),(124,6,0,''),(124,6,1,''),(124,7,0,''),(124,7,1,''),(124,8,0,''),(124,8,1,''),(124,9,0,''),(124,9,1,''),(124,10,0,''),(124,10,1,''),(124,11,0,''),(124,11,1,''),(125,1,0,''),(125,1,1,''),(125,2,0,''),(125,2,1,''),(125,3,0,''),(125,3,1,''),(125,4,0,''),(125,4,1,''),(125,5,0,''),(125,5,1,''),(125,6,0,''),(125,6,1,''),(125,7,0,''),(125,7,1,''),(125,8,0,''),(125,8,1,''),(125,9,0,''),(125,9,1,''),(125,10,0,''),(125,10,1,''),(125,11,0,''),(125,11,1,''),(126,1,0,''),(126,1,1,''),(126,2,0,''),(126,2,1,''),(126,3,0,''),(126,3,1,''),(126,4,0,''),(126,4,1,''),(126,5,0,''),(126,5,1,''),(126,6,0,''),(126,6,1,''),(126,7,0,''),(126,7,1,''),(126,8,0,''),(126,8,1,''),(126,9,0,''),(126,9,1,''),(126,10,0,''),(126,10,1,''),(126,11,0,''),(126,11,1,''),(127,1,0,''),(127,1,1,''),(127,2,0,''),(127,2,1,''),(127,3,0,''),(127,3,1,''),(127,4,0,''),(127,4,1,''),(127,5,0,''),(127,5,1,''),(127,6,0,''),(127,6,1,''),(127,7,0,''),(127,7,1,''),(127,8,0,''),(127,8,1,''),(127,9,0,''),(127,9,1,''),(127,10,0,''),(127,10,1,''),(127,11,0,''),(127,11,1,''),(128,1,0,''),(128,1,1,''),(128,2,0,''),(128,2,1,''),(128,3,0,''),(128,3,1,''),(128,4,0,''),(128,4,1,''),(128,5,0,''),(128,5,1,''),(128,6,0,''),(128,6,1,''),(128,7,0,''),(128,7,1,''),(128,8,0,''),(128,8,1,''),(128,9,0,''),(128,9,1,''),(128,10,0,''),(128,10,1,''),(128,11,0,''),(128,11,1,''),(129,1,0,''),(129,1,1,''),(129,2,0,''),(129,2,1,''),(129,3,0,''),(129,3,1,''),(129,4,0,''),(129,4,1,''),(129,5,0,''),(129,5,1,''),(129,6,0,''),(129,6,1,''),(129,7,0,''),(129,7,1,''),(129,8,0,''),(129,8,1,''),(129,9,0,''),(129,9,1,''),(129,10,0,''),(129,10,1,''),(129,11,0,''),(129,11,1,''),(130,1,0,''),(130,1,1,''),(130,2,0,''),(130,2,1,''),(130,3,0,''),(130,3,1,''),(130,4,0,''),(130,4,1,''),(130,5,0,''),(130,5,1,''),(130,6,0,''),(130,6,1,''),(130,7,0,''),(130,7,1,''),(130,8,0,''),(130,8,1,''),(130,9,0,''),(130,9,1,''),(130,10,0,''),(130,10,1,''),(130,11,0,''),(130,11,1,''),(131,1,0,''),(131,1,1,''),(131,2,0,''),(131,2,1,''),(131,3,0,''),(131,3,1,''),(131,4,0,''),(131,4,1,''),(131,5,0,''),(131,5,1,''),(131,6,0,''),(131,6,1,''),(131,7,0,''),(131,7,1,''),(131,8,0,''),(131,8,1,''),(131,9,0,''),(131,9,1,''),(131,10,0,''),(131,10,1,''),(131,11,0,''),(131,11,1,''),(132,1,0,''),(132,1,1,''),(132,2,0,''),(132,2,1,''),(132,3,0,''),(132,3,1,''),(132,4,0,''),(132,4,1,''),(132,5,0,''),(132,5,1,''),(132,6,0,''),(132,6,1,''),(132,7,0,''),(132,7,1,''),(132,8,0,''),(132,8,1,''),(132,9,0,''),(132,9,1,''),(132,10,0,''),(132,10,1,''),(132,11,0,''),(132,11,1,''),(133,1,0,''),(133,1,1,''),(133,2,0,''),(133,2,1,''),(133,3,0,''),(133,3,1,''),(133,4,0,''),(133,4,1,''),(133,5,0,''),(133,5,1,''),(133,6,0,''),(133,6,1,''),(133,7,0,''),(133,7,1,''),(133,8,0,''),(133,8,1,''),(133,9,0,''),(133,9,1,''),(133,10,0,''),(133,10,1,''),(133,11,0,''),(133,11,1,''),(134,1,0,''),(134,1,1,''),(134,2,0,''),(134,2,1,''),(134,3,0,''),(134,3,1,''),(134,4,0,''),(134,4,1,''),(134,5,0,''),(134,5,1,''),(134,6,0,''),(134,6,1,''),(134,7,0,''),(134,7,1,''),(134,8,0,''),(134,8,1,''),(134,9,0,''),(134,9,1,''),(134,10,0,''),(134,10,1,''),(134,11,0,''),(134,11,1,''),(135,1,0,''),(135,1,1,''),(135,2,0,''),(135,2,1,''),(135,3,0,''),(135,3,1,''),(135,4,0,''),(135,4,1,''),(135,5,0,''),(135,5,1,''),(135,6,0,''),(135,6,1,''),(135,7,0,''),(135,7,1,''),(135,8,0,''),(135,8,1,''),(135,9,0,''),(135,9,1,''),(135,10,0,''),(135,10,1,''),(135,11,0,''),(135,11,1,''),(136,1,0,''),(136,1,1,''),(136,2,0,''),(136,2,1,''),(136,3,0,''),(136,3,1,''),(136,4,0,''),(136,4,1,''),(136,5,0,''),(136,5,1,''),(136,6,0,''),(136,6,1,''),(136,7,0,''),(136,7,1,''),(136,8,0,''),(136,8,1,''),(136,9,0,''),(136,9,1,''),(136,10,0,''),(136,10,1,''),(136,11,0,''),(136,11,1,''),(137,1,0,''),(137,1,1,''),(137,2,0,''),(137,2,1,''),(137,3,0,''),(137,3,1,''),(137,4,0,''),(137,4,1,''),(137,5,0,''),(137,5,1,''),(137,6,0,''),(137,6,1,''),(137,7,0,''),(137,7,1,''),(137,8,0,''),(137,8,1,''),(137,9,0,''),(137,9,1,''),(137,10,0,''),(137,10,1,''),(137,11,0,''),(137,11,1,''),(138,1,0,''),(138,1,1,''),(138,2,0,''),(138,2,1,''),(138,3,0,''),(138,3,1,''),(138,4,0,''),(138,4,1,''),(138,5,0,''),(138,5,1,''),(138,6,0,''),(138,6,1,''),(138,7,0,''),(138,7,1,''),(138,8,0,''),(138,8,1,''),(138,9,0,''),(138,9,1,''),(138,10,0,''),(138,10,1,''),(138,11,0,''),(138,11,1,''),(139,1,0,''),(139,1,1,''),(139,2,0,''),(139,2,1,''),(139,3,0,''),(139,3,1,''),(139,4,0,''),(139,4,1,''),(139,5,0,''),(139,5,1,''),(139,6,0,''),(139,6,1,''),(139,7,0,''),(139,7,1,''),(139,8,0,''),(139,8,1,''),(139,9,0,''),(139,9,1,''),(139,10,0,''),(139,10,1,''),(139,11,0,''),(139,11,1,''),(140,1,0,''),(140,1,1,''),(140,2,0,''),(140,2,1,''),(140,3,0,''),(140,3,1,''),(140,4,0,''),(140,4,1,''),(140,5,0,''),(140,5,1,''),(140,6,0,''),(140,6,1,''),(140,7,0,''),(140,7,1,''),(140,8,0,''),(140,8,1,''),(140,9,0,''),(140,9,1,''),(140,10,0,''),(140,10,1,''),(140,11,0,''),(140,11,1,''),(141,1,0,''),(141,1,1,''),(141,2,0,''),(141,2,1,''),(141,3,0,''),(141,3,1,''),(141,4,0,''),(141,4,1,''),(141,5,0,''),(141,5,1,''),(141,6,0,''),(141,6,1,''),(141,7,0,''),(141,7,1,''),(141,8,0,''),(141,8,1,''),(141,9,0,''),(141,9,1,''),(141,10,0,''),(141,10,1,''),(141,11,0,''),(141,11,1,''),(142,1,0,''),(142,1,1,''),(142,2,0,''),(142,2,1,''),(142,3,0,''),(142,3,1,''),(142,4,0,''),(142,4,1,''),(142,5,0,''),(142,5,1,''),(142,6,0,''),(142,6,1,''),(142,7,0,''),(142,7,1,''),(142,8,0,''),(142,8,1,''),(142,9,0,''),(142,9,1,''),(142,10,0,''),(142,10,1,''),(142,11,0,''),(142,11,1,''),(143,1,0,''),(143,1,1,''),(143,2,0,''),(143,2,1,''),(143,3,0,''),(143,3,1,''),(143,4,0,''),(143,4,1,''),(143,5,0,''),(143,5,1,''),(143,6,0,''),(143,6,1,''),(143,7,0,''),(143,7,1,''),(143,8,0,''),(143,8,1,''),(143,9,0,''),(143,9,1,''),(143,10,0,''),(143,10,1,''),(143,11,0,''),(143,11,1,''),(144,1,0,''),(144,1,1,''),(144,2,0,''),(144,2,1,''),(144,3,0,''),(144,3,1,''),(144,4,0,''),(144,4,1,''),(144,5,0,''),(144,5,1,''),(144,6,0,''),(144,6,1,''),(144,7,0,''),(144,7,1,''),(144,8,0,''),(144,8,1,''),(144,9,0,''),(144,9,1,''),(144,10,0,''),(144,10,1,''),(144,11,0,''),(144,11,1,''),(145,1,0,''),(145,1,1,''),(145,2,0,''),(145,2,1,''),(145,3,0,''),(145,3,1,''),(145,4,0,''),(145,4,1,''),(145,5,0,''),(145,5,1,''),(145,6,0,''),(145,6,1,''),(145,7,0,''),(145,7,1,''),(145,8,0,''),(145,8,1,''),(145,9,0,''),(145,9,1,''),(145,10,0,''),(145,10,1,''),(145,11,0,''),(145,11,1,''),(146,1,0,''),(146,1,1,''),(146,2,0,''),(146,2,1,''),(146,3,0,''),(146,3,1,''),(146,4,0,''),(146,4,1,''),(146,5,0,''),(146,5,1,''),(146,6,0,''),(146,6,1,''),(146,7,0,''),(146,7,1,''),(146,8,0,''),(146,8,1,''),(146,9,0,''),(146,9,1,''),(146,10,0,''),(146,10,1,''),(146,11,0,''),(146,11,1,''),(147,1,0,''),(147,1,1,''),(147,2,0,''),(147,2,1,''),(147,3,0,''),(147,3,1,''),(147,4,0,''),(147,4,1,''),(147,5,0,''),(147,5,1,''),(147,6,0,''),(147,6,1,''),(147,7,0,''),(147,7,1,''),(147,8,0,''),(147,8,1,''),(147,9,0,''),(147,9,1,''),(147,10,0,''),(147,10,1,''),(147,11,0,''),(147,11,1,''),(148,1,0,''),(148,1,1,''),(148,2,0,''),(148,2,1,''),(148,3,0,''),(148,3,1,''),(148,4,0,''),(148,4,1,''),(148,5,0,''),(148,5,1,''),(148,6,0,''),(148,6,1,''),(148,7,0,''),(148,7,1,''),(148,8,0,''),(148,8,1,''),(148,9,0,''),(148,9,1,''),(148,10,0,''),(148,10,1,''),(148,11,0,''),(148,11,1,''),(149,1,0,''),(149,1,1,''),(149,2,0,''),(149,2,1,''),(149,3,0,''),(149,3,1,''),(149,4,0,''),(149,4,1,''),(149,5,0,''),(149,5,1,''),(149,6,0,''),(149,6,1,''),(149,7,0,''),(149,7,1,''),(149,8,0,''),(149,8,1,''),(149,9,0,''),(149,9,1,''),(149,10,0,''),(149,10,1,''),(149,11,0,''),(149,11,1,''),(150,1,0,''),(150,1,1,''),(150,2,0,''),(150,2,1,''),(150,3,0,''),(150,3,1,''),(150,4,0,''),(150,4,1,''),(150,5,0,''),(150,5,1,''),(150,6,0,''),(150,6,1,''),(150,7,0,''),(150,7,1,''),(150,8,0,''),(150,8,1,''),(150,9,0,''),(150,9,1,''),(150,10,0,''),(150,10,1,''),(150,11,0,''),(150,11,1,''),(151,1,0,''),(151,1,1,''),(151,2,0,''),(151,2,1,''),(151,3,0,''),(151,3,1,''),(151,4,0,''),(151,4,1,''),(151,5,0,''),(151,5,1,''),(151,6,0,''),(151,6,1,''),(151,7,0,''),(151,7,1,''),(151,8,0,''),(151,8,1,''),(151,9,0,''),(151,9,1,''),(151,10,0,''),(151,10,1,''),(151,11,0,''),(151,11,1,''),(152,1,0,''),(152,1,1,''),(152,2,0,''),(152,2,1,''),(152,3,0,''),(152,3,1,''),(152,4,0,''),(152,4,1,''),(152,5,0,''),(152,5,1,''),(152,6,0,''),(152,6,1,''),(152,7,0,''),(152,7,1,''),(152,8,0,''),(152,8,1,''),(152,9,0,''),(152,9,1,''),(152,10,0,''),(152,10,1,''),(152,11,0,''),(152,11,1,''),(153,1,0,''),(153,1,1,''),(153,2,0,''),(153,2,1,''),(153,3,0,''),(153,3,1,''),(153,4,0,''),(153,4,1,''),(153,5,0,''),(153,5,1,''),(153,6,0,''),(153,6,1,''),(153,7,0,''),(153,7,1,''),(153,8,0,''),(153,8,1,''),(153,9,0,''),(153,9,1,''),(153,10,0,''),(153,10,1,''),(153,11,0,''),(153,11,1,''),(154,1,0,''),(154,1,1,''),(154,2,0,''),(154,2,1,''),(154,3,0,''),(154,3,1,''),(154,4,0,''),(154,4,1,''),(154,5,0,''),(154,5,1,''),(154,6,0,''),(154,6,1,''),(154,7,0,''),(154,7,1,''),(154,8,0,''),(154,8,1,''),(154,9,0,''),(154,9,1,''),(154,10,0,''),(154,10,1,''),(154,11,0,''),(154,11,1,''),(155,1,0,''),(155,1,1,''),(155,2,0,''),(155,2,1,''),(155,3,0,''),(155,3,1,''),(155,4,0,''),(155,4,1,''),(155,5,0,''),(155,5,1,''),(155,6,0,''),(155,6,1,''),(155,7,0,''),(155,7,1,''),(155,8,0,''),(155,8,1,''),(155,9,0,''),(155,9,1,''),(155,10,0,''),(155,10,1,''),(155,11,0,''),(155,11,1,''),(156,1,0,''),(156,1,1,''),(156,2,0,''),(156,2,1,''),(156,3,0,''),(156,3,1,''),(156,4,0,''),(156,4,1,''),(156,5,0,''),(156,5,1,''),(156,6,0,''),(156,6,1,''),(156,7,0,''),(156,7,1,''),(156,8,0,''),(156,8,1,''),(156,9,0,''),(156,9,1,''),(156,10,0,''),(156,10,1,''),(156,11,0,''),(156,11,1,''),(157,1,0,''),(157,1,1,''),(157,2,0,''),(157,2,1,''),(157,3,0,''),(157,3,1,''),(157,4,0,''),(157,4,1,''),(157,5,0,''),(157,5,1,''),(157,6,0,''),(157,6,1,''),(157,7,0,''),(157,7,1,''),(157,8,0,''),(157,8,1,''),(157,9,0,''),(157,9,1,''),(157,10,0,''),(157,10,1,''),(157,11,0,''),(157,11,1,''),(158,1,0,''),(158,1,1,''),(158,2,0,''),(158,2,1,''),(158,3,0,''),(158,3,1,''),(158,4,0,''),(158,4,1,''),(158,5,0,''),(158,5,1,''),(158,6,0,''),(158,6,1,''),(158,7,0,''),(158,7,1,''),(158,8,0,''),(158,8,1,''),(158,9,0,''),(158,9,1,''),(158,10,0,''),(158,10,1,''),(158,11,0,''),(158,11,1,''),(159,1,0,''),(159,1,1,''),(159,2,0,''),(159,2,1,''),(159,3,0,''),(159,3,1,''),(159,4,0,''),(159,4,1,''),(159,5,0,''),(159,5,1,''),(159,6,0,''),(159,6,1,''),(159,7,0,''),(159,7,1,''),(159,8,0,''),(159,8,1,''),(159,9,0,''),(159,9,1,''),(159,10,0,''),(159,10,1,''),(159,11,0,''),(159,11,1,''),(160,1,0,''),(160,1,1,''),(160,2,0,''),(160,2,1,''),(160,3,0,''),(160,3,1,''),(160,4,0,''),(160,4,1,''),(160,5,0,''),(160,5,1,''),(160,6,0,''),(160,6,1,''),(160,7,0,''),(160,7,1,''),(160,8,0,''),(160,8,1,''),(160,9,0,''),(160,9,1,''),(160,10,0,''),(160,10,1,''),(160,11,0,''),(160,11,1,''),(161,1,0,''),(161,1,1,''),(161,2,0,''),(161,2,1,''),(161,3,0,''),(161,3,1,''),(161,4,0,''),(161,4,1,''),(161,5,0,''),(161,5,1,''),(161,6,0,''),(161,6,1,''),(161,7,0,''),(161,7,1,''),(161,8,0,''),(161,8,1,''),(161,9,0,''),(161,9,1,''),(161,10,0,''),(161,10,1,''),(161,11,0,''),(161,11,1,''),(162,1,0,''),(162,1,1,''),(162,2,0,''),(162,2,1,''),(162,3,0,''),(162,3,1,''),(162,4,0,''),(162,4,1,''),(162,5,0,''),(162,5,1,''),(162,6,0,''),(162,6,1,''),(162,7,0,''),(162,7,1,''),(162,8,0,''),(162,8,1,''),(162,9,0,''),(162,9,1,''),(162,10,0,''),(162,10,1,''),(162,11,0,''),(162,11,1,''),(163,1,0,''),(163,1,1,''),(163,2,0,''),(163,2,1,''),(163,3,0,''),(163,3,1,''),(163,4,0,''),(163,4,1,''),(163,5,0,''),(163,5,1,''),(163,6,0,''),(163,6,1,''),(163,7,0,''),(163,7,1,''),(163,8,0,''),(163,8,1,''),(163,9,0,''),(163,9,1,''),(163,10,0,''),(163,10,1,''),(163,11,0,''),(163,11,1,''),(164,1,0,''),(164,1,1,''),(164,2,0,''),(164,2,1,''),(164,3,0,''),(164,3,1,''),(164,4,0,''),(164,4,1,''),(164,5,0,''),(164,5,1,''),(164,6,0,''),(164,6,1,''),(164,7,0,''),(164,7,1,''),(164,8,0,''),(164,8,1,''),(164,9,0,''),(164,9,1,''),(164,10,0,''),(164,10,1,''),(164,11,0,''),(164,11,1,'');
/*!40000 ALTER TABLE `products_images_external_url` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_images_inventory`
--

DROP TABLE IF EXISTS `products_images_inventory`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_images_inventory` (
  `products_images_id` int(11) NOT NULL,
  `inventory_id` int(11) NOT NULL,
  PRIMARY KEY (`products_images_id`,`inventory_id`),
  KEY `inventory_id` (`inventory_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_images_inventory`
--

LOCK TABLES `products_images_inventory` WRITE;
/*!40000 ALTER TABLE `products_images_inventory` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_images_inventory` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_notes`
--

DROP TABLE IF EXISTS `products_notes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_notes` (
  `products_notes_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` int(11) DEFAULT NULL,
  `note` text,
  `updated_at` int(11) DEFAULT NULL,
  `created_at` int(11) DEFAULT NULL,
  PRIMARY KEY (`products_notes_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_notes`
--

LOCK TABLES `products_notes` WRITE;
/*!40000 ALTER TABLE `products_notes` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_notes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_notifications`
--

DROP TABLE IF EXISTS `products_notifications`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_notifications` (
  `products_id` int(11) NOT NULL DEFAULT '0',
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `date_added` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (`products_id`,`customers_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_notifications`
--

LOCK TABLES `products_notifications` WRITE;
/*!40000 ALTER TABLE `products_notifications` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_notifications` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_notify`
--

DROP TABLE IF EXISTS `products_notify`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_notify` (
  `products_notify_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_notify_products_id` varchar(255) DEFAULT NULL,
  `products_notify_email` varchar(64) DEFAULT NULL,
  `products_notify_name` varchar(64) DEFAULT NULL,
  `products_notify_customers_id` int(11) DEFAULT NULL,
  `products_notify_date` datetime DEFAULT NULL,
  `products_notify_sent` datetime DEFAULT NULL,
  `suppliers_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '1',
  PRIMARY KEY (`products_notify_id`),
  KEY `i_products_notify_email` (`products_notify_email`),
  KEY `idx_products_notify` (`products_notify_products_id`,`suppliers_id`,`products_notify_email`,`products_notify_sent`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_notify`
--

LOCK TABLES `products_notify` WRITE;
/*!40000 ALTER TABLE `products_notify` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_notify` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_options`
--

DROP TABLE IF EXISTS `products_options`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_options` (
  `products_options_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '1',
  `products_options_name` varchar(32) NOT NULL DEFAULT '',
  `products_options_sort_order` int(4) NOT NULL DEFAULT '0',
  `type` varchar(16) NOT NULL DEFAULT '',
  `products_options_image` varchar(32) NOT NULL DEFAULT '',
  `products_options_color` varchar(8) NOT NULL DEFAULT '',
  `is_virtual` tinyint(32) NOT NULL DEFAULT '0',
  `display_filter` tinyint(1) NOT NULL DEFAULT '1',
  `display_search` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`products_options_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_options`
--

LOCK TABLES `products_options` WRITE;
/*!40000 ALTER TABLE `products_options` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_options` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_options_values`
--

DROP TABLE IF EXISTS `products_options_values`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_options_values` (
  `products_options_values_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '1',
  `products_options_values_name` varchar(64) NOT NULL DEFAULT '',
  `products_options_values_sort_order` int(11) NOT NULL DEFAULT '0',
  `products_options_values_image` varchar(32) NOT NULL DEFAULT '',
  `products_options_values_color` varchar(8) NOT NULL DEFAULT '',
  `products_options_values_name_alias` varchar(255) NOT NULL DEFAULT '',
  `custom_input_type` tinyint(2) DEFAULT NULL,
  PRIMARY KEY (`products_options_values_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_options_values`
--

LOCK TABLES `products_options_values` WRITE;
/*!40000 ALTER TABLE `products_options_values` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_options_values` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_options_values_to_products_options`
--

DROP TABLE IF EXISTS `products_options_values_to_products_options`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_options_values_to_products_options` (
  `products_options_values_to_products_options_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_options_id` int(11) NOT NULL DEFAULT '0',
  `products_options_values_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`products_options_values_to_products_options_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_options_values_to_products_options`
--

LOCK TABLES `products_options_values_to_products_options` WRITE;
/*!40000 ALTER TABLE `products_options_values_to_products_options` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_options_values_to_products_options` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_popularity`
--

DROP TABLE IF EXISTS `products_popularity`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_popularity` (
  `products_id` int(11) NOT NULL,
  `products_viewed` int(11) DEFAULT NULL,
  `viewed_date` date NOT NULL,
  PRIMARY KEY (`products_id`,`viewed_date`),
  KEY `idx_viewed_date` (`viewed_date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_popularity`
--

LOCK TABLES `products_popularity` WRITE;
/*!40000 ALTER TABLE `products_popularity` DISABLE KEYS */;
INSERT INTO `products_popularity` VALUES (1,5,'2022-07-06'),(1,2,'2022-07-07'),(1,1,'2022-07-15'),(1,3,'2022-07-18'),(1,2,'2022-07-21'),(1,2,'2022-07-22'),(1,1,'2022-07-24'),(2,1,'2022-07-02'),(2,6,'2022-07-06'),(2,2,'2022-07-07'),(2,2,'2022-07-08'),(2,3,'2022-07-18'),(2,1,'2022-07-23'),(2,2,'2022-07-25'),(3,1,'2022-07-02'),(3,1,'2022-07-03'),(3,2,'2022-07-04'),(3,3,'2022-07-05'),(3,5,'2022-07-06'),(3,1,'2022-07-07'),(3,4,'2022-07-08'),(3,3,'2022-07-18'),(3,1,'2022-07-23'),(4,1,'2022-06-29'),(4,1,'2022-07-01'),(4,1,'2022-07-03'),(4,2,'2022-07-04'),(4,2,'2022-07-05'),(4,5,'2022-07-06'),(4,4,'2022-07-07'),(4,1,'2022-07-15'),(4,3,'2022-07-18'),(5,1,'2022-07-06'),(5,1,'2022-07-23'),(6,1,'2022-07-06'),(6,1,'2022-07-07'),(6,1,'2022-07-25'),(7,1,'2022-07-01'),(7,2,'2022-07-03'),(7,1,'2022-07-04'),(7,2,'2022-07-05'),(7,6,'2022-07-06'),(7,2,'2022-07-07'),(7,3,'2022-07-18'),(7,1,'2022-07-21'),(8,1,'2022-07-03'),(8,1,'2022-07-06'),(9,2,'2022-06-26'),(9,1,'2022-06-27'),(9,2,'2022-06-28'),(9,1,'2022-06-29'),(9,2,'2022-07-01'),(9,5,'2022-07-06'),(9,2,'2022-07-07'),(9,3,'2022-07-18'),(9,1,'2022-07-21'),(9,2,'2022-07-23'),(9,3,'2022-07-25'),(10,4,'2022-07-06'),(10,1,'2022-07-07'),(10,2,'2022-07-08'),(10,3,'2022-07-18'),(10,1,'2022-07-23'),(10,1,'2022-07-25'),(11,4,'2022-07-06'),(11,1,'2022-07-07'),(11,2,'2022-07-08'),(11,3,'2022-07-18'),(11,1,'2022-07-24'),(12,1,'2022-07-04'),(12,1,'2022-07-06'),(13,4,'2022-07-06'),(13,1,'2022-07-07'),(13,2,'2022-07-08'),(13,3,'2022-07-18'),(13,1,'2022-07-21'),(13,1,'2022-07-22'),(13,1,'2022-07-23'),(13,1,'2022-07-25'),(14,1,'2022-06-29'),(14,2,'2022-07-02'),(14,2,'2022-07-04'),(14,4,'2022-07-06'),(14,1,'2022-07-07'),(14,2,'2022-07-08'),(14,3,'2022-07-18'),(14,1,'2022-07-24'),(15,1,'2022-07-05'),(15,5,'2022-07-06'),(15,3,'2022-07-07'),(15,1,'2022-07-13'),(15,3,'2022-07-18'),(15,4,'2022-07-23'),(15,1,'2022-07-25'),(16,1,'2022-07-03'),(16,1,'2022-07-05'),(16,4,'2022-07-06'),(16,1,'2022-07-07'),(16,2,'2022-07-08'),(16,3,'2022-07-18'),(16,1,'2022-07-23'),(16,1,'2022-07-24'),(16,1,'2022-07-25'),(17,2,'2022-06-27'),(17,2,'2022-06-29'),(17,1,'2022-07-04'),(17,4,'2022-07-06'),(17,1,'2022-07-07'),(17,3,'2022-07-08'),(17,1,'2022-07-16'),(17,3,'2022-07-18'),(17,1,'2022-07-23'),(18,5,'2022-07-06'),(18,2,'2022-07-07'),(18,1,'2022-07-08'),(18,3,'2022-07-18'),(18,1,'2022-07-21'),(18,2,'2022-07-25'),(19,1,'2022-07-06'),(19,1,'2022-07-22'),(19,1,'2022-07-25'),(20,1,'2022-07-05'),(20,1,'2022-07-06'),(20,1,'2022-07-07'),(21,1,'2022-07-02'),(21,1,'2022-07-05'),(21,4,'2022-07-06'),(21,1,'2022-07-07'),(21,3,'2022-07-08'),(21,3,'2022-07-11'),(21,3,'2022-07-18'),(21,2,'2022-07-23'),(21,1,'2022-07-25'),(22,5,'2022-07-06'),(22,2,'2022-07-07'),(22,3,'2022-07-18'),(22,1,'2022-07-19'),(22,3,'2022-07-21'),(22,2,'2022-07-23'),(22,2,'2022-07-24'),(22,2,'2022-07-25'),(23,2,'2022-06-26'),(23,1,'2022-06-27'),(23,1,'2022-06-30'),(23,5,'2022-07-06'),(23,2,'2022-07-07'),(23,1,'2022-07-17'),(23,3,'2022-07-18'),(23,1,'2022-07-19'),(23,1,'2022-07-21'),(23,3,'2022-07-23'),(23,2,'2022-07-24'),(23,1,'2022-07-25'),(24,2,'2022-06-26'),(24,1,'2022-06-27'),(24,2,'2022-06-30'),(24,5,'2022-07-06'),(24,3,'2022-07-07'),(24,3,'2022-07-18'),(24,2,'2022-07-23'),(24,1,'2022-07-24'),(24,3,'2022-07-25'),(25,1,'2022-07-03'),(25,1,'2022-07-05'),(25,8,'2022-07-06'),(25,3,'2022-07-07'),(25,3,'2022-07-08'),(25,3,'2022-07-18'),(25,1,'2022-07-23'),(25,2,'2022-07-25'),(26,2,'2022-07-05'),(26,5,'2022-07-06'),(26,3,'2022-07-07'),(26,3,'2022-07-18'),(26,2,'2022-07-23'),(26,2,'2022-07-25'),(27,1,'2022-06-29'),(27,1,'2022-07-01'),(27,5,'2022-07-06'),(27,3,'2022-07-07'),(27,3,'2022-07-18'),(27,1,'2022-07-20'),(27,1,'2022-07-22'),(27,1,'2022-07-23'),(27,4,'2022-07-24'),(27,1,'2022-07-25'),(28,1,'2022-06-27'),(28,1,'2022-07-05'),(28,5,'2022-07-06'),(28,2,'2022-07-07'),(28,4,'2022-07-18'),(28,2,'2022-07-20'),(28,1,'2022-07-22'),(28,2,'2022-07-23'),(28,3,'2022-07-25'),(29,3,'2022-06-27'),(29,2,'2022-06-28'),(29,3,'2022-06-29'),(29,2,'2022-06-30'),(29,1,'2022-07-04'),(29,5,'2022-07-06'),(29,3,'2022-07-07'),(29,1,'2022-07-13'),(29,3,'2022-07-18'),(29,1,'2022-07-19'),(29,1,'2022-07-23'),(29,1,'2022-07-24'),(29,2,'2022-07-25'),(30,1,'2022-06-27'),(30,1,'2022-06-29'),(30,3,'2022-07-01'),(30,4,'2022-07-06'),(30,1,'2022-07-07'),(30,2,'2022-07-08'),(30,3,'2022-07-18'),(30,1,'2022-07-21'),(30,1,'2022-07-22'),(30,2,'2022-07-25'),(31,1,'2022-07-03'),(31,1,'2022-07-04'),(31,1,'2022-07-05'),(31,6,'2022-07-06'),(31,3,'2022-07-07'),(31,3,'2022-07-08'),(31,3,'2022-07-18'),(31,1,'2022-07-25'),(32,4,'2022-07-06'),(32,1,'2022-07-07'),(32,2,'2022-07-08'),(32,1,'2022-07-17'),(32,3,'2022-07-18'),(32,2,'2022-07-22'),(32,1,'2022-07-24'),(32,5,'2022-07-25'),(33,1,'2022-07-05'),(33,4,'2022-07-06'),(33,2,'2022-07-07'),(33,2,'2022-07-08'),(33,1,'2022-07-15'),(33,6,'2022-07-18'),(33,3,'2022-07-20'),(33,1,'2022-07-24'),(33,1,'2022-07-25'),(34,1,'2022-07-03'),(34,4,'2022-07-06'),(34,1,'2022-07-07'),(34,2,'2022-07-08'),(34,1,'2022-07-13'),(34,3,'2022-07-16'),(34,6,'2022-07-18'),(34,1,'2022-07-20'),(34,1,'2022-07-22'),(34,1,'2022-07-23'),(34,1,'2022-07-25'),(35,4,'2022-07-06'),(35,2,'2022-07-07'),(35,2,'2022-07-08'),(35,1,'2022-07-15'),(35,4,'2022-07-17'),(35,3,'2022-07-18'),(35,3,'2022-07-19'),(35,2,'2022-07-21'),(35,1,'2022-07-23'),(36,1,'2022-07-03'),(36,1,'2022-07-04'),(36,1,'2022-07-05'),(36,5,'2022-07-06'),(36,1,'2022-07-07'),(36,2,'2022-07-08'),(36,3,'2022-07-18'),(36,1,'2022-07-23'),(37,4,'2022-07-06'),(37,1,'2022-07-07'),(37,2,'2022-07-08'),(37,1,'2022-07-14'),(37,3,'2022-07-17'),(37,3,'2022-07-18'),(37,2,'2022-07-20'),(37,1,'2022-07-24'),(38,1,'2022-07-03'),(38,5,'2022-07-06'),(38,1,'2022-07-07'),(38,3,'2022-07-08'),(38,1,'2022-07-11'),(38,2,'2022-07-15'),(38,2,'2022-07-17'),(38,4,'2022-07-18'),(38,2,'2022-07-19'),(38,1,'2022-07-20'),(38,6,'2022-07-25'),(39,4,'2022-07-06'),(39,1,'2022-07-07'),(39,3,'2022-07-08'),(39,3,'2022-07-13'),(39,3,'2022-07-18'),(39,1,'2022-07-21'),(40,1,'2022-07-03'),(40,4,'2022-07-06'),(40,1,'2022-07-07'),(40,3,'2022-07-08'),(40,1,'2022-07-11'),(40,2,'2022-07-12'),(40,1,'2022-07-13'),(40,3,'2022-07-18'),(40,2,'2022-07-21'),(41,1,'2022-07-03'),(41,1,'2022-07-05'),(41,4,'2022-07-06'),(41,1,'2022-07-07'),(41,4,'2022-07-08'),(41,1,'2022-07-09'),(41,1,'2022-07-10'),(41,2,'2022-07-11'),(41,3,'2022-07-18'),(41,1,'2022-07-20'),(41,1,'2022-07-21'),(41,1,'2022-07-25'),(42,4,'2022-07-06'),(42,1,'2022-07-07'),(42,2,'2022-07-08'),(42,1,'2022-07-14'),(42,3,'2022-07-17'),(42,3,'2022-07-18'),(42,2,'2022-07-19'),(42,1,'2022-07-20'),(42,1,'2022-07-23'),(42,1,'2022-07-25'),(43,1,'2022-07-04'),(43,4,'2022-07-06'),(43,1,'2022-07-07'),(43,2,'2022-07-08'),(43,1,'2022-07-15'),(43,4,'2022-07-18'),(43,2,'2022-07-19'),(43,1,'2022-07-20'),(43,2,'2022-07-21'),(43,1,'2022-07-22'),(43,1,'2022-07-24'),(43,2,'2022-07-25'),(44,1,'2022-07-03'),(44,1,'2022-07-05'),(44,6,'2022-07-06'),(44,1,'2022-07-07'),(44,4,'2022-07-08'),(44,1,'2022-07-09'),(44,2,'2022-07-10'),(44,3,'2022-07-18'),(44,1,'2022-07-21'),(44,1,'2022-07-23'),(44,1,'2022-07-25'),(45,4,'2022-07-06'),(45,1,'2022-07-07'),(45,2,'2022-07-08'),(45,1,'2022-07-16'),(45,4,'2022-07-18'),(45,1,'2022-07-20'),(45,1,'2022-07-24'),(45,1,'2022-07-25'),(46,1,'2022-07-03'),(46,1,'2022-07-05'),(46,4,'2022-07-06'),(46,1,'2022-07-07'),(46,2,'2022-07-08'),(46,1,'2022-07-12'),(46,2,'2022-07-14'),(46,2,'2022-07-16'),(46,5,'2022-07-18'),(46,1,'2022-07-25'),(47,4,'2022-07-06'),(47,1,'2022-07-07'),(47,2,'2022-07-08'),(47,1,'2022-07-10'),(47,3,'2022-07-14'),(47,3,'2022-07-18'),(47,1,'2022-07-24'),(47,1,'2022-07-25'),(48,1,'2022-07-02'),(48,1,'2022-07-03'),(48,1,'2022-07-04'),(48,8,'2022-07-06'),(48,3,'2022-07-07'),(48,2,'2022-07-09'),(48,3,'2022-07-18'),(48,1,'2022-07-24'),(48,2,'2022-07-25'),(49,1,'2022-07-03'),(49,5,'2022-07-06'),(49,5,'2022-07-07'),(49,3,'2022-07-10'),(49,2,'2022-07-12'),(49,3,'2022-07-18'),(49,2,'2022-07-23'),(49,1,'2022-07-24'),(49,2,'2022-07-25'),(50,1,'2022-07-02'),(50,2,'2022-07-05'),(50,5,'2022-07-06'),(50,5,'2022-07-07'),(50,3,'2022-07-18'),(50,1,'2022-07-23'),(50,1,'2022-07-24'),(51,5,'2022-07-06'),(51,2,'2022-07-07'),(51,1,'2022-07-09'),(51,1,'2022-07-12'),(51,1,'2022-07-13'),(51,3,'2022-07-15'),(51,5,'2022-07-18'),(51,1,'2022-07-22'),(52,5,'2022-07-06'),(52,2,'2022-07-07'),(52,1,'2022-07-16'),(52,4,'2022-07-18'),(52,3,'2022-07-22'),(52,2,'2022-07-23'),(52,2,'2022-07-24'),(52,1,'2022-07-25'),(53,1,'2022-06-27'),(53,1,'2022-06-29'),(53,2,'2022-06-30'),(53,3,'2022-07-02'),(53,1,'2022-07-03'),(53,1,'2022-07-04'),(53,2,'2022-07-05'),(53,5,'2022-07-06'),(53,4,'2022-07-07'),(53,1,'2022-07-12'),(53,5,'2022-07-18'),(53,1,'2022-07-20'),(54,1,'2022-07-02'),(54,1,'2022-07-03'),(54,1,'2022-07-04'),(54,1,'2022-07-05'),(54,5,'2022-07-06'),(54,2,'2022-07-07'),(54,6,'2022-07-18'),(54,2,'2022-07-19'),(54,1,'2022-07-20'),(54,1,'2022-07-24'),(55,1,'2022-06-27'),(55,3,'2022-06-29'),(55,4,'2022-07-01'),(55,1,'2022-07-04'),(55,5,'2022-07-06'),(55,2,'2022-07-07'),(55,1,'2022-07-11'),(55,5,'2022-07-18'),(55,2,'2022-07-20'),(55,1,'2022-07-21'),(55,1,'2022-07-25'),(56,1,'2022-07-23'),(56,1,'2022-07-25'),(57,1,'2022-07-02'),(57,1,'2022-07-04'),(57,1,'2022-07-05'),(57,3,'2022-07-06'),(57,1,'2022-07-07'),(57,1,'2022-07-18'),(57,1,'2022-07-21'),(57,1,'2022-07-22'),(57,1,'2022-07-23'),(57,2,'2022-07-25'),(58,1,'2022-07-04'),(58,3,'2022-07-06'),(58,1,'2022-07-07'),(58,1,'2022-07-18'),(59,1,'2022-07-03'),(59,2,'2022-07-05'),(59,2,'2022-07-06'),(59,2,'2022-07-07'),(59,1,'2022-07-18'),(59,1,'2022-07-23'),(60,1,'2022-07-03'),(60,1,'2022-07-05'),(60,2,'2022-07-06'),(60,2,'2022-07-07'),(60,1,'2022-07-18'),(61,1,'2022-07-02'),(61,1,'2022-07-03'),(61,2,'2022-07-05'),(61,2,'2022-07-06'),(61,2,'2022-07-07'),(61,2,'2022-07-18'),(61,3,'2022-07-23'),(62,1,'2022-07-02'),(62,1,'2022-07-04'),(62,2,'2022-07-06'),(62,1,'2022-07-07'),(62,1,'2022-07-18'),(62,1,'2022-07-23'),(63,1,'2022-07-04'),(63,2,'2022-07-06'),(63,1,'2022-07-07'),(63,2,'2022-07-18'),(63,2,'2022-07-24'),(63,1,'2022-07-25'),(64,2,'2022-06-29'),(64,1,'2022-07-02'),(64,1,'2022-07-05'),(64,2,'2022-07-06'),(64,1,'2022-07-07'),(64,1,'2022-07-15'),(64,1,'2022-07-18'),(64,1,'2022-07-20'),(64,1,'2022-07-23'),(65,1,'2022-07-04'),(65,1,'2022-07-05'),(65,4,'2022-07-06'),(65,1,'2022-07-07'),(65,1,'2022-07-18'),(65,6,'2022-07-24'),(65,4,'2022-07-25'),(66,2,'2022-07-03'),(66,2,'2022-07-05'),(66,3,'2022-07-06'),(66,1,'2022-07-18'),(67,1,'2022-07-04'),(67,1,'2022-07-05'),(67,3,'2022-07-06'),(67,1,'2022-07-07'),(67,2,'2022-07-18'),(67,1,'2022-07-20'),(67,1,'2022-07-23'),(68,1,'2022-07-02'),(68,1,'2022-07-03'),(68,1,'2022-07-04'),(68,3,'2022-07-06'),(68,2,'2022-07-18'),(68,2,'2022-07-20'),(68,1,'2022-07-21'),(68,1,'2022-07-22'),(68,1,'2022-07-25'),(69,2,'2022-07-03'),(69,1,'2022-07-05'),(69,2,'2022-07-06'),(69,1,'2022-07-07'),(69,1,'2022-07-18'),(69,1,'2022-07-19'),(69,1,'2022-07-21'),(69,1,'2022-07-22'),(69,1,'2022-07-23'),(69,1,'2022-07-24'),(69,1,'2022-07-25'),(70,1,'2022-07-02'),(70,1,'2022-07-04'),(70,2,'2022-07-06'),(70,1,'2022-07-07'),(70,1,'2022-07-18'),(70,1,'2022-07-20'),(70,1,'2022-07-22'),(70,1,'2022-07-23'),(70,2,'2022-07-25'),(71,1,'2022-06-28'),(71,1,'2022-07-04'),(71,1,'2022-07-05'),(71,2,'2022-07-06'),(71,1,'2022-07-07'),(71,2,'2022-07-18'),(71,1,'2022-07-20'),(71,1,'2022-07-22'),(71,2,'2022-07-25'),(72,1,'2022-07-04'),(72,2,'2022-07-06'),(72,1,'2022-07-07'),(72,1,'2022-07-13'),(72,1,'2022-07-16'),(72,1,'2022-07-18'),(72,1,'2022-07-21'),(72,3,'2022-07-24'),(72,1,'2022-07-25'),(73,1,'2022-07-02'),(73,1,'2022-07-04'),(73,2,'2022-07-06'),(73,1,'2022-07-07'),(73,1,'2022-07-18'),(73,1,'2022-07-22'),(73,1,'2022-07-25'),(74,1,'2022-07-03'),(74,1,'2022-07-05'),(74,2,'2022-07-06'),(74,2,'2022-07-07'),(74,2,'2022-07-18'),(74,1,'2022-07-20'),(74,2,'2022-07-23'),(74,2,'2022-07-25'),(75,1,'2022-07-03'),(75,1,'2022-07-05'),(75,2,'2022-07-06'),(75,2,'2022-07-07'),(75,1,'2022-07-18'),(75,4,'2022-07-25'),(76,1,'2022-07-04'),(76,3,'2022-07-06'),(76,1,'2022-07-07'),(76,1,'2022-07-18'),(76,1,'2022-07-21'),(103,3,'2022-07-21'),(112,1,'2022-07-21');
/*!40000 ALTER TABLE `products_popularity` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_prices`
--

DROP TABLE IF EXISTS `products_prices`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_prices` (
  `products_id` int(11) NOT NULL DEFAULT '0',
  `groups_id` int(11) NOT NULL DEFAULT '0',
  `products_group_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `products_group_discount_price` varchar(255) NOT NULL DEFAULT '',
  `currencies_id` int(11) NOT NULL DEFAULT '0',
  `bonus_points_price` decimal(15,4) NOT NULL DEFAULT '-2.0000',
  `bonus_points_cost` decimal(15,2) NOT NULL DEFAULT '-2.00',
  `products_group_price_pack_unit` decimal(15,6) NOT NULL DEFAULT '-2.000000',
  `products_group_discount_price_pack_unit` varchar(255) NOT NULL DEFAULT '',
  `products_group_price_packaging` decimal(15,6) NOT NULL DEFAULT '-2.000000',
  `products_group_discount_price_packaging` varchar(255) NOT NULL DEFAULT '',
  `products_price_configurator` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `shipping_surcharge_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `supplier_price_manual` tinyint(1) DEFAULT NULL,
  `products_sets_discount` decimal(12,2) NOT NULL DEFAULT '0.00',
  PRIMARY KEY (`products_id`,`groups_id`,`currencies_id`),
  KEY `idx_currencies_id` (`currencies_id`),
  KEY `idx_groups_id` (`groups_id`),
  KEY `idx_productd_group_price` (`products_group_price`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_prices`
--

LOCK TABLES `products_prices` WRITE;
/*!40000 ALTER TABLE `products_prices` DISABLE KEYS */;
INSERT INTO `products_prices` VALUES (1,0,111.900000,'10:111.9;50:100;100:80;',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(1,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(1,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(2,0,87.540000,'2:80;3:75;4:70;',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(2,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(2,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(3,0,180.000000,'3:16;5:14;10:10;',0,50.0000,40.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(3,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(3,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(4,0,37.450000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(4,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(4,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(5,0,55.833333,'4:54.166667;6:50;10:45.833333;',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(5,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(5,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(6,0,150.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(6,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(6,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(7,0,28.940000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(7,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(7,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(8,0,61.280000,'10:60;20:50;30:40;',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(8,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(8,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(9,0,49.360000,'',0,20.0000,10.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(9,1,49.360000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(9,2,44.430000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(10,0,109.841667,'2:10;3:9;4:8;5:7;',0,150.0000,45.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(10,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(10,2,10.000000,'',0,200.0000,150.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(11,0,217.490000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(11,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(11,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(12,0,47.660000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(12,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(12,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(13,0,44.200000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(13,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(13,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(14,0,180.000000,'3:16;5:14;10:10;',0,50.0000,40.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(14,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(14,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(15,0,40.040000,'5:37.5;7:33.333333;10:31.666667;',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(15,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(15,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(16,0,38.300000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(16,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(16,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(17,0,56.170000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(17,1,56.170000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(17,2,50.550000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(18,0,51.670000,'3:51;5:50;',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(18,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(18,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(19,0,42.970000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(19,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(19,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(20,0,150.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(20,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(20,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(21,0,11.510101,'2:10;3:9;4:8;5:7;',0,150.0000,45.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(21,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(21,2,10.000000,'',0,200.0000,150.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(22,0,211.670000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(22,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(22,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(23,0,264.170000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(23,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(23,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(24,0,145.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(24,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(24,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(25,0,189.170000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(25,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(25,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(26,0,35.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(26,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(26,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(27,0,39.150000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(27,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(27,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(28,0,50.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(28,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(28,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(29,0,157.500000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(29,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(29,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(30,0,82.500000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(30,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(30,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(31,0,74.158333,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(31,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(31,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(32,0,107.491667,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(32,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(32,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(33,0,65.833333,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(33,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(33,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(34,0,262.500000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(34,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(34,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(35,0,274.100000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(35,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(35,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(36,0,180.200000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(36,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(36,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(37,0,54.166667,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(37,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(37,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(38,0,99.991667,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(38,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(38,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(39,0,74.991667,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(39,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(39,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(40,0,247.408333,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(40,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(40,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(41,0,832.483333,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(41,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(41,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(42,0,166.658333,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(42,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(42,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(43,0,2075.825000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(43,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(43,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(44,0,58.325000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(44,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(44,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(45,0,66.658333,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(45,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(45,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(46,0,291.658333,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(46,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(46,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(47,0,83.325000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(47,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(47,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(48,0,116.658333,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(48,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(48,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(49,0,324.166667,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(49,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(49,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(50,0,346.956522,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(50,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(50,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(51,0,303.478261,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(51,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(51,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(52,0,2999.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(52,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(52,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(53,0,1390.434783,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(53,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(53,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(54,0,1303.478261,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(54,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(54,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(55,0,2346.956522,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(55,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(55,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(56,0,78.217391,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(56,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(56,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(57,0,69.521739,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(57,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(57,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(58,0,49.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(58,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(58,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(59,0,39.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(59,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(59,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(60,0,49.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(60,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(60,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(61,0,49.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(61,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(61,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(62,0,799.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(62,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(62,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(63,0,1564.347826,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(63,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(63,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(64,0,1912.173913,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(64,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(64,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(65,0,1899.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(65,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(65,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(66,0,546.956522,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(66,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(66,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(67,0,699.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(67,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(67,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(68,0,999.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(68,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(68,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(69,0,868.695652,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(69,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(69,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(70,0,520.869565,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(70,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(70,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(71,0,260.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(71,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(71,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(72,0,868.695652,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(72,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(72,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(73,0,799.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(73,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(73,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(74,0,694.782609,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(74,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(74,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(75,0,399.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(75,1,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00),(75,2,-2.000000,'',0,0.0000,0.00,-2.000000,'',-2.000000,'',0.000000,0.000000,NULL,0.00);
/*!40000 ALTER TABLE `products_prices` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_settings`
--

DROP TABLE IF EXISTS `products_settings`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_settings` (
  `products_id` int(11) NOT NULL AUTO_INCREMENT,
  `show_attributes_quantity` tinyint(3) DEFAULT '0',
  PRIMARY KEY (`products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_settings`
--

LOCK TABLES `products_settings` WRITE;
/*!40000 ALTER TABLE `products_settings` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_settings` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_stock_delivery_terms`
--

DROP TABLE IF EXISTS `products_stock_delivery_terms`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_stock_delivery_terms` (
  `stock_delivery_terms_id` int(11) NOT NULL AUTO_INCREMENT,
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `is_default` tinyint(1) NOT NULL DEFAULT '0',
  `stock_code` varchar(16) NOT NULL DEFAULT 'out-stock',
  `text_stock_code` varchar(16) NOT NULL DEFAULT 'out-stock',
  `delivery_delay` int(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`stock_delivery_terms_id`),
  KEY `sort_order` (`sort_order`)
) ENGINE=InnoDB AUTO_INCREMENT=11 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_stock_delivery_terms`
--

LOCK TABLES `products_stock_delivery_terms` WRITE;
/*!40000 ALTER TABLE `products_stock_delivery_terms` DISABLE KEYS */;
INSERT INTO `products_stock_delivery_terms` VALUES (1,1,0,'in-stock','in-stock',0),(2,9,1,'out-stock','out-stock',0),(3,2,0,'transit','transit',0),(4,4,0,'in-stock','transit',0),(5,5,0,'transit','transit',0),(6,6,0,'in-stock','pre-order',0),(7,7,0,'pre-order','pre-order',0),(8,8,0,'out-stock','out-stock',0),(10,3,0,'transit','transit',0);
/*!40000 ALTER TABLE `products_stock_delivery_terms` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_stock_delivery_terms_text`
--

DROP TABLE IF EXISTS `products_stock_delivery_terms_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_stock_delivery_terms_text` (
  `stock_delivery_terms_id` int(11) NOT NULL,
  `language_id` int(11) NOT NULL,
  `stock_delivery_terms_text` varchar(64) NOT NULL DEFAULT '',
  `stock_delivery_terms_short_text` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`stock_delivery_terms_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_stock_delivery_terms_text`
--

LOCK TABLES `products_stock_delivery_terms_text` WRITE;
/*!40000 ALTER TABLE `products_stock_delivery_terms_text` DISABLE KEYS */;
INSERT INTO `products_stock_delivery_terms_text` VALUES (1,1,'In stock',''),(1,3,'Op voorraad',''),(1,10,'Auf Lager',''),(1,11,'En stock',''),(1,12,'På lager',''),(1,13,'Disponibile',''),(1,15,'В наявності',''),(1,17,'В наличии',''),(1,22,'In stock',''),(1,23,'In stock',''),(1,24,'In stock',''),(1,25,'In stock',''),(1,26,'Na stanie',''),(1,27,'In stock',''),(1,28,'In stock',''),(1,29,'In stock',''),(2,1,'Currently out of Stock','Out of stock'),(2,3,'Momenteel niet op voorraad','Niet op voorraad'),(2,10,'Zur Zeit nicht am Lager','Ausverkauft'),(2,11,'Actuellement en rupture de stock','En rupture de stock'),(2,12,'For tiden ikke på lager','Utsolgt'),(2,13,'Attualmente non disponibile','Esaurito'),(2,15,'Зараз немає в наявності','Немає в наявності'),(2,17,'В настоящее время нет в наличии','Нет в наличии'),(2,22,'Currently out of Stock','Out of stock'),(2,23,'Currently out of Stock','Out of stock'),(2,24,'Currently out of Stock','Out of stock'),(2,25,'Currently out of Stock','Out of stock'),(2,26,'Tymczasowo niedostępne','Tymczasowo niedostępne'),(2,27,'Currently out of Stock','Out of stock'),(2,28,'Currently out of Stock','Out of stock'),(2,29,'Currently out of Stock','Out of stock'),(3,1,'1-2 days',''),(3,3,'1-2 dagen',''),(3,10,'1 bis 2 Tage',''),(3,11,'1 à 2 jours',''),(3,12,'1-2 dager',''),(3,13,'1-2 giorni',''),(3,15,'1-2 дні',''),(3,17,'1-2 дня',''),(3,22,'1-2 days',''),(3,23,'1-2 days',''),(3,24,'1-2 days',''),(3,25,'1-2 days',''),(3,26,'1-2 dni',''),(3,27,'1-2 days',''),(3,28,'1-2 days',''),(3,29,'1-2 days',''),(4,1,'1 week',''),(4,3,'1 week',''),(4,10,'1 Woche',''),(4,11,'1 semaine',''),(4,12,'1 uke',''),(4,13,'1 settimana',''),(4,15,'1 тиждень',''),(4,17,'1 неделя',''),(4,22,'1 week',''),(4,23,'1 week',''),(4,24,'1 week',''),(4,25,'1 week',''),(4,26,'1 tydzień',''),(4,27,'1 week',''),(4,28,'1 week',''),(4,29,'1 week',''),(5,1,'2-4 weeks',''),(5,3,'2-4 weken',''),(5,10,'2 bis 4 Wochen',''),(5,11,'2 à 4 semaines',''),(5,12,'2-4 uker',''),(5,13,'2-4 settimane',''),(5,15,'2-4 тижнів',''),(5,17,'2-4 недели',''),(5,22,'2-4 weeks',''),(5,23,'2-4 weeks',''),(5,24,'2-4 weeks',''),(5,25,'2-4 weeks',''),(5,26,'2-4 tydzień',''),(5,27,'2-4 weeks',''),(5,28,'2-4 weeks',''),(5,29,'2-4 weeks',''),(6,1,'Coming Soon',''),(6,3,'Binnenkort beschikbaar',''),(6,10,'Demnächst',''),(6,11,'Arrive bientôt',''),(6,12,'Kommer snart',''),(6,13,'Prossimamente',''),(6,15,'Незабаром',''),(6,17,'Скоро',''),(6,22,'Coming Soon',''),(6,23,'Coming Soon',''),(6,24,'Coming Soon',''),(6,25,'Coming Soon',''),(6,26,'Coming Soon',''),(6,27,'Coming Soon',''),(6,28,'Coming Soon',''),(6,29,'Coming Soon',''),(7,1,'Pre-order',''),(7,3,'Pre-order',''),(7,10,'Vorbestellen',''),(7,11,'Pré-commande',''),(7,12,'Forhåndsbestill',''),(7,13,'Pre-ordine',''),(7,15,'Попереднє замовлення',''),(7,17,'Предзаказ',''),(7,22,'Pre-order',''),(7,23,'Pre-order',''),(7,24,'Pre-order',''),(7,25,'Pre-order',''),(7,26,'Przedsprzedaży',''),(7,27,'Pre-order',''),(7,28,'Pre-order',''),(7,29,'Pre-order',''),(8,1,'End of Life',''),(8,3,'Eind van het leven',''),(8,10,'Ende des Lebens',''),(8,11,'Fin de vie',''),(8,12,'Slutten på livet',''),(8,13,'Fine della vita',''),(8,15,'Знятий з виробництва',''),(8,17,'Снят с производства',''),(8,22,'End of Life',''),(8,23,'End of Life',''),(8,24,'End of Life',''),(8,25,'End of Life',''),(8,26,'Wycofano',''),(8,27,'End of Life',''),(8,28,'End of Life',''),(8,29,'End of Life',''),(10,1,'3-5 days',''),(10,3,'3-5 dagen',''),(10,10,'3-5 Tage',''),(10,11,'3-5 jours',''),(10,12,'3-5 dager',''),(10,13,'3-5 giorni',''),(10,15,'3-5 днів',''),(10,17,'3-5 дней',''),(10,22,'3-5 days',''),(10,23,'3-5 days',''),(10,24,'3-5 days',''),(10,25,'3-5 days',''),(10,26,'3-5 dni',''),(10,27,'3-5 days',''),(10,28,'3-5 days',''),(10,29,'3-5 days','');
/*!40000 ALTER TABLE `products_stock_delivery_terms_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_stock_indication`
--

DROP TABLE IF EXISTS `products_stock_indication`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_stock_indication` (
  `stock_indication_id` int(11) NOT NULL AUTO_INCREMENT,
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `is_default` tinyint(1) NOT NULL DEFAULT '0',
  `stock_code` varchar(16) NOT NULL DEFAULT 'out-stock',
  `allow_out_of_stock_checkout` tinyint(1) NOT NULL DEFAULT '0',
  `allow_out_of_stock_add_to_cart` tinyint(1) NOT NULL DEFAULT '0',
  `allow_in_stock_notify` tinyint(1) NOT NULL DEFAULT '0',
  `disable_product_on_oos` tinyint(1) NOT NULL DEFAULT '0',
  `reset_status_on_oos` int(1) NOT NULL DEFAULT '0',
  `request_for_quote` tinyint(1) NOT NULL DEFAULT '0',
  `is_hidden` tinyint(1) NOT NULL DEFAULT '0',
  `display_price_options` int(5) NOT NULL DEFAULT '0',
  `display_virtual_options` int(5) NOT NULL DEFAULT '0',
  `limit_cart_qty_by_stock` tinyint(1) DEFAULT '0',
  PRIMARY KEY (`stock_indication_id`),
  KEY `sort_order` (`sort_order`),
  KEY `is_hidden` (`is_hidden`)
) ENGINE=InnoDB AUTO_INCREMENT=11 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_stock_indication`
--

LOCK TABLES `products_stock_indication` WRITE;
/*!40000 ALTER TABLE `products_stock_indication` DISABLE KEYS */;
INSERT INTO `products_stock_indication` VALUES (1,1,0,'in-stock',1,1,0,0,0,0,0,2,0,0),(2,2,1,'out-stock',0,0,1,0,0,0,0,2,0,0),(6,3,0,'pre-order',1,1,0,0,1,1,0,2,0,0),(8,6,0,'out-stock',1,0,0,1,0,0,0,0,0,0),(10,5,0,'out-stock',0,0,0,0,0,0,1,0,0,0);
/*!40000 ALTER TABLE `products_stock_indication` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_stock_indication_text`
--

DROP TABLE IF EXISTS `products_stock_indication_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_stock_indication_text` (
  `stock_indication_id` int(11) NOT NULL,
  `language_id` int(11) NOT NULL,
  `stock_indication_text` varchar(64) NOT NULL DEFAULT '',
  `stock_indication_short_text` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`stock_indication_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_stock_indication_text`
--

LOCK TABLES `products_stock_indication_text` WRITE;
/*!40000 ALTER TABLE `products_stock_indication_text` DISABLE KEYS */;
INSERT INTO `products_stock_indication_text` VALUES (1,1,'In stock',''),(1,3,'Op voorraad',''),(1,10,'Auf Lager',''),(1,11,'En stock',''),(1,12,'På lager',''),(1,13,'Disponibile',''),(1,15,'В наявності',''),(1,17,'В наличии',''),(1,22,'In stock',''),(1,23,'In stock',''),(1,24,'In stock',''),(1,25,'In stock',''),(1,26,'Na stanie',''),(1,27,'In stock',''),(1,28,'In stock',''),(1,29,'In stock',''),(2,1,'Currently out of Stock','Out of stock'),(2,3,'Momenteel niet op voorraad','Out of stock'),(2,10,'Zur Zeit nicht am Lager','Out of stock'),(2,11,'Actuellement en rupture de stock','Out of stock'),(2,12,'For tiden ikke på lager','Out of stock'),(2,13,'Attualmente non disponibile','Out of stock'),(2,15,'Зараз немає в наявності','Out of stock'),(2,17,'В настоящее время нет в наличии','Out of stock'),(2,22,'Currently out of Stock','Out of stock'),(2,23,'Currently out of Stock','Out of stock'),(2,24,'Currently out of Stock','Out of stock'),(2,25,'Currently out of Stock','Out of stock'),(2,26,'Tymczasowo niedostępne','Out of stock'),(2,27,'Currently out of Stock','Out of stock'),(2,28,'Currently out of Stock','Out of stock'),(2,29,'Currently out of Stock','Out of stock'),(6,1,'Pre Order',''),(6,3,'Pre Order',''),(6,10,'Pre Order',''),(6,11,'Pre Order',''),(6,12,'Pre Order',''),(6,13,'Pre Order',''),(6,15,'Pre Order',''),(6,17,'Pre Order',''),(6,22,'Pre Order',''),(6,23,'Pre Order',''),(6,24,'Pre Order',''),(6,25,'Pre Order',''),(6,26,'Pre Order',''),(6,27,'Pre Order',''),(6,28,'Pre Order',''),(6,29,'Pre Order',''),(8,1,'End of Life',''),(8,3,'Eind van het leven',''),(8,10,'Ende des Lebens',''),(8,11,'Fin de vie',''),(8,12,'Slutten på livet',''),(8,13,'Fine della vita',''),(8,15,'Знятий з виробництва',''),(8,17,'Снят с производства',''),(8,22,'End of Life',''),(8,23,'End of Life',''),(8,24,'End of Life',''),(8,25,'End of Life',''),(8,26,'Przerwać',''),(8,27,'End of Life',''),(8,28,'End of Life',''),(8,29,'End of Life',''),(10,1,'Hidden',''),(10,3,'Verborgen',''),(10,10,'Versteckt',''),(10,11,'Caché',''),(10,12,'Skjult',''),(10,13,'Nascosto',''),(10,15,'Прихований',''),(10,17,'Скрытый',''),(10,22,'Hidden',''),(10,23,'Hidden',''),(10,24,'Hidden',''),(10,25,'Hidden',''),(10,26,'Ukryty',''),(10,27,'Hidden',''),(10,28,'Hidden',''),(10,29,'Hidden','');
/*!40000 ALTER TABLE `products_stock_indication_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_stock_statuses_cross_link`
--

DROP TABLE IF EXISTS `products_stock_statuses_cross_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_stock_statuses_cross_link` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `stock_indication_id` int(11) NOT NULL DEFAULT '0',
  `stock_delivery_terms_id` int(11) NOT NULL DEFAULT '0',
  `is_default_term` int(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `products_stock_cross_link_indication_idx` (`stock_indication_id`)
) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_stock_statuses_cross_link`
--

LOCK TABLES `products_stock_statuses_cross_link` WRITE;
/*!40000 ALTER TABLE `products_stock_statuses_cross_link` DISABLE KEYS */;
INSERT INTO `products_stock_statuses_cross_link` VALUES (1,1,1,1),(2,1,3,0),(3,1,10,0),(4,1,4,0),(5,1,5,0),(6,2,2,1),(10,8,8,1),(11,6,7,1),(12,2,6,1);
/*!40000 ALTER TABLE `products_stock_statuses_cross_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_to_categories`
--

DROP TABLE IF EXISTS `products_to_categories`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_to_categories` (
  `products_id` int(11) NOT NULL DEFAULT '0',
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`products_id`,`categories_id`),
  KEY `categories_id` (`categories_id`,`sort_order`,`products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_to_categories`
--

LOCK TABLES `products_to_categories` WRITE;
/*!40000 ALTER TABLE `products_to_categories` DISABLE KEYS */;
INSERT INTO `products_to_categories` VALUES (14,2,0),(1,2,3),(9,2,4),(11,2,5),(10,2,6),(18,2,7),(3,2,8),(2,2,9),(13,3,0),(14,3,0),(29,3,0),(13,4,0),(21,4,1),(16,4,2),(15,4,3),(17,4,4),(25,4,5),(26,4,6),(28,4,7),(27,4,8),(24,4,9),(22,4,10),(23,4,11),(8,4,12),(12,4,13),(4,4,14),(19,4,15),(20,4,16),(6,4,17),(7,4,18),(5,4,19),(29,4,20),(30,6,0),(31,6,0),(32,6,0),(33,6,0),(34,7,0),(35,7,0),(36,8,0),(37,8,0),(38,10,0),(39,10,0),(40,10,0),(41,10,0),(42,11,0),(43,11,0),(44,11,0),(45,11,0),(46,12,0),(47,12,0),(48,12,0),(49,12,0),(56,14,0),(57,14,0),(58,14,0),(59,14,0),(60,14,0),(61,14,0),(52,15,0),(53,15,0),(54,15,0),(55,15,0),(65,15,0),(62,16,0),(63,16,0),(64,16,0),(66,16,0),(67,16,0),(68,16,0),(74,16,0),(50,17,0),(51,17,0),(73,17,0),(75,17,0),(69,18,0),(70,18,0),(71,18,0),(72,18,0);
/*!40000 ALTER TABLE `products_to_categories` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_to_options_templates`
--

DROP TABLE IF EXISTS `products_to_options_templates`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_to_options_templates` (
  `products_id` int(11) NOT NULL DEFAULT '0',
  `options_templates_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`products_id`,`options_templates_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_to_options_templates`
--

LOCK TABLES `products_to_options_templates` WRITE;
/*!40000 ALTER TABLE `products_to_options_templates` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_to_options_templates` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_upsell`
--

DROP TABLE IF EXISTS `products_upsell`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_upsell` (
  `ID` int(10) NOT NULL AUTO_INCREMENT,
  `products_id` int(10) unsigned NOT NULL DEFAULT '1',
  `upsell_id` int(10) unsigned NOT NULL DEFAULT '1',
  `sort_order` int(10) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (`ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_upsell`
--

LOCK TABLES `products_upsell` WRITE;
/*!40000 ALTER TABLE `products_upsell` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_upsell` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_videos`
--

DROP TABLE IF EXISTS `products_videos`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_videos` (
  `video_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` int(11) NOT NULL DEFAULT '0',
  `video` varchar(255) DEFAULT NULL,
  `language_id` int(11) NOT NULL DEFAULT '0',
  `type` int(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`video_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_videos`
--

LOCK TABLES `products_videos` WRITE;
/*!40000 ALTER TABLE `products_videos` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_videos` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_xsell`
--

DROP TABLE IF EXISTS `products_xsell`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_xsell` (
  `ID` int(10) NOT NULL AUTO_INCREMENT,
  `products_id` int(10) unsigned NOT NULL DEFAULT '1',
  `xsell_type_id` int(11) NOT NULL DEFAULT '0',
  `xsell_id` int(10) unsigned NOT NULL DEFAULT '1',
  `sort_order` int(10) unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (`ID`),
  KEY `products_id` (`products_id`,`xsell_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_xsell`
--

LOCK TABLES `products_xsell` WRITE;
/*!40000 ALTER TABLE `products_xsell` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_xsell` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `products_xsell_type`
--

DROP TABLE IF EXISTS `products_xsell_type`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `products_xsell_type` (
  `xsell_type_id` int(11) NOT NULL,
  `language_id` int(11) NOT NULL,
  `xsell_type_name` varchar(64) NOT NULL DEFAULT '',
  `link_update_disable` tinyint(1) NOT NULL DEFAULT '0',
  `xsell_type_code` varchar(16) DEFAULT NULL,
  PRIMARY KEY (`xsell_type_id`,`language_id`),
  KEY `xsell_type_name` (`xsell_type_name`(8))
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `products_xsell_type`
--

LOCK TABLES `products_xsell_type` WRITE;
/*!40000 ALTER TABLE `products_xsell_type` DISABLE KEYS */;
/*!40000 ALTER TABLE `products_xsell_type` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `properties`
--

DROP TABLE IF EXISTS `properties`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `properties` (
  `properties_id` int(11) NOT NULL AUTO_INCREMENT,
  `parent_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) DEFAULT '0',
  `properties_type` enum('text','number','interval','flag','file','category') NOT NULL DEFAULT 'text',
  `multi_choice` tinyint(1) NOT NULL DEFAULT '0',
  `multi_line` tinyint(1) NOT NULL DEFAULT '0',
  `decimals` tinyint(1) NOT NULL DEFAULT '0',
  `display_product` tinyint(1) NOT NULL DEFAULT '0',
  `display_listing` tinyint(1) NOT NULL DEFAULT '0',
  `display_filter` tinyint(1) NOT NULL DEFAULT '0',
  `display_search` tinyint(1) NOT NULL DEFAULT '0',
  `display_compare` tinyint(1) NOT NULL DEFAULT '0',
  `products_groups` tinyint(1) NOT NULL DEFAULT '0',
  `extra_values` tinyint(1) NOT NULL DEFAULT '0',
  `range_select` tinyint(1) NOT NULL DEFAULT '0',
  `date_added` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `display_as_image` int(1) NOT NULL DEFAULT '0',
  `display_filter_as` varchar(32) NOT NULL DEFAULT '',
  `filter_by_property` int(11) NOT NULL DEFAULT '0',
  `filter_steps` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`properties_id`),
  KEY `idx_parent_id` (`parent_id`)
) ENGINE=InnoDB AUTO_INCREMENT=39 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `properties`
--

LOCK TABLES `properties` WRITE;
/*!40000 ALTER TABLE `properties` DISABLE KEYS */;
INSERT INTO `properties` VALUES (1,0,0,'category',0,0,0,0,0,0,0,0,0,0,0,'2022-07-25 10:15:05',NULL,0,'',0,0),(2,0,0,'category',0,0,0,0,0,0,0,0,0,0,0,'2022-07-25 10:16:08',NULL,0,'',0,0),(3,0,0,'category',0,0,0,0,0,0,0,0,0,0,0,'2022-07-25 10:16:18',NULL,0,'',0,0),(4,0,0,'category',0,0,0,0,0,0,0,0,0,0,0,'2022-07-25 10:16:29',NULL,0,'',0,0),(5,1,0,'text',0,0,0,1,1,1,1,1,0,0,0,'2022-07-25 10:32:29','2022-07-25 12:26:03',0,'',0,0),(6,1,2,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 10:35:34','2022-07-25 11:38:59',0,'',0,0),(7,1,3,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 10:36:21','2022-07-25 10:36:32',0,'',0,0),(8,1,4,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 10:36:56','2022-07-25 11:27:43',0,'',0,0),(9,1,6,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 10:45:07','2022-07-25 11:19:24',0,'',0,0),(10,1,8,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 10:45:38','2022-07-25 11:36:27',0,'',0,0),(11,1,9,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 10:46:43','2022-07-25 10:46:50',0,'',0,0),(12,1,1,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 10:49:15','2022-07-25 11:38:43',0,'',0,0),(13,1,7,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 10:55:31','2022-07-25 10:55:37',0,'',0,0),(14,1,5,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 10:55:58','2022-07-25 11:32:25',0,'',0,0),(15,1,0,'text',0,0,0,1,1,1,1,1,0,0,0,'2022-07-25 11:00:26','2022-07-25 12:25:51',0,'',0,0),(16,1,0,'text',0,0,0,1,1,1,1,1,0,0,0,'2022-07-25 11:00:58','2022-07-25 12:26:21',0,'',0,0),(17,1,0,'text',0,0,0,1,1,1,1,1,0,0,0,'2022-07-25 11:01:28','2022-07-25 12:23:53',0,'',0,0),(18,1,0,'text',0,0,0,1,1,1,1,1,0,0,0,'2022-07-25 11:02:05','2022-07-25 12:24:16',0,'',0,0),(19,1,0,'text',0,0,0,1,1,1,1,1,0,0,0,'2022-07-25 11:02:37','2022-07-25 12:24:28',0,'',0,0),(20,1,0,'text',0,0,0,1,1,1,1,1,0,0,0,'2022-07-25 11:03:24','2022-07-25 12:26:33',0,'',0,0),(21,1,0,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 11:10:34','2022-07-25 11:39:16',0,'',0,0),(22,1,0,'text',0,0,0,1,1,1,1,1,0,0,0,'2022-07-25 11:11:04','2022-07-25 12:25:36',0,'',0,0),(23,2,0,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:03:28','2022-07-25 12:26:23',0,'',0,0),(24,2,1,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:03:58','2022-07-25 12:25:23',0,'',0,0),(25,2,2,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:04:27','2022-07-25 12:26:03',0,'',0,0),(26,2,3,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:04:59','2022-07-25 12:07:14',0,'',0,0),(27,2,4,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:05:27','2022-07-25 12:27:17',0,'',0,0),(28,2,5,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:05:51','2022-07-25 12:25:48',0,'',0,0),(29,2,6,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:06:16','2022-07-25 12:25:08',0,'',0,0),(30,2,7,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:06:40','2022-07-25 12:26:53',0,'',0,0),(31,2,8,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:07:06','2022-07-25 12:24:02',0,'',0,0),(32,4,0,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:31:31','2022-07-25 12:59:40',0,'',0,0),(33,4,0,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:32:02','2022-07-25 13:03:34',0,'',0,0),(34,4,0,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:32:39','2022-07-25 12:34:55',0,'',0,0),(35,4,0,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:33:09','2022-07-25 12:39:23',0,'',0,0),(36,4,0,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:33:37','2022-07-25 13:03:49',0,'',0,0),(37,4,0,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:34:49','2022-07-25 13:01:13',0,'',0,0),(38,4,0,'text',0,0,0,1,1,1,1,0,0,0,0,'2022-07-25 12:36:10','2022-07-25 12:55:17',0,'',0,0);
/*!40000 ALTER TABLE `properties` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `properties_categories`
--

DROP TABLE IF EXISTS `properties_categories`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `properties_categories` (
  `categories_id` int(11) NOT NULL AUTO_INCREMENT,
  `parent_id` int(11) DEFAULT '0',
  `sort_ORDER` int(11) DEFAULT '0',
  `date_added` date DEFAULT NULL,
  `last_modified` date DEFAULT NULL,
  PRIMARY KEY (`categories_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `properties_categories`
--

LOCK TABLES `properties_categories` WRITE;
/*!40000 ALTER TABLE `properties_categories` DISABLE KEYS */;
/*!40000 ALTER TABLE `properties_categories` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `properties_categories_description`
--

DROP TABLE IF EXISTS `properties_categories_description`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `properties_categories_description` (
  `categories_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `categories_name` varchar(65) DEFAULT NULL,
  `categories_description` text,
  PRIMARY KEY (`categories_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `properties_categories_description`
--

LOCK TABLES `properties_categories_description` WRITE;
/*!40000 ALTER TABLE `properties_categories_description` DISABLE KEYS */;
/*!40000 ALTER TABLE `properties_categories_description` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `properties_description`
--

DROP TABLE IF EXISTS `properties_description`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `properties_description` (
  `properties_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `properties_name` varchar(128) DEFAULT NULL,
  `properties_description` text,
  `properties_image` varchar(255) NOT NULL DEFAULT '',
  `properties_color` varchar(8) NOT NULL DEFAULT '',
  `properties_units_id` int(11) NOT NULL DEFAULT '0',
  `properties_seo_page_name` varchar(255) NOT NULL DEFAULT '',
  `properties_name_alt` varchar(128) NOT NULL DEFAULT '',
  PRIMARY KEY (`properties_id`,`language_id`),
  KEY `idx_properties_name` (`properties_name`),
  KEY `idx_properties_name_alt` (`properties_name_alt`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `properties_description`
--

LOCK TABLES `properties_description` WRITE;
/*!40000 ALTER TABLE `properties_description` DISABLE KEYS */;
INSERT INTO `properties_description` VALUES (1,1,'Printshop','','','',0,'printshop',''),(2,1,'Watch','','','',0,'watch',''),(3,1,'Furniture','','','',0,'furniture',''),(4,1,'Supermarket','','','',0,'supermarket',''),(5,1,'Product Dimensions','','','',0,'product-dimensions',''),(6,1,'Color','','','',0,'color',''),(7,1,'Standing screen display size','','','',0,'standing-screen-display-size',''),(8,1,'Connectivity Type','','','',0,'connectivity-type',''),(9,1,'Hardware Platform','','','',0,'hardware-platform',''),(10,1,'Operating System','','','',0,'operating-system',''),(11,1,'Are Batteries Included','','','',0,'are-batteries-included',''),(12,1,'Series','','','',0,'series',''),(13,1,'Wireless Type','','','',0,'wireless-type',''),(14,1,'Power Source','','','',0,'power-source',''),(15,1,'Maximum Resolution','','','',0,'maximum-resolution',''),(16,1,'Scan Modes','','','',0,'scan-modes',''),(17,1,'Color Depth','','','',0,'color-depth',''),(18,1,'Grayscale Depth','','','',0,'grayscale-depth',''),(19,1,'Light Source','','','',0,'light-source',''),(20,1,'Scan Sizes','','','',0,'scan-sizes',''),(21,1,'Wattage','','','',0,'wattage',''),(22,1,'Lithium Battery Energy Content','','','',0,'lithium-battery-energy-content',''),(23,1,'Band Material','','','',0,'material',''),(24,1,'Calendar Type','','','',0,'calendar-type',''),(25,1,'Case Diameter','','','',0,'case-diameter',''),(26,1,'Item Shape','','','',0,'item-shape',''),(27,1,'Clasp Type','','','',0,'clasp-type',''),(28,1,'Watch Movement Type','','','',0,'watch-movement-type',''),(29,1,'Band Color','','','',0,'color',''),(30,1,'Band size','','','',0,'size',''),(31,1,'Band width','','','',0,'width',''),(32,1,'Product Dimensions','','','',0,'product-dimensions',''),(33,1,'Item Weight','','','',0,'item-weight',''),(34,1,'Special Feature','','','',0,'special-feature',''),(35,1,'Style','','','',0,'style',''),(36,1,'Material','','','',0,'furniture-finish',''),(37,1,'Finish Type','','','',0,'finish-type',''),(38,1,'Color','','','',0,'color','');
/*!40000 ALTER TABLE `properties_description` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `properties_to_products`
--

DROP TABLE IF EXISTS `properties_to_products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `properties_to_products` (
  `products_id` int(11) NOT NULL DEFAULT '0',
  `properties_id` int(11) NOT NULL DEFAULT '0',
  `values_id` int(11) NOT NULL DEFAULT '0',
  `values_flag` tinyint(1) DEFAULT NULL,
  `extra_value` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`products_id`,`properties_id`,`values_id`),
  KEY `properties_IDX` (`properties_id`,`products_id`),
  KEY `properties_values_IDX` (`values_id`,`products_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `properties_to_products`
--

LOCK TABLES `properties_to_products` WRITE;
/*!40000 ALTER TABLE `properties_to_products` DISABLE KEYS */;
INSERT INTO `properties_to_products` VALUES (13,23,55,NULL,0),(13,24,56,NULL,0),(13,25,57,NULL,0),(13,26,58,NULL,0),(13,27,59,NULL,0),(13,28,60,NULL,0),(13,29,61,NULL,0),(13,30,62,NULL,0),(13,31,63,NULL,0),(15,23,77,NULL,0),(15,24,74,NULL,0),(15,25,76,NULL,0),(15,26,58,NULL,0),(15,27,79,NULL,0),(15,28,75,NULL,0),(15,29,73,NULL,0),(15,30,78,NULL,0),(15,31,72,NULL,0),(16,23,70,NULL,0),(16,24,56,NULL,0),(16,26,58,NULL,0),(16,28,60,NULL,0),(16,29,61,NULL,0),(16,31,71,NULL,0),(21,23,64,NULL,0),(21,25,66,NULL,0),(21,27,67,NULL,0),(21,28,69,NULL,0),(21,29,61,NULL,0),(21,30,65,NULL,0),(21,31,68,NULL,0),(30,32,89,NULL,0),(30,33,90,NULL,0),(30,34,82,NULL,0),(30,35,91,NULL,0),(30,36,88,NULL,0),(30,38,87,NULL,0),(31,32,97,NULL,0),(31,33,96,NULL,0),(31,34,82,NULL,0),(31,35,91,NULL,0),(31,36,88,NULL,0),(31,37,85,NULL,0),(31,38,95,NULL,0),(32,32,94,NULL,0),(32,33,93,NULL,0),(32,34,82,NULL,0),(32,35,91,NULL,0),(32,36,88,NULL,0),(32,37,85,NULL,0),(32,38,92,NULL,0),(33,32,80,NULL,0),(33,33,81,NULL,0),(33,34,82,NULL,0),(33,35,83,NULL,0),(33,36,84,NULL,0),(33,37,85,NULL,0),(33,38,86,NULL,0),(34,32,106,NULL,0),(34,33,110,NULL,0),(34,36,111,NULL,0),(34,37,108,NULL,0),(34,38,95,NULL,0),(35,32,106,NULL,0),(35,33,107,NULL,0),(35,36,109,NULL,0),(35,37,108,NULL,0),(35,38,86,NULL,0),(36,32,105,NULL,0),(36,33,104,NULL,0),(36,36,102,NULL,0),(36,37,100,NULL,0),(36,38,103,NULL,0),(37,32,98,NULL,0),(37,33,99,NULL,0),(37,36,102,NULL,0),(37,37,100,NULL,0),(37,38,101,NULL,0),(38,6,2,NULL,0),(38,8,35,NULL,0),(38,9,5,NULL,0),(38,10,6,NULL,0),(38,12,36,NULL,0),(38,14,13,NULL,0),(38,21,25,NULL,0),(39,5,30,NULL,0),(39,6,2,NULL,0),(39,7,3,NULL,0),(39,8,11,NULL,0),(39,9,32,NULL,0),(39,10,6,NULL,0),(39,12,31,NULL,0),(39,14,22,NULL,0),(39,16,15,NULL,0),(40,5,27,NULL,0),(40,6,29,NULL,0),(40,7,3,NULL,0),(40,8,11,NULL,0),(40,12,28,NULL,0),(40,14,13,NULL,0),(40,16,15,NULL,0),(40,17,16,NULL,0),(40,18,17,NULL,0),(41,5,33,NULL,0),(41,6,2,NULL,0),(41,8,11,NULL,0),(41,10,6,NULL,0),(41,11,7,NULL,0),(41,12,34,NULL,0),(41,14,13,NULL,0),(42,5,9,NULL,0),(42,6,2,NULL,0),(42,8,11,NULL,0),(42,11,7,NULL,0),(42,12,10,NULL,0),(42,13,12,NULL,0),(42,14,13,NULL,0),(43,5,20,NULL,0),(43,9,5,NULL,0),(43,10,6,NULL,0),(43,11,7,NULL,0),(43,14,22,NULL,0),(43,15,14,NULL,0),(43,16,15,NULL,0),(43,17,16,NULL,0),(43,18,17,NULL,0),(43,19,18,NULL,0),(44,5,1,NULL,0),(44,6,2,NULL,0),(44,7,3,NULL,0),(44,8,4,NULL,0),(44,9,5,NULL,0),(44,10,6,NULL,0),(44,11,7,NULL,0),(44,12,8,NULL,0),(45,5,23,NULL,0),(45,7,3,NULL,0),(45,9,5,NULL,0),(45,10,6,NULL,0),(45,12,24,NULL,0),(45,14,13,NULL,0),(45,21,25,NULL,0),(45,22,26,NULL,0),(46,5,48,NULL,0),(46,6,29,NULL,0),(46,7,3,NULL,0),(46,8,37,NULL,0),(46,10,49,NULL,0),(46,11,7,NULL,0),(46,12,50,NULL,0),(47,5,47,NULL,0),(47,8,4,NULL,0),(47,10,39,NULL,0),(47,11,7,NULL,0),(47,12,46,NULL,0),(47,14,43,NULL,0),(47,21,44,NULL,0),(48,5,38,NULL,0),(48,6,2,NULL,0),(48,8,37,NULL,0),(48,10,42,NULL,0),(48,11,7,NULL,0),(48,12,41,NULL,0),(48,14,13,NULL,0),(48,21,40,NULL,0),(49,5,51,NULL,0),(49,6,53,NULL,0),(49,8,11,NULL,0),(49,10,45,NULL,0),(49,11,7,NULL,0),(49,12,52,NULL,0),(49,14,13,NULL,0),(49,21,54,NULL,0);
/*!40000 ALTER TABLE `properties_to_products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `properties_to_properties_categories`
--

DROP TABLE IF EXISTS `properties_to_properties_categories`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `properties_to_properties_categories` (
  `properties_id` int(11) DEFAULT NULL,
  `categories_id` int(11) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `properties_to_properties_categories`
--

LOCK TABLES `properties_to_properties_categories` WRITE;
/*!40000 ALTER TABLE `properties_to_properties_categories` DISABLE KEYS */;
/*!40000 ALTER TABLE `properties_to_properties_categories` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `properties_units`
--

DROP TABLE IF EXISTS `properties_units`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `properties_units` (
  `properties_units_id` int(11) NOT NULL AUTO_INCREMENT,
  `properties_units_title` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`properties_units_id`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `properties_units`
--

LOCK TABLES `properties_units` WRITE;
/*!40000 ALTER TABLE `properties_units` DISABLE KEYS */;
INSERT INTO `properties_units` VALUES (1,'5'),(2,'%');
/*!40000 ALTER TABLE `properties_units` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `properties_values`
--

DROP TABLE IF EXISTS `properties_values`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `properties_values` (
  `values_id` int(11) NOT NULL,
  `properties_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `values_text` varchar(1024) NOT NULL DEFAULT '',
  `values_number` float NOT NULL DEFAULT '0',
  `values_number_upto` float NOT NULL DEFAULT '0',
  `values_alt` varchar(1024) NOT NULL DEFAULT '',
  `values_prefix` varchar(8) NOT NULL DEFAULT '',
  `values_postfix` varchar(8) NOT NULL DEFAULT '',
  `values_seo_page_name` varchar(255) NOT NULL DEFAULT '',
  `values_color` varchar(8) NOT NULL DEFAULT '',
  `values_image` varchar(255) NOT NULL DEFAULT '',
  `maps_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`values_id`,`properties_id`,`language_id`),
  KEY `idx_values_id` (`values_id`),
  KEY `idx_properties_id` (`properties_id`),
  KEY `idx_language_id` (`language_id`),
  KEY `idx_values_text` (`values_text`(255)),
  KEY `idx_values_number` (`values_number`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `properties_values`
--

LOCK TABLES `properties_values` WRITE;
/*!40000 ALTER TABLE `properties_values` DISABLE KEYS */;
INSERT INTO `properties_values` VALUES (1,5,1,6,'15.87 x 12.4 x 5.83 cm; 8.12 Kilograms',16,0,'','','','15-87-x-12-4-x-5-83-cm-8-12-kilograms','','',0),(2,6,1,1,'Black',0,0,'','','','black','','',0),(3,7,1,2,'‎1.44 Inches',0,0,'','','','1-44-inches','','',0),(4,8,1,1,'Bluetooth, Wi-Fi',0,0,'','','','bluetooth-wi-fi','','',0),(5,9,1,1,'Smartphone',0,0,'','','','smartphone','','',0),(6,10,1,1,'Windows, Mac',0,0,'','','','windows-mac','','',0),(7,11,1,2,'No',0,0,'','','','no','','',0),(8,12,1,6,'TS5350',0,0,'','','','ts5350','','',0),(9,5,1,11,'‎17.13 x 12.44 x 5.71 cm; 3.9 Kilograms',0,0,'','','','17-13-x-12-44-x-5-71-cm-3-9-kilograms','','',0),(10,12,1,11,'2422Y27',2422,0,'','','','2422y27','','',0),(11,8,1,4,'Wi-Fi',0,0,'','','','wi-fi','','',0),(12,13,1,2,'802.11n, 802.11b, 802.11g',802,0,'','','','802-11n-802-11b-802-11g','','',0),(13,14,1,1,'AC 100-240v, 50/60hz',0,0,'','','','ac-100-240v-5060hz','','',0),(14,15,1,1,'600 dpi (Optical)',600,0,'','','','600-dpi-optical','','',0),(15,16,1,1,'Color, Monochrome',0,0,'','','','color-monochrome','','',0),(16,17,1,1,'24-Bit (External)',24,0,'','','','24-bit-external','','',0),(17,18,1,1,'8-Bit (External)',8,0,'','','','8-bit-external','','',0),(18,19,1,1,'LED',0,0,'','','','led','','',0),(19,20,1,1,'Maximum: 8.5 x 14\" / 21.6 x 35.6 cm',0,0,'','','','maximum-8-5-x-14-21-6-x-35-6-cm','','',0),(20,5,1,10,'10.9 x 12.5 x 7.3\" / 27.7 x 31.8 x 18.5 cm',11,0,'','','','10-9-x-12-5-x-7-3-27-7-x-31-8-x-18-5-cm','','',0),(21,14,1,4,'33 W (Maximum)',33,0,'','','','33-w-maximum','','',0),(22,14,1,3,'120 VAC, 60 Hz',120,0,'','','','120-vac-60-hz','','',0),(23,5,1,9,'36.4 x 40.3 x 20.6 cm; 8.2 Kilograms',36,0,'','','','36-4-x-40-3-x-20-6-cm-8-2-kilograms','','',0),(24,12,1,10,'4460C026',4460,0,'','','','4460c026','','',0),(25,21,1,1,'14 watts',14,0,'','','','14-watts','','',0),(26,22,1,1,'2.6 Watt Hours',3,0,'','','','2-6-watt-hours','','',0),(27,5,1,8,'7.87 x 14.76 x 12.52 inches',8,0,'','','','7-87-x-14-76-x-12-52-inches','','',0),(28,12,1,9,'C11CJ18401',0,0,'','','','b0841mrbvg','','',0),(29,6,1,3,'Gray',0,0,'','','','gray','','',0),(30,5,1,7,'7.8 x 5.39 x 2.2 inches',8,0,'','','','7-8-x-5-39-x-2-2-inches','','',0),(31,12,1,8,'B07PDNS5CZ',0,0,'','','','b07pdns5cz','','',0),(32,9,1,2,'Smartphones, PC, Laptops',0,0,'','','','smartphones-pc-laptops','','',0),(33,5,1,4,'59 x 55 x 43.5 cm; 22.95 Kilograms',59,0,'','','','59-x-55-x-43-5-cm-22-95-kilograms','','',0),(34,12,1,7,'M15140',0,0,'','','','m15140','','',0),(35,8,1,3,'Bluetooth, Wi-Fi, Ethernet',0,0,'','','','bluetooth-wi-fi-ethernet','','',0),(36,12,1,4,'B08DXBLK14',0,0,'','','','b08dxblk14','','',0),(37,8,1,2,'Wi-Fi, USB',0,0,'','','','wi-fi-usb','','',0),(38,5,1,5,'15.16 x 13.39 x 10.04 cm; 7.2 Kilograms',15,0,'','','','15-2-x-13-4-x-10-centimetres','','',0),(39,10,1,5,'‎Windows, Mac, Linux',0,0,'','','','windows-mac-linux','','',0),(40,21,1,4,'‎380 watts',0,0,'','','','380-watts','','',0),(41,12,1,5,'‎DCP-1612W',0,0,'','','','dcp-1612w','','',0),(42,10,1,4,'‎Laptop, PC, Tablet, Smartphone',0,0,'','','','laptop-pc-tablet-smartphone','','',0),(43,14,1,2,'AC 220-240v, 50/60hz',0,0,'','','','ac-220-240v-5060hz','','',0),(44,21,1,3,'460 watts',460,0,'','','','460-watts','','',0),(45,10,1,3,'Windows, Mac, Linux',0,0,'','','','windows-mac-linux','','',0),(46,12,1,2,'‎HL-L2310D',0,0,'','','','hl-l2310d','','',0),(47,5,1,2,'‎14.17 x 14.02 x 7.2 cm; 7.2 Kilograms',0,0,'','','','14-17-x-14-02-x-7-2-cm-7-2-kilograms','','',0),(48,5,1,3,'16.1 x 18.7 x 16.3 inches',16,0,'','','','16-1-x-18-7-x-16-3-inches','','',0),(49,10,1,2,'Wi-Fi, Ethernet',0,0,'','','','wi-fi-ethernet','','',0),(50,12,1,3,'B07TYHRBKP',0,0,'','','','b07tyhrbkp','','',0),(51,5,1,1,'21.22 x 20.71 x 17.13 cm; 27.9 Kilograms',21,0,'','','','21-22-x-20-71-x-17-13-cm-27-9-kilograms','','',0),(52,12,1,1,'5837357',5837360,0,'','','','5837357','','',0),(53,6,1,2,'‎Light Grey/Black',0,0,'','','','light-greyblack','','',0),(54,21,1,2,'580 watts',580,0,'','','','580-watts','','',0),(55,23,1,1,'Pastic',0,0,'','','','pastic','','',0),(56,24,1,1,'Day-Date-Month',0,0,'','','','day-date-month','','',0),(57,25,1,1,'47.8 Millimeters',48,0,'','','','47-8-millimeters','','',0),(58,26,1,2,'Round',0,0,'','','','round','','',0),(59,27,1,1,'Tang Buckle',0,0,'','','','tang-buckle','','',0),(60,28,1,1,'Quartz',0,0,'','','','quartz','','',0),(61,29,1,1,'Black',0,0,'','','','black','','',0),(62,30,1,1,'9 Inches',9,0,'','','','9-inches','','',0),(63,31,1,1,'25 Millimeters',25,0,'','','','25-millimeters','','',0),(64,23,1,4,'Leather',0,0,'','','','leather','','',0),(65,30,1,3,'Unisex',0,0,'','','','unisex','','',0),(66,25,1,3,'33 millimeters',33,0,'','','','33-millimeters','','',0),(67,27,1,3,'Deployment clasp with double push button',0,0,'','','','deployment-clasp-with-double-push-button','','',0),(68,31,1,4,'20 millimeters',20,0,'','','','20-millimeters','','',0),(69,28,1,3,'Swiss Automatic',0,0,'','','','swiss-automatic','','',0),(70,23,1,3,'Stainless Steel',0,0,'','','','stainless-steel-bracelet','','',0),(71,31,1,3,'12.7 millimeters',13,0,'','','','12-7-millimeters','','',0),(72,31,1,2,'18 millimetres',18,0,'','','','18-millimetres','','',0),(73,29,1,2,'Brown',0,0,'','','','brown','','',0),(74,24,1,2,'Day-Date',0,0,'','','','day-date','','',0),(75,28,1,2,'Quarz (Japanisch)',0,0,'','','','quarz-japanisch','','',0),(76,25,1,2,'36 millimetres',36,0,'','','','36-millimetres','','',0),(77,23,1,2,'Edelstahl',0,0,'','','','edelstahl','','',0),(78,30,1,2,'Men\'s standard',0,0,'','','','mens-standard','','',0),(79,27,1,2,'Buckle',0,0,'','','','buckle','','',0),(80,32,1,2,'26.1 x 25.4 x 46.4 inches',26,0,'','','','26-1-x-25-4-x-46-4-inches','','',0),(81,33,1,3,'30 pounds',30,0,'','','','30-pounds','','',0),(82,34,1,2,'Ergonomic',0,0,'','','','ergonomic','','',0),(83,35,1,1,'Modern',0,0,'','','','modern','','',0),(84,36,1,1,'Faux Leather',0,0,'','','','leather','','',0),(85,37,1,1,'Polished',0,0,'','','','polished','','',0),(86,38,1,1,'Black',0,0,'','','','black','','',0),(87,38,1,6,'Red, Black',0,0,'','','','red-black','','',0),(88,36,1,5,'Nylon',0,0,'','','','nylon','','',0),(89,32,1,7,'25 x 25 x 42 inches',25,0,'','','','25-x-25-x-42-inches','','',0),(90,33,1,8,'26 Pounds',26,0,'','','','26-pounds','','',0),(91,35,1,2,'Traditional',0,0,'','','','traditional','','',0),(92,38,1,5,'Chrome',0,0,'','','','chrome','','',0),(93,33,1,7,'10 kg',10,0,'','','','10-kg','','',0),(94,32,1,6,'34 x 25 x 25 inches',34,0,'','','','34-x-25-x-25-inches','','',0),(95,38,1,4,'White',0,0,'','','','white','','',0),(96,33,1,6,'8.85 kg',9,0,'','','','8-85-kg','','',0),(97,32,1,5,'36 x 23.7 x 23.7 inches',36,0,'','','','36-x-23-7-x-23-7-inches','','',0),(98,32,1,4,'31 x 20 x 30 inches',31,0,'','','','31-x-20-x-30-inches','','',0),(99,33,1,5,'91.2 pounds',91,0,'','','','91-2-pounds','','',0),(100,37,1,3,'Laminate',0,0,'','','','laminate','','',0),(101,38,1,3,'Reclaimed Pine',0,0,'','','','reclaimed-pine','','',0),(102,36,1,4,'Engineered Wood',0,0,'','','','engineered-wood','','',0),(103,38,1,2,'Grey Oak/Silver',0,0,'','','','grey-oaksilver','','',0),(104,33,1,4,'25 kg',25,0,'','','','25-kg','','',0),(105,32,1,3,'63 x 47.2 x 28.7 inches',63,0,'','','','63-x-25-x-42-inches','','',0),(106,32,1,1,'32.8 x 24.3 x 5.5 inches',33,0,'','','','32-8-x-24-3-x-5-5-inches','','',0),(107,33,1,1,'50.7 pounds',51,0,'','','','50-7-pounds','','',0),(108,37,1,2,'Matte',0,0,'','','','matte','','',0),(109,36,1,3,'Metal, Plastic',0,0,'','','','metal-plastic','','',0),(110,33,1,2,'51 kg',51,0,'','','','51-kg','','',0),(111,36,1,2,'Plastic',0,0,'','','','plastic','','',0);
/*!40000 ALTER TABLE `properties_values` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `purchase_api`
--

DROP TABLE IF EXISTS `purchase_api`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `purchase_api` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL DEFAULT '',
  `class` varchar(255) NOT NULL DEFAULT '',
  `active` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `purchase_api`
--

LOCK TABLES `purchase_api` WRITE;
/*!40000 ALTER TABLE `purchase_api` DISABLE KEYS */;
/*!40000 ALTER TABLE `purchase_api` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `purchase_api_orders`
--

DROP TABLE IF EXISTS `purchase_api_orders`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `purchase_api_orders` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `purchase_api_id` int(11) NOT NULL DEFAULT '0',
  `code` varchar(255) NOT NULL DEFAULT '',
  `invoice` varchar(255) NOT NULL DEFAULT '',
  `create_datetime` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `close` tinyint(1) NOT NULL DEFAULT '0',
  `close_datetime` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `purchase_api_orders`
--

LOCK TABLES `purchase_api_orders` WRITE;
/*!40000 ALTER TABLE `purchase_api_orders` DISABLE KEYS */;
/*!40000 ALTER TABLE `purchase_api_orders` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `recurly`
--

DROP TABLE IF EXISTS `recurly`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `recurly` (
  `recurly_id` int(11) NOT NULL AUTO_INCREMENT,
  `xml` text NOT NULL,
  PRIMARY KEY (`recurly_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `recurly`
--

LOCK TABLES `recurly` WRITE;
/*!40000 ALTER TABLE `recurly` DISABLE KEYS */;
/*!40000 ALTER TABLE `recurly` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `regular_offers`
--

DROP TABLE IF EXISTS `regular_offers`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `regular_offers` (
  `customers_id` int(11) NOT NULL,
  `period` int(11) NOT NULL DEFAULT '0',
  `date_end` date DEFAULT NULL,
  `token` varchar(32) NOT NULL DEFAULT '',
  `date_send` date DEFAULT NULL,
  PRIMARY KEY (`customers_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `regular_offers`
--

LOCK TABLES `regular_offers` WRITE;
/*!40000 ALTER TABLE `regular_offers` DISABLE KEYS */;
/*!40000 ALTER TABLE `regular_offers` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `reviews`
--

DROP TABLE IF EXISTS `reviews`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `reviews` (
  `reviews_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` int(11) NOT NULL DEFAULT '0',
  `customers_id` int(11) DEFAULT NULL,
  `customers_name` varchar(64) NOT NULL DEFAULT '',
  `reviews_rating` int(1) DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `reviews_read` int(5) NOT NULL DEFAULT '0',
  `status` tinyint(1) NOT NULL DEFAULT '0',
  `new` tinyint(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (`reviews_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `reviews`
--

LOCK TABLES `reviews` WRITE;
/*!40000 ALTER TABLE `reviews` DISABLE KEYS */;
/*!40000 ALTER TABLE `reviews` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `reviews_description`
--

DROP TABLE IF EXISTS `reviews_description`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `reviews_description` (
  `reviews_id` int(11) NOT NULL DEFAULT '0',
  `languages_id` int(11) NOT NULL DEFAULT '0',
  `reviews_text` text NOT NULL,
  PRIMARY KEY (`reviews_id`,`languages_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `reviews_description`
--

LOCK TABLES `reviews_description` WRITE;
/*!40000 ALTER TABLE `reviews_description` DISABLE KEYS */;
/*!40000 ALTER TABLE `reviews_description` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sales_filters`
--

DROP TABLE IF EXISTS `sales_filters`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `sales_filters` (
  `sales_filters_id` int(11) NOT NULL AUTO_INCREMENT,
  `sales_filter_name` varchar(255) NOT NULL DEFAULT '',
  `sales_filter_vals` text,
  PRIMARY KEY (`sales_filters_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sales_filters`
--

LOCK TABLES `sales_filters` WRITE;
/*!40000 ALTER TABLE `sales_filters` DISABLE KEYS */;
/*!40000 ALTER TABLE `sales_filters` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `scart`
--

DROP TABLE IF EXISTS `scart`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `scart` (
  `scartid` int(11) NOT NULL AUTO_INCREMENT,
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `basket_id` int(11) NOT NULL DEFAULT '0',
  `dateadded` varchar(8) NOT NULL DEFAULT '',
  `datemodified` varchar(8) NOT NULL DEFAULT '',
  `note` text NOT NULL,
  `recovered` tinyint(4) NOT NULL DEFAULT '0',
  `workedout` tinyint(4) NOT NULL DEFAULT '0',
  `contacted` tinyint(4) NOT NULL DEFAULT '0',
  `offered_discount` tinyint(4) DEFAULT '0',
  PRIMARY KEY (`scartid`),
  UNIQUE KEY `scartid` (`scartid`),
  KEY `customers_id` (`customers_id`,`basket_id`),
  KEY `scart_offered_discount_index` (`offered_discount`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `scart`
--

LOCK TABLES `scart` WRITE;
/*!40000 ALTER TABLE `scart` DISABLE KEYS */;
/*!40000 ALTER TABLE `scart` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `seo_redirect`
--

DROP TABLE IF EXISTS `seo_redirect`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `seo_redirect` (
  `seo_redirect_id` int(11) NOT NULL AUTO_INCREMENT,
  `old_url` varchar(512) NOT NULL DEFAULT '',
  `new_url` varchar(512) NOT NULL DEFAULT '',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `redirect_code` varchar(5) NOT NULL DEFAULT '301',
  `status` int(1) NOT NULL DEFAULT '1',
  `last_checked` datetime DEFAULT NULL,
  `check_details` varchar(2048) NOT NULL DEFAULT '',
  `regexp` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`seo_redirect_id`),
  KEY `old_url` (`old_url`(255)),
  KEY `idx_status` (`status`,`platform_id`,`old_url`(255)),
  KEY `idx_last_checked` (`last_checked`),
  KEY `idx_new_url` (`new_url`(255))
) ENGINE=InnoDB AUTO_INCREMENT=531 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `seo_redirect`
--

LOCK TABLES `seo_redirect` WRITE;
/*!40000 ALTER TABLE `seo_redirect` DISABLE KEYS */;
INSERT INTO `seo_redirect` VALUES (1,'redmiwatch2liteblue-redmi-watch-2-lite-79','smart-devices',1,'301',1,NULL,'',0),(2,'redmiwatch2liteblue-79','smart-devices',7,'301',1,NULL,'',0),(3,'redmiwatch2liteblue-79','smart-devices',8,'301',1,NULL,'',0),(4,'redmiwatch2liteblue-79','smart-devices',9,'301',1,NULL,'',0),(5,'redmiwatch2liteblue-79','smart-devices',10,'301',1,NULL,'',0),(6,'dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch','women-s',1,'301',1,NULL,'',0),(7,'dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch','women-s',4,'301',1,NULL,'',0),(8,'dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch','women-s',5,'301',1,NULL,'',0),(9,'dkny-women-s-ny2146-soho-colored-chronograph-bracelet-watch','women-s',6,'301',1,NULL,'',0),(10,'dkny-womens-ny2146-soho-colored-chronograph-bracelet-watch','women-s',7,'301',1,NULL,'',0),(11,'dkny-womens-ny2146-soho-colored-chronograph-bracelet-watch','women-s',8,'301',1,NULL,'',0),(13,'puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial','women-s',1,'301',1,NULL,'',0),(14,'puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial','women-s',4,'301',1,NULL,'',0),(15,'puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial','women-s',5,'301',1,NULL,'',0),(16,'puma-women-s-motor-white-polyurethane-quartz-watch-with-black-dial','women-s',6,'301',1,NULL,'',0),(17,'puma-womens-motor-white-polyurethane-quartz-watch-with-black-dial','women-s',7,'301',1,NULL,'',0),(18,'puma-womens-motor-white-polyurethane-quartz-watch-with-black-dial','women-s',8,'301',1,NULL,'',0),(20,'puma-women-s-motor-pink-polyurethane-analog-quartz-watch','women-s',1,'301',1,NULL,'',0),(21,'puma-women-s-motor-pink-polyurethane-analog-quartz-watch','women-s',4,'301',1,NULL,'',0),(22,'puma-women-s-motor-pink-polyurethane-analog-quartz-watch','women-s',5,'301',1,NULL,'',0),(23,'puma-women-s-motor-pink-polyurethane-analog-quartz-watch','women-s',6,'301',1,NULL,'',0),(24,'puma-womens-motor-pink-polyurethane-analog-quartz-watch','women-s',7,'301',1,NULL,'',0),(25,'puma-womens-motor-pink-polyurethane-analog-quartz-watch','women-s',8,'301',1,NULL,'',0),(27,'guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','men-s',1,'301',1,NULL,'',0),(28,'guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','men-s',4,'301',1,NULL,'',0),(29,'guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','men-s',5,'301',1,NULL,'',0),(30,'guess-men-s-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','men-s',6,'301',1,NULL,'',0),(31,'guess-mens-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','men-s',7,'301',1,NULL,'',0),(32,'guess-mens-u25004l1-silver-stainless-steel-quartz-watch-with-silver-dial','men-s',8,'301',1,NULL,'',0),(34,'tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch','men-s',1,'301',1,NULL,'',0),(35,'tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch','men-s',4,'301',1,NULL,'',0),(36,'tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch','men-s',5,'301',1,NULL,'',0),(37,'tommy-hilfiger-men-s-skywinder-stainless-steel-and-leather-strap-watch','men-s',6,'301',1,NULL,'',0),(38,'tommy-hilfiger-mens-skywinder-stainless-steel-and-leather-strap-watch','men-s',7,'301',1,NULL,'',0),(39,'tommy-hilfiger-mens-skywinder-stainless-steel-and-leather-strap-watch','men-s',8,'301',1,NULL,'',0),(41,'tommy-hilfiger-men-s-1790708-black-silicone-sport-watch','men-s',1,'301',1,NULL,'',0),(42,'tommy-hilfiger-men-s-1790708-black-silicone-sport-watch','men-s',4,'301',1,NULL,'',0),(43,'tommy-hilfiger-men-s-1790708-black-silicone-sport-watch','men-s',5,'301',1,NULL,'',0),(44,'tommy-hilfiger-men-s-1790708-black-silicone-sport-watch','men-s',6,'301',1,NULL,'',0),(45,'tommy-hilfiger-mens-1790708-black-silicone-sport-watch','men-s',7,'301',1,NULL,'',0),(46,'tommy-hilfiger-mens-1790708-black-silicone-sport-watch','men-s',8,'301',1,NULL,'',0),(48,'tommy-hilfiger-men-s-black-silicone-quartz-watch','men-s',1,'301',1,NULL,'',0),(49,'tommy-hilfiger-men-s-black-silicone-quartz-watch','men-s',4,'301',1,NULL,'',0),(50,'tommy-hilfiger-men-s-black-silicone-quartz-watch','men-s',5,'301',1,NULL,'',0),(51,'tommy-hilfiger-men-s-black-silicone-quartz-watch','men-s',6,'301',1,NULL,'',0),(52,'tommy-hilfiger-mens-black-silicone-quartz-watch','men-s',7,'301',1,NULL,'',0),(53,'tommy-hilfiger-mens-black-silicone-quartz-watch','men-s',8,'301',1,NULL,'',0),(55,'gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono','men-s',1,'301',1,NULL,'',0),(56,'gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono','men-s',4,'301',1,NULL,'',0),(57,'gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono','men-s',5,'301',1,NULL,'',0),(58,'gucci-men-s-ya126238-timeless-grey-dial-stainless-steel-chrono','men-s',6,'301',1,NULL,'',0),(59,'gucci-mens-ya126238-timeless-grey-dial-stainless-steel-chrono','men-s',7,'301',1,NULL,'',0),(60,'gucci-mens-ya126238-timeless-grey-dial-stainless-steel-chrono','men-s',8,'301',1,NULL,'',0),(62,'dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white','women-s',1,'301',1,NULL,'',0),(63,'dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white','women-s',4,'301',1,NULL,'',0),(64,'dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white','women-s',5,'301',1,NULL,'',0),(65,'dkny-women-s-ny8183-gold-stainless-steel-quartz-watch-with-white','women-s',6,'301',1,NULL,'',0),(66,'dkny-womens-ny8183-gold-stainless-steel-quartz-watch-with-white-zusa','women-s',7,'301',1,NULL,'',0),(67,'dkny-womens-ny8183-gold-stainless-steel-quartz-watch-with-white-zusa','women-s',8,'301',1,NULL,'',0),(69,'interlocking-g-small-brown-dial-ladies-watch','women-s',1,'301',1,NULL,'',0),(70,'interlocking-g-small-brown-dial-ladies-watch','women-s',4,'301',1,NULL,'',0),(71,'interlocking-g-small-brown-dial-ladies-watch','women-s',5,'301',1,NULL,'',0),(72,'interlocking-g-small-brown-dial-ladies-watch','women-s',6,'301',1,NULL,'',0),(73,'interlocking-g-small-brown-dial-ladies-watch','women-s',7,'301',1,NULL,'',0),(74,'interlocking-g-small-brown-dial-ladies-watch','women-s',8,'301',1,NULL,'',0),(76,'gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','women-s',1,'301',1,NULL,'',0),(77,'gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','women-s',4,'301',1,NULL,'',0),(78,'gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','women-s',5,'301',1,NULL,'',0),(79,'gucci-women-s-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','women-s',6,'301',1,NULL,'',0),(80,'gucci-womens-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','women-s',7,'301',1,NULL,'',0),(81,'gucci-womens-ya129444-gucci-u-play-collection-stainless-steel-watch-with-striped-nylon-band','women-s',8,'301',1,NULL,'',0),(83,'gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp','men-s',1,'301',1,NULL,'',0),(84,'gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp','men-s',4,'301',1,NULL,'',0),(85,'gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp','men-s',5,'301',1,NULL,'',0),(86,'gucci-men-s-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap-sp','men-s',6,'301',1,NULL,'',0),(87,'gucci-mens-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap','men-s',7,'301',1,NULL,'',0),(88,'gucci-mens-ya133202-grammy-xl-interlocking-yellow-dial-black-leather-strap','men-s',8,'301',1,NULL,'',0),(90,'casio-men-s-g100-1bv-g-shock-watch-in-black-resin','for-all',1,'301',1,NULL,'',0),(91,'casio-men-s-g100-1bv-g-shock-watch-in-black-resin','for-all',4,'301',1,NULL,'',0),(92,'casio-men-s-g100-1bv-g-shock-watch-in-black-resin','for-all',5,'301',1,NULL,'',0),(93,'casio-men-s-g100-1bv-g-shock-watch-in-black-resin','for-all',6,'301',1,NULL,'',0),(94,'casio-g-shock-g100-1bv-wrist-watch-price-1200','for-all',7,'301',1,NULL,'',0),(95,'casio-g-shock-g100-1bv-wrist-watch-price-1200','for-all',8,'301',1,NULL,'',0),(97,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital','women-s',1,'301',1,NULL,'',0),(98,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital','women-s',4,'301',1,NULL,'',0),(99,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital','women-s',5,'301',1,NULL,'',0),(100,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital','women-s',6,'301',1,NULL,'',0),(101,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital1','women-s',7,'301',1,NULL,'',0),(102,'casio-baby-g-bg169g-7b-face-protector-ion-plated-metal-white-rose-gold-watch-digital1','women-s',8,'301',1,NULL,'',0),(104,'casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','men-s',1,'301',1,NULL,'',0),(105,'casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','men-s',4,'301',1,NULL,'',0),(106,'casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','men-s',5,'301',1,NULL,'',0),(107,'casio-men-s-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','men-s',6,'301',1,NULL,'',0),(108,'casio-mens-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','men-s',7,'301',1,NULL,'',0),(109,'casio-mens-core-mtp1192e-7a-brown-leather-quartz-watch-with-white-dial','men-s',8,'301',1,NULL,'',0),(111,'casio-general-men-s-watches-edifice-digital-analog-combination','men-s',1,'301',1,NULL,'',0),(112,'casio-general-men-s-watches-edifice-digital-analog-combination','men-s',4,'301',1,NULL,'',0),(113,'casio-general-men-s-watches-edifice-digital-analog-combination','men-s',5,'301',1,NULL,'',0),(114,'casio-general-men-s-watches-edifice-digital-analog-combination','men-s',6,'301',1,NULL,'',0),(115,'casio-general-mens-watches-edifice-digital-analog-combination','men-s',7,'301',1,NULL,'',0),(116,'casio-general-mens-watches-edifice-digital-analog-combination','men-s',8,'301',1,NULL,'',0),(118,'casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p','men-s',1,'301',1,NULL,'',0),(119,'casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p','men-s',4,'301',1,NULL,'',0),(120,'casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p','men-s',5,'301',1,NULL,'',0),(121,'casio-men-s-w753-2av-blue-resin-quartz-watch-with-digital-dial-p','men-s',6,'301',1,NULL,'',0),(122,'casio-mens-w753-2av-blue-resin-quartz-watch-with-digital-dial','men-s',7,'301',1,NULL,'',0),(123,'casio-mens-w753-2av-blue-resin-quartz-watch-with-digital-dial','men-s',8,'301',1,NULL,'',0),(125,'nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','women-s',1,'301',1,NULL,'',0),(126,'nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','women-s',4,'301',1,NULL,'',0),(127,'nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','women-s',5,'301',1,NULL,'',0),(128,'nemesis-women-s-classic-yellow-plant-art-leather-cuff-band-watch','women-s',6,'301',1,NULL,'',0),(129,'nemesis-womens-classic-yellow-plant-art-leather-cuff-band-watch','women-s',7,'301',1,NULL,'',0),(130,'nemesis-womens-classic-yellow-plant-art-leather-cuff-band-watch','women-s',8,'301',1,NULL,'',0),(132,'nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch','men-s',1,'301',1,NULL,'',0),(133,'nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch','men-s',4,'301',1,NULL,'',0),(134,'nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch','men-s',5,'301',1,NULL,'',0),(135,'nemesis-men-s-brown-wide-leather-cuff-band-analog-brown-dial-watch','men-s',6,'301',1,NULL,'',0),(136,'nemesis-mens-brown-wide-leather-cuff-band-analog-brown-dial-watch','men-s',7,'301',1,NULL,'',0),(137,'nemesis-mens-brown-wide-leather-cuff-band-analog-brown-dial-watch','men-s',8,'301',1,NULL,'',0),(139,'nemesis-men-s-wide-sunrise-black-leather-cuff-watch','men-s',1,'301',1,NULL,'',0),(140,'nemesis-men-s-wide-sunrise-black-leather-cuff-watch','men-s',4,'301',1,NULL,'',0),(141,'nemesis-men-s-wide-sunrise-black-leather-cuff-watch','men-s',5,'301',1,NULL,'',0),(142,'nemesis-men-s-wide-sunrise-black-leather-cuff-watch','men-s',6,'301',1,NULL,'',0),(143,'nemesis-mens-wide-sunrise-black-leather-cuff-watch','men-s',7,'301',1,NULL,'',0),(144,'nemesis-mens-wide-sunrise-black-leather-cuff-watch','men-s',8,'301',1,NULL,'',0),(146,'cartier-men-s-santos-18k-gold-and-steel-automatic-watch','men-s',1,'301',1,NULL,'',0),(147,'cartier-men-s-santos-18k-gold-and-steel-automatic-watch','men-s',4,'301',1,NULL,'',0),(148,'cartier-men-s-santos-18k-gold-and-steel-automatic-watch','men-s',5,'301',1,NULL,'',0),(149,'cartier-men-s-santos-18k-gold-and-steel-automatic-watch','men-s',6,'301',1,NULL,'',0),(150,'cartier-mens-santos-18k-gold-and-steel-automatic-watch1','men-s',7,'301',1,NULL,'',0),(151,'cartier-mens-santos-18k-gold-and-steel-automatic-watch1','men-s',8,'301',1,NULL,'',0),(153,'edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','men-s',1,'301',1,NULL,'',0),(154,'edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','men-s',4,'301',1,NULL,'',0),(155,'edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','men-s',5,'301',1,NULL,'',0),(156,'edox-men-s-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','men-s',6,'301',1,NULL,'',0),(157,'edox-mens-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','men-s',7,'301',1,NULL,'',0),(158,'edox-mens-les-vauberts-automatic-yellow-goldtone-stainless-steel-mechanical-a','men-s',8,'301',1,NULL,'',0),(160,'edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch','men-s',1,'301',1,NULL,'',0),(161,'edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch','men-s',4,'301',1,NULL,'',0),(162,'edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch','men-s',5,'301',1,NULL,'',0),(163,'edox-men-s-wrc-stainless-steel-multifunction-chronograph-watch','men-s',6,'301',1,NULL,'',0),(164,'edox-mens-wrc-stainless-steel-multifunction-chronograph-watch','men-s',7,'301',1,NULL,'',0),(165,'edox-mens-wrc-stainless-steel-multifunction-chronograph-watch','men-s',8,'301',1,NULL,'',0),(167,'concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch','men-s',1,'301',1,NULL,'',0),(168,'concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch','men-s',4,'301',1,NULL,'',0),(169,'concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch','men-s',5,'301',1,NULL,'',0),(170,'concord-men-s-saratoga-black-stainless-steel-swiss-quartz-watch','men-s',6,'301',1,NULL,'',0),(171,'concord-mens-saratoga-black-stainless-steel-swiss-quartz-watch','men-s',7,'301',1,NULL,'',0),(172,'concord-mens-saratoga-black-stainless-steel-swiss-quartz-watch','men-s',8,'301',1,NULL,'',0),(174,'citizen-eco-drive-silver-tone-men','men-s',1,'301',1,NULL,'',0),(175,'citizen-eco-drive-silver-tone-men','men-s',4,'301',1,NULL,'',0),(176,'citizen-eco-drive-silver-tone-men','men-s',5,'301',1,NULL,'',0),(177,'citizen-eco-drive-silver-tone-men','men-s',6,'301',1,NULL,'',0),(178,'citizen-eco-drive-silver-tone-men','men-s',7,'301',1,NULL,'',0),(179,'citizen-eco-drive-silver-tone-men','men-s',8,'301',1,NULL,'',0),(181,'citizen-men-s-eco-drive-primo-black-blue-chronograph-watch','men-s',1,'301',1,NULL,'',0),(182,'citizen-men-s-eco-drive-primo-black-blue-chronograph-watch','men-s',4,'301',1,NULL,'',0),(183,'citizen-men-s-eco-drive-primo-black-blue-chronograph-watch','men-s',5,'301',1,NULL,'',0),(184,'citizen-men-s-eco-drive-primo-black-blue-chronograph-watch','men-s',6,'301',1,NULL,'',0),(185,'citizen-mens-eco-drive-primo-black-blue-chronograph-watch','men-s',7,'301',1,NULL,'',0),(186,'citizen-mens-eco-drive-primo-black-blue-chronograph-watch','men-s',8,'301',1,NULL,'',0),(188,'citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','men-s',1,'301',1,NULL,'',0),(189,'citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','men-s',4,'301',1,NULL,'',0),(190,'citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','men-s',5,'301',1,NULL,'',0),(191,'citizen-men-s-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','men-s',6,'301',1,NULL,'',0),(192,'citizen-mens-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','men-s',7,'301',1,NULL,'',0),(193,'citizen-mens-eco-drive-at2215-07e-black-leather-eco-drive-watch-with-black-dial','men-s',8,'301',1,NULL,'',0),(195,'citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','men-s',1,'301',1,NULL,'',0),(196,'citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','men-s',4,'301',1,NULL,'',0),(197,'citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','men-s',5,'301',1,NULL,'',0),(198,'citizen-men-s-bj8050-08e-eco-drive-professional-diver-black-sport-watch','men-s',6,'301',1,NULL,'',0),(199,'citizen-mens-bj8050-08e-eco-drive-professional-diver-black-sport-watch','men-s',7,'301',1,NULL,'',0),(200,'citizen-mens-bj8050-08e-eco-drive-professional-diver-black-sport-watch','men-s',8,'301',1,NULL,'',0),(202,'chasy-royal-london-41003-03','for-all',1,'301',1,NULL,'',0),(203,'chasy-royal-london-41003-03','for-all',4,'301',1,NULL,'',0),(204,'chasy-royal-london-41003-03','for-all',5,'301',1,NULL,'',0),(205,'chasy-royal-london-41003-03','for-all',6,'301',1,NULL,'',0),(206,'royal-london-41003-03','for-all',7,'301',1,NULL,'',0),(207,'royal-london-41003-03','for-all',8,'301',1,NULL,'',0),(209,'cozy-sleep-queen-mattress','mattress',1,'301',1,NULL,'',0),(210,'edlp-deal-cozy-sleep-queen-mattress','mattress',4,'301',1,NULL,'',0),(211,'edlp-deal-cozy-sleep-queen-mattress','mattress',5,'301',1,NULL,'',0),(212,'edlp-deal-cozy-sleep-queen-mattress','mattress',6,'301',1,NULL,'',0),(213,'cozy-sleep-queen-mattress','mattress',7,'301',1,NULL,'',0),(214,'cozy-sleep-queen-mattress','mattress',8,'301',1,NULL,'',0),(216,'cozy-sleep-double-mattress','mattress',1,'301',1,NULL,'',0),(217,'edlp-deal-cozy-sleep-double-mattress','mattress',4,'301',1,NULL,'',0),(218,'edlp-deal-cozy-sleep-double-mattress','mattress',5,'301',1,NULL,'',0),(219,'edlp-deal-cozy-sleep-double-mattress','mattress',6,'301',1,NULL,'',0),(220,'cozy-sleep-double-mattress','mattress',7,'301',1,NULL,'',0),(221,'cozy-sleep-double-mattress','mattress',8,'301',1,NULL,'',0),(223,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462','bedroom-suites',1,'301',1,NULL,'',0),(224,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462','bedroom-suites',4,'301',1,NULL,'',0),(225,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462','bedroom-suites',5,'301',1,NULL,'',0),(226,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm-462','bedroom-suites',6,'301',1,NULL,'',0),(227,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm','bedroom-suites',7,'301',1,NULL,'',0),(228,'country-6pcs-package-1xqb2xbs1xtb1xdt1xdm','bedroom-suites',8,'301',1,NULL,'',0),(230,'jack-5-piece-king-bedroom-suites','bedroom-suites',1,'301',1,NULL,'',0),(231,'edlp-deal-jack-5pce-king-bedroom-package-1xkb2xbs1xdt1xdm','bedroom-suites',4,'301',1,NULL,'',0),(232,'edlp-deal-jack-5pce-king-bedroom-package-1xkb2xbs1xdt1xdm','bedroom-suites',5,'301',1,NULL,'',0),(233,'edlp-deal-jack-5pce-king-bedroom-package-1xkb2xbs1xdt1xdm','bedroom-suites',6,'301',1,NULL,'',0),(234,'jack-5-piece-king-bedroom-suite','bedroom-suites',7,'301',1,NULL,'',0),(235,'jack-5-piece-king-bedroom-suite','bedroom-suites',8,'301',1,NULL,'',0),(237,'jack-4-piece-king-bedroom-suites','bedroom-suites',1,'301',1,NULL,'',0),(238,'edlp-deal-jack-4pce-king-bedroom-package-1xkb2xbs1xtb','bedroom-suites',4,'301',1,NULL,'',0),(239,'edlp-deal-jack-4pce-king-bedroom-package-1xkb2xbs1xtb','bedroom-suites',5,'301',1,NULL,'',0),(240,'edlp-deal-jack-4pce-king-bedroom-package-1xkb2xbs1xtb','bedroom-suites',6,'301',1,NULL,'',0),(241,'jack-4-piece-king-bedroom-suite','bedroom-suites',7,'301',1,NULL,'',0),(242,'jack-4-piece-king-bedroom-suite','bedroom-suites',8,'301',1,NULL,'',0),(244,'hamptons-5-piece-queen-bedroom-suites','bedroom-suites',1,'301',1,NULL,'',0),(245,'edlp-deal-hamptons-5pcs-package-1xqb2xbs1xdt1xdm','bedroom-suites',4,'301',1,NULL,'',0),(246,'edlp-deal-hamptons-5pcs-package-1xqb2xbs1xdt1xdm','bedroom-suites',5,'301',1,NULL,'',0),(247,'edlp-deal-hamptons-5pcs-package-1xqb2xbs1xdt1xdm','bedroom-suites',6,'301',1,NULL,'',0),(248,'pham02-05a201','bedroom-suites',7,'301',1,NULL,'',0),(249,'pham02-05a201','bedroom-suites',8,'301',1,NULL,'',0),(251,'brolly-quilted-fitted-mattress-protector-king','accessories',1,'301',1,NULL,'',0),(252,'edlp-deal-brolly-quilted-fitted-mattress-protector-king','accessories',4,'301',1,NULL,'',0),(253,'edlp-deal-brolly-quilted-fitted-mattress-protector-king','accessories',5,'301',1,NULL,'',0),(254,'brolly-quilted-fitted-mattress-protector-king','accessories',6,'301',1,NULL,'',0),(255,'00mpkq-010000-k','accessories',7,'301',1,NULL,'',0),(256,'00mpkq-010000-k','accessories',8,'301',1,NULL,'',0),(258,'brolly-quilted-fitted-mattress-protector-queen','accessories',1,'301',1,NULL,'',0),(259,'edlp-deal-brolly-quilted-fitted-mattress-protector-queen','accessories',4,'301',1,NULL,'',0),(260,'edlp-deal-brolly-quilted-fitted-mattress-protector-queen','accessories',5,'301',1,NULL,'',0),(261,'edlp-deal-brolly-quilted-fitted-mattress-protector-queen','accessories',6,'301',1,NULL,'',0),(262,'brolly-quilted-fitted-mattress-protector-queen','accessories',7,'301',1,NULL,'',0),(263,'brolly-quilted-fitted-mattress-protector-queen','accessories',8,'301',1,NULL,'',0),(265,'messina-cushion-turquorise','accessories',1,'301',1,NULL,'',0),(266,'messina-cushion-turquorise','accessories',4,'301',1,NULL,'',0),(267,'messina-cushion-turquorise','accessories',5,'301',1,NULL,'',0),(268,'messina-cushion-turquorise','accessories',6,'301',1,NULL,'',0),(269,'furtex','accessories',7,'301',1,NULL,'',0),(270,'furtex','accessories',8,'301',1,NULL,'',0),(272,'metrix-cushion-orange','accessories',1,'301',1,NULL,'',0),(273,'metrix-cushion-orange','accessories',4,'301',1,NULL,'',0),(274,'metrix-cushion-orange','accessories',5,'301',1,NULL,'',0),(275,'metrix-cushion-orange','accessories',6,'301',1,NULL,'',0),(276,'22898c-furtex','accessories',7,'301',1,NULL,'',0),(277,'22898c-furtex','accessories',8,'301',1,NULL,'',0),(279,'clara-throw-lime','accessories',1,'301',1,NULL,'',0),(280,'clara-throw-lime','accessories',4,'301',1,NULL,'',0),(281,'clara-throw-lime','accessories',5,'301',1,NULL,'',0),(282,'clara-throw-lime','accessories',6,'301',1,NULL,'',0),(283,'23077t-furtex','accessories',7,'301',1,NULL,'',0),(284,'23077t-furtex','accessories',8,'301',1,NULL,'',0),(286,'clara-throw-peacock','accessories',1,'301',1,NULL,'',0),(287,'clara-throw-peacock','accessories',4,'301',1,NULL,'',0),(288,'clara-throw-peacock','accessories',5,'301',1,NULL,'',0),(289,'clara-throw-peacock','accessories',6,'301',1,NULL,'',0),(290,'23078t-furtex','accessories',7,'301',1,NULL,'',0),(291,'23078t-furtex','accessories',8,'301',1,NULL,'',0),(293,'olivia-3-drawer-dressing-table','clearance',1,'301',1,NULL,'',0),(294,'olivia-3-drawer-dressing-table','clearance',4,'301',1,NULL,'',0),(295,'olivia-3-drawer-dressing-table','clearance',5,'301',1,NULL,'',0),(296,'olivia-3-drawer-dressing-table','clearance',6,'301',1,NULL,'',0),(297,'olivia-3-drawer-dressing-table','clearance',7,'301',1,NULL,'',0),(298,'olivia-3-drawer-dressing-table','clearance',8,'301',1,NULL,'',0),(300,'clayton-3rr-2rr-brown','clearance',1,'301',1,NULL,'',0),(301,'clayton32-r8308-brown','clearance',4,'301',1,NULL,'',0),(302,'clayton32-r8308-brown','clearance',5,'301',1,NULL,'',0),(303,'clayton32-r8308-brown','clearance',6,'301',1,NULL,'',0),(304,'clayton-recliner-lounge-suite','clearance',7,'301',1,NULL,'',0),(305,'clayton-recliner-lounge-suite','clearance',8,'301',1,NULL,'',0),(307,'clayton-3rr-2rr-sr-brown','clearance',1,'301',1,NULL,'',0),(308,'clayton321-r8308-brown','clearance',4,'301',1,NULL,'',0),(309,'clayton321-r8308-brown','clearance',5,'301',1,NULL,'',0),(310,'clayton321-r8308-brown','clearance',6,'301',1,NULL,'',0),(311,'clayton321-r8308-brown-clayton-recliner-lounge-suite','clearance',7,'301',1,NULL,'',0),(312,'clayton321-r8308-brown-clayton-recliner-lounge-suite','clearance',8,'301',1,NULL,'',0),(314,'new-veronica-4pcs-package-1xqb-2xbs-1xtb','bedroom-suites',1,'301',1,NULL,'',0),(315,'veronicaqueen4-new','bedroom-suites',4,'301',1,NULL,'',0),(316,'veronicaqueen4-new','bedroom-suites',5,'301',1,NULL,'',0),(317,'veronicaqueen4-new','bedroom-suites',6,'301',1,NULL,'',0),(318,'veronica-4-piece-queen-bedroom-suite','bedroom-suites',7,'301',1,NULL,'',0),(319,'veronica-4-piece-queen-bedroom-suite','bedroom-suites',8,'301',1,NULL,'',0),(321,'mona-1237-red','clearance',1,'301',1,NULL,'',0),(322,'mona-1237-red','clearance',4,'301',1,NULL,'',0),(323,'mona-1237-red','clearance',5,'301',1,NULL,'',0),(324,'mona-1237-red','clearance',6,'301',1,NULL,'',0),(325,'mona-1237-red','clearance',7,'301',1,NULL,'',0),(326,'mona-1237-red','clearance',8,'301',1,NULL,'',0),(328,'michael-150-dining-package-black-1-table-6-blue-chairs','clearance',1,'301',1,NULL,'',0),(329,'michael-150blk-package','clearance',4,'301',1,NULL,'',0),(330,'michael-150blk-package','clearance',5,'301',1,NULL,'',0),(331,'michael-150blk-package','clearance',6,'301',1,NULL,'',0),(332,'michael-7-piece-150-dining-suite','clearance',7,'301',1,NULL,'',0),(333,'michael-7-piece-150-dining-suite','clearance',8,'301',1,NULL,'',0),(335,'casper-120-dining-package-1-x-table-4-chairs','clearance',1,'301',1,NULL,'',0),(336,'casperpackage','clearance',4,'301',1,NULL,'',0),(337,'casperpackage','clearance',5,'301',1,NULL,'',0),(338,'casperpackage','clearance',6,'301',1,NULL,'',0),(339,'casperpackage','clearance',7,'301',1,NULL,'',0),(340,'casperpackage','clearance',8,'301',1,NULL,'',0),(342,'jonas180package','outdoor',1,'301',1,NULL,'',0),(343,'jonas180package','outdoor',4,'301',1,NULL,'',0),(344,'jonas180package','outdoor',5,'301',1,NULL,'',0),(345,'jonas180package','outdoor',6,'301',1,NULL,'',0),(346,'jonas-7-piece-outdoor-dining-set','outdoor',7,'301',1,NULL,'',0),(347,'jonas-7-piece-outdoor-dining-set','outdoor',8,'301',1,NULL,'',0),(349,'jonasbarpackage','outdoor',1,'301',1,NULL,'',0),(350,'jonasbarpackage','outdoor',4,'301',1,NULL,'',0),(351,'jonasbarpackage','outdoor',5,'301',1,NULL,'',0),(352,'jonasbarpackage','outdoor',6,'301',1,NULL,'',0),(353,'jonasbarpackage','outdoor',7,'301',1,NULL,'',0),(354,'jonasbarpackage','outdoor',8,'301',1,NULL,'',0),(356,'huc25806','outdoor',1,'301',1,NULL,'',0),(357,'huc25806','outdoor',4,'301',1,NULL,'',0),(358,'huc25806','outdoor',5,'301',1,NULL,'',0),(359,'huc25806','outdoor',6,'301',1,NULL,'',0),(360,'jonas-jack-and-jill-outdoor-setting','outdoor',7,'301',1,NULL,'',0),(361,'jonas-jack-and-jill-outdoor-setting','outdoor',8,'301',1,NULL,'',0),(363,'jonaslounge','outdoor',1,'301',1,NULL,'',0),(364,'jonaslounge','outdoor',4,'301',1,NULL,'',0),(365,'jonaslounge','outdoor',5,'301',1,NULL,'',0),(366,'jonaslounge','outdoor',6,'301',1,NULL,'',0),(367,'jonas-4-piece-outdoor-lounge-setting','outdoor',7,'301',1,NULL,'',0),(368,'jonas-4-piece-outdoor-lounge-setting','outdoor',8,'301',1,NULL,'',0),(370,'erin-trundle-bed-with-mattresses','mattress',1,'301',1,NULL,'',0),(371,'00tb03-newerin-ks','mattress',4,'301',1,NULL,'',0),(372,'00tb03-newerin-ks','mattress',5,'301',1,NULL,'',0),(373,'00tb03-newerin-ks','mattress',6,'301',1,NULL,'',0),(374,'erin-trundle-bed-with-pocket-spring-mattresses','mattress',7,'301',1,NULL,'',0),(375,'erin-trundle-bed-with-pocket-spring-mattresses','mattress',8,'301',1,NULL,'',0),(377,'199523-berbei-3sc','clearance',1,'301',1,NULL,'',0),(378,'199523-berbei-3sc','clearance',4,'301',1,NULL,'',0),(379,'199523-berbei-3sc','clearance',5,'301',1,NULL,'',0),(380,'199523-berbei-3sc','clearance',6,'301',1,NULL,'',0),(381,'199523-berbei-3sc','clearance',7,'301',1,NULL,'',0),(382,'199523-berbei-3sc','clearance',8,'301',1,NULL,'',0),(384,'r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box','mattress',1,'301',1,NULL,'',0),(385,'pr539-zeds-quasar-q','mattress',4,'301',1,NULL,'',0),(386,'pr539-zeds-quasar-q','mattress',5,'301',1,NULL,'',0),(387,'r535-zeds-quasar-s','mattress',6,'301',1,NULL,'',0),(388,'zeds-quasar-queen-mattress-in-a-box','mattress',7,'301',1,NULL,'',0),(389,'zeds-quasar-queen-mattress-in-a-box','mattress',8,'301',1,NULL,'',0),(391,'epson-workforce-pro-wf-3820dwf-all-in-one-wireless-printer-black','epson',1,'301',1,NULL,'',0),(392,'89502105','epson',7,'301',1,NULL,'',0),(393,'89502105','epson',8,'301',1,NULL,'',0),(394,'89502105','epson',9,'301',1,NULL,'',0),(395,'89502105','epson',10,'301',1,NULL,'',0),(398,'epson-expression-premium-xp-6100-wi-fi-all-in-one-printer-black','epson',1,'301',1,NULL,'',0),(399,'89502103','epson',7,'301',1,NULL,'',0),(400,'89502103','epson',8,'301',1,NULL,'',0),(401,'89502103','epson',9,'301',1,NULL,'',0),(402,'89502103','epson',10,'301',1,NULL,'',0),(405,'epson-ecotank-et-m2120','epson',1,'301',1,NULL,'',0),(406,'ecotank-m2120','epson',7,'301',1,NULL,'',0),(407,'ecotank-m2120','epson',8,'301',1,NULL,'',0),(408,'ecotank-m2120','epson',9,'301',1,NULL,'',0),(409,'epson-ecotank-et-m2120','epson',10,'301',1,NULL,'',0),(412,'epson-m15140-wi-fi-c11cj41404','epson',1,'301',1,NULL,'',0),(413,'ecotankm15140','epson',7,'301',1,NULL,'',0),(414,'ecotankm15140','epson',8,'301',1,NULL,'',0),(415,'ecotankm15140','epson',9,'301',1,NULL,'',0),(416,'epson-m15140-wi-fi-c11cj41404','epson',10,'301',1,NULL,'',0),(419,'canon-pixma-wireless-inkjet-printer-g3260','canon',1,'301',1,NULL,'',0),(420,'g3260','canon',7,'301',1,NULL,'',0),(421,'g3260','canon',8,'301',1,NULL,'',0),(422,'g3260','canon',9,'301',1,NULL,'',0),(423,'canon-pixma-wireless-inkjet-printer-g3260','canon',10,'301',1,NULL,'',0),(426,'canon-imageformula-dr-6010c-sheetfed-scanner-24-bit-color-8-bit-grayscale-usb-scsi','canon',1,'301',1,NULL,'',0),(427,'dr-6010c','canon',7,'301',1,NULL,'',0),(428,'dr-6010c','canon',8,'301',1,NULL,'',0),(429,'dr-6010c','canon',9,'301',1,NULL,'',0),(430,'canon-imageformula-dr-6010c-sheetfed-scanner-24-bit-color-8-bit-grayscale-usb-scsi','canon',10,'301',1,NULL,'',0),(433,'canon-pixma-ts5350-allinone-wireless-inkjet-printer','canon',1,'301',1,NULL,'',0),(434,'629373','canon',7,'301',1,NULL,'',0),(435,'629373','canon',8,'301',1,NULL,'',0),(436,'629373','canon',9,'301',1,NULL,'',0),(437,'canon-pixma-ts5350-allinone-wireless-inkjet-printer','canon',10,'301',1,NULL,'',0),(440,'canon-pixma-ts7451-allinone-wireless-inkjet-printer-white','canon',1,'301',1,NULL,'',0),(441,'780020','canon',7,'301',1,NULL,'',0),(442,'780020','canon',8,'301',1,NULL,'',0),(443,'780020','canon',9,'301',1,NULL,'',0),(444,'canon-pixma-ts7451-allinone-wireless-inkjet-printer-white','canon',10,'301',1,NULL,'',0),(447,'brother-mfcl3750cdw-allinone-laser-printer-with-fax','brother',1,'301',1,NULL,'',0),(448,'789669','brother',7,'301',1,NULL,'',0),(449,'789669','brother',8,'301',1,NULL,'',0),(450,'789669','brother',9,'301',1,NULL,'',0),(451,'brother-mfcl3750cdw-allinone-laser-printer-with-fax','brother',10,'301',1,NULL,'',0),(454,'brother-hll2310d-monochrome-laser-printer','brother',1,'301',1,NULL,'',0),(455,'236124','brother',7,'301',1,NULL,'',0),(456,'236124','brother',8,'301',1,NULL,'',0),(457,'236124','brother',9,'301',1,NULL,'',0),(458,'brother-hll2310d-monochrome-laser-printer','brother',10,'301',1,NULL,'',0),(461,'brother-dcp1612w-monochrome-allinone-wireless-laser-printer','brother',1,'301',1,NULL,'',0),(462,'131109','brother',7,'301',1,NULL,'',0),(463,'131109','brother',8,'301',1,NULL,'',0),(464,'131109','brother',9,'301',1,NULL,'',0),(465,'brother-dcp1612w-monochrome-allinone-wireless-laser-printer','brother',10,'301',1,NULL,'',0),(468,'brother-mfcl8690cdw-allinone-wireless-laser-colour-printer-with-fax','brother',1,'301',1,NULL,'',0),(469,'245042','brother',7,'301',1,NULL,'',0),(470,'245042','brother',8,'301',1,NULL,'',0),(471,'245042','brother',9,'301',1,NULL,'',0),(472,'brother-mfcl8690cdw-allinone-wireless-laser-colour-printer-with-fax','brother',10,'301',1,NULL,'',0),(475,'workwell-meeting-chair-4-star-fixed-mwt14','chair',1,'301',1,NULL,'',0),(476,'mwt14','chair',7,'301',1,NULL,'',0),(477,'mwt14','chair',8,'301',1,NULL,'',0),(478,'workwell-meeting-chair-4-star-fixed-mwt14','chair',9,'301',1,NULL,'',0),(479,'mwt14','chair',10,'301',1,NULL,'',0),(482,'workwell-meeting-chair-cantilever-mwt15','chair',1,'301',1,NULL,'',0),(483,'mwt15','chair',7,'301',1,NULL,'',0),(484,'mwt15','chair',8,'301',1,NULL,'',0),(485,'mwt15','chair',9,'301',1,NULL,'',0),(486,'workwell-meeting-chair-cantilever-mwt15','chair',10,'301',1,NULL,'',0),(489,'workwell-meeting-chair-5-star-castor-base-mwt13','chair',1,'301',1,NULL,'',0),(490,'mwt13','chair',7,'301',1,NULL,'',0),(491,'mwt13','chair',8,'301',1,NULL,'',0),(492,'mwt13','chair',9,'301',1,NULL,'',0),(493,'workwell-meeting-chair-5-star-castor-base-mwt13','chair',10,'301',1,NULL,'',0),(496,'executive-office-chair-high-back-armrests-real-leather-black','chair',1,'301',1,NULL,'',0),(497,'39849','chair',7,'301',1,NULL,'',0),(498,'39849','chair',8,'301',1,NULL,'',0),(499,'39849','chair',9,'301',1,NULL,'',0),(500,'executive-office-chair-high-back-armrests-real-leather-black','chair',10,'301',1,NULL,'',0),(503,'fellowes-white-lotus-dx-sit-stand-workstation','computer-workstations',1,'301',1,NULL,'',0),(504,'8081101','computer-workstations',7,'301',1,NULL,'',0),(505,'8081101','computer-workstations',8,'301',1,NULL,'',0),(506,'8081101','computer-workstations',9,'301',1,NULL,'',0),(507,'fellowes-white-lotus-dx-sit-stand-workstation','computer-workstations',10,'301',1,NULL,'',0),(510,'fellowes-black-lotus-dx-sit-stand-workstation','computer-workstations',1,'301',1,NULL,'',0),(511,'8081001','computer-workstations',7,'301',1,NULL,'',0),(512,'8081001','computer-workstations',8,'301',1,NULL,'',0),(513,'8081001','computer-workstations',9,'301',1,NULL,'',0),(514,'fellowes-black-lotus-dx-sit-stand-workstation','computer-workstations',10,'301',1,NULL,'',0),(517,'jemini-1600mm-grey-oaksilver-cantilever-left-hand-radial-desk','tables',1,'301',1,NULL,'',0),(518,'kf807537','tables',7,'301',1,NULL,'',0),(519,'kf807537','tables',8,'301',1,NULL,'',0),(520,'jemini-1600mm-grey-oaksilver-cantilever-left-hand-radial-desk','tables',9,'301',1,NULL,'',0),(521,'kf807537','tables',10,'301',1,NULL,'',0),(524,'2-drawer-side-filing-office-cabinet','tables',1,'301',1,NULL,'',0),(525,'drawerside','tables',7,'301',1,NULL,'',0),(526,'drawerside','tables',8,'301',1,NULL,'',0),(527,'2-drawer-side-filing-office-cabinet','tables',9,'301',1,NULL,'',0),(528,'drawerside','tables',10,'301',1,NULL,'',0);
/*!40000 ALTER TABLE `seo_redirect` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `seo_redirects_named`
--

DROP TABLE IF EXISTS `seo_redirects_named`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `seo_redirects_named` (
  `seo_redirects_named_id` int(32) NOT NULL AUTO_INCREMENT,
  `redirects_type` varchar(64) NOT NULL DEFAULT '',
  `owner_id` int(32) NOT NULL DEFAULT '0',
  `old_seo_page_name` varchar(255) NOT NULL DEFAULT '',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`seo_redirects_named_id`),
  KEY `old_seo_page_name` (`old_seo_page_name`),
  KEY `owner_id` (`owner_id`,`language_id`,`redirects_type`)
) ENGINE=InnoDB AUTO_INCREMENT=52 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `seo_redirects_named`
--

LOCK TABLES `seo_redirects_named` WRITE;
/*!40000 ALTER TABLE `seo_redirects_named` DISABLE KEYS */;
INSERT INTO `seo_redirects_named` VALUES (8,'info',22,'abouttest',1,1),(9,'category',2,'for-him',1,0),(10,'category',3,'for-her',1,0),(11,'product',30,'cozy-sleep-queen-mattress',1,6),(12,'product',30,'cozy-sleep-queen-mattress',1,4),(13,'product',30,'cozy-sleep-queen-mattress',1,5),(14,'product',31,'cozy-sleep-double-mattress',1,6),(15,'product',31,'cozy-sleep-double-mattress',1,4),(16,'product',31,'cozy-sleep-double-mattress',1,5),(17,'product',33,'jack-5-piece-king-bedroom-suites',1,6),(18,'product',33,'jack-5-piece-king-bedroom-suites',1,4),(19,'product',33,'jack-5-piece-king-bedroom-suites',1,5),(20,'product',34,'jack-4-piece-king-bedroom-suites',1,6),(21,'product',34,'jack-4-piece-king-bedroom-suites',1,4),(22,'product',34,'jack-4-piece-king-bedroom-suites',1,5),(26,'product',36,'brolly-quilted-fitted-mattress-protector-king',1,4),(27,'product',36,'brolly-quilted-fitted-mattress-protector-king',1,5),(28,'product',37,'brolly-quilted-fitted-mattress-protector-queen',1,6),(29,'product',37,'brolly-quilted-fitted-mattress-protector-queen',1,4),(30,'product',37,'brolly-quilted-fitted-mattress-protector-queen',1,5),(31,'product',43,'clayton-3rr-2rr-brown',1,6),(32,'product',43,'clayton-3rr-2rr-brown',1,4),(33,'product',43,'clayton-3rr-2rr-brown',1,5),(34,'product',44,'clayton-3rr-2rr-sr-brown',1,6),(35,'product',44,'clayton-3rr-2rr-sr-brown',1,4),(36,'product',44,'clayton-3rr-2rr-sr-brown',1,5),(37,'product',45,'new-veronica-4pcs-package-1xqb-2xbs-1xtb',1,6),(38,'product',45,'new-veronica-4pcs-package-1xqb-2xbs-1xtb',1,4),(39,'product',45,'new-veronica-4pcs-package-1xqb-2xbs-1xtb',1,5),(40,'product',47,'michael-150-dining-package-black-1-table-6-blue-chairs',1,6),(41,'product',47,'michael-150-dining-package-black-1-table-6-blue-chairs',1,4),(42,'product',47,'michael-150-dining-package-black-1-table-6-blue-chairs',1,5),(46,'product',53,'erin-trundle-bed-with-mattresses',1,6),(47,'product',53,'erin-trundle-bed-with-mattresses',1,4),(48,'product',53,'erin-trundle-bed-with-mattresses',1,5),(49,'product',55,'r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box',1,6),(50,'product',55,'r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box',1,4),(51,'product',55,'r535-zeds-quasar-s-zeds-quasar-single-mattress-in-a-box',1,5);
/*!40000 ALTER TABLE `seo_redirects_named` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sessions`
--

DROP TABLE IF EXISTS `sessions`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `sessions` (
  `sesskey` varchar(32) NOT NULL,
  `expiry` int(11) unsigned NOT NULL DEFAULT '0',
  `value` text NOT NULL,
  PRIMARY KEY (`sesskey`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `sessions_admin`
--

DROP TABLE IF EXISTS `sessions_admin`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `sessions_admin` (
  `sesskey` varchar(32) NOT NULL,
  `expiry` int(11) unsigned NOT NULL DEFAULT '0',
  `value` text NOT NULL,
  PRIMARY KEY (`sesskey`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `sets_products`
--

DROP TABLE IF EXISTS `sets_products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `sets_products` (
  `sets_id` int(11) NOT NULL DEFAULT '0',
  `product_id` int(11) NOT NULL DEFAULT '0',
  `num_product` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(1) NOT NULL DEFAULT '0',
  `price` decimal(11,2) NOT NULL DEFAULT '0.00',
  `discount` decimal(11,2) NOT NULL DEFAULT '0.00',
  `price_formula` varchar(1024) NOT NULL DEFAULT '',
  PRIMARY KEY (`sets_id`,`product_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sets_products`
--

LOCK TABLES `sets_products` WRITE;
/*!40000 ALTER TABLE `sets_products` DISABLE KEYS */;
/*!40000 ALTER TABLE `sets_products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ship_options`
--

DROP TABLE IF EXISTS `ship_options`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ship_options` (
  `ship_options_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `ship_options_name` varchar(255) NOT NULL DEFAULT '',
  `sort_order` tinyint(1) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `restrict_access` int(11) NOT NULL DEFAULT '0',
  KEY `platform_id` (`platform_id`,`language_id`,`ship_options_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ship_options`
--

LOCK TABLES `ship_options` WRITE;
/*!40000 ALTER TABLE `ship_options` DISABLE KEYS */;
INSERT INTO `ship_options` VALUES (1,1,'Shipping Cost',1,1,0),(1,3,'DPD',1,1,0),(1,10,'DPD',1,1,0),(1,11,'DPD',1,1,0),(7,1,'Shipping Cost',7,10,0),(8,1,'Shipping Cost',8,7,0),(9,1,'Shipping Cost',9,8,0),(10,1,'Shipping Cost',10,9,0);
/*!40000 ALTER TABLE `ship_options` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `ship_zones`
--

DROP TABLE IF EXISTS `ship_zones`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ship_zones` (
  `ship_zone_id` int(11) NOT NULL AUTO_INCREMENT,
  `ship_zone_name` varchar(32) NOT NULL DEFAULT '',
  `ship_zone_description` varchar(255) NOT NULL DEFAULT '',
  `last_modified` datetime DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`ship_zone_id`)
) ENGINE=InnoDB AUTO_INCREMENT=22 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `ship_zones`
--

LOCK TABLES `ship_zones` WRITE;
/*!40000 ALTER TABLE `ship_zones` DISABLE KEYS */;
INSERT INTO `ship_zones` VALUES (3,'UK','',NULL,'2017-02-10 14:37:20',1),(7,'Ireland','',NULL,'2017-04-09 12:56:54',1),(8,'All','',NULL,'2017-04-09 12:58:22',1),(10,'All','',NULL,'2022-06-24 16:50:22',10),(11,'Ireland','',NULL,'2022-06-24 16:50:24',10),(12,'UK','',NULL,'2022-06-24 16:50:25',10),(13,'All','',NULL,'2022-06-24 16:58:41',7),(14,'UK','',NULL,'2022-06-24 16:58:43',7),(15,'Ireland','',NULL,'2022-06-24 16:58:44',7),(16,'All','',NULL,'2022-06-24 17:01:14',8),(17,'Ireland','',NULL,'2022-06-24 17:01:16',8),(18,'UK','',NULL,'2022-06-24 17:01:18',8),(19,'All','',NULL,'2022-06-24 17:04:02',9),(20,'Ireland','',NULL,'2022-06-24 17:04:05',9),(21,'UK','',NULL,'2022-06-24 17:04:06',9);
/*!40000 ALTER TABLE `ship_zones` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `shipping_fee`
--

DROP TABLE IF EXISTS `shipping_fee`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `shipping_fee` (
  `shipping_fee_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `shipping_code` varchar(64) DEFAULT NULL,
  `percent_prefix` int(4) NOT NULL DEFAULT '1',
  `percent_value` double(11,2) NOT NULL DEFAULT '0.00',
  `fixed_prefix` int(4) NOT NULL DEFAULT '1',
  `fixed_value` decimal(11,2) NOT NULL DEFAULT '0.00',
  PRIMARY KEY (`shipping_fee_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `shipping_fee`
--

LOCK TABLES `shipping_fee` WRITE;
/*!40000 ALTER TABLE `shipping_fee` DISABLE KEYS */;
/*!40000 ALTER TABLE `shipping_fee` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `shipping_np_order_params`
--

DROP TABLE IF EXISTS `shipping_np_order_params`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `shipping_np_order_params` (
  `orders_id` int(11) NOT NULL,
  `name` varchar(50) NOT NULL DEFAULT '',
  `value` text NOT NULL,
  `type` varchar(96) NOT NULL DEFAULT '',
  PRIMARY KEY (`orders_id`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `shipping_np_order_params`
--

LOCK TABLES `shipping_np_order_params` WRITE;
/*!40000 ALTER TABLE `shipping_np_order_params` DISABLE KEYS */;
/*!40000 ALTER TABLE `shipping_np_order_params` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sms_templates`
--

DROP TABLE IF EXISTS `sms_templates`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `sms_templates` (
  `sms_templates_id` int(11) NOT NULL AUTO_INCREMENT,
  `sms_templates_key` varchar(255) NOT NULL DEFAULT '',
  `sms_templates_type_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`sms_templates_id`),
  UNIQUE KEY `sms_templates_key` (`sms_templates_key`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sms_templates`
--

LOCK TABLES `sms_templates` WRITE;
/*!40000 ALTER TABLE `sms_templates` DISABLE KEYS */;
INSERT INTO `sms_templates` VALUES (1,'Admin Login Security Key',0);
/*!40000 ALTER TABLE `sms_templates` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sms_templates_texts`
--

DROP TABLE IF EXISTS `sms_templates_texts`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `sms_templates_texts` (
  `sms_templates_id` int(11) NOT NULL DEFAULT '0',
  `sms_templates_body` text,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `affiliate_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`sms_templates_id`,`platform_id`,`language_id`,`affiliate_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sms_templates_texts`
--

LOCK TABLES `sms_templates_texts` WRITE;
/*!40000 ALTER TABLE `sms_templates_texts` DISABLE KEYS */;
INSERT INTO `sms_templates_texts` VALUES (1,'Your login security key is: ##SECURITY_KEY##',1,1,0),(1,'Your login security key is: ##SECURITY_KEY##',1,3,0),(1,'Your login security key is: ##SECURITY_KEY##',1,10,0),(1,'Your login security key is: ##SECURITY_KEY##',1,11,0),(1,'Your login security key is: ##SECURITY_KEY##',1,12,0),(1,'Your login security key is: ##SECURITY_KEY##',1,13,0),(1,'Your login security key is: ##SECURITY_KEY##',1,15,0),(1,'Your login security key is: ##SECURITY_KEY##',1,17,0),(1,'Your login security key is: ##SECURITY_KEY##',1,26,0),(1,'Your login security key is: ##SECURITY_KEY##',1,28,0),(1,'Your login security key is: ##SECURITY_KEY##',1,29,0);
/*!40000 ALTER TABLE `sms_templates_texts` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `social_addons`
--

DROP TABLE IF EXISTS `social_addons`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `social_addons` (
  `social_addons_id` int(11) NOT NULL AUTO_INCREMENT,
  `socials_id` int(11) NOT NULL DEFAULT '0',
  `block_name` varchar(64) DEFAULT NULL,
  `configuration_key` varchar(64) DEFAULT NULL,
  `configuration_value` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`social_addons_id`),
  KEY `socials_id` (`socials_id`)
) ENGINE=InnoDB AUTO_INCREMENT=79 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `social_addons`
--

LOCK TABLES `social_addons` WRITE;
/*!40000 ALTER TABLE `social_addons` DISABLE KEYS */;
INSERT INTO `social_addons` VALUES (22,6,'google-web-side-auth','GAPI_CLIENT_ID',''),(23,6,'google-web-side-auth','GAPI_PROJECT_ID',''),(24,6,'google-web-side-auth','GAPI_CLIENT_SECRET',''),(25,6,'google-web-side-auth','GAPI_RETURN_URI','https://www.trueloaded.co.uk/admin/index/auth-callback'),(40,2,'posts','FB_APPLICATION_ID','132046347554786'),(41,2,'posts','FB_APPLICATION_SECRET','0a9b71c150bbb41ae4b16a5fca782b47'),(42,2,'posts','FB_PAGE_ID','trueloaded'),(46,8,'posts','FB_APPLICATION_ID','Facebook Application ID'),(47,8,'posts','FB_APPLICATION_SECRET','Facebook Application Secret'),(48,8,'posts','FB_PAGE_ID','Facebook Page ID'),(63,28,'posts','YT_API_KEY','YouTube API Key'),(69,26,'posts','TW_ACCESS_TOKEN','Twitter Access token'),(70,26,'posts','TW_ACCESS_TOKEN_SECRET','Twitter Access token secret'),(71,26,'posts','TW_CONSUMER_KEY','Twitter Consumer key'),(72,26,'posts','TW_CONSUMER_SECRET','Twitter Consumer secret'),(73,26,'posts','TW_SCREEN_NAME','Twitter Screen name'),(74,25,'posts','FB_APPLICATION_ID','Facebook Application ID'),(75,25,'posts','FB_APPLICATION_SECRET','Facebook Application Secret'),(76,25,'posts','FB_PAGE_ID','Facebook Page ID'),(77,29,'posts','IN_ACCESS_TOKEN','Instagram Access token'),(78,29,'posts','IN_USERNAME','Instagram Username');
/*!40000 ALTER TABLE `social_addons` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `socials`
--

DROP TABLE IF EXISTS `socials`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `socials` (
  `socials_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `module` varchar(32) NOT NULL DEFAULT '',
  `client_id` varchar(255) NOT NULL DEFAULT '',
  `client_secret` varchar(255) NOT NULL DEFAULT '',
  `active` tinyint(4) NOT NULL DEFAULT '0',
  `test_success` tinyint(4) NOT NULL DEFAULT '0',
  `link` varchar(255) NOT NULL DEFAULT '',
  `image` varchar(255) NOT NULL DEFAULT '',
  `css_class` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`socials_id`),
  KEY `platform_idx` (`platform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `socials`
--

LOCK TABLES `socials` WRITE;
/*!40000 ALTER TABLE `socials` DISABLE KEYS */;
/*!40000 ALTER TABLE `socials` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `specials`
--

DROP TABLE IF EXISTS `specials`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `specials` (
  `specials_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` int(11) NOT NULL DEFAULT '0',
  `specials_new_products_price` decimal(15,6) NOT NULL DEFAULT '0.000000',
  `specials_date_added` datetime DEFAULT NULL,
  `specials_last_modified` datetime DEFAULT NULL,
  `expires_date` datetime DEFAULT NULL,
  `date_status_change` datetime DEFAULT NULL,
  `status` int(1) NOT NULL DEFAULT '1',
  `start_date` datetime DEFAULT NULL,
  `specials_type_id` int(11) NOT NULL DEFAULT '0',
  `specials_disabled` int(1) NOT NULL DEFAULT '0',
  `specials_enabled` int(1) NOT NULL DEFAULT '0',
  `promote_type` int(5) NOT NULL DEFAULT '0' COMMENT '-1 - disabled, 0 - default, 1 - percent 2 - fixed',
  `total_qty` int(11) NOT NULL DEFAULT '0',
  `max_per_order` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`specials_id`),
  KEY `status` (`status`),
  KEY `products_id` (`products_id`,`status`),
  KEY `idx_start_date` (`start_date`),
  KEY `idx_expires_date` (`expires_date`),
  KEY `idx_specials_disabled` (`specials_disabled`),
  KEY `idx_specials_enabled` (`specials_enabled`),
  KEY `idx_specials_main_active` (`products_id`,`status`,`specials_type_id`,`specials_new_products_price`)
) ENGINE=InnoDB AUTO_INCREMENT=25 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `specials`
--

LOCK TABLES `specials` WRITE;
/*!40000 ALTER TABLE `specials` DISABLE KEYS */;
INSERT INTO `specials` VALUES (1,61,35.000000,'2022-07-23 14:14:28','2022-07-23 14:26:42','0000-00-00 00:00:00','2022-07-23 14:26:21',1,'2022-07-23 14:14:00',0,0,1,-1,0,0),(2,56,72.000000,'2022-07-23 14:45:49',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 14:45:49',0,0,1,-1,0,0),(3,53,1285.000000,'2022-07-23 14:46:30',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 14:46:30',0,0,1,-1,0,0),(4,65,1799.000000,'2022-07-23 14:47:07','2022-07-24 12:05:57','0000-00-00 00:00:00',NULL,1,'2022-07-23 14:47:00',0,0,1,-1,0,0),(5,60,44.990000,'2022-07-23 15:18:32',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:18:32',0,0,0,-1,0,0),(6,60,0.000000,'2022-07-23 15:18:40',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:18:40',0,0,1,-1,0,0),(7,9,37.491667,'2022-07-23 15:19:42',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:19:42',0,0,1,-1,0,0),(8,13,40.000000,'2022-07-23 15:20:22',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:20:22',0,0,1,-1,0,0),(9,11,184.166667,'2022-07-23 15:21:20',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 00:00:00',0,0,1,-1,0,0),(10,2,82.500000,'2022-07-23 15:21:45',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:21:45',0,0,0,-1,0,0),(11,15,36.666667,'2022-07-23 15:22:28',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:22:28',0,0,1,-1,0,0),(12,33,61.666667,'2022-07-23 15:23:38',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:23:38',0,0,1,-1,0,0),(13,31,60.833333,'2022-07-23 15:24:21',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:24:21',0,0,1,-1,0,0),(14,30,76.666667,'2022-07-23 15:24:45',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:24:45',0,0,1,-1,0,0),(15,34,249.166667,'2022-07-23 15:26:08',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:26:08',0,0,1,-1,0,0),(16,36,165.833333,'2022-07-23 15:26:45',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:26:45',0,0,1,-1,0,0),(17,41,790.833333,'2022-07-23 15:30:47',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:30:47',0,0,1,-1,0,0),(18,38,92.500000,'2022-07-23 15:31:08',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:31:08',0,0,1,-1,0,0),(19,43,1999.166667,'2022-07-23 15:31:57',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:31:57',0,0,1,-1,0,0),(20,45,56.666667,'2022-07-23 15:32:19',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:32:19',0,0,1,-1,0,0),(21,47,74.166667,'2022-07-23 15:33:02',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:33:02',0,0,0,-1,0,0),(22,49,315.833333,'2022-07-23 15:35:12',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-23 15:35:12',0,0,1,-1,0,0),(23,63,1499.000000,'2022-07-25 08:53:56',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-25 08:53:56',0,0,1,-1,0,0),(24,23,249.166667,'2022-07-25 08:55:16',NULL,'0000-00-00 00:00:00',NULL,1,'2022-07-25 08:55:16',0,0,1,-1,0,0);
/*!40000 ALTER TABLE `specials` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `specials_prices`
--

DROP TABLE IF EXISTS `specials_prices`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `specials_prices` (
  `specials_id` int(11) NOT NULL DEFAULT '0',
  `currencies_id` int(11) NOT NULL DEFAULT '1',
  `groups_id` int(11) NOT NULL DEFAULT '0',
  `specials_new_products_price` float(15,4) NOT NULL DEFAULT '0.0000',
  PRIMARY KEY (`specials_id`,`currencies_id`,`groups_id`),
  KEY `idx_main_disabled` (`specials_new_products_price`,`specials_id`,`groups_id`,`currencies_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `specials_prices`
--

LOCK TABLES `specials_prices` WRITE;
/*!40000 ALTER TABLE `specials_prices` DISABLE KEYS */;
INSERT INTO `specials_prices` VALUES (6,0,0,-2.0000),(1,0,0,35.0000),(11,0,0,36.6667),(7,0,0,37.4917),(8,0,0,40.0000),(5,0,0,44.9900),(20,0,0,56.6667),(13,0,0,60.8333),(12,0,0,61.6667),(2,0,0,72.0000),(21,0,0,74.1667),(14,0,0,76.6667),(10,0,0,82.5000),(18,0,0,92.5000),(16,0,0,165.8333),(9,0,0,184.1667),(15,0,0,249.1667),(24,0,0,249.1667),(22,0,0,315.8333),(17,0,0,790.8333),(3,0,0,1285.0000),(23,0,0,1499.0000),(4,0,0,1799.0000),(19,0,0,1999.1667);
/*!40000 ALTER TABLE `specials_prices` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `specials_types`
--

DROP TABLE IF EXISTS `specials_types`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `specials_types` (
  `specials_type_id` int(11) NOT NULL,
  `language_id` int(11) NOT NULL,
  `specials_type_name` varchar(64) NOT NULL DEFAULT '',
  `specials_type_code` varchar(12) NOT NULL DEFAULT '',
  PRIMARY KEY (`specials_type_id`,`language_id`),
  KEY `specials_type_name` (`specials_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `specials_types`
--

LOCK TABLES `specials_types` WRITE;
/*!40000 ALTER TABLE `specials_types` DISABLE KEYS */;
/*!40000 ALTER TABLE `specials_types` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `stock_history`
--

DROP TABLE IF EXISTS `stock_history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `stock_history` (
  `stock_history_id` int(11) NOT NULL AUTO_INCREMENT,
  `products_id` varchar(255) NOT NULL DEFAULT '',
  `prid` int(11) NOT NULL DEFAULT '0',
  `products_model` varchar(40) NOT NULL DEFAULT '',
  `products_quantity_before` int(11) NOT NULL DEFAULT '0',
  `warehouse_quantity_before` int(11) DEFAULT '0',
  `products_quantity_update_prefix` varchar(1) NOT NULL DEFAULT '',
  `products_quantity_update` int(11) NOT NULL DEFAULT '0',
  `orders_id` int(11) NOT NULL DEFAULT '0',
  `warehouse_id` int(11) NOT NULL DEFAULT '0',
  `suppliers_id` int(11) NOT NULL DEFAULT '0',
  `location_id` int(11) NOT NULL DEFAULT '0',
  `purchase_orders_id` int(11) NOT NULL DEFAULT '0',
  `admin_id` int(11) NOT NULL DEFAULT '0',
  `comments` mediumtext NOT NULL,
  `date_added` datetime DEFAULT NULL,
  `is_temporary` tinyint(1) NOT NULL DEFAULT '0',
  `relation_type` varchar(32) NOT NULL DEFAULT '',
  `parent_id` int(11) DEFAULT NULL,
  `parent_products_model` varchar(32) DEFAULT NULL,
  `parent_products_name` varchar(255) DEFAULT NULL,
  `layers_id` int(11) NOT NULL DEFAULT '0',
  `batch_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`stock_history_id`),
  KEY `idx_products_id` (`products_id`),
  KEY `idx_prid` (`prid`),
  KEY `idx_layers_id` (`layers_id`),
  KEY `idx_batch_id` (`batch_id`)
) ENGINE=InnoDB AUTO_INCREMENT=71 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `stock_history`
--

LOCK TABLES `stock_history` WRITE;
/*!40000 ALTER TABLE `stock_history` DISABLE KEYS */;
INSERT INTO `stock_history` VALUES (1,'49',49,'245042',100,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-24 15:53:07',1,'',NULL,NULL,NULL,0,0),(2,'49',49,'245042',99,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-24 15:53:40',1,'',NULL,NULL,NULL,0,0),(3,'49',49,'245042',100,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-24 15:53:40',1,'',NULL,NULL,NULL,0,0),(4,'49',49,'245042',99,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-24 15:53:44',1,'',NULL,NULL,NULL,0,0),(5,'45',45,'780020',100,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-24 15:54:14',1,'',NULL,NULL,NULL,0,0),(6,'45',45,'780020',99,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-24 15:55:05',1,'',NULL,NULL,NULL,0,0),(7,'48',48,'131109',100,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-24 15:56:01',1,'',NULL,NULL,NULL,0,0),(8,'48',48,'131109',99,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-24 15:56:11',1,'',NULL,NULL,NULL,0,0),(9,'48',48,'131109',99,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-24 15:58:42',1,'',NULL,NULL,NULL,0,0),(10,'48',48,'131109',98,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-24 15:58:46',1,'',NULL,NULL,NULL,0,0),(11,'48',48,'131109',98,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-24 15:59:33',1,'',NULL,NULL,NULL,0,0),(12,'48',48,'131109',97,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-24 16:31:56',1,'',NULL,NULL,NULL,0,0),(13,'57',57,'00MPQQ-010000-Q',957,957,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 08:51:57',1,'',NULL,NULL,NULL,0,0),(14,'56',56,'00MPKQ-010000-K',1020,1020,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 08:51:57',1,'',NULL,NULL,NULL,0,0),(15,'65',65,'VERONICAQUEEN4-NEW',2000,2000,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 08:51:57',1,'',NULL,NULL,NULL,0,0),(16,'65',65,'VERONICAQUEEN4-NEW',1999,2000,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 08:55:15',1,'',NULL,NULL,NULL,0,0),(17,'56',56,'00MPKQ-010000-K',1019,1020,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 08:55:15',1,'',NULL,NULL,NULL,0,0),(18,'57',57,'00MPQQ-010000-Q',956,957,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 08:55:15',1,'',NULL,NULL,NULL,0,0),(19,'57',57,'00MPQQ-010000-Q',957,957,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 08:55:15',1,'',NULL,NULL,NULL,0,0),(20,'56',56,'00MPKQ-010000-K',1020,1020,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 08:55:15',1,'',NULL,NULL,NULL,0,0),(21,'65',65,'VERONICAQUEEN4-NEW',2000,2000,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 08:55:15',1,'',NULL,NULL,NULL,0,0),(22,'65',65,'VERONICAQUEEN4-NEW',1999,2000,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 08:55:18',1,'',NULL,NULL,NULL,0,0),(23,'56',56,'00MPKQ-010000-K',1019,1020,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 08:55:18',1,'',NULL,NULL,NULL,0,0),(24,'57',57,'00MPQQ-010000-Q',956,957,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 08:55:18',1,'',NULL,NULL,NULL,0,0),(25,'74',74,'199523-BERBEI-3S/C',1000,1000,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 09:01:31',1,'',NULL,NULL,NULL,0,0),(26,'34',34,'8081101',100,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 09:17:57',1,'',NULL,NULL,NULL,0,0),(27,'34',34,'8081101',99,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 09:18:34',1,'',NULL,NULL,NULL,0,0),(28,'34',34,'8081101',100,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 09:18:34',1,'',NULL,NULL,NULL,0,0),(29,'34',34,'8081101',99,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 09:18:37',1,'',NULL,NULL,NULL,0,0),(30,'48',48,'131109',98,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 09:22:56',1,'',NULL,NULL,NULL,0,0),(31,'74',74,'199523-BERBEI-3S/C',999,1000,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 09:34:24',1,'',NULL,NULL,NULL,0,0),(32,'74',74,'199523-BERBEI-3S/C',1000,1000,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 09:45:19',1,'',NULL,NULL,NULL,0,0),(33,'48',48,'131109',97,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 09:53:08',1,'',NULL,NULL,NULL,0,0),(34,'74',74,'199523-BERBEI-3S/C',999,1000,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 10:15:21',1,'',NULL,NULL,NULL,0,0),(35,'74',74,'199523-BERBEI-3S/C',1000,1000,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 10:48:21',1,'',NULL,NULL,NULL,0,0),(36,'74',74,'199523-BERBEI-3S/C',999,1000,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 11:18:59',1,'',NULL,NULL,NULL,0,0),(37,'41',41,'ECOTANKM15140',100,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 12:02:17',1,'',NULL,NULL,NULL,0,0),(38,'49',49,'245042',99,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 12:02:29',1,'',NULL,NULL,NULL,0,0),(39,'74',74,'199523-BERBEI-3S/C',1000,1000,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 12:20:45',1,'',NULL,NULL,NULL,0,0),(40,'41',41,'ECOTANKM15140',99,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 12:32:32',1,'',NULL,NULL,NULL,0,0),(41,'49',49,'245042',98,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 12:32:32',1,'',NULL,NULL,NULL,0,0),(42,'43',43,'DR-6010C',100,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 12:34:58',1,'',NULL,NULL,NULL,0,0),(43,'49',49,'245042',99,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 12:45:00',1,'',NULL,NULL,NULL,0,0),(44,'74',74,'199523-BERBEI-3S/C',999,1000,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 12:51:36',1,'',NULL,NULL,NULL,0,0),(45,'74',74,'199523-BERBEI-3S/C',1000,1000,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:05:10',1,'',NULL,NULL,NULL,0,0),(46,'43',43,'DR-6010C',99,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:05:10',1,'',NULL,NULL,NULL,0,0),(47,'49',49,'245042',98,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:15:06',1,'',NULL,NULL,NULL,0,0),(48,'74',74,'199523-BERBEI-3S/C',999,1000,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:41:12',1,'',NULL,NULL,NULL,0,0),(49,'74',74,'199523-BERBEI-3S/C',1000,1000,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:41:19',1,'',NULL,NULL,NULL,0,0),(50,'64',64,'CLAYTON321-R8308-BROWN',999,999,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:43:21',1,'',NULL,NULL,NULL,0,0),(51,'57',57,'00MPQQ-010000-Q',956,957,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:43:21',1,'',NULL,NULL,NULL,0,0),(52,'75',75,'PR539-ZEDS QUASAR-Q',2166,2166,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:43:21',1,'',NULL,NULL,NULL,0,0),(53,'74',74,'199523-BERBEI-3S/C',999,1000,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:44:02',1,'',NULL,NULL,NULL,0,0),(54,'75',75,'PR539-ZEDS QUASAR-Q',2165,2166,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:44:02',1,'',NULL,NULL,NULL,0,0),(55,'57',57,'00MPQQ-010000-Q',955,957,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:44:03',1,'',NULL,NULL,NULL,0,0),(56,'64',64,'CLAYTON321-R8308-BROWN',998,999,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:44:03',1,'',NULL,NULL,NULL,0,0),(57,'64',64,'CLAYTON321-R8308-BROWN',999,999,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:44:03',1,'',NULL,NULL,NULL,0,0),(58,'57',57,'00MPQQ-010000-Q',956,957,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:44:03',1,'',NULL,NULL,NULL,0,0),(59,'75',75,'PR539-ZEDS QUASAR-Q',2166,2166,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:44:03',1,'',NULL,NULL,NULL,0,0),(60,'74',74,'199523-BERBEI-3S/C',1000,1000,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:44:03',1,'',NULL,NULL,NULL,0,0),(61,'74',74,'199523-BERBEI-3S/C',999,1000,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:44:05',1,'',NULL,NULL,NULL,0,0),(62,'75',75,'PR539-ZEDS QUASAR-Q',2165,2166,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:44:06',1,'',NULL,NULL,NULL,0,0),(63,'57',57,'00MPQQ-010000-Q',955,957,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:44:06',1,'',NULL,NULL,NULL,0,0),(64,'64',64,'CLAYTON321-R8308-BROWN',998,999,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 13:44:06',1,'',NULL,NULL,NULL,0,0),(65,'49',49,'245042',99,100,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 14:17:06',1,'',NULL,NULL,NULL,0,0),(66,'9',9,'NY8183',99,99,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 14:23:56',1,'',NULL,NULL,NULL,0,0),(67,'9',9,'NY8183',98,99,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 14:24:31',1,'',NULL,NULL,NULL,0,0),(68,'9',9,'NY8183',99,99,'-',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 14:24:31',1,'',NULL,NULL,NULL,0,0),(69,'9',9,'NY8183',98,99,'+',1,0,1,9,0,0,0,'Temporary Stock Update','2022-07-25 14:24:34',1,'',NULL,NULL,NULL,0,0),(70,'49',49,'245042',99,100,'+',1,0,1,9,0,0,0,'Temporary Stock Update','[[regtime]]',1,'',NULL,NULL,NULL,0,0);
/*!40000 ALTER TABLE `stock_history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `subscribers`
--

DROP TABLE IF EXISTS `subscribers`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `subscribers` (
  `subscribers_id` int(11) NOT NULL AUTO_INCREMENT,
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `subscribers_md5hash` varchar(255) NOT NULL DEFAULT '',
  `subscribers_firstname` varchar(255) NOT NULL DEFAULT '',
  `subscribers_lastname` varchar(255) NOT NULL DEFAULT '',
  `subscribers_email_address` varchar(255) NOT NULL DEFAULT '',
  `subscribers_status` int(11) NOT NULL DEFAULT '0',
  `subscribers_datetime` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `subscribers_sales1` int(11) NOT NULL DEFAULT '0',
  `subscribers_sales2` int(11) NOT NULL DEFAULT '0',
  `subscribers_sales3` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `all_lists` int(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (`subscribers_id`),
  UNIQUE KEY `idx_platform_id_email` (`subscribers_email_address`,`platform_id`),
  KEY `idx_all_lists` (`all_lists`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `subscribers`
--

LOCK TABLES `subscribers` WRITE;
/*!40000 ALTER TABLE `subscribers` DISABLE KEYS */;
/*!40000 ALTER TABLE `subscribers` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `subscribers_lists`
--

DROP TABLE IF EXISTS `subscribers_lists`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `subscribers_lists` (
  `subscribers_lists_id` int(11) NOT NULL DEFAULT '0',
  `platform_id` int(11) NOT NULL DEFAULT '0',
  `language_id` int(11) NOT NULL DEFAULT '0',
  `name` varchar(255) NOT NULL DEFAULT '',
  `parent_id` int(11) NOT NULL DEFAULT '0',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `description` varchar(255) NOT NULL DEFAULT '',
  `status` int(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`subscribers_lists_id`,`language_id`,`platform_id`),
  KEY `idx_parent_id` (`parent_id`),
  KEY `idx_status` (`status`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `subscribers_lists`
--

LOCK TABLES `subscribers_lists` WRITE;
/*!40000 ALTER TABLE `subscribers_lists` DISABLE KEYS */;
/*!40000 ALTER TABLE `subscribers_lists` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `subscribers_lists_newsletters`
--

DROP TABLE IF EXISTS `subscribers_lists_newsletters`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `subscribers_lists_newsletters` (
  `subscribers_lists_id` int(11) NOT NULL DEFAULT '0',
  `external_id` varchar(255) NOT NULL DEFAULT '',
  `provider` varchar(255) NOT NULL DEFAULT '',
  `external_name` varchar(255) NOT NULL DEFAULT '',
  `type` varchar(50) NOT NULL DEFAULT '',
  PRIMARY KEY (`subscribers_lists_id`,`provider`,`external_id`),
  KEY `idx_provider_ext_id` (`provider`,`external_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `subscribers_lists_newsletters`
--

LOCK TABLES `subscribers_lists_newsletters` WRITE;
/*!40000 ALTER TABLE `subscribers_lists_newsletters` DISABLE KEYS */;
/*!40000 ALTER TABLE `subscribers_lists_newsletters` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `subscribers_to_lists`
--

DROP TABLE IF EXISTS `subscribers_to_lists`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `subscribers_to_lists` (
  `subscribers_lists_id` int(11) NOT NULL DEFAULT '0',
  `subscribers_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`subscribers_lists_id`,`subscribers_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `subscribers_to_lists`
--

LOCK TABLES `subscribers_to_lists` WRITE;
/*!40000 ALTER TABLE `subscribers_to_lists` DISABLE KEYS */;
/*!40000 ALTER TABLE `subscribers_to_lists` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suppliers`
--

DROP TABLE IF EXISTS `suppliers`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `suppliers` (
  `suppliers_id` int(11) NOT NULL AUTO_INCREMENT,
  `suppliers_name` varchar(96) DEFAULT NULL,
  `_suppliers_surcharge_amount` decimal(8,2) NOT NULL DEFAULT '0.00',
  `_suppliers_margin_percentage` decimal(8,2) NOT NULL DEFAULT '0.00',
  `suppliers_script` varchar(64) NOT NULL DEFAULT '',
  `date_added` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `is_default` int(1) DEFAULT '0',
  `_price_formula` varchar(1024) NOT NULL DEFAULT '',
  `status` smallint(6) NOT NULL DEFAULT '1',
  `condition` text NOT NULL,
  `condition_description` text NOT NULL,
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `currencies_id` int(11) NOT NULL DEFAULT '15',
  `delivery_days_min` int(3) DEFAULT NULL,
  `delivery_days_max` int(3) DEFAULT NULL,
  `company` varchar(128) NOT NULL DEFAULT '',
  `company_vat` varchar(64) NOT NULL DEFAULT '',
  `tax_class_id` int(11) NOT NULL DEFAULT '0',
  `supplier_prices_with_tax` tinyint(1) NOT NULL DEFAULT '1',
  `tax_rate` decimal(5,2) NOT NULL DEFAULT '0.00',
  `send_email` varchar(2048) NOT NULL DEFAULT '',
  `document_format` varchar(16) NOT NULL DEFAULT '',
  `reorder_auto` tinyint(1) NOT NULL DEFAULT '0',
  `send_amount` decimal(15,2) NOT NULL DEFAULT '0.00',
  `send_qty` int(11) NOT NULL DEFAULT '1',
  `warehouse_id` int(11) NOT NULL DEFAULT '0',
  `contact_name` varchar(128) NOT NULL DEFAULT '',
  `contact_phone` varchar(128) NOT NULL DEFAULT '',
  `awrs_no` varchar(128) NOT NULL DEFAULT '',
  `sage_code` varchar(128) NOT NULL DEFAULT '',
  `payment_delay` int(11) NOT NULL DEFAULT '0',
  `supply_delay` int(11) NOT NULL DEFAULT '0',
  `street_address` varchar(128) NOT NULL DEFAULT '',
  `suburb` varchar(128) NOT NULL DEFAULT '',
  `city` varchar(128) NOT NULL DEFAULT '',
  `postcode` varchar(128) NOT NULL DEFAULT '',
  `state` varchar(128) NOT NULL DEFAULT '',
  `country` varchar(128) NOT NULL DEFAULT 'GB',
  `invoice_needed_to_complete_po` tinyint(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (`suppliers_id`),
  KEY `idx_suppliers_name` (`suppliers_name`)
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suppliers`
--

LOCK TABLES `suppliers` WRITE;
/*!40000 ALTER TABLE `suppliers` DISABLE KEYS */;
INSERT INTO `suppliers` VALUES (9,'Default Supplier',0.00,0.00,'','0000-00-00 00:00:00','2022-07-22 21:08:14',1,'',1,'','',0,2,0,0,'My Company','GB123456789',0,1,0.00,'','txt',0,0.00,1,1,'','','','',0,0,'','','','','','GB',1);
/*!40000 ALTER TABLE `suppliers` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suppliers_auth_data`
--

DROP TABLE IF EXISTS `suppliers_auth_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `suppliers_auth_data` (
  `suppliers_id` int(11) NOT NULL AUTO_INCREMENT,
  `email_address` varchar(128) DEFAULT NULL,
  `password` varchar(128) DEFAULT NULL,
  PRIMARY KEY (`suppliers_id`),
  CONSTRAINT `suppliers_id` FOREIGN KEY (`suppliers_id`) REFERENCES `suppliers` (`suppliers_id`)
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suppliers_auth_data`
--

LOCK TABLES `suppliers_auth_data` WRITE;
/*!40000 ALTER TABLE `suppliers_auth_data` DISABLE KEYS */;
INSERT INTO `suppliers_auth_data` VALUES (9,NULL,NULL);
/*!40000 ALTER TABLE `suppliers_auth_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suppliers_catalog_discount`
--

DROP TABLE IF EXISTS `suppliers_catalog_discount`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `suppliers_catalog_discount` (
  `catalog_discount_id` int(11) NOT NULL AUTO_INCREMENT,
  `suppliers_id` int(11) NOT NULL DEFAULT '0',
  `category_id` int(11) NOT NULL DEFAULT '0',
  `manufacturer_id` int(11) NOT NULL DEFAULT '0',
  `quantity_from` int(11) DEFAULT NULL,
  `quantity_to` int(11) DEFAULT NULL,
  `supplier_discount` decimal(8,2) DEFAULT NULL,
  PRIMARY KEY (`catalog_discount_id`),
  KEY `suppliers_id` (`suppliers_id`),
  KEY `category_id` (`category_id`),
  KEY `manufacturer_id` (`manufacturer_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suppliers_catalog_discount`
--

LOCK TABLES `suppliers_catalog_discount` WRITE;
/*!40000 ALTER TABLE `suppliers_catalog_discount` DISABLE KEYS */;
/*!40000 ALTER TABLE `suppliers_catalog_discount` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suppliers_catalog_price_rules`
--

DROP TABLE IF EXISTS `suppliers_catalog_price_rules`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `suppliers_catalog_price_rules` (
  `rule_id` int(11) NOT NULL AUTO_INCREMENT,
  `suppliers_id` int(11) NOT NULL DEFAULT '0',
  `category_id` int(11) NOT NULL DEFAULT '0',
  `manufacturer_id` int(11) NOT NULL DEFAULT '0',
  `currencies_id` int(11) NOT NULL DEFAULT '0',
  `rule_condition` varchar(32) NOT NULL DEFAULT '',
  `supplier_price_from` decimal(15,6) DEFAULT NULL,
  `supplier_price_to` decimal(15,6) DEFAULT NULL,
  `supplier_price_not_below` decimal(15,6) DEFAULT NULL,
  `supplier_discount` decimal(8,2) DEFAULT NULL,
  `surcharge_amount` decimal(8,2) DEFAULT NULL,
  `margin_percentage` decimal(8,2) DEFAULT NULL,
  `price_formula` varchar(1024) DEFAULT NULL,
  PRIMARY KEY (`rule_id`),
  KEY `suppliers_id` (`suppliers_id`),
  KEY `category_id` (`category_id`),
  KEY `manufacturer_id` (`manufacturer_id`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suppliers_catalog_price_rules`
--

LOCK TABLES `suppliers_catalog_price_rules` WRITE;
/*!40000 ALTER TABLE `suppliers_catalog_price_rules` DISABLE KEYS */;
/*!40000 ALTER TABLE `suppliers_catalog_price_rules` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suppliers_currencies`
--

DROP TABLE IF EXISTS `suppliers_currencies`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `suppliers_currencies` (
  `suppliers_id` int(11) NOT NULL,
  `currencies_id` int(11) NOT NULL,
  `status` int(1) DEFAULT '0',
  `use_custom_currency_value` int(1) DEFAULT '0',
  `currency_value` double DEFAULT '0',
  `margin_value` float DEFAULT '0',
  `margin_type` char(8) DEFAULT '%',
  PRIMARY KEY (`suppliers_id`,`currencies_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suppliers_currencies`
--

LOCK TABLES `suppliers_currencies` WRITE;
/*!40000 ALTER TABLE `suppliers_currencies` DISABLE KEYS */;
INSERT INTO `suppliers_currencies` VALUES (9,2,0,0,1.13334,0,'%'),(9,11,0,0,1.39695001,0,'%'),(9,15,1,0,1,0,NULL);
/*!40000 ALTER TABLE `suppliers_currencies` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suppliers_dispatch_time`
--

DROP TABLE IF EXISTS `suppliers_dispatch_time`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `suppliers_dispatch_time` (
  `suppliers_dispatch_time_id` int(11) NOT NULL AUTO_INCREMENT,
  `suppliers_id` int(11) NOT NULL DEFAULT '0',
  `days` int(4) NOT NULL DEFAULT '0',
  `time_from` int(4) NOT NULL DEFAULT '0',
  `time_to` int(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`suppliers_dispatch_time_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suppliers_dispatch_time`
--

LOCK TABLES `suppliers_dispatch_time` WRITE;
/*!40000 ALTER TABLE `suppliers_dispatch_time` DISABLE KEYS */;
/*!40000 ALTER TABLE `suppliers_dispatch_time` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suppliers_products`
--

DROP TABLE IF EXISTS `suppliers_products`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `suppliers_products` (
  `products_id` int(11) NOT NULL DEFAULT '0',
  `uprid` varchar(255) NOT NULL,
  `suppliers_id` int(11) NOT NULL DEFAULT '0',
  `suppliers_model` varchar(64) NOT NULL DEFAULT '',
  `suppliers_price` decimal(8,2) NOT NULL DEFAULT '0.00',
  `supplier_discount` decimal(8,2) DEFAULT NULL,
  `suppliers_surcharge_amount` decimal(8,2) DEFAULT NULL,
  `suppliers_margin_percentage` decimal(8,2) DEFAULT NULL,
  `suppliers_quantity` int(11) NOT NULL DEFAULT '0',
  `date_added` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `suppliers_product_name` varchar(255) NOT NULL DEFAULT '',
  `suppliers_upc` varchar(14) DEFAULT NULL,
  `is_default` int(1) DEFAULT '0',
  `currencies_id` int(11) NOT NULL DEFAULT '0',
  `status` smallint(1) DEFAULT '1',
  `suppliers_asin` varchar(10) DEFAULT NULL,
  `suppliers_isbn` varchar(13) DEFAULT NULL,
  `suppliers_ean` varchar(13) DEFAULT NULL,
  `tax_rate` decimal(5,2) DEFAULT NULL,
  `price_with_tax` tinyint(1) DEFAULT NULL,
  `landed_price` decimal(11,2) DEFAULT NULL,
  `notes` text,
  `source` varchar(32) NOT NULL DEFAULT '',
  `emergency_stock` int(11) NOT NULL DEFAULT '0',
  `stock_reorder_level_on` int(11) NOT NULL DEFAULT '0',
  `stock_reorder_level` int(11) NOT NULL DEFAULT '0',
  `stock_reorder_quantity_on` int(11) NOT NULL DEFAULT '0',
  `stock_reorder_quantity` int(11) NOT NULL DEFAULT '0',
  `suppliers_price_discount` varchar(255) NOT NULL DEFAULT '',
  `sort_order` int(11) DEFAULT NULL,
  PRIMARY KEY (`products_id`,`uprid`,`suppliers_id`),
  KEY `idx_products_id` (`products_id`),
  KEY `idx_suppliers_id` (`suppliers_id`),
  KEY `idx_suppliers_model` (`suppliers_model`),
  KEY `idx_uprid` (`uprid`),
  KEY `suppliers_products_source` (`source`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suppliers_products`
--

LOCK TABLES `suppliers_products` WRITE;
/*!40000 ALTER TABLE `suppliers_products` DISABLE KEYS */;
INSERT INTO `suppliers_products` VALUES (1,'1',9,'',90.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 13:58:28','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(2,'2',9,'',60.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 15:21:49','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(3,'3',9,'',150.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 13:58:59','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(4,'4',9,'',25.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:01:06','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(5,'5',9,'',45.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:01:32','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(6,'6',9,'',130.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:01:22','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(7,'7',9,'',20.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:01:27','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(8,'8',9,'',50.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:00:55','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(9,'9',9,'',30.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 15:19:45','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(10,'10',9,'',80.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 13:58:47','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(11,'11',9,'',190.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 15:21:23','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(12,'12',9,'',30.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:01:00','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(13,'13',9,'',30.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-25 12:08:47','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(14,'14',9,'',150.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 13:59:18','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(15,'15',9,'',35.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-25 12:27:22','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(16,'16',9,'',25.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-25 12:22:36','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(17,'17',9,'',45.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:00:14','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(18,'18',9,'',40.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 15:20:51','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(19,'19',9,'',35.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:01:11','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(20,'20',9,'',80.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:01:16','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(21,'21',9,'',30.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-25 12:17:51','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(22,'22',9,'',160.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:00:44','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(23,'23',9,'',240.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-25 08:55:20','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(24,'24',9,'',120.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:00:39','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(25,'25',9,'',160.00,NULL,NULL,NULL,10,'2022-07-22 21:07:07','2022-07-23 14:00:19','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(26,'26',9,'',25.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:00:23','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(27,'27',9,'',28.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:00:33','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(28,'28',9,'',30.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:00:28','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(29,'29',9,'',130.00,NULL,NULL,NULL,0,'2022-07-22 21:07:07','2022-07-23 14:01:37','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(30,'30',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:00','2022-07-25 12:39:32','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(31,'31',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:00','2022-07-25 12:48:07','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(32,'32',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:00','2022-07-25 12:45:27','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(33,'33',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:00','2022-07-25 12:36:32','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(34,'34',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:00','2022-07-25 13:04:06','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(35,'35',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:00','2022-07-25 13:02:21','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(36,'36',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:00','2022-07-25 12:58:38','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(37,'37',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:00','2022-07-25 12:53:54','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(38,'38',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:10','2022-07-25 11:26:57','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(39,'39',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:10','2022-07-25 11:20:19','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(40,'40',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:10','2022-07-25 11:16:14','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(41,'41',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:10','2022-07-25 11:22:59','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(42,'42',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:10','2022-07-25 10:56:54','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(43,'43',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:10','2022-07-25 11:12:33','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(44,'44',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:10','2022-07-25 10:50:13','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(45,'45',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:10','2022-07-25 11:12:09','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(46,'46',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:10','2022-07-25 11:37:40','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(47,'47',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:10','2022-07-25 11:34:37','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(48,'48',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:10','2022-07-25 11:31:29','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(49,'49',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:07:10','2022-07-25 11:40:02','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(50,'50',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:06:19','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(51,'51',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:06:13','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(52,'52',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:25:18','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(53,'53',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:46:33','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(54,'54',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:43:56','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(55,'55',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:04:43','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(56,'56',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:45:53','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(57,'57',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:02:02','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(58,'58',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:02:30','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(59,'59',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:45:08','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(60,'60',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 15:18:44','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(61,'61',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:16:28','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(62,'62',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:06:00','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(63,'63',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-25 08:54:01','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(64,'64',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:05:38','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(65,'65',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:47:13','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(66,'66',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:05:55','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(67,'67',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:05:49','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(68,'68',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:44:33','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(69,'69',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:44:48','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(70,'70',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:06:50','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(71,'71',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:07:11','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(72,'72',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:06:44','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(73,'73',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:06:25','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(74,'74',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:05:25','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL),(75,'75',9,'',0.00,NULL,NULL,NULL,0,'2022-07-22 21:08:14','2022-07-23 14:06:31','','',0,15,1,'','','',NULL,0,NULL,'','',0,0,0,0,0,'',NULL);
/*!40000 ALTER TABLE `suppliers_products` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suppliers_products_options`
--

DROP TABLE IF EXISTS `suppliers_products_options`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `suppliers_products_options` (
  `suppliers_id` int(11) NOT NULL,
  `suppliers_products_options_id` int(11) NOT NULL,
  `products_options_id` int(11) NOT NULL,
  PRIMARY KEY (`suppliers_id`,`suppliers_products_options_id`,`products_options_id`),
  KEY `suppliers_id` (`suppliers_id`),
  KEY `suppliers_products_options_id` (`suppliers_products_options_id`),
  KEY `products_options_id` (`products_options_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suppliers_products_options`
--

LOCK TABLES `suppliers_products_options` WRITE;
/*!40000 ALTER TABLE `suppliers_products_options` DISABLE KEYS */;
/*!40000 ALTER TABLE `suppliers_products_options` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `suppliers_products_options_values`
--

DROP TABLE IF EXISTS `suppliers_products_options_values`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `suppliers_products_options_values` (
  `suppliers_id` int(11) NOT NULL,
  `suppliers_products_options_values_id` int(11) NOT NULL,
  `products_options_values_id` int(11) NOT NULL,
  `suppliers_products_model` varchar(255) NOT NULL,
  PRIMARY KEY (`suppliers_id`,`suppliers_products_options_values_id`,`products_options_values_id`,`suppliers_products_model`),
  KEY `suppliers_id` (`suppliers_id`),
  KEY `suppliers_products_options_values_id` (`suppliers_products_options_values_id`),
  KEY `products_options_values_id` (`products_options_values_id`),
  KEY `suppliers_products_model` (`suppliers_products_model`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `suppliers_products_options_values`
--

LOCK TABLES `suppliers_products_options_values` WRITE;
/*!40000 ALTER TABLE `suppliers_products_options_values` DISABLE KEYS */;
/*!40000 ALTER TABLE `suppliers_products_options_values` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tax_class`
--

DROP TABLE IF EXISTS `tax_class`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tax_class` (
  `tax_class_id` int(11) NOT NULL AUTO_INCREMENT,
  `tax_class_title` varchar(32) NOT NULL DEFAULT '',
  `tax_class_description` varchar(255) NOT NULL DEFAULT '',
  `last_modified` datetime DEFAULT NULL,
  `date_added` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  PRIMARY KEY (`tax_class_id`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tax_class`
--

LOCK TABLES `tax_class` WRITE;
/*!40000 ALTER TABLE `tax_class` DISABLE KEYS */;
INSERT INTO `tax_class` VALUES (3,'Tax EU-20%','Tax EU-20%','2017-09-19 10:58:52','2006-03-18 16:30:07');
/*!40000 ALTER TABLE `tax_class` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tax_rates`
--

DROP TABLE IF EXISTS `tax_rates`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tax_rates` (
  `tax_rates_id` int(11) NOT NULL AUTO_INCREMENT,
  `tax_zone_id` int(11) NOT NULL DEFAULT '0',
  `tax_class_id` int(11) NOT NULL DEFAULT '0',
  `tax_priority` int(5) DEFAULT '1',
  `tax_rate` decimal(7,4) NOT NULL DEFAULT '0.0000',
  `tax_description` varchar(255) NOT NULL DEFAULT '',
  `last_modified` datetime DEFAULT NULL,
  `date_added` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `max_total` decimal(10,6) DEFAULT NULL,
  `min_total` decimal(10,6) DEFAULT NULL,
  `company_number` varchar(128) NOT NULL DEFAULT '',
  `company_name` varchar(1024) NOT NULL DEFAULT '',
  `company_address` varchar(1024) NOT NULL DEFAULT '',
  PRIMARY KEY (`tax_rates_id`),
  KEY `tax_class_id` (`tax_class_id`)
) ENGINE=InnoDB AUTO_INCREMENT=16 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tax_rates`
--

LOCK TABLES `tax_rates` WRITE;
/*!40000 ALTER TABLE `tax_rates` DISABLE KEYS */;
INSERT INTO `tax_rates` VALUES (5,4,3,0,20.0000,'VAT 20%','2017-12-18 14:23:58','2006-01-13 20:32:50',NULL,NULL,'','','Unit 21 Fonthill Business Park, Fonthill Road, Clondalkin, D22 FR82, Ireland'),(13,4,6,0,10.0000,'VAT 30%','2017-09-19 10:58:21','2017-06-06 09:49:31',NULL,NULL,'','','Unit 21 Fonthill Business Park, Fonthill Road, Clondalkin, D22 FR82, Ireland'),(14,12,7,32,16.0000,'Описание','2018-02-21 12:40:13','2018-02-21 12:39:36',NULL,NULL,'','','Unit 21 Fonthill Business Park, Fonthill Road, Clondalkin, D22 FR82, Ireland');
/*!40000 ALTER TABLE `tax_rates` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `tax_zones`
--

DROP TABLE IF EXISTS `tax_zones`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `tax_zones` (
  `geo_zone_id` int(11) NOT NULL AUTO_INCREMENT,
  `geo_zone_name` varchar(32) NOT NULL DEFAULT '',
  `geo_zone_description` varchar(255) NOT NULL DEFAULT '',
  `last_modified` datetime DEFAULT NULL,
  `date_added` datetime DEFAULT NULL,
  PRIMARY KEY (`geo_zone_id`)
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `tax_zones`
--

LOCK TABLES `tax_zones` WRITE;
/*!40000 ALTER TABLE `tax_zones` DISABLE KEYS */;
INSERT INTO `tax_zones` VALUES (1,'TAX USA','USA','2005-01-10 21:39:04','2003-07-17 10:29:23'),(4,'TAX EU','EU','2017-01-23 09:25:50','2006-03-18 16:29:55');
/*!40000 ALTER TABLE `tax_zones` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `template`
--

DROP TABLE IF EXISTS `template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `template` (
  `template_id` int(11) NOT NULL AUTO_INCREMENT,
  `template_name` varchar(64) DEFAULT '0',
  `date_added` datetime DEFAULT NULL,
  `last_modified` datetime DEFAULT NULL,
  `template_image` varchar(64) DEFAULT NULL,
  `template_cellpadding_main` char(3) NOT NULL DEFAULT '0',
  `template_cellpadding_sub` char(3) NOT NULL DEFAULT '0',
  `template_cellpadding_left` char(3) NOT NULL DEFAULT '0',
  `template_cellpadding_right` char(3) NOT NULL DEFAULT '0',
  `site_width` varchar(5) NOT NULL DEFAULT '100%',
  `include_column_left` varchar(64) NOT NULL DEFAULT 'yes',
  `include_column_right` varchar(64) NOT NULL DEFAULT 'yes',
  `box_width_left` varchar(4) NOT NULL DEFAULT '125',
  `box_width_right` varchar(4) NOT NULL DEFAULT '125',
  `main_table_border` varchar(6) NOT NULL DEFAULT 'no',
  `active` char(1) NOT NULL DEFAULT '1',
  `show_heading_title_original` varchar(6) NOT NULL DEFAULT 'yes',
  `languages_in_header` char(3) DEFAULT 'no',
  `cart_in_header` char(3) NOT NULL DEFAULT 'no',
  `show_header_link_buttons` char(3) NOT NULL DEFAULT 'no',
  `module_one` varchar(64) NOT NULL DEFAULT '',
  `module_two` varchar(64) NOT NULL DEFAULT '',
  `module_three` varchar(64) NOT NULL DEFAULT '',
  `module_four` varchar(64) NOT NULL DEFAULT '',
  `module_five` varchar(64) NOT NULL DEFAULT '',
  `module_six` varchar(64) NOT NULL DEFAULT '',
  `customer_greeting` char(3) NOT NULL DEFAULT 'yes',
  `edit_customer_greeting_personal` text NOT NULL,
  `edit_customer_greeting_personal_relogon` text NOT NULL,
  `edit_greeting_guest` text NOT NULL,
  `side_box_left_width` int(10) DEFAULT '1',
  `side_box_right_width` int(10) DEFAULT '1',
  `one_page_checkout` tinyint(4) NOT NULL DEFAULT '1',
  PRIMARY KEY (`template_id`),
  KEY `IDX_TEMPLATE_NAME` (`template_name`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `template`
--

LOCK TABLES `template` WRITE;
/*!40000 ALTER TABLE `template` DISABLE KEYS */;
INSERT INTO `template` VALUES (1,'Original','2003-11-26 23:55:06','2006-10-31 00:49:03','Original.gif','0','10','0','0','100%','yes','yes','227','227','no','1','yes','no','no','no','example.html','default_specials.php','new_products.php','featured.php','newsdesk.php','','yes','','','',0,0,1),(2,'creator','2010-10-08 08:05:43','2016-03-18 18:07:39','Original.gif','0','0','0','0','1684','yes','yes','284','284','no','1','yes','no','no','no','banner.php','brands.php','default_specials.php','new_products.php','featured.php','','no','','','',0,0,1),(3,'mobile','2014-04-21 11:00:48',NULL,'Original.gif','0','0','0','0','100%','no','no','181','181','no','1','yes','no','no','no','default_specials.php','featured.php','','','','','no','','','',0,0,0);
/*!40000 ALTER TABLE `template` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `temporary_stock`
--

DROP TABLE IF EXISTS `temporary_stock`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `temporary_stock` (
  `temporary_stock_id` int(11) NOT NULL AUTO_INCREMENT,
  `warehouse_id` int(11) NOT NULL DEFAULT '0',
  `suppliers_id` int(11) NOT NULL DEFAULT '0',
  `location_id` int(11) NOT NULL DEFAULT '0',
  `session_id` varchar(128) NOT NULL DEFAULT '',
  `customers_id` int(11) NOT NULL DEFAULT '0',
  `prid` int(11) NOT NULL DEFAULT '0',
  `parent_id` int(11) NOT NULL DEFAULT '0',
  `child_id` text NOT NULL,
  `products_id` text NOT NULL,
  `normalize_id` text NOT NULL,
  `temporary_stock_quantity` int(2) NOT NULL DEFAULT '0',
  `not_available_quantity` int(2) NOT NULL DEFAULT '0',
  `temporary_stock_datetime` datetime DEFAULT NULL,
  `specials_id` int(11) NOT NULL DEFAULT '0',
  `layers_id` int(11) NOT NULL DEFAULT '0',
  `batch_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`temporary_stock_id`),
  KEY `session_id` (`session_id`),
  KEY `customers_id` (`customers_id`),
  KEY `prid` (`prid`),
  KEY `products_id` (`products_id`(128)),
  KEY `normalize_id` (`normalize_id`(128)),
  KEY `temporary_stock_datetime` (`temporary_stock_datetime`),
  KEY `warehouse_id` (`warehouse_id`),
  KEY `idx_suppliers_id` (`suppliers_id`),
  KEY `location_id` (`location_id`),
  KEY `idx_specials_id` (`specials_id`),
  KEY `idx_layers_id` (`layers_id`),
  KEY `idx_batch_id` (`batch_id`)
) ENGINE=InnoDB AUTO_INCREMENT=44 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `temporary_stock`
--

LOCK TABLES `temporary_stock` WRITE;
/*!40000 ALTER TABLE `temporary_stock` DISABLE KEYS */;
/*!40000 ALTER TABLE `temporary_stock` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `themes`
--

DROP TABLE IF EXISTS `themes`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `themes` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `theme_name` varchar(64) DEFAULT NULL,
  `title` varchar(128) DEFAULT NULL,
  `description` text,
  `install` int(1) DEFAULT NULL,
  `is_default` int(1) DEFAULT NULL,
  `sort_order` int(11) DEFAULT NULL,
  `parent_theme` varchar(256) NOT NULL DEFAULT '',
  `themes_group_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `id` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=92 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `themes`
--

LOCK TABLES `themes` WRITE;
/*!40000 ALTER TABLE `themes` DISABLE KEYS */;
INSERT INTO `themes` VALUES (2,'watch','Watch',NULL,1,0,11,'0',0),(3,'furniture','Furniture',NULL,1,0,10,'0',0),(6,'printshop','Printshop',NULL,1,0,12,'0',0),(9,'deals','Deals',NULL,1,0,13,'0',0),(47,'splash','Splash',NULL,1,0,14,'0',0);
/*!40000 ALTER TABLE `themes` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `themes_groups`
--

DROP TABLE IF EXISTS `themes_groups`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `themes_groups` (
  `themes_group_id` int(11) NOT NULL AUTO_INCREMENT,
  `title` varchar(255) NOT NULL DEFAULT '',
  `sort_order` int(11) NOT NULL DEFAULT '0',
  `image` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`themes_group_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `themes_groups`
--

LOCK TABLES `themes_groups` WRITE;
/*!40000 ALTER TABLE `themes_groups` DISABLE KEYS */;
/*!40000 ALTER TABLE `themes_groups` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `themes_settings`
--

DROP TABLE IF EXISTS `themes_settings`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `themes_settings` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `theme_name` varchar(128) DEFAULT NULL,
  `setting_group` varchar(255) DEFAULT NULL,
  `setting_name` varchar(255) DEFAULT NULL,
  `setting_value` text,
  PRIMARY KEY (`id`),
  KEY `id` (`id`),
  KEY `theme_name` (`theme_name`),
  KEY `setting_group` (`setting_group`),
  KEY `setting_name` (`setting_name`)
) ENGINE=InnoDB AUTO_INCREMENT=8522 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `themes_settings`
--

LOCK TABLES `themes_settings` WRITE;
/*!40000 ALTER TABLE `themes_settings` DISABLE KEYS */;
INSERT INTO `themes_settings` VALUES (287,'watch-mobile','main','show_products_from_subcategories','1'),(288,'watch-mobile','javascript','javascript',''),(289,'watch-mobile','hide','backup_date','1694451242'),(290,'watch-mobile','extend','media_query','w720'),(291,'watch-mobile','extend','media_query','w800'),(292,'watch-mobile','extend','media_query','w1255'),(293,'watch-mobile','added_page','home','home2'),(294,'watch-mobile','added_page','products','Wedding Registry List'),(295,'watch-mobile','main','include_css','3'),(296,'watch-mobile','extend','media_query','720w'),(297,'watch-mobile','main','use_mobile_theme','1'),(298,'watch-mobile','extend','media_query','w1150'),(299,'watch-mobile','extend','media_query','w1000'),(300,'watch-mobile','added_page','info','inf 2'),(301,'watch-mobile','extend','font_added','@font-face {\r\n font-family: \'FontAwesome\';\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?v=3.2.1\');\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?#iefix&v=3.2.1\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.woff?v=3.2.1\') format(\'woff\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.ttf?v=3.2.1\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.svg#fontawesomeregular?v=3.2.1\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\n }'),(302,'watch-mobile','main','login_view',''),(303,'watch-mobile','extend','media_query','w1024'),(304,'watch-mobile','main','after_add','popup'),(305,'watch-mobile','added_page','info','Testimonials'),(306,'watch-mobile','extend','font_added','@font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/woSH4aW-1wuybBQItyfdsvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/FdFTd030tby8r55hlt7EYfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/0IXD51eZ8qgi73bhvRidlQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/Vb88BBmXXgbpZxolKzz6dw.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/eND698DA6CUFWomaRdrTiw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/xLdg5JI0N_C2fvyu9XVzXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/bWPw4Za2XndpOjggSNN5JPY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/TCDCvLw6ewp4kJ2WSI4MT_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/_JiDQLq4JWzs7prWhNNmuA.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/HMitXFBPwJyXZfGm6rEhuvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/-H4xgvCtDmIfFNvmoAPAKvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/A2xpLU2z2kq5byuh5bkohg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/AFoPIhbuX_gBhSszntNC0_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/503ks6dbq2nVdfUL61JyAfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/PQuIEfcr_wdF_zOSNjqWKQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }'),(307,'watch-mobile','hide','new_attributes','1'),(308,'watch-mobile','main','show_empty_categories',''),(309,'watch-mobile','extend','font_added','@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrkByb1TKJa77egybnpn19yM.woff2) format(\'woff2\');\r\n unicode-range: U+0590-05FF, U+20AA, U+25CC, U+FB1D-FB4F;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrugdm0LZdjqr5-oayXSOefg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n\r\n\r\n@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round Regular\'), local(\'VarelaRound-Regular\'), url(https://fonts.gstatic.com/s/varelaround/v8/APH4jr0uSos5wiut5cpjrnhCUOGz7vYGh680lGh-uXM.woff) format(\'woff\');\r\n}\r\n'),(310,'watch-mobile','added_page_settings','Product N','is_bundle'),(311,'watch-mobile','hide','theme_update','1520263888'),(312,'watch-mobile','added_page','categories','cl2'),(313,'watch-mobile','added_page_settings','Wedding Registry List','wedding_registry'),(314,'watch-mobile','main','checkout_view',''),(315,'watch-mobile','extend','media_query','w600'),(316,'watch-mobile','added_page','product','Product N'),(317,'watch-mobile','extend','media_query','w900'),(318,'watch-mobile','layout','index','home'),(319,'watch-mobile','extend','media_query','w650'),(320,'watch-mobile','extend','media_query','w500'),(321,'watch-mobile','extend','font_added','@font-face {\r\n font-family: \'trueloaded\';\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p\');\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p#iefix\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/trueloaded.ttf?4rk52p\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/trueloaded.woff?4rk52p\') format(\'woff\'),\r\n url(\'themes/basic/fonts/trueloaded.svg?4rk52p#trueloaded\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\n }'),(322,'watch-mobile','hide','theme_version','217'),(323,'watch-mobile','main','group_product_by_product_group',''),(324,'watch-mobile','main','show_in_cart_button',''),(325,'watch-mobile','main','customer_account','new'),(326,'watch-mobile','main','products_carousel',''),(327,'watch-mobile','main','theme_color',''),(328,'watch-mobile','main','service_worker',''),(329,'watch-mobile','main','backup_hours',''),(330,'watch-mobile','main','backup_count',''),(331,'watch-mobile','main','dev_mode',''),(332,'watch-mobile','main','old_listing',''),(333,'watch-mobile','main','base64_product',''),(334,'watch-mobile','main','base64_category',''),(335,'watch-mobile','main','base64_banner',''),(336,'watch-mobile','hide','favicon','themes/watch-mobile/img/favicon_osc-1.png'),(337,'watch-mobile','hide','logo','themes/watch-mobile/img/watchlogo.png'),(338,'watch-mobile','hide','na_category','themes/watch-mobile/img/no-categories-1.png'),(339,'watch-mobile','hide','na_product','themes/watch-mobile/img/na.png'),(340,'watch-mobile','added_page','categories',''),(341,'watch-mobile','added_page','gift_card',''),(342,'watch-mobile','added_page','account',''),(343,'watch-mobile','added_page','email',''),(344,'watch-mobile','added_page','account',''),(345,'watch-mobile','added_page','categories',''),(346,'watch-mobile','added_page_settings','Category no Filters',''),(347,'watch-mobile','added_page','productListing','b2b'),(348,'watch-mobile','added_page','account',''),(349,'watch-mobile','added_page','account',''),(350,'watch-mobile','added_page','productListing','Rows'),(351,'watch-mobile','added_page','productListing','Compare Products'),(352,'watch-mobile','added_page','categories',''),(353,'watch-mobile','added_page','categories',''),(354,'watch-mobile','added_page','account',''),(355,'watch-mobile','added_page','email',''),(356,'watch-mobile','added_page','account',''),(357,'watch-mobile','added_page','gift_card',''),(358,'watch-mobile','added_page','account',''),(359,'watch-mobile','added_page','email',''),(360,'watch-mobile','added_page','account',''),(361,'watch-mobile','added_page','invoice',''),(362,'watch-mobile','added_page','cart',''),(363,'watch-mobile','added_page','inform',''),(364,'watch-mobile','added_page','inform',''),(365,'watch-mobile','added_page','account',''),(366,'watch-mobile','added_page','account',''),(367,'watch-mobile','added_page','account',''),(368,'watch-mobile','added_page','home',''),(369,'watch-mobile','added_page','account',''),(370,'watch-mobile','added_page','components',''),(371,'watch-mobile','added_page','account',''),(372,'watch-mobile','added_page','account',''),(373,'watch-mobile','added_page','productListing','Batch'),(374,'watch-mobile','added_page','label',''),(375,'watch-mobile','added_page','account',''),(376,'watch-mobile','added_page','account',''),(377,'watch-mobile','added_page','account',''),(378,'watch-mobile','added_page','account',''),(379,'watch-mobile','added_page','productListing','Batch Selected'),(380,'watch-mobile','added_page','delivery-location',''),(381,'watch-mobile','added_page','products',''),(382,'watch-mobile','added_page_settings','No Filters',''),(383,'watch-mobile','added_page','account',''),(384,'watch-mobile','added_page','components',''),(385,'watch-mobile','added_page','account','Quotations'),(386,'watch-mobile','added_page','account','Points Earnt History'),(387,'watch-mobile','added_page','account','Tracking numbers'),(388,'watch-mobile','added_page','account','Samples'),(389,'watch-mobile','added_page','account','Quotation Info'),(390,'watch-mobile','added_page','account','Order pay'),(391,'watch-mobile','added_page','account','Order History'),(392,'watch-mobile','added_page','account','Account edit'),(393,'watch-mobile','added_page','account','Review'),(394,'watch-mobile','added_page','account','Order History Info'),(395,'watch-mobile','added_page','account','Sample Info'),(396,'watch-mobile','added_page','account','My password'),(397,'watch-mobile','added_page','account','Address Book Process'),(398,'watch-mobile','added_page','account','Created success'),(399,'watch-mobile','added_page','account','Gift Certificate'),(400,'watch-mobile','added_page','account','Address Book'),(401,'watch-mobile','added_page','account','Personal Catalog'),(402,'watch-mobile','added_page','account','Subscription'),(690,'printshop-mobile','main','show_products_from_subcategories','1'),(691,'printshop-mobile','javascript','javascript',''),(692,'printshop-mobile','hide','backup_date','1713810941'),(693,'printshop-mobile','extend','media_query','w720'),(694,'printshop-mobile','extend','media_query','w800'),(695,'printshop-mobile','extend','media_query','w1255'),(696,'printshop-mobile','added_page','home','home2'),(697,'printshop-mobile','added_page','products','Wedding Registry List'),(698,'printshop-mobile','main','include_css','3'),(699,'printshop-mobile','extend','media_query','720w'),(700,'printshop-mobile','main','use_mobile_theme','1'),(701,'printshop-mobile','extend','media_query','w1150'),(702,'printshop-mobile','extend','media_query','w1000'),(703,'printshop-mobile','added_page','info','inf 2'),(704,'printshop-mobile','extend','font_added','@font-face {\r\n font-family: \'FontAwesome\';\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?v=3.2.1\');\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?#iefix&v=3.2.1\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.woff?v=3.2.1\') format(\'woff\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.ttf?v=3.2.1\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.svg#fontawesomeregular?v=3.2.1\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\n }'),(705,'printshop-mobile','main','login_view',''),(706,'printshop-mobile','extend','media_query','w1024'),(707,'printshop-mobile','main','after_add','popup'),(708,'printshop-mobile','added_page','info','Testimonials'),(709,'printshop-mobile','extend','font_added','@font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/woSH4aW-1wuybBQItyfdsvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/FdFTd030tby8r55hlt7EYfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/0IXD51eZ8qgi73bhvRidlQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/Vb88BBmXXgbpZxolKzz6dw.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/eND698DA6CUFWomaRdrTiw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/xLdg5JI0N_C2fvyu9XVzXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/bWPw4Za2XndpOjggSNN5JPY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/TCDCvLw6ewp4kJ2WSI4MT_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/_JiDQLq4JWzs7prWhNNmuA.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/HMitXFBPwJyXZfGm6rEhuvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/-H4xgvCtDmIfFNvmoAPAKvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/A2xpLU2z2kq5byuh5bkohg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/AFoPIhbuX_gBhSszntNC0_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/503ks6dbq2nVdfUL61JyAfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/PQuIEfcr_wdF_zOSNjqWKQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }'),(710,'printshop-mobile','hide','new_attributes','1'),(711,'printshop-mobile','main','show_empty_categories',''),(712,'printshop-mobile','extend','font_added','@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrkByb1TKJa77egybnpn19yM.woff2) format(\'woff2\');\r\n unicode-range: U+0590-05FF, U+20AA, U+25CC, U+FB1D-FB4F;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrugdm0LZdjqr5-oayXSOefg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n\r\n\r\n@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round Regular\'), local(\'VarelaRound-Regular\'), url(https://fonts.gstatic.com/s/varelaround/v8/APH4jr0uSos5wiut5cpjrnhCUOGz7vYGh680lGh-uXM.woff) format(\'woff\');\r\n}\r\n'),(713,'printshop-mobile','added_page_settings','Product N','is_bundle'),(714,'printshop-mobile','hide','theme_update','1520263888'),(715,'printshop-mobile','added_page','categories','cl2'),(716,'printshop-mobile','added_page_settings','Wedding Registry List','wedding_registry'),(717,'printshop-mobile','main','checkout_view',''),(718,'printshop-mobile','extend','media_query','w600'),(719,'printshop-mobile','added_page','product','Product N'),(720,'printshop-mobile','extend','media_query','w900'),(721,'printshop-mobile','layout','index','home'),(722,'printshop-mobile','extend','media_query','w650'),(723,'printshop-mobile','extend','media_query','w500'),(724,'printshop-mobile','extend','font_added','@font-face {\r\n font-family: \'trueloaded\';\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p\');\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p#iefix\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/trueloaded.ttf?4rk52p\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/trueloaded.woff?4rk52p\') format(\'woff\'),\r\n url(\'themes/basic/fonts/trueloaded.svg?4rk52p#trueloaded\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\n }'),(725,'printshop-mobile','hide','theme_version','74'),(726,'printshop-mobile','main','group_product_by_product_group',''),(727,'printshop-mobile','main','show_in_cart_button',''),(728,'printshop-mobile','main','customer_account','new'),(729,'printshop-mobile','main','products_carousel',''),(730,'printshop-mobile','main','theme_color',''),(731,'printshop-mobile','main','service_worker',''),(732,'printshop-mobile','main','backup_hours',''),(733,'printshop-mobile','main','backup_count',''),(734,'printshop-mobile','main','dev_mode',''),(735,'printshop-mobile','main','old_listing',''),(736,'printshop-mobile','main','base64_product',''),(737,'printshop-mobile','main','base64_category',''),(738,'printshop-mobile','main','base64_banner',''),(739,'printshop-mobile','hide','favicon','themes/printshop-mobile/img/favicon_osc-1.png'),(740,'printshop-mobile','hide','logo','themes/printshop-mobile/img/oscommerce_logo-2.png'),(741,'printshop-mobile','hide','na_category','themes/printshop-mobile/img/no-categories-1.png'),(742,'printshop-mobile','hide','na_product','themes/printshop-mobile/img/na.png'),(743,'printshop-mobile','added_page_settings','Category no Filters',''),(744,'printshop-mobile','added_page_settings','No Filters',''),(745,'printshop-mobile','added_page','account','Quotations'),(746,'printshop-mobile','added_page','account','Points Earnt History'),(747,'printshop-mobile','added_page','account','Tracking numbers'),(748,'printshop-mobile','added_page','account','Samples'),(749,'printshop-mobile','added_page','account','Quotation Info'),(750,'printshop-mobile','added_page','account','Order pay'),(751,'printshop-mobile','added_page','account','Order History'),(752,'printshop-mobile','added_page','account','Account edit'),(753,'printshop-mobile','added_page','account','Review'),(754,'printshop-mobile','added_page','account','Order History Info'),(755,'printshop-mobile','added_page','account','Sample Info'),(756,'printshop-mobile','added_page','account','My password'),(757,'printshop-mobile','added_page','account','Address Book Process'),(758,'printshop-mobile','added_page','account','Created success'),(759,'printshop-mobile','added_page','account','Gift Certificate'),(760,'printshop-mobile','added_page','account','Address Book'),(761,'printshop-mobile','added_page','account','Personal Catalog'),(762,'printshop-mobile','added_page','account','Subscription'),(860,'deals-mobile','main','show_products_from_subcategories','1'),(861,'deals-mobile','javascript','javascript',''),(862,'deals-mobile','hide','backup_date','1713811296'),(863,'deals-mobile','extend','media_query','w720'),(864,'deals-mobile','extend','media_query','w800'),(865,'deals-mobile','extend','media_query','w1255'),(866,'deals-mobile','added_page','home','home2'),(867,'deals-mobile','added_page','products','Wedding Registry List'),(868,'deals-mobile','main','include_css','3'),(869,'deals-mobile','extend','media_query','720w'),(870,'deals-mobile','main','use_mobile_theme','1'),(871,'deals-mobile','extend','media_query','w1150'),(872,'deals-mobile','extend','media_query','w1000'),(873,'deals-mobile','added_page','info','inf 2'),(874,'deals-mobile','extend','font_added','@font-face {\r\n font-family: \'FontAwesome\';\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?v=3.2.1\');\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?#iefix&v=3.2.1\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.woff?v=3.2.1\') format(\'woff\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.ttf?v=3.2.1\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.svg#fontawesomeregular?v=3.2.1\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\n }'),(875,'deals-mobile','main','login_view',''),(876,'deals-mobile','extend','media_query','w1024'),(877,'deals-mobile','main','after_add','popup'),(878,'deals-mobile','added_page','info','Testimonials'),(879,'deals-mobile','extend','font_added','@font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/woSH4aW-1wuybBQItyfdsvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/FdFTd030tby8r55hlt7EYfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/0IXD51eZ8qgi73bhvRidlQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/Vb88BBmXXgbpZxolKzz6dw.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/eND698DA6CUFWomaRdrTiw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/xLdg5JI0N_C2fvyu9XVzXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/bWPw4Za2XndpOjggSNN5JPY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/TCDCvLw6ewp4kJ2WSI4MT_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/_JiDQLq4JWzs7prWhNNmuA.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/HMitXFBPwJyXZfGm6rEhuvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/-H4xgvCtDmIfFNvmoAPAKvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/A2xpLU2z2kq5byuh5bkohg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/AFoPIhbuX_gBhSszntNC0_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/503ks6dbq2nVdfUL61JyAfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/PQuIEfcr_wdF_zOSNjqWKQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }'),(880,'deals-mobile','hide','new_attributes','1'),(881,'deals-mobile','main','show_empty_categories',''),(882,'deals-mobile','extend','font_added','@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrkByb1TKJa77egybnpn19yM.woff2) format(\'woff2\');\r\n unicode-range: U+0590-05FF, U+20AA, U+25CC, U+FB1D-FB4F;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrugdm0LZdjqr5-oayXSOefg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\n }\r\n\r\n\r\n@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round Regular\'), local(\'VarelaRound-Regular\'), url(https://fonts.gstatic.com/s/varelaround/v8/APH4jr0uSos5wiut5cpjrnhCUOGz7vYGh680lGh-uXM.woff) format(\'woff\');\r\n}\r\n'),(883,'deals-mobile','added_page_settings','Product N','is_bundle'),(884,'deals-mobile','hide','theme_update','1520263888'),(885,'deals-mobile','added_page','categories','cl2'),(886,'deals-mobile','added_page_settings','Wedding Registry List','wedding_registry'),(887,'deals-mobile','main','checkout_view',''),(888,'deals-mobile','extend','media_query','w600'),(889,'deals-mobile','added_page','product','Product N'),(890,'deals-mobile','extend','media_query','w900'),(891,'deals-mobile','layout','index','home'),(892,'deals-mobile','extend','media_query','w650'),(893,'deals-mobile','extend','media_query','w500'),(894,'deals-mobile','extend','font_added','@font-face {\r\n font-family: \'trueloaded\';\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p\');\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p#iefix\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/trueloaded.ttf?4rk52p\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/trueloaded.woff?4rk52p\') format(\'woff\'),\r\n url(\'themes/basic/fonts/trueloaded.svg?4rk52p#trueloaded\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\n }'),(895,'deals-mobile','hide','theme_version','74'),(896,'deals-mobile','main','group_product_by_product_group',''),(897,'deals-mobile','main','show_in_cart_button',''),(898,'deals-mobile','main','customer_account','new'),(899,'deals-mobile','main','products_carousel',''),(900,'deals-mobile','main','theme_color',''),(901,'deals-mobile','main','service_worker',''),(902,'deals-mobile','main','backup_hours',''),(903,'deals-mobile','main','backup_count',''),(904,'deals-mobile','main','dev_mode',''),(905,'deals-mobile','main','old_listing',''),(906,'deals-mobile','main','base64_product',''),(907,'deals-mobile','main','base64_category',''),(908,'deals-mobile','main','base64_banner',''),(909,'deals-mobile','hide','favicon','themes/deals-mobile/img/favicon_osc-1.png'),(910,'deals-mobile','hide','logo','themes/deals-mobile/img/oscommerce_logo-2.png'),(911,'deals-mobile','hide','na_category','themes/deals-mobile/img/no-categories-1.png'),(912,'deals-mobile','hide','na_product','themes/deals-mobile/img/na.png'),(913,'deals-mobile','added_page_settings','Category no Filters',''),(914,'deals-mobile','added_page_settings','No Filters',''),(915,'deals-mobile','added_page','account','Quotations'),(916,'deals-mobile','added_page','account','Points Earnt History'),(917,'deals-mobile','added_page','account','Tracking numbers'),(918,'deals-mobile','added_page','account','Samples'),(919,'deals-mobile','added_page','account','Quotation Info'),(920,'deals-mobile','added_page','account','Order pay'),(921,'deals-mobile','added_page','account','Order History'),(922,'deals-mobile','added_page','account','Account edit'),(923,'deals-mobile','added_page','account','Review'),(924,'deals-mobile','added_page','account','Order History Info'),(925,'deals-mobile','added_page','account','Sample Info'),(926,'deals-mobile','added_page','account','My password'),(927,'deals-mobile','added_page','account','Address Book Process'),(928,'deals-mobile','added_page','account','Created success'),(929,'deals-mobile','added_page','account','Gift Certificate'),(930,'deals-mobile','added_page','account','Address Book'),(931,'deals-mobile','added_page','account','Personal Catalog'),(932,'deals-mobile','added_page','account','Subscription'),(972,NULL,NULL,NULL,'1682607793'),(973,NULL,NULL,NULL,'1682607826'),(1314,'watch-mobile','extend','media_query','w992'),(1315,'watch-mobile','extend','media_query','w768'),(2858,'furniture-mobile','added_page','product','tt'),(2859,'furniture-mobile','main','show_in_cart_button','no'),(2860,'furniture-mobile','hide','na_banner','themes/furniture/img/'),(2861,'furniture-mobile','main','base64_product',''),(2862,'furniture-mobile','main','base64_category',''),(2863,'furniture-mobile','main','base64_banner','data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjwhLS0gR2VuZXJhdG9yOiBBZG9iZSBJbGx1c3RyYXRvciAxNy4xLjAsIFNWRyBFeHBvcnQgUGx1Zy1JbiAuIFNWRyBWZXJzaW9uOiA2LjAwIEJ1aWxkIDApICAtLT4NCjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+DQo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4Ig0KCSB2aWV3Qm94PSIwIDAgMTI3IDE0OC4zIiBlbmFibGUtYmFja2dyb3VuZD0ibmV3IDAgMCAxMjcgMTQ4LjMiIHhtbDpzcGFjZT0icHJlc2VydmUiPg0KPGc+DQoJPHBhdGggZmlsbD0iI0NFQ0VDRSIgZD0iTTEyNC4zLDQ2LjZ2OTEuMWMwLDQuMi0zLjQsNy42LTcuNiw3LjZIMTAuNGMtNC4yLDAtNy42LTMuNC03LjYtNy42VjExLjJjMC00LjIsMy40LTcuNiw3LjYtNy42aDcwLjgNCgkJYzQuMiwwLDEwLDIuNSwxMyw1LjRsMjQuNywyNC43QzEyMS44LDM2LjUsMTI0LjMsNDIuNCwxMjQuMyw0Ni42eiBNMTE0LjIsNTQuMkg4MS4zYy00LjIsMC03LjYtMy40LTcuNi03LjZWMTMuN0gxM3YxMjEuNGgxMDEuMg0KCQlWNTQuMnogTTIzLjEsNjkuM2MwLTguNCw2LjgtMTUuMiwxNS4yLTE1LjJTNTMuNCw2MSw1My40LDY5LjNzLTYuOCwxNS4yLTE1LjIsMTUuMlMyMy4xLDc3LjcsMjMuMSw2OS4zeiBNMTA0LDEyNUgyMy4xdi0xNS4yDQoJCWwxNS4yLTE1LjJsMTAuMSwxMC4xbDMwLjQtMzAuNEwxMDQsOTkuN1YxMjV6IE04My44LDQ0aDI5LjdjLTAuNS0xLjMtMS4yLTIuNy0xLjctMy4yTDg3LDE2LjFjLTAuNi0wLjYtMS45LTEuMy0zLjItMS43VjQ0eiIvPg0KPC9nPg0KPC9zdmc+DQo='),(2864,'furniture-mobile','main','products_carousel','1'),(2865,'furniture-mobile','hide','backup_date','1712068913'),(2866,'furniture-mobile','added_page','account','Samples'),(2867,'furniture-mobile','added_page_settings','invoice','sheet_format:A4'),(2868,'furniture-mobile','added_page_settings','invoice','sheet_format:A4'),(2869,'furniture-mobile','added_page_settings','invoice','sheet_format:A4'),(2870,'furniture-mobile','added_page_settings','invoice','sheet_format:A4'),(2871,'furniture-mobile','added_page_settings','invoice','sheet_format:A4'),(2872,'furniture-mobile','added_page','account','Tracking numbers'),(2873,'furniture-mobile','added_page','productListing','b2b'),(2874,'furniture-mobile','added_page','categories','Category no Filters'),(2875,'furniture-mobile','added_page_settings','Category no Filters','no_filters'),(2876,'furniture-mobile','extend','media_query','w768'),(2877,'furniture-mobile','hide','new_attributes','1'),(2878,'furniture-mobile','added_page','products','Wedding Registry List'),(2879,'furniture-mobile','added_page','account','Points Earnt History'),(2880,'furniture-mobile','layout','index','home'),(2881,'furniture-mobile','added_page','email','Email 3'),(2882,'furniture-mobile','added_page','info','inf 2'),(2883,'furniture-mobile','main','show_empty_categories',''),(2884,'furniture-mobile','main','after_add','popup'),(2885,'furniture-mobile','extend','media_query','w992'),(2886,'furniture-mobile','main','include_css','3'),(2887,'furniture-mobile','added_page','account','Gift Certificate'),(2888,'furniture-mobile','added_page','account','Address Book'),(2889,'furniture-mobile','added_page','account','Created success'),(2890,'furniture-mobile','extend','media_query','w1200'),(2891,'furniture-mobile','added_page','account','Personal Catalog'),(2892,'furniture-mobile','added_page','info','Testimonials'),(2893,'furniture-mobile','main','use_mobile_theme','1'),(2894,'furniture-mobile','hide','theme_update','1520263888'),(2895,'furniture-mobile','added_page','products','No Filters'),(2896,'furniture-mobile','main','login_view',''),(2897,'furniture-mobile','added_page','components','lending form'),(2898,'furniture-mobile','added_page','account','Address Book Process'),(2899,'furniture-mobile','added_page','account','My password'),(2900,'furniture-mobile','added_page','productListing','Rows'),(2901,'furniture-mobile','main','old_listing',''),(2902,'furniture-mobile','main','dev_mode','1'),(2903,'furniture-mobile','main','theme_color',''),(2904,'furniture-mobile','added_page_settings','No Filters','no_filters'),(2905,'furniture-mobile','hide','favicon','themes/furniture/img/favicon_osc.png'),(2906,'furniture-mobile','extend','media_query','w576'),(2907,'furniture-mobile','added_page','account','Quotation Info'),(2908,'furniture-mobile','hide','logo','themes/furniture/img/logonew.png'),(2909,'furniture-mobile','main','show_products_from_subcategories','1'),(2910,'furniture-mobile','added_page','account','Order pay'),(2911,'furniture-mobile','added_page','email','Email 2'),(2912,'furniture-mobile','added_page','gift_card','Gigt Card 3'),(2913,'furniture-mobile','extend','font_added','@font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/woSH4aW-1wuybBQItyfdsvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/FdFTd030tby8r55hlt7EYfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/0IXD51eZ8qgi73bhvRidlQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/Vb88BBmXXgbpZxolKzz6dw.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/eND698DA6CUFWomaRdrTiw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/xLdg5JI0N_C2fvyu9XVzXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/bWPw4Za2XndpOjggSNN5JPY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/TCDCvLw6ewp4kJ2WSI4MT_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/_JiDQLq4JWzs7prWhNNmuA.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/HMitXFBPwJyXZfGm6rEhuvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/-H4xgvCtDmIfFNvmoAPAKvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/A2xpLU2z2kq5byuh5bkohg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/AFoPIhbuX_gBhSszntNC0_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/503ks6dbq2nVdfUL61JyAfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/PQuIEfcr_wdF_zOSNjqWKQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }'),(2914,'furniture-mobile','added_page','account','Wishlist'),(2915,'furniture-mobile','added_page','account','Review'),(2916,'furniture-mobile','main','checkout_view','1'),(2917,'furniture-mobile','added_page','account','Order History Info'),(2918,'furniture-mobile','added_page','home','Need Login'),(2919,'furniture-mobile','added_page','account','Sample Info'),(2920,'furniture-mobile','extend','font_added','@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrkByb1TKJa77egybnpn19yM.woff2) format(\'woff2\');\r\n unicode-range: U+0590-05FF, U+20AA, U+25CC, U+FB1D-FB4F;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrugdm0LZdjqr5-oayXSOefg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n\r\n\r\n@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round Regular\'), local(\'VarelaRound-Regular\'), url(https://fonts.gstatic.com/s/varelaround/v8/APH4jr0uSos5wiut5cpjrnhCUOGz7vYGh680lGh-uXM.woff) format(\'woff\');\r\nfont-display: swap;\r\n}\r\n'),(2921,'furniture-mobile','extend','font_added','@font-face {\r\n font-family: \'trueloaded\';\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p\');\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p#iefix\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/trueloaded.ttf?4rk52p\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/trueloaded.woff?4rk52p\') format(\'woff\'),\r\n url(\'themes/basic/fonts/trueloaded.svg?4rk52p#trueloaded\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(2922,'furniture-mobile','hide','na_product','themes/furniture/img/na.png'),(2923,'furniture-mobile','hide','na_category','themes/furniture/img/no-categories-1.png'),(2924,'furniture-mobile','javascript','javascript',''),(2925,'furniture-mobile','added_page','invoice','ticket'),(2926,'furniture-mobile','added_page','account','Account edit'),(2927,'furniture-mobile','added_page','email','Email 4'),(2928,'furniture-mobile','added_page','account','Order History'),(2929,'furniture-mobile','added_page_settings','Wedding Registry List','wedding_registry'),(2930,'furniture-mobile','added_page_settings','invoice','sheet_format:A4'),(2931,'furniture-mobile','added_page','gift_card','Gift Card 2'),(2932,'furniture-mobile','added_page_settings','invoice','page_width:84'),(2933,'furniture-mobile','added_page','account','Quotations'),(2934,'furniture-mobile','added_page_settings','invoice','orientation:P'),(2935,'furniture-mobile','added_page_settings','invoice','page_height:36'),(2936,'furniture-mobile','main','customer_account','new'),(2937,'furniture-mobile','added_page','label','test label'),(2938,'furniture-mobile','extend','font_added','@font-face {\r\n font-family: \'FontAwesome\';\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?v=3.2.1\');\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?#iefix&v=3.2.1\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.woff?v=3.2.1\') format(\'woff\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.ttf?v=3.2.1\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.svg#fontawesomeregular?v=3.2.1\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(2939,'furniture-mobile','main','group_product_by_product_group','1'),(2940,'furniture-mobile','main','service_worker',''),(2941,'furniture-mobile','main','backup_hours',''),(2942,'furniture-mobile','main','backup_count',''),(2943,'furniture-mobile','hide','theme_version','2429'),(2944,'furniture-mobile','extend','font_added','/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}'),(2945,'furniture-mobile','extend','media_query','993w'),(2946,'furniture-mobile','added_page','components','Customer care'),(2947,'furniture-mobile','added_page','components','Social'),(2948,'furniture-mobile','added_page','components','Header menu'),(2949,'furniture-mobile','added_page','productListing','CompareProduct'),(2950,'furniture-mobile','added_page','account','Credit Amount History'),(2951,'furniture-mobile','added_page','inform','Questionnaire'),(2952,'furniture-mobile','added_page','inform','Catalog pages'),(2955,'furniture-mobile','main','hide_empty_brands',''),(2956,'furniture-mobile','main','contact_name',''),(2962,'watch-mobile','main','hide_empty_brands',''),(2963,'watch-mobile','main','contact_name',''),(3927,NULL,NULL,NULL,'1695724460'),(3928,NULL,NULL,NULL,'1695724462'),(3929,NULL,NULL,NULL,'1695724540'),(3962,NULL,NULL,NULL,'1697797415'),(3966,NULL,NULL,NULL,'1697797464'),(5082,'splash','hide','theme_version','92'),(5083,'splash','hide','new_attributes','1'),(5084,'splash','main','after_add',''),(5085,'splash','main','show_products_from_subcategories',''),(5086,'splash','main','show_empty_categories',''),(5087,'splash','main','group_product_by_product_group',''),(5088,'splash','main','show_in_cart_button',''),(5089,'splash','main','checkout_view',''),(5090,'splash','main','customer_account',''),(5091,'splash','main','products_carousel',''),(5092,'splash','main','theme_color',''),(5093,'splash','main','use_mobile_theme',''),(5094,'splash','main','service_worker',''),(5095,'splash','main','backup_hours',''),(5096,'splash','main','backup_count',''),(5097,'splash','main','dev_mode',''),(5098,'splash','main','old_listing',''),(5099,'splash','main','include_css',''),(5100,'splash','main','base64_product',''),(5101,'splash','main','base64_category',''),(5102,'splash','main','base64_banner',''),(5103,'splash','hide','favicon','themes/splash/img/'),(5104,'splash','hide','logo','themes/splash/img/oscommerce_logo.jpg'),(5105,'splash','hide','na_category','themes/splash/img/'),(5106,'splash','hide','na_product','themes/splash/img/'),(5107,'splash','extend','media_query','w900'),(5108,'splash','extend','media_query','w850'),(5109,'splash','extend','media_query','w1250'),(5110,'splash','added_page','inform','contact'),(5111,'splash','hide','theme_image','themes/splash/img/theme-splash.jpg'),(5112,'splash-mobile','added_page','inform','contact'),(5113,'splash-mobile','hide','theme_version','4'),(5114,'furniture','main','show_in_cart_button','no'),(5115,'furniture','hide','na_banner','themes/furniture/img/'),(5116,'furniture','main','base64_product',''),(5117,'furniture','main','base64_category',''),(5118,'furniture','main','base64_banner','data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjwhLS0gR2VuZXJhdG9yOiBBZG9iZSBJbGx1c3RyYXRvciAxNy4xLjAsIFNWRyBFeHBvcnQgUGx1Zy1JbiAuIFNWRyBWZXJzaW9uOiA2LjAwIEJ1aWxkIDApICAtLT4NCjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+DQo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4Ig0KCSB2aWV3Qm94PSIwIDAgMTI3IDE0OC4zIiBlbmFibGUtYmFja2dyb3VuZD0ibmV3IDAgMCAxMjcgMTQ4LjMiIHhtbDpzcGFjZT0icHJlc2VydmUiPg0KPGc+DQoJPHBhdGggZmlsbD0iI0NFQ0VDRSIgZD0iTTEyNC4zLDQ2LjZ2OTEuMWMwLDQuMi0zLjQsNy42LTcuNiw3LjZIMTAuNGMtNC4yLDAtNy42LTMuNC03LjYtNy42VjExLjJjMC00LjIsMy40LTcuNiw3LjYtNy42aDcwLjgNCgkJYzQuMiwwLDEwLDIuNSwxMyw1LjRsMjQuNywyNC43QzEyMS44LDM2LjUsMTI0LjMsNDIuNCwxMjQuMyw0Ni42eiBNMTE0LjIsNTQuMkg4MS4zYy00LjIsMC03LjYtMy40LTcuNi03LjZWMTMuN0gxM3YxMjEuNGgxMDEuMg0KCQlWNTQuMnogTTIzLjEsNjkuM2MwLTguNCw2LjgtMTUuMiwxNS4yLTE1LjJTNTMuNCw2MSw1My40LDY5LjNzLTYuOCwxNS4yLTE1LjIsMTUuMlMyMy4xLDc3LjcsMjMuMSw2OS4zeiBNMTA0LDEyNUgyMy4xdi0xNS4yDQoJCWwxNS4yLTE1LjJsMTAuMSwxMC4xbDMwLjQtMzAuNEwxMDQsOTkuN1YxMjV6IE04My44LDQ0aDI5LjdjLTAuNS0xLjMtMS4yLTIuNy0xLjctMy4yTDg3LDE2LjFjLTAuNi0wLjYtMS45LTEuMy0zLjItMS43VjQ0eiIvPg0KPC9nPg0KPC9zdmc+DQo='),(5119,'furniture','main','products_carousel',''),(5120,'furniture','hide','backup_date','1713944194'),(5121,'furniture','added_page','account','Samples'),(5122,'furniture','added_page_settings','invoice','sheet_format:A4'),(5123,'furniture','added_page_settings','invoice','sheet_format:A4'),(5124,'furniture','added_page_settings','invoice','sheet_format:A4'),(5125,'furniture','added_page_settings','invoice','sheet_format:A4'),(5126,'furniture','added_page_settings','invoice','sheet_format:A4'),(5127,'furniture','added_page','account','Tracking numbers'),(5128,'furniture','added_page','productListing','b2b'),(5129,'furniture','added_page','categories','Category no Filters'),(5130,'furniture','added_page_settings','Category no Filters','no_filters'),(5131,'furniture','extend','media_query','w768'),(5132,'furniture','hide','new_attributes','1'),(5134,'furniture','added_page','account','Points Earnt History'),(5135,'furniture','layout','index','home'),(5136,'furniture','added_page','email','Email 3'),(5138,'furniture','main','show_empty_categories',''),(5139,'furniture','main','after_add','popup'),(5140,'furniture','extend','media_query','w992'),(5141,'furniture','main','include_css','3'),(5142,'furniture','added_page','account','Gift Certificate'),(5143,'furniture','added_page','account','Address Book'),(5144,'furniture','added_page','account','Created success'),(5145,'furniture','extend','media_query','w1200'),(5146,'furniture','added_page','account','Personal Catalog'),(5148,'furniture','main','use_mobile_theme',''),(5149,'furniture','hide','theme_update','1520263888'),(5150,'furniture','added_page','products','No Filters'),(5151,'furniture','main','login_view',''),(5152,'furniture','added_page','components','lending form'),(5153,'furniture','added_page','account','Address Book Process'),(5154,'furniture','added_page','account','My password'),(5155,'furniture','added_page','productListing','Rows'),(5156,'furniture','main','old_listing',''),(5157,'furniture','main','dev_mode',''),(5158,'furniture','main','theme_color',''),(5159,'furniture','added_page_settings','No Filters','no_filters'),(5160,'furniture','hide','favicon','themes/furniture/img/favicon_osc.png'),(5161,'furniture','extend','media_query','w576'),(5162,'furniture','added_page','account','Quotation Info'),(5163,'furniture','hide','logo','themes/furniture/img/logonew.png'),(5164,'furniture','main','show_products_from_subcategories','1'),(5165,'furniture','added_page','account','Order pay'),(5166,'furniture','added_page','email','Email 2'),(5167,'furniture','added_page','gift_card','Gigt Card 3'),(5168,'furniture','added_page','account','Wishlist'),(5169,'furniture','added_page','account','Review'),(5170,'furniture','main','checkout_view',''),(5171,'furniture','added_page','account','Order History Info'),(5172,'furniture','added_page','home','Need Login'),(5173,'furniture','added_page','account','Sample Info'),(5174,'furniture','extend','font_added','@font-face {\r\n font-family: \'trueloaded\';\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p\');\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p#iefix\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/trueloaded.ttf?4rk52p\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/trueloaded.woff?4rk52p\') format(\'woff\'),\r\n url(\'themes/basic/fonts/trueloaded.svg?4rk52p#trueloaded\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(5175,'furniture','hide','na_product','themes/furniture/img/na.png'),(5176,'furniture','hide','na_category','themes/furniture/img/no-categories-1.png'),(5177,'furniture','javascript','javascript',''),(5178,'furniture','added_page','invoice','ticket'),(5179,'furniture','added_page','account','Account edit'),(5180,'furniture','added_page','email','Email 4'),(5181,'furniture','added_page','account','Order History'),(5183,'furniture','added_page_settings','invoice','sheet_format:A4'),(5184,'furniture','added_page','gift_card','Gift Card 2'),(5185,'furniture','added_page_settings','invoice','page_width:84'),(5186,'furniture','added_page','account','Quotations'),(5187,'furniture','added_page_settings','invoice','orientation:P'),(5188,'furniture','added_page_settings','invoice','page_height:36'),(5189,'furniture','main','customer_account','new'),(5190,'furniture','added_page','label','test label'),(5191,'furniture','extend','font_added','@font-face {\r\n font-family: \'FontAwesome\';\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?v=3.2.1\');\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?#iefix&v=3.2.1\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.woff?v=3.2.1\') format(\'woff\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.ttf?v=3.2.1\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.svg#fontawesomeregular?v=3.2.1\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(5192,'furniture','main','group_product_by_product_group','1'),(5193,'furniture','main','service_worker',''),(5194,'furniture','main','backup_hours',''),(5195,'furniture','main','backup_count',''),(5196,'furniture','hide','theme_version','2588'),(5197,'furniture','extend','font_added','/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}'),(5198,'furniture','extend','media_query','993w'),(5199,'furniture','added_page','components','Social'),(5200,'furniture','added_page','components','Header menu'),(5201,'furniture','added_page','productListing','CompareProduct'),(5202,'furniture','added_page','account','Credit Amount History'),(5205,'furniture','hide','theme_image','themes/furniture/img/theme-furniture.jpg'),(5206,'furniture','extend','media_query','1921w'),(5207,'furniture','extend','media_query','w1024'),(5208,'furniture','extend','media_query','w1025'),(5209,'furniture','extend','media_query','w1300'),(5210,'furniture','extend','media_query','w1400'),(5211,'furniture','main','hide_empty_brands',''),(5212,'furniture','main','contact_name',''),(5213,'furniture','extend','font_added','@font-face {\r\n	font-family: \'themify\';\r\n	src:url(\'themes/basic/fonts/themify.eot?-fvbane\');\r\n	src:url(\'themes/basic/fonts/themify.eot?#iefix-fvbane\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/themify.woff?-fvbane\') format(\'woff\'),\r\n url(\'themes/basic/fonts/themify.ttf?-fvbane\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/themify.svg?-fvbane#themify\') format(\'svg\');\r\n	font-weight: normal;\r\n	font-style: normal;\r\n}'),(5215,'watch','main','show_in_cart_button','no'),(5216,'watch','hide','na_banner','themes/watch/img/'),(5217,'watch','main','base64_product',''),(5218,'watch','main','base64_category',''),(5219,'watch','main','base64_banner','data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjwhLS0gR2VuZXJhdG9yOiBBZG9iZSBJbGx1c3RyYXRvciAxNy4xLjAsIFNWRyBFeHBvcnQgUGx1Zy1JbiAuIFNWRyBWZXJzaW9uOiA2LjAwIEJ1aWxkIDApICAtLT4NCjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+DQo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4Ig0KCSB2aWV3Qm94PSIwIDAgMTI3IDE0OC4zIiBlbmFibGUtYmFja2dyb3VuZD0ibmV3IDAgMCAxMjcgMTQ4LjMiIHhtbDpzcGFjZT0icHJlc2VydmUiPg0KPGc+DQoJPHBhdGggZmlsbD0iI0NFQ0VDRSIgZD0iTTEyNC4zLDQ2LjZ2OTEuMWMwLDQuMi0zLjQsNy42LTcuNiw3LjZIMTAuNGMtNC4yLDAtNy42LTMuNC03LjYtNy42VjExLjJjMC00LjIsMy40LTcuNiw3LjYtNy42aDcwLjgNCgkJYzQuMiwwLDEwLDIuNSwxMyw1LjRsMjQuNywyNC43QzEyMS44LDM2LjUsMTI0LjMsNDIuNCwxMjQuMyw0Ni42eiBNMTE0LjIsNTQuMkg4MS4zYy00LjIsMC03LjYtMy40LTcuNi03LjZWMTMuN0gxM3YxMjEuNGgxMDEuMg0KCQlWNTQuMnogTTIzLjEsNjkuM2MwLTguNCw2LjgtMTUuMiwxNS4yLTE1LjJTNTMuNCw2MSw1My40LDY5LjNzLTYuOCwxNS4yLTE1LjIsMTUuMlMyMy4xLDc3LjcsMjMuMSw2OS4zeiBNMTA0LDEyNUgyMy4xdi0xNS4yDQoJCWwxNS4yLTE1LjJsMTAuMSwxMC4xbDMwLjQtMzAuNEwxMDQsOTkuN1YxMjV6IE04My44LDQ0aDI5LjdjLTAuNS0xLjMtMS4yLTIuNy0xLjctMy4yTDg3LDE2LjFjLTAuNi0wLjYtMS45LTEuMy0zLjItMS43VjQ0eiIvPg0KPC9nPg0KPC9zdmc+DQo='),(5220,'watch','main','products_carousel',''),(5221,'watch','hide','backup_date','1713944226'),(5222,'watch','added_page','account','Samples'),(5223,'watch','added_page_settings','invoice','sheet_format:A4'),(5224,'watch','added_page_settings','invoice','sheet_format:A4'),(5225,'watch','added_page_settings','invoice','sheet_format:A4'),(5226,'watch','added_page_settings','invoice','sheet_format:A4'),(5227,'watch','added_page_settings','invoice','sheet_format:A4'),(5228,'watch','added_page','account','Tracking numbers'),(5229,'watch','added_page','productListing','b2b'),(5230,'watch','added_page','categories','Category no Filters'),(5231,'watch','added_page_settings','Category no Filters','no_filters'),(5232,'watch','extend','media_query','w768'),(5233,'watch','hide','new_attributes','1'),(5235,'watch','added_page','account','Points Earnt History'),(5236,'watch','layout','index','home'),(5237,'watch','added_page','email','Email 3'),(5238,'watch','main','show_empty_categories',''),(5239,'watch','main','after_add','popup'),(5240,'watch','extend','media_query','w992'),(5241,'watch','main','include_css','3'),(5242,'watch','added_page','account','Gift Certificate'),(5243,'watch','added_page','account','Address Book'),(5244,'watch','added_page','account','Created success'),(5245,'watch','extend','media_query','w1200'),(5246,'watch','added_page','account','Personal Catalog'),(5247,'watch','added_page','info','Testimonials'),(5248,'watch','main','use_mobile_theme',''),(5249,'watch','hide','theme_update','1520263888'),(5250,'watch','added_page','products','No Filters'),(5251,'watch','main','login_view',''),(5252,'watch','added_page','components','lending form'),(5253,'watch','added_page','account','Address Book Process'),(5254,'watch','added_page','account','My password'),(5255,'watch','added_page','productListing','Rows'),(5256,'watch','main','old_listing',''),(5257,'watch','main','dev_mode',''),(5258,'watch','main','theme_color',''),(5259,'watch','added_page_settings','No Filters','no_filters'),(5260,'watch','hide','favicon','themes/watch/img/favicon_osc.png'),(5261,'watch','extend','media_query','w576'),(5262,'watch','added_page','account','Quotation Info'),(5263,'watch','hide','logo','themes/watch/img/watchlogo.png'),(5264,'watch','main','show_products_from_subcategories','1'),(5265,'watch','added_page','account','Order pay'),(5266,'watch','added_page','email','Email 2'),(5267,'watch','added_page','gift_card','Gigt Card 3'),(5268,'watch','extend','font_added','@font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/woSH4aW-1wuybBQItyfdsvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/FdFTd030tby8r55hlt7EYfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/0IXD51eZ8qgi73bhvRidlQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/Vb88BBmXXgbpZxolKzz6dw.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/eND698DA6CUFWomaRdrTiw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/xLdg5JI0N_C2fvyu9XVzXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/bWPw4Za2XndpOjggSNN5JPY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/TCDCvLw6ewp4kJ2WSI4MT_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/_JiDQLq4JWzs7prWhNNmuA.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/HMitXFBPwJyXZfGm6rEhuvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/-H4xgvCtDmIfFNvmoAPAKvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/A2xpLU2z2kq5byuh5bkohg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/AFoPIhbuX_gBhSszntNC0_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/503ks6dbq2nVdfUL61JyAfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/PQuIEfcr_wdF_zOSNjqWKQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }'),(5269,'watch','added_page','account','Wishlist'),(5270,'watch','added_page','account','Review'),(5271,'watch','main','checkout_view',''),(5272,'watch','added_page','account','Order History Info'),(5273,'watch','added_page','home','Need Login'),(5274,'watch','added_page','account','Sample Info'),(5275,'watch','extend','font_added','@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrkByb1TKJa77egybnpn19yM.woff2) format(\'woff2\');\r\n unicode-range: U+0590-05FF, U+20AA, U+25CC, U+FB1D-FB4F;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrugdm0LZdjqr5-oayXSOefg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n\r\n\r\n@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round Regular\'), local(\'VarelaRound-Regular\'), url(https://fonts.gstatic.com/s/varelaround/v8/APH4jr0uSos5wiut5cpjrnhCUOGz7vYGh680lGh-uXM.woff) format(\'woff\');\r\nfont-display: swap;\r\n}\r\n'),(5276,'watch','extend','font_added','@font-face {\r\n font-family: \'trueloaded\';\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p\');\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p#iefix\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/trueloaded.ttf?4rk52p\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/trueloaded.woff?4rk52p\') format(\'woff\'),\r\n url(\'themes/basic/fonts/trueloaded.svg?4rk52p#trueloaded\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(5277,'watch','hide','na_product','themes/watch/img/na.png'),(5278,'watch','hide','na_category','themes/watch/img/no-categories-1.png'),(5279,'watch','javascript','javascript',' '),(5280,'watch','added_page','invoice','ticket'),(5281,'watch','added_page','account','Account edit'),(5282,'watch','added_page','email','Email 4'),(5283,'watch','added_page','account','Order History'),(5285,'watch','added_page_settings','invoice','sheet_format:A4'),(5286,'watch','added_page','gift_card','Gift Card 2'),(5287,'watch','added_page_settings','invoice','page_width:84'),(5288,'watch','added_page','account','Quotations'),(5289,'watch','added_page_settings','invoice','orientation:P'),(5290,'watch','added_page_settings','invoice','page_height:36'),(5291,'watch','main','customer_account','new'),(5292,'watch','added_page','label','test label'),(5293,'watch','extend','font_added','@font-face {\r\n font-family: \'FontAwesome\';\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?v=3.2.1\');\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?#iefix&v=3.2.1\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.woff?v=3.2.1\') format(\'woff\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.ttf?v=3.2.1\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.svg#fontawesomeregular?v=3.2.1\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(5294,'watch','main','group_product_by_product_group',''),(5295,'watch','main','service_worker',''),(5296,'watch','main','backup_hours',''),(5297,'watch','main','backup_count',''),(5298,'watch','hide','theme_version','274'),(5300,'watch','added_page','productListing','Compare Products'),(5301,'watch','added_page','productListing','Batch'),(5307,'watch','added_page','productListing','Batch Selected'),(5311,'watch','hide','theme_image','themes/watch/img/theme-watch.jpg'),(5312,'watch','extend','media_query','w720'),(5313,'watch','main','hide_empty_brands',''),(5314,'watch','main','contact_name',''),(5315,'watch','extend','font_added','@font-face {\r\n	font-family: \'themify\';\r\n	src:url(\'themes/basic/fonts/themify.eot?-fvbane\');\r\n	src:url(\'themes/basic/fonts/themify.eot?#iefix-fvbane\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/themify.woff?-fvbane\') format(\'woff\'),\r\n url(\'themes/basic/fonts/themify.ttf?-fvbane\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/themify.svg?-fvbane#themify\') format(\'svg\');\r\n	font-weight: normal;\r\n	font-style: normal;\r\n}'),(5316,'printshop','main','show_in_cart_button','no'),(5317,'printshop','hide','na_banner','themes/printshop/img/'),(5318,'printshop','main','base64_product',''),(5319,'printshop','main','base64_category',''),(5320,'printshop','main','base64_banner','data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjwhLS0gR2VuZXJhdG9yOiBBZG9iZSBJbGx1c3RyYXRvciAxNy4xLjAsIFNWRyBFeHBvcnQgUGx1Zy1JbiAuIFNWRyBWZXJzaW9uOiA2LjAwIEJ1aWxkIDApICAtLT4NCjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+DQo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4Ig0KCSB2aWV3Qm94PSIwIDAgMTI3IDE0OC4zIiBlbmFibGUtYmFja2dyb3VuZD0ibmV3IDAgMCAxMjcgMTQ4LjMiIHhtbDpzcGFjZT0icHJlc2VydmUiPg0KPGc+DQoJPHBhdGggZmlsbD0iI0NFQ0VDRSIgZD0iTTEyNC4zLDQ2LjZ2OTEuMWMwLDQuMi0zLjQsNy42LTcuNiw3LjZIMTAuNGMtNC4yLDAtNy42LTMuNC03LjYtNy42VjExLjJjMC00LjIsMy40LTcuNiw3LjYtNy42aDcwLjgNCgkJYzQuMiwwLDEwLDIuNSwxMyw1LjRsMjQuNywyNC43QzEyMS44LDM2LjUsMTI0LjMsNDIuNCwxMjQuMyw0Ni42eiBNMTE0LjIsNTQuMkg4MS4zYy00LjIsMC03LjYtMy40LTcuNi03LjZWMTMuN0gxM3YxMjEuNGgxMDEuMg0KCQlWNTQuMnogTTIzLjEsNjkuM2MwLTguNCw2LjgtMTUuMiwxNS4yLTE1LjJTNTMuNCw2MSw1My40LDY5LjNzLTYuOCwxNS4yLTE1LjIsMTUuMlMyMy4xLDc3LjcsMjMuMSw2OS4zeiBNMTA0LDEyNUgyMy4xdi0xNS4yDQoJCWwxNS4yLTE1LjJsMTAuMSwxMC4xbDMwLjQtMzAuNEwxMDQsOTkuN1YxMjV6IE04My44LDQ0aDI5LjdjLTAuNS0xLjMtMS4yLTIuNy0xLjctMy4yTDg3LDE2LjFjLTAuNi0wLjYtMS45LTEuMy0zLjItMS43VjQ0eiIvPg0KPC9nPg0KPC9zdmc+DQo='),(5321,'printshop','main','products_carousel',''),(5322,'printshop','hide','backup_date','1713944384'),(5323,'printshop','added_page','account','Samples'),(5324,'printshop','added_page_settings','invoice','sheet_format:A4'),(5325,'printshop','added_page_settings','invoice','sheet_format:A4'),(5326,'printshop','added_page_settings','invoice','sheet_format:A4'),(5327,'printshop','added_page_settings','invoice','sheet_format:A4'),(5328,'printshop','added_page_settings','invoice','sheet_format:A4'),(5329,'printshop','added_page','account','Tracking numbers'),(5330,'printshop','added_page','productListing','b2b'),(5331,'printshop','added_page','categories','Category no Filters'),(5332,'printshop','added_page_settings','Category no Filters','no_filters'),(5333,'printshop','extend','media_query','w768'),(5334,'printshop','hide','new_attributes','1'),(5336,'printshop','added_page','account','Points Earnt History'),(5337,'printshop','layout','index','home'),(5338,'printshop','added_page','email','Email 3'),(5340,'printshop','main','show_empty_categories',''),(5341,'printshop','main','after_add','popup'),(5342,'printshop','extend','media_query','w992'),(5343,'printshop','main','include_css','3'),(5344,'printshop','added_page','account','Gift Certificate'),(5345,'printshop','added_page','account','Address Book'),(5346,'printshop','added_page','account','Created success'),(5347,'printshop','extend','media_query','w1200'),(5348,'printshop','added_page','account','Personal Catalog'),(5350,'printshop','main','use_mobile_theme',''),(5351,'printshop','hide','theme_update','1520263888'),(5352,'printshop','added_page','products','No Filters'),(5353,'printshop','main','login_view',''),(5354,'printshop','added_page','components','lending form'),(5355,'printshop','added_page','account','Address Book Process'),(5356,'printshop','added_page','account','My password'),(5357,'printshop','added_page','productListing','Rows'),(5358,'printshop','main','old_listing',''),(5359,'printshop','main','dev_mode',''),(5360,'printshop','main','theme_color',''),(5361,'printshop','added_page_settings','No Filters','no_filters'),(5362,'printshop','hide','favicon','themes/printshop/img/favicon_osc.png'),(5363,'printshop','extend','media_query','w576'),(5364,'printshop','added_page','account','Quotation Info'),(5365,'printshop','hide','logo','themes/printshop/img/logo-2.png'),(5366,'printshop','main','show_products_from_subcategories','1'),(5367,'printshop','added_page','account','Order pay'),(5368,'printshop','added_page','email','Email 2'),(5369,'printshop','added_page','gift_card','Gigt Card 3'),(5370,'printshop','added_page','account','Wishlist'),(5371,'printshop','added_page','account','Review'),(5372,'printshop','main','checkout_view',''),(5373,'printshop','added_page','account','Order History Info'),(5374,'printshop','added_page','home','Need Login'),(5375,'printshop','added_page','account','Sample Info'),(5376,'printshop','extend','font_added','@font-face {\r\n font-family: \'trueloaded\';\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p\');\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p#iefix\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/trueloaded.ttf?4rk52p\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/trueloaded.woff?4rk52p\') format(\'woff\'),\r\n url(\'themes/basic/fonts/trueloaded.svg?4rk52p#trueloaded\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(5377,'printshop','hide','na_product','themes/printshop/img/na.png'),(5378,'printshop','hide','na_category','themes/printshop/img/no-categories-1.png'),(5379,'printshop','javascript','javascript',''),(5380,'printshop','added_page','invoice','ticket'),(5381,'printshop','added_page','account','Account edit'),(5382,'printshop','added_page','email','Email 4'),(5383,'printshop','added_page','account','Order History'),(5385,'printshop','added_page_settings','invoice','sheet_format:A4'),(5386,'printshop','added_page','gift_card','Gift Card 2'),(5387,'printshop','added_page_settings','invoice','page_width:84'),(5388,'printshop','added_page','account','Quotations'),(5389,'printshop','added_page_settings','invoice','orientation:P'),(5390,'printshop','added_page_settings','invoice','page_height:36'),(5391,'printshop','main','customer_account','new'),(5392,'printshop','added_page','label','test label'),(5393,'printshop','extend','font_added','@font-face {\r\n font-family: \'FontAwesome\';\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?v=3.2.1\');\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?#iefix&v=3.2.1\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.woff?v=3.2.1\') format(\'woff\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.ttf?v=3.2.1\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.svg#fontawesomeregular?v=3.2.1\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(5394,'printshop','main','group_product_by_product_group','1'),(5395,'printshop','main','service_worker',''),(5396,'printshop','main','backup_hours',''),(5397,'printshop','main','backup_count',''),(5398,'printshop','hide','theme_version','3512'),(5399,'printshop','extend','font_added','\r\n/* cyrillic-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TjASc3CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;\r\n}\r\n/* cyrillic */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TjASc-CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;\r\n}\r\n/* greek-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TjASc2CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+1F00-1FFF;\r\n}\r\n/* greek */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TjASc5CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0370-03FF;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TjASc1CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TjASc0CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TjASc6CsQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* cyrillic-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOkCnqEu92Fr1Mu51xFIzIFKw.woff2) format(\'woff2\');\r\n unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;\r\n}\r\n/* cyrillic */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOkCnqEu92Fr1Mu51xMIzIFKw.woff2) format(\'woff2\');\r\n unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;\r\n}\r\n/* greek-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOkCnqEu92Fr1Mu51xEIzIFKw.woff2) format(\'woff2\');\r\n unicode-range: U+1F00-1FFF;\r\n}\r\n/* greek */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOkCnqEu92Fr1Mu51xLIzIFKw.woff2) format(\'woff2\');\r\n unicode-range: U+0370-03FF;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOkCnqEu92Fr1Mu51xHIzIFKw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOkCnqEu92Fr1Mu51xGIzIFKw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOkCnqEu92Fr1Mu51xIIzI.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* cyrillic-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51S7ACc3CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;\r\n}\r\n/* cyrillic */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51S7ACc-CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;\r\n}\r\n/* greek-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51S7ACc2CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+1F00-1FFF;\r\n}\r\n/* greek */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51S7ACc5CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0370-03FF;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51S7ACc1CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51S7ACc0CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51S7ACc6CsQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* cyrillic-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TzBic3CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;\r\n}\r\n/* cyrillic */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TzBic-CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;\r\n}\r\n/* greek-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TzBic2CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+1F00-1FFF;\r\n}\r\n/* greek */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TzBic5CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0370-03FF;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TzBic1CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TzBic0CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TzBic6CsQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* cyrillic-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TLBCc3CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;\r\n}\r\n/* cyrillic */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TLBCc-CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;\r\n}\r\n/* greek-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TLBCc2CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+1F00-1FFF;\r\n}\r\n/* greek */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TLBCc5CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0370-03FF;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TLBCc1CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TLBCc0CsTKlA.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TLBCc6CsQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* cyrillic-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmSU5fCRc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;\r\n}\r\n/* cyrillic */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmSU5fABc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;\r\n}\r\n/* greek-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmSU5fCBc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+1F00-1FFF;\r\n}\r\n/* greek */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmSU5fBxc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0370-03FF;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmSU5fCxc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmSU5fChc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmSU5fBBc4.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* cyrillic-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOmCnqEu92Fr1Mu72xKOzY.woff2) format(\'woff2\');\r\n unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;\r\n}\r\n/* cyrillic */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOmCnqEu92Fr1Mu5mxKOzY.woff2) format(\'woff2\');\r\n unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;\r\n}\r\n/* greek-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOmCnqEu92Fr1Mu7mxKOzY.woff2) format(\'woff2\');\r\n unicode-range: U+1F00-1FFF;\r\n}\r\n/* greek */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOmCnqEu92Fr1Mu4WxKOzY.woff2) format(\'woff2\');\r\n unicode-range: U+0370-03FF;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOmCnqEu92Fr1Mu7WxKOzY.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOmCnqEu92Fr1Mu7GxKOzY.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOmCnqEu92Fr1Mu4mxK.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* cyrillic-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmEU9fCRc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;\r\n}\r\n/* cyrillic */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmEU9fABc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;\r\n}\r\n/* greek-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmEU9fCBc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+1F00-1FFF;\r\n}\r\n/* greek */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmEU9fBxc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0370-03FF;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmEU9fCxc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmEU9fChc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmEU9fBBc4.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* cyrillic-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmWUlfCRc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;\r\n}\r\n/* cyrillic */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmWUlfABc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;\r\n}\r\n/* greek-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmWUlfCBc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+1F00-1FFF;\r\n}\r\n/* greek */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmWUlfBxc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0370-03FF;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmWUlfCxc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmWUlfChc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmWUlfBBc4.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* cyrillic-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmYUtfCRc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;\r\n}\r\n/* cyrillic */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmYUtfABc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;\r\n}\r\n/* greek-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmYUtfCBc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+1F00-1FFF;\r\n}\r\n/* greek */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmYUtfBxc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0370-03FF;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmYUtfCxc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmYUtfChc4EsA.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmYUtfBBc4.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TjARc-AMP6lQ.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOkCnqEu92Fr1Mu52xMKTU1Kg.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51S7ABc-AMP6lQ.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TzBhc-AMP6lQ.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: italic;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOjCnqEu92Fr1Mu51TLBBc-AMP6lQ.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmSU5vAB0_IsE.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOmCnqEu92Fr1Me5mZNCzc.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmEU9vAB0_IsE.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmWUlvAB0_IsE.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Roboto\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/roboto/v29/KFOlCnqEu92Fr1MmYUtvAB0_IsE.woff) format(\'woff\');\r\n}'),(5400,'printshop','extend','media_query','993w'),(5401,'printshop','added_page','components','Customer care'),(5402,'printshop','added_page','components','Social'),(5403,'printshop','added_page','productListing','CompareProduct'),(5404,'printshop','added_page','account','Credit Amount History'),(5407,'printshop','extend','font_added','@font-face {\r\n	font-family: \'themify\';\r\n	src:url(\'themes/basic/fonts/themify.eot?-fvbane\');\r\n	src:url(\'themes/basic/fonts/themify.eot?#iefix-fvbane\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/themify.woff?-fvbane\') format(\'woff\'),\r\n url(\'themes/basic/fonts/themify.ttf?-fvbane\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/themify.svg?-fvbane#themify\') format(\'svg\');\r\n	font-weight: normal;\r\n	font-style: normal;\r\n}'),(5408,'printshop','extend','media_query','1201w'),(5409,'printshop','hide','theme_image','themes/printshop/img/theme-printshop.jpg'),(5410,'printshop','extend','media_query','1920w'),(5411,'printshop','extend','media_query','w720'),(5412,'printshop','main','hide_empty_brands',''),(5413,'printshop','main','contact_name',''),(5613,'deals','main','show_in_cart_button','no'),(5614,'deals','hide','na_banner','themes/deals/img/'),(5615,'deals','main','base64_product',''),(5616,'deals','main','base64_category',''),(5617,'deals','main','base64_banner','data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjwhLS0gR2VuZXJhdG9yOiBBZG9iZSBJbGx1c3RyYXRvciAxNy4xLjAsIFNWRyBFeHBvcnQgUGx1Zy1JbiAuIFNWRyBWZXJzaW9uOiA2LjAwIEJ1aWxkIDApICAtLT4NCjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+DQo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4Ig0KCSB2aWV3Qm94PSIwIDAgMTI3IDE0OC4zIiBlbmFibGUtYmFja2dyb3VuZD0ibmV3IDAgMCAxMjcgMTQ4LjMiIHhtbDpzcGFjZT0icHJlc2VydmUiPg0KPGc+DQoJPHBhdGggZmlsbD0iI0NFQ0VDRSIgZD0iTTEyNC4zLDQ2LjZ2OTEuMWMwLDQuMi0zLjQsNy42LTcuNiw3LjZIMTAuNGMtNC4yLDAtNy42LTMuNC03LjYtNy42VjExLjJjMC00LjIsMy40LTcuNiw3LjYtNy42aDcwLjgNCgkJYzQuMiwwLDEwLDIuNSwxMyw1LjRsMjQuNywyNC43QzEyMS44LDM2LjUsMTI0LjMsNDIuNCwxMjQuMyw0Ni42eiBNMTE0LjIsNTQuMkg4MS4zYy00LjIsMC03LjYtMy40LTcuNi03LjZWMTMuN0gxM3YxMjEuNGgxMDEuMg0KCQlWNTQuMnogTTIzLjEsNjkuM2MwLTguNCw2LjgtMTUuMiwxNS4yLTE1LjJTNTMuNCw2MSw1My40LDY5LjNzLTYuOCwxNS4yLTE1LjIsMTUuMlMyMy4xLDc3LjcsMjMuMSw2OS4zeiBNMTA0LDEyNUgyMy4xdi0xNS4yDQoJCWwxNS4yLTE1LjJsMTAuMSwxMC4xbDMwLjQtMzAuNEwxMDQsOTkuN1YxMjV6IE04My44LDQ0aDI5LjdjLTAuNS0xLjMtMS4yLTIuNy0xLjctMy4yTDg3LDE2LjFjLTAuNi0wLjYtMS45LTEuMy0zLjItMS43VjQ0eiIvPg0KPC9nPg0KPC9zdmc+DQo='),(5618,'deals','main','products_carousel',''),(5619,'deals','hide','backup_date','1713944436'),(5620,'deals','added_page','account','Samples'),(5621,'deals','added_page_settings','invoice','sheet_format:A4'),(5622,'deals','added_page_settings','invoice','sheet_format:A4'),(5623,'deals','added_page_settings','invoice','sheet_format:A4'),(5624,'deals','added_page_settings','invoice','sheet_format:A4'),(5625,'deals','added_page_settings','invoice','sheet_format:A4'),(5626,'deals','added_page','account','Tracking numbers'),(5627,'deals','added_page','productListing','b2b'),(5628,'deals','added_page','categories','Category no Filters'),(5629,'deals','added_page_settings','Category no Filters','no_filters'),(5630,'deals','extend','media_query','w768'),(5631,'deals','hide','new_attributes','1'),(5633,'deals','added_page','account','Points Earnt History'),(5634,'deals','layout','index','home'),(5635,'deals','added_page','email','Email 3'),(5637,'deals','main','show_empty_categories',''),(5638,'deals','main','after_add','popup'),(5639,'deals','extend','media_query','w992'),(5640,'deals','main','include_css','3'),(5641,'deals','added_page','account','Gift Certificate'),(5642,'deals','added_page','account','Address Book'),(5643,'deals','added_page','account','Created success'),(5644,'deals','extend','media_query','w1200'),(5645,'deals','added_page','account','Personal Catalog'),(5647,'deals','main','use_mobile_theme',''),(5648,'deals','hide','theme_update','1520263888'),(5649,'deals','added_page','products','No Filters'),(5650,'deals','main','login_view',''),(5651,'deals','added_page','components','lending form'),(5652,'deals','added_page','account','Address Book Process'),(5653,'deals','added_page','account','My password'),(5654,'deals','added_page','productListing','Rows'),(5655,'deals','main','old_listing',''),(5656,'deals','main','dev_mode',''),(5657,'deals','main','theme_color',''),(5658,'deals','added_page_settings','No Filters','no_filters'),(5659,'deals','hide','favicon','themes/deals/img/favicon_osc.png'),(5660,'deals','extend','media_query','w576'),(5661,'deals','added_page','account','Quotation Info'),(5662,'deals','hide','logo','themes/deals/img/b2b-supermarket-logo.png'),(5663,'deals','main','show_products_from_subcategories','1'),(5664,'deals','added_page','account','Order pay'),(5665,'deals','added_page','email','Email 2'),(5666,'deals','added_page','gift_card','Gigt Card 3'),(5667,'deals','added_page','account','Wishlist'),(5668,'deals','added_page','account','Review'),(5669,'deals','main','checkout_view',''),(5670,'deals','added_page','account','Order History Info'),(5671,'deals','added_page','home','Need Login'),(5672,'deals','added_page','account','Sample Info'),(5673,'deals','extend','font_added','@font-face {\r\n font-family: \'trueloaded\';\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p\');\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p#iefix\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/trueloaded.ttf?4rk52p\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/trueloaded.woff?4rk52p\') format(\'woff\'),\r\n url(\'themes/basic/fonts/trueloaded.svg?4rk52p#trueloaded\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(5674,'deals','hide','na_product','themes/deals/img/na.png'),(5675,'deals','hide','na_category','themes/deals/img/no-categories-1.png'),(5676,'deals','javascript','javascript',''),(5677,'deals','added_page','invoice','ticket'),(5678,'deals','added_page','account','Account edit'),(5679,'deals','added_page','email','Email 4'),(5680,'deals','added_page','account','Order History'),(5682,'deals','added_page_settings','invoice','sheet_format:A4'),(5683,'deals','added_page','gift_card','Gift Card 2'),(5684,'deals','added_page_settings','invoice','page_width:84'),(5685,'deals','added_page','account','Quotations'),(5686,'deals','added_page_settings','invoice','orientation:P'),(5687,'deals','added_page_settings','invoice','page_height:36'),(5688,'deals','main','customer_account','new'),(5689,'deals','added_page','label','test label'),(5690,'deals','extend','font_added','@font-face {\r\n font-family: \'FontAwesome\';\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?v=3.2.1\');\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?#iefix&v=3.2.1\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.woff?v=3.2.1\') format(\'woff\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.ttf?v=3.2.1\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.svg#fontawesomeregular?v=3.2.1\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(5691,'deals','main','group_product_by_product_group','1'),(5692,'deals','main','service_worker',''),(5693,'deals','main','backup_hours',''),(5694,'deals','main','backup_count',''),(5695,'deals','hide','theme_version','3578'),(5696,'deals','extend','font_added','/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}'),(5697,'deals','added_page','components','Customer care'),(5698,'deals','added_page','components','Social'),(5699,'deals','added_page','components','Header menu'),(5700,'deals','added_page','productListing','CompareProduct'),(5701,'deals','added_page','account','Credit Amount History'),(5704,'deals','extend','font_added','/* devanagari */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiGyp8kv8JHgFVrJJLucXtAKPY.woff2) format(\'woff2\');\r\n unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiGyp8kv8JHgFVrJJLufntAKPY.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiGyp8kv8JHgFVrJJLucHtA.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* devanagari */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLDz8Z11lFc-K.woff2) format(\'woff2\');\r\n unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLDz8Z1JlFc-K.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLDz8Z1xlFQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* devanagari */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiEyp8kv8JHgFVrJJbecmNE.woff2) format(\'woff2\');\r\n unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiEyp8kv8JHgFVrJJnecmNE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiEyp8kv8JHgFVrJJfecg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* devanagari */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLGT9Z11lFc-K.woff2) format(\'woff2\');\r\n unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLGT9Z1JlFc-K.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLGT9Z1xlFQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* devanagari */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLEj6Z11lFc-K.woff2) format(\'woff2\');\r\n unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLEj6Z1JlFc-K.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLEj6Z1xlFQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* devanagari */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLCz7Z11lFc-K.woff2) format(\'woff2\');\r\n unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLCz7Z1JlFc-K.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLCz7Z1xlFQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* devanagari */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLBT5Z11lFc-K.woff2) format(\'woff2\');\r\n unicode-range: U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200C-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLBT5Z1JlFc-K.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLBT5Z1xlFQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n@font-face {\r\n font-family: \'Lato\';\r\n font-style: italic;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/lato/v20/S6u_w4BMUTPHjxsI3wiPHw3q5d0.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Lato\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/lato/v20/S6u9w4BMUTPHh50XewyFHi_o.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiGyp8kv8JHgFVrJJLedHFHGPc.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 300;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLDz8V1hvEv-L.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiEyp8kv8JHgFVrFJPUdVNF.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLGT9V1hvEv-L.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLEj6V1hvEv-L.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLCz7V1hvEv-L.woff) format(\'woff\');\r\n}\r\n@font-face {\r\n font-family: \'Poppins\';\r\n font-style: normal;\r\n font-weight: 900;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/poppins/v15/pxiByp8kv8JHgFVrLBT5V1hvEv-L.woff) format(\'woff\');\r\n}'),(5705,'deals','extend','media_query','769w'),(5706,'deals','hide','theme_image','themes/deals/img/theme-b2b-supermarket.jpg'),(5707,'deals','extend','media_query','w900'),(5708,'deals','main','hide_empty_brands',''),(5709,'deals','main','contact_name',''),(5710,'deals','extend','font_added','@font-face {\r\n	font-family: \'themify\';\r\n	src:url(\'themes/basic/fonts/themify.eot?-fvbane\');\r\n	src:url(\'themes/basic/fonts/themify.eot?#iefix-fvbane\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/themify.woff?-fvbane\') format(\'woff\'),\r\n url(\'themes/basic/fonts/themify.ttf?-fvbane\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/themify.svg?-fvbane#themify\') format(\'svg\');\r\n	font-weight: normal;\r\n	font-style: normal;\r\n}'),(5711,NULL,NULL,NULL,'1710755904'),(5712,NULL,NULL,NULL,'1710755905'),(5713,NULL,NULL,NULL,'1710756009'),(7916,'furniture','extend','media_query','769w'),(7917,'watch','extend','media_query','769w'),(7918,'watch','extend','media_query','993w'),(7921,'watch','extend','media_query','w762'),(7922,'printshop','extend','media_query','w762'),(7923,'deals','extend','media_query','w762'),(8304,'watch','added_page','account','Review'),(8305,'watch','added_page','account','Order History Info'),(8306,'watch','added_page','account','Account edit'),(8307,'watch','added_page','account','Order History'),(8308,'watch','added_page','account','Review'),(8309,'watch','added_page','account','Order History Info'),(8310,'watch','added_page','account','Address Book'),(8311,'watch','added_page','account','Account edit'),(8312,'watch','added_page','account','Order History'),(8313,'watch','added_page','account','Address Book Process'),(8314,'furniture','added_page','account','Review'),(8315,'furniture','added_page','account','Order History Info'),(8316,'furniture','added_page','account','Address Book'),(8317,'furniture','added_page','account','Account edit'),(8318,'furniture','added_page','account','Order History'),(8319,'furniture','added_page','account','Address Book Process'),(8320,'printshop','added_page','account','Review'),(8321,'printshop','added_page','account','Order History Info'),(8322,'printshop','added_page','account','Address Book'),(8323,'printshop','added_page','account','Account edit'),(8324,'printshop','added_page','account','Order History'),(8325,'printshop','added_page','account','Address Book Process'),(8326,'deals','added_page','account','Review'),(8327,'deals','added_page','account','Order History Info'),(8328,'deals','added_page','account','Address Book'),(8329,'deals','added_page','account','Account edit'),(8330,'deals','added_page','account','Order History'),(8331,'deals','added_page','account','Address Book Process'),(8332,'origin','main','show_in_cart_button','no'),(8333,'origin','hide','na_banner','themes/basic/img/'),(8334,'origin','main','base64_product',''),(8335,'origin','main','base64_category',''),(8336,'origin','main','base64_banner','data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjwhLS0gR2VuZXJhdG9yOiBBZG9iZSBJbGx1c3RyYXRvciAxNy4xLjAsIFNWRyBFeHBvcnQgUGx1Zy1JbiAuIFNWRyBWZXJzaW9uOiA2LjAwIEJ1aWxkIDApICAtLT4NCjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+DQo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4Ig0KCSB2aWV3Qm94PSIwIDAgMTI3IDE0OC4zIiBlbmFibGUtYmFja2dyb3VuZD0ibmV3IDAgMCAxMjcgMTQ4LjMiIHhtbDpzcGFjZT0icHJlc2VydmUiPg0KPGc+DQoJPHBhdGggZmlsbD0iI0NFQ0VDRSIgZD0iTTEyNC4zLDQ2LjZ2OTEuMWMwLDQuMi0zLjQsNy42LTcuNiw3LjZIMTAuNGMtNC4yLDAtNy42LTMuNC03LjYtNy42VjExLjJjMC00LjIsMy40LTcuNiw3LjYtNy42aDcwLjgNCgkJYzQuMiwwLDEwLDIuNSwxMyw1LjRsMjQuNywyNC43QzEyMS44LDM2LjUsMTI0LjMsNDIuNCwxMjQuMyw0Ni42eiBNMTE0LjIsNTQuMkg4MS4zYy00LjIsMC03LjYtMy40LTcuNi03LjZWMTMuN0gxM3YxMjEuNGgxMDEuMg0KCQlWNTQuMnogTTIzLjEsNjkuM2MwLTguNCw2LjgtMTUuMiwxNS4yLTE1LjJTNTMuNCw2MSw1My40LDY5LjNzLTYuOCwxNS4yLTE1LjIsMTUuMlMyMy4xLDc3LjcsMjMuMSw2OS4zeiBNMTA0LDEyNUgyMy4xdi0xNS4yDQoJCWwxNS4yLTE1LjJsMTAuMSwxMC4xbDMwLjQtMzAuNEwxMDQsOTkuN1YxMjV6IE04My44LDQ0aDI5LjdjLTAuNS0xLjMtMS4yLTIuNy0xLjctMy4yTDg3LDE2LjFjLTAuNi0wLjYtMS45LTEuMy0zLjItMS43VjQ0eiIvPg0KPC9nPg0KPC9zdmc+DQo='),(8337,'origin','main','products_carousel',''),(8338,'origin','hide','backup_date','1713776818'),(8339,'origin','added_page','account','Samples'),(8340,'origin','added_page_settings','invoice','sheet_format:A4'),(8341,'origin','added_page_settings','invoice','sheet_format:A4'),(8342,'origin','added_page_settings','invoice','sheet_format:A4'),(8343,'origin','added_page_settings','invoice','sheet_format:A4'),(8344,'origin','added_page_settings','invoice','sheet_format:A4'),(8345,'origin','added_page','account','Tracking numbers'),(8346,'origin','added_page','productListing','b2b'),(8347,'origin','added_page','categories','Category no Filters'),(8348,'origin','added_page_settings','Category no Filters','no_filters'),(8349,'origin','extend','media_query','w768'),(8350,'origin','hide','new_attributes','1'),(8351,'origin','added_page','account','Points Earnt History'),(8352,'origin','layout','index','home'),(8353,'origin','added_page','email','Email 3'),(8354,'origin','main','show_empty_categories',''),(8355,'origin','main','after_add','popup'),(8356,'origin','extend','media_query','w992'),(8357,'origin','main','include_css','3'),(8358,'origin','added_page','account','Gift Certificate'),(8359,'origin','added_page','account','Address Book'),(8360,'origin','added_page','account','Created success'),(8361,'origin','extend','media_query','w1200'),(8362,'origin','added_page','account','Personal Catalog'),(8363,'origin','added_page','info','Testimonials'),(8364,'origin','main','use_mobile_theme',''),(8365,'origin','hide','theme_update','1520263888'),(8366,'origin','added_page','products','No Filters'),(8367,'origin','main','login_view',''),(8368,'origin','added_page','components','lending form'),(8369,'origin','added_page','account','Address Book Process'),(8370,'origin','added_page','account','My password'),(8371,'origin','added_page','productListing','Rows'),(8372,'origin','main','old_listing',''),(8373,'origin','main','dev_mode','1'),(8374,'origin','main','theme_color',''),(8375,'origin','added_page_settings','No Filters','no_filters'),(8376,'origin','hide','favicon','themes/basic/img/favicon_osc.png'),(8377,'origin','extend','media_query','w576'),(8378,'origin','added_page','account','Quotation Info'),(8379,'origin','hide','logo','themes/basic/img/oscommerce_logo.png'),(8380,'origin','main','show_products_from_subcategories','1'),(8381,'origin','added_page','account','Order pay'),(8382,'origin','added_page','email','Email 2'),(8383,'origin','added_page','gift_card','Gigt Card 3'),(8384,'origin','extend','font_added','@font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/woSH4aW-1wuybBQItyfdsvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/FdFTd030tby8r55hlt7EYfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/0IXD51eZ8qgi73bhvRidlQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/Vb88BBmXXgbpZxolKzz6dw.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/eND698DA6CUFWomaRdrTiw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/xLdg5JI0N_C2fvyu9XVzXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/bWPw4Za2XndpOjggSNN5JPY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/TCDCvLw6ewp4kJ2WSI4MT_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/_JiDQLq4JWzs7prWhNNmuA.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/HMitXFBPwJyXZfGm6rEhuvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/-H4xgvCtDmIfFNvmoAPAKvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/A2xpLU2z2kq5byuh5bkohg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/AFoPIhbuX_gBhSszntNC0_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/503ks6dbq2nVdfUL61JyAfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/PQuIEfcr_wdF_zOSNjqWKQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }'),(8385,'origin','added_page','account','Wishlist'),(8386,'origin','added_page','account','Review'),(8387,'origin','main','checkout_view',''),(8388,'origin','added_page','account','Order History Info'),(8389,'origin','added_page','home','Need Login'),(8390,'origin','added_page','account','Sample Info'),(8391,'origin','extend','font_added','@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrkByb1TKJa77egybnpn19yM.woff2) format(\'woff2\');\r\n unicode-range: U+0590-05FF, U+20AA, U+25CC, U+FB1D-FB4F;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrugdm0LZdjqr5-oayXSOefg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n\r\n\r\n@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round Regular\'), local(\'VarelaRound-Regular\'), url(https://fonts.gstatic.com/s/varelaround/v8/APH4jr0uSos5wiut5cpjrnhCUOGz7vYGh680lGh-uXM.woff) format(\'woff\');\r\nfont-display: swap;\r\n}\r\n'),(8392,'origin','extend','font_added','@font-face {\r\n font-family: \'trueloaded\';\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p\');\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p#iefix\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/trueloaded.ttf?4rk52p\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/trueloaded.woff?4rk52p\') format(\'woff\'),\r\n url(\'themes/basic/fonts/trueloaded.svg?4rk52p#trueloaded\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(8393,'origin','hide','na_product','themes/basic/img/na.png'),(8394,'origin','hide','na_category','themes/basic/img/no-categories.png'),(8395,'origin','javascript','javascript',' '),(8396,'origin','added_page','invoice','ticket'),(8397,'origin','added_page','account','Account edit'),(8398,'origin','added_page','email','Email 4'),(8399,'origin','added_page','account','Order History'),(8400,'origin','added_page_settings','invoice','sheet_format:A4'),(8401,'origin','added_page','gift_card','Gift Card 2'),(8402,'origin','added_page_settings','invoice','page_width:84'),(8403,'origin','added_page','account','Quotations'),(8404,'origin','added_page_settings','invoice','orientation:P'),(8405,'origin','added_page_settings','invoice','page_height:36'),(8406,'origin','main','customer_account','new'),(8407,'origin','added_page','label','test label'),(8408,'origin','extend','font_added','@font-face {\r\n font-family: \'FontAwesome\';\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?v=3.2.1\');\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?#iefix&v=3.2.1\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.woff?v=3.2.1\') format(\'woff\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.ttf?v=3.2.1\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.svg#fontawesomeregular?v=3.2.1\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(8409,'origin','main','group_product_by_product_group',''),(8410,'origin','main','service_worker',''),(8411,'origin','main','backup_hours',''),(8412,'origin','main','backup_count',''),(8413,'origin','hide','theme_version','274'),(8414,'origin','added_page','productListing','Compare Products'),(8415,'origin','added_page','productListing','Batch'),(8416,'origin','added_page','productListing','Batch Selected'),(8417,'origin','hide','theme_image','themes/basic/img/theme.png'),(8418,'origin','main','hide_empty_brands',''),(8419,'origin','main','contact_name',''),(8420,'origin','extend','font_added','@font-face {\r\n	font-family: \'themify\';\r\n	src:url(\'themes/basic/fonts/themify.eot?-fvbane\');\r\n	src:url(\'themes/basic/fonts/themify.eot?#iefix-fvbane\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/themify.woff?-fvbane\') format(\'woff\'),\r\n url(\'themes/basic/fonts/themify.ttf?-fvbane\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/themify.svg?-fvbane#themify\') format(\'svg\');\r\n	font-weight: normal;\r\n	font-style: normal;\r\n}'),(8421,'origin','extend','media_query','769w'),(8422,'origin','extend','media_query','993w'),(8423,'origin','extend','media_query','1201w'),(8424,'origin','extend','font_added','/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}'),(8425,'origin','extend','media_query','w762'),(8426,'origin','extend','media_query','w720'),(8427,'new_theme','main','show_in_cart_button','no'),(8428,'new_theme','hide','na_banner','themes/basic/img/'),(8429,'new_theme','main','base64_product',''),(8430,'new_theme','main','base64_category',''),(8431,'new_theme','main','base64_banner','data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjwhLS0gR2VuZXJhdG9yOiBBZG9iZSBJbGx1c3RyYXRvciAxNy4xLjAsIFNWRyBFeHBvcnQgUGx1Zy1JbiAuIFNWRyBWZXJzaW9uOiA2LjAwIEJ1aWxkIDApICAtLT4NCjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+DQo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4Ig0KCSB2aWV3Qm94PSIwIDAgMTI3IDE0OC4zIiBlbmFibGUtYmFja2dyb3VuZD0ibmV3IDAgMCAxMjcgMTQ4LjMiIHhtbDpzcGFjZT0icHJlc2VydmUiPg0KPGc+DQoJPHBhdGggZmlsbD0iI0NFQ0VDRSIgZD0iTTEyNC4zLDQ2LjZ2OTEuMWMwLDQuMi0zLjQsNy42LTcuNiw3LjZIMTAuNGMtNC4yLDAtNy42LTMuNC03LjYtNy42VjExLjJjMC00LjIsMy40LTcuNiw3LjYtNy42aDcwLjgNCgkJYzQuMiwwLDEwLDIuNSwxMyw1LjRsMjQuNywyNC43QzEyMS44LDM2LjUsMTI0LjMsNDIuNCwxMjQuMyw0Ni42eiBNMTE0LjIsNTQuMkg4MS4zYy00LjIsMC03LjYtMy40LTcuNi03LjZWMTMuN0gxM3YxMjEuNGgxMDEuMg0KCQlWNTQuMnogTTIzLjEsNjkuM2MwLTguNCw2LjgtMTUuMiwxNS4yLTE1LjJTNTMuNCw2MSw1My40LDY5LjNzLTYuOCwxNS4yLTE1LjIsMTUuMlMyMy4xLDc3LjcsMjMuMSw2OS4zeiBNMTA0LDEyNUgyMy4xdi0xNS4yDQoJCWwxNS4yLTE1LjJsMTAuMSwxMC4xbDMwLjQtMzAuNEwxMDQsOTkuN1YxMjV6IE04My44LDQ0aDI5LjdjLTAuNS0xLjMtMS4yLTIuNy0xLjctMy4yTDg3LDE2LjFjLTAuNi0wLjYtMS45LTEuMy0zLjItMS43VjQ0eiIvPg0KPC9nPg0KPC9zdmc+DQo='),(8432,'new_theme','main','products_carousel',''),(8433,'new_theme','hide','backup_date','1713776818'),(8434,'new_theme','added_page','account','Samples'),(8435,'new_theme','added_page_settings','invoice','sheet_format:A4'),(8436,'new_theme','added_page_settings','invoice','sheet_format:A4'),(8437,'new_theme','added_page_settings','invoice','sheet_format:A4'),(8438,'new_theme','added_page_settings','invoice','sheet_format:A4'),(8439,'new_theme','added_page_settings','invoice','sheet_format:A4'),(8440,'new_theme','added_page','account','Tracking numbers'),(8441,'new_theme','added_page','productListing','b2b'),(8442,'new_theme','added_page','categories','Category no Filters'),(8443,'new_theme','added_page_settings','Category no Filters','no_filters'),(8444,'new_theme','extend','media_query','w768'),(8445,'new_theme','hide','new_attributes','1'),(8446,'new_theme','added_page','account','Points Earnt History'),(8447,'new_theme','layout','index','home'),(8448,'new_theme','added_page','email','Email 3'),(8449,'new_theme','main','show_empty_categories',''),(8450,'new_theme','main','after_add','popup'),(8451,'new_theme','extend','media_query','w992'),(8452,'new_theme','main','include_css','3'),(8453,'new_theme','added_page','account','Gift Certificate'),(8454,'new_theme','added_page','account','Address Book'),(8455,'new_theme','added_page','account','Created success'),(8456,'new_theme','extend','media_query','w1200'),(8457,'new_theme','added_page','account','Personal Catalog'),(8458,'new_theme','added_page','info','Testimonials'),(8459,'new_theme','main','use_mobile_theme',''),(8460,'new_theme','hide','theme_update','1520263888'),(8461,'new_theme','added_page','products','No Filters'),(8462,'new_theme','main','login_view',''),(8463,'new_theme','added_page','components','lending form'),(8464,'new_theme','added_page','account','Address Book Process'),(8465,'new_theme','added_page','account','My password'),(8466,'new_theme','added_page','productListing','Rows'),(8467,'new_theme','main','old_listing',''),(8468,'new_theme','main','dev_mode','1'),(8469,'new_theme','main','theme_color',''),(8470,'new_theme','added_page_settings','No Filters','no_filters'),(8471,'new_theme','hide','favicon','themes/basic/img/favicon_osc.png'),(8472,'new_theme','extend','media_query','w576'),(8473,'new_theme','added_page','account','Quotation Info'),(8474,'new_theme','hide','logo','themes/basic/img/oscommerce_logo.png'),(8475,'new_theme','main','show_products_from_subcategories','1'),(8476,'new_theme','added_page','account','Order pay'),(8477,'new_theme','added_page','email','Email 2'),(8478,'new_theme','added_page','gift_card','Gigt Card 3'),(8479,'new_theme','extend','font_added','@font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/woSH4aW-1wuybBQItyfdsvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/FdFTd030tby8r55hlt7EYfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 300;\r\n src: local(\'Hind Light\'), local(\'Hind-Light\'), url(//fonts.gstatic.com/s/hind/v6/0IXD51eZ8qgi73bhvRidlQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/Vb88BBmXXgbpZxolKzz6dw.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/eND698DA6CUFWomaRdrTiw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Hind\'), local(\'Hind-Regular\'), url(//fonts.gstatic.com/s/hind/v6/xLdg5JI0N_C2fvyu9XVzXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/bWPw4Za2XndpOjggSNN5JPY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/TCDCvLw6ewp4kJ2WSI4MT_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 500;\r\n src: local(\'Hind Medium\'), local(\'Hind-Medium\'), url(//fonts.gstatic.com/s/hind/v6/_JiDQLq4JWzs7prWhNNmuA.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/HMitXFBPwJyXZfGm6rEhuvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/-H4xgvCtDmIfFNvmoAPAKvY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 600;\r\n src: local(\'Hind SemiBold\'), local(\'Hind-SemiBold\'), url(//fonts.gstatic.com/s/hind/v6/A2xpLU2z2kq5byuh5bkohg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n /* devanagari */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/AFoPIhbuX_gBhSszntNC0_Y6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+02BC, U+0900-097F, U+1CD0-1CF6, U+1CF8-1CF9, U+200B-200D, U+20A8, U+20B9, U+25CC, U+A830-A839, U+A8E0-A8FB;\r\nfont-display: swap;\r\n }\r\n /* latin-ext */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/503ks6dbq2nVdfUL61JyAfY6323mHUZFJMgTvxaG2iE.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Hind\';\r\n font-style: normal;\r\n font-weight: 700;\r\n src: local(\'Hind Bold\'), local(\'Hind-Bold\'), url(//fonts.gstatic.com/s/hind/v6/PQuIEfcr_wdF_zOSNjqWKQ.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }'),(8480,'new_theme','added_page','account','Wishlist'),(8481,'new_theme','added_page','account','Review'),(8482,'new_theme','main','checkout_view',''),(8483,'new_theme','added_page','account','Order History Info'),(8484,'new_theme','added_page','home','Need Login'),(8485,'new_theme','added_page','account','Sample Info'),(8486,'new_theme','extend','font_added','@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrkByb1TKJa77egybnpn19yM.woff2) format(\'woff2\');\r\n unicode-range: U+0590-05FF, U+20AA, U+25CC, U+FB1D-FB4F;\r\nfont-display: swap;\r\n }\r\n /* latin */\r\n @font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round\'), local(\'VarelaRound-Regular\'), url(//fonts.gstatic.com/s/varelaround/v7/APH4jr0uSos5wiut5cpjrugdm0LZdjqr5-oayXSOefg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;\r\nfont-display: swap;\r\n }\r\n\r\n\r\n@font-face {\r\n font-family: \'Varela Round\';\r\n font-style: normal;\r\n font-weight: 400;\r\n src: local(\'Varela Round Regular\'), local(\'VarelaRound-Regular\'), url(https://fonts.gstatic.com/s/varelaround/v8/APH4jr0uSos5wiut5cpjrnhCUOGz7vYGh680lGh-uXM.woff) format(\'woff\');\r\nfont-display: swap;\r\n}\r\n'),(8487,'new_theme','extend','font_added','@font-face {\r\n font-family: \'trueloaded\';\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p\');\r\n src: url(\'themes/basic/fonts/trueloaded.eot?4rk52p#iefix\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/trueloaded.ttf?4rk52p\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/trueloaded.woff?4rk52p\') format(\'woff\'),\r\n url(\'themes/basic/fonts/trueloaded.svg?4rk52p#trueloaded\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(8488,'new_theme','hide','na_product','themes/basic/img/na.png'),(8489,'new_theme','hide','na_category','themes/basic/img/no-categories.png'),(8490,'new_theme','javascript','javascript',' '),(8491,'new_theme','added_page','invoice','ticket'),(8492,'new_theme','added_page','account','Account edit'),(8493,'new_theme','added_page','email','Email 4'),(8494,'new_theme','added_page','account','Order History'),(8495,'new_theme','added_page_settings','invoice','sheet_format:A4'),(8496,'new_theme','added_page','gift_card','Gift Card 2'),(8497,'new_theme','added_page_settings','invoice','page_width:84'),(8498,'new_theme','added_page','account','Quotations'),(8499,'new_theme','added_page_settings','invoice','orientation:P'),(8500,'new_theme','added_page_settings','invoice','page_height:36'),(8501,'new_theme','main','customer_account','new'),(8502,'new_theme','added_page','label','test label'),(8503,'new_theme','extend','font_added','@font-face {\r\n font-family: \'FontAwesome\';\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?v=3.2.1\');\r\n src: url(\'themes/basic/fonts/fontawesome-webfont.eot?#iefix&v=3.2.1\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.woff?v=3.2.1\') format(\'woff\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.ttf?v=3.2.1\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/fontawesome-webfont.svg#fontawesomeregular?v=3.2.1\') format(\'svg\');\r\n font-weight: normal;\r\n font-style: normal;\r\nfont-display: swap;\r\n }'),(8504,'new_theme','main','group_product_by_product_group',''),(8505,'new_theme','main','service_worker',''),(8506,'new_theme','main','backup_hours',''),(8507,'new_theme','main','backup_count',''),(8508,'new_theme','hide','theme_version','274'),(8509,'new_theme','added_page','productListing','Compare Products'),(8510,'new_theme','added_page','productListing','Batch'),(8511,'new_theme','added_page','productListing','Batch Selected'),(8512,'new_theme','hide','theme_image','themes/basic/img/theme.png'),(8513,'new_theme','main','hide_empty_brands',''),(8514,'new_theme','main','contact_name',''),(8515,'new_theme','extend','font_added','@font-face {\r\n	font-family: \'themify\';\r\n	src:url(\'themes/basic/fonts/themify.eot?-fvbane\');\r\n	src:url(\'themes/basic/fonts/themify.eot?#iefix-fvbane\') format(\'embedded-opentype\'),\r\n url(\'themes/basic/fonts/themify.woff?-fvbane\') format(\'woff\'),\r\n url(\'themes/basic/fonts/themify.ttf?-fvbane\') format(\'truetype\'),\r\n url(\'themes/basic/fonts/themify.svg?-fvbane#themify\') format(\'svg\');\r\n	font-weight: normal;\r\n	font-style: normal;\r\n}'),(8516,'new_theme','extend','media_query','769w'),(8517,'new_theme','extend','media_query','993w'),(8518,'new_theme','extend','media_query','1201w'),(8519,'new_theme','extend','font_added','/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnhHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OngHXi-Ag.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: italic;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4g0qWljRw-Pd815fNqc8T_wAFcX-c37OnuHXg.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 400;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 500;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 600;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}\r\n/* vietnamese */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6XvptnsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;\r\n}\r\n/* latin-ext */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvp9nsBXw.woff2) format(\'woff2\');\r\n unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;\r\n}\r\n/* latin */\r\n@font-face {\r\n font-family: \'Cabin\';\r\n font-style: normal;\r\n font-weight: 700;\r\n font-stretch: 100%;\r\n font-display: swap;\r\n src: url(https://fonts.gstatic.com/s/cabin/v18/u-4i0qWljRw-PfU81xCKCpdpbgZJl6Xvqdns.woff2) format(\'woff2\');\r\n unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\r\n}'),(8520,'new_theme','extend','media_query','w762'),(8521,'new_theme','extend','media_query','w720');
/*!40000 ALTER TABLE `themes_settings` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `themes_steps`
--

DROP TABLE IF EXISTS `themes_steps`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `themes_steps` (
  `steps_id` int(11) NOT NULL AUTO_INCREMENT,
  `parent_id` int(11) NOT NULL DEFAULT '0',
  `event` varchar(64) NOT NULL DEFAULT '',
  `data` mediumtext NOT NULL,
  `theme_name` varchar(128) CHARACTER SET latin1 COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `date_added` datetime DEFAULT NULL,
  `active` tinyint(1) NOT NULL DEFAULT '0',
  `admin_id` int(11) NOT NULL DEFAULT '0',
  `mode` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`steps_id`),
  KEY `id` (`steps_id`)
) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `themes_steps`
--

LOCK TABLES `themes_steps` WRITE;
/*!40000 ALTER TABLE `themes_steps` DISABLE KEYS */;
INSERT INTO `themes_steps` VALUES (1,0,'applyMigration','[{\"steps_id\":176,\"parent_id\":0,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".w-cart-listing .promos-info .promo-name\",\"attribute\":\"border_radius_1_measure\",\"value_old\":\"\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"},{\"selector\":\".w-cart-listing .promos-info .promo-name\",\"attribute\":\"border_radius_4_measure\",\"value_old\":\"\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"}],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-listing .price small\",\"attribute\":\"display\",\"value\":\"block\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-listing .price small\",\"attribute\":\"line-height\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:21:39\",\"active\":0,\"admin_id\":28},{\"steps_id\":178,\"parent_id\":177,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:21:39\",\"active\":0,\"admin_id\":28},{\"steps_id\":179,\"parent_id\":178,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"line-height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"line_height_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"display\",\"value\":\"block\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:25:02\",\"active\":0,\"admin_id\":28},{\"steps_id\":180,\"parent_id\":179,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:25:03\",\"active\":0,\"admin_id\":28},{\"steps_id\":181,\"parent_id\":180,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value_old\":\"flex\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:25:58\",\"active\":0,\"admin_id\":28},{\"steps_id\":182,\"parent_id\":181,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120900\",\"block_name\":\"1644251633-2\",\"widget_name\":\"cart\\\\SubTotal\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1619363,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1621699,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total .title\",\"attribute\":\"font-size\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1621700,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"font-size\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1622367,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total .title\",\"attribute\":\"font-weight\",\"value\":\"600\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1622368,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"font-weight\",\"value\":\"600\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1625100,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-bottom\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1625721,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1626306,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1626890,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1634448,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"text-align\",\"value\":\"right\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1636658,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1636659,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total .price-row > div\",\"attribute\":\"width\",\"value\":\"50\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1637422,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1637423,\"theme_name\":\"deals\",\"selector\":\".w-cart-sub-total .price-row > div\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"}]},\"translation\":[],\"box_id\":\"191763\",\"siblings\":[{\"id\":191763,\"microtime\":\"120900\",\"theme_name\":\"deals\",\"block_name\":\"block-191761-2\",\"widget_name\":\"cart\\\\SubTotal\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":191764,\"microtime\":\"1639476084\",\"theme_name\":\"deals\",\"block_name\":\"block-191761-2\",\"widget_name\":\"cart\\\\FreeDelivery\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:26:39\",\"active\":0,\"admin_id\":28},{\"steps_id\":184,\"parent_id\":183,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665923716.738\",\"block_name\":\"116337\",\"page_name\":null,\"widget_name\":\"checkout\\\\LoginOnForm\",\"sort_order\":0},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:35:16\",\"active\":0,\"admin_id\":28},{\"steps_id\":185,\"parent_id\":184,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224960\",\"microtime\":\"1665923716.738\",\"block_name\":\"116336\",\"sort_order\":1},{\"id\":\"191890\",\"microtime\":\"116350\",\"block_name\":\"116336\",\"sort_order\":2},{\"id\":\"191875\",\"microtime\":\"116337\",\"block_name\":\"116336\",\"sort_order\":3},{\"id\":\"191878\",\"microtime\":\"116340\",\"block_name\":\"116336\",\"sort_order\":4},{\"id\":\"191877\",\"microtime\":\"116339\",\"block_name\":\"116336\",\"sort_order\":5}],\"positions_old\":[{\"id\":\"224960\",\"block_name\":\"116337\",\"sort_order\":\"0\",\"microtime\":\"1665923716.738\"},{\"id\":\"191890\",\"block_name\":\"116336\",\"sort_order\":\"2\",\"microtime\":\"116350\"},{\"id\":\"191875\",\"block_name\":\"116336\",\"sort_order\":\"3\",\"microtime\":\"116337\"},{\"id\":\"191878\",\"block_name\":\"116336\",\"sort_order\":\"4\",\"microtime\":\"116340\"},{\"id\":\"191877\",\"block_name\":\"116336\",\"sort_order\":\"5\",\"microtime\":\"116339\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:35:27\",\"active\":0,\"admin_id\":28},{\"steps_id\":186,\"parent_id\":185,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224960\",\"microtime\":\"1665923716.738\",\"block_name\":\"116326\",\"sort_order\":1},{\"id\":\"191874\",\"microtime\":\"116336\",\"block_name\":\"116326\",\"sort_order\":2},{\"id\":\"191895\",\"microtime\":\"116354\",\"block_name\":\"116326\",\"sort_order\":3},{\"id\":\"191868\",\"microtime\":\"116330\",\"block_name\":\"116326\",\"sort_order\":4},{\"id\":\"191865\",\"microtime\":\"116327\",\"block_name\":\"116326\",\"sort_order\":5},{\"id\":\"191891\",\"microtime\":\"116351\",\"block_name\":\"116326\",\"sort_order\":6}],\"positions_old\":[{\"id\":\"224960\",\"block_name\":\"116336\",\"sort_order\":\"1\",\"microtime\":\"1665923716.738\"},{\"id\":\"191874\",\"block_name\":\"116326\",\"sort_order\":\"2\",\"microtime\":\"116336\"},{\"id\":\"191895\",\"block_name\":\"116326\",\"sort_order\":\"3\",\"microtime\":\"116354\"},{\"id\":\"191868\",\"block_name\":\"116326\",\"sort_order\":\"4\",\"microtime\":\"116330\"},{\"id\":\"191865\",\"block_name\":\"116326\",\"sort_order\":\"5\",\"microtime\":\"116327\"},{\"id\":\"191891\",\"block_name\":\"116326\",\"sort_order\":\"6\",\"microtime\":\"116351\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:35:31\",\"active\":0,\"admin_id\":28},{\"steps_id\":187,\"parent_id\":186,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665923764.8423\",\"block_name\":\"116336\",\"page_name\":null,\"widget_name\":\"BlockBox\",\"sort_order\":0},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:36:04\",\"active\":0,\"admin_id\":28},{\"steps_id\":188,\"parent_id\":187,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224960\",\"microtime\":\"1665923716.738\",\"block_name\":\"116326\",\"sort_order\":1},{\"id\":\"224961\",\"microtime\":\"1665923764.8423\",\"block_name\":\"116326\",\"sort_order\":2},{\"id\":\"191874\",\"microtime\":\"116336\",\"block_name\":\"116326\",\"sort_order\":3},{\"id\":\"191895\",\"microtime\":\"116354\",\"block_name\":\"116326\",\"sort_order\":4},{\"id\":\"191868\",\"microtime\":\"116330\",\"block_name\":\"116326\",\"sort_order\":5},{\"id\":\"191865\",\"microtime\":\"116327\",\"block_name\":\"116326\",\"sort_order\":6},{\"id\":\"191891\",\"microtime\":\"116351\",\"block_name\":\"116326\",\"sort_order\":7}],\"positions_old\":[{\"id\":\"224960\",\"block_name\":\"116326\",\"sort_order\":\"1\",\"microtime\":\"1665923716.738\"},{\"id\":\"224961\",\"block_name\":\"116336\",\"sort_order\":\"0\",\"microtime\":\"1665923764.8423\"},{\"id\":\"191874\",\"block_name\":\"116326\",\"sort_order\":\"2\",\"microtime\":\"116336\"},{\"id\":\"191895\",\"block_name\":\"116326\",\"sort_order\":\"3\",\"microtime\":\"116354\"},{\"id\":\"191868\",\"block_name\":\"116326\",\"sort_order\":\"4\",\"microtime\":\"116330\"},{\"id\":\"191865\",\"block_name\":\"116326\",\"sort_order\":\"5\",\"microtime\":\"116327\"},{\"id\":\"191891\",\"block_name\":\"116326\",\"sort_order\":\"6\",\"microtime\":\"116351\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:36:12\",\"active\":0,\"admin_id\":28},{\"steps_id\":189,\"parent_id\":188,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665923764.8423\",\"box_id\":\"224961\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"}],\"box_settings_old\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:36:16\",\"active\":0,\"admin_id\":28},{\"steps_id\":190,\"parent_id\":189,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224960\",\"microtime\":\"1665923716.738\",\"block_name\":\"1665923764.8423\",\"sort_order\":1}],\"positions_old\":[{\"id\":\"224960\",\"block_name\":\"116326\",\"sort_order\":\"1\",\"microtime\":\"1665923716.738\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:37:11\",\"active\":0,\"admin_id\":28},{\"steps_id\":191,\"parent_id\":190,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665923764.8423\",\"box_id\":\"224961\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:37:42\",\"active\":0,\"admin_id\":28},{\"steps_id\":192,\"parent_id\":191,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665923912.5198\",\"block_name\":\"116362\",\"page_name\":null,\"widget_name\":\"cart\\\\Products\",\"sort_order\":0},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:38:32\",\"active\":0,\"admin_id\":28},{\"steps_id\":193,\"parent_id\":192,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"191905\",\"microtime\":\"116364\",\"block_name\":\"116362\",\"sort_order\":1},{\"id\":\"224962\",\"microtime\":\"1665923912.5198\",\"block_name\":\"116362\",\"sort_order\":2},{\"id\":\"191907\",\"microtime\":\"116366\",\"block_name\":\"116362\",\"sort_order\":3},{\"id\":\"191908\",\"microtime\":\"116367\",\"block_name\":\"116362\",\"sort_order\":4},{\"id\":\"191906\",\"microtime\":\"116365\",\"block_name\":\"116362\",\"sort_order\":5},{\"id\":\"191904\",\"microtime\":\"116363\",\"block_name\":\"116362\",\"sort_order\":6}],\"positions_old\":[{\"id\":\"191905\",\"block_name\":\"116362\",\"sort_order\":\"1\",\"microtime\":\"116364\"},{\"id\":\"224962\",\"block_name\":\"116362\",\"sort_order\":\"0\",\"microtime\":\"1665923912.5198\"},{\"id\":\"191907\",\"block_name\":\"116362\",\"sort_order\":\"2\",\"microtime\":\"116366\"},{\"id\":\"191908\",\"block_name\":\"116362\",\"sort_order\":\"3\",\"microtime\":\"116367\"},{\"id\":\"191906\",\"block_name\":\"116362\",\"sort_order\":\"4\",\"microtime\":\"116365\"},{\"id\":\"191904\",\"block_name\":\"116362\",\"sort_order\":\"5\",\"microtime\":\"116363\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:38:40\",\"active\":0,\"admin_id\":28},{\"steps_id\":195,\"parent_id\":194,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .headings\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .headings\",\"attribute\":\"grid-template-columns\",\"value\":\"3fr 1fr 1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"3fr 1fr 1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"grid-column\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price\",\"attribute\":\"grid-column\",\"value\":\"3\\/4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price\",\"attribute\":\"grid-row\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty\",\"attribute\":\"grid-column\",\"value\":\"2\\/3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty\",\"attribute\":\"grid-row\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item > div.image\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .price\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing.type-2 .image\",\"attribute\":\"grid-column\",\"value\":\"1 \\/ 3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing.type-2 .image\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:39:25\",\"active\":0,\"admin_id\":28},{\"steps_id\":196,\"parent_id\":195,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:39:26\",\"active\":0,\"admin_id\":28},{\"steps_id\":197,\"parent_id\":196,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .checkout-cart-listing\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .checkout-cart-listing\",\"attribute\":\"border-bottom-color\",\"value\":\"#e2e2e2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:40:47\",\"active\":0,\"admin_id\":28},{\"steps_id\":198,\"parent_id\":197,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:40:48\",\"active\":0,\"admin_id\":28},{\"steps_id\":199,\"parent_id\":198,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-rows\",\"value\":\"1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:41:58\",\"active\":0,\"admin_id\":28},{\"steps_id\":200,\"parent_id\":199,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:41:59\",\"active\":0,\"admin_id\":28},{\"steps_id\":201,\"parent_id\":200,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665923764.8423\",\"box_id\":\"224961\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665923764.8423\",\"theme_name\":\"deals\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-top-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-left-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-right-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-bottom-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:42:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":203,\"parent_id\":202,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .closeable-heading .heading-2\",\"attribute\":\"margin-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:48:17\",\"active\":0,\"admin_id\":28},{\"steps_id\":204,\"parent_id\":203,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:48:18\",\"active\":0,\"admin_id\":28},{\"steps_id\":205,\"parent_id\":204,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .closeable-heading + .closeable-content\",\"attribute\":\"padding-top\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:48:57\",\"active\":0,\"admin_id\":28},{\"steps_id\":206,\"parent_id\":205,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:48:57\",\"active\":0,\"admin_id\":28},{\"steps_id\":207,\"parent_id\":206,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"line-height\",\"value\":\"2\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:49:39\",\"active\":0,\"admin_id\":28},{\"steps_id\":208,\"parent_id\":207,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 13:49:40\",\"active\":0,\"admin_id\":28},{\"steps_id\":212,\"parent_id\":208,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .checkout-cart-listing.main-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:25:35\",\"active\":0,\"admin_id\":28},{\"steps_id\":214,\"parent_id\":213,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:25:37\",\"active\":0,\"admin_id\":28},{\"steps_id\":215,\"parent_id\":214,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:25:38\",\"active\":0,\"admin_id\":28},{\"steps_id\":216,\"parent_id\":215,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224961\",\"microtime\":\"1665923764.8423\",\"block_name\":\"116326\",\"sort_order\":1},{\"id\":\"191874\",\"microtime\":\"116336\",\"block_name\":\"116326\",\"sort_order\":2},{\"id\":\"191895\",\"microtime\":\"116354\",\"block_name\":\"116326\",\"sort_order\":3},{\"id\":\"191868\",\"microtime\":\"116330\",\"block_name\":\"116326\",\"sort_order\":4},{\"id\":\"191865\",\"microtime\":\"116327\",\"block_name\":\"116326\",\"sort_order\":5},{\"id\":\"191892\",\"microtime\":\"116352\",\"block_name\":\"116326\",\"sort_order\":6},{\"id\":\"191891\",\"microtime\":\"116351\",\"block_name\":\"116326\",\"sort_order\":7}],\"positions_old\":[{\"id\":\"224961\",\"block_name\":\"116326\",\"sort_order\":\"2\",\"microtime\":\"1665923764.8423\"},{\"id\":\"191874\",\"block_name\":\"116326\",\"sort_order\":\"3\",\"microtime\":\"116336\"},{\"id\":\"191895\",\"block_name\":\"116326\",\"sort_order\":\"4\",\"microtime\":\"116354\"},{\"id\":\"191868\",\"block_name\":\"116326\",\"sort_order\":\"5\",\"microtime\":\"116330\"},{\"id\":\"191865\",\"block_name\":\"116326\",\"sort_order\":\"6\",\"microtime\":\"116327\"},{\"id\":\"191892\",\"block_name\":\"116351\",\"sort_order\":\"1\",\"microtime\":\"116352\"},{\"id\":\"191891\",\"block_name\":\"116326\",\"sort_order\":\"7\",\"microtime\":\"116351\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:26:16\",\"active\":0,\"admin_id\":28},{\"steps_id\":217,\"parent_id\":216,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116352\",\"box_id\":\"191892\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"}],\"box_settings_old\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:27:03\",\"active\":0,\"admin_id\":28},{\"steps_id\":218,\"parent_id\":217,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224961\",\"microtime\":\"1665923764.8423\",\"block_name\":\"116326\",\"sort_order\":1},{\"id\":\"191874\",\"microtime\":\"116336\",\"block_name\":\"116326\",\"sort_order\":2},{\"id\":\"191895\",\"microtime\":\"116354\",\"block_name\":\"116326\",\"sort_order\":3},{\"id\":\"191868\",\"microtime\":\"116330\",\"block_name\":\"116326\",\"sort_order\":4},{\"id\":\"191865\",\"microtime\":\"116327\",\"block_name\":\"116326\",\"sort_order\":5},{\"id\":\"191892\",\"microtime\":\"116352\",\"block_name\":\"116326\",\"sort_order\":6},{\"id\":\"191893\",\"microtime\":\"116353\",\"block_name\":\"116326\",\"sort_order\":7},{\"id\":\"191891\",\"microtime\":\"116351\",\"block_name\":\"116326\",\"sort_order\":8}],\"positions_old\":[{\"id\":\"224961\",\"block_name\":\"116326\",\"sort_order\":\"1\",\"microtime\":\"1665923764.8423\"},{\"id\":\"191874\",\"block_name\":\"116326\",\"sort_order\":\"2\",\"microtime\":\"116336\"},{\"id\":\"191895\",\"block_name\":\"116326\",\"sort_order\":\"3\",\"microtime\":\"116354\"},{\"id\":\"191868\",\"block_name\":\"116326\",\"sort_order\":\"4\",\"microtime\":\"116330\"},{\"id\":\"191865\",\"block_name\":\"116326\",\"sort_order\":\"5\",\"microtime\":\"116327\"},{\"id\":\"191892\",\"block_name\":\"116326\",\"sort_order\":\"6\",\"microtime\":\"116352\"},{\"id\":\"191893\",\"block_name\":\"116351\",\"sort_order\":\"2\",\"microtime\":\"116353\"},{\"id\":\"191891\",\"block_name\":\"116326\",\"sort_order\":\"7\",\"microtime\":\"116351\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:27:20\",\"active\":0,\"admin_id\":28},{\"steps_id\":224,\"parent_id\":219,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .w-cart-listing .multi-cart .item\",\"attribute\":\"grid-template-rows\",\"value\":\"1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:32:56\",\"active\":0,\"admin_id\":28},{\"steps_id\":225,\"parent_id\":224,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:32:56\",\"active\":0,\"admin_id\":28},{\"steps_id\":226,\"parent_id\":225,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116362\",\"box_id\":\"191903\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116362\",\"theme_name\":\"deals\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116362\",\"theme_name\":\"deals\"},{\"setting_name\":\"style_class\",\"setting_value\":\"order-summary\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116362\",\"theme_name\":\"deals\"},{\"setting_name\":\"margin-left\",\"setting_value\":\"25\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116362\",\"theme_name\":\"deals\"},{\"setting_name\":\"margin-left\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116362\",\"theme_name\":\"deals\"},{\"setting_name\":\"margin-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116362\",\"theme_name\":\"deals\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"style_class\",\"setting_value\":\"order-summary\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-left\",\"setting_value\":\"25\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-left\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:34:28\",\"active\":0,\"admin_id\":28},{\"steps_id\":228,\"parent_id\":227,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116352\",\"box_id\":\"191892\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"}],\"box_settings_old\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-top-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-left-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-right-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-bottom-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:36:41\",\"active\":0,\"admin_id\":28},{\"steps_id\":230,\"parent_id\":229,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116327\",\"box_id\":\"191865\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box closeable-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116327\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116327\",\"theme_name\":\"deals\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"14\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box closeable-box\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-top-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-left-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-right-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-bottom-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"7\",\"language_id\":\"0\",\"visibility\":\"w992\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:37:34\",\"active\":0,\"admin_id\":28},{\"steps_id\":231,\"parent_id\":230,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116330\",\"box_id\":\"191868\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box closeable-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116330\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116330\",\"theme_name\":\"deals\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"14\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box closeable-box\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-top-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-left-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-right-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-bottom-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"15\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"7\",\"language_id\":\"0\",\"visibility\":\"w992\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:37:54\",\"active\":0,\"admin_id\":28},{\"steps_id\":233,\"parent_id\":232,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing.summary-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:39:52\",\"active\":0,\"admin_id\":28},{\"steps_id\":234,\"parent_id\":233,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:39:53\",\"active\":0,\"admin_id\":28},{\"steps_id\":235,\"parent_id\":234,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-rows\",\"value\":\"1fr\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:41:26\",\"active\":0,\"admin_id\":28},{\"steps_id\":236,\"parent_id\":235,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:41:27\",\"active\":0,\"admin_id\":28},{\"steps_id\":237,\"parent_id\":236,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-rows\",\"value\":\"1fr\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"1fr\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:41:53\",\"active\":0,\"admin_id\":28},{\"steps_id\":238,\"parent_id\":237,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:41:53\",\"active\":0,\"admin_id\":28},{\"steps_id\":239,\"parent_id\":238,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:42:17\",\"active\":0,\"admin_id\":28},{\"steps_id\":240,\"parent_id\":239,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"1fr\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"1fr\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:42:42\",\"active\":0,\"admin_id\":28},{\"steps_id\":241,\"parent_id\":240,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:42:43\",\"active\":0,\"admin_id\":28},{\"steps_id\":242,\"parent_id\":241,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116352\",\"box_id\":\"191892\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116352\",\"theme_name\":\"deals\"}],\"box_settings_old\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-top-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-left-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-right-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"border-bottom-color\",\"setting_value\":\"#e2e2e2\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"border-top-width\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"border-left-width\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"border-right-width\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"border-bottom-width\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 14:53:47\",\"active\":0,\"admin_id\":28},{\"steps_id\":277,\"parent_id\":243,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 15:14:29\",\"active\":0,\"admin_id\":28},{\"steps_id\":278,\"parent_id\":277,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 15:14:30\",\"active\":0,\"admin_id\":28},{\"steps_id\":368,\"parent_id\":278,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".w-checkout-shipping-choice span\",\"attribute\":\"padding-left\",\"value_old\":\"10\",\"value\":\"6\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"selector\":\".w-checkout-shipping-choice span\",\"attribute\":\"padding-right\",\"value_old\":\"10\",\"value\":\"6\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"}],\"attributes_delete\":[{\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-ms-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-webkit-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"}],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 20:58:54\",\"active\":0,\"admin_id\":28},{\"steps_id\":370,\"parent_id\":369,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-ms-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"theme_name\":\"deals\",\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-webkit-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"theme_name\":\"deals\",\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-ms-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"theme_name\":\"deals\",\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-webkit-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 20:58:55\",\"active\":0,\"admin_id\":28},{\"steps_id\":371,\"parent_id\":370,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-ms-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-webkit-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"}],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-16 20:58:56\",\"active\":0,\"admin_id\":28},{\"steps_id\":383,\"parent_id\":371,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"font-size\",\"value\":\"21\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"content\",\"value\":\"\\\\f283\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"margin-left\",\"value\":\"15\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 05:50:12\",\"active\":0,\"admin_id\":28},{\"steps_id\":385,\"parent_id\":384,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 05:50:13\",\"active\":0,\"admin_id\":28},{\"steps_id\":386,\"parent_id\":385,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 05:50:14\",\"active\":0,\"admin_id\":28},{\"steps_id\":387,\"parent_id\":386,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"font-size\",\"value_old\":\"21\",\"value\":\"18\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 05:50:29\",\"active\":0,\"admin_id\":28},{\"steps_id\":388,\"parent_id\":387,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"font-weight\",\"value\":\"400\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 05:50:41\",\"active\":0,\"admin_id\":28},{\"steps_id\":410,\"parent_id\":388,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .points\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 06:03:08\",\"active\":0,\"admin_id\":28},{\"steps_id\":411,\"parent_id\":410,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 06:03:08\",\"active\":0,\"admin_id\":28},{\"steps_id\":412,\"parent_id\":411,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665983279.1518\",\"block_name\":\"116236\",\"page_name\":null,\"widget_name\":\"cart\\\\OrderTotal\",\"sort_order\":0},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 06:08:00\",\"active\":0,\"admin_id\":28},{\"steps_id\":413,\"parent_id\":412,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665983279.1518\",\"box_id\":\"229886\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"style_class\",\"setting_value\":\"top-totals\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665983279.1518\",\"theme_name\":\"deals\"}],\"box_settings_old\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 06:08:16\",\"active\":0,\"admin_id\":28},{\"steps_id\":414,\"parent_id\":413,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116240\",\"box_id\":\"191769\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"style_class\",\"setting_value\":\"bottom-totals\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116240\",\"theme_name\":\"deals\"}],\"box_settings_old\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 06:08:39\",\"active\":0,\"admin_id\":28},{\"steps_id\":415,\"parent_id\":414,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"191770\",\"microtime\":\"116241\",\"block_name\":\"116236\",\"sort_order\":1},{\"id\":\"229886\",\"microtime\":\"1665983279.1518\",\"block_name\":\"116236\",\"sort_order\":2},{\"id\":\"191766\",\"microtime\":\"116237\",\"block_name\":\"116236\",\"sort_order\":3}],\"positions_old\":[{\"id\":\"191770\",\"block_name\":\"116236\",\"sort_order\":\"1\",\"microtime\":\"116241\"},{\"id\":\"229886\",\"block_name\":\"116236\",\"sort_order\":\"0\",\"microtime\":\"1665983279.1518\"},{\"id\":\"191766\",\"block_name\":\"116236\",\"sort_order\":\"2\",\"microtime\":\"116237\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 06:08:44\",\"active\":0,\"admin_id\":28},{\"steps_id\":416,\"parent_id\":415,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"191759\",\"microtime\":\"116230\",\"block_name\":\"116237\",\"sort_order\":1},{\"id\":\"191769\",\"microtime\":\"116240\",\"block_name\":\"116237\",\"sort_order\":2},{\"id\":\"191768\",\"microtime\":\"116239\",\"block_name\":\"116237\",\"sort_order\":3},{\"id\":\"191767\",\"microtime\":\"116238\",\"block_name\":\"116237\",\"sort_order\":4}],\"positions_old\":[{\"id\":\"191759\",\"block_name\":\"116229\",\"sort_order\":\"1\",\"microtime\":\"116230\"},{\"id\":\"191769\",\"block_name\":\"116237\",\"sort_order\":\"1\",\"microtime\":\"116240\"},{\"id\":\"191768\",\"block_name\":\"116237\",\"sort_order\":\"2\",\"microtime\":\"116239\"},{\"id\":\"191767\",\"block_name\":\"116237\",\"sort_order\":\"4\",\"microtime\":\"116238\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 06:08:56\",\"active\":0,\"admin_id\":28},{\"steps_id\":417,\"parent_id\":416,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"229886\",\"microtime\":\"1665983279.1518\",\"block_name\":\"116237\",\"sort_order\":1},{\"id\":\"191759\",\"microtime\":\"116230\",\"block_name\":\"116237\",\"sort_order\":2},{\"id\":\"191769\",\"microtime\":\"116240\",\"block_name\":\"116237\",\"sort_order\":3},{\"id\":\"191768\",\"microtime\":\"116239\",\"block_name\":\"116237\",\"sort_order\":4},{\"id\":\"191767\",\"microtime\":\"116238\",\"block_name\":\"116237\",\"sort_order\":5}],\"positions_old\":[{\"id\":\"229886\",\"block_name\":\"116236\",\"sort_order\":\"2\",\"microtime\":\"1665983279.1518\"},{\"id\":\"191759\",\"block_name\":\"116237\",\"sort_order\":\"1\",\"microtime\":\"116230\"},{\"id\":\"191769\",\"block_name\":\"116237\",\"sort_order\":\"2\",\"microtime\":\"116240\"},{\"id\":\"191768\",\"block_name\":\"116237\",\"sort_order\":\"3\",\"microtime\":\"116239\"},{\"id\":\"191767\",\"block_name\":\"116237\",\"sort_order\":\"4\",\"microtime\":\"116238\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 06:09:11\",\"active\":0,\"admin_id\":28},{\"steps_id\":418,\"parent_id\":417,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"191759\",\"microtime\":\"116230\",\"block_name\":\"116229\",\"sort_order\":1}],\"positions_old\":[{\"id\":\"191759\",\"block_name\":\"116237\",\"sort_order\":\"2\",\"microtime\":\"116230\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 06:09:24\",\"active\":0,\"admin_id\":28},{\"steps_id\":419,\"parent_id\":418,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1665983279.1518\",\"block_name\":\"116237\",\"widget_name\":\"cart\\\\OrderTotal\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":[{\"microtime\":\"1665983279.1518\",\"setting_name\":\"style_class\",\"setting_value\":\"top-totals\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[{\"id\":1635965,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636236,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636248,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636300,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636449,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636528,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636974,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636992,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1637039,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1637047,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1637051,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1637186,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"}]},\"translation\":[],\"box_id\":\"229886\",\"siblings\":[{\"id\":191767,\"microtime\":\"116238\",\"theme_name\":\"deals\",\"block_name\":\"block-191766\",\"widget_name\":\"Image\",\"widget_params\":\"\",\"sort_order\":5},{\"id\":191768,\"microtime\":\"116239\",\"theme_name\":\"deals\",\"block_name\":\"block-191766\",\"widget_name\":\"cart\\\\CheckoutBtn\",\"widget_params\":\"\",\"sort_order\":4},{\"id\":191769,\"microtime\":\"116240\",\"theme_name\":\"deals\",\"block_name\":\"block-191766\",\"widget_name\":\"cart\\\\OrderTotal\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":229886,\"microtime\":\"1665983279.1518\",\"theme_name\":\"deals\",\"block_name\":\"block-191766\",\"widget_name\":\"cart\\\\OrderTotal\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 06:09:28\",\"active\":0,\"admin_id\":28},{\"steps_id\":421,\"parent_id\":420,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .checkout-cart-listing.main-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .checkout-cart-listing.main-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .checkout-cart-listing.main-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .checkout-cart-listing.main-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-checkout-index .checkout-cart-listing.main-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 06:10:52\",\"active\":0,\"admin_id\":28},{\"steps_id\":422,\"parent_id\":421,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-17 06:10:53\",\"active\":0,\"admin_id\":28},{\"steps_id\":445,\"parent_id\":422,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"191759\",\"microtime\":\"116230\",\"block_name\":\"116237\",\"sort_order\":1},{\"id\":\"191769\",\"microtime\":\"116240\",\"block_name\":\"116237\",\"sort_order\":2},{\"id\":\"191768\",\"microtime\":\"116239\",\"block_name\":\"116237\",\"sort_order\":3},{\"id\":\"191767\",\"microtime\":\"116238\",\"block_name\":\"116237\",\"sort_order\":4}],\"positions_old\":[{\"id\":\"191759\",\"block_name\":\"116229\",\"sort_order\":\"1\",\"microtime\":\"116230\"},{\"id\":\"191769\",\"block_name\":\"116237\",\"sort_order\":\"3\",\"microtime\":\"116240\"},{\"id\":\"191768\",\"block_name\":\"116237\",\"sort_order\":\"4\",\"microtime\":\"116239\"},{\"id\":\"191767\",\"block_name\":\"116237\",\"sort_order\":\"5\",\"microtime\":\"116238\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:05:07\",\"active\":0,\"admin_id\":45},{\"steps_id\":447,\"parent_id\":446,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"191760\",\"microtime\":\"1639491248\",\"block_name\":\"116229\",\"sort_order\":1}],\"positions_old\":[{\"id\":\"191760\",\"block_name\":\"116229-2\",\"sort_order\":\"2\",\"microtime\":\"1639491248\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:05:25\",\"active\":0,\"admin_id\":45},{\"steps_id\":448,\"parent_id\":447,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1666159553.7755\",\"block_name\":\"116237\",\"page_name\":null,\"widget_name\":\"cart\\\\OrderTotal\",\"sort_order\":0},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:05:53\",\"active\":0,\"admin_id\":45},{\"steps_id\":449,\"parent_id\":448,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1666159553.7755\",\"box_id\":\"234718\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"style_class\",\"setting_value\":\"top-totals\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1666159553.7755\",\"theme_name\":\"deals\"}],\"box_settings_old\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:06:35\",\"active\":0,\"admin_id\":45},{\"steps_id\":451,\"parent_id\":450,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .bottom-totals .price-box .icon\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .bottom-totals .price-box .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:07:36\",\"active\":0,\"admin_id\":45},{\"steps_id\":452,\"parent_id\":451,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:07:37\",\"active\":0,\"admin_id\":45},{\"steps_id\":453,\"parent_id\":452,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .top-totals .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:09:38\",\"active\":0,\"admin_id\":45},{\"steps_id\":454,\"parent_id\":453,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:09:39\",\"active\":0,\"admin_id\":45},{\"steps_id\":455,\"parent_id\":454,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .bottom-totals .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:10:25\",\"active\":0,\"admin_id\":45},{\"steps_id\":456,\"parent_id\":455,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:10:26\",\"active\":0,\"admin_id\":45},{\"steps_id\":457,\"parent_id\":456,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .inp\",\"attribute\":\"display\",\"value_old\":\"flex\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-bottom\",\"value_old\":\"15\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"border-bottom-color\",\"value\":\"#e2e2e2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"600\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"background-color\",\"value\":\"#eeeeee\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-top\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"margin-bottom\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"400\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"0.75\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f107\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-family\",\"value\":\"\'fontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-left\",\"value\":\"10\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp\",\"attribute\":\"margin-top\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:11:40\",\"active\":0,\"admin_id\":45},{\"steps_id\":458,\"parent_id\":457,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:11:41\",\"active\":0,\"admin_id\":45},{\"steps_id\":459,\"parent_id\":458,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"background-color\",\"value_old\":\"#eeeeee\",\"value\":\"#e2e2e2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:12:35\",\"active\":0,\"admin_id\":45},{\"steps_id\":460,\"parent_id\":459,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:12:36\",\"active\":0,\"admin_id\":45},{\"steps_id\":461,\"parent_id\":460,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116230\",\"box_id\":\"191759\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116230\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"116230\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"116230\",\"theme_name\":\"deals\"}],\"box_settings_old\":[{\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"24\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w768\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:12:46\",\"active\":0,\"admin_id\":45},{\"steps_id\":463,\"parent_id\":462,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f108\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:14:07\",\"active\":0,\"admin_id\":45},{\"steps_id\":464,\"parent_id\":463,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:14:08\",\"active\":0,\"admin_id\":45},{\"steps_id\":465,\"parent_id\":464,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value_old\":\"\\\\f107\",\"value\":\"\\\\f106\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:14:20\",\"active\":0,\"admin_id\":45},{\"steps_id\":466,\"parent_id\":465,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value_old\":\"\\\\f106\",\"value\":\"\\\\f107\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value_old\":\"\\\\f108\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:14:26\",\"active\":0,\"admin_id\":45},{\"steps_id\":467,\"parent_id\":466,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".order-summary .bottom-totals .price-row\",\"attribute\":\"display\",\"value_old\":\"flex\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:15:23\",\"active\":0,\"admin_id\":45},{\"steps_id\":468,\"parent_id\":467,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:15:24\",\"active\":0,\"admin_id\":45},{\"steps_id\":469,\"parent_id\":468,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .top-totals .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:16:04\",\"active\":0,\"admin_id\":45},{\"steps_id\":470,\"parent_id\":469,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:16:05\",\"active\":0,\"admin_id\":45},{\"steps_id\":471,\"parent_id\":470,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".order-summary .price-box\",\"attribute\":\"margin-bottom\",\"value_old\":\"20\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:16:35\",\"active\":0,\"admin_id\":45},{\"steps_id\":472,\"parent_id\":471,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:16:36\",\"active\":0,\"admin_id\":45},{\"steps_id\":473,\"parent_id\":472,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:16:49\",\"active\":0,\"admin_id\":45},{\"steps_id\":474,\"parent_id\":473,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"margin-bottom\",\"value_old\":\"20\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:17:03\",\"active\":0,\"admin_id\":45},{\"steps_id\":475,\"parent_id\":474,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:17:04\",\"active\":0,\"admin_id\":45},{\"steps_id\":476,\"parent_id\":475,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1639476084\",\"block_name\":\"1644251633-2\",\"widget_name\":\"cart\\\\FreeDelivery\",\"widget_params\":\"\",\"sort_order\":\"2\",\"settings\":[{\"microtime\":\"1639476084\",\"setting_name\":\"text-align\",\"setting_value\":\"right\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"191764\",\"siblings\":[{\"id\":191764,\"microtime\":\"1639476084\",\"theme_name\":\"deals\",\"block_name\":\"block-191761-2\",\"widget_name\":\"cart\\\\FreeDelivery\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:17:59\",\"active\":0,\"admin_id\":45},{\"steps_id\":477,\"parent_id\":476,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"191762\",\"microtime\":\"116232\",\"block_name\":\"1644251633-2\",\"sort_order\":1}],\"positions_old\":[{\"id\":\"191762\",\"block_name\":\"1644251633\",\"sort_order\":\"1\",\"microtime\":\"116232\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:18:03\",\"active\":0,\"admin_id\":45},{\"steps_id\":478,\"parent_id\":477,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"191760\",\"microtime\":\"1639491248\",\"block_name\":\"1644251633\",\"sort_order\":1}],\"positions_old\":[{\"id\":\"191760\",\"block_name\":\"116229\",\"sort_order\":\"1\",\"microtime\":\"1639491248\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:18:05\",\"active\":0,\"admin_id\":45},{\"steps_id\":479,\"parent_id\":478,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"116229\",\"block_name\":\"1644252514\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":[{\"microtime\":\"116229\",\"setting_name\":\"block_type\",\"setting_value\":\"2\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116229\",\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116229\",\"setting_name\":\"schema\",\"setting_value\":\"2-2\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"116229\",\"setting_name\":\"padding-top\",\"setting_value\":\"10\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116229\",\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"191758\",\"siblings\":[{\"id\":191758,\"microtime\":\"116229\",\"theme_name\":\"deals\",\"block_name\":\"block-191757\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":191761,\"microtime\":\"1644251633\",\"theme_name\":\"deals\",\"block_name\":\"block-191757\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:18:08\",\"active\":0,\"admin_id\":45},{\"steps_id\":481,\"parent_id\":480,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:23:25\",\"active\":0,\"admin_id\":45},{\"steps_id\":482,\"parent_id\":481,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .inp\",\"attribute\":\"display\",\"value_old\":\"none\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-bottom\",\"value_old\":\"0\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"background-color\",\"value\":\"#e2e2e2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-top\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"margin-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"400\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"0.75\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f107\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-family\",\"value\":\"\'fontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-left\",\"value\":\"10\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp\",\"attribute\":\"margin-top\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"600\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"border-bottom-color\",\"value\":\"#e2e2e2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:25:48\",\"active\":0,\"admin_id\":45},{\"steps_id\":483,\"parent_id\":482,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:25:48\",\"active\":0,\"admin_id\":45},{\"steps_id\":484,\"parent_id\":483,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value_old\":\"none\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .price-box\",\"attribute\":\"margin-bottom\",\"value_old\":\"10\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"line-height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"line_height_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"display\",\"value\":\"block\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .headings\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .headings\",\"attribute\":\"grid-template-columns\",\"value\":\"3fr 1fr 1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"3fr 1fr 1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"grid-column\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price\",\"attribute\":\"grid-column\",\"value\":\"3\\/4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price\",\"attribute\":\"grid-row\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty\",\"attribute\":\"grid-column\",\"value\":\"2\\/3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty\",\"attribute\":\"grid-row\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item > div.image\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .price\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing.type-2 .image\",\"attribute\":\"grid-column\",\"value\":\"1 \\/ 3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing.type-2 .image\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .checkout-cart-listing\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .checkout-cart-listing\",\"attribute\":\"border-bottom-color\",\"value\":\"#e2e2e2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-rows\",\"value\":\"1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .checkout-cart-listing.main-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"1fr\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-listing .item .points\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .bottom-totals .price-box .icon\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .bottom-totals .price-box .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .top-totals .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .bottom-totals .price-row\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .top-totals .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:26:33\",\"active\":0,\"admin_id\":45},{\"steps_id\":485,\"parent_id\":484,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:26:34\",\"active\":0,\"admin_id\":45},{\"steps_id\":486,\"parent_id\":485,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value_old\":\"flex\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .price-box\",\"attribute\":\"margin-bottom\",\"value_old\":\"20\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .bottom-totals .price-box .icon\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .bottom-totals .price-box .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .bottom-totals .price-row\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .checkout-cart-listing\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .checkout-cart-listing\",\"attribute\":\"border-bottom-color\",\"value\":\"#e2e2e2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .checkout-cart-listing.main-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"line-height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"line_height_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"display\",\"value\":\"block\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .top-totals .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .top-totals .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .headings\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .headings\",\"attribute\":\"grid-template-columns\",\"value\":\"3fr 1fr 1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"3fr 1fr 1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-rows\",\"value\":\"1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"grid-column\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .points\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price\",\"attribute\":\"grid-column\",\"value\":\"3\\/4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price\",\"attribute\":\"grid-row\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty\",\"attribute\":\"grid-column\",\"value\":\"2\\/3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty\",\"attribute\":\"grid-row\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item > div.image\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .price\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing.type-2 .image\",\"attribute\":\"grid-column\",\"value\":\"1 \\/ 3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing.type-2 .image\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"deals\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"1fr\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:26:55\",\"active\":0,\"admin_id\":45},{\"steps_id\":487,\"parent_id\":486,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:26:56\",\"active\":0,\"admin_id\":45},{\"steps_id\":488,\"parent_id\":487,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .bottom-totals .price-row\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:27:13\",\"active\":0,\"admin_id\":45},{\"steps_id\":489,\"parent_id\":488,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:28:37\",\"active\":0,\"admin_id\":45},{\"steps_id\":490,\"parent_id\":489,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:28:38\",\"active\":0,\"admin_id\":45},{\"steps_id\":491,\"parent_id\":490,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .bottom-totals .price-box .icon\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .bottom-totals .price-box .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:29:27\",\"active\":0,\"admin_id\":45},{\"steps_id\":492,\"parent_id\":491,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"218777\",\"microtime\":\"1658412724.2426\",\"block_name\":\"1643218297\",\"sort_order\":1},{\"id\":\"191759\",\"microtime\":\"116230\",\"block_name\":\"1643218297\",\"sort_order\":2},{\"id\":\"191757\",\"microtime\":\"1644252514\",\"block_name\":\"1643218297\",\"sort_order\":3}],\"positions_old\":[{\"id\":\"218777\",\"block_name\":\"1643218297\",\"sort_order\":\"0\",\"microtime\":\"1658412724.2426\"},{\"id\":\"191759\",\"block_name\":\"116237\",\"sort_order\":\"1\",\"microtime\":\"116230\"},{\"id\":\"191757\",\"block_name\":\"1643218297\",\"sort_order\":\"4\",\"microtime\":\"1644252514\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:29:35\",\"active\":0,\"admin_id\":45},{\"steps_id\":493,\"parent_id\":492,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1666160988.5573\",\"block_name\":\"1644251633\",\"page_name\":null,\"widget_name\":\"BlockBox\",\"sort_order\":0},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:29:48\",\"active\":0,\"admin_id\":45},{\"steps_id\":494,\"parent_id\":493,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1666159553.7755\",\"block_name\":\"116237\",\"widget_name\":\"cart\\\\OrderTotal\",\"widget_params\":\"\",\"sort_order\":\"0\",\"settings\":[{\"microtime\":\"1666159553.7755\",\"setting_name\":\"style_class\",\"setting_value\":\"top-totals\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[{\"id\":1635965,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636236,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636248,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636300,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636449,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636528,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636974,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1636992,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1637039,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1637047,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1637051,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"},{\"id\":1637186,\"theme_name\":\"deals\",\"selector\":\".w-cart-order-total.box\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-order-total\"}]},\"translation\":[],\"box_id\":\"234718\",\"siblings\":[{\"id\":191767,\"microtime\":\"116238\",\"theme_name\":\"deals\",\"block_name\":\"block-191766\",\"widget_name\":\"Image\",\"widget_params\":\"\",\"sort_order\":4},{\"id\":191768,\"microtime\":\"116239\",\"theme_name\":\"deals\",\"block_name\":\"block-191766\",\"widget_name\":\"cart\\\\CheckoutBtn\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":191769,\"microtime\":\"116240\",\"theme_name\":\"deals\",\"block_name\":\"block-191766\",\"widget_name\":\"cart\\\\OrderTotal\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":234718,\"microtime\":\"1666159553.7755\",\"theme_name\":\"deals\",\"block_name\":\"block-191766\",\"widget_name\":\"cart\\\\OrderTotal\",\"widget_params\":\"\",\"sort_order\":0}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:30:06\",\"active\":0,\"admin_id\":45},{\"steps_id\":496,\"parent_id\":495,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"234719\",\"microtime\":\"1666160988.5573\",\"block_name\":\"1644252514\",\"sort_order\":1},{\"id\":\"191761\",\"microtime\":\"1644251633\",\"block_name\":\"1644252514\",\"sort_order\":2}],\"positions_old\":[{\"id\":\"234719\",\"block_name\":\"1644251633\",\"sort_order\":\"0\",\"microtime\":\"1666160988.5573\"},{\"id\":\"191761\",\"block_name\":\"1644252514\",\"sort_order\":\"2\",\"microtime\":\"1644251633\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:31:25\",\"active\":0,\"admin_id\":45},{\"steps_id\":497,\"parent_id\":496,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1666160988.5573\",\"box_id\":\"234719\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1666160988.5573\",\"theme_name\":\"deals\"}],\"box_settings_old\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:31:28\",\"active\":0,\"admin_id\":45},{\"steps_id\":498,\"parent_id\":497,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"191759\",\"microtime\":\"116230\",\"block_name\":\"1666160988.5573\",\"sort_order\":1}],\"positions_old\":[{\"id\":\"191759\",\"block_name\":\"1643218297\",\"sort_order\":\"2\",\"microtime\":\"116230\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 07:31:35\",\"active\":0,\"admin_id\":45},{\"steps_id\":500,\"parent_id\":499,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"218776\",\"microtime\":\"1658412409.6985\",\"block_name\":\"116218\",\"sort_order\":1},{\"id\":\"191743\",\"microtime\":\"116220\",\"block_name\":\"116218\",\"sort_order\":2},{\"id\":\"191742\",\"microtime\":\"116219\",\"block_name\":\"116218\",\"sort_order\":3},{\"id\":\"191757\",\"microtime\":\"1644252514\",\"block_name\":\"116218\",\"sort_order\":4}],\"positions_old\":[{\"id\":\"218776\",\"block_name\":\"116218\",\"sort_order\":\"0\",\"microtime\":\"1658412409.6985\"},{\"id\":\"191743\",\"block_name\":\"116218\",\"sort_order\":\"4\",\"microtime\":\"116220\"},{\"id\":\"191742\",\"block_name\":\"116218\",\"sort_order\":\"5\",\"microtime\":\"116219\"},{\"id\":\"191757\",\"block_name\":\"1643218297\",\"sort_order\":\"3\",\"microtime\":\"1644252514\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 08:48:44\",\"active\":0,\"admin_id\":45},{\"steps_id\":502,\"parent_id\":501,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"191741\",\"microtime\":\"116218\",\"block_name\":\"116214\",\"sort_order\":1},{\"id\":\"191757\",\"microtime\":\"1644252514\",\"block_name\":\"116214\",\"sort_order\":2},{\"id\":\"191755\",\"microtime\":\"1643218297\",\"block_name\":\"116214\",\"sort_order\":3},{\"id\":\"191754\",\"microtime\":\"1639494018\",\"block_name\":\"116214\",\"sort_order\":4},{\"id\":\"191748\",\"microtime\":\"116224\",\"block_name\":\"116214\",\"sort_order\":5},{\"id\":\"191738\",\"microtime\":\"116215\",\"block_name\":\"116214\",\"sort_order\":6},{\"id\":\"191751\",\"microtime\":\"116233\",\"block_name\":\"116214\",\"sort_order\":7}],\"positions_old\":[{\"id\":\"191741\",\"block_name\":\"116214\",\"sort_order\":\"1\",\"microtime\":\"116218\"},{\"id\":\"191757\",\"block_name\":\"116218\",\"sort_order\":\"4\",\"microtime\":\"1644252514\"},{\"id\":\"191755\",\"block_name\":\"116214\",\"sort_order\":\"2\",\"microtime\":\"1643218297\"},{\"id\":\"191754\",\"block_name\":\"116214\",\"sort_order\":\"4\",\"microtime\":\"1639494018\"},{\"id\":\"191748\",\"block_name\":\"116214\",\"sort_order\":\"5\",\"microtime\":\"116224\"},{\"id\":\"191738\",\"block_name\":\"116214\",\"sort_order\":\"6\",\"microtime\":\"116215\"},{\"id\":\"191751\",\"block_name\":\"116214\",\"sort_order\":\"7\",\"microtime\":\"116233\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 08:48:51\",\"active\":0,\"admin_id\":45},{\"steps_id\":503,\"parent_id\":502,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1643218297\",\"block_name\":\"116214\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"3\",\"settings\":[{\"microtime\":\"1643218297\",\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1643218297\",\"setting_name\":\"style_class\",\"setting_value\":\"closeable-box\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1643218297\",\"setting_name\":\"margin-bottom\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":[],\"sub_1\":[{\"microtime\":\"1658412724.2426\",\"block_name\":\"block-191755\",\"widget_name\":\"Html_box\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":[{\"microtime\":\"1658412724.2426\",\"setting_name\":\"text\",\"setting_value\":\"<div class=\\\"heading-3\\\">##TEXT_SAVINGS##<\\/div>\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1658412724.2426\",\"setting_name\":\"style_class\",\"setting_value\":\"savings-ico closeable-heading closeable-event\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":{\"main\":{\"TEXT_SAVINGS\":{\"en\":\"Savings\"}}}}],\"box_id\":\"191755\",\"siblings\":[{\"id\":191738,\"microtime\":\"116215\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"BlockBox\",\"widget_params\":\"cart-content\",\"sort_order\":6},{\"id\":191741,\"microtime\":\"116218\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"BlockBox\",\"widget_params\":\"cart-top\",\"sort_order\":1},{\"id\":191748,\"microtime\":\"116224\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"BlockBox\",\"widget_params\":\"cart-content\",\"sort_order\":5},{\"id\":191751,\"microtime\":\"116233\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"BlockBox\",\"widget_params\":\"cart-bottom\",\"sort_order\":7},{\"id\":191754,\"microtime\":\"1639494018\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"cart\\\\DependedProducts\",\"widget_params\":\"8\",\"sort_order\":4},{\"id\":191755,\"microtime\":\"1643218297\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":191757,\"microtime\":\"1644252514\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 08:49:06\",\"active\":0,\"admin_id\":45},{\"steps_id\":504,\"parent_id\":503,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"191741\",\"microtime\":\"116218\",\"block_name\":\"116214\",\"sort_order\":1},{\"id\":\"191757\",\"microtime\":\"1644252514\",\"block_name\":\"116214\",\"sort_order\":2},{\"id\":\"191754\",\"microtime\":\"1639494018\",\"block_name\":\"116214\",\"sort_order\":3},{\"id\":\"191748\",\"microtime\":\"116224\",\"block_name\":\"116214\",\"sort_order\":4},{\"id\":\"191738\",\"microtime\":\"116215\",\"block_name\":\"116214\",\"sort_order\":5},{\"id\":\"191753\",\"microtime\":\"116235\",\"block_name\":\"116214\",\"sort_order\":6},{\"id\":\"191751\",\"microtime\":\"116233\",\"block_name\":\"116214\",\"sort_order\":7}],\"positions_old\":[{\"id\":\"191741\",\"block_name\":\"116214\",\"sort_order\":\"1\",\"microtime\":\"116218\"},{\"id\":\"191757\",\"block_name\":\"116214\",\"sort_order\":\"2\",\"microtime\":\"1644252514\"},{\"id\":\"191754\",\"block_name\":\"116214\",\"sort_order\":\"4\",\"microtime\":\"1639494018\"},{\"id\":\"191748\",\"block_name\":\"116214\",\"sort_order\":\"5\",\"microtime\":\"116224\"},{\"id\":\"191738\",\"block_name\":\"116214\",\"sort_order\":\"6\",\"microtime\":\"116215\"},{\"id\":\"191753\",\"block_name\":\"116233\",\"sort_order\":\"2\",\"microtime\":\"116235\"},{\"id\":\"191751\",\"block_name\":\"116214\",\"sort_order\":\"7\",\"microtime\":\"116233\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 08:49:22\",\"active\":0,\"admin_id\":45},{\"steps_id\":505,\"parent_id\":504,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"116233\",\"block_name\":\"116214\",\"widget_name\":\"BlockBox\",\"widget_params\":\"cart-bottom\",\"sort_order\":\"7\",\"settings\":[{\"microtime\":\"116233\",\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116233\",\"setting_name\":\"margin-bottom\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116233\",\"setting_name\":\"style_class\",\"setting_value\":\"closeable-box\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116233\",\"setting_name\":\"display\",\"setting_value\":\"none\",\"language_id\":0,\"visibility\":\"w992\"},{\"microtime\":\"116233\",\"setting_name\":\"display\",\"setting_value\":\"none\",\"language_id\":0,\"visibility\":\"w992\"}],\"css\":{\"current\":[]},\"translation\":[],\"sub_1\":[{\"microtime\":\"116234\",\"block_name\":\"block-191751\",\"widget_name\":\"Html_box\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":[{\"microtime\":\"116234\",\"setting_name\":\"text\",\"setting_value\":\"<div class=\\\"heading-3\\\">##TEXT_SHIPPING##<\\/div>\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116234\",\"setting_name\":\"style_class\",\"setting_value\":\"shipping-ico closeable-heading closeable-event\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":{\"main\":{\"TEXT_SHIPPING\":{\"en\":\"Shipping\"}}}}],\"box_id\":\"191751\",\"siblings\":[{\"id\":191738,\"microtime\":\"116215\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"BlockBox\",\"widget_params\":\"cart-content\",\"sort_order\":5},{\"id\":191741,\"microtime\":\"116218\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"BlockBox\",\"widget_params\":\"cart-top\",\"sort_order\":1},{\"id\":191748,\"microtime\":\"116224\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"BlockBox\",\"widget_params\":\"cart-content\",\"sort_order\":4},{\"id\":191751,\"microtime\":\"116233\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"BlockBox\",\"widget_params\":\"cart-bottom\",\"sort_order\":7},{\"id\":191753,\"microtime\":\"116235\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"cart\\\\ShippingEstimator\",\"widget_params\":\"\",\"sort_order\":6},{\"id\":191754,\"microtime\":\"1639494018\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"cart\\\\DependedProducts\",\"widget_params\":\"8\",\"sort_order\":3},{\"id\":191757,\"microtime\":\"1644252514\",\"theme_name\":\"deals\",\"block_name\":\"block-191737\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-19 08:49:24\",\"active\":0,\"admin_id\":45},{\"steps_id\":507,\"parent_id\":506,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"191759\",\"microtime\":\"116230\",\"block_name\":\"116237\",\"sort_order\":1},{\"id\":\"191769\",\"microtime\":\"116240\",\"block_name\":\"116237\",\"sort_order\":2},{\"id\":\"191768\",\"microtime\":\"116239\",\"block_name\":\"116237\",\"sort_order\":3},{\"id\":\"191767\",\"microtime\":\"116238\",\"block_name\":\"116237\",\"sort_order\":4}],\"positions_old\":[{\"id\":\"191759\",\"block_name\":\"1666160988.5573\",\"sort_order\":\"1\",\"microtime\":\"116230\"},{\"id\":\"191769\",\"block_name\":\"116237\",\"sort_order\":\"2\",\"microtime\":\"116240\"},{\"id\":\"191768\",\"block_name\":\"116237\",\"sort_order\":\"3\",\"microtime\":\"116239\"},{\"id\":\"191767\",\"block_name\":\"116237\",\"sort_order\":\"4\",\"microtime\":\"116238\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:31:25\",\"active\":0,\"admin_id\":28},{\"steps_id\":509,\"parent_id\":508,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1666333898.753\",\"block_name\":\"116236\",\"page_name\":null,\"widget_name\":\"cart\\\\OrderTotal\",\"sort_order\":0},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:31:38\",\"active\":0,\"admin_id\":28},{\"steps_id\":510,\"parent_id\":509,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"234720\",\"microtime\":\"1666333898.753\",\"block_name\":\"116237\",\"sort_order\":1},{\"id\":\"191759\",\"microtime\":\"116230\",\"block_name\":\"116237\",\"sort_order\":2},{\"id\":\"191769\",\"microtime\":\"116240\",\"block_name\":\"116237\",\"sort_order\":3},{\"id\":\"191768\",\"microtime\":\"116239\",\"block_name\":\"116237\",\"sort_order\":4},{\"id\":\"191767\",\"microtime\":\"116238\",\"block_name\":\"116237\",\"sort_order\":5}],\"positions_old\":[{\"id\":\"234720\",\"block_name\":\"116236\",\"sort_order\":\"0\",\"microtime\":\"1666333898.753\"},{\"id\":\"191759\",\"block_name\":\"116237\",\"sort_order\":\"1\",\"microtime\":\"116230\"},{\"id\":\"191769\",\"block_name\":\"116237\",\"sort_order\":\"2\",\"microtime\":\"116240\"},{\"id\":\"191768\",\"block_name\":\"116237\",\"sort_order\":\"3\",\"microtime\":\"116239\"},{\"id\":\"191767\",\"block_name\":\"116237\",\"sort_order\":\"4\",\"microtime\":\"116238\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:31:46\",\"active\":0,\"admin_id\":28},{\"steps_id\":511,\"parent_id\":510,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1666333898.753\",\"box_id\":\"234720\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"style_class\",\"setting_value\":\"top-totals\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1666333898.753\",\"theme_name\":\"deals\"}],\"box_settings_old\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:31:59\",\"active\":0,\"admin_id\":28},{\"steps_id\":513,\"parent_id\":512,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .inp\",\"attribute\":\"display\",\"value_old\":\"flex\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-bottom\",\"value_old\":\"15\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"600\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"border-bottom-color\",\"value\":\"#e2e2e2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"background-color\",\"value\":\"#e2e2e2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-top\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"margin-bottom\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp\",\"attribute\":\"margin-top\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"400\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"0.75\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f107\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-family\",\"value\":\"\'fontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-left\",\"value\":\"10\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:36:08\",\"active\":0,\"admin_id\":28},{\"steps_id\":514,\"parent_id\":513,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:36:09\",\"active\":0,\"admin_id\":28},{\"steps_id\":516,\"parent_id\":515,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1666160988.5573\",\"block_name\":\"1644252514\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":[{\"microtime\":\"1666160988.5573\",\"setting_name\":\"block_type\",\"setting_value\":\"2\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"234719\",\"siblings\":[{\"id\":191761,\"microtime\":\"1644251633\",\"theme_name\":\"deals\",\"block_name\":\"block-191757\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":234719,\"microtime\":\"1666160988.5573\",\"theme_name\":\"deals\",\"block_name\":\"block-191757\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:36:46\",\"active\":0,\"admin_id\":28},{\"steps_id\":518,\"parent_id\":517,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon + .bottom-totals .icon\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:38:08\",\"active\":0,\"admin_id\":28},{\"steps_id\":519,\"parent_id\":518,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon + .bottom-totals .icon\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:39:08\",\"active\":0,\"admin_id\":28},{\"steps_id\":520,\"parent_id\":519,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:39:09\",\"active\":0,\"admin_id\":28},{\"steps_id\":521,\"parent_id\":520,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".p-shopping-cart-index .bottom-totals .icon\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-shopping-cart-index .bottom-totals .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:39:44\",\"active\":0,\"admin_id\":28},{\"steps_id\":522,\"parent_id\":521,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:39:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":523,\"parent_id\":522,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-shopping-cart-index .bottom-totals .icon\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"selector\":\".p-shopping-cart-index .bottom-totals .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".p-shopping-cart-index .order-summary .bottom-totals .icon\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-shopping-cart-index .order-summary .bottom-totals .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-shopping-cart-index .order-summary .price-row\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-shopping-cart-index .order-summary .price-row\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:40:54\",\"active\":0,\"admin_id\":28},{\"steps_id\":524,\"parent_id\":523,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:40:55\",\"active\":0,\"admin_id\":28},{\"steps_id\":525,\"parent_id\":524,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-shopping-cart-index .order-summary .price-row\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:41:26\",\"active\":0,\"admin_id\":28},{\"steps_id\":526,\"parent_id\":525,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".p-shopping-cart-index .order-summary .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:42:14\",\"active\":0,\"admin_id\":28},{\"steps_id\":527,\"parent_id\":526,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-shopping-cart-index .order-summary .price-row\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"selector\":\".p-shopping-cart-index .order-summary .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".p-shopping-cart-index .order-summary .bottom-totals .price-row\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"deals\",\"selector\":\".p-shopping-cart-index .order-summary .bottom-totals .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:42:40\",\"active\":0,\"admin_id\":28},{\"steps_id\":528,\"parent_id\":527,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:42:40\",\"active\":0,\"admin_id\":28},{\"steps_id\":529,\"parent_id\":528,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"margin-bottom\",\"value_old\":\"20\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:45:09\",\"active\":0,\"admin_id\":28},{\"steps_id\":530,\"parent_id\":529,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 07:45:09\",\"active\":0,\"admin_id\":28},{\"steps_id\":548,\"parent_id\":530,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 08:34:08\",\"active\":0,\"admin_id\":28},{\"steps_id\":550,\"parent_id\":549,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 08:34:09\",\"active\":0,\"admin_id\":28},{\"steps_id\":551,\"parent_id\":550,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 08:34:10\",\"active\":0,\"admin_id\":28},{\"steps_id\":552,\"parent_id\":551,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 08:35:15\",\"active\":0,\"admin_id\":28},{\"steps_id\":553,\"parent_id\":552,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-21 08:35:16\",\"active\":0,\"admin_id\":28},{\"steps_id\":602,\"parent_id\":553,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120945\",\"block_name\":\"116212\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1612736,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1620835,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1624620,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-navigation\",\"attribute\":\"margin-bottom\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1627858,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1629182,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1630496,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1631792,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"}]},\"translation\":[],\"box_id\":\"191771\",\"siblings\":[{\"id\":191737,\"microtime\":\"116214\",\"theme_name\":\"deals\",\"block_name\":\"block-191736\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":191771,\"microtime\":\"120945\",\"theme_name\":\"deals\",\"block_name\":\"block-191736\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-24 08:27:36\",\"active\":0,\"admin_id\":28},{\"steps_id\":604,\"parent_id\":603,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120945\",\"block_name\":\"116212\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1612736,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1620835,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1624620,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-navigation\",\"attribute\":\"margin-bottom\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1627858,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1629182,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1630496,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1631792,\"theme_name\":\"deals\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"}]},\"translation\":[],\"box_id\":\"191771\",\"siblings\":[{\"id\":191737,\"microtime\":\"116214\",\"theme_name\":\"deals\",\"block_name\":\"block-191736\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":191771,\"microtime\":\"120945\",\"theme_name\":\"deals\",\"block_name\":\"block-191736\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-24 08:27:38\",\"active\":0,\"admin_id\":28},{\"steps_id\":607,\"parent_id\":606,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120945\",\"block_name\":null,\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1917142,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1917215,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-li\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1918178,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .tab-li\",\"attribute\":\"border-bottom-width\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1918181,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-li\",\"attribute\":\"border-bottom-width\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1925478,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1926539,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"14\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1929421,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-navigation\",\"attribute\":\"margin-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1932737,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1934140,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1935530,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1936877,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"}]},\"translation\":[],\"box_id\":\"225216\",\"siblings\":[{\"id\":225184,\"microtime\":\"116214\",\"theme_name\":\"printshop\",\"block_name\":\"block-225183\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":225216,\"microtime\":\"120945\",\"theme_name\":\"printshop\",\"block_name\":\"block-225183\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-24 08:29:09\",\"active\":0,\"admin_id\":28},{\"steps_id\":616,\"parent_id\":609,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-shipping-estimator .left-area\",\"attribute\":\"float\",\"value\":\"none\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-shipping-estimator .left-area\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-shipping-estimator .left-area\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-shipping-estimator .right-area\",\"attribute\":\"float\",\"value\":\"none\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-shipping-estimator .right-area\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"},{\"theme_name\":\"deals\",\"selector\":\".w-cart-shipping-estimator .right-area\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-25 13:12:35\",\"active\":0,\"admin_id\":45},{\"steps_id\":618,\"parent_id\":617,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-25 13:13:25\",\"active\":0,\"admin_id\":45},{\"steps_id\":619,\"parent_id\":618,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-shipping-estimator .estimate-shipping .col-right > span\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-25 13:15:40\",\"active\":0,\"admin_id\":45},{\"steps_id\":620,\"parent_id\":619,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-shipping-estimator .shipping-estimator\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-25 13:17:50\",\"active\":0,\"admin_id\":45},{\"steps_id\":621,\"parent_id\":620,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116230\",\"box_id\":\"191759\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116230\",\"theme_name\":\"deals\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"116230\",\"theme_name\":\"deals\"}],\"box_settings_old\":[{\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w768\"}]},\"theme_name\":\"deals\",\"date_added\":\"2022-10-25 13:19:28\",\"active\":0,\"admin_id\":45}]','deals','2022-10-26 14:02:56',0,0,''),(2,0,'applyMigration','[{\"steps_id\":323,\"parent_id\":321,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120900\",\"block_name\":\"1644503846-2\",\"widget_name\":\"cart\\\\SubTotal\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1923987,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1926331,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .title\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1926332,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1926544,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .title, .w-cart-sub-total .price\",\"attribute\":\"font-size\",\"value\":\"21\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1927096,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .title\",\"attribute\":\"font-weight\",\"value\":\"500\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1927097,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"font-weight\",\"value\":\"500\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1929911,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-bottom\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1930557,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1931155,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1931761,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1939595,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"text-align\",\"value\":\"right\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1941870,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1941871,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price-row > div\",\"attribute\":\"width\",\"value\":\"50\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1942634,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1942635,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price-row > div\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"}]},\"translation\":[],\"box_id\":\"225197\",\"siblings\":[{\"id\":225197,\"microtime\":\"120900\",\"theme_name\":\"printshop\",\"block_name\":\"block-225195-2\",\"widget_name\":\"cart\\\\SubTotal\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":225198,\"microtime\":\"1639476084\",\"theme_name\":\"printshop\",\"block_name\":\"block-225195-2\",\"widget_name\":\"cart\\\\FreeDelivery\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:30:07\",\"active\":0,\"admin_id\":28},{\"steps_id\":325,\"parent_id\":324,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120900\",\"block_name\":\"1644503846-2\",\"widget_name\":\"cart\\\\SubTotal\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1923987,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1926331,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .title\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1926332,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1926544,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .title, .w-cart-sub-total .price\",\"attribute\":\"font-size\",\"value\":\"21\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1927096,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .title\",\"attribute\":\"font-weight\",\"value\":\"500\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1927097,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"font-weight\",\"value\":\"500\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1929911,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-bottom\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1930557,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1931155,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1931761,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1939595,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"text-align\",\"value\":\"right\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1941870,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1941871,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price-row > div\",\"attribute\":\"width\",\"value\":\"50\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1942634,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1942635,\"theme_name\":\"printshop\",\"selector\":\".w-cart-sub-total .price-row > div\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"}]},\"translation\":[],\"box_id\":\"225197\",\"siblings\":[{\"id\":225197,\"microtime\":\"120900\",\"theme_name\":\"printshop\",\"block_name\":\"block-225195-2\",\"widget_name\":\"cart\\\\SubTotal\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":225198,\"microtime\":\"1639476084\",\"theme_name\":\"printshop\",\"block_name\":\"block-225195-2\",\"widget_name\":\"cart\\\\FreeDelivery\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:30:10\",\"active\":0,\"admin_id\":28},{\"steps_id\":328,\"parent_id\":327,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".order-summary .cart-listing.w-cart-listing.type-2.summary-listing\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .cart-listing.w-cart-listing.type-2.summary-listing\",\"attribute\":\"border-bottom-color\",\"value\":\"#e0e0e0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .checkout-cart-listing.main-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"line-height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"line_height_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"display\",\"value\":\"block\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:32:06\",\"active\":0,\"admin_id\":28},{\"steps_id\":329,\"parent_id\":328,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:32:07\",\"active\":0,\"admin_id\":28},{\"steps_id\":330,\"parent_id\":329,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[{\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value_old\":\"flex\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:33:08\",\"active\":0,\"admin_id\":28},{\"steps_id\":331,\"parent_id\":330,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:33:09\",\"active\":0,\"admin_id\":28},{\"steps_id\":336,\"parent_id\":331,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .headings\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .headings\",\"attribute\":\"grid-template-columns\",\"value\":\"3fr 1fr 1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"3fr 1fr 1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"grid-column\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price\",\"attribute\":\"grid-column\",\"value\":\"3\\/4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price\",\"attribute\":\"grid-row\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty\",\"attribute\":\"grid-column\",\"value\":\"2\\/3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty\",\"attribute\":\"grid-row\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item > div.image\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .price\",\"attribute\":\"font-size\",\"value\":\"16\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing.type-2 .image\",\"attribute\":\"grid-column\",\"value\":\"1 \\/ 3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing.type-2 .image\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:37:44\",\"active\":0,\"admin_id\":28},{\"steps_id\":337,\"parent_id\":336,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".w-cart-listing .price small\",\"attribute\":\"display\",\"value\":\"block\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-listing .price small\",\"attribute\":\"line-height\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:38:26\",\"active\":0,\"admin_id\":28},{\"steps_id\":338,\"parent_id\":337,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:38:27\",\"active\":0,\"admin_id\":28},{\"steps_id\":339,\"parent_id\":338,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665949227.5645\",\"block_name\":\"116362\",\"page_name\":null,\"widget_name\":\"cart\\\\Products\",\"sort_order\":0},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:40:27\",\"active\":0,\"admin_id\":28},{\"steps_id\":340,\"parent_id\":339,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"225332\",\"microtime\":\"116364\",\"block_name\":\"116362\",\"sort_order\":1},{\"id\":\"229883\",\"microtime\":\"1665949227.5645\",\"block_name\":\"116362\",\"sort_order\":2},{\"id\":\"225334\",\"microtime\":\"116366\",\"block_name\":\"116362\",\"sort_order\":3},{\"id\":\"225335\",\"microtime\":\"116367\",\"block_name\":\"116362\",\"sort_order\":4},{\"id\":\"225333\",\"microtime\":\"116365\",\"block_name\":\"116362\",\"sort_order\":5},{\"id\":\"225331\",\"microtime\":\"116363\",\"block_name\":\"116362\",\"sort_order\":6}],\"positions_old\":[{\"id\":\"225332\",\"block_name\":\"116362\",\"sort_order\":\"1\",\"microtime\":\"116364\"},{\"id\":\"229883\",\"block_name\":\"116362\",\"sort_order\":\"0\",\"microtime\":\"1665949227.5645\"},{\"id\":\"225334\",\"block_name\":\"116362\",\"sort_order\":\"2\",\"microtime\":\"116366\"},{\"id\":\"225335\",\"block_name\":\"116362\",\"sort_order\":\"3\",\"microtime\":\"116367\"},{\"id\":\"225333\",\"block_name\":\"116362\",\"sort_order\":\"4\",\"microtime\":\"116365\"},{\"id\":\"225331\",\"block_name\":\"116362\",\"sort_order\":\"5\",\"microtime\":\"116363\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:40:34\",\"active\":0,\"admin_id\":28},{\"steps_id\":342,\"parent_id\":341,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .cart-listing.w-cart-listing.type-2.summary-listing\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .cart-listing.w-cart-listing.type-2.summary-listing\",\"attribute\":\"border-bottom-color\",\"value\":\"#e0e0e0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".order-summary .checkout-cart-listing.summary-listing\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .checkout-cart-listing.summary-listing\",\"attribute\":\"border-bottom-color\",\"value\":\"#e0e0e0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:42:32\",\"active\":0,\"admin_id\":28},{\"steps_id\":343,\"parent_id\":342,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:42:33\",\"active\":0,\"admin_id\":28},{\"steps_id\":344,\"parent_id\":343,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".order-summary .checkout-cart-listing.summary-listing\",\"attribute\":\"padding-top\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:43:52\",\"active\":0,\"admin_id\":28},{\"steps_id\":345,\"parent_id\":344,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing.summary-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .w-cart-listing .multi-cart .item\",\"attribute\":\"grid-template-rows\",\"value\":\"1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:49:57\",\"active\":0,\"admin_id\":28},{\"steps_id\":346,\"parent_id\":345,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:49:58\",\"active\":0,\"admin_id\":28},{\"steps_id\":347,\"parent_id\":346,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"225302\",\"microtime\":\"116336\",\"block_name\":\"116326\",\"sort_order\":1},{\"id\":\"225322\",\"microtime\":\"116354\",\"block_name\":\"116326\",\"sort_order\":2},{\"id\":\"225296\",\"microtime\":\"116330\",\"block_name\":\"116326\",\"sort_order\":3},{\"id\":\"225293\",\"microtime\":\"116327\",\"block_name\":\"116326\",\"sort_order\":4},{\"id\":\"225321\",\"microtime\":\"1639494585\",\"block_name\":\"116326\",\"sort_order\":5},{\"id\":\"225318\",\"microtime\":\"116351\",\"block_name\":\"116326\",\"sort_order\":6}],\"positions_old\":[{\"id\":\"225302\",\"block_name\":\"116326\",\"sort_order\":\"2\",\"microtime\":\"116336\"},{\"id\":\"225322\",\"block_name\":\"116326\",\"sort_order\":\"3\",\"microtime\":\"116354\"},{\"id\":\"225296\",\"block_name\":\"116326\",\"sort_order\":\"4\",\"microtime\":\"116330\"},{\"id\":\"225293\",\"block_name\":\"116326\",\"sort_order\":\"5\",\"microtime\":\"116327\"},{\"id\":\"225321\",\"block_name\":\"116351\",\"sort_order\":\"0\",\"microtime\":\"1639494585\"},{\"id\":\"225318\",\"block_name\":\"116326\",\"sort_order\":\"6\",\"microtime\":\"116351\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:50:06\",\"active\":0,\"admin_id\":28},{\"steps_id\":348,\"parent_id\":347,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"225302\",\"microtime\":\"116336\",\"block_name\":\"116326\",\"sort_order\":1},{\"id\":\"225322\",\"microtime\":\"116354\",\"block_name\":\"116326\",\"sort_order\":2},{\"id\":\"225296\",\"microtime\":\"116330\",\"block_name\":\"116326\",\"sort_order\":3},{\"id\":\"225293\",\"microtime\":\"116327\",\"block_name\":\"116326\",\"sort_order\":4},{\"id\":\"225321\",\"microtime\":\"1639494585\",\"block_name\":\"116326\",\"sort_order\":5},{\"id\":\"225319\",\"microtime\":\"116352\",\"block_name\":\"116326\",\"sort_order\":6},{\"id\":\"225318\",\"microtime\":\"116351\",\"block_name\":\"116326\",\"sort_order\":7}],\"positions_old\":[{\"id\":\"225302\",\"block_name\":\"116326\",\"sort_order\":\"1\",\"microtime\":\"116336\"},{\"id\":\"225322\",\"block_name\":\"116326\",\"sort_order\":\"2\",\"microtime\":\"116354\"},{\"id\":\"225296\",\"block_name\":\"116326\",\"sort_order\":\"3\",\"microtime\":\"116330\"},{\"id\":\"225293\",\"block_name\":\"116326\",\"sort_order\":\"4\",\"microtime\":\"116327\"},{\"id\":\"225321\",\"block_name\":\"116326\",\"sort_order\":\"5\",\"microtime\":\"1639494585\"},{\"id\":\"225319\",\"block_name\":\"116351\",\"sort_order\":\"1\",\"microtime\":\"116352\"},{\"id\":\"225318\",\"block_name\":\"116326\",\"sort_order\":\"6\",\"microtime\":\"116351\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:50:08\",\"active\":0,\"admin_id\":28},{\"steps_id\":349,\"parent_id\":348,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"225302\",\"microtime\":\"116336\",\"block_name\":\"116326\",\"sort_order\":1},{\"id\":\"225322\",\"microtime\":\"116354\",\"block_name\":\"116326\",\"sort_order\":2},{\"id\":\"225296\",\"microtime\":\"116330\",\"block_name\":\"116326\",\"sort_order\":3},{\"id\":\"225293\",\"microtime\":\"116327\",\"block_name\":\"116326\",\"sort_order\":4},{\"id\":\"225321\",\"microtime\":\"1639494585\",\"block_name\":\"116326\",\"sort_order\":5},{\"id\":\"225319\",\"microtime\":\"116352\",\"block_name\":\"116326\",\"sort_order\":6},{\"id\":\"225320\",\"microtime\":\"116353\",\"block_name\":\"116326\",\"sort_order\":7},{\"id\":\"225318\",\"microtime\":\"116351\",\"block_name\":\"116326\",\"sort_order\":8}],\"positions_old\":[{\"id\":\"225302\",\"block_name\":\"116326\",\"sort_order\":\"1\",\"microtime\":\"116336\"},{\"id\":\"225322\",\"block_name\":\"116326\",\"sort_order\":\"2\",\"microtime\":\"116354\"},{\"id\":\"225296\",\"block_name\":\"116326\",\"sort_order\":\"3\",\"microtime\":\"116330\"},{\"id\":\"225293\",\"block_name\":\"116326\",\"sort_order\":\"4\",\"microtime\":\"116327\"},{\"id\":\"225321\",\"block_name\":\"116326\",\"sort_order\":\"5\",\"microtime\":\"1639494585\"},{\"id\":\"225319\",\"block_name\":\"116326\",\"sort_order\":\"6\",\"microtime\":\"116352\"},{\"id\":\"225320\",\"block_name\":\"116351\",\"sort_order\":\"2\",\"microtime\":\"116353\"},{\"id\":\"225318\",\"block_name\":\"116326\",\"sort_order\":\"7\",\"microtime\":\"116351\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:50:12\",\"active\":0,\"admin_id\":28},{\"steps_id\":350,\"parent_id\":349,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"116351\",\"block_name\":\"116326\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"8\",\"settings\":[{\"microtime\":\"116351\",\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"padding-left\",\"setting_value\":\"15\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"116351\",\"setting_name\":\"padding-right\",\"setting_value\":\"15\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"116351\",\"setting_name\":\"padding-top\",\"setting_value\":\"15\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"116351\",\"setting_name\":\"padding-bottom\",\"setting_value\":\"15\",\"language_id\":0,\"visibility\":\"w768\"}],\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"225318\",\"siblings\":[{\"id\":225293,\"microtime\":\"116327\",\"theme_name\":\"printshop\",\"block_name\":\"block-225292\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":4},{\"id\":225296,\"microtime\":\"116330\",\"theme_name\":\"printshop\",\"block_name\":\"block-225292\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":225302,\"microtime\":\"116336\",\"theme_name\":\"printshop\",\"block_name\":\"block-225292\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":225318,\"microtime\":\"116351\",\"theme_name\":\"printshop\",\"block_name\":\"block-225292\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":8},{\"id\":225319,\"microtime\":\"116352\",\"theme_name\":\"printshop\",\"block_name\":\"block-225292\",\"widget_name\":\"cart\\\\Products\",\"widget_params\":\"\",\"sort_order\":6},{\"id\":225320,\"microtime\":\"116353\",\"theme_name\":\"printshop\",\"block_name\":\"block-225292\",\"widget_name\":\"checkout\\\\CreateAccount\",\"widget_params\":\"\",\"sort_order\":7},{\"id\":225321,\"microtime\":\"1639494585\",\"theme_name\":\"printshop\",\"block_name\":\"block-225292\",\"widget_name\":\"DeliveryOptions\\\\Checkout\",\"widget_params\":\"\",\"sort_order\":5},{\"id\":225322,\"microtime\":\"116354\",\"theme_name\":\"printshop\",\"block_name\":\"block-225292\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:50:18\",\"active\":0,\"admin_id\":28},{\"steps_id\":351,\"parent_id\":350,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116352\",\"box_id\":\"225319\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"printshop\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"printshop\"}],\"box_settings_old\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:50:36\",\"active\":0,\"admin_id\":28},{\"steps_id\":352,\"parent_id\":351,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116353\",\"box_id\":\"225320\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"margin-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#eceff1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"}],\"box_settings_old\":[{\"setting_name\":\"padding-top\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#eceff1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"8\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:51:16\",\"active\":0,\"admin_id\":28},{\"steps_id\":353,\"parent_id\":352,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116353\",\"box_id\":\"225320\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"margin-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"}],\"box_settings_old\":[{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#eceff1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:51:32\",\"active\":0,\"admin_id\":28},{\"steps_id\":355,\"parent_id\":354,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:52:15\",\"active\":0,\"admin_id\":28},{\"steps_id\":356,\"parent_id\":355,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:52:15\",\"active\":0,\"admin_id\":28},{\"steps_id\":357,\"parent_id\":356,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:53:23\",\"active\":0,\"admin_id\":28},{\"steps_id\":358,\"parent_id\":357,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:53:29\",\"active\":0,\"admin_id\":28},{\"steps_id\":359,\"parent_id\":358,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:53:29\",\"active\":0,\"admin_id\":28},{\"steps_id\":360,\"parent_id\":359,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116353\",\"box_id\":\"225320\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"printshop\"}],\"box_settings_old\":[{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w992\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:54:23\",\"active\":0,\"admin_id\":28},{\"steps_id\":362,\"parent_id\":361,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"1fr\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:56:22\",\"active\":0,\"admin_id\":28},{\"steps_id\":363,\"parent_id\":362,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:56:23\",\"active\":0,\"admin_id\":28},{\"steps_id\":364,\"parent_id\":363,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[{\"selector\":\".w-checkout-shipping-choice span\",\"attribute\":\"padding-left\",\"value_old\":\"10\",\"value\":\"5\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"selector\":\".w-checkout-shipping-choice span\",\"attribute\":\"padding-right\",\"value_old\":\"10\",\"value\":\"5\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"}],\"attributes_delete\":[{\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-ms-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-webkit-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"}],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:57:38\",\"active\":0,\"admin_id\":28},{\"steps_id\":365,\"parent_id\":364,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-ms-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"theme_name\":\"printshop\",\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-webkit-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"theme_name\":\"printshop\",\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-ms-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"theme_name\":\"printshop\",\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-webkit-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:57:38\",\"active\":0,\"admin_id\":28},{\"steps_id\":372,\"parent_id\":365,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".header-middle \",\"attribute\":\"z-index\",\"value\":\"999\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".header-middle\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:59:57\",\"active\":0,\"admin_id\":28},{\"steps_id\":373,\"parent_id\":372,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 20:59:58\",\"active\":0,\"admin_id\":28},{\"steps_id\":374,\"parent_id\":373,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[{\"selector\":\".header-middle \",\"attribute\":\"z-index\",\"value_old\":\"999\",\"value\":\"999999\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".header-middle\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 21:00:20\",\"active\":0,\"admin_id\":28},{\"steps_id\":375,\"parent_id\":374,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 21:00:21\",\"active\":0,\"admin_id\":28},{\"steps_id\":376,\"parent_id\":375,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665950513.5754\",\"block_name\":\"116326\",\"page_name\":null,\"widget_name\":\"BlockBox\",\"sort_order\":0},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 21:01:53\",\"active\":0,\"admin_id\":28},{\"steps_id\":377,\"parent_id\":376,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665950513.5754\",\"box_id\":\"229884\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665950513.5754\",\"theme_name\":\"printshop\"}],\"box_settings_old\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 21:02:05\",\"active\":0,\"admin_id\":28},{\"steps_id\":378,\"parent_id\":377,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665950537.7441\",\"block_name\":\"1665950513.5754\",\"page_name\":null,\"widget_name\":\"checkout\\\\LoginOnForm\",\"sort_order\":0},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 21:02:17\",\"active\":0,\"admin_id\":28},{\"steps_id\":379,\"parent_id\":378,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665950513.5754\",\"box_id\":\"229884\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665950513.5754\",\"theme_name\":\"printshop\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665950513.5754\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665950513.5754\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665950513.5754\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665950513.5754\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665950513.5754\",\"theme_name\":\"printshop\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665950513.5754\",\"theme_name\":\"printshop\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 21:02:44\",\"active\":0,\"admin_id\":28},{\"steps_id\":381,\"parent_id\":380,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[{\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"line-height\",\"value_old\":\"55\",\"value\":\"2\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .closeable-heading + .closeable-content\",\"attribute\":\"padding-top\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-checkout-index .closeable-heading .heading-2\",\"attribute\":\"margin-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 21:04:05\",\"active\":0,\"admin_id\":28},{\"steps_id\":382,\"parent_id\":381,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[{\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"line-height\",\"value_old\":\"2\",\"value\":\"55\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-16 21:04:06\",\"active\":0,\"admin_id\":28},{\"steps_id\":389,\"parent_id\":382,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"content\",\"value\":\"\\\\f283\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"margin-left\",\"value\":\"15\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"font-weight\",\"value\":\"400\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-17 05:51:51\",\"active\":0,\"admin_id\":28},{\"steps_id\":391,\"parent_id\":390,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-17 05:51:52\",\"active\":0,\"admin_id\":28},{\"steps_id\":404,\"parent_id\":391,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".order-summary .w-cart-listing .item .points\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-17 06:02:07\",\"active\":0,\"admin_id\":28},{\"steps_id\":405,\"parent_id\":404,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-17 06:02:07\",\"active\":0,\"admin_id\":28},{\"steps_id\":535,\"parent_id\":405,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"225214\",\"microtime\":\"116240\",\"block_name\":\"116237\",\"sort_order\":1},{\"id\":\"225200\",\"microtime\":\"116230\",\"block_name\":\"116237\",\"sort_order\":2},{\"id\":\"225213\",\"microtime\":\"116239\",\"block_name\":\"116237\",\"sort_order\":3},{\"id\":\"225212\",\"microtime\":\"116238\",\"block_name\":\"116237\",\"sort_order\":4}],\"positions_old\":[{\"id\":\"225214\",\"block_name\":\"116237\",\"sort_order\":\"1\",\"microtime\":\"116240\"},{\"id\":\"225200\",\"block_name\":\"1644503891\",\"sort_order\":\"1\",\"microtime\":\"116230\"},{\"id\":\"225213\",\"block_name\":\"116237\",\"sort_order\":\"2\",\"microtime\":\"116239\"},{\"id\":\"225212\",\"block_name\":\"116237\",\"sort_order\":\"4\",\"microtime\":\"116238\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:30:27\",\"active\":0,\"admin_id\":28},{\"steps_id\":537,\"parent_id\":536,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"225200\",\"microtime\":\"116230\",\"block_name\":\"116237\",\"sort_order\":1},{\"id\":\"225214\",\"microtime\":\"116240\",\"block_name\":\"116237\",\"sort_order\":2},{\"id\":\"225213\",\"microtime\":\"116239\",\"block_name\":\"116237\",\"sort_order\":3},{\"id\":\"225212\",\"microtime\":\"116238\",\"block_name\":\"116237\",\"sort_order\":4}],\"positions_old\":[{\"id\":\"225200\",\"block_name\":\"116237\",\"sort_order\":\"2\",\"microtime\":\"116230\"},{\"id\":\"225214\",\"block_name\":\"116237\",\"sort_order\":\"1\",\"microtime\":\"116240\"},{\"id\":\"225213\",\"block_name\":\"116237\",\"sort_order\":\"3\",\"microtime\":\"116239\"},{\"id\":\"225212\",\"block_name\":\"116237\",\"sort_order\":\"4\",\"microtime\":\"116238\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:30:31\",\"active\":0,\"admin_id\":28},{\"steps_id\":538,\"parent_id\":537,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1666337442.4869\",\"block_name\":\"116237\",\"page_name\":null,\"widget_name\":\"cart\\\\OrderTotal\",\"sort_order\":0},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:30:42\",\"active\":0,\"admin_id\":28},{\"steps_id\":539,\"parent_id\":538,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1666337442.4869\",\"box_id\":\"234721\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"style_class\",\"setting_value\":\"top-totals\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1666337442.4869\",\"theme_name\":\"printshop\"}],\"box_settings_old\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:31:00\",\"active\":0,\"admin_id\":28},{\"steps_id\":540,\"parent_id\":539,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"225201\",\"microtime\":\"1639491248\",\"block_name\":\"1644503891\",\"sort_order\":1}],\"positions_old\":[{\"id\":\"225201\",\"block_name\":\"1644503891-2\",\"sort_order\":\"1\",\"microtime\":\"1639491248\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:31:15\",\"active\":0,\"admin_id\":28},{\"steps_id\":541,\"parent_id\":540,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116240\",\"box_id\":\"225214\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"style_class\",\"setting_value\":\"bottom-totals\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116240\",\"theme_name\":\"printshop\"}],\"box_settings_old\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:31:49\",\"active\":0,\"admin_id\":28},{\"steps_id\":543,\"parent_id\":542,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .inp\",\"attribute\":\"display\",\"value_old\":\"flex\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-bottom\",\"value_old\":\"24\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"border-bottom-color\",\"value\":\"#e5e5e5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-bottom\",\"value\":\"7\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"background-color\",\"value\":\"#e2e2e2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-top\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"margin-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"400\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"0.75\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f107\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-family\",\"value\":\"\'fontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-left\",\"value\":\"10\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp\",\"attribute\":\"margin-top\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:32:34\",\"active\":0,\"admin_id\":28},{\"steps_id\":544,\"parent_id\":543,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"background-color\",\"value_old\":\"#e2e2e2\",\"value\":\"#eceff1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:32:52\",\"active\":0,\"admin_id\":28},{\"steps_id\":545,\"parent_id\":544,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:32:53\",\"active\":0,\"admin_id\":28},{\"steps_id\":546,\"parent_id\":545,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116230\",\"box_id\":\"225200\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116230\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"116230\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"116230\",\"theme_name\":\"printshop\"}],\"box_settings_old\":[{\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"24\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w768\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:33:42\",\"active\":0,\"admin_id\":28},{\"steps_id\":554,\"parent_id\":547,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".p-shopping-cart-index .order-summary .bottom-totals .icon\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-shopping-cart-index .order-summary .bottom-totals .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-shopping-cart-index .order-summary .bottom-totals .price-row\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"printshop\",\"selector\":\".p-shopping-cart-index .order-summary .bottom-totals .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:35:30\",\"active\":0,\"admin_id\":28},{\"steps_id\":555,\"parent_id\":554,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:35:30\",\"active\":0,\"admin_id\":28},{\"steps_id\":556,\"parent_id\":555,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".order-summary .top-totals .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .top-totals .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:36:57\",\"active\":0,\"admin_id\":28},{\"steps_id\":557,\"parent_id\":556,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:36:58\",\"active\":0,\"admin_id\":28},{\"steps_id\":558,\"parent_id\":557,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[{\"selector\":\".order-summary .price-box\",\"attribute\":\"margin-bottom\",\"value_old\":\"20\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:37:22\",\"active\":0,\"admin_id\":28},{\"steps_id\":559,\"parent_id\":558,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:37:23\",\"active\":0,\"admin_id\":28},{\"steps_id\":560,\"parent_id\":559,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"116234\",\"block_name\":\"116233\",\"widget_name\":\"Html_box\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":[{\"microtime\":\"116234\",\"setting_name\":\"text\",\"setting_value\":\"<div class=\\\"heading-3\\\">##TEXT_SHIPPING##<\\/div>\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116234\",\"setting_name\":\"style_class\",\"setting_value\":\"shipping-ico\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[],\".shipping-ico\":[{\"id\":1917497,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"border-bottom-color\",\"value\":\"#e5e5e5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1918105,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1926334,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1929912,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"margin-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1930558,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1931156,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1931762,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"margin-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1933565,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"padding-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1934976,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1936324,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1937696,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"}]},\"translation\":{\"main\":{\"TEXT_SHIPPING\":{\"en\":\"Shipping\"}}},\"box_id\":\"225207\",\"siblings\":[{\"id\":225207,\"microtime\":\"116234\",\"theme_name\":\"printshop\",\"block_name\":\"block-225206\",\"widget_name\":\"Html_box\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":225208,\"microtime\":\"116235\",\"theme_name\":\"printshop\",\"block_name\":\"block-225206\",\"widget_name\":\"cart\\\\ShippingEstimator\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:37:52\",\"active\":0,\"admin_id\":28},{\"steps_id\":562,\"parent_id\":561,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"225199\",\"microtime\":\"1644503891\",\"block_name\":\"116229\",\"sort_order\":1},{\"id\":\"225201\",\"microtime\":\"1639491248\",\"block_name\":\"116229\",\"sort_order\":2},{\"id\":\"225195\",\"microtime\":\"1644503846\",\"block_name\":\"116229\",\"sort_order\":3}],\"positions_old\":[{\"id\":\"225199\",\"block_name\":\"116229\",\"sort_order\":\"1\",\"microtime\":\"1644503891\"},{\"id\":\"225201\",\"block_name\":\"1644503891\",\"sort_order\":\"1\",\"microtime\":\"1639491248\"},{\"id\":\"225195\",\"block_name\":\"116229\",\"sort_order\":\"2\",\"microtime\":\"1644503846\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:38:39\",\"active\":0,\"admin_id\":28},{\"steps_id\":563,\"parent_id\":562,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1644503891\",\"block_name\":\"116229\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":[{\"microtime\":\"1644503891\",\"setting_name\":\"block_type\",\"setting_value\":\"2\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1644503891\",\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1644503891\",\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1644503891\",\"setting_name\":\"border-bottom-width\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1644503891\",\"setting_name\":\"border-bottom-color\",\"setting_value\":\"#e5e5e5\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1644503891\",\"setting_name\":\"schema\",\"setting_value\":\"2-2\",\"language_id\":0,\"visibility\":\"w768\"}],\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"225199\",\"siblings\":[{\"id\":225195,\"microtime\":\"1644503846\",\"theme_name\":\"printshop\",\"block_name\":\"block-225194\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":225199,\"microtime\":\"1644503891\",\"theme_name\":\"printshop\",\"block_name\":\"block-225194\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":225201,\"microtime\":\"1639491248\",\"theme_name\":\"printshop\",\"block_name\":\"block-225194\",\"widget_name\":\"cart\\\\CreditAmount\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:38:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":564,\"parent_id\":563,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1639476084\",\"block_name\":\"1644503846-2\",\"widget_name\":\"cart\\\\FreeDelivery\",\"widget_params\":\"\",\"sort_order\":\"2\",\"settings\":[{\"microtime\":\"1639476084\",\"setting_name\":\"text-align\",\"setting_value\":\"right\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"225198\",\"siblings\":[{\"id\":225198,\"microtime\":\"1639476084\",\"theme_name\":\"printshop\",\"block_name\":\"block-225195-2\",\"widget_name\":\"cart\\\\FreeDelivery\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:38:52\",\"active\":0,\"admin_id\":28},{\"steps_id\":565,\"parent_id\":564,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"225196\",\"microtime\":\"116232\",\"block_name\":\"1644503846\",\"sort_order\":1},{\"id\":\"225201\",\"microtime\":\"1639491248\",\"block_name\":\"1644503846\",\"sort_order\":2}],\"positions_old\":[{\"id\":\"225196\",\"block_name\":\"1644503846\",\"sort_order\":\"1\",\"microtime\":\"116232\"},{\"id\":\"225201\",\"block_name\":\"116229\",\"sort_order\":\"2\",\"microtime\":\"1639491248\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:38:59\",\"active\":0,\"admin_id\":28},{\"steps_id\":566,\"parent_id\":565,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"225196\",\"microtime\":\"116232\",\"block_name\":\"1644503846-2\",\"sort_order\":1}],\"positions_old\":[{\"id\":\"225196\",\"block_name\":\"1644503846\",\"sort_order\":\"1\",\"microtime\":\"116232\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:39:03\",\"active\":0,\"admin_id\":28},{\"steps_id\":568,\"parent_id\":567,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116229\",\"box_id\":\"225194\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116229\",\"theme_name\":\"printshop\"},{\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116229\",\"theme_name\":\"printshop\"},{\"setting_name\":\"schema\",\"setting_value\":\"2-2\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"116229\",\"theme_name\":\"printshop\"},{\"setting_name\":\"style_class\",\"setting_value\":\"closeable-content\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116229\",\"theme_name\":\"printshop\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"schema\",\"setting_value\":\"2-2\",\"language_id\":\"0\",\"visibility\":\"w768\"},{\"setting_name\":\"style_class\",\"setting_value\":\"closeable-content\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:40:00\",\"active\":0,\"admin_id\":28},{\"steps_id\":570,\"parent_id\":569,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116230\",\"box_id\":\"225200\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116230\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"116230\",\"theme_name\":\"printshop\"}],\"box_settings_old\":[{\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w768\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:41:04\",\"active\":0,\"admin_id\":28},{\"steps_id\":572,\"parent_id\":571,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"225188\",\"microtime\":\"116218\",\"block_name\":\"116214\",\"sort_order\":1},{\"id\":\"225209\",\"microtime\":\"1639494018\",\"block_name\":\"116214\",\"sort_order\":2},{\"id\":\"225203\",\"microtime\":\"116224\",\"block_name\":\"116214\",\"sort_order\":3},{\"id\":\"225185\",\"microtime\":\"116215\",\"block_name\":\"116214\",\"sort_order\":4},{\"id\":\"225208\",\"microtime\":\"116235\",\"block_name\":\"116214\",\"sort_order\":5},{\"id\":\"225206\",\"microtime\":\"116233\",\"block_name\":\"116214\",\"sort_order\":6}],\"positions_old\":[{\"id\":\"225188\",\"block_name\":\"116214\",\"sort_order\":\"1\",\"microtime\":\"116218\"},{\"id\":\"225209\",\"block_name\":\"116214\",\"sort_order\":\"2\",\"microtime\":\"1639494018\"},{\"id\":\"225203\",\"block_name\":\"116214\",\"sort_order\":\"3\",\"microtime\":\"116224\"},{\"id\":\"225185\",\"block_name\":\"116214\",\"sort_order\":\"4\",\"microtime\":\"116215\"},{\"id\":\"225208\",\"block_name\":\"116233\",\"sort_order\":\"2\",\"microtime\":\"116235\"},{\"id\":\"225206\",\"block_name\":\"116214\",\"sort_order\":\"5\",\"microtime\":\"116233\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:41:56\",\"active\":0,\"admin_id\":28},{\"steps_id\":573,\"parent_id\":572,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"116233\",\"block_name\":\"116214\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"6\",\"settings\":[{\"microtime\":\"116233\",\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116233\",\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116233\",\"setting_name\":\"padding-top\",\"setting_value\":\"20\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116233\",\"setting_name\":\"padding-left\",\"setting_value\":\"25\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116233\",\"setting_name\":\"padding-right\",\"setting_value\":\"25\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116233\",\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116233\",\"setting_name\":\"margin-bottom\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116233\",\"setting_name\":\"style_class\",\"setting_value\":\"closeable-box\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116233\",\"setting_name\":\"display\",\"setting_value\":\"none\",\"language_id\":0,\"visibility\":\"w992\"},{\"microtime\":\"116233\",\"setting_name\":\"display\",\"setting_value\":\"none\",\"language_id\":0,\"visibility\":\"w992\"},{\"microtime\":\"116233\",\"setting_name\":\"padding-left\",\"setting_value\":\"15\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"116233\",\"setting_name\":\"padding-right\",\"setting_value\":\"15\",\"language_id\":0,\"visibility\":\"w768\"}],\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"225206\",\"siblings\":[{\"id\":225185,\"microtime\":\"116215\",\"theme_name\":\"printshop\",\"block_name\":\"block-225184\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":4},{\"id\":225188,\"microtime\":\"116218\",\"theme_name\":\"printshop\",\"block_name\":\"block-225184\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":225203,\"microtime\":\"116224\",\"theme_name\":\"printshop\",\"block_name\":\"block-225184\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":225206,\"microtime\":\"116233\",\"theme_name\":\"printshop\",\"block_name\":\"block-225184\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":6},{\"id\":225208,\"microtime\":\"116235\",\"theme_name\":\"printshop\",\"block_name\":\"block-225184\",\"widget_name\":\"cart\\\\ShippingEstimator\",\"widget_params\":\"\",\"sort_order\":5},{\"id\":225209,\"microtime\":\"1639494018\",\"theme_name\":\"printshop\",\"block_name\":\"block-225184\",\"widget_name\":\"cart\\\\DependedProducts\",\"widget_params\":\"8\",\"sort_order\":2}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:42:29\",\"active\":0,\"admin_id\":28},{\"steps_id\":574,\"parent_id\":573,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116235\",\"box_id\":\"225208\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"font-weight\",\"setting_value\":\"normal\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116235\",\"theme_name\":\"printshop\"},{\"setting_name\":\"hide_parents\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116235\",\"theme_name\":\"printshop\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116235\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"25\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116235\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"25\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116235\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"25\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116235\",\"theme_name\":\"printshop\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"25\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116235\",\"theme_name\":\"printshop\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116235\",\"theme_name\":\"printshop\"}],\"box_settings_old\":[{\"setting_name\":\"font-weight\",\"setting_value\":\"normal\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"hide_parents\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-21 08:42:51\",\"active\":0,\"admin_id\":28},{\"steps_id\":623,\"parent_id\":610,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".w-cart-shipping-estimator .shipping-estimator\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-shipping-estimator .left-area\",\"attribute\":\"float\",\"value\":\"none\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-shipping-estimator .left-area\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-shipping-estimator .left-area\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-shipping-estimator .right-area\",\"attribute\":\"float\",\"value\":\"none\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-shipping-estimator .right-area\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-shipping-estimator .right-area\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"},{\"theme_name\":\"printshop\",\"selector\":\".w-cart-shipping-estimator .estimate-shipping .col-right > span\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-shipping-estimator\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-25 13:21:56\",\"active\":0,\"admin_id\":45},{\"steps_id\":625,\"parent_id\":624,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-25 13:21:58\",\"active\":0,\"admin_id\":45},{\"steps_id\":626,\"parent_id\":625,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2022-10-25 13:21:59\",\"active\":1,\"admin_id\":45}]','printshop','2022-10-26 14:03:00',0,0,''),(3,0,'applyMigration','[{\"steps_id\":3,\"parent_id\":0,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1664256380.7348\",\"block_name\":\"116337\",\"page_name\":null,\"widget_name\":\"BlockBox\",\"sort_order\":0},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-27 06:26:20\",\"active\":0,\"admin_id\":28},{\"steps_id\":5,\"parent_id\":4,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224950\",\"microtime\":\"1664256380.7348\",\"block_name\":\"116326\",\"sort_order\":1},{\"id\":\"160715\",\"microtime\":\"116336\",\"block_name\":\"116326\",\"sort_order\":2},{\"id\":\"160736\",\"microtime\":\"116354\",\"block_name\":\"116326\",\"sort_order\":3},{\"id\":\"160709\",\"microtime\":\"116330\",\"block_name\":\"116326\",\"sort_order\":4},{\"id\":\"160706\",\"microtime\":\"116327\",\"block_name\":\"116326\",\"sort_order\":5},{\"id\":\"160732\",\"microtime\":\"116351\",\"block_name\":\"116326\",\"sort_order\":6}],\"positions_old\":[{\"id\":\"224950\",\"block_name\":\"116337\",\"sort_order\":\"0\",\"microtime\":\"1664256380.7348\"},{\"id\":\"160715\",\"block_name\":\"116326\",\"sort_order\":\"2\",\"microtime\":\"116336\"},{\"id\":\"160736\",\"block_name\":\"116326\",\"sort_order\":\"3\",\"microtime\":\"116354\"},{\"id\":\"160709\",\"block_name\":\"116326\",\"sort_order\":\"4\",\"microtime\":\"116330\"},{\"id\":\"160706\",\"block_name\":\"116326\",\"sort_order\":\"5\",\"microtime\":\"116327\"},{\"id\":\"160732\",\"block_name\":\"116326\",\"sort_order\":\"6\",\"microtime\":\"116351\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-27 06:27:22\",\"active\":0,\"admin_id\":28},{\"steps_id\":6,\"parent_id\":5,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1664256380.7348\",\"box_id\":\"224950\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-27 06:27:25\",\"active\":0,\"admin_id\":28},{\"steps_id\":7,\"parent_id\":6,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1664256498.4635\",\"block_name\":\"1664256380.7348\",\"page_name\":null,\"widget_name\":\"checkout\\\\LoginOnForm\",\"sort_order\":0},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-27 06:28:18\",\"active\":0,\"admin_id\":28},{\"steps_id\":8,\"parent_id\":7,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1664256380.7348\",\"box_id\":\"224950\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#111111\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-27 06:30:36\",\"active\":0,\"admin_id\":28},{\"steps_id\":9,\"parent_id\":8,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1664256498.4635\",\"box_id\":\"224951\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256498.4635\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-27 06:30:52\",\"active\":0,\"admin_id\":28},{\"steps_id\":10,\"parent_id\":9,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1664256498.4635\",\"box_id\":\"224951\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"color\",\"setting_value\":\"#ffeb0e\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256498.4635\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-27 06:31:16\",\"active\":0,\"admin_id\":28},{\"steps_id\":12,\"parent_id\":11,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1664256498.4635\",\"box_id\":\"224951\",\"page_name\":\"checkout\",\"box_settings\":[],\"box_settings_old\":[{\"setting_name\":\"color\",\"setting_value\":\"#ffeb0e\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-27 06:32:12\",\"active\":0,\"admin_id\":28},{\"steps_id\":13,\"parent_id\":12,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1664256380.7348\",\"box_id\":\"224950\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#111111\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-27 06:37:09\",\"active\":0,\"admin_id\":28},{\"steps_id\":15,\"parent_id\":14,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .closeable-heading .heading-2\",\"attribute\":\"margin-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-27 06:38:18\",\"active\":0,\"admin_id\":28},{\"steps_id\":16,\"parent_id\":15,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-27 06:38:18\",\"active\":0,\"admin_id\":28},{\"steps_id\":17,\"parent_id\":16,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116330\",\"box_id\":\"160709\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"furniture\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"furniture\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"furniture\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box closeable-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116330\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"14\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box closeable-box\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:17:28\",\"active\":0,\"admin_id\":28},{\"steps_id\":19,\"parent_id\":18,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116327\",\"box_id\":\"160706\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"furniture\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"furniture\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"furniture\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box closeable-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116327\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"14\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box closeable-box\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:17:39\",\"active\":0,\"admin_id\":28},{\"steps_id\":21,\"parent_id\":20,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116325\",\"box_id\":\"160704\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"4\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116325\",\"theme_name\":\"furniture\"},{\"setting_name\":\"schema\",\"setting_value\":\"4-2\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116325\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"7\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"schema\",\"setting_value\":\"4-2\",\"language_id\":\"0\",\"visibility\":\"w992\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:42:07\",\"active\":0,\"admin_id\":28},{\"steps_id\":23,\"parent_id\":22,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1664362070.8586\",\"block_name\":\"116362\",\"page_name\":null,\"widget_name\":\"cart\\\\Products\",\"sort_order\":0},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:47:51\",\"active\":0,\"admin_id\":28},{\"steps_id\":25,\"parent_id\":24,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"3fr 1fr 1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .headings\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .headings\",\"attribute\":\"grid-template-columns\",\"value\":\"3fr 1fr 1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item > div.image\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"grid-column\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty\",\"attribute\":\"grid-column\",\"value\":\"2\\/3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty\",\"attribute\":\"grid-row\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:51:25\",\"active\":0,\"admin_id\":28},{\"steps_id\":26,\"parent_id\":25,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price\",\"attribute\":\"grid-column\",\"value\":\"3\\/4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price\",\"attribute\":\"grid-row\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:51:44\",\"active\":0,\"admin_id\":28},{\"steps_id\":27,\"parent_id\":26,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:51:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":28,\"parent_id\":27,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing.type-2 .image\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:54:02\",\"active\":0,\"admin_id\":28},{\"steps_id\":29,\"parent_id\":28,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:54:02\",\"active\":0,\"admin_id\":28},{\"steps_id\":30,\"parent_id\":29,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-cart-products .w-cart-listing.type-2 .image\",\"attribute\":\"grid-column\",\"value\":\"1 \\/ 1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-products\"},{\"selector\":\".w-cart-products .w-cart-listing.type-2 .item, .w-cart-products .w-cart-listing.type-2 .headings\",\"attribute\":\"grid-template-columns\",\"value\":\"120px 1fr 100px 150px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-products\"},{\"selector\":\".w-cart-products .w-cart-listing.type-2 .name\",\"attribute\":\"grid-column\",\"value\":\"2 \\/ 2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-products\"},{\"selector\":\".w-cart-products .w-cart-listing.type-2 .price\",\"attribute\":\"grid-column\",\"value\":\"4 \\/ 4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-products\"},{\"selector\":\".w-cart-products .w-cart-listing.type-2 .qty\",\"attribute\":\"grid-column\",\"value\":\"3 \\/ 3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-products\"},{\"selector\":\".w-cart-products .w-cart-listing.type-2 .item\",\"attribute\":\"grid-template-columns\",\"value\":\"80px 1fr 50px 1fr\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".w-cart-products\"},{\"selector\":\".w-cart-products .w-cart-listing.type-2 .name\",\"attribute\":\"grid-column\",\"value\":\"2 \\/ 5\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".w-cart-products\"}],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-cart-products .w-cart-listing.type-2.main-listing .image\",\"attribute\":\"grid-column\",\"value\":\"1 \\/ 1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-products\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-products .w-cart-listing.type-2.main-listing .item, .w-cart-products .w-cart-listing.type-2.main-listing .headings\",\"attribute\":\"grid-template-columns\",\"value\":\"120px 1fr 100px 150px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-products\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-products .w-cart-listing.type-2.main-listing .name\",\"attribute\":\"grid-column\",\"value\":\"2 \\/ 2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-products\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-products .w-cart-listing.type-2.main-listing .price\",\"attribute\":\"grid-column\",\"value\":\"4 \\/ 4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-products\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-products .w-cart-listing.type-2.main-listing .qty\",\"attribute\":\"grid-column\",\"value\":\"3 \\/ 3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-products\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-products .w-cart-listing.type-2.main-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"80px 1fr 50px 1fr\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".w-cart-products\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-products .w-cart-listing.type-2.main-listing .name\",\"attribute\":\"grid-column\",\"value\":\"2 \\/ 5\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".w-cart-products\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:55:27\",\"active\":0,\"admin_id\":28},{\"steps_id\":31,\"parent_id\":30,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:55:27\",\"active\":0,\"admin_id\":28},{\"steps_id\":32,\"parent_id\":31,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .hiding-box .w-cart-listing.type-2.summary-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:58:33\",\"active\":0,\"admin_id\":28},{\"steps_id\":33,\"parent_id\":32,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:58:33\",\"active\":0,\"admin_id\":28},{\"steps_id\":34,\"parent_id\":33,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing.type-2.main-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:59:06\",\"active\":0,\"admin_id\":28},{\"steps_id\":35,\"parent_id\":34,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 11:59:06\",\"active\":0,\"admin_id\":28},{\"steps_id\":36,\"parent_id\":35,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"160746\",\"microtime\":\"116364\",\"block_name\":\"116362\",\"sort_order\":1},{\"id\":\"224952\",\"microtime\":\"1664362070.8586\",\"block_name\":\"116362\",\"sort_order\":2},{\"id\":\"160748\",\"microtime\":\"116366\",\"block_name\":\"116362\",\"sort_order\":3},{\"id\":\"160749\",\"microtime\":\"116367\",\"block_name\":\"116362\",\"sort_order\":4},{\"id\":\"160747\",\"microtime\":\"116365\",\"block_name\":\"116362\",\"sort_order\":5},{\"id\":\"160745\",\"microtime\":\"116363\",\"block_name\":\"116362\",\"sort_order\":6}],\"positions_old\":[{\"id\":\"160746\",\"block_name\":\"116362\",\"sort_order\":\"1\",\"microtime\":\"116364\"},{\"id\":\"224952\",\"block_name\":\"116362\",\"sort_order\":\"0\",\"microtime\":\"1664362070.8586\"},{\"id\":\"160748\",\"block_name\":\"116362\",\"sort_order\":\"2\",\"microtime\":\"116366\"},{\"id\":\"160749\",\"block_name\":\"116362\",\"sort_order\":\"3\",\"microtime\":\"116367\"},{\"id\":\"160747\",\"block_name\":\"116362\",\"sort_order\":\"4\",\"microtime\":\"116365\"},{\"id\":\"160745\",\"block_name\":\"116362\",\"sort_order\":\"5\",\"microtime\":\"116363\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 12:39:21\",\"active\":0,\"admin_id\":28},{\"steps_id\":39,\"parent_id\":38,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing.type-2 .image\",\"attribute\":\"grid-column\",\"value\":\"1 \\/ 3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 12:42:06\",\"active\":0,\"admin_id\":28},{\"steps_id\":40,\"parent_id\":39,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 12:42:07\",\"active\":0,\"admin_id\":28},{\"steps_id\":41,\"parent_id\":40,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"160607\",\"microtime\":\"116240\",\"block_name\":\"116237\",\"sort_order\":1},{\"id\":\"160587\",\"microtime\":\"116230\",\"block_name\":\"116237\",\"sort_order\":2},{\"id\":\"160606\",\"microtime\":\"116239\",\"block_name\":\"116237\",\"sort_order\":3},{\"id\":\"160605\",\"microtime\":\"116238\",\"block_name\":\"116237\",\"sort_order\":4}],\"positions_old\":[{\"id\":\"160607\",\"block_name\":\"116237\",\"sort_order\":\"1\",\"microtime\":\"116240\"},{\"id\":\"160587\",\"block_name\":\"116229\",\"sort_order\":\"1\",\"microtime\":\"116230\"},{\"id\":\"160606\",\"block_name\":\"116237\",\"sort_order\":\"2\",\"microtime\":\"116239\"},{\"id\":\"160605\",\"block_name\":\"116237\",\"sort_order\":\"4\",\"microtime\":\"116238\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:34:58\",\"active\":0,\"admin_id\":28},{\"steps_id\":43,\"parent_id\":42,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116240\",\"box_id\":\"160607\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"style_class\",\"setting_value\":\"top-totals\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116240\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:36:04\",\"active\":0,\"admin_id\":28},{\"steps_id\":44,\"parent_id\":43,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1664372184.3958\",\"block_name\":\"116237\",\"page_name\":null,\"widget_name\":\"cart\\\\OrderTotal\",\"sort_order\":0},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:36:24\",\"active\":0,\"admin_id\":28},{\"steps_id\":45,\"parent_id\":44,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224953\",\"microtime\":\"1664372184.3958\",\"block_name\":\"116237\",\"sort_order\":1},{\"id\":\"160587\",\"microtime\":\"116230\",\"block_name\":\"116237\",\"sort_order\":2},{\"id\":\"160607\",\"microtime\":\"116240\",\"block_name\":\"116237\",\"sort_order\":3},{\"id\":\"160606\",\"microtime\":\"116239\",\"block_name\":\"116237\",\"sort_order\":4},{\"id\":\"160605\",\"microtime\":\"116238\",\"block_name\":\"116237\",\"sort_order\":5}],\"positions_old\":[{\"id\":\"224953\",\"block_name\":\"116237\",\"sort_order\":\"0\",\"microtime\":\"1664372184.3958\"},{\"id\":\"160587\",\"block_name\":\"116237\",\"sort_order\":\"2\",\"microtime\":\"116230\"},{\"id\":\"160607\",\"block_name\":\"116237\",\"sort_order\":\"1\",\"microtime\":\"116240\"},{\"id\":\"160606\",\"block_name\":\"116237\",\"sort_order\":\"3\",\"microtime\":\"116239\"},{\"id\":\"160605\",\"block_name\":\"116237\",\"sort_order\":\"4\",\"microtime\":\"116238\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:36:30\",\"active\":0,\"admin_id\":28},{\"steps_id\":46,\"parent_id\":45,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"160589\",\"microtime\":\"1639491248.6828\",\"block_name\":\"116229\",\"sort_order\":1}],\"positions_old\":[{\"id\":\"160589\",\"block_name\":\"116229-2\",\"sort_order\":\"2\",\"microtime\":\"1639491248.6828\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:36:36\",\"active\":0,\"admin_id\":28},{\"steps_id\":49,\"parent_id\":48,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116214\",\"box_id\":\"160576\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"4\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116214\",\"theme_name\":\"furniture\"},{\"setting_name\":\"schema\",\"setting_value\":\"4-1\",\"language_id\":\"0\",\"visibility\":\"w1200\",\"microtime\":\"116214\",\"theme_name\":\"furniture\"},{\"setting_name\":\"schema\",\"setting_value\":\"4-2\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"116214\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"7\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"schema\",\"setting_value\":\"4-1\",\"language_id\":\"0\",\"visibility\":\"w1200\"},{\"setting_name\":\"schema\",\"setting_value\":\"4-2\",\"language_id\":\"0\",\"visibility\":\"w992\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:38:11\",\"active\":0,\"admin_id\":28},{\"steps_id\":51,\"parent_id\":50,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"160607\",\"microtime\":\"116240\",\"block_name\":\"116237\",\"sort_order\":1},{\"id\":\"224953\",\"microtime\":\"1664372184.3958\",\"block_name\":\"116237\",\"sort_order\":2},{\"id\":\"160587\",\"microtime\":\"116230\",\"block_name\":\"116237\",\"sort_order\":3},{\"id\":\"160606\",\"microtime\":\"116239\",\"block_name\":\"116237\",\"sort_order\":4},{\"id\":\"160605\",\"microtime\":\"116238\",\"block_name\":\"116237\",\"sort_order\":5}],\"positions_old\":[{\"id\":\"160607\",\"block_name\":\"116237\",\"sort_order\":\"3\",\"microtime\":\"116240\"},{\"id\":\"224953\",\"block_name\":\"116237\",\"sort_order\":\"1\",\"microtime\":\"1664372184.3958\"},{\"id\":\"160587\",\"block_name\":\"116237\",\"sort_order\":\"2\",\"microtime\":\"116230\"},{\"id\":\"160606\",\"block_name\":\"116237\",\"sort_order\":\"4\",\"microtime\":\"116239\"},{\"id\":\"160605\",\"block_name\":\"116237\",\"sort_order\":\"5\",\"microtime\":\"116238\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:38:40\",\"active\":0,\"admin_id\":28},{\"steps_id\":52,\"parent_id\":51,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"160607\",\"microtime\":\"116240\",\"block_name\":\"116237\",\"sort_order\":1},{\"id\":\"160587\",\"microtime\":\"116230\",\"block_name\":\"116237\",\"sort_order\":2},{\"id\":\"224953\",\"microtime\":\"1664372184.3958\",\"block_name\":\"116237\",\"sort_order\":3},{\"id\":\"160606\",\"microtime\":\"116239\",\"block_name\":\"116237\",\"sort_order\":4},{\"id\":\"160605\",\"microtime\":\"116238\",\"block_name\":\"116237\",\"sort_order\":5}],\"positions_old\":[{\"id\":\"160607\",\"block_name\":\"116237\",\"sort_order\":\"1\",\"microtime\":\"116240\"},{\"id\":\"160587\",\"block_name\":\"116237\",\"sort_order\":\"3\",\"microtime\":\"116230\"},{\"id\":\"224953\",\"block_name\":\"116237\",\"sort_order\":\"2\",\"microtime\":\"1664372184.3958\"},{\"id\":\"160606\",\"block_name\":\"116237\",\"sort_order\":\"4\",\"microtime\":\"116239\"},{\"id\":\"160605\",\"block_name\":\"116237\",\"sort_order\":\"5\",\"microtime\":\"116238\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:38:43\",\"active\":0,\"admin_id\":28},{\"steps_id\":53,\"parent_id\":52,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1664372184.3958\",\"box_id\":\"224953\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"style_class\",\"setting_value\":\"bottom-totals\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664372184.3958\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:38:54\",\"active\":0,\"admin_id\":28},{\"steps_id\":55,\"parent_id\":54,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120900\",\"block_name\":\"116229-3\",\"widget_name\":\"cart\\\\SubTotal\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1485231,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1487657,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total .title\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1487658,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"font-size\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1488270,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total .title\",\"attribute\":\"font-weight\",\"value\":\"700\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1488271,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"font-weight\",\"value\":\"700\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1491005,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-bottom\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1491626,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1492216,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1492806,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1500446,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"text-align\",\"value\":\"right\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1502692,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1502693,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total .price-row > div\",\"attribute\":\"width\",\"value\":\"50\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1503432,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1503433,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total .price-row > div\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1828661,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"align-items\",\"value\":\"baseline\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1828793,\"theme_name\":\"furniture\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"}]},\"translation\":[],\"box_id\":\"160590\",\"siblings\":[{\"id\":160590,\"microtime\":\"120900\",\"theme_name\":\"furniture\",\"block_name\":\"block-160586-3\",\"widget_name\":\"cart\\\\SubTotal\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":160591,\"microtime\":\"1639476084.6036\",\"theme_name\":\"furniture\",\"block_name\":\"block-160586-3\",\"widget_name\":\"cart\\\\FreeDelivery\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:39:42\",\"active\":0,\"admin_id\":28},{\"steps_id\":57,\"parent_id\":56,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .top-totals .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:40:34\",\"active\":0,\"admin_id\":28},{\"steps_id\":58,\"parent_id\":57,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:40:35\",\"active\":0,\"admin_id\":28},{\"steps_id\":59,\"parent_id\":58,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .bottom-totals .price-row:not(.ot_total, .order-summary .bottom-totals .empty_cart)\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:41:04\",\"active\":0,\"admin_id\":28},{\"steps_id\":60,\"parent_id\":59,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:41:05\",\"active\":0,\"admin_id\":28},{\"steps_id\":61,\"parent_id\":60,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".order-summary .price-box\",\"attribute\":\"margin-bottom\",\"value_old\":\"20\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:41:40\",\"active\":0,\"admin_id\":28},{\"steps_id\":62,\"parent_id\":61,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:41:41\",\"active\":0,\"admin_id\":28},{\"steps_id\":63,\"parent_id\":62,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .inp\",\"attribute\":\"display\",\"value_old\":\"flex\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-bottom\",\"value_old\":\"10\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"border-bottom-color\",\"value\":\"#c9c9c9\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-family\",\"value\":\"\'Cabin\'\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"bold\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-bottom\",\"value\":\"7\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"background-color\",\"value\":\"#eeeeee\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-top\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"margin-bottom\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp\",\"attribute\":\"margin-top\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"400\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"0.75\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f107\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-family\",\"value\":\"\'fontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-left\",\"value\":\"10\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:43:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":64,\"parent_id\":63,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:43:46\",\"active\":0,\"admin_id\":28},{\"steps_id\":65,\"parent_id\":64,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116230\",\"box_id\":\"160587\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116230\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"116230\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"116230\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"24\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"w768\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 14:44:09\",\"active\":0,\"admin_id\":28},{\"steps_id\":68,\"parent_id\":67,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"content\",\"value\":\"\\\\f283\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"margin-left\",\"value\":\"15\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:00:15\",\"active\":0,\"admin_id\":28},{\"steps_id\":69,\"parent_id\":68,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:00:16\",\"active\":0,\"admin_id\":28},{\"steps_id\":70,\"parent_id\":69,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-cart-checkout-btn .w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"selector\":\".w-cart-checkout-btn .w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"content\",\"value\":\"\\\\f283\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"selector\":\".w-cart-checkout-btn .w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"selector\":\".w-cart-checkout-btn .w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"selector\":\".w-cart-checkout-btn .w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"margin-left\",\"value\":\"15\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"content\",\"value\":\"\\\\f283\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"margin-left\",\"value\":\"15\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:00:35\",\"active\":0,\"admin_id\":28},{\"steps_id\":71,\"parent_id\":70,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:00:36\",\"active\":0,\"admin_id\":28},{\"steps_id\":72,\"parent_id\":71,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"font-size\",\"value\":\"21\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:02:05\",\"active\":0,\"admin_id\":28},{\"steps_id\":73,\"parent_id\":72,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:02:06\",\"active\":0,\"admin_id\":28},{\"steps_id\":74,\"parent_id\":73,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".order-summary .heading-2\",\"attribute\":\"padding-top\",\"value_old\":\"10\",\"value\":\"16\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:03:33\",\"active\":0,\"admin_id\":28},{\"steps_id\":75,\"parent_id\":74,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:03:34\",\"active\":0,\"admin_id\":28},{\"steps_id\":76,\"parent_id\":75,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .order-summary .heading-2\",\"attribute\":\"padding-top\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:21:24\",\"active\":0,\"admin_id\":28},{\"steps_id\":77,\"parent_id\":76,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:21:24\",\"active\":0,\"admin_id\":28},{\"steps_id\":78,\"parent_id\":77,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .cart-listing.w-cart-listing.type-2.summary-listing\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .cart-listing.w-cart-listing.type-2.summary-listing\",\"attribute\":\"border-bottom-color\",\"value\":\"#e0e0e0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:22:58\",\"active\":0,\"admin_id\":28},{\"steps_id\":79,\"parent_id\":78,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:22:59\",\"active\":0,\"admin_id\":28},{\"steps_id\":80,\"parent_id\":79,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1664375440.5421\",\"block_name\":\"116220\",\"page_name\":null,\"widget_name\":\"BlockBox\",\"sort_order\":0},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:30:40\",\"active\":0,\"admin_id\":28},{\"steps_id\":81,\"parent_id\":80,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"160609\",\"microtime\":\"120945\",\"block_name\":\"116212\",\"sort_order\":1},{\"id\":\"224954\",\"microtime\":\"1664375440.5421\",\"block_name\":\"116212\",\"sort_order\":2},{\"id\":\"160576\",\"microtime\":\"116214\",\"block_name\":\"116212\",\"sort_order\":3}],\"positions_old\":[{\"id\":\"160609\",\"block_name\":\"116212\",\"sort_order\":\"1\",\"microtime\":\"120945\"},{\"id\":\"224954\",\"block_name\":\"116220\",\"sort_order\":\"0\",\"microtime\":\"1664375440.5421\"},{\"id\":\"160576\",\"block_name\":\"116212\",\"sort_order\":\"2\",\"microtime\":\"116214\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:30:48\",\"active\":0,\"admin_id\":28},{\"steps_id\":82,\"parent_id\":81,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1664375440.5421\",\"box_id\":\"224954\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664375440.5421\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:30:53\",\"active\":0,\"admin_id\":28},{\"steps_id\":83,\"parent_id\":82,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1664375550.2031\",\"block_name\":\"1664375440.5421\",\"page_name\":null,\"widget_name\":\"Import\",\"sort_order\":0},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:32:30\",\"active\":0,\"admin_id\":28},{\"steps_id\":84,\"parent_id\":83,\"event\":\"importBlock\",\"data\":{\"content\":{\"microtime\":\"116239\",\"block_name\":\"block-220249\",\"widget_name\":\"cart\\\\CheckoutBtn\",\"widget_params\":\"\",\"sort_order\":\"4\",\"settings\":[{\"microtime\":\"116239\",\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116239\",\"setting_name\":\"box_align\",\"setting_value\":\"4\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116239\",\"setting_name\":\"text-align\",\"setting_value\":\"center\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"116239\",\"setting_name\":\"float\",\"setting_value\":\"none\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"116239\",\"setting_name\":\"width\",\"setting_value\":\"100\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"116239\",\"setting_name\":\"width_measure\",\"setting_value\":\"%\",\"language_id\":0,\"visibility\":\"w768\"}],\"css\":{\"current\":[{\"id\":1888214,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"padding-left\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1889731,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"padding-right\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1892800,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"text-align\",\"value\":\"center\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1894804,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1894981,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn \",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1895651,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn \",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1895772,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1924031,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-top\",\"value\":\"-5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1924032,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1924033,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1924034,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"translation\":[]},\"id_old\":\"224955\",\"id\":224956,\"theme_name\":\"furniture\",\"microtime\":\"1664375561.987763\",\"siblings\":[{\"id\":224956,\"microtime\":\"1664375561.987763\",\"theme_name\":\"furniture\",\"block_name\":\"block-224954\",\"widget_name\":\"cart\\\\CheckoutBtn\",\"widget_params\":\"\",\"sort_order\":4}],\"block_name\":\"1664375440.5421\"},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:32:42\",\"active\":0,\"admin_id\":28},{\"steps_id\":85,\"parent_id\":84,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224954\",\"microtime\":\"1664375440.5421\",\"block_name\":\"120945\",\"sort_order\":1}],\"positions_old\":[{\"id\":\"224954\",\"block_name\":\"116212\",\"sort_order\":\"2\",\"microtime\":\"1664375440.5421\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:33:04\",\"active\":0,\"admin_id\":28},{\"steps_id\":86,\"parent_id\":85,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1664375440.5421\",\"block_name\":\"120945\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":[{\"microtime\":\"1664375440.5421\",\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":[],\"sub_1\":[{\"microtime\":\"1664375561.987763\",\"block_name\":\"block-224954\",\"widget_name\":\"cart\\\\CheckoutBtn\",\"widget_params\":\"\",\"sort_order\":\"4\",\"settings\":[{\"microtime\":\"1664375561.987763\",\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1664375561.987763\",\"setting_name\":\"box_align\",\"setting_value\":\"4\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1664375561.987763\",\"setting_name\":\"text-align\",\"setting_value\":\"center\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"1664375561.987763\",\"setting_name\":\"float\",\"setting_value\":\"none\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"1664375561.987763\",\"setting_name\":\"width\",\"setting_value\":\"100\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"1664375561.987763\",\"setting_name\":\"width_measure\",\"setting_value\":\"%\",\"language_id\":0,\"visibility\":\"w768\"}],\"css\":{\"current\":[{\"id\":1478004,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"background-color\",\"value\":\"#eeeeee\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1487204,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"font-size\",\"value\":\"17\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1490432,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"margin-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1490884,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1491237,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1491427,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1491979,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1492021,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1492556,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-top\",\"value\":\"-5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1492603,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"margin-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1495449,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"padding-left\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1496972,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"padding-right\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1500061,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"text-align\",\"value\":\"center\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1502070,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1502247,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn \",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1502919,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn \",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1503040,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916199,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916200,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"content\",\"value\":\"\\\\f283\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916201,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916202,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916203,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"margin-left\",\"value\":\"15\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916204,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"font-size\",\"value\":\"21\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"translation\":[]}],\"box_id\":\"224954\",\"siblings\":[{\"id\":224954,\"microtime\":\"1664375440.5421\",\"theme_name\":\"furniture\",\"block_name\":\"block-160609\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:33:05\",\"active\":0,\"admin_id\":28},{\"steps_id\":87,\"parent_id\":86,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1664375625.054\",\"block_name\":\"1664256380.7348\",\"page_name\":null,\"widget_name\":\"BlockBox\",\"sort_order\":0},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:33:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":88,\"parent_id\":87,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1664375625.054\",\"box_id\":\"224957\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664375625.054\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:33:53\",\"active\":0,\"admin_id\":28},{\"steps_id\":89,\"parent_id\":88,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224957\",\"microtime\":\"1664375625.054\",\"block_name\":\"116326\",\"sort_order\":1},{\"id\":\"224950\",\"microtime\":\"1664256380.7348\",\"block_name\":\"116326\",\"sort_order\":2},{\"id\":\"160715\",\"microtime\":\"116336\",\"block_name\":\"116326\",\"sort_order\":3},{\"id\":\"160736\",\"microtime\":\"116354\",\"block_name\":\"116326\",\"sort_order\":4},{\"id\":\"160709\",\"microtime\":\"116330\",\"block_name\":\"116326\",\"sort_order\":5},{\"id\":\"160706\",\"microtime\":\"116327\",\"block_name\":\"116326\",\"sort_order\":6},{\"id\":\"160732\",\"microtime\":\"116351\",\"block_name\":\"116326\",\"sort_order\":7}],\"positions_old\":[{\"id\":\"224957\",\"block_name\":\"1664256380.7348\",\"sort_order\":\"0\",\"microtime\":\"1664375625.054\"},{\"id\":\"224950\",\"block_name\":\"116326\",\"sort_order\":\"1\",\"microtime\":\"1664256380.7348\"},{\"id\":\"160715\",\"block_name\":\"116326\",\"sort_order\":\"2\",\"microtime\":\"116336\"},{\"id\":\"160736\",\"block_name\":\"116326\",\"sort_order\":\"3\",\"microtime\":\"116354\"},{\"id\":\"160709\",\"block_name\":\"116326\",\"sort_order\":\"4\",\"microtime\":\"116330\"},{\"id\":\"160706\",\"block_name\":\"116326\",\"sort_order\":\"5\",\"microtime\":\"116327\"},{\"id\":\"160732\",\"block_name\":\"116326\",\"sort_order\":\"6\",\"microtime\":\"116351\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:34:01\",\"active\":0,\"admin_id\":28},{\"steps_id\":90,\"parent_id\":89,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1664375646.2568\",\"block_name\":\"1664375625.054\",\"page_name\":null,\"widget_name\":\"Import\",\"sort_order\":0},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:34:06\",\"active\":0,\"admin_id\":28},{\"steps_id\":91,\"parent_id\":90,\"event\":\"importBlock\",\"data\":{\"content\":{\"microtime\":\"116239\",\"block_name\":\"block-220249\",\"widget_name\":\"cart\\\\CheckoutBtn\",\"widget_params\":\"\",\"sort_order\":\"4\",\"settings\":[{\"microtime\":\"116239\",\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116239\",\"setting_name\":\"box_align\",\"setting_value\":\"4\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116239\",\"setting_name\":\"text-align\",\"setting_value\":\"center\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"116239\",\"setting_name\":\"float\",\"setting_value\":\"none\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"116239\",\"setting_name\":\"width\",\"setting_value\":\"100\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"116239\",\"setting_name\":\"width_measure\",\"setting_value\":\"%\",\"language_id\":0,\"visibility\":\"w768\"}],\"css\":{\"current\":[{\"id\":1888214,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"padding-left\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1889731,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"padding-right\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1892800,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"text-align\",\"value\":\"center\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1894804,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1894981,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn \",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1895651,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn \",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1895772,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1924031,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-top\",\"value\":\"-5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1924032,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1924033,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1924034,\"theme_name\":\"ferraramalta\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"translation\":[]},\"id_old\":\"224958\",\"id\":224959,\"theme_name\":\"furniture\",\"microtime\":\"1664375795.558420\",\"siblings\":[{\"id\":224959,\"microtime\":\"1664375795.558420\",\"theme_name\":\"furniture\",\"block_name\":\"block-224957\",\"widget_name\":\"cart\\\\CheckoutBtn\",\"widget_params\":\"\",\"sort_order\":4}],\"block_name\":\"1664375625.054\"},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:36:35\",\"active\":0,\"admin_id\":28},{\"steps_id\":93,\"parent_id\":92,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1664375625.054\",\"block_name\":\"116326\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":[{\"microtime\":\"1664375625.054\",\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":[],\"sub_1\":[{\"microtime\":\"1664375795.558420\",\"block_name\":\"block-224957\",\"widget_name\":\"cart\\\\CheckoutBtn\",\"widget_params\":\"\",\"sort_order\":\"4\",\"settings\":[{\"microtime\":\"1664375795.558420\",\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1664375795.558420\",\"setting_name\":\"box_align\",\"setting_value\":\"4\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1664375795.558420\",\"setting_name\":\"text-align\",\"setting_value\":\"center\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"1664375795.558420\",\"setting_name\":\"float\",\"setting_value\":\"none\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"1664375795.558420\",\"setting_name\":\"width\",\"setting_value\":\"100\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"1664375795.558420\",\"setting_name\":\"width_measure\",\"setting_value\":\"%\",\"language_id\":0,\"visibility\":\"w768\"}],\"css\":{\"current\":[{\"id\":1478004,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"background-color\",\"value\":\"#eeeeee\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1487204,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"font-size\",\"value\":\"17\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1490432,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"margin-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1490884,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1491237,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1491427,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1491979,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1492021,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1492556,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-top\",\"value\":\"-5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1492603,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"margin-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1495449,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"padding-left\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1496972,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"padding-right\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1500061,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"text-align\",\"value\":\"center\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1502070,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1502247,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn \",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1502919,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn \",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1503040,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916199,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916200,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"content\",\"value\":\"\\\\f283\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916201,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916202,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916203,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"margin-left\",\"value\":\"15\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916204,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"font-size\",\"value\":\"21\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"translation\":[]}],\"box_id\":\"224957\",\"siblings\":[{\"id\":160706,\"microtime\":\"116327\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":6},{\"id\":160709,\"microtime\":\"116330\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":5},{\"id\":160715,\"microtime\":\"116336\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":160732,\"microtime\":\"116351\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":7},{\"id\":160736,\"microtime\":\"116354\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":4},{\"id\":224950,\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":224957,\"microtime\":\"1664375625.054\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:37:46\",\"active\":0,\"admin_id\":28},{\"steps_id\":95,\"parent_id\":94,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1664375625.054\",\"block_name\":\"116326\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":[{\"microtime\":\"1664375625.054\",\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":[],\"sub_1\":[{\"microtime\":\"1664375795.558420\",\"block_name\":\"block-224957\",\"widget_name\":\"cart\\\\CheckoutBtn\",\"widget_params\":\"\",\"sort_order\":\"4\",\"settings\":[{\"microtime\":\"1664375795.558420\",\"setting_name\":\"font-weight\",\"setting_value\":\"400\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1664375795.558420\",\"setting_name\":\"box_align\",\"setting_value\":\"4\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1664375795.558420\",\"setting_name\":\"text-align\",\"setting_value\":\"center\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"1664375795.558420\",\"setting_name\":\"float\",\"setting_value\":\"none\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"1664375795.558420\",\"setting_name\":\"width\",\"setting_value\":\"100\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"1664375795.558420\",\"setting_name\":\"width_measure\",\"setting_value\":\"%\",\"language_id\":0,\"visibility\":\"w768\"}],\"css\":{\"current\":[{\"id\":1478004,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"background-color\",\"value\":\"#eeeeee\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1487204,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"font-size\",\"value\":\"17\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1490432,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"margin-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1490884,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1491237,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1491427,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1491979,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1492021,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1492556,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .or-text\",\"attribute\":\"margin-top\",\"value\":\"-5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1492603,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn + .w-image\",\"attribute\":\"margin-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1495449,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"padding-left\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1496972,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"padding-right\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1500061,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"text-align\",\"value\":\"center\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1502070,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1502247,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn \",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1502919,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn \",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1503040,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn a\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916199,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916200,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"content\",\"value\":\"\\\\f283\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916201,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916202,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916203,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"margin-left\",\"value\":\"15\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"id\":1916204,\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"font-size\",\"value\":\"21\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"translation\":[]}],\"box_id\":\"224957\",\"siblings\":[{\"id\":160706,\"microtime\":\"116327\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":6},{\"id\":160709,\"microtime\":\"116330\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":5},{\"id\":160715,\"microtime\":\"116336\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":160732,\"microtime\":\"116351\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":7},{\"id\":160736,\"microtime\":\"116354\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":4},{\"id\":224950,\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":224957,\"microtime\":\"1664375625.054\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-28 15:37:54\",\"active\":0,\"admin_id\":28},{\"steps_id\":98,\"parent_id\":97,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:22:33\",\"active\":0,\"admin_id\":28},{\"steps_id\":100,\"parent_id\":99,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:22:36\",\"active\":0,\"admin_id\":28},{\"steps_id\":101,\"parent_id\":100,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:22:37\",\"active\":0,\"admin_id\":28},{\"steps_id\":102,\"parent_id\":101,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116352\",\"box_id\":\"160733\",\"page_name\":\"checkout\",\"box_settings\":[],\"box_settings_old\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:35:25\",\"active\":0,\"admin_id\":28},{\"steps_id\":104,\"parent_id\":103,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1639494585.748\",\"block_name\":\"116351\",\"widget_name\":\"DeliveryOptions\\\\Checkout\",\"widget_params\":\"\",\"sort_order\":\"0\",\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"160735\",\"siblings\":[{\"id\":160733,\"microtime\":\"116352\",\"theme_name\":\"furniture\",\"block_name\":\"block-160732\",\"widget_name\":\"cart\\\\Products\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":160734,\"microtime\":\"116353\",\"theme_name\":\"furniture\",\"block_name\":\"block-160732\",\"widget_name\":\"checkout\\\\CreateAccount\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":160735,\"microtime\":\"1639494585.748\",\"theme_name\":\"furniture\",\"block_name\":\"block-160732\",\"widget_name\":\"DeliveryOptions\\\\Checkout\",\"widget_params\":\"\",\"sort_order\":0}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:38:21\",\"active\":0,\"admin_id\":28},{\"steps_id\":105,\"parent_id\":104,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224950\",\"microtime\":\"1664256380.7348\",\"block_name\":\"116326\",\"sort_order\":1},{\"id\":\"160715\",\"microtime\":\"116336\",\"block_name\":\"116326\",\"sort_order\":2},{\"id\":\"160736\",\"microtime\":\"116354\",\"block_name\":\"116326\",\"sort_order\":3},{\"id\":\"160709\",\"microtime\":\"116330\",\"block_name\":\"116326\",\"sort_order\":4},{\"id\":\"160706\",\"microtime\":\"116327\",\"block_name\":\"116326\",\"sort_order\":5},{\"id\":\"160733\",\"microtime\":\"116352\",\"block_name\":\"116326\",\"sort_order\":6},{\"id\":\"160732\",\"microtime\":\"116351\",\"block_name\":\"116326\",\"sort_order\":7}],\"positions_old\":[{\"id\":\"224950\",\"block_name\":\"116326\",\"sort_order\":\"2\",\"microtime\":\"1664256380.7348\"},{\"id\":\"160715\",\"block_name\":\"116326\",\"sort_order\":\"3\",\"microtime\":\"116336\"},{\"id\":\"160736\",\"block_name\":\"116326\",\"sort_order\":\"4\",\"microtime\":\"116354\"},{\"id\":\"160709\",\"block_name\":\"116326\",\"sort_order\":\"5\",\"microtime\":\"116330\"},{\"id\":\"160706\",\"block_name\":\"116326\",\"sort_order\":\"6\",\"microtime\":\"116327\"},{\"id\":\"160733\",\"block_name\":\"116351\",\"sort_order\":\"1\",\"microtime\":\"116352\"},{\"id\":\"160732\",\"block_name\":\"116326\",\"sort_order\":\"7\",\"microtime\":\"116351\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:38:26\",\"active\":0,\"admin_id\":28},{\"steps_id\":106,\"parent_id\":105,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224950\",\"microtime\":\"1664256380.7348\",\"block_name\":\"116326\",\"sort_order\":1},{\"id\":\"160715\",\"microtime\":\"116336\",\"block_name\":\"116326\",\"sort_order\":2},{\"id\":\"160736\",\"microtime\":\"116354\",\"block_name\":\"116326\",\"sort_order\":3},{\"id\":\"160709\",\"microtime\":\"116330\",\"block_name\":\"116326\",\"sort_order\":4},{\"id\":\"160706\",\"microtime\":\"116327\",\"block_name\":\"116326\",\"sort_order\":5},{\"id\":\"160733\",\"microtime\":\"116352\",\"block_name\":\"116326\",\"sort_order\":6},{\"id\":\"160734\",\"microtime\":\"116353\",\"block_name\":\"116326\",\"sort_order\":7},{\"id\":\"160732\",\"microtime\":\"116351\",\"block_name\":\"116326\",\"sort_order\":8}],\"positions_old\":[{\"id\":\"224950\",\"block_name\":\"116326\",\"sort_order\":\"1\",\"microtime\":\"1664256380.7348\"},{\"id\":\"160715\",\"block_name\":\"116326\",\"sort_order\":\"2\",\"microtime\":\"116336\"},{\"id\":\"160736\",\"block_name\":\"116326\",\"sort_order\":\"3\",\"microtime\":\"116354\"},{\"id\":\"160709\",\"block_name\":\"116326\",\"sort_order\":\"4\",\"microtime\":\"116330\"},{\"id\":\"160706\",\"block_name\":\"116326\",\"sort_order\":\"5\",\"microtime\":\"116327\"},{\"id\":\"160733\",\"block_name\":\"116326\",\"sort_order\":\"6\",\"microtime\":\"116352\"},{\"id\":\"160734\",\"block_name\":\"116351\",\"sort_order\":\"2\",\"microtime\":\"116353\"},{\"id\":\"160732\",\"block_name\":\"116326\",\"sort_order\":\"7\",\"microtime\":\"116351\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:38:31\",\"active\":0,\"admin_id\":28},{\"steps_id\":107,\"parent_id\":106,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"116351\",\"block_name\":\"116326\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"8\",\"settings\":[{\"microtime\":\"116351\",\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116351\",\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"160732\",\"siblings\":[{\"id\":160706,\"microtime\":\"116327\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":5},{\"id\":160709,\"microtime\":\"116330\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":4},{\"id\":160715,\"microtime\":\"116336\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":160732,\"microtime\":\"116351\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":8},{\"id\":160733,\"microtime\":\"116352\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"cart\\\\Products\",\"widget_params\":\"\",\"sort_order\":6},{\"id\":160734,\"microtime\":\"116353\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"checkout\\\\CreateAccount\",\"widget_params\":\"\",\"sort_order\":7},{\"id\":160736,\"microtime\":\"116354\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":224950,\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\",\"block_name\":\"block-160705\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:38:35\",\"active\":0,\"admin_id\":28},{\"steps_id\":108,\"parent_id\":107,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116352\",\"box_id\":\"160733\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:39:03\",\"active\":0,\"admin_id\":28},{\"steps_id\":109,\"parent_id\":108,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116353\",\"box_id\":\"160734\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"padding-top\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"furniture\"},{\"setting_name\":\"margin-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"furniture\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"8\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"padding-top\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#eeeeee\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"8\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:40:07\",\"active\":0,\"admin_id\":28},{\"steps_id\":110,\"parent_id\":109,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116352\",\"box_id\":\"160733\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:40:23\",\"active\":0,\"admin_id\":28},{\"steps_id\":112,\"parent_id\":111,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116352\",\"box_id\":\"160733\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:41:31\",\"active\":0,\"admin_id\":28},{\"steps_id\":115,\"parent_id\":114,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .w-cart-listing.type-2.main-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .checkout-cart-listing.main-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:46:41\",\"active\":0,\"admin_id\":28},{\"steps_id\":116,\"parent_id\":115,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:46:41\",\"active\":0,\"admin_id\":28},{\"steps_id\":117,\"parent_id\":116,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-checkout-index .hiding-box .w-cart-listing.type-2.summary-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing.summary-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:47:15\",\"active\":0,\"admin_id\":28},{\"steps_id\":118,\"parent_id\":117,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:47:16\",\"active\":0,\"admin_id\":28},{\"steps_id\":119,\"parent_id\":118,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116352\",\"box_id\":\"160733\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116352\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:49:02\",\"active\":0,\"admin_id\":28},{\"steps_id\":121,\"parent_id\":120,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:50:05\",\"active\":0,\"admin_id\":28},{\"steps_id\":122,\"parent_id\":121,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value_old\":\"30\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value_old\":\"30\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value_old\":\"30\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value_old\":\"30\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_delete\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:50:05\",\"active\":0,\"admin_id\":28},{\"steps_id\":123,\"parent_id\":122,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:50:09\",\"active\":0,\"admin_id\":28},{\"steps_id\":124,\"parent_id\":123,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value_old\":\"30\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value_old\":\"30\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value_old\":\"30\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value_old\":\"30\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_delete\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:50:10\",\"active\":0,\"admin_id\":28},{\"steps_id\":125,\"parent_id\":124,\"event\":\"boxSave\",\"data\":{\"microtime\":\"116353\",\"box_id\":\"160734\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"furniture\"},{\"setting_name\":\"margin-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"furniture\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"116353\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"padding-top\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"8\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:52:59\",\"active\":0,\"admin_id\":28},{\"steps_id\":126,\"parent_id\":125,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1664256380.7348\",\"box_id\":\"224950\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1664256380.7348\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 16:53:13\",\"active\":0,\"admin_id\":28},{\"steps_id\":128,\"parent_id\":127,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:12:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":129,\"parent_id\":128,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value_old\":\"30\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value_old\":\"30\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value_old\":\"30\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value_old\":\"30\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_delete\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:12:46\",\"active\":0,\"admin_id\":28},{\"steps_id\":130,\"parent_id\":129,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:13:18\",\"active\":0,\"admin_id\":28},{\"steps_id\":131,\"parent_id\":130,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value_old\":\"30\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value_old\":\"30\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value_old\":\"30\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value_old\":\"30\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_delete\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:13:20\",\"active\":0,\"admin_id\":28},{\"steps_id\":132,\"parent_id\":131,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:13:51\",\"active\":0,\"admin_id\":28},{\"steps_id\":133,\"parent_id\":132,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value_old\":\"30\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value_old\":\"30\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value_old\":\"30\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value_old\":\"30\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_delete\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:13:53\",\"active\":0,\"admin_id\":28},{\"steps_id\":134,\"parent_id\":133,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:14:54\",\"active\":0,\"admin_id\":28},{\"steps_id\":135,\"parent_id\":134,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value_old\":\"30\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value_old\":\"30\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value_old\":\"30\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value_old\":\"30\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_delete\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:14:54\",\"active\":0,\"admin_id\":28},{\"steps_id\":136,\"parent_id\":135,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"margin-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"margin-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"margin-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"margin-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:15:55\",\"active\":0,\"admin_id\":28},{\"steps_id\":137,\"parent_id\":136,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:15:56\",\"active\":0,\"admin_id\":28},{\"steps_id\":138,\"parent_id\":137,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value_old\":\"15\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value_old\":\"10\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value_old\":\"15\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value_old\":\"10\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_delete\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"margin-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"margin-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"margin-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"margin-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:16:40\",\"active\":0,\"admin_id\":28},{\"steps_id\":139,\"parent_id\":138,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:16:41\",\"active\":0,\"admin_id\":28},{\"steps_id\":140,\"parent_id\":139,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:18:55\",\"active\":0,\"admin_id\":28},{\"steps_id\":141,\"parent_id\":140,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:18:56\",\"active\":0,\"admin_id\":28},{\"steps_id\":142,\"parent_id\":141,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-products\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-products\",\"attribute\":\"border-bottom-color\",\"value\":\"#e0e0e0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:40:30\",\"active\":0,\"admin_id\":28},{\"steps_id\":144,\"parent_id\":143,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:40:32\",\"active\":0,\"admin_id\":28},{\"steps_id\":145,\"parent_id\":144,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-09-29 17:40:33\",\"active\":0,\"admin_id\":28},{\"steps_id\":146,\"parent_id\":145,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"content\",\"value\":\"\\\\f283\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"margin-left\",\"value\":\"15\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"selector\":\".w-cart-checkout-btn .btn-to-checkout\",\"attribute\":\"font-size\",\"value\":\"21\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"font-size\",\"value\":\"21\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"content\",\"value\":\"\\\\f283\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"margin-left\",\"value\":\"15\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-03 15:47:29\",\"active\":0,\"admin_id\":28},{\"steps_id\":148,\"parent_id\":147,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-03 15:47:30\",\"active\":0,\"admin_id\":28},{\"steps_id\":149,\"parent_id\":148,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-03 15:47:31\",\"active\":0,\"admin_id\":28},{\"steps_id\":150,\"parent_id\":149,\"event\":\"boxSave\",\"data\":{\"microtime\":\"117389\",\"box_id\":\"161802\",\"page_name\":\"main\",\"box_settings\":[{\"setting_name\":\"col_in_row\",\"setting_value\":\"4\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_attributes\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"3\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"w576\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"listing_type\",\"setting_value\":\"productListing\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_qty_input\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_compare\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"lazy_load\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_model\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_properties\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_bonus_points\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_buy_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_view_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_wishlist_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"hide_parents\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"col_in_row\",\"setting_value\":\"4\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"view_as\",\"setting_value\":\"carousel\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_attributes\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"3\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"w768\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"w576\"},{\"setting_name\":\"listing_type\",\"setting_value\":\"productListing\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_qty_input\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_compare\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"lazy_load\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_model\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_properties\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_bonus_points\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_buy_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_view_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_wishlist_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"hide_parents\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-03 18:33:09\",\"active\":0,\"admin_id\":28},{\"steps_id\":152,\"parent_id\":151,\"event\":\"boxSave\",\"data\":{\"microtime\":\"117389\",\"box_id\":\"161802\",\"page_name\":\"main\",\"box_settings\":[{\"setting_name\":\"col_in_row\",\"setting_value\":\"4\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_attributes\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"3\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"w576\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"listing_type\",\"setting_value\":\"productListing\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_qty_input\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_compare\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"lazy_load\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_model\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_properties\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_bonus_points\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_buy_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_view_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_wishlist_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"hide_parents\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"col_in_row\",\"setting_value\":\"4\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_attributes\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"3\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"w768\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"w576\"},{\"setting_name\":\"listing_type\",\"setting_value\":\"productListing\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_qty_input\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_compare\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"lazy_load\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_model\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_properties\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_bonus_points\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_buy_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_view_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_wishlist_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"hide_parents\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-03 18:54:23\",\"active\":0,\"admin_id\":28},{\"steps_id\":154,\"parent_id\":153,\"event\":\"boxSave\",\"data\":{\"microtime\":\"117389\",\"box_id\":\"161802\",\"page_name\":\"main\",\"box_settings\":[{\"setting_name\":\"col_in_row\",\"setting_value\":\"4\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_attributes\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"3\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"w576\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"listing_type\",\"setting_value\":\"productListing\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_qty_input\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_compare\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"lazy_load\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_model\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_properties\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_bonus_points\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_buy_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_view_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"show_wishlist_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"hide_parents\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"},{\"setting_name\":\"view_as\",\"setting_value\":\"carousel\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"117389\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[{\"setting_name\":\"col_in_row\",\"setting_value\":\"4\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_attributes\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"3\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"w768\"},{\"setting_name\":\"col_in_row\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"w576\"},{\"setting_name\":\"listing_type\",\"setting_value\":\"productListing\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_qty_input\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_compare\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"lazy_load\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_model\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_properties\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_bonus_points\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_buy_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_view_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"show_wishlist_button\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"hide_parents\",\"setting_value\":\"2\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-03 18:56:01\",\"active\":0,\"admin_id\":28},{\"steps_id\":156,\"parent_id\":155,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .w-cart-products\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .w-cart-products\",\"attribute\":\"border-bottom-color\",\"value\":\"#e0e0e0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .checkout-cart-listing\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .checkout-cart-listing\",\"attribute\":\"border-bottom-color\",\"value\":\"#e0e0e0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-04 10:07:37\",\"active\":0,\"admin_id\":28},{\"steps_id\":158,\"parent_id\":157,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-04 10:07:41\",\"active\":0,\"admin_id\":28},{\"steps_id\":159,\"parent_id\":158,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-04 10:07:42\",\"active\":0,\"admin_id\":28},{\"steps_id\":160,\"parent_id\":159,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value_old\":\"flex\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"height\",\"value\":\"23\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"display\",\"value\":\"block\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:00:59\",\"active\":0,\"admin_id\":28},{\"steps_id\":162,\"parent_id\":161,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:01:01\",\"active\":0,\"admin_id\":28},{\"steps_id\":163,\"parent_id\":162,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:01:02\",\"active\":0,\"admin_id\":28},{\"steps_id\":164,\"parent_id\":163,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .bottom-totals .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .bottom-totals .price-box .price-row.total\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:02:28\",\"active\":0,\"admin_id\":28},{\"steps_id\":165,\"parent_id\":164,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:02:29\",\"active\":0,\"admin_id\":28},{\"steps_id\":166,\"parent_id\":165,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .bottom-totals .price-box .icon\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .bottom-totals .price-box .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:04:11\",\"active\":0,\"admin_id\":28},{\"steps_id\":167,\"parent_id\":166,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:04:12\",\"active\":0,\"admin_id\":28},{\"steps_id\":168,\"parent_id\":167,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".w-cart-listing .promos-info .promo-name\",\"attribute\":\"border_radius_1_measure\",\"value_old\":\"\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"},{\"selector\":\".w-cart-listing .promos-info .promo-name\",\"attribute\":\"border_radius_4_measure\",\"value_old\":\"\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"}],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-cart-listing .price small\",\"attribute\":\"display\",\"value\":\"block\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-listing .price small\",\"attribute\":\"line-height\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:05:38\",\"active\":0,\"admin_id\":28},{\"steps_id\":169,\"parent_id\":168,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:05:39\",\"active\":0,\"admin_id\":28},{\"steps_id\":170,\"parent_id\":169,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:11:50\",\"active\":0,\"admin_id\":28},{\"steps_id\":171,\"parent_id\":170,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:11:50\",\"active\":0,\"admin_id\":28},{\"steps_id\":172,\"parent_id\":171,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .price\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:12:26\",\"active\":0,\"admin_id\":28},{\"steps_id\":173,\"parent_id\":172,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:13:35\",\"active\":0,\"admin_id\":28},{\"steps_id\":174,\"parent_id\":173,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".order-summary .icon\",\"attribute\":\"height\",\"value_old\":\"23\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"line-height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"line_height_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:17:32\",\"active\":0,\"admin_id\":28},{\"steps_id\":175,\"parent_id\":174,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 12:17:32\",\"active\":0,\"admin_id\":28},{\"steps_id\":209,\"parent_id\":175,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".order-summary .w-cart-listing .price\",\"attribute\":\"font-size\",\"value_old\":\"18\",\"value\":\"16\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 14:06:56\",\"active\":0,\"admin_id\":28},{\"steps_id\":211,\"parent_id\":210,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 14:06:58\",\"active\":0,\"admin_id\":28},{\"steps_id\":220,\"parent_id\":211,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .w-cart-listing .multi-cart .item\",\"attribute\":\"grid-template-rows\",\"value\":\"1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 14:29:37\",\"active\":0,\"admin_id\":28},{\"steps_id\":221,\"parent_id\":220,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 14:29:37\",\"active\":0,\"admin_id\":28},{\"steps_id\":222,\"parent_id\":221,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-checkout-index .w-cart-listing .multi-cart .item\",\"attribute\":\"grid-template-rows\",\"value\":\"1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".p-checkout-index .w-cart-listing .multi-cart .item\",\"attribute\":\"grid-template-rows\",\"value\":\"1fr\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 14:30:51\",\"active\":0,\"admin_id\":28},{\"steps_id\":223,\"parent_id\":222,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 14:30:52\",\"active\":0,\"admin_id\":28},{\"steps_id\":332,\"parent_id\":223,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 20:37:35\",\"active\":0,\"admin_id\":28},{\"steps_id\":334,\"parent_id\":333,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 20:37:40\",\"active\":0,\"admin_id\":28},{\"steps_id\":335,\"parent_id\":334,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 20:37:41\",\"active\":0,\"admin_id\":28},{\"steps_id\":366,\"parent_id\":335,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".w-checkout-shipping-choice span\",\"attribute\":\"padding-left\",\"value_old\":\"10\",\"value\":\"6\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"selector\":\".w-checkout-shipping-choice span\",\"attribute\":\"padding-right\",\"value_old\":\"10\",\"value\":\"6\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"}],\"attributes_delete\":[{\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-ms-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-webkit-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"}],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 20:58:32\",\"active\":0,\"admin_id\":28},{\"steps_id\":367,\"parent_id\":366,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-ms-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"theme_name\":\"furniture\",\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-webkit-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"theme_name\":\"furniture\",\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-ms-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"theme_name\":\"furniture\",\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-webkit-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-16 20:58:33\",\"active\":0,\"admin_id\":28},{\"steps_id\":406,\"parent_id\":367,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .w-cart-listing .item .points\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-17 06:02:36\",\"active\":0,\"admin_id\":28},{\"steps_id\":408,\"parent_id\":407,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-17 06:02:37\",\"active\":0,\"admin_id\":28},{\"steps_id\":409,\"parent_id\":408,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-17 06:02:38\",\"active\":0,\"admin_id\":28},{\"steps_id\":423,\"parent_id\":409,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1666100388.2869\",\"block_name\":\"120864\",\"page_name\":null,\"widget_name\":\"BlockBox\",\"sort_order\":0},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-18 14:39:48\",\"active\":0,\"admin_id\":45},{\"steps_id\":425,\"parent_id\":424,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1666100388.2869\",\"box_id\":\"229887\",\"page_name\":\"main\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1666100388.2869\",\"theme_name\":\"furniture\"}],\"box_settings_old\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-18 14:40:47\",\"active\":0,\"admin_id\":45},{\"steps_id\":427,\"parent_id\":426,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1666100388.2869\",\"block_name\":\"120864\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"0\",\"settings\":[{\"microtime\":\"1666100388.2869\",\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"229887\",\"siblings\":[{\"id\":161805,\"microtime\":\"120865\",\"theme_name\":\"furniture\",\"block_name\":\"block-161804\",\"widget_name\":\"Banner\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":161806,\"microtime\":\"121015\",\"theme_name\":\"furniture\",\"block_name\":\"block-161804\",\"widget_name\":\"Html_box\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":229887,\"microtime\":\"1666100388.2869\",\"theme_name\":\"furniture\",\"block_name\":\"block-161804\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":0}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-18 14:42:46\",\"active\":0,\"admin_id\":45},{\"steps_id\":531,\"parent_id\":428,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-21 07:48:43\",\"active\":0,\"admin_id\":28},{\"steps_id\":533,\"parent_id\":532,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-21 07:48:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":534,\"parent_id\":533,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-21 07:48:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":595,\"parent_id\":534,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120945\",\"block_name\":\"116212\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1478537,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1486714,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1490508,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-navigation\",\"attribute\":\"margin-bottom\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1493762,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1495095,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1496433,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1497734,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"}]},\"translation\":[],\"box_id\":\"160609\",\"siblings\":[{\"id\":160576,\"microtime\":\"116214\",\"theme_name\":\"furniture\",\"block_name\":\"block-160575\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":160609,\"microtime\":\"120945\",\"theme_name\":\"furniture\",\"block_name\":\"block-160575\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-24 08:25:39\",\"active\":0,\"admin_id\":28},{\"steps_id\":597,\"parent_id\":596,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120945\",\"block_name\":\"116212\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1478537,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1486714,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1490508,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-navigation\",\"attribute\":\"margin-bottom\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1493762,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1495095,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1496433,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1497734,\"theme_name\":\"furniture\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"}]},\"translation\":[],\"box_id\":\"160609\",\"siblings\":[{\"id\":160576,\"microtime\":\"116214\",\"theme_name\":\"furniture\",\"block_name\":\"block-160575\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":160609,\"microtime\":\"120945\",\"theme_name\":\"furniture\",\"block_name\":\"block-160575\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-24 08:25:42\",\"active\":0,\"admin_id\":28},{\"steps_id\":599,\"parent_id\":598,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"margin-bottom\",\"value_old\":\"20\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-24 08:26:25\",\"active\":0,\"admin_id\":28},{\"steps_id\":600,\"parent_id\":599,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2022-10-24 08:26:26\",\"active\":0,\"admin_id\":28}]','furniture','2022-10-26 14:03:08',0,0,''),(4,0,'applyMigration','[{\"steps_id\":306,\"parent_id\":0,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[{\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value_old\":\"flex\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"line-height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"line_height_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"display\",\"value\":\"block\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2022-10-16 19:18:04\",\"active\":0,\"admin_id\":28},{\"steps_id\":308,\"parent_id\":307,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2022-10-16 19:18:05\",\"active\":0,\"admin_id\":28},{\"steps_id\":309,\"parent_id\":308,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2022-10-16 19:18:05\",\"active\":0,\"admin_id\":28},{\"steps_id\":310,\"parent_id\":309,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2022-10-16 19:18:42\",\"active\":0,\"admin_id\":28},{\"steps_id\":311,\"parent_id\":310,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120900\",\"block_name\":\"116229-3\",\"widget_name\":\"cart\\\\SubTotal\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1552631,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1555057,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total .title\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1555058,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"font-size\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1555670,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total .title\",\"attribute\":\"font-weight\",\"value\":\"700\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1555671,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"font-weight\",\"value\":\"700\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1558405,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-bottom\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1559026,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1559616,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1560206,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total \",\"attribute\":\"margin-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1567846,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"text-align\",\"value\":\"right\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1570092,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1570093,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total .price-row > div\",\"attribute\":\"width\",\"value\":\"50\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1570832,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total .price-row\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1570833,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total .price-row > div\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"},{\"id\":1828794,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-sub-total .price\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".w-cart-sub-total\"}]},\"translation\":[],\"box_id\":\"168073\",\"siblings\":[{\"id\":168073,\"microtime\":\"120900\",\"theme_name\":\"furniture-mobile\",\"block_name\":\"block-168064-3\",\"widget_name\":\"cart\\\\SubTotal\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":168074,\"microtime\":\"1639476084.6036\",\"theme_name\":\"furniture-mobile\",\"block_name\":\"block-168064-3\",\"widget_name\":\"cart\\\\FreeDelivery\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2022-10-16 19:28:59\",\"active\":0,\"admin_id\":28},{\"steps_id\":313,\"parent_id\":312,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[{\"selector\":\".w-checkout-shipping-choice span\",\"attribute\":\"padding-left\",\"value_old\":\"10\",\"value\":\"6\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"selector\":\".w-checkout-shipping-choice span\",\"attribute\":\"padding-right\",\"value_old\":\"10\",\"value\":\"6\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"}],\"attributes_delete\":[{\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-ms-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"},{\"selector\":\".w-checkout-shipping-choice input:checked + span:before\",\"attribute\":\"-webkit-transform\",\"value\":\"rotate(45deg)\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-checkout-shipping-choice\"}],\"attributes_new\":[]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2022-10-16 19:30:26\",\"active\":0,\"admin_id\":28},{\"steps_id\":314,\"parent_id\":313,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665945121.9283\",\"block_name\":\"116326\",\"page_name\":null,\"widget_name\":\"BlockBox\",\"sort_order\":0},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2022-10-16 19:32:01\",\"active\":0,\"admin_id\":28},{\"steps_id\":315,\"parent_id\":314,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665945121.9283\",\"box_id\":\"224972\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"}],\"box_settings_old\":[]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2022-10-16 19:32:18\",\"active\":0,\"admin_id\":28},{\"steps_id\":316,\"parent_id\":315,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665945121.9283\",\"box_id\":\"224972\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"29\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2022-10-16 19:33:31\",\"active\":0,\"admin_id\":28},{\"steps_id\":317,\"parent_id\":316,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665945223.4062\",\"block_name\":\"1665945121.9283\",\"page_name\":null,\"widget_name\":\"checkout\\\\LoginOnForm\",\"sort_order\":0},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2022-10-16 19:33:43\",\"active\":0,\"admin_id\":28},{\"steps_id\":319,\"parent_id\":318,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665945121.9283\",\"box_id\":\"224972\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665945121.9283\",\"theme_name\":\"furniture-mobile\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"29\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2022-10-16 19:34:50\",\"active\":0,\"admin_id\":28}]','furniture-mobile','2022-10-26 14:03:09',0,0,''),(5,0,'applyMigration','[{\"steps_id\":244,\"parent_id\":0,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[{\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value_old\":\"flex\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".order-summary .checkout-cart-listing\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .checkout-cart-listing\",\"attribute\":\"border-bottom-color\",\"value\":\"#e0e0e0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .checkout-cart-listing.main-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"line-height\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"line_height_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"display\",\"value\":\"block\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 14:59:55\",\"active\":0,\"admin_id\":28},{\"steps_id\":246,\"parent_id\":245,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 14:59:56\",\"active\":0,\"admin_id\":28},{\"steps_id\":247,\"parent_id\":246,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .headings\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .headings\",\"attribute\":\"grid-template-columns\",\"value\":\"3fr 1fr 1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"3fr 1fr 1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-rows\",\"value\":\"1fr\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"grid-column\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item .name\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price\",\"attribute\":\"grid-column\",\"value\":\"3\\/4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price\",\"attribute\":\"grid-row\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty\",\"attribute\":\"grid-column\",\"value\":\"2\\/3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty\",\"attribute\":\"grid-row\",\"value\":\"1\\/2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item > div ~ div\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item > div.image\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .price\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing.type-2 .image\",\"attribute\":\"grid-column\",\"value\":\"1 \\/ 3\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing.type-2 .image\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"1fr\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:00:50\",\"active\":0,\"admin_id\":28},{\"steps_id\":248,\"parent_id\":247,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:00:51\",\"active\":0,\"admin_id\":28},{\"steps_id\":249,\"parent_id\":248,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".order-summary .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:01:22\",\"active\":0,\"admin_id\":28},{\"steps_id\":250,\"parent_id\":249,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:01:23\",\"active\":0,\"admin_id\":28},{\"steps_id\":251,\"parent_id\":250,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665928935.3129\",\"block_name\":\"73511\",\"page_name\":null,\"widget_name\":\"BlockBox\",\"sort_order\":0},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:02:15\",\"active\":0,\"admin_id\":28},{\"steps_id\":252,\"parent_id\":251,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224963\",\"microtime\":\"1665928935.3129\",\"block_name\":\"73500\",\"sort_order\":1},{\"id\":\"209351\",\"microtime\":\"73510\",\"block_name\":\"73500\",\"sort_order\":2},{\"id\":\"209369\",\"microtime\":\"73528\",\"block_name\":\"73500\",\"sort_order\":3},{\"id\":\"209345\",\"microtime\":\"73504\",\"block_name\":\"73500\",\"sort_order\":4},{\"id\":\"209342\",\"microtime\":\"73501\",\"block_name\":\"73500\",\"sort_order\":5},{\"id\":\"209366\",\"microtime\":\"73525\",\"block_name\":\"73500\",\"sort_order\":6}],\"positions_old\":[{\"id\":\"224963\",\"block_name\":\"73511\",\"sort_order\":\"0\",\"microtime\":\"1665928935.3129\"},{\"id\":\"209351\",\"block_name\":\"73500\",\"sort_order\":\"2\",\"microtime\":\"73510\"},{\"id\":\"209369\",\"block_name\":\"73500\",\"sort_order\":\"3\",\"microtime\":\"73528\"},{\"id\":\"209345\",\"block_name\":\"73500\",\"sort_order\":\"4\",\"microtime\":\"73504\"},{\"id\":\"209342\",\"block_name\":\"73500\",\"sort_order\":\"5\",\"microtime\":\"73501\"},{\"id\":\"209366\",\"block_name\":\"73500\",\"sort_order\":\"6\",\"microtime\":\"73525\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:02:21\",\"active\":0,\"admin_id\":28},{\"steps_id\":253,\"parent_id\":252,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665928935.3129\",\"box_id\":\"224963\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"}],\"box_settings_old\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:02:25\",\"active\":0,\"admin_id\":28},{\"steps_id\":254,\"parent_id\":253,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665928935.3129\",\"box_id\":\"224963\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:02:58\",\"active\":0,\"admin_id\":28},{\"steps_id\":255,\"parent_id\":254,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665928988.5154\",\"block_name\":\"1665928935.3129\",\"page_name\":null,\"widget_name\":\"checkout\\\\LoginOnForm\",\"sort_order\":0},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:03:08\",\"active\":0,\"admin_id\":28},{\"steps_id\":256,\"parent_id\":255,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665928935.3129\",\"box_id\":\"224963\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:03:17\",\"active\":0,\"admin_id\":28},{\"steps_id\":258,\"parent_id\":257,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665929257.8163\",\"block_name\":\"73536\",\"page_name\":null,\"widget_name\":\"cart\\\\Products\",\"sort_order\":0},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:07:37\",\"active\":0,\"admin_id\":28},{\"steps_id\":259,\"parent_id\":258,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"209379\",\"microtime\":\"73538\",\"block_name\":\"73536\",\"sort_order\":1},{\"id\":\"224965\",\"microtime\":\"1665929257.8163\",\"block_name\":\"73536\",\"sort_order\":2},{\"id\":\"209381\",\"microtime\":\"73540\",\"block_name\":\"73536\",\"sort_order\":3},{\"id\":\"209382\",\"microtime\":\"73541\",\"block_name\":\"73536\",\"sort_order\":4},{\"id\":\"209380\",\"microtime\":\"73539\",\"block_name\":\"73536\",\"sort_order\":5},{\"id\":\"209378\",\"microtime\":\"73537\",\"block_name\":\"73536\",\"sort_order\":6}],\"positions_old\":[{\"id\":\"209379\",\"block_name\":\"73536\",\"sort_order\":\"1\",\"microtime\":\"73538\"},{\"id\":\"224965\",\"block_name\":\"73536\",\"sort_order\":\"0\",\"microtime\":\"1665929257.8163\"},{\"id\":\"209381\",\"block_name\":\"73536\",\"sort_order\":\"2\",\"microtime\":\"73540\"},{\"id\":\"209382\",\"block_name\":\"73536\",\"sort_order\":\"3\",\"microtime\":\"73541\"},{\"id\":\"209380\",\"block_name\":\"73536\",\"sort_order\":\"4\",\"microtime\":\"73539\"},{\"id\":\"209378\",\"block_name\":\"73536\",\"sort_order\":\"5\",\"microtime\":\"73537\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:07:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":261,\"parent_id\":260,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".p-checkout-index .closeable-heading + .closeable-content\",\"attribute\":\"padding-top\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-checkout-index .closeable-heading .heading-2\",\"attribute\":\"margin-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:08:52\",\"active\":0,\"admin_id\":28},{\"steps_id\":262,\"parent_id\":261,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:08:53\",\"active\":0,\"admin_id\":28},{\"steps_id\":263,\"parent_id\":262,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73504\",\"box_id\":\"209345\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73504\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73504\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73504\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73504\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73504\",\"theme_name\":\"watch\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73504\",\"theme_name\":\"watch\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73504\",\"theme_name\":\"watch\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box closeable-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73504\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"14\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box closeable-box\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:09:33\",\"active\":0,\"admin_id\":28},{\"steps_id\":264,\"parent_id\":263,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73501\",\"box_id\":\"209342\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73501\",\"theme_name\":\"watch\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73501\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73501\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73501\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73501\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73501\",\"theme_name\":\"watch\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73501\",\"theme_name\":\"watch\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box closeable-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73501\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"14\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box closeable-box\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:09:55\",\"active\":0,\"admin_id\":28},{\"steps_id\":266,\"parent_id\":265,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224963\",\"microtime\":\"1665928935.3129\",\"block_name\":\"73500\",\"sort_order\":1},{\"id\":\"209351\",\"microtime\":\"73510\",\"block_name\":\"73500\",\"sort_order\":2},{\"id\":\"209369\",\"microtime\":\"73528\",\"block_name\":\"73500\",\"sort_order\":3},{\"id\":\"209345\",\"microtime\":\"73504\",\"block_name\":\"73500\",\"sort_order\":4},{\"id\":\"209342\",\"microtime\":\"73501\",\"block_name\":\"73500\",\"sort_order\":5},{\"id\":\"209367\",\"microtime\":\"73526\",\"block_name\":\"73500\",\"sort_order\":6},{\"id\":\"209366\",\"microtime\":\"73525\",\"block_name\":\"73500\",\"sort_order\":7}],\"positions_old\":[{\"id\":\"224963\",\"block_name\":\"73500\",\"sort_order\":\"1\",\"microtime\":\"1665928935.3129\"},{\"id\":\"209351\",\"block_name\":\"73500\",\"sort_order\":\"2\",\"microtime\":\"73510\"},{\"id\":\"209369\",\"block_name\":\"73500\",\"sort_order\":\"3\",\"microtime\":\"73528\"},{\"id\":\"209345\",\"block_name\":\"73500\",\"sort_order\":\"4\",\"microtime\":\"73504\"},{\"id\":\"209342\",\"block_name\":\"73500\",\"sort_order\":\"5\",\"microtime\":\"73501\"},{\"id\":\"209367\",\"block_name\":\"73525\",\"sort_order\":\"1\",\"microtime\":\"73526\"},{\"id\":\"209366\",\"block_name\":\"73500\",\"sort_order\":\"6\",\"microtime\":\"73525\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:10:58\",\"active\":0,\"admin_id\":28},{\"steps_id\":267,\"parent_id\":266,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"224963\",\"microtime\":\"1665928935.3129\",\"block_name\":\"73500\",\"sort_order\":1},{\"id\":\"209351\",\"microtime\":\"73510\",\"block_name\":\"73500\",\"sort_order\":2},{\"id\":\"209369\",\"microtime\":\"73528\",\"block_name\":\"73500\",\"sort_order\":3},{\"id\":\"209345\",\"microtime\":\"73504\",\"block_name\":\"73500\",\"sort_order\":4},{\"id\":\"209342\",\"microtime\":\"73501\",\"block_name\":\"73500\",\"sort_order\":5},{\"id\":\"209367\",\"microtime\":\"73526\",\"block_name\":\"73500\",\"sort_order\":6},{\"id\":\"209368\",\"microtime\":\"73527\",\"block_name\":\"73500\",\"sort_order\":7},{\"id\":\"209366\",\"microtime\":\"73525\",\"block_name\":\"73500\",\"sort_order\":8}],\"positions_old\":[{\"id\":\"224963\",\"block_name\":\"73500\",\"sort_order\":\"1\",\"microtime\":\"1665928935.3129\"},{\"id\":\"209351\",\"block_name\":\"73500\",\"sort_order\":\"2\",\"microtime\":\"73510\"},{\"id\":\"209369\",\"block_name\":\"73500\",\"sort_order\":\"3\",\"microtime\":\"73528\"},{\"id\":\"209345\",\"block_name\":\"73500\",\"sort_order\":\"4\",\"microtime\":\"73504\"},{\"id\":\"209342\",\"block_name\":\"73500\",\"sort_order\":\"5\",\"microtime\":\"73501\"},{\"id\":\"209367\",\"block_name\":\"73500\",\"sort_order\":\"6\",\"microtime\":\"73526\"},{\"id\":\"209368\",\"block_name\":\"73525\",\"sort_order\":\"2\",\"microtime\":\"73527\"},{\"id\":\"209366\",\"block_name\":\"73500\",\"sort_order\":\"7\",\"microtime\":\"73525\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:11:08\",\"active\":0,\"admin_id\":28},{\"steps_id\":268,\"parent_id\":267,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"73525\",\"block_name\":\"73500\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"8\",\"settings\":[{\"microtime\":\"73525\",\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"73525\",\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"73525\",\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"73525\",\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"73525\",\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"73525\",\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"73525\",\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"73525\",\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"209366\",\"siblings\":[{\"id\":209342,\"microtime\":\"73501\",\"theme_name\":\"watch\",\"block_name\":\"block-209341\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":5},{\"id\":209345,\"microtime\":\"73504\",\"theme_name\":\"watch\",\"block_name\":\"block-209341\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":4},{\"id\":209351,\"microtime\":\"73510\",\"theme_name\":\"watch\",\"block_name\":\"block-209341\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":209366,\"microtime\":\"73525\",\"theme_name\":\"watch\",\"block_name\":\"block-209341\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":8},{\"id\":209367,\"microtime\":\"73526\",\"theme_name\":\"watch\",\"block_name\":\"block-209341\",\"widget_name\":\"cart\\\\Products\",\"widget_params\":\"\",\"sort_order\":6},{\"id\":209368,\"microtime\":\"73527\",\"theme_name\":\"watch\",\"block_name\":\"block-209341\",\"widget_name\":\"checkout\\\\CreateAccount\",\"widget_params\":\"\",\"sort_order\":7},{\"id\":209369,\"microtime\":\"73528\",\"theme_name\":\"watch\",\"block_name\":\"block-209341\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":224963,\"microtime\":\"1665928935.3129\",\"theme_name\":\"watch\",\"block_name\":\"block-209341\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:11:10\",\"active\":0,\"admin_id\":28},{\"steps_id\":269,\"parent_id\":268,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73526\",\"box_id\":\"209367\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:11:26\",\"active\":0,\"admin_id\":28},{\"steps_id\":271,\"parent_id\":270,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".p-checkout-index .hiding-box .checkout-cart-listing.summary-listing\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:12:29\",\"active\":0,\"admin_id\":28},{\"steps_id\":272,\"parent_id\":271,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:12:29\",\"active\":0,\"admin_id\":28},{\"steps_id\":273,\"parent_id\":272,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73526\",\"box_id\":\"209367\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:12:55\",\"active\":0,\"admin_id\":28},{\"steps_id\":275,\"parent_id\":274,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73526\",\"box_id\":\"209367\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73526\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"style_class\",\"setting_value\":\"hiding-box\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 15:13:26\",\"active\":0,\"admin_id\":28},{\"steps_id\":279,\"parent_id\":276,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".p-checkout-index .w-cart-listing .item .price\",\"attribute\":\"float\",\"value\":\"none\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-checkout-index .w-cart-listing .item .price\",\"attribute\":\"text-align\",\"value\":\"right\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 18:30:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":281,\"parent_id\":280,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 18:30:46\",\"active\":0,\"admin_id\":28},{\"steps_id\":282,\"parent_id\":281,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 18:30:47\",\"active\":0,\"admin_id\":28},{\"steps_id\":283,\"parent_id\":282,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73527\",\"box_id\":\"209368\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"padding-top\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73527\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73527\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73527\",\"theme_name\":\"watch\"},{\"setting_name\":\"margin-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73527\",\"theme_name\":\"watch\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73527\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"30\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73527\",\"theme_name\":\"watch\"},{\"setting_name\":\"margin-bottom\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73527\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"padding-top\",\"setting_value\":\"10\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-left\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"margin-top\",\"setting_value\":\"20\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"background-color\",\"setting_value\":\"#eeeeee\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-bottom\",\"setting_value\":\"8\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-16 18:32:54\",\"active\":0,\"admin_id\":28},{\"steps_id\":392,\"parent_id\":284,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"content\",\"value\":\"\\\\f283\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"margin-left\",\"value\":\"15\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-checkout-btn .with-card\",\"attribute\":\"font-weight\",\"value\":\"400\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-checkout-btn\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-17 05:53:17\",\"active\":0,\"admin_id\":28},{\"steps_id\":394,\"parent_id\":393,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-17 05:53:17\",\"active\":0,\"admin_id\":28},{\"steps_id\":395,\"parent_id\":394,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-17 05:53:18\",\"active\":0,\"admin_id\":28},{\"steps_id\":396,\"parent_id\":395,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".p-checkout-index .checkout-cart-listing.main-listing\",\"attribute\":\"background-color\",\"value\":\"#ffffff\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-checkout-index .checkout-cart-listing.main-listing\",\"attribute\":\"padding-top\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-checkout-index .checkout-cart-listing.main-listing\",\"attribute\":\"padding-right\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-checkout-index .checkout-cart-listing.main-listing\",\"attribute\":\"padding-bottom\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-checkout-index .checkout-cart-listing.main-listing\",\"attribute\":\"padding-left\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-17 05:56:40\",\"active\":0,\"admin_id\":28},{\"steps_id\":397,\"parent_id\":396,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-17 05:56:41\",\"active\":0,\"admin_id\":28},{\"steps_id\":398,\"parent_id\":397,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\"#frmCheckout\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"w1200\",\"media\":\"\",\"accessibility\":\"\"},{\"theme_name\":\"watch\",\"selector\":\"#frmCheckout\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"w1200\",\"media\":\"\",\"accessibility\":\"\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-17 05:57:39\",\"active\":0,\"admin_id\":28},{\"steps_id\":399,\"parent_id\":398,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-17 05:57:40\",\"active\":0,\"admin_id\":28},{\"steps_id\":400,\"parent_id\":399,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\"#frmCheckout\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"w1200\",\"media\":\"\",\"accessibility\":\"\"},{\"selector\":\"#frmCheckout\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"w1200\",\"media\":\"\",\"accessibility\":\"\"}],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\"#frmCheckout .checkout > .type-1\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"w1200\",\"media\":\"\",\"accessibility\":\"\"},{\"theme_name\":\"watch\",\"selector\":\"#frmCheckout .checkout > .type-1\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"w1200\",\"media\":\"\",\"accessibility\":\"\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-17 05:58:37\",\"active\":0,\"admin_id\":28},{\"steps_id\":401,\"parent_id\":400,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-17 05:58:38\",\"active\":0,\"admin_id\":28},{\"steps_id\":402,\"parent_id\":401,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".order-summary .w-cart-listing .item .points\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-17 05:59:56\",\"active\":0,\"admin_id\":28},{\"steps_id\":403,\"parent_id\":402,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-17 05:59:57\",\"active\":0,\"admin_id\":28},{\"steps_id\":576,\"parent_id\":403,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"209242\",\"microtime\":\"115924\",\"block_name\":\"115931\",\"sort_order\":1},{\"id\":\"209255\",\"microtime\":\"115934\",\"block_name\":\"115931\",\"sort_order\":2},{\"id\":\"209254\",\"microtime\":\"115933\",\"block_name\":\"115931\",\"sort_order\":3},{\"id\":\"209253\",\"microtime\":\"115932\",\"block_name\":\"115931\",\"sort_order\":4}],\"positions_old\":[{\"id\":\"209242\",\"block_name\":\"115923\",\"sort_order\":\"1\",\"microtime\":\"115924\"},{\"id\":\"209255\",\"block_name\":\"115931\",\"sort_order\":\"1\",\"microtime\":\"115934\"},{\"id\":\"209254\",\"block_name\":\"115931\",\"sort_order\":\"2\",\"microtime\":\"115933\"},{\"id\":\"209253\",\"block_name\":\"115931\",\"sort_order\":\"4\",\"microtime\":\"115932\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:45:16\",\"active\":0,\"admin_id\":28},{\"steps_id\":578,\"parent_id\":577,\"event\":\"boxSave\",\"data\":{\"microtime\":\"115934\",\"box_id\":\"209255\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"style_class\",\"setting_value\":\"bottom-totals\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"115934\",\"theme_name\":\"watch\"}],\"box_settings_old\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:45:35\",\"active\":0,\"admin_id\":28},{\"steps_id\":579,\"parent_id\":578,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"209243\",\"microtime\":\"115925\",\"block_name\":\"115923\",\"sort_order\":1}],\"positions_old\":[{\"id\":\"209243\",\"block_name\":\"115923-2\",\"sort_order\":\"1\",\"microtime\":\"115925\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:45:42\",\"active\":0,\"admin_id\":28},{\"steps_id\":580,\"parent_id\":579,\"event\":\"blocksMove\",\"data\":{\"positions\":[{\"id\":\"209244\",\"microtime\":\"115926\",\"block_name\":\"115923-2\",\"sort_order\":1}],\"positions_old\":[{\"id\":\"209244\",\"block_name\":\"115923-3\",\"sort_order\":\"1\",\"microtime\":\"115926\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:45:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":581,\"parent_id\":580,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1666338369.6032\",\"block_name\":\"115931\",\"page_name\":null,\"widget_name\":\"cart\\\\OrderTotal\",\"sort_order\":0},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:46:09\",\"active\":0,\"admin_id\":28},{\"steps_id\":582,\"parent_id\":581,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1666338369.6032\",\"box_id\":\"234722\",\"page_name\":\"cart\",\"box_settings\":[{\"setting_name\":\"style_class\",\"setting_value\":\"top-totals\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1666338369.6032\",\"theme_name\":\"watch\"}],\"box_settings_old\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:46:28\",\"active\":0,\"admin_id\":28},{\"steps_id\":584,\"parent_id\":583,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".order-summary .top-totals .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"watch\",\"selector\":\".order-summary .top-totals .price-row\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:47:01\",\"active\":0,\"admin_id\":28},{\"steps_id\":585,\"parent_id\":584,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:47:02\",\"active\":0,\"admin_id\":28},{\"steps_id\":586,\"parent_id\":585,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-shopping-cart-index .gift-code .heading-4\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"0,2,4\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"selector\":\".p-shopping-cart-index .gift-code .heading-4\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"0,4\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"selector\":\".p-shopping-cart-index .gift-code .heading-4\",\"attribute\":\"font-family\",\"value\":\"FontAwesome\",\"visibility\":\"0,4\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"selector\":\".p-shopping-cart-index .gift-code .heading-4\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"0,4\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"selector\":\".p-shopping-cart-index .gift-code .heading-4\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"0,4\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"selector\":\".p-shopping-cart-index .gift-code .heading-4\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"0,4\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".p-shopping-cart-index .order-summary .bottom-totals .icon\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-shopping-cart-index .order-summary .bottom-totals .icon\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-shopping-cart-index .order-summary .bottom-totals .price-row\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-shopping-cart-index .order-summary .bottom-totals .price-box .price-row.total\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-shopping-cart-index .gift-code .heading-4\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-shopping-cart-index .gift-code .heading-4\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-shopping-cart-index .gift-code .heading-4\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-shopping-cart-index .gift-code .heading-4\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-shopping-cart-index .gift-code .heading-4\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"watch\",\"selector\":\".p-shopping-cart-index .gift-code .heading-4\",\"attribute\":\"font-family\",\"value\":\"FontAwesome\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:47:20\",\"active\":0,\"admin_id\":28},{\"steps_id\":587,\"parent_id\":586,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:47:21\",\"active\":0,\"admin_id\":28},{\"steps_id\":588,\"parent_id\":587,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"color\",\"value\":\"#00a858\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"%\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"bold\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-right\",\"value\":\"5\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"background-color\",\"value\":\"#eeeeee\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-top\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .discount-box\",\"attribute\":\"margin-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .inp\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"400\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"0.75\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f107\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-family\",\"value\":\"\'fontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-left\",\"value\":\"10\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-size\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp\",\"attribute\":\"margin-top\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:48:23\",\"active\":0,\"admin_id\":28},{\"steps_id\":589,\"parent_id\":588,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:48:24\",\"active\":0,\"admin_id\":28},{\"steps_id\":590,\"parent_id\":589,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon input[type=\\\"text\\\"]\",\"attribute\":\"width\",\"value_old\":\"140\",\"value\":\"100\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon input[type=\\\"text\\\"]\",\"attribute\":\"width_important\",\"value\":\"important\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon input[type=\\\"text\\\"]\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:48:43\",\"active\":0,\"admin_id\":28},{\"steps_id\":591,\"parent_id\":590,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[{\"selector\":\".order-summary .price-box\",\"attribute\":\"margin-bottom\",\"value_old\":\"20\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:49:48\",\"active\":0,\"admin_id\":28},{\"steps_id\":592,\"parent_id\":591,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-cart-listing .remove-btn span\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"},{\"selector\":\".w-cart-listing .remove-btn span\",\"attribute\":\"display_important\",\"value\":\"important\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"}],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:52:00\",\"active\":0,\"admin_id\":28},{\"steps_id\":593,\"parent_id\":592,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-cart-listing .item .price\",\"attribute\":\"float\",\"value\":\"left\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"},{\"selector\":\".w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"80px 1fr 150px 130px\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"},{\"selector\":\".w-cart-listing .item .price\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".w-cart-listing\"}],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:52:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":594,\"parent_id\":593,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-21 08:52:45\",\"active\":0,\"admin_id\":28},{\"steps_id\":611,\"parent_id\":594,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"73433\",\"block_name\":\"73432\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1786602,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1795607,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1799675,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-navigation\",\"attribute\":\"margin-bottom\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1803267,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1804623,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1806010,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1807344,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"}]},\"translation\":[],\"box_id\":\"209230\",\"siblings\":[{\"id\":209230,\"microtime\":\"73433\",\"theme_name\":\"watch\",\"block_name\":\"block-209229\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":209231,\"microtime\":\"115908\",\"theme_name\":\"watch\",\"block_name\":\"block-209229\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-24 08:32:25\",\"active\":0,\"admin_id\":28},{\"steps_id\":613,\"parent_id\":612,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"73433\",\"block_name\":\"73432\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1786602,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1795607,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1799675,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-navigation\",\"attribute\":\"margin-bottom\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1803267,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1804623,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1806010,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1807344,\"theme_name\":\"watch\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"}]},\"translation\":[],\"box_id\":\"209230\",\"siblings\":[{\"id\":209230,\"microtime\":\"73433\",\"theme_name\":\"watch\",\"block_name\":\"block-209229\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":209231,\"microtime\":\"115908\",\"theme_name\":\"watch\",\"block_name\":\"block-209229\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"watch\",\"date_added\":\"2022-10-24 08:32:30\",\"active\":0,\"admin_id\":28}]','watch','2022-10-26 14:03:12',0,0,''),(6,0,'applyMigration','[{\"steps_id\":285,\"parent_id\":0,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665942917.1838\",\"block_name\":\"113736\",\"page_name\":null,\"widget_name\":\"BlockBox\",\"sort_order\":0},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 18:55:17\",\"active\":0,\"admin_id\":28},{\"steps_id\":287,\"parent_id\":286,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665942917.1838\",\"box_id\":\"224966\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665942917.1838\",\"theme_name\":\"watch-mobile\"}],\"box_settings_old\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 18:56:28\",\"active\":0,\"admin_id\":28},{\"steps_id\":288,\"parent_id\":287,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"113724\",\"block_name\":\"113723\",\"widget_name\":\"Html_box\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":[{\"microtime\":\"113724\",\"setting_name\":\"text\",\"setting_value\":\"<div class=\\\"heading-2 ship-ico\\\">##TEXT_SHIPPING##<\\/div>\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[{\"id\":1816114,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .linkedin\",\"attribute\":\"color\",\"value\":\"#0073b0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816115,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .instagram\",\"attribute\":\"color\",\"value\":\"#d02f7a\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816116,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .stumbleupon\",\"attribute\":\"color\",\"value\":\"#eb4924\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816117,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .pinterest\",\"attribute\":\"color\",\"value\":\"#bd081c\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816118,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .twitter\",\"attribute\":\"color\",\"value\":\"#1b95e0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816119,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .facebook\",\"attribute\":\"color\",\"value\":\"#4267b2\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816121,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .google-plus\",\"attribute\":\"color\",\"value\":\"#dc4a38\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816552,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .stumbleupon\",\"attribute\":\"content\",\"value\":\"\\\\f1a4\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816553,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .twitter\",\"attribute\":\"content\",\"value\":\"\\\\f099\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816554,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .linkedin\",\"attribute\":\"content\",\"value\":\"\\\\f0e1\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816555,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .instagram\",\"attribute\":\"content\",\"value\":\"\\\\f16d\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816556,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .pinterest\",\"attribute\":\"content\",\"value\":\"\\\\f0d2\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816557,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .facebook\",\"attribute\":\"content\",\"value\":\"\\\\f230\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1816558,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .google-plus\",\"attribute\":\"content\",\"value\":\"\\\\f2b3\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1818194,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .socials\",\"attribute\":\"font-family\",\"value\":\"FontAwesome\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1818504,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .socials a\",\"attribute\":\"font-size\",\"value\":\"26\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1818516,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .socials a\",\"attribute\":\"font-size\",\"value\":\"30\",\"visibility\":\"w720\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1820754,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .socials a\",\"attribute\":\"margin-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1821146,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .socials a\",\"attribute\":\"margin-left\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1821430,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .socials a\",\"attribute\":\"margin-right\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1821731,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .socials a\",\"attribute\":\"margin-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-html_box\"},{\"id\":1826479,\"theme_name\":\"watch-mobile\",\"selector\":\".w-html_box .socials a\",\"attribute\":\"text-decoration\",\"value\":\"none\",\"visibility\":\"1\",\"media\":\"\",\"accessibility\":\".w-html_box\"}]},\"translation\":{\"main\":{\"TEXT_SHIPPING\":{\"en\":\"Shipping\"}}},\"box_id\":\"211801\",\"siblings\":[{\"id\":211801,\"microtime\":\"113724\",\"theme_name\":\"watch-mobile\",\"block_name\":\"block-211800\",\"widget_name\":\"Html_box\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":211802,\"microtime\":\"113725\",\"theme_name\":\"watch-mobile\",\"block_name\":\"block-211800\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":211808,\"microtime\":\"113731\",\"theme_name\":\"watch-mobile\",\"block_name\":\"block-211800\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":4},{\"id\":211812,\"microtime\":\"113735\",\"theme_name\":\"watch-mobile\",\"block_name\":\"block-211800\",\"widget_name\":\"Neighbour\\\\Checkout\",\"widget_params\":\"\",\"sort_order\":5},{\"id\":211813,\"microtime\":\"113736\",\"theme_name\":\"watch-mobile\",\"block_name\":\"block-211800\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 18:58:36\",\"active\":0,\"admin_id\":28},{\"steps_id\":290,\"parent_id\":288,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1665943133.880417\",\"block_name\":\"1665943133.815952\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"0\",\"settings\":[{\"microtime\":\"1665943133.880417\",\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"224969\",\"siblings\":[{\"id\":224968,\"microtime\":\"1665943133.878737\",\"theme_name\":\"watch-mobile\",\"block_name\":\"block-224967\",\"widget_name\":\"checkout\\\\ShippingChoice\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":224969,\"microtime\":\"1665943133.880417\",\"theme_name\":\"watch-mobile\",\"block_name\":\"block-224967\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":0}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 18:59:15\",\"active\":0,\"admin_id\":28},{\"steps_id\":291,\"parent_id\":290,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665943189.9632\",\"block_name\":\"113723\",\"page_name\":null,\"widget_name\":\"BlockBox\",\"sort_order\":0},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 18:59:49\",\"active\":0,\"admin_id\":28},{\"steps_id\":292,\"parent_id\":291,\"event\":\"boxSave\",\"data\":{\"microtime\":\"1665943189.9632\",\"box_id\":\"224970\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"1665943189.9632\",\"theme_name\":\"watch-mobile\"}],\"box_settings_old\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:00:03\",\"active\":0,\"admin_id\":28},{\"steps_id\":293,\"parent_id\":292,\"event\":\"boxAdd\",\"data\":{\"block_id\":null,\"microtime\":\"1665943216.4571\",\"block_name\":\"1665943189.9632\",\"page_name\":null,\"widget_name\":\"checkout\\\\LoginOnForm\",\"sort_order\":0},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:00:16\",\"active\":0,\"admin_id\":28},{\"steps_id\":295,\"parent_id\":294,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .add-buttons.hide-box\",\"attribute\":\"position\",\"value\":\"relative\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:04:26\",\"active\":0,\"admin_id\":28},{\"steps_id\":296,\"parent_id\":295,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:04:26\",\"active\":0,\"admin_id\":28},{\"steps_id\":297,\"parent_id\":296,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .heading-2\",\"attribute\":\"text-align\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .heading-2\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:05:19\",\"active\":0,\"admin_id\":28},{\"steps_id\":298,\"parent_id\":297,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .w-checkout-login-on-form\",\"attribute\":\"margin-bottom\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:05:47\",\"active\":0,\"admin_id\":28},{\"steps_id\":299,\"parent_id\":298,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:05:48\",\"active\":0,\"admin_id\":28},{\"steps_id\":300,\"parent_id\":299,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[{\"selector\":\".p-checkout-index .heading-2\",\"attribute\":\"font-size\",\"value_old\":\"18\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:06:27\",\"active\":0,\"admin_id\":28},{\"steps_id\":301,\"parent_id\":300,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"padding-right\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:07:14\",\"active\":0,\"admin_id\":28},{\"steps_id\":302,\"parent_id\":301,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:07:15\",\"active\":0,\"admin_id\":28},{\"steps_id\":303,\"parent_id\":302,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"padding-right\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .closeable-heading .heading-2\",\"attribute\":\"padding-right\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:07:35\",\"active\":0,\"admin_id\":28},{\"steps_id\":304,\"parent_id\":303,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".w-cart-discount-coupon .discount-box .inp\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:11:13\",\"active\":0,\"admin_id\":28},{\"steps_id\":305,\"parent_id\":304,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2022-10-16 19:11:14\",\"active\":1,\"admin_id\":28}]','watch-mobile','2022-10-26 14:03:13',0,0,''),(7,0,'applyMigration','{\"0\":{\"steps_id\":48,\"parent_id\":1,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-account-address-book .btn-del\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-account-address-book .btn-edit\",\"attribute\":\"margin-right\",\"value\":\"7\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-12 16:50:27\",\"active\":0,\"admin_id\":44},\"1\":{\"steps_id\":50,\"parent_id\":49,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-12 16:50:28\",\"active\":0,\"admin_id\":44},\"2\":{\"steps_id\":51,\"parent_id\":50,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-12 16:50:29\",\"active\":0,\"admin_id\":44},\"3\":{\"steps_id\":52,\"parent_id\":51,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-12 16:53:06\",\"active\":0,\"admin_id\":44},\"4\":{\"steps_id\":53,\"parent_id\":52,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-12 16:53:06\",\"active\":0,\"admin_id\":44},\"5\":{\"steps_id\":54,\"parent_id\":53,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-12 16:53:41\",\"active\":0,\"admin_id\":44},\"6\":{\"steps_id\":55,\"parent_id\":54,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-12 16:53:42\",\"active\":0,\"admin_id\":44},\"7\":{\"steps_id\":125,\"parent_id\":55,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-17 17:08:18\",\"active\":0,\"admin_id\":44},\"8\":{\"steps_id\":127,\"parent_id\":126,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-17 17:08:29\",\"active\":0,\"admin_id\":44},\"9\":{\"steps_id\":128,\"parent_id\":127,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-17 17:08:33\",\"active\":0,\"admin_id\":44},\"10\":{\"steps_id\":129,\"parent_id\":128,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-17 17:16:47\",\"active\":0,\"admin_id\":44},\"11\":{\"steps_id\":130,\"parent_id\":129,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-17 17:17:32\",\"active\":0,\"admin_id\":44},\"12\":{\"steps_id\":131,\"parent_id\":130,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary \",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-17 17:18:51\",\"active\":0,\"admin_id\":44},\"13\":{\"steps_id\":132,\"parent_id\":131,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary \",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon.selected\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-17 17:23:05\",\"active\":0,\"admin_id\":44},\"14\":{\"steps_id\":133,\"parent_id\":132,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .icon.selected\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".order-summary .icon.opened\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-18 18:31:29\",\"active\":0,\"admin_id\":44},\"15\":{\"steps_id\":135,\"parent_id\":134,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"deals\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[{\"theme_name\":\"deals\",\"selector\":\".w-cart-discount-coupon .title.opened\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"deals\",\"date_added\":\"2023-02-18 18:32:27\",\"active\":1,\"admin_id\":44},\"designer_mode\":\"\"}','deals','2023-02-22 13:14:33',1,0,'basic'),(8,0,'applyMigration','{\"0\":{\"steps_id\":38,\"parent_id\":2,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120945\",\"block_name\":\"116212\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1829603,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1829676,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-li\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1830639,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .tab-li\",\"attribute\":\"border-bottom-width\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1830642,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-li\",\"attribute\":\"border-bottom-width\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1837941,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1839002,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"14\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1841885,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-navigation\",\"attribute\":\"margin-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1845202,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1846606,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1847997,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1849345,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"}]},\"translation\":[],\"box_id\":\"214100\",\"siblings\":[{\"id\":214068,\"microtime\":\"116214\",\"theme_name\":\"printshop\",\"block_name\":\"block-214067\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":214100,\"microtime\":\"120945\",\"theme_name\":\"printshop\",\"block_name\":\"block-214067\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-12 15:52:02\",\"active\":0,\"admin_id\":44},\"1\":{\"steps_id\":40,\"parent_id\":39,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120945\",\"block_name\":\"116212\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1829603,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1829676,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-li\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"2\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1830639,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .tab-li\",\"attribute\":\"border-bottom-width\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1830642,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-li\",\"attribute\":\"border-bottom-width\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1837941,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1839002,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"14\",\"visibility\":\"w576\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1841885,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-navigation\",\"attribute\":\"margin-bottom\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1845202,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1846606,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1847997,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1849345,\"theme_name\":\"printshop\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"}]},\"translation\":[],\"box_id\":\"214100\",\"siblings\":[{\"id\":214068,\"microtime\":\"116214\",\"theme_name\":\"printshop\",\"block_name\":\"block-214067\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":214100,\"microtime\":\"120945\",\"theme_name\":\"printshop\",\"block_name\":\"block-214067\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-12 15:52:09\",\"active\":0,\"admin_id\":44},\"2\":{\"steps_id\":41,\"parent_id\":40,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"1639494018\",\"block_name\":\"116214\",\"widget_name\":\"cart\\\\DependedProducts\",\"widget_params\":\"8\",\"sort_order\":\"2\",\"settings\":[{\"microtime\":\"1639494018\",\"setting_name\":\"listing_type\",\"setting_value\":\"productListing\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1639494018\",\"setting_name\":\"col_in_row\",\"setting_value\":\"4\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1639494018\",\"setting_name\":\"show_popup\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1639494018\",\"setting_name\":\"col_in_row\",\"setting_value\":\"3\",\"language_id\":0,\"visibility\":\"w992\"},{\"microtime\":\"1639494018\",\"setting_name\":\"col_in_row\",\"setting_value\":\"2\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"1639494018\",\"setting_name\":\"col_in_row\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"w576\"},{\"microtime\":\"1639494018\",\"setting_name\":\"padding-top\",\"setting_value\":\"20\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1639494018\",\"setting_name\":\"padding-left\",\"setting_value\":\"25\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1639494018\",\"setting_name\":\"padding-right\",\"setting_value\":\"25\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1639494018\",\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1639494018\",\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1639494018\",\"setting_name\":\"margin-bottom\",\"setting_value\":\"5\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"1639494018\",\"setting_name\":\"padding-left\",\"setting_value\":\"15\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"1639494018\",\"setting_name\":\"padding-right\",\"setting_value\":\"15\",\"language_id\":0,\"visibility\":\"w768\"}],\"css\":{\"current\":[]},\"translation\":[],\"box_id\":\"214093\",\"siblings\":[{\"id\":214069,\"microtime\":\"116215\",\"theme_name\":\"printshop\",\"block_name\":\"block-214068\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":4},{\"id\":214072,\"microtime\":\"116218\",\"theme_name\":\"printshop\",\"block_name\":\"block-214068\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":214087,\"microtime\":\"116224\",\"theme_name\":\"printshop\",\"block_name\":\"block-214068\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":214092,\"microtime\":\"116235\",\"theme_name\":\"printshop\",\"block_name\":\"block-214068\",\"widget_name\":\"cart\\\\ShippingEstimator\",\"widget_params\":\"\",\"sort_order\":5},{\"id\":214093,\"microtime\":\"1639494018\",\"theme_name\":\"printshop\",\"block_name\":\"block-214068\",\"widget_name\":\"cart\\\\DependedProducts\",\"widget_params\":\"8\",\"sort_order\":2}]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-12 15:52:47\",\"active\":0,\"admin_id\":44},\"3\":{\"steps_id\":43,\"parent_id\":42,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"116224\",\"block_name\":\"116214\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":\"3\",\"settings\":[{\"microtime\":\"116224\",\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116224\",\"setting_name\":\"padding-top\",\"setting_value\":\"20\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116224\",\"setting_name\":\"padding-bottom\",\"setting_value\":\"20\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116224\",\"setting_name\":\"padding-left\",\"setting_value\":\"25\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116224\",\"setting_name\":\"padding-right\",\"setting_value\":\"25\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116224\",\"setting_name\":\"background-color\",\"setting_value\":\"#ffffff\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116224\",\"setting_name\":\"margin-bottom\",\"setting_value\":\"5\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116224\",\"setting_name\":\"padding-left\",\"setting_value\":\"15\",\"language_id\":0,\"visibility\":\"w768\"},{\"microtime\":\"116224\",\"setting_name\":\"padding-right\",\"setting_value\":\"15\",\"language_id\":0,\"visibility\":\"w768\"}],\"css\":{\"current\":[]},\"translation\":[],\"sub_1\":[{\"microtime\":\"116225\",\"block_name\":\"block-214087\",\"widget_name\":\"cart\\\\GiveAway\",\"widget_params\":\"\",\"sort_order\":\"2\",\"settings\":[{\"microtime\":\"116225\",\"setting_name\":\"hide_parents\",\"setting_value\":\"2\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[{\"id\":1829707,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"border-bottom-color\",\"value\":\"#e0e0e0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1830379,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1833426,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column:nth-child(2n + 1)\",\"attribute\":\"clear\",\"value\":\"both\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1833538,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_name\",\"attribute\":\"clear\",\"value\":\"both\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1834842,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_name\",\"attribute\":\"content\",\"value\":\"\\\\_\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1835879,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away h2\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1836118,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_name\",\"attribute\":\"display\",\"value\":\"block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1837045,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes > div\",\"attribute\":\"float\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1837088,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"float\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1837162,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_img\",\"attribute\":\"float\",\"value\":\"left\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1837215,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_price .checkBoxWrap\",\"attribute\":\"float\",\"value\":\"right\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1837691,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_qty\",\"attribute\":\"font-family\",\"value\":\"Cabin\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1838584,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_name\",\"attribute\":\"font-size\",\"value\":\"16\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1838585,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_qty\",\"attribute\":\"font-size\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1838586,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_qty\",\"attribute\":\"font-size\",\"value\":\"17\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1839459,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_price\",\"attribute\":\"font-weight\",\"value\":\"700\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1841810,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes > div\",\"attribute\":\"margin-bottom\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1842263,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_wrapper\",\"attribute\":\"margin-bottom\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1842825,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes > div\",\"attribute\":\"margin-left\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1842833,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"margin-left\",\"value\":\"2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1842931,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1843447,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"margin-right\",\"value\":\"2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1843532,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes > div\",\"attribute\":\"margin-right\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1843538,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_img\",\"attribute\":\"margin-right\",\"value\":\"2\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1843539,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1843862,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes > div\",\"attribute\":\"margin-top\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1844301,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes > div\",\"attribute\":\"margin_bottom_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1844314,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"margin_left_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1844324,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes > div\",\"attribute\":\"margin_left_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1844351,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"margin_right_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1844355,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_img\",\"attribute\":\"margin_right_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1844356,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes > div\",\"attribute\":\"margin_right_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1844365,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes > div\",\"attribute\":\"margin_top_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1844838,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_ovr\",\"attribute\":\"overflow\",\"value\":\"hidden\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1844839,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_wrapper\",\"attribute\":\"overflow\",\"value\":\"hidden\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1845555,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1847198,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_img\",\"attribute\":\"padding-left\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1848567,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_img\",\"attribute\":\"padding-right\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1849120,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1850451,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_img\",\"attribute\":\"padding_left_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1850467,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_img\",\"attribute\":\"padding_right_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1851930,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_img\",\"attribute\":\"text-align\",\"value\":\"center\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1853741,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes select\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1853794,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"width\",\"value\":\"46\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1853795,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes > div\",\"attribute\":\"width\",\"value\":\"48\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1854147,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_img\",\"attribute\":\"width\",\"value\":\"30\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1854148,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1854654,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes select\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1854687,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1854806,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_attributes > div\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1855017,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_img\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"},{\"id\":1855018,\"theme_name\":\"printshop\",\"selector\":\".w-cart-give-away .ga_column\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-give-away\"}]},\"translation\":[]},{\"microtime\":\"116226\",\"block_name\":\"block-214087\",\"widget_name\":\"Html_box\",\"widget_params\":\"\",\"sort_order\":\"1\",\"settings\":[{\"microtime\":\"116226\",\"setting_name\":\"text\",\"setting_value\":\"<div class=\\\"heading-3\\\">##TEXT_GA_PRODUCTS##<\\/div>\",\"language_id\":0,\"visibility\":\"\"},{\"microtime\":\"116226\",\"setting_name\":\"style_class\",\"setting_value\":\"shipping-ico\",\"language_id\":0,\"visibility\":\"\"}],\"css\":{\"current\":[],\".shipping-ico\":[{\"id\":1829958,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"border-bottom-color\",\"value\":\"#e5e5e5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1830566,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1838797,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1842376,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"margin-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1843022,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1843621,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1844227,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"margin-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1846030,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"padding-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1847442,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1848791,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"},{\"id\":1850164,\"theme_name\":\"printshop\",\"selector\":\".shipping-ico .heading-3\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".shipping-ico\"}]},\"translation\":{\"main\":{\"TEXT_GA_PRODUCTS\":{\"en\":\"The items you can get for free if your basket value has reached an appointed value\"}}}}],\"box_id\":\"214087\",\"siblings\":[{\"id\":214069,\"microtime\":\"116215\",\"theme_name\":\"printshop\",\"block_name\":\"block-214068\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":4},{\"id\":214072,\"microtime\":\"116218\",\"theme_name\":\"printshop\",\"block_name\":\"block-214068\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":1},{\"id\":214087,\"microtime\":\"116224\",\"theme_name\":\"printshop\",\"block_name\":\"block-214068\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":3},{\"id\":214092,\"microtime\":\"116235\",\"theme_name\":\"printshop\",\"block_name\":\"block-214068\",\"widget_name\":\"cart\\\\ShippingEstimator\",\"widget_params\":\"\",\"sort_order\":5}]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-12 15:52:55\",\"active\":0,\"admin_id\":44},\"4\":{\"steps_id\":45,\"parent_id\":44,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"1fr\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-12 16:36:44\",\"active\":0,\"admin_id\":44},\"5\":{\"steps_id\":46,\"parent_id\":45,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-12 16:36:45\",\"active\":0,\"admin_id\":44},\"6\":{\"steps_id\":47,\"parent_id\":46,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-12 16:37:51\",\"active\":0,\"admin_id\":44},\"7\":{\"steps_id\":136,\"parent_id\":47,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".w-cart-discount-coupon .title.opened\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-18 18:58:46\",\"active\":0,\"admin_id\":44},\"8\":{\"steps_id\":138,\"parent_id\":137,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-18 18:58:54\",\"active\":0,\"admin_id\":44},\"9\":{\"steps_id\":139,\"parent_id\":138,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon.opened\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-18 18:59:21\",\"active\":0,\"admin_id\":44},\"10\":{\"steps_id\":140,\"parent_id\":139,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-18 18:59:24\",\"active\":0,\"admin_id\":44},\"11\":{\"steps_id\":141,\"parent_id\":140,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value_old\":\"\\\\f067\",\"value\":\"\\\\e61a\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon.opened\",\"attribute\":\"content\",\"value_old\":\"\\\\f068\",\"value\":\"\\\\e622\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_delete\":[{\"selector\":\".order-summary .icon\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-18 19:03:48\",\"active\":0,\"admin_id\":44},\"12\":{\"steps_id\":142,\"parent_id\":141,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-18 19:03:52\",\"active\":0,\"admin_id\":44},\"13\":{\"steps_id\":143,\"parent_id\":142,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-family\",\"value\":\"\'Themify\'\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"printshop\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-weight\",\"value\":\"600\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-18 19:07:18\",\"active\":0,\"admin_id\":44},\"14\":{\"steps_id\":144,\"parent_id\":143,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value_old\":\"\\\\f107\",\"value\":\"\\\\e64b\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-family\",\"value_old\":\"\'fontAwesome\'\",\"value\":\"\'Themify\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title.opened\",\"attribute\":\"content\",\"value_old\":\"\\\\f106\",\"value\":\"\\\\e648\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-18 19:10:30\",\"active\":0,\"admin_id\":44},\"15\":{\"steps_id\":145,\"parent_id\":144,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"printshop\",\"attributes_changed\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-size\",\"value_old\":\"24\",\"value\":\"18\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"printshop\",\"date_added\":\"2023-02-18 19:13:49\",\"active\":1,\"admin_id\":44},\"designer_mode\":\"\"}','printshop','2023-02-22 13:14:34',1,0,'basic'),(9,0,'applyMigration','{\"0\":{\"steps_id\":7,\"parent_id\":3,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-account-address-book .btn-del\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-10 16:45:21\",\"active\":0,\"admin_id\":44},\"1\":{\"steps_id\":9,\"parent_id\":8,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-account-address-book .btn-edit\",\"attribute\":\"margin-right\",\"value\":\"7\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-10 16:45:39\",\"active\":0,\"admin_id\":44},\"2\":{\"steps_id\":10,\"parent_id\":9,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-10 16:45:40\",\"active\":0,\"admin_id\":44},\"3\":{\"steps_id\":11,\"parent_id\":10,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-account-address-book .add_item\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"furniture\",\"selector\":\".w-account-address-book .add_item\",\"attribute\":\"align-items\",\"value\":\"center\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"furniture\",\"selector\":\".w-account-address-book .add_item\",\"attribute\":\"justify-content\",\"value\":\"center\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-10 16:46:41\",\"active\":0,\"admin_id\":44},\"4\":{\"steps_id\":12,\"parent_id\":11,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-10 16:46:42\",\"active\":0,\"admin_id\":44},\"5\":{\"steps_id\":13,\"parent_id\":12,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-account-address-book .btn-del\",\"attribute\":\"cursor\",\"value\":\"pointer\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-10 16:47:00\",\"active\":0,\"admin_id\":44},\"6\":{\"steps_id\":14,\"parent_id\":13,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-10 16:47:01\",\"active\":0,\"admin_id\":44},\"7\":{\"steps_id\":15,\"parent_id\":14,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-cart .price\",\"attribute\":\"font-size\",\"value\":\"16\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart a.item\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart a.item\",\"attribute\":\"border-bottom-color\",\"value\":\"#e0e0e0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-12 14:22:35\",\"active\":0,\"admin_id\":28},\"8\":{\"steps_id\":17,\"parent_id\":16,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-12 14:22:38\",\"active\":0,\"admin_id\":28},\"9\":{\"steps_id\":29,\"parent_id\":17,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-12 15:33:11\",\"active\":0,\"admin_id\":44},\"10\":{\"steps_id\":31,\"parent_id\":30,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-12 15:33:14\",\"active\":0,\"admin_id\":44},\"11\":{\"steps_id\":32,\"parent_id\":31,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-12 15:34:12\",\"active\":0,\"admin_id\":44},\"12\":{\"steps_id\":114,\"parent_id\":32,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .icon\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-13 17:00:05\",\"active\":0,\"admin_id\":28},\"13\":{\"steps_id\":116,\"parent_id\":115,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-13 17:00:07\",\"active\":0,\"admin_id\":28},\"14\":{\"steps_id\":117,\"parent_id\":116,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-size\",\"value\":\"18\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\'\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-13 17:00:11\",\"active\":0,\"admin_id\":28},\"15\":{\"steps_id\":118,\"parent_id\":117,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-13 17:00:12\",\"active\":0,\"admin_id\":28},\"16\":{\"steps_id\":119,\"parent_id\":118,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"400\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"0.75\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f107\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-family\",\"value\":\"\'fontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-left\",\"value\":\"10\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-13 18:38:52\",\"active\":0,\"admin_id\":44},\"17\":{\"steps_id\":121,\"parent_id\":120,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-13 18:38:54\",\"active\":0,\"admin_id\":44},\"18\":{\"steps_id\":122,\"parent_id\":121,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-size\",\"value\":\"24\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-weight\",\"value\":\"400\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"vertical-align\",\"value\":\"middle\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"line-height\",\"value\":\"0.75\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f107\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"display\",\"value\":\"inline-block\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"font-family\",\"value\":\"\'fontAwesome\'\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"margin-left\",\"value\":\"10\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-13 18:39:02\",\"active\":0,\"admin_id\":44},\"19\":{\"steps_id\":123,\"parent_id\":122,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-13 18:39:03\",\"active\":0,\"admin_id\":44},\"20\":{\"steps_id\":124,\"parent_id\":123,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-13 18:39:28\",\"active\":0,\"admin_id\":44},\"21\":{\"steps_id\":146,\"parent_id\":124,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".order-summary .icon.opened\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-18 19:16:38\",\"active\":0,\"admin_id\":44},\"22\":{\"steps_id\":148,\"parent_id\":147,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-18 19:17:00\",\"active\":0,\"admin_id\":44},\"23\":{\"steps_id\":149,\"parent_id\":148,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-18 19:17:03\",\"active\":0,\"admin_id\":44},\"24\":{\"steps_id\":150,\"parent_id\":149,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[{\"theme_name\":\"furniture\",\"selector\":\".w-cart-discount-coupon .title.opened\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-18 19:17:38\",\"active\":0,\"admin_id\":44},\"25\":{\"steps_id\":151,\"parent_id\":150,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture\",\"date_added\":\"2023-02-18 19:17:39\",\"active\":1,\"admin_id\":44},\"designer_mode\":\"\"}','furniture','2023-02-22 13:14:36',1,0,'basic'),(10,0,'applyMigration','{\"0\":{\"steps_id\":18,\"parent_id\":4,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture-mobile\",\"selector\":\".p-account-index .topInfo > div\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".p-account-index .topInfo > div\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".p-account-index .topInfo > div\",\"attribute\":\"float\",\"value\":\"none\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".p-account-index\"}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 14:30:14\",\"active\":0,\"admin_id\":44},\"1\":{\"steps_id\":20,\"parent_id\":19,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 14:30:15\",\"active\":0,\"admin_id\":44},\"2\":{\"steps_id\":21,\"parent_id\":20,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture-mobile\",\"selector\":\".p-account-index .topInfo > div\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".p-account-index\"}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 14:30:43\",\"active\":0,\"admin_id\":44},\"3\":{\"steps_id\":22,\"parent_id\":21,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 14:30:44\",\"active\":0,\"admin_id\":44},\"4\":{\"steps_id\":23,\"parent_id\":22,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 14:30:59\",\"active\":0,\"admin_id\":44},\"5\":{\"steps_id\":24,\"parent_id\":23,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture-mobile\",\"selector\":\".w-account-address-book .address-book\",\"attribute\":\"flex-direction\",\"value\":\"column\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".w-account-address-book .item\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".w-account-address-book .item\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".w-account-address-book .item\",\"attribute\":\"float\",\"value\":\"none\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 14:32:18\",\"active\":0,\"admin_id\":44},\"6\":{\"steps_id\":25,\"parent_id\":24,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 14:32:19\",\"active\":0,\"admin_id\":44},\"7\":{\"steps_id\":26,\"parent_id\":25,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 14:33:06\",\"active\":0,\"admin_id\":44},\"8\":{\"steps_id\":27,\"parent_id\":26,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture-mobile\",\"selector\":\".p-account-index .rightMes ul\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".p-account-index .rightMes ul\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".p-account-index .rightMes ul\",\"attribute\":\"padding-bottom\",\"value\":\"0\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".p-account-index .rightMes ul\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".p-account-index .rightMes ul\",\"attribute\":\"margin-top\",\"value\":\"0\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".p-account-index .rightMes ul\",\"attribute\":\"margin-right\",\"value\":\"0\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".p-account-index .rightMes ul\",\"attribute\":\"margin-bottom\",\"value\":\"0\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"furniture-mobile\",\"selector\":\".p-account-index .rightMes ul\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".p-account-index\"}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 14:35:04\",\"active\":0,\"admin_id\":44},\"9\":{\"steps_id\":28,\"parent_id\":27,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 14:35:05\",\"active\":0,\"admin_id\":44},\"10\":{\"steps_id\":33,\"parent_id\":28,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 15:42:00\",\"active\":0,\"admin_id\":44},\"11\":{\"steps_id\":35,\"parent_id\":34,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 15:42:02\",\"active\":0,\"admin_id\":44},\"12\":{\"steps_id\":36,\"parent_id\":35,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-account-address-book .btn-del\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}],\"attributes_new\":[{\"theme_name\":\"furniture-mobile\",\"selector\":\".w-account-address-book .btn-edit\",\"attribute\":\"margin-right\",\"value\":\"7\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 15:44:36\",\"active\":0,\"admin_id\":44},\"13\":{\"steps_id\":37,\"parent_id\":36,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 15:44:37\",\"active\":0,\"admin_id\":44},\"14\":{\"steps_id\":109,\"parent_id\":37,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120945\",\"block_name\":\"116212\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1545937,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1554114,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1557908,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-navigation\",\"attribute\":\"margin-bottom\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1561162,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1562495,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1563833,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1565134,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"}]},\"translation\":[],\"box_id\":\"168053\",\"siblings\":[{\"id\":168052,\"microtime\":\"116214\",\"theme_name\":\"furniture-mobile\",\"block_name\":\"block-170164\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":168053,\"microtime\":\"120945\",\"theme_name\":\"furniture-mobile\",\"block_name\":\"block-170164\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 18:03:17\",\"active\":0,\"admin_id\":44},\"15\":{\"steps_id\":111,\"parent_id\":110,\"event\":\"boxDelete\",\"data\":{\"microtime\":\"120945\",\"block_name\":\"116212\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":\"1\",\"css\":{\"current\":[{\"id\":1545937,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"border\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1554114,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-a\",\"attribute\":\"font-size\",\"value\":\"12\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1557908,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs .tab-navigation\",\"attribute\":\"margin-bottom\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1561162,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-bottom\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1562495,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1563833,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"},{\"id\":1565134,\"theme_name\":\"furniture-mobile\",\"selector\":\".w-cart-cart-tabs .w-tabs > .block\",\"attribute\":\"padding-top\",\"value\":\"0\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-cart-tabs\"}]},\"translation\":[],\"box_id\":\"168053\",\"siblings\":[{\"id\":168052,\"microtime\":\"116214\",\"theme_name\":\"furniture-mobile\",\"block_name\":\"block-170164\",\"widget_name\":\"BlockBox\",\"widget_params\":\"\",\"sort_order\":2},{\"id\":168053,\"microtime\":\"120945\",\"theme_name\":\"furniture-mobile\",\"block_name\":\"block-170164\",\"widget_name\":\"cart\\\\CartTabs\",\"widget_params\":\"\",\"sort_order\":1}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-12 18:03:21\",\"active\":0,\"admin_id\":44},\"16\":{\"steps_id\":152,\"parent_id\":113,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"furniture-mobile\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"furniture-mobile\",\"selector\":\".order-summary .icon.opened\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"furniture-mobile\",\"date_added\":\"2023-02-18 19:19:13\",\"active\":0,\"admin_id\":44},\"designer_mode\":\"\"}','furniture-mobile','2023-02-22 13:14:38',1,0,'basic'),(11,0,'applyMigration','{\"0\":{\"steps_id\":56,\"parent_id\":5,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 16:59:07\",\"active\":0,\"admin_id\":44},\"1\":{\"steps_id\":58,\"parent_id\":57,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 16:59:10\",\"active\":0,\"admin_id\":44},\"2\":{\"steps_id\":59,\"parent_id\":58,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 16:59:12\",\"active\":0,\"admin_id\":44},\"3\":{\"steps_id\":60,\"parent_id\":59,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .w-cart-listing .item\",\"attribute\":\"grid-template-columns\",\"value\":\"1fr\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 16:59:52\",\"active\":0,\"admin_id\":44},\"4\":{\"steps_id\":61,\"parent_id\":60,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 16:59:53\",\"active\":0,\"admin_id\":44},\"5\":{\"steps_id\":62,\"parent_id\":61,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73500\",\"box_id\":\"209341\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"73500\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"40\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:04:46\",\"active\":0,\"admin_id\":44},\"6\":{\"steps_id\":64,\"parent_id\":62,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73500\",\"box_id\":\"209341\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"73500\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:05:54\",\"active\":0,\"admin_id\":44},\"7\":{\"steps_id\":66,\"parent_id\":64,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73500\",\"box_id\":\"209341\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73500\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:08:30\",\"active\":0,\"admin_id\":44},\"8\":{\"steps_id\":68,\"parent_id\":66,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73500\",\"box_id\":\"209341\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"73500\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:09:02\",\"active\":0,\"admin_id\":44},\"9\":{\"steps_id\":73,\"parent_id\":68,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73500\",\"box_id\":\"209341\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"73500\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:12:12\",\"active\":0,\"admin_id\":44},\"10\":{\"steps_id\":74,\"parent_id\":73,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73500\",\"box_id\":\"209341\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"73500\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:16:38\",\"active\":0,\"admin_id\":44},\"11\":{\"steps_id\":77,\"parent_id\":74,\"event\":\"boxSave\",\"data\":{\"microtime\":\"73500\",\"box_id\":\"209341\",\"page_name\":\"checkout\",\"box_settings\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"40\",\"language_id\":\"0\",\"visibility\":\"\",\"microtime\":\"73500\",\"theme_name\":\"watch\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\",\"microtime\":\"73500\",\"theme_name\":\"watch\"}],\"box_settings_old\":[{\"setting_name\":\"block_type\",\"setting_value\":\"1\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w992\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"\"},{\"setting_name\":\"padding-right\",\"setting_value\":\"0\",\"language_id\":\"0\",\"visibility\":\"w768\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:24:57\",\"active\":0,\"admin_id\":44},\"12\":{\"steps_id\":92,\"parent_id\":78,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".order-summary \",\"attribute\":\"margin-bottom\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:35:02\",\"active\":0,\"admin_id\":44},\"13\":{\"steps_id\":93,\"parent_id\":92,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:35:02\",\"active\":0,\"admin_id\":44},\"14\":{\"steps_id\":94,\"parent_id\":93,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:35:03\",\"active\":0,\"admin_id\":44},\"15\":{\"steps_id\":95,\"parent_id\":94,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-account-address-book .btn-edit\",\"attribute\":\"margin-left\",\"value\":\"20\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"selector\":\".w-account-address-book .btn-del\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .btn-edit\",\"attribute\":\"margin-right\",\"value\":\"7\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:36:47\",\"active\":0,\"admin_id\":44},\"16\":{\"steps_id\":96,\"parent_id\":95,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:36:48\",\"active\":0,\"admin_id\":44},\"17\":{\"steps_id\":97,\"parent_id\":96,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"flex-direction\",\"value\":\"column\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"height\",\"value\":\"100\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"height_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"justify-content\",\"value\":\"space-between\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"box_shadow_left\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"box_shadow_left_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"box_shadow_top\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"box_shadow_top_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"box_shadow_blur\",\"value\":\"4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"box_shadow_blur_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"box_shadow_color\",\"value\":\"#c4c4c4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border-top-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border-left-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border-right-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border-bottom-width\",\"value\":\"1\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border-top-color\",\"value\":\"#c4c4c4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border-left-color\",\"value\":\"#c4c4c4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border-right-color\",\"value\":\"#c4c4c4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border-bottom-color\",\"value\":\"#c4c4c4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border-top-left-radius\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border_radius_1_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border-top-right-radius\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border_radius_2_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border-bottom-right-radius\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border_radius_3_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border-bottom-left-radius\",\"value\":\"5\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"border_radius_4_measure\",\"value\":\"px\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"padding-top\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"padding-right\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"padding-bottom\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .wrap\",\"attribute\":\"padding-left\",\"value\":\"15\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"color\",\"value\":\"#c4c4c4\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"flex-direction\",\"value\":\"column\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"font-size\",\"value\":\"25\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"font-weight\",\"value\":\"bold\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"height\",\"value\":\"100\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"height_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"justify-content\",\"value\":\"center\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"text-align\",\"value\":\"center\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"display\",\"value\":\"block\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\', Verdana, Arial, sans-serif\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:38:47\",\"active\":0,\"admin_id\":44},\"18\":{\"steps_id\":98,\"parent_id\":97,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:38:48\",\"active\":0,\"admin_id\":44},\"19\":{\"steps_id\":99,\"parent_id\":98,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-account-address-book .address-book\",\"attribute\":\"overflow\",\"value\":\"hidden\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .address-book\",\"attribute\":\"flex-wrap\",\"value\":\"wrap\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .address-book\",\"attribute\":\"justify-content\",\"value\":\"space-between\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .address-book\",\"attribute\":\"display\",\"value\":\"flex\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .item\",\"attribute\":\"padding-top\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .item\",\"attribute\":\"padding-right\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .item\",\"attribute\":\"padding-bottom\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .item\",\"attribute\":\"padding-left\",\"value\":\"10\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:49:56\",\"active\":0,\"admin_id\":44},\"20\":{\"steps_id\":100,\"parent_id\":99,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:49:57\",\"active\":0,\"admin_id\":44},\"21\":{\"steps_id\":101,\"parent_id\":100,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".w-account-address-book .add_item a\",\"attribute\":\"text-decoration\",\"value\":\"none\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:50:25\",\"active\":0,\"admin_id\":44},\"22\":{\"steps_id\":102,\"parent_id\":101,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-12 17:50:26\",\"active\":0,\"admin_id\":44},\"23\":{\"steps_id\":154,\"parent_id\":102,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".order-summary\"},{\"selector\":\".order-summary .icon\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".order-summary\"}],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".order-summary .icon.opened\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".order-summary\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-18 19:24:27\",\"active\":0,\"admin_id\":44},\"24\":{\"steps_id\":156,\"parent_id\":155,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-18 19:24:31\",\"active\":0,\"admin_id\":44},\"25\":{\"steps_id\":157,\"parent_id\":156,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"},{\"selector\":\".w-cart-discount-coupon .title\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":null,\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}],\"attributes_new\":[{\"theme_name\":\"watch\",\"selector\":\".w-cart-discount-coupon .title.opened\",\"attribute\":\"content\",\"value\":\"\\\\f106\",\"visibility\":\"4\",\"media\":\"\",\"accessibility\":\".w-cart-discount-coupon\"}]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-18 19:25:15\",\"active\":0,\"admin_id\":44},\"26\":{\"steps_id\":158,\"parent_id\":157,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch\",\"date_added\":\"2023-02-18 19:25:16\",\"active\":1,\"admin_id\":44},\"designer_mode\":\"\"}','watch','2023-02-22 13:14:40',1,0,'basic'),(12,0,'applyMigration','{\"0\":{\"steps_id\":70,\"parent_id\":69,\"event\":\"cssSave\",\"data\":{\"attributes_box_changed\":null,\"attributes_box_delete\":[{\"box_id\":\"211788\",\"setting_name\":\"padding-right\",\"setting_value\":\"40\",\"visibility\":\"\"},{\"box_id\":\"212756\",\"setting_name\":\"margin_left_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212756\",\"setting_name\":\"margin_right_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212764\",\"setting_name\":\"margin_left_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212764\",\"setting_name\":\"margin_right_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212812\",\"setting_name\":\"margin_left_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212812\",\"setting_name\":\"margin_right_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212820\",\"setting_name\":\"margin_left_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212820\",\"setting_name\":\"margin_right_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212823\",\"setting_name\":\"margin_left_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212823\",\"setting_name\":\"margin_right_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212832\",\"setting_name\":\"margin_left_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212832\",\"setting_name\":\"margin_right_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212883\",\"setting_name\":\"margin_left_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212883\",\"setting_name\":\"margin_right_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"213066\",\"setting_name\":\"margin_left_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"213066\",\"setting_name\":\"margin_right_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"213339\",\"setting_name\":\"margin_left_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"213339\",\"setting_name\":\"margin_right_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"213786\",\"setting_name\":\"background_image\",\"setting_value\":\"themes\\/watch-mobile\\/img\\/wedding-registry-page-1-1.jpg\",\"visibility\":\"\"},{\"box_id\":\"213787\",\"setting_name\":\"margin_left_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"213787\",\"setting_name\":\"margin_right_measure\",\"setting_value\":\"auto\",\"visibility\":\"\"}],\"attributes_box_new\":[{\"box_id\":\"212756\",\"setting_name\":\"margin-right\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212756\",\"setting_name\":\"margin-left\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212764\",\"setting_name\":\"margin-right\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212764\",\"setting_name\":\"margin-left\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212812\",\"setting_name\":\"margin-right\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212812\",\"setting_name\":\"margin-left\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212820\",\"setting_name\":\"margin-right\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212820\",\"setting_name\":\"margin-left\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212823\",\"setting_name\":\"margin-right\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212823\",\"setting_name\":\"margin-left\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212832\",\"setting_name\":\"margin-right\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212832\",\"setting_name\":\"margin-left\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212883\",\"setting_name\":\"margin-right\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"212883\",\"setting_name\":\"margin-left\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"213066\",\"setting_name\":\"margin-right\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"213066\",\"setting_name\":\"margin-left\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"213339\",\"setting_name\":\"margin-right\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"213339\",\"setting_name\":\"margin-left\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"213786\",\"setting_name\":\"background-image\",\"setting_value\":\"url(\'\')\",\"visibility\":\"\"},{\"box_id\":\"213787\",\"setting_name\":\"margin-right\",\"setting_value\":\"auto\",\"visibility\":\"\"},{\"box_id\":\"213787\",\"setting_name\":\"margin-left\",\"setting_value\":\"auto\",\"visibility\":\"\"}],\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:10:10\",\"active\":0,\"admin_id\":44},\"1\":{\"steps_id\":75,\"parent_id\":72,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .checkout > .type-1 > .type-1 > .type-1\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .checkout > .type-1 > .type-1 > .type-1\",\"attribute\":\"padding-right_important\",\"value\":\"important\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:20:23\",\"active\":0,\"admin_id\":44},\"2\":{\"steps_id\":76,\"parent_id\":75,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:20:23\",\"active\":0,\"admin_id\":44},\"3\":{\"steps_id\":79,\"parent_id\":76,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\', Verdana, Arial, sans-serif\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-checkout-index .closeable-heading.closed\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:27:20\",\"active\":0,\"admin_id\":44},\"4\":{\"steps_id\":80,\"parent_id\":79,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:27:20\",\"active\":0,\"admin_id\":44},\"5\":{\"steps_id\":81,\"parent_id\":80,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .closeable-heading.closed\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\', Verdana, Arial, sans-serif\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"},{\"selector\":\".p-checkout-index .closeable-heading\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".p-checkout-index\"}],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:28:13\",\"active\":0,\"admin_id\":44},\"6\":{\"steps_id\":82,\"parent_id\":81,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:28:14\",\"active\":0,\"admin_id\":44},\"7\":{\"steps_id\":83,\"parent_id\":82,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".closeable-heading\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\"\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".closeable-heading\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\"\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".closeable-heading\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\"\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".closeable-heading\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\"\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".closeable-heading\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\', Verdana, Arial, sans-serif\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\"\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".closeable-heading.closed\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\"\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:28:26\",\"active\":0,\"admin_id\":44},\"8\":{\"steps_id\":84,\"parent_id\":83,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:28:27\",\"active\":0,\"admin_id\":44},\"9\":{\"steps_id\":85,\"parent_id\":84,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".closeable-heading\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\"\"},{\"selector\":\".closeable-heading.closed\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\"\"},{\"selector\":\".closeable-heading\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\', Verdana, Arial, sans-serif\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\"\"},{\"selector\":\".closeable-heading\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\"\"},{\"selector\":\".closeable-heading\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\"\"},{\"selector\":\".closeable-heading\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\"\"}],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:29:16\",\"active\":0,\"admin_id\":44},\"10\":{\"steps_id\":86,\"parent_id\":85,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".b-bottom .closeable-heading\",\"attribute\":\"position\",\"value\":\"absolute\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".b-bottom\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".b-bottom .closeable-heading\",\"attribute\":\"right\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".b-bottom\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".b-bottom .closeable-heading\",\"attribute\":\"top\",\"value\":\"0\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".b-bottom\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".b-bottom .closeable-heading\",\"attribute\":\"content\",\"value\":\"\\\\f068\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".b-bottom\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".b-bottom .closeable-heading\",\"attribute\":\"font-family\",\"value\":\"\'FontAwesome\', Verdana, Arial, sans-serif\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".b-bottom\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".b-bottom .closeable-heading.closed\",\"attribute\":\"content\",\"value\":\"\\\\f067\",\"visibility\":\"3\",\"media\":\"\",\"accessibility\":\".b-bottom\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:29:47\",\"active\":0,\"admin_id\":44},\"11\":{\"steps_id\":87,\"parent_id\":86,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".p-shopping-cart-index .order-summary\",\"attribute\":\"margin-left\",\"value\":\"0\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-shopping-cart-index .order-summary\",\"attribute\":\"margin-left_important\",\"value\":\"important\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:31:35\",\"active\":0,\"admin_id\":44},\"12\":{\"steps_id\":88,\"parent_id\":87,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:31:36\",\"active\":0,\"admin_id\":44},\"13\":{\"steps_id\":89,\"parent_id\":88,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".p-shopping-cart-index .order-summary\",\"attribute\":\"margin-bottom\",\"value\":\"40\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:33:38\",\"active\":0,\"admin_id\":44},\"14\":{\"steps_id\":90,\"parent_id\":89,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-shopping-cart-index .order-summary\",\"attribute\":\"margin-bottom\",\"value\":\"40\",\"visibility\":\"w992\",\"media\":\"\",\"accessibility\":\".p-shopping-cart-index\"}],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:34:12\",\"active\":0,\"admin_id\":44},\"15\":{\"steps_id\":91,\"parent_id\":90,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:34:13\",\"active\":0,\"admin_id\":44},\"16\":{\"steps_id\":103,\"parent_id\":91,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[{\"selector\":\".p-account-index .moduleRowDue td\",\"attribute\":\"background_image\",\"value\":\"themes\\/watch-mobile\\/img\\/pattern-1.png\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-account-index\"}],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".p-account-index .moduleRowDue td\",\"attribute\":\"background-image\",\"value\":\"url(\'\')\",\"visibility\":\"\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-account-index .account .bottom-left\",\"attribute\":\"display\",\"value\":\"none\",\"visibility\":\"w900\",\"media\":\"\",\"accessibility\":\".p-account-index\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:52:52\",\"active\":0,\"admin_id\":44},\"17\":{\"steps_id\":104,\"parent_id\":103,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:52:53\",\"active\":0,\"admin_id\":44},\"18\":{\"steps_id\":105,\"parent_id\":104,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".w-account-address-book .item\",\"attribute\":\"width\",\"value\":\"100\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".w-account-address-book .item\",\"attribute\":\"width_measure\",\"value\":\"%\",\"visibility\":\"w768\",\"media\":\"\",\"accessibility\":\".w-account-address-book\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:54:06\",\"active\":0,\"admin_id\":44},\"19\":{\"steps_id\":106,\"parent_id\":105,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:54:07\",\"active\":0,\"admin_id\":44},\"20\":{\"steps_id\":107,\"parent_id\":106,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[{\"theme_name\":\"watch-mobile\",\"selector\":\".p-account-index .w-widgets-aria > .block > .type-1\",\"attribute\":\"padding-top\",\"value\":\"20\",\"visibility\":\"w900\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-account-index .w-widgets-aria > .block > .type-1\",\"attribute\":\"padding-right\",\"value\":\"0\",\"visibility\":\"w900\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-account-index .w-widgets-aria > .block > .type-1\",\"attribute\":\"padding-bottom\",\"value\":\"20\",\"visibility\":\"w900\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-account-index .w-widgets-aria > .block > .type-1\",\"attribute\":\"padding-left\",\"value\":\"0\",\"visibility\":\"w900\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-account-index .w-widgets-aria > .block > .type-1\",\"attribute\":\"padding-top_important\",\"value\":\"important\",\"visibility\":\"w900\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-account-index .w-widgets-aria > .block > .type-1\",\"attribute\":\"padding-right_important\",\"value\":\"important\",\"visibility\":\"w900\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-account-index .w-widgets-aria > .block > .type-1\",\"attribute\":\"padding-bottom_important\",\"value\":\"important\",\"visibility\":\"w900\",\"media\":\"\",\"accessibility\":\".p-account-index\"},{\"theme_name\":\"watch-mobile\",\"selector\":\".p-account-index .w-widgets-aria > .block > .type-1\",\"attribute\":\"padding-left_important\",\"value\":\"important\",\"visibility\":\"w900\",\"media\":\"\",\"accessibility\":\".p-account-index\"}]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:55:51\",\"active\":0,\"admin_id\":44},\"21\":{\"steps_id\":108,\"parent_id\":107,\"event\":\"cssSave\",\"data\":{\"theme_name\":\"watch-mobile\",\"attributes_changed\":[],\"attributes_delete\":[],\"attributes_new\":[]},\"theme_name\":\"watch-mobile\",\"date_added\":\"2023-02-12 17:55:52\",\"active\":1,\"admin_id\":44},\"designer_mode\":\"\"}','watch-mobile','2023-02-22 13:14:41',1,0,'basic');
/*!40000 ALTER TABLE `themes_steps` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `themes_styles`
--

DROP TABLE IF EXISTS `themes_styles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `themes_styles` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `theme_name` varchar(128) COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `selector` varchar(256) COLLATE latin1_general_ci DEFAULT NULL,
  `attribute` varchar(256) COLLATE latin1_general_ci DEFAULT NULL,
  `value` varchar(256) COLLATE latin1_general_ci DEFAULT NULL,
  `visibility` varchar(64) COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `media` varchar(128) COLLATE latin1_general_ci NOT NULL DEFAULT '',
  `accessibility` varchar(64) COLLATE latin1_general_ci NOT NULL DEFAULT '',
  PRIMARY KEY (`id`),
  KEY `idx_accesibility_media_selector_attr_vis2` (`accessibility`,`media`,`selector`,`attribute`,`visibility`),
  KEY `idx_theme_name_attribute` (`theme_name`,`attribute`)
) ENGINE=InnoDB AUTO_INCREMENT=1571472 DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `themes_styles`
--

LOCK TABLES `themes_styles` WRITE;
/*!40000 ALTER TABLE `themes_styles` DISABLE KEYS */;
INSERT INTO `themes_styles` VALUES (29676,'watch-mobile','.b-slick .slick-slider','-khtml-user-select','none','','','.b-slick'),(29677,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','-moz-border-radius','15px','','','.b-fancybox'),(29678,'watch-mobile','.b-fancybox .fancybox-skin','-moz-border-radius','4px','','','.b-fancybox'),(29679,'watch-mobile','.b-fancybox .fancybox-opened .fancybox-skin','-moz-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(29680,'watch-mobile','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-moz-box-sizing','border-box','','','.b-select-suggest'),(29681,'watch-mobile','.b-rating #stars-default .glyphicon','-moz-osx-font-smoothing','grayscale','','','.b-rating'),(29682,'watch-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-moz-transform','translate3d(0, 0, 0)','','','.b-slick'),(29683,'watch-mobile','.b-products-listing .hover-box-content','-moz-transform','rotate( 45deg )','3','','.b-products-listing'),(29684,'watch-mobile','.b-slick .slick-slider','-moz-user-select','none','','','.b-slick'),(29685,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','-moz-user-select','none','','','.b-select-suggest'),(29686,'watch-mobile','.b-select-suggest .select2-container .select2-choice','-moz-user-select','none','','','.b-select-suggest'),(29687,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-moz-user-select','none','','','.b-select-suggest'),(29688,'watch-mobile','.b-slick .slick-slider','-ms-touch-action','pan-y','','','.b-slick'),(29689,'watch-mobile','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(29690,'watch-mobile','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(29691,'watch-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-ms-transform','translate3d(0, 0, 0)','','','.b-slick'),(29692,'watch-mobile','.b-products-listing .hover-box-content','-ms-transform','rotate( 45deg )','3','','.b-products-listing'),(29693,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(29694,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(29695,'watch-mobile','.b-slick .slick-slider','-ms-user-select','none','','','.b-slick'),(29696,'watch-mobile','.b-select-suggest .select2-container .select2-choice','-ms-user-select','none','','','.b-select-suggest'),(29697,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','-ms-user-select','none','','','.b-select-suggest'),(29698,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-ms-user-select','none','','','.b-select-suggest'),(29699,'watch-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-o-transform','translate3d(0, 0, 0)','','','.b-slick'),(29700,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','-webkit-border-radius','15px','','','.b-fancybox'),(29701,'watch-mobile','.b-fancybox .fancybox-skin','-webkit-border-radius','4px','','','.b-fancybox'),(29702,'watch-mobile','.b-fancybox .fancybox-opened .fancybox-skin','-webkit-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(29703,'watch-mobile','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-webkit-box-sizing','border-box','','','.b-select-suggest'),(29704,'watch-mobile','.b-rating #stars-default .glyphicon','-webkit-font-smoothing','antialiased','','','.b-rating'),(29705,'watch-mobile','.b-fancybox .fancybox-type-iframe .fancybox-inner','-webkit-overflow-scrolling','touch','','','.b-fancybox'),(29706,'watch-mobile','.b-fancybox .fancybox-nav','-webkit-tap-highlight-color','rgba(0,0,0,0)','','','.b-fancybox'),(29707,'watch-mobile','.b-slick .slick-slider','-webkit-tap-highlight-color','transparent','','','.b-slick'),(29708,'watch-mobile','.b-select-suggest .select2-results','-webkit-tap-highlight-color','rgba(0, 0, 0, 0)','','','.b-select-suggest'),(29709,'watch-mobile','.b-slick .slick-slider','-webkit-touch-callout','none','','','.b-slick'),(29710,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(29711,'watch-mobile','.b-select-suggest .select2-container .select2-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(29712,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','-webkit-touch-callout','none','','','.b-select-suggest'),(29713,'watch-mobile','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(29714,'watch-mobile','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(29715,'watch-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-webkit-transform','translate3d(0, 0, 0)','','','.b-slick'),(29716,'watch-mobile','.b-products-listing .hover-box-content','-webkit-transform','rotate( 45deg )','3','','.b-products-listing'),(29717,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(29718,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(29719,'watch-mobile','.b-slick .slick-slider','-webkit-user-select','none','','','.b-slick'),(29720,'watch-mobile','.b-select-suggest .select2-container .select2-choice','-webkit-user-select','none','','','.b-select-suggest'),(29721,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','-webkit-user-select','none','','','.b-select-suggest'),(29722,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-user-select','none','','','.b-select-suggest'),(29723,'watch-mobile','.p-wedding-registry-search .search-form','align-items','center','','','.p-wedding-registry-search'),(29724,'watch-mobile','.w-banner .carousel .middle-center','align-items','center','','','.w-banner'),(29725,'watch-mobile','.w-banner .carousel .bottom-right','align-items','flex-end','','','.w-banner'),(29726,'watch-mobile','.w-banner .carousel .middle-right','align-items','center','','','.w-banner'),(29727,'watch-mobile','.w-banner .carousel .top-right','align-items','flex-start','','','.w-banner'),(29728,'watch-mobile','.w-banner .carousel .top-center','align-items','flex-start','','','.w-banner'),(29729,'watch-mobile','.w-banner .carousel .middle-left','align-items','center','','','.w-banner'),(29730,'watch-mobile','.w-banner .carousel .bottom-center','align-items','flex-end','','','.w-banner'),(29731,'watch-mobile','.w-banner .carousel .bottom-left','align-items','flex-end','','','.w-banner'),(29732,'watch-mobile','.w-banner .carousel .top-left','align-items','flex-start','','','.w-banner'),(29733,'watch-mobile','.b-products-listing .products-listing .attribute-qty-block','align-items','center','','','.b-products-listing'),(29734,'watch-mobile','.b-products-listing .promos-info .promo-item','align-items','center','','','.b-products-listing'),(29735,'watch-mobile','.b-products-listing .select-attributes','align-items','center','','','.b-products-listing'),(29736,'watch-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(29737,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','align-items','center','','','.b-menu-style-1'),(29738,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .languages','align-items','center','','','.b-menu-style-2'),(29739,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','align-items','center','','','.b-menu-style-2'),(29740,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies','align-items','center','','','.b-menu-style-2'),(29741,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','align-items','center','','','.b-menu-style-2'),(29742,'watch-mobile','.b-messages .email-line','align-items','center','','','.b-messages'),(29743,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(29744,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(29745,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(29746,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(29747,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(29748,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(29749,'watch-mobile','.p-quick-order-index .quick-order-total','align-items','center','','','.p-quick-order-index'),(29750,'watch-mobile','.w-account-customer-additional-field .field-type-text','align-items','center','','','.w-account-customer-additional-field'),(29751,'watch-mobile','.w-account-subscription .subscription-variant','align-items','center','','','.w-account-subscription'),(29752,'watch-mobile','.w-catalog-compare .cross-box .different-all','align-items','flex-end','','','.w-catalog-compare'),(29753,'watch-mobile','.w-communication-new-topic #communication_group_holder + .columns','align-items','flex-end','','','.w-communication-new-topic'),(29754,'watch-mobile','.w-personal-gift-status-bar .timeline','align-items','center','','','.w-personal-gift-status-bar'),(29755,'watch-mobile','.w-promotions .promo-cart-discount','align-items','flex-start','','','.w-promotions'),(29756,'watch-mobile','.w-taxable form','align-items','center','','','.w-taxable'),(29757,'watch-mobile','.b-products-listing .btn-preloader','animation','load8 1.5s infinite linear','3','','.b-products-listing'),(29758,'watch-mobile','.b-products-listing .loader','animation','load8 1.5s infinite linear','4','','.b-products-listing'),(29759,'watch-mobile','.b-preloader .preloader','animation','load8 1.5s infinite linear','3','','.b-preloader'),(29760,'watch-mobile','.w-product-customers-activity .customers-activity','animation','customers-activity-show 4s ease-in-out','','','.w-product-customers-activity'),(29761,'watch-mobile','.w-product-customers-activity .customers-activity.closed','animation','customers-activity-hide 2s ease-in-out','','','.w-product-customers-activity'),(29762,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(29763,'watch-mobile','.w-filters .ui-slider-range','background','none','','','.w-filters'),(29764,'watch-mobile','.w-filters .ui-slider','background','none','','','.w-filters'),(29765,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','background','transparent','','','.b-fancybox'),(29766,'watch-mobile','.w-top-categories .categories h2','background','none','','','.w-top-categories'),(29767,'watch-mobile','.w-categories .categories h2','background','none','','','.w-categories'),(29768,'watch-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','background','none','','','.b-products-listing'),(29769,'watch-mobile','.b-products-listing .products-listing h2','background','none','','','.b-products-listing'),(29770,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.b-data-table'),(29771,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.b-data-table'),(29772,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','background','none','','','.b-menu-style-2'),(29773,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','background','none','','','.b-menu-style-2'),(29774,'watch-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','background','transparent','','','.b-select-suggest'),(29775,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','background','none','','','.b-select-suggest'),(29776,'watch-mobile','.b-select-suggest .select2-results .select2-highlighted em','background','transparent','','','.b-select-suggest'),(29777,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background','transparent','','','.b-select-suggest'),(29778,'watch-mobile','.batchPr .checkbox input + span','background','none','','','.batchPr'),(29779,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.p-quick-order-index'),(29780,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.p-quick-order-index'),(29781,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','background','none','','','.w-catalog-compare'),(29782,'watch-mobile','.b-select-suggest .select2-container .select2-choice','background-clip','padding-box','','','.b-select-suggest'),(29783,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','background-clip','padding-box','','','.b-select-suggest'),(29784,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','background-clip','padding-box','','','.b-select-suggest'),(29785,'watch-mobile','.w-menu .hided.menu','background-color','inherit','','','.w-menu'),(29786,'watch-mobile','.w-menu .menu .menu-ico','background-color','inherit','','','.w-menu'),(29787,'watch-mobile','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','background-color','$background-5','','','.b-cookie-notice'),(29788,'watch-mobile','.w-sale .left-count-days','background-color','$background-7','','','.w-sale'),(29789,'watch-mobile','.w-menu-horizontal > ul > li > ul > li > ul','background-color','$background-7','','','.w-menu-horizontal'),(29790,'watch-mobile','.w-menu-slider .menu-ico','background-color','$background-2','','','.w-menu-slider'),(29791,'watch-mobile','.w-menu-horizontal > ul > li > ul','background-color','$background-7','','','.w-menu-horizontal'),(29792,'watch-mobile','.w-menu-slider > ul > li.active > ul','background-color','$background-2','','','.w-menu-slider'),(29793,'watch-mobile','.w-menu-style-1 .menu-ico','background-color','$background-2','','','.w-menu-style-1'),(29794,'watch-mobile','.w-sale .badge','background-color','$background-2','','','.w-sale'),(29795,'watch-mobile','.w-menu-style-1 > ul > li > ul','background-color','$background-2','','','.w-menu-style-1'),(29796,'watch-mobile','.w-menu-style-1 > ul','background-color','$background-2','','','.w-menu-style-1'),(29797,'watch-mobile','.w-menu-style-1 > ul > li','background-color','$background-1','1','','.w-menu-style-1'),(29798,'watch-mobile','.w-menu-style-1 > ul > li > ul > li','background-color','$background-1','1','','.w-menu-style-1'),(29799,'watch-mobile','.w-menu-style-1 > ul > li > ul > li ul','background-color','$background-2','','','.w-menu-style-1'),(29800,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > ul li','background-color','$background-1','1','','.w-menu-style-1'),(29801,'watch-mobile','.w-product-sale-ends .left-count','background-color','$background-2','','','.w-product-sale-ends'),(29802,'watch-mobile','.w-product-sale-ends .left-count-hours','background-color','$background-7','','','.w-product-sale-ends'),(29804,'watch-mobile','.w-product-sale-ends .left-count-days','background-color','$background-7','','','.w-product-sale-ends'),(29805,'watch-mobile','.p-account-trade-form .trade-form-area','background-color','$background-6','','','.p-account-trade-form'),(29806,'watch-mobile','.w-quote .cart-box','background-color','$background-7','','','.w-quote'),(29807,'watch-mobile','.w-product-reviews .reviews-list .review','background-color','$background-7','','','.w-product-reviews'),(29808,'watch-mobile','.w-quote .cart-box-link','background-color','$background-2','','','.w-quote'),(29809,'watch-mobile','.b-compare .popupCompare .pop-up-content','background-color','$background-6','','','.b-compare'),(29810,'watch-mobile','.w-menu-slider > ul','background-color','$background-2','','','.w-menu-slider'),(29811,'watch-mobile','.w-menu-slider > ul > li > ul','background-color','$background-2','','','.w-menu-slider'),(29812,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','background-color','$background-4','3','','.b-multi-page-checkout'),(29813,'watch-mobile','.b-info-popup .info-popup div','background-color','$background-7','','','.b-info-popup'),(29814,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','background-color','$background-2','','','.b-multi-page-checkout'),(29815,'watch-mobile','.testimonials .review','background-color','$background-6','','',''),(29816,'watch-mobile','.p-wedding-registry-manage .wr-search button','background-color','$background-transparent','','','.p-wedding-registry-manage'),(29817,'watch-mobile','.b-pagination .pagination span','background-color','$background-2','2','','.b-pagination'),(29819,'watch-mobile','.w-filters .head-filter-widget','background-color','$background-2','317','','.w-filters'),(29820,'watch-mobile','.w-list-type-2_2 .compare-box-item','background-color','$background-6','','','.w-list-type-2_2'),(29821,'watch-mobile','.w-list-type-2_2 .button-wishlist button','background-color','$background-7','','','.w-list-type-2_2'),(29822,'watch-mobile','.w-chat .w-chat-box','background-color','$background-2','','','.w-chat'),(29823,'watch-mobile','.p-wedding-registry-index .middle-box','background-color','$background-7','','','.p-wedding-registry-index'),(29824,'watch-mobile','.b-table .table .headings td','background-color','$background-6','','','.b-table'),(29825,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','background-color','$background-2','','','.b-switch'),(29826,'watch-mobile','.b-bottom .popup-heading','background-color','$background-6','','','.b-bottom'),(29827,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label','background-color','$background-7','3','','.b-switch'),(29828,'watch-mobile','.b-compare .compare-box-item','background-color','$background-6','','','.b-compare'),(29829,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label','background-color','$background-7','3','','.b-switch'),(29830,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','background-color','$background-6','','','.b-switch'),(29831,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','background-color','$background-3','','','.b-fancybox'),(29832,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','background-color','$background-7','','','.b-slick'),(29833,'watch-mobile','.w-reviews .review','background-color','$background-7','','','.w-reviews'),(29834,'watch-mobile','.w-search .suggest','background-color','$background-7','','','.w-search'),(29835,'watch-mobile','.btn-1','background-color','$background-5','','',''),(29836,'watch-mobile','body','background-color','$background-7','','',''),(29837,'watch-mobile','.w-currencies .select','background-color','$background-7','','','.w-currencies'),(29838,'watch-mobile','.b-bottom .popup-box.popupCompare','background-color','$background-6','','','.b-bottom'),(29839,'watch-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','background-color','$background-7','','','.w-compare-box-item'),(29840,'watch-mobile','.w-compare-box-item .checkbox:checked + span:before','background-color','$message-color','','','.w-compare-box-item'),(29841,'watch-mobile','.p-account-subscription-historyinfo .order_history_table th','background-color','$background-6','','','.p-account-subscription-historyinfo'),(29842,'watch-mobile','.b-info-popup .info-popup div','background-color','$background-7','3','','.b-info-popup'),(29843,'watch-mobile','.w-menu-mobile .menu-ico','background-color','$background-2','','','.w-menu-mobile'),(29846,'watch-mobile','.b-compare .popupCompare table','background-color','$background-7','','','.b-compare'),(29847,'watch-mobile','.b-fancybox .fancybox-skin','background-color','$background-6','','','.b-fancybox'),(29848,'watch-mobile','.b-fancybox .fancybox-overlay','background-color','$background-3','','','.b-fancybox'),(29849,'watch-mobile','.p-reviews-info .review-info-content','background-color','$background-6','','','.p-reviews-info'),(29850,'watch-mobile','.p-reviews-info .review-info-image','background-color','$background-7','','','.p-reviews-info'),(29851,'watch-mobile','.w-sale .left-count','background-color','$background-2','','','.w-sale'),(29852,'watch-mobile','.w-sale .left-count-hours','background-color','$background-7','','','.w-sale'),(29853,'watch-mobile','.w-cart .cart-content','background-color','$background-7','','','.w-cart'),(29854,'watch-mobile','.b-fancybox .fancybox-nav span','background-color','$background-3','','','.b-fancybox'),(29855,'watch-mobile','.b-form .hide-billing-address','background-color','$background-7','','','.b-form'),(29858,'watch-mobile','.b-fancybox .filter-listing-loader','background-color','$background-9','','','.b-fancybox'),(29859,'watch-mobile','.b-compare .vary td','background-color','$background-8','','','.b-compare'),(29860,'watch-mobile','.b-datepicker .datepicker-dropdown','background-color','$background-7','','','.b-datepicker'),(29861,'watch-mobile','.w-list-type-2 .button-wishlist button','background-color','$background-7','','','.w-list-type-2'),(29862,'watch-mobile','.w-list-type-2 .compare-box-item','background-color','$background-6','','','.w-list-type-2'),(29863,'watch-mobile','.btn-2','background-color','$background-5','','',''),(29864,'watch-mobile','.btn','background-color','$background-7','','',''),(29865,'watch-mobile','.w-list-type-1_3 .compare-box-item','background-color','$background-6','','','.w-list-type-1_3'),(29866,'watch-mobile','.w-list-type-1_3 .button-wishlist button','background-color','$background-7','','','.w-list-type-1_3'),(29867,'watch-mobile','.b-bottom .around-pop-up','background-color','$background-1','','','.b-bottom'),(29868,'watch-mobile','.w-list-type-1_2 .compare-box-item','background-color','$background-6','','','.w-list-type-1_2'),(29869,'watch-mobile','.w-list-type-1_2 .button-wishlist button','background-color','$background-7','','','.w-list-type-1_2'),(29870,'watch-mobile','.b-bottom .pop-up-content','background-color','$background-7','','','.b-bottom'),(29871,'watch-mobile','.p-reviews-info .review-info-text','background-color','$background-7','','','.p-reviews-info'),(29872,'watch-mobile','.b-bottom .popup-box','background-color','$background-7','','','.b-bottom'),(29873,'watch-mobile','.w-list-type-1 .compare-box-item','background-color','$background-6','','','.w-list-type-1'),(29874,'watch-mobile','.w-filters .ui-slider','background-color','$background-6','','','.w-filters'),(29875,'watch-mobile','.w-filters .ui-slider-range','background-color','$background-2','','','.w-filters'),(29876,'watch-mobile','.w-list-type-1 .button-wishlist button','background-color','$background-7','','','.w-list-type-1'),(29877,'watch-mobile','.w-languages .select','background-color','$background-7','','','.w-languages'),(29878,'watch-mobile','.w-reviews .reviews','background-color','$background-6','','','.w-reviews'),(29879,'watch-mobile','.w-search .button-search','background-color','$background-transparent','','','.w-search'),(29880,'watch-mobile','.b-form .required-message','background-color','$background-6','','','.b-form'),(29881,'watch-mobile','.b-products-listing .loader','background-color','$background-9','3','','.b-products-listing'),(29882,'watch-mobile','.b-products-listing .products-listing .qty-input.hidden','background-color','$background-7','3','','.b-products-listing'),(29883,'watch-mobile','.b-products-listing .promos-info .promo-name','background-color','$background-3','','','.b-products-listing'),(29884,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','$background-6','','','.b-data-table'),(29885,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.b-data-table'),(29886,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','$background-7','','','.b-dropdown'),(29887,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','$background-7','','','.b-dropdown'),(29888,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','$background-7','','','.b-dropdown'),(29889,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','$background-7','','','.b-dropdown'),(29890,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','$background-7','','','.b-dropdown'),(29891,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','$background-7','','','.b-dropdown'),(29892,'watch-mobile','.b-email .heading-products','background-color','$background-6','','','.b-email'),(29893,'watch-mobile','.b-email .heading-products','background-color','$background-6','','','.b-email'),(29894,'watch-mobile','.b-email .heading-products','background-color','$background-6','','','.b-email'),(29895,'watch-mobile','.b-email .heading-products','background-color','$background-6','','','.b-email'),(29896,'watch-mobile','.b-email .heading-products','background-color','$background-6','','','.b-email'),(29897,'watch-mobile','.b-email .heading-products','background-color','$background-6','','','.b-email'),(29898,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','background-color','$background-6','','','.b-menu-style-1'),(29899,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li:hover > a','background-color','$background-6','','','.b-menu-style-1'),(29900,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2','background-color','$background-6','','','.b-menu-style-1'),(29901,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .menu-content','background-color','$background-2','','','.b-menu-style-2'),(29902,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] ul','background-color','$background-2','','','.b-menu-style-3'),(29903,'watch-mobile','.b-messages .msv_to_cc','background-color','$background-6','','','.b-messages'),(29904,'watch-mobile','.b-messages .msv_history','background-color','$background-6','','','.b-messages'),(29905,'watch-mobile','.b-messages .email-heading','background-color','$background-6','','','.b-messages'),(29906,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','background-color','$background-6','','','.b-messages'),(29907,'watch-mobile','.b-preloader .preloader','background-color','$background-9','','','.b-preloader'),(29908,'watch-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','background-color','$background-6','','','.b-select-suggest'),(29909,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-color','$background-6','','','.b-select-suggest'),(29910,'watch-mobile','.b-select-suggest .select2-search input','background-color','$background-7','','','.b-select-suggest'),(29911,'watch-mobile','.b-select-suggest .select2-search input.select2-active','background-color','$background-7','','','.b-select-suggest'),(29912,'watch-mobile','.b-select-suggest .select2-drop','background-color','$background-7','','','.b-select-suggest'),(29913,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-color','$background-6','','','.b-select-suggest'),(29914,'watch-mobile','.b-select-suggest .select2-drop-mask','background-color','$background-7','','','.b-select-suggest'),(29915,'watch-mobile','.b-select-suggest .select2-results .select2-disabled','background-color','$background-6','','','.b-select-suggest'),(29916,'watch-mobile','.b-select-suggest .select2-results .select2-highlighted','background-color','$background-6','','','.b-select-suggest'),(29917,'watch-mobile','.b-select-suggest .select2-results li em','background-color','$background-8','','','.b-select-suggest'),(29918,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-color','$background-6','','','.b-select-suggest'),(29919,'watch-mobile','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','background-color','$background-6','','','.b-select-suggest'),(29920,'watch-mobile','.b-select-suggest .select2-more-results.select2-active','background-color','$background-6','','','.b-select-suggest'),(29921,'watch-mobile','.b-select-suggest .select2-more-results','background-color','$background-6','','','.b-select-suggest'),(29922,'watch-mobile','.b-select-suggest .select2-results .select2-highlighted ul','background-color','$background-7','','','.b-select-suggest'),(29923,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','background-color','$background-7','','','.b-select-suggest'),(29924,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-color','$background-6','','','.b-select-suggest'),(29925,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color','$background-7','','','.b-select-suggest'),(29926,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus','background-color','$background-6','','','.b-select-suggest'),(29927,'watch-mobile','.b-trade-approval .steps-bar','background-color','$background-6','','','.b-trade-approval'),(29928,'watch-mobile','.b-trade-approval .steps-bar li.current a','background-color','$background-2','','','.b-trade-approval'),(29929,'watch-mobile','.batchPr .checkbox input:checked + span','background-color','$background-2','','','.batchPr'),(29930,'watch-mobile','.batchPr .checkbox input + span','background-color','$background-7','','','.batchPr'),(29931,'watch-mobile','.batchPr .btn-batch-remove','background-color','$background-5','','','.batchPr'),(29945,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.p-quick-order-index'),(29946,'watch-mobile','.p-quick-order-index .all-scroll-div','background-color','$background-2','','','.p-quick-order-index'),(29947,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','$background-6','','','.p-quick-order-index'),(29948,'watch-mobile','.w-account-personal-catalog .list-switcher a','background-color','$background-7','2','','.w-account-personal-catalog'),(29949,'watch-mobile','.w-blog-widget-post-listing .post_content','background-color','$background-7','','','.w-blog-widget-post-listing'),(29950,'watch-mobile','.w-blog-widget-post-listing .post_image','background-color','$background-7','','','.w-blog-widget-post-listing'),(29951,'watch-mobile','.w-blog-widget-post-share ','background-color','$background-10','4','','.w-blog-widget-post-share'),(29952,'watch-mobile','.w-blog-widget-related-posts .post_content a','background-color','$background-7','','','.w-blog-widget-related-posts'),(29953,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','background-color','$background-10','','','.w-blog-widget-related-posts'),(29954,'watch-mobile','.w-blog-widget-related-posts-by-category .post_img','background-color','$background-7','','','.w-blog-widget-related-posts-by-category'),(29955,'watch-mobile','.w-blog-widget-related-posts-by-category .post_content','background-color','$background-7','','','.w-blog-widget-related-posts-by-category'),(29956,'watch-mobile','.w-blog-widget-tag-cloud a','background-color','$background-6','','','.w-blog-widget-tag-cloud'),(29957,'watch-mobile','.w-cart-compare .price-cell','background-color','$background-10','','','.w-cart-compare'),(29958,'watch-mobile','.w-cart-compare .attributes-cell','background-color','$background-10','','','.w-cart-compare'),(29959,'watch-mobile','.w-cart-compare .price-block + .attributes-block .attributes-cell','background-color','$background-7','','','.w-cart-compare'),(29960,'watch-mobile','.w-catalog-b2b-add-button ','background-color','$background-2','','','.w-catalog-b2b-add-button'),(29961,'watch-mobile','.w-catalog-compare tr','background-color','$background-6','1','','.w-catalog-compare'),(29962,'watch-mobile','.w-catalog-compare .compare .checkbox input:checked + span','background-color','$background-7','','','.w-catalog-compare'),(29963,'watch-mobile','.w-catalog-compare .compare-fix-bar','background-color','$background-7','','','.w-catalog-compare'),(29964,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','background-color','$background-7','2','','.w-catalog-compare'),(29965,'watch-mobile','.w-catalog-paging ','background-color','$background-2','2','','.w-catalog-paging'),(29966,'watch-mobile','.w-checkout-billing-address .same-address','background-color','$background-6','','','.w-checkout-billing-address'),(29967,'watch-mobile','.w-checkout-shipping-choice input:checked + span','background-color','$background-2','','','.w-checkout-shipping-choice'),(29968,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','background-color','$background-2','','','.w-checkout-shipping-choice'),(29969,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','background-color','$background-6','','','.w-communication-new-topic'),(29970,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','background-color','$background-6','','','.w-communication-new-topic'),(29971,'watch-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','background-color','$background-7','','','.w-delivery-day'),(29972,'watch-mobile','.w-delivery-day .left-count','background-color','$background-2','','','.w-delivery-day'),(29973,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','background-color','$background-7','','','.w-image-maps'),(29974,'watch-mobile','.w-personal-gift-status-bar .progress-bar','background-color','$background-7','','','.w-personal-gift-status-bar'),(29975,'watch-mobile','.w-personal-gift-status-bar .timeline','background-color','$background-6','','','.w-personal-gift-status-bar'),(29976,'watch-mobile','.w-personal-gift-status-bar .progress-bar-content','background-color','$background-2','','','.w-personal-gift-status-bar'),(29977,'watch-mobile','.w-product-customers-activity .customers-activity','background-color','$background-6','','','.w-product-customers-activity'),(29978,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','background-color','$background-7','','','.w-promotions'),(29979,'watch-mobile','.w-promotions .promo-cart-discount .master .item','background-color','$background-7','','','.w-promotions'),(29980,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','background-color','$background-7','','','.w-promotions'),(29981,'watch-mobile','.w-promotions .promo-cart-discount .slave .item','background-color','$background-7','','','.w-promotions'),(29982,'watch-mobile','.w-promotions .promo-salemaker .item','background-color','$background-7','','','.w-promotions'),(29983,'watch-mobile','.w-promotions .promo-item','background-color','$background-6','','','.w-promotions'),(29984,'watch-mobile','.w-promotions .promo-salemaker .discount','background-color','$background-7','','','.w-promotions'),(29985,'watch-mobile','.w-promotions .nextdiscount .content > div','background-color','$background-7','','','.w-promotions'),(29986,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','background-color','$background-7','','','.w-promotions'),(29987,'watch-mobile','.w-promotions .nextdiscount .promo-for-each','background-color','$background-6','','','.w-promotions'),(29988,'watch-mobile','.w-promotions .prom-multi-discount .promo-product','background-color','$background-7','','','.w-promotions'),(29989,'watch-mobile','.w-reviews-content .author','background-color','$background-6','','','.w-reviews-content'),(29990,'watch-mobile','.w-reviews-content .review','background-color','$background-6','','','.w-reviews-content'),(29991,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','background-color','$background-6','','','.w-upload-customer-id-upload-customer-id-form'),(29992,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','background-color','$background-7','','','.w-upload-customer-id-upload-customer-id-form'),(29993,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-color','$background-7','','','.w-wedding-registry-widgets-photos'),(29994,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.b-data-table'),(29995,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color_important','important','','','.b-select-suggest'),(29996,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.p-quick-order-index'),(29999,'watch-mobile','.p-wedding-registry-share .wedding-image','background-image','url(themes/theme-1/img/wedding-registry-page.jpg)','','','.p-wedding-registry-share'),(30001,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-image','none','','','.b-select-suggest'),(30002,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(30003,'watch-mobile','.b-select-suggest .select2-more-results.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(30004,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-image','none','','','.b-select-suggest'),(30005,'watch-mobile','.b-select-suggest .select2-search input','background-image','url(\'\')','','','.b-select-suggest'),(30006,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-image','url(\'\')','','','.b-select-suggest'),(30007,'watch-mobile','.b-select-suggest .select2-results li','background-image','none','','','.b-select-suggest'),(30008,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-image','none','','','.b-select-suggest'),(30009,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-image','none','','','.b-select-suggest'),(30010,'watch-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-image','url(\'\')','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(30011,'watch-mobile','.b-select-suggest .select2-search-choice-close','background-image','url(\'\')','','','.b-select-suggest'),(30012,'watch-mobile','.b-select-suggest .select2-search input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(30025,'watch-mobile','.w-categories .image','background-position','50% 50%','','','.w-categories'),(30026,'watch-mobile','.p-wedding-registry-manage .wedding-image','background-position','50%','','','.p-wedding-registry-manage'),(30027,'watch-mobile','.p-wedding-registry-index .main-content','background-position','50%','','','.p-wedding-registry-index'),(30028,'watch-mobile','.p-wedding-registry-share .wedding-image','background-position','50%','','','.p-wedding-registry-share'),(30029,'watch-mobile','.w-top-categories .image','background-position','50% 50%','','','.w-top-categories'),(30030,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close','background-position','right -11px','1','','.b-select-suggest'),(30031,'watch-mobile','.b-select-suggest .select2-search-choice-close','background-position','top right','','','.b-select-suggest'),(30032,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close','background-position','right -11px','','','.b-select-suggest'),(30033,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-position','right -11px','1','','.b-select-suggest'),(30034,'watch-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow b','background-position','-18px 1px','','','.b-select-suggest'),(30035,'watch-mobile','.b-select-suggest .select2-search input','background-position','100% -22px','','','.b-select-suggest'),(30036,'watch-mobile','.b-select-suggest .select2-search input','background-position','100% -21px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(30037,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-position','top right','','','.b-select-suggest'),(30038,'watch-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','background-position','50%','','','.w-wedding-registry-widgets-manage-banner'),(30039,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-position','center','','','.w-wedding-registry-widgets-photos'),(30040,'watch-mobile','.b-select-suggest .select2-search input','background-position_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(30041,'watch-mobile','.b-select-suggest .select2-search-choice-close','background-repeat','no-repeat','','','.b-select-suggest'),(30042,'watch-mobile','.b-select-suggest .select2-search input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(30043,'watch-mobile','.b-select-suggest .select2-search input','background-repeat','no-repeat','','','.b-select-suggest'),(30044,'watch-mobile','.b-select-suggest .select2-more-results.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(30045,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-repeat','no-repeat','','','.b-select-suggest'),(30046,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','','.b-select-suggest'),(30047,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(30048,'watch-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(30049,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-repeat','no-repeat','','','.w-wedding-registry-widgets-photos'),(30050,'watch-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(30051,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat_important','important','','','.b-select-suggest'),(30052,'watch-mobile','.w-categories .image','background-size','cover','','','.w-categories'),(30053,'watch-mobile','.p-wedding-registry-index .main-content','background-size','cover','','','.p-wedding-registry-index'),(30054,'watch-mobile','.p-wedding-registry-manage .wedding-image','background-size','cover','','','.p-wedding-registry-manage'),(30055,'watch-mobile','.p-wedding-registry-share .wedding-image','background-size','cover','','','.p-wedding-registry-share'),(30056,'watch-mobile','.w-top-categories .image','background-size','cover','','','.w-top-categories'),(30057,'watch-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size','60px 40px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(30058,'watch-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','background-size','cover','','','.w-wedding-registry-widgets-manage-banner'),(30059,'watch-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(30061,'watch-mobile','.p-wedding-registry-manage .wedding-image','background_image','themes/watch-mobile/img/wedding-registry-page-1-1-1.jpg','','','.p-wedding-registry-manage'),(30062,'watch-mobile','.p-wedding-registry-index .main-content','background_image','themes/watch-mobile/img/wedding-registry-page-1-1-1.jpg','','','.p-wedding-registry-index'),(30063,'watch-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','background_image','themes/watch-mobile/img/wedding-registry-page-2.jpg','','','.w-wedding-registry-widgets-manage-banner'),(30064,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','background_image','themes/watch-mobile/img/avatar-bg-1.png','','','.w-wedding-registry-widgets-photos'),(30065,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.b-data-table'),(30066,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background_important','important','','','.b-select-suggest'),(30067,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.p-quick-order-index'),(30068,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(30069,'watch-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','border','none','','','.b-cookie-notice'),(30070,'watch-mobile','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(30074,'watch-mobile','.w-product-wedding-registry-button .btn','border','none','','','.w-product-wedding-registry-button'),(30075,'watch-mobile','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(30076,'watch-mobile','.p-wedding-registry-share .middle-form > input','border','none','','','.p-wedding-registry-share'),(30077,'watch-mobile','.b-compare .compare-head','border','none','','','.b-compare'),(30078,'watch-mobile','.w-product-personal-catalog-button .btn','border','none','','','.w-product-personal-catalog-button'),(30079,'watch-mobile','.w-filters .input-checkbox','border','none','','','.w-filters'),(30080,'watch-mobile','.b-bottom .popup-box.popupCompare','border','none','','','.b-bottom'),(30081,'watch-mobile','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(30082,'watch-mobile','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(30083,'watch-mobile','.w-compare-box-item .checkbox','border','none','','','.w-compare-box-item'),(30085,'watch-mobile','.w-categories .categories h2','border','none','','','.w-categories'),(30086,'watch-mobile','.w-top-categories .categories h2','border','none','','','.w-top-categories'),(30087,'watch-mobile','.b-form .checkbox-style','border','none','','','.b-form'),(30090,'watch-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input + span','border','none','','','.b-products-listing'),(30091,'watch-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','border','none','','','.b-products-listing'),(30092,'watch-mobile','.b-products-listing .products-listing a.btn.view-button','border','none','','','.b-products-listing'),(30093,'watch-mobile','.b-products-listing .products-listing h2','border','none','','','.b-products-listing'),(30094,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.b-data-table'),(30095,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.b-data-table'),(30096,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.b-data-table'),(30097,'watch-mobile','.b-data-table table.dataTable thead td','border','none','','','.b-data-table'),(30098,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','border','none','','','.b-menu-style-2'),(30099,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','border','none','','','.b-menu-style-2'),(30100,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','border','none','','','.b-menu-style-2'),(30101,'watch-mobile','.b-messages .select2-container-multi input.select2-input','border','none','','','.b-messages'),(30102,'watch-mobile','.b-messages .emailLineTextArea textarea','border','none','','','.b-messages'),(30103,'watch-mobile','.b-sub-totals .historyTotal td','border','none','','','.b-sub-totals'),(30104,'watch-mobile','.b-sub-totals .historyTotal table','border','none','','','.b-sub-totals'),(30105,'watch-mobile','.b-trade-approval .w-login-block .heading-3','border','none','','','.b-trade-approval'),(30112,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.p-quick-order-index'),(30113,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','1','','.p-quick-order-index'),(30114,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.p-quick-order-index'),(30115,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.p-quick-order-index'),(30116,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border','none','','','.w-blog-widget-related-posts'),(30117,'watch-mobile','.w-cart-cart-tabs .w-tabs > .block','border','none','','','.w-cart-cart-tabs'),(30118,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','border','none','','','.w-catalog-compare'),(30119,'watch-mobile','.w-checkout-gdpr .privacy-row','border','none','','','.w-checkout-gdpr'),(30120,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','border','none','','','.w-communication-new-topic'),(30121,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','border','none','','','.w-communication-new-topic'),(30122,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','border','none','','','.w-communication-new-topic'),(30123,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','border','none','','','.w-filters'),(30124,'watch-mobile','.w-cart-shipping-estimator .addresses','border-bottom','none','','','.w-cart-shipping-estimator'),(30125,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable.no-footer','border-bottom','none','','','.b-messages'),(30126,'watch-mobile','.w-account-personal-catalog .list-switcher a','border-bottom','none','2','','.w-account-personal-catalog'),(30127,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','border-bottom','none','2','','.w-catalog-compare'),(30128,'watch-mobile','.w-promotions .heading-3','border-bottom','none','','','.w-promotions'),(30129,'watch-mobile','.w-sale .sale-holder','border-bottom-color','$border-color-10','','','.w-sale'),(30130,'watch-mobile','.w-product-wedding-registry-button .btn','border-bottom-color','$border-color-2','3','','.w-product-wedding-registry-button'),(30131,'watch-mobile','.w-product-sale-ends .left-text-left','border-bottom-color','$border-color-10','','','.w-product-sale-ends'),(30132,'watch-mobile','.w-product-sale-ends .left-text-right','border-bottom-color','$border-color-10','','','.w-product-sale-ends'),(30133,'watch-mobile','.w-currencies .select','border-bottom-color','$border-color-1','','','.w-currencies'),(30135,'watch-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-color','$border-color-5','','','.w-compare-box-item'),(30136,'watch-mobile','.w-catalog-listing-look .list','border-bottom-color','$border-color-1','','','.w-catalog-listing-look'),(30137,'watch-mobile','.w-catalog-listing-look .grid','border-bottom-color','$border-color-1','','','.w-catalog-listing-look'),(30138,'watch-mobile','.b-pagination .pagination span','border-bottom-color','$border-color-1','2','','.b-pagination'),(30139,'watch-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-bottom-color','$border-color-10','2','','.b-product-images'),(30140,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-color','$border-color-1','','','.b-multi-page-checkout'),(30141,'watch-mobile','textarea','border-bottom-color','$border-color-1','','',''),(30142,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-color','$border-color-1','','','.p-blog-index'),(30143,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-color','$border-color-10','','','.b-multi-page-checkout'),(30144,'watch-mobile','.b-info-popup .info-popup div','border-bottom-color','$border-color-1','','','.b-info-popup'),(30145,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-color','$border-color-2','','','.b-multi-page-checkout'),(30146,'watch-mobile','.w-promo-code .holder','border-bottom-color','$border-color-1','','','.w-promo-code'),(30148,'watch-mobile','.testimonials .review','border-bottom-color','transparent','3','',''),(30149,'watch-mobile','.b-pagination .pagination .prev-pages','border-bottom-color','$border-color-1','','','.b-pagination'),(30150,'watch-mobile','.b-pagination .pagination .page-number','border-bottom-color','$border-color-1','','','.b-pagination'),(30151,'watch-mobile','.b-pagination .pagination .prev','border-bottom-color','$border-color-1','','','.b-pagination'),(30152,'watch-mobile','.b-pagination .pagination .next-pages','border-bottom-color','$border-color-1','','','.b-pagination'),(30153,'watch-mobile','.b-pagination .pagination .next','border-bottom-color','$border-color-1','','','.b-pagination'),(30156,'watch-mobile','.w-cart .cart-content','border-bottom-color','$border-color-10','','','.w-cart'),(30157,'watch-mobile','.p-blog-index .comments-area article','border-bottom-color','$border-color-1','','','.p-blog-index'),(30158,'watch-mobile','.w-product-wedding-registry-button .btn','border-bottom-color','$border-color-2','4','','.w-product-wedding-registry-button'),(30159,'watch-mobile','.p-reviews-info .review-info-text','border-bottom-color','$border-color-9','4','','.p-reviews-info'),(30160,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-color','$border-color-1','3','','.b-form'),(30161,'watch-mobile','.p-wedding-registry-manage .links','border-bottom-color','$border-color-1','','','.p-wedding-registry-manage'),(30162,'watch-mobile','.b-pagination .pagination a','border-bottom-color','$border-color-1','','','.b-pagination'),(30164,'watch-mobile','.b-compare .compare_pagination','border-bottom-color','$border-color-1','','','.b-compare'),(30165,'watch-mobile','.w-tabs .accordion-heading','border-bottom-color','$border-color-2','2','','.w-tabs'),(30166,'watch-mobile','.w-tabs .accordion-heading','border-bottom-color','$border-color-1','','','.w-tabs'),(30167,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-color','$border-color-10','','','.b-slick'),(30169,'watch-mobile','.btn','border-bottom-color','$border-color-2','','',''),(30170,'watch-mobile','.w-languages .select','border-bottom-color','$border-color-1','','','.w-languages'),(30171,'watch-mobile','.w-tabs .tab-a','border-bottom-color','$border-color-1','','','.w-tabs'),(30172,'watch-mobile','.w-tabs .tab-a','border-bottom-color','$border-color-2','2','','.w-tabs'),(30173,'watch-mobile','.w-socials > li','border-bottom-color','$border-color-10','','','.w-socials'),(30174,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-bottom-color','$border-color-1','','',''),(30175,'watch-mobile','.heading-4, h4','border-bottom-color','$border-color-1','','',''),(30176,'watch-mobile','.heading-2, h2','border-bottom-color','$border-color-1','','',''),(30177,'watch-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-color','$border-color-1','','','.p-account-trade-form'),(30178,'watch-mobile','.p-account-trade-form .widget .widget','border-bottom-color','$border-color-1','','','.p-account-trade-form'),(30179,'watch-mobile','.w-filters .filter-box-head','border-bottom-color','$border-color-1','','','.w-filters'),(30180,'watch-mobile','.w-currencies .currencies-title','border-bottom-color','$border-color-2','','','.w-currencies'),(30181,'watch-mobile','.w-compare-box-item .checkbox + span','border-bottom-color','$border-color-10','','','.w-compare-box-item'),(30182,'watch-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-color','$border-color-8','','','.b-compare'),(30183,'watch-mobile','.w-cart-products .checkout-attention-message','border-bottom-color','$border-color-3','','','.w-cart-products'),(30184,'watch-mobile','.w-product-quantity .qty_packs .qty-input','border-bottom-color','$border-color-10','','','.w-product-quantity'),(30185,'watch-mobile','.w-sale .left-text-left','border-bottom-color','$border-color-10','','','.w-sale'),(30186,'watch-mobile','.w-sale .left-text-right','border-bottom-color','$border-color-10','','','.w-sale'),(30187,'watch-mobile','.b-form .col-full-padding','border-bottom-color','$border-color-10','','','.b-form'),(30188,'watch-mobile','.b-quantity .qty-box .smaller','border-bottom-color','$border-color-1','','','.b-quantity'),(30189,'watch-mobile','.b-quantity .qty-box .bigger','border-bottom-color','$border-color-1','','','.b-quantity'),(30190,'watch-mobile','.w-cart .cart-total','border-bottom-color','$border-color-1','','','.w-cart'),(30191,'watch-mobile','.w-cart-give-away .ga_column','border-bottom-color','$border-color-1','','','.w-cart-give-away'),(30192,'watch-mobile','.w-catalog-listing-look .b2b','border-bottom-color','$border-color-1','','','.w-catalog-listing-look'),(30193,'watch-mobile','.btn-3','border-bottom-color','$border-color-2','','',''),(30194,'watch-mobile','.b-bottom .popup-box','border-bottom-color','$border-color-10','','','.b-bottom'),(30195,'watch-mobile','.w-reviews .review','border-bottom-color','transparent','3','','.w-reviews'),(30196,'watch-mobile','.b-form .required-error','border-bottom-color','$border-color-3','','','.b-form'),(30199,'watch-mobile','.b-products-listing .products-listing .compare','border-bottom-color','$border-color-1','','','.b-products-listing'),(30200,'watch-mobile','.b-data-table table.dataTable.no-footer','border-bottom-color','$border-color-1','','','.b-data-table'),(30201,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$border-color-1','','','.b-dropdown'),(30202,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$border-color-1','','','.b-dropdown'),(30203,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$border-color-1','','','.b-dropdown'),(30204,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$border-color-1','','','.b-dropdown'),(30205,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$border-color-1','','','.b-dropdown'),(30206,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$border-color-1','','','.b-dropdown'),(30207,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-bottom-color','$border-color-9','','','.b-menu-style-2'),(30208,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','border-bottom-color','$border-color-4','','','.b-menu-style-2'),(30209,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-bottom-color','$border-color-9','','','.b-menu-style-2'),(30210,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-bottom-color','$border-color-9','','','.b-menu-style-2'),(30211,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-bottom-color','$border-color-9','','','.b-menu-style-2'),(30212,'watch-mobile','.b-messages .msv_btn','border-bottom-color','$border-color-1','','','.b-messages'),(30213,'watch-mobile','.b-messages .content_management_attach button','border-bottom-color','$border-color-2','','','.b-messages'),(30214,'watch-mobile','.b-messages .content_management_attach','border-bottom-color','$border-color-1','','','.b-messages'),(30215,'watch-mobile','.b-messages .email-heading','border-bottom-color','$border-color-1','','','.b-messages'),(30216,'watch-mobile','.b-messages .dataTables_wrapper > .bottom','border-bottom-color','$border-color-1','','','.b-messages'),(30217,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-color','$border-color-1','','','.b-messages'),(30218,'watch-mobile','.b-messages .msv_to_cc','border-bottom-color','$border-color-1','','','.b-messages'),(30219,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-color','$border-color-1','','','.b-messages'),(30220,'watch-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-color','$border-color-1','','','.b-messages'),(30221,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-color','$border-color-1','','','.b-select-suggest'),(30222,'watch-mobile','.b-select-suggest .select2-dropdown-open .select2-choice','border-bottom-color','transparent','','','.b-select-suggest'),(30223,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-color','$border-color-1','','','.b-select-suggest'),(30224,'watch-mobile','.b-select-suggest .select2-drop','border-bottom-color','$border-color-1','','','.b-select-suggest'),(30225,'watch-mobile','.b-select-suggest .select2-container .select2-choice','border-bottom-color','$border-color-1','','','.b-select-suggest'),(30226,'watch-mobile','.b-select-suggest .select2-container.select2-drop-above .select2-choice','border-bottom-color','$border-color-1','','','.b-select-suggest'),(30227,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-color','$border-color-1','','','.b-select-suggest'),(30228,'watch-mobile','.b-select-suggest .select2-search input','border-bottom-color','$border-color-1','','','.b-select-suggest'),(30229,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-color','$border-color-1','','','.b-select-suggest'),(30230,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-color','$border-color-1','','','.b-select-suggest'),(30231,'watch-mobile','.b-select-suggest .select2-drop-active','border-bottom-color','$border-color-1','','','.b-select-suggest'),(30232,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-color','$border-color-1','','','.b-select-suggest'),(30233,'watch-mobile','.b-trade-approval .orders-table th','border-bottom-color','$border-color-1','','','.b-trade-approval'),(30234,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-color','$border-color-1','','','.b-trade-approval'),(30235,'watch-mobile','.b-upload-file .snapshot','border-bottom-color','$border-color-8','','','.b-upload-file'),(30236,'watch-mobile','.b-upload-file .upload-file-template div','border-bottom-color','$border-color-1','','','.b-upload-file'),(30237,'watch-mobile','.b-upload-file .upload-file-template','border-bottom-color','$border-color-1','','','.b-upload-file'),(30238,'watch-mobile','.b-upload-files .upload-files','border-bottom-color','$border-color-1','','','.b-upload-files'),(30239,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-color','$border-color-1','','','.batchPr'),(30240,'watch-mobile','.batchPr .checkbox input + span','border-bottom-color','$border-color-1','','','.batchPr'),(30241,'watch-mobile','.batchPr .checkbox input + span','border-bottom-color','$border-color-1','','','.batchPr'),(30242,'watch-mobile','.batchPr .w-batch-selected-products','border-bottom-color','$border-color-1','','','.batchPr'),(30243,'watch-mobile','.batchPr .checkbox input:checked + span','border-bottom-color','$border-color-2','','','.batchPr'),(30244,'watch-mobile','.blogsidebar .heading-title','border-bottom-color','$border-color-1','','','.blogsidebar'),(30245,'watch-mobile','.blogsidebar .heading-title','border-bottom-color','$border-color-1','','','.blogsidebar'),(30246,'watch-mobile','.blogsidebar .heading-title','border-bottom-color','$border-color-1','','','.blogsidebar'),(30247,'watch-mobile','.blogsidebar .heading-title','border-bottom-color','$border-color-1','','','.blogsidebar'),(30262,'watch-mobile','.p-payer-order-confirmation .input-wrapper','border-bottom-color','$border-color-1','','','.p-payer-order-confirmation'),(30263,'watch-mobile','.p-payer-order-pay .input-wrapper','border-bottom-color','$border-color-1','','','.p-payer-order-pay'),(30264,'watch-mobile','.w-account-address-book .wrap','border-bottom-color','$border-color-10','','','.w-account-address-book'),(30265,'watch-mobile','.w-account-personal-catalog .list-switcher a','border-bottom-color','$border-color-1','','','.w-account-personal-catalog'),(30266,'watch-mobile','.w-blog-widget-post-listing .post_content','border-bottom-color','$border-color-1','','','.w-blog-widget-post-listing'),(30267,'watch-mobile','.w-blog-widget-post-listing .post_name','border-bottom-color','$border-color-1','','','.w-blog-widget-post-listing'),(30268,'watch-mobile','.w-blog-widget-post-title ','border-bottom-color','$border-color-1','','','.w-blog-widget-post-title'),(30269,'watch-mobile','.w-cart-compare .compare-table','border-bottom-color','$border-color-1','','','.w-cart-compare'),(30270,'watch-mobile','.w-cart-compare .cart-cell > div','border-bottom-color','$border-color-1','','','.w-cart-compare'),(30271,'watch-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-color','$border-color-9','','','.w-catalog-compare'),(30272,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','border-bottom-color','$border-color-1','','','.w-catalog-compare'),(30273,'watch-mobile','.w-catalog-paging .next','border-bottom-color','$border-color-1','','','.w-catalog-paging'),(30274,'watch-mobile','.w-catalog-paging .prev','border-bottom-color','$border-color-1','','','.w-catalog-paging'),(30275,'watch-mobile','.w-catalog-paging ','border-bottom-color','$border-color-1','2','','.w-catalog-paging'),(30276,'watch-mobile','.w-catalog-paging .next-pages','border-bottom-color','$border-color-1','','','.w-catalog-paging'),(30277,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-color','$border-color-1','','','.w-catalog-paging'),(30278,'watch-mobile','.w-catalog-paging .prev-pages','border-bottom-color','$border-color-1','','','.w-catalog-paging'),(30279,'watch-mobile','.w-catalog-paging .page-number','border-bottom-color','$border-color-1','','','.w-catalog-paging'),(30280,'watch-mobile','.w-checkout-shipping-choice span','border-bottom-color','$border-color-2','','','.w-checkout-shipping-choice'),(30281,'watch-mobile','.w-communication-post .communication-post','border-bottom-color','$border-color-1','','','.w-communication-post'),(30282,'watch-mobile','.w-delivery-day .left-text-left','border-bottom-color','$border-color-1','','','.w-delivery-day'),(30283,'watch-mobile','.w-delivery-day .left-text-right','border-bottom-color','$border-color-1','','','.w-delivery-day'),(30284,'watch-mobile','.w-product-customers-activity .customers-activity','border-bottom-color','$border-color-1','','','.w-product-customers-activity'),(30285,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-color','$border-color-3','','','.w-promotions'),(30286,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-color','$border-color-3','','','.w-promotions'),(30287,'watch-mobile','.w-promotions .promo-salemaker .discount','border-bottom-color','$border-color-3','','','.w-promotions'),(30288,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-color','$border-color-3','','','.w-promotions'),(30289,'watch-mobile','.w-reviews-content .item','border-bottom-color','$border-color-1','','','.w-reviews-content'),(30290,'watch-mobile','.w-reviews-content .review','border-bottom-color','$border-color-1','3','','.w-reviews-content'),(30291,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-color','$border-color-10','','','.w-upload-customer-id-upload-customer-id-form'),(30292,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-bottom-color','$border-color-1','','','.w-wedding-registry-widgets-photos'),(30293,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-bottom-color','$border-color-1','','','.w-wedding-registry-widgets-photos'),(30294,'watch-mobile','.b-data-table table.dataTable.no-footer','border-bottom-color_important','important','','','.b-data-table'),(30295,'watch-mobile','.w-product-sale-ends .left-count-days','border-bottom-left-radius','3','','','.w-product-sale-ends'),(30296,'watch-mobile','.w-sale .left-count-days','border-bottom-left-radius','3','','','.w-sale'),(30297,'watch-mobile','.w-sale .badge','border-bottom-left-radius','50','','','.w-sale'),(30298,'watch-mobile','.w-product-wedding-registry-button .btn','border-bottom-left-radius','50','3','','.w-product-wedding-registry-button'),(30299,'watch-mobile','.w-product-sale-ends .left-count','border-bottom-left-radius','3','','','.w-product-sale-ends'),(30300,'watch-mobile','.w-product-sale-ends .left-count-hours','border-bottom-left-radius','3','','','.w-product-sale-ends'),(30301,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-left-radius','50','3','','.b-multi-page-checkout'),(30302,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-left-radius','50','','','.b-multi-page-checkout'),(30303,'watch-mobile','.p-blog-index .avatar','border-bottom-left-radius','50','','','.p-blog-index'),(30304,'watch-mobile','.w-product-wedding-registry-button .btn','border-bottom-left-radius','50','4','','.w-product-wedding-registry-button'),(30305,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-left-radius','50','3','','.b-form'),(30306,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(30307,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(30308,'watch-mobile','.b-switch .bootstrap-switch','border-bottom-left-radius','14','','','.b-switch'),(30309,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border-bottom-left-radius','30','303','','.w-list-type-1'),(30310,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-left-radius','50','','','.b-slick'),(30311,'watch-mobile','.b-fancybox .fancybox-skin','border-bottom-left-radius','4','','','.b-fancybox'),(30312,'watch-mobile','.w-sale .left-count-hours','border-bottom-left-radius','3','','','.w-sale'),(30313,'watch-mobile','.w-sale .left-count','border-bottom-left-radius','3','','','.w-sale'),(30314,'watch-mobile','.b-fancybox .fancybox-nav span','border-bottom-left-radius','50','','','.b-fancybox'),(30315,'watch-mobile','.btn-3','border-bottom-left-radius','24','','',''),(30316,'watch-mobile','.btn-1','border-bottom-left-radius','20','','',''),(30317,'watch-mobile','.btn','border-bottom-left-radius','24','','',''),(30318,'watch-mobile','.btn-2','border-bottom-left-radius','24','','',''),(30319,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-left-radius','15','','','.b-fancybox'),(30320,'watch-mobile','.b-products-listing .promos-info .promo-name','border-bottom-left-radius','0','','','.b-products-listing'),(30321,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.b-data-table'),(30322,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.b-data-table'),(30323,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-left-radius','5','','','.b-messages'),(30324,'watch-mobile','.b-trade-approval .steps-bar','border-bottom-left-radius','18','','','.b-trade-approval'),(30325,'watch-mobile','.b-upload-file .snapshot','border-bottom-left-radius','50','','','.b-upload-file'),(30326,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-left-radius','10','','','.batchPr'),(30327,'watch-mobile','.batchPr .checkbox input + span','border-bottom-left-radius','18','','','.batchPr'),(30328,'watch-mobile','.batchPr .btn-batch-remove','border-bottom-left-radius','100','','','.batchPr'),(30329,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-bottom-left-radius','0','','','.batchPr'),(30331,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.p-quick-order-index'),(30332,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.p-quick-order-index'),(30333,'watch-mobile','.w-account-address-book .wrap','border-bottom-left-radius','5','','','.w-account-address-book'),(30334,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-bottom-left-radius','0','','','.w-blog-widget-related-posts'),(30335,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-left-radius','0','','','.w-catalog-paging'),(30336,'watch-mobile','.w-checkout-shipping-choice label:last-child span','border-bottom-left-radius','0','','','.w-checkout-shipping-choice'),(30337,'watch-mobile','.w-checkout-shipping-choice label:first-child span','border-bottom-left-radius','16','','','.w-checkout-shipping-choice'),(30338,'watch-mobile','.w-delivery-day .left-count','border-bottom-left-radius','3','','','.w-delivery-day'),(30339,'watch-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-left-radius','3','','','.w-delivery-day'),(30340,'watch-mobile','.w-personal-gift-status-bar .progress-bar-content','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(30341,'watch-mobile','.w-personal-gift-status-bar .progress-bar','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(30342,'watch-mobile','.w-product-customers-activity .customers-activity','border-bottom-left-radius','0','','','.w-product-customers-activity'),(30343,'watch-mobile','.w-product-customers-activity .close','border-bottom-left-radius','50','','','.w-product-customers-activity'),(30344,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-left-radius','12','','','.w-promotions'),(30345,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-left-radius','12','','','.w-promotions'),(30346,'watch-mobile','.w-promotions .promo-salemaker .discount','border-bottom-left-radius','12','','','.w-promotions'),(30347,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-left-radius','12','','','.w-promotions'),(30348,'watch-mobile','.w-product-sale-ends .left-count-days','border-bottom-right-radius','3','','','.w-product-sale-ends'),(30349,'watch-mobile','.w-sale .left-count-days','border-bottom-right-radius','3','','','.w-sale'),(30350,'watch-mobile','.w-sale .badge','border-bottom-right-radius','50','','','.w-sale'),(30351,'watch-mobile','.w-product-wedding-registry-button .btn','border-bottom-right-radius','50','3','','.w-product-wedding-registry-button'),(30352,'watch-mobile','.w-product-sale-ends .left-count','border-bottom-right-radius','3','','','.w-product-sale-ends'),(30353,'watch-mobile','.w-product-sale-ends .left-count-hours','border-bottom-right-radius','3','','','.w-product-sale-ends'),(30354,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-right-radius','50','3','','.b-multi-page-checkout'),(30355,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-right-radius','50','','','.b-multi-page-checkout'),(30356,'watch-mobile','.p-blog-index .avatar','border-bottom-right-radius','50','','','.p-blog-index'),(30357,'watch-mobile','.w-product-wedding-registry-button .btn','border-bottom-right-radius','50','4','','.w-product-wedding-registry-button'),(30358,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-right-radius','50','3','','.b-form'),(30359,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(30360,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(30361,'watch-mobile','.b-switch .bootstrap-switch','border-bottom-right-radius','14','','','.b-switch'),(30362,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border-bottom-right-radius','30','303','','.w-list-type-1'),(30363,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-right-radius','50','','','.b-slick'),(30364,'watch-mobile','.b-fancybox .fancybox-skin','border-bottom-right-radius','4','','','.b-fancybox'),(30365,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-right-radius','15','','','.b-fancybox'),(30366,'watch-mobile','.b-fancybox .fancybox-nav span','border-bottom-right-radius','50','','','.b-fancybox'),(30367,'watch-mobile','.w-sale .left-count-hours','border-bottom-right-radius','3','','','.w-sale'),(30368,'watch-mobile','.w-sale .left-count','border-bottom-right-radius','3','','','.w-sale'),(30369,'watch-mobile','.btn-3','border-bottom-right-radius','24','','',''),(30370,'watch-mobile','.btn-2','border-bottom-right-radius','24','','',''),(30371,'watch-mobile','.btn','border-bottom-right-radius','24','','',''),(30372,'watch-mobile','.btn-1','border-bottom-right-radius','20','','',''),(30373,'watch-mobile','.b-products-listing .promos-info .promo-name','border-bottom-right-radius','8','','','.b-products-listing'),(30374,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.b-data-table'),(30375,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.b-data-table'),(30376,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-right-radius','5','','','.b-messages'),(30377,'watch-mobile','.b-trade-approval .steps-bar','border-bottom-right-radius','18','','','.b-trade-approval'),(30378,'watch-mobile','.b-upload-file .snapshot','border-bottom-right-radius','50','','','.b-upload-file'),(30379,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-right-radius','10','','','.batchPr'),(30380,'watch-mobile','.batchPr .checkbox input + span','border-bottom-right-radius','18','','','.batchPr'),(30381,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-bottom-right-radius','0','','','.batchPr'),(30382,'watch-mobile','.batchPr .btn-batch-remove','border-bottom-right-radius','100','','','.batchPr'),(30384,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.p-quick-order-index'),(30385,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.p-quick-order-index'),(30386,'watch-mobile','.w-account-address-book .wrap','border-bottom-right-radius','5','','','.w-account-address-book'),(30387,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-bottom-right-radius','0','','','.w-blog-widget-related-posts'),(30388,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-right-radius','0','','','.w-catalog-paging'),(30389,'watch-mobile','.w-checkout-shipping-choice label:last-child span','border-bottom-right-radius','16','','','.w-checkout-shipping-choice'),(30390,'watch-mobile','.w-checkout-shipping-choice label:first-child span','border-bottom-right-radius','0','','','.w-checkout-shipping-choice'),(30391,'watch-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-right-radius','3','','','.w-delivery-day'),(30392,'watch-mobile','.w-delivery-day .left-count','border-bottom-right-radius','3','','','.w-delivery-day'),(30393,'watch-mobile','.w-personal-gift-status-bar .progress-bar','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(30394,'watch-mobile','.w-personal-gift-status-bar .progress-bar-content','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(30395,'watch-mobile','.w-product-customers-activity .customers-activity','border-bottom-right-radius','0','','','.w-product-customers-activity'),(30396,'watch-mobile','.w-product-customers-activity .close','border-bottom-right-radius','50','','','.w-product-customers-activity'),(30397,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-right-radius','12','','','.w-promotions'),(30398,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-right-radius','12','','','.w-promotions'),(30399,'watch-mobile','.w-promotions .promo-salemaker .discount','border-bottom-right-radius','12','','','.w-promotions'),(30400,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-right-radius','12','','','.w-promotions'),(30401,'watch-mobile','.b-upload-file .upload-file-template div','border-bottom-style','dotted','','','.b-upload-file'),(30402,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(30403,'watch-mobile','.w-sale .sale-holder','border-bottom-width','2','','','.w-sale'),(30404,'watch-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','border-bottom-width','2','','','.b-product-images'),(30405,'watch-mobile','.w-product-wedding-registry-button .btn','border-bottom-width','2','3','','.w-product-wedding-registry-button'),(30406,'watch-mobile','.w-product-sale-ends .left-text-right','border-bottom-width','2','','','.w-product-sale-ends'),(30407,'watch-mobile','.w-product-sale-ends .left-text-left','border-bottom-width','2','','','.w-product-sale-ends'),(30408,'watch-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-bottom-width','2','2','','.b-product-images'),(30409,'watch-mobile','.w-currencies .select','border-bottom-width','1','','','.w-currencies'),(30411,'watch-mobile','.b-pagination .pagination span','border-bottom-width','1','2','','.b-pagination'),(30412,'watch-mobile','.w-product-reviews .reviews-list .review','border-bottom-width','13','3','','.w-product-reviews'),(30413,'watch-mobile','.w-catalog-listing-look .list','border-bottom-width','1','','','.w-catalog-listing-look'),(30414,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-width','1','','','.b-multi-page-checkout'),(30415,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-width','2','','','.p-blog-index'),(30416,'watch-mobile','textarea','border-bottom-width','2','','',''),(30417,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(30418,'watch-mobile','.b-info-popup .info-popup div','border-bottom-width','1','','','.b-info-popup'),(30419,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(30420,'watch-mobile','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(30422,'watch-mobile','.testimonials .review','border-bottom-width','7','3','',''),(30423,'watch-mobile','.b-pagination .pagination .prev','border-bottom-width','1','','','.b-pagination'),(30424,'watch-mobile','.b-pagination .pagination .prev-pages','border-bottom-width','1','','','.b-pagination'),(30425,'watch-mobile','.p-wedding-registry-manage .wr-search button','border-bottom-width','0','','','.p-wedding-registry-manage'),(30426,'watch-mobile','.b-pagination .pagination .page-number','border-bottom-width','1','','','.b-pagination'),(30427,'watch-mobile','.b-pagination .pagination .next-pages','border-bottom-width','1','','','.b-pagination'),(30428,'watch-mobile','.b-pagination .pagination .next','border-bottom-width','1','','','.b-pagination'),(30431,'watch-mobile','.p-blog-index .comments-area article','border-bottom-width','1','','','.p-blog-index'),(30432,'watch-mobile','.w-cart .cart-content','border-bottom-width','1','','','.w-cart'),(30433,'watch-mobile','.w-list-type-2_2 .button-wishlist button','border-bottom-width','0','','','.w-list-type-2_2'),(30434,'watch-mobile','.w-product-wedding-registry-button .btn','border-bottom-width','2','4','','.w-product-wedding-registry-button'),(30435,'watch-mobile','.p-reviews-info .review-info-text','border-bottom-width','5','4','','.p-reviews-info'),(30436,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-width','2','3','','.b-form'),(30437,'watch-mobile','.p-wedding-registry-manage .links','border-bottom-width','1','','','.p-wedding-registry-manage'),(30438,'watch-mobile','.b-pagination .pagination a','border-bottom-width','1','','','.b-pagination'),(30439,'watch-mobile','.b-bottom .popup-heading','border-bottom-width','1','','','.b-bottom'),(30440,'watch-mobile','.b-compare .compare_pagination','border-bottom-width','1','','','.b-compare'),(30441,'watch-mobile','.w-tabs .accordion-heading','border-bottom-width','1','','','.w-tabs'),(30442,'watch-mobile','.w-tabs .accordion-heading','border-bottom-width','3','2','','.w-tabs'),(30443,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-width','2','','','.b-slick'),(30444,'watch-mobile','.b-bottom .footerTitle','border-bottom-width','1','290','','.b-bottom'),(30445,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-bottom-width','2','','',''),(30446,'watch-mobile','.btn','border-bottom-width','2','','',''),(30447,'watch-mobile','.w-tabs .tab-a','border-bottom-width','3','2','','.w-tabs'),(30448,'watch-mobile','.w-tabs .tab-a','border-bottom-width','1','','','.w-tabs'),(30449,'watch-mobile','.w-search .search-input','border-bottom-width','0','','','.w-search'),(30450,'watch-mobile','.p-account-trade-form .widget .widget','border-bottom-width','1','','','.p-account-trade-form'),(30451,'watch-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-width','1','','','.p-account-trade-form'),(30452,'watch-mobile','.w-filters .filter-box-head','border-bottom-width','1','','','.w-filters'),(30453,'watch-mobile','.w-currencies .currencies-title','border-bottom-width','2','','','.w-currencies'),(30454,'watch-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-width','1','','','.w-compare-box-item'),(30455,'watch-mobile','.w-compare-box-item .checkbox + span','border-bottom-width','1','','','.w-compare-box-item'),(30456,'watch-mobile','.b-slick .slick-vertical .slick-slide','border-bottom-width','1','','','.b-slick'),(30457,'watch-mobile','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(30458,'watch-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-width','1','','','.b-compare'),(30459,'watch-mobile','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(30460,'watch-mobile','.heading-4, h4','border-bottom-width','1','','',''),(30461,'watch-mobile','.heading-2, h2','border-bottom-width','1','','',''),(30462,'watch-mobile','.w-sale .left-text-right','border-bottom-width','2','','','.w-sale'),(30463,'watch-mobile','.w-sale .left-text-left','border-bottom-width','2','','','.w-sale'),(30464,'watch-mobile','.b-form .col-full-padding','border-bottom-width','1','','','.b-form'),(30465,'watch-mobile','.b-quantity .qty-box .smaller','border-bottom-width','2','','','.b-quantity'),(30466,'watch-mobile','.b-quantity .qty-box .bigger','border-bottom-width','2','','','.b-quantity'),(30467,'watch-mobile','.w-cart .cart-total','border-bottom-width','1','','','.w-cart'),(30468,'watch-mobile','.w-catalog-listing-look .grid','border-bottom-width','1','','','.w-catalog-listing-look'),(30469,'watch-mobile','.w-cart-give-away .ga_column','border-bottom-width','1','','','.w-cart-give-away'),(30470,'watch-mobile','.w-catalog-listing-look .b2b','border-bottom-width','1','','','.w-catalog-listing-look'),(30471,'watch-mobile','.w-list-type-2 .button-wishlist button','border-bottom-width','0','','','.w-list-type-2'),(30472,'watch-mobile','.b-autocomplete .ui-autocomplete li','border-bottom-width','1','','','.b-autocomplete'),(30473,'watch-mobile','.btn-3','border-bottom-width','2','','',''),(30474,'watch-mobile','.w-list-type-1_3 .button-wishlist button','border-bottom-width','0','','','.w-list-type-1_3'),(30475,'watch-mobile','.w-list-type-1_2 .button-wishlist button','border-bottom-width','0','','','.w-list-type-1_2'),(30476,'watch-mobile','.b-bottom .popup-box','border-bottom-width','1','','','.b-bottom'),(30477,'watch-mobile','.w-list-type-1 .button-wishlist button','border-bottom-width','0','','','.w-list-type-1'),(30478,'watch-mobile','.w-filters .ui-slider','border-bottom-width','0','','','.w-filters'),(30479,'watch-mobile','.w-filters .ui-slider-range','border-bottom-width','0','','','.w-filters'),(30480,'watch-mobile','.w-filters .ui-slider-handle','border-bottom-width','0','','','.w-filters'),(30481,'watch-mobile','.w-languages .select','border-bottom-width','1','','','.w-languages'),(30482,'watch-mobile','.w-reviews .review','border-bottom-width','7','3','','.w-reviews'),(30483,'watch-mobile','.w-search .button-search','border-bottom-width','0','','','.w-search'),(30484,'watch-mobile','.w-socials > li','border-bottom-width','1','','','.w-socials'),(30485,'watch-mobile','.b-form .required-error','border-bottom-width','1','','','.b-form'),(30488,'watch-mobile','.b-products-listing .products-listing .compare','border-bottom-width','1','','','.b-products-listing'),(30489,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(30490,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(30491,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(30492,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(30493,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(30494,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(30495,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','border-bottom-width','1','','','.b-menu-style-2'),(30496,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-bottom-width','1','','','.b-menu-style-2'),(30497,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-bottom-width','3','','','.b-menu-style-2'),(30498,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-bottom-width','1','','','.b-menu-style-2'),(30499,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-bottom-width','3','','','.b-menu-style-2'),(30500,'watch-mobile','.b-messages .msv_to_cc','border-bottom-width','1','','','.b-messages'),(30501,'watch-mobile','.b-messages .msv_btn','border-bottom-width','1','','','.b-messages'),(30502,'watch-mobile','.b-messages .email-heading','border-bottom-width','1','','','.b-messages'),(30503,'watch-mobile','.b-messages .content_management_attach button','border-bottom-width','1','','','.b-messages'),(30504,'watch-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-width','2','','','.b-messages'),(30505,'watch-mobile','.b-messages .content_management_attach','border-bottom-width','1','','','.b-messages'),(30506,'watch-mobile','.b-messages .dataTables_wrapper > .bottom','border-bottom-width','1','','','.b-messages'),(30507,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-width','1','','','.b-messages'),(30508,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-width','1','','','.b-messages'),(30509,'watch-mobile','.b-select-suggest .select2-search input','border-bottom-width','1','','','.b-select-suggest'),(30510,'watch-mobile','.b-select-suggest .select2-container .select2-choice','border-bottom-width','2','','','.b-select-suggest'),(30511,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(30512,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(30513,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(30514,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-width','1','','','.b-select-suggest'),(30515,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(30516,'watch-mobile','.b-select-suggest .select2-drop-active','border-bottom-width','1','','','.b-select-suggest'),(30517,'watch-mobile','.b-select-suggest .select2-drop','border-bottom-width','1','','','.b-select-suggest'),(30518,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(30519,'watch-mobile','.b-trade-approval .orders-table th','border-bottom-width','1','','','.b-trade-approval'),(30520,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-width','2','','','.b-trade-approval'),(30521,'watch-mobile','.b-upload-file .snapshot','border-bottom-width','1','','','.b-upload-file'),(30522,'watch-mobile','.b-upload-file .upload-file-template div','border-bottom-width','1','','','.b-upload-file'),(30523,'watch-mobile','.b-upload-file .upload-file-template','border-bottom-width','1','','','.b-upload-file'),(30524,'watch-mobile','.b-upload-files .upload-files','border-bottom-width','1','','','.b-upload-files'),(30525,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-width','1','','','.batchPr'),(30526,'watch-mobile','.batchPr .checkbox input + span','border-bottom-width','1','','','.batchPr'),(30527,'watch-mobile','.batchPr .checkbox input + span','border-bottom-width','1','','','.batchPr'),(30528,'watch-mobile','.batchPr .checkbox input:checked + span','border-bottom-width','1','','','.batchPr'),(30529,'watch-mobile','.batchPr .w-batch-selected-products','border-bottom-width','1','','','.batchPr'),(30530,'watch-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(30531,'watch-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(30532,'watch-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(30533,'watch-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(30548,'watch-mobile','.p-payer-order-confirmation .input-wrapper','border-bottom-width','2','','','.p-payer-order-confirmation'),(30549,'watch-mobile','.p-payer-order-pay .input-wrapper','border-bottom-width','2','','','.p-payer-order-pay'),(30550,'watch-mobile','.w-account-address-book .wrap','border-bottom-width','1','','','.w-account-address-book'),(30551,'watch-mobile','.w-account-personal-catalog .list-switcher a','border-bottom-width','1','','','.w-account-personal-catalog'),(30552,'watch-mobile','.w-blog-widget-post-listing .post_content','border-bottom-width','1','','','.w-blog-widget-post-listing'),(30553,'watch-mobile','.w-blog-widget-post-listing .post_name','border-bottom-width','1','','','.w-blog-widget-post-listing'),(30554,'watch-mobile','.w-blog-widget-post-title ','border-bottom-width','1','','','.w-blog-widget-post-title'),(30555,'watch-mobile','.w-cart-compare .cart-cell > div','border-bottom-width','1','','','.w-cart-compare'),(30556,'watch-mobile','.w-cart-compare .compare-table','border-bottom-width','1','','','.w-cart-compare'),(30557,'watch-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-width','1','','','.w-catalog-compare'),(30558,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','border-bottom-width','1','','','.w-catalog-compare'),(30559,'watch-mobile','.w-catalog-paging .prev','border-bottom-width','1','','','.w-catalog-paging'),(30560,'watch-mobile','.w-catalog-paging .page-number','border-bottom-width','1','','','.w-catalog-paging'),(30561,'watch-mobile','.w-catalog-paging .next','border-bottom-width','1','','','.w-catalog-paging'),(30562,'watch-mobile','.w-catalog-paging ','border-bottom-width','1','2','','.w-catalog-paging'),(30563,'watch-mobile','.w-catalog-paging .next-pages','border-bottom-width','1','','','.w-catalog-paging'),(30564,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-width','1','','','.w-catalog-paging'),(30565,'watch-mobile','.w-catalog-paging .prev-pages','border-bottom-width','1','','','.w-catalog-paging'),(30566,'watch-mobile','.w-checkout-shipping-choice span','border-bottom-width','2','','','.w-checkout-shipping-choice'),(30567,'watch-mobile','.w-communication-post .communication-post','border-bottom-width','1','','','.w-communication-post'),(30568,'watch-mobile','.w-delivery-day .left-text-right','border-bottom-width','2','','','.w-delivery-day'),(30569,'watch-mobile','.w-delivery-day .left-text-left','border-bottom-width','2','','','.w-delivery-day'),(30570,'watch-mobile','.w-product-customers-activity .customers-activity','border-bottom-width','1','','','.w-product-customers-activity'),(30571,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-width','1','','','.w-promotions'),(30572,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-width','1','','','.w-promotions'),(30573,'watch-mobile','.w-promotions .promo-salemaker .discount','border-bottom-width','1','','','.w-promotions'),(30574,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-width','1','','','.w-promotions'),(30575,'watch-mobile','.w-reviews-content .review','border-bottom-width','8','3','','.w-reviews-content'),(30576,'watch-mobile','.w-reviews-content .item','border-bottom-width','1','','','.w-reviews-content'),(30577,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(30578,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-bottom-width','1','','','.w-wedding-registry-widgets-photos'),(30579,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-bottom-width','1','','','.w-wedding-registry-widgets-photos'),(30580,'watch-mobile','.b-compare .popupCompare table','border-collapse','collapse','','','.b-compare'),(30581,'watch-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','border-left','none','','','.b-select-suggest'),(30582,'watch-mobile','.w-catalog-listing-look .list','border-left-color','$border-color-1','','','.w-catalog-listing-look'),(30583,'watch-mobile','.w-sale .sale-holder','border-left-color','$border-color-10','','','.w-sale'),(30584,'watch-mobile','.w-product-wedding-registry-button .btn','border-left-color','$border-color-2','3','','.w-product-wedding-registry-button'),(30585,'watch-mobile','.w-cart-products .checkout-attention-message','border-left-color','$border-color-3','','','.w-cart-products'),(30586,'watch-mobile','.w-currencies .select','border-left-color','$border-color-1','','','.w-currencies'),(30587,'watch-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-left-color','$border-color-10','2','','.b-product-images'),(30588,'watch-mobile','.b-pagination .pagination span','border-left-color','$border-color-1','2','','.b-pagination'),(30589,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-color','$border-color-1','','','.b-multi-page-checkout'),(30590,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-color','$border-color-1','','','.p-blog-index'),(30591,'watch-mobile','textarea','border-left-color','$border-color-1','','',''),(30592,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-color','$border-color-10','','','.b-multi-page-checkout'),(30593,'watch-mobile','.b-info-popup .info-popup div','border-left-color','$border-color-1','3','','.b-info-popup'),(30594,'watch-mobile','.b-info-popup .info-popup div','border-left-color','$border-color-1','','','.b-info-popup'),(30595,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-color','$border-color-2','','','.b-multi-page-checkout'),(30596,'watch-mobile','.w-promo-code .holder','border-left-color','$border-color-1','','','.w-promo-code'),(30597,'watch-mobile','.testimonials .review','border-left-color','$border-color-1','3','',''),(30598,'watch-mobile','.b-pagination .pagination .prev-pages','border-left-color','$border-color-1','','','.b-pagination'),(30599,'watch-mobile','.b-pagination .pagination .prev','border-left-color','$border-color-1','','','.b-pagination'),(30600,'watch-mobile','.b-pagination .pagination .page-number','border-left-color','$border-color-1','','','.b-pagination'),(30601,'watch-mobile','.b-pagination .pagination .next-pages','border-left-color','$border-color-1','','','.b-pagination'),(30602,'watch-mobile','.b-pagination .pagination .next','border-left-color','$border-color-1','','','.b-pagination'),(30605,'watch-mobile','.w-cart .cart-content','border-left-color','$border-color-10','','','.w-cart'),(30606,'watch-mobile','.w-product-wedding-registry-button .btn','border-left-color','$border-color-2','4','','.w-product-wedding-registry-button'),(30607,'watch-mobile','.p-reviews-info .review-info-text','border-left-color','$border-color-9','4','','.p-reviews-info'),(30608,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-left-color','$border-color-1','3','','.b-form'),(30609,'watch-mobile','.p-wedding-registry-manage .links a + a','border-left-color','$border-color-1','','','.p-wedding-registry-manage'),(30610,'watch-mobile','.b-pagination .pagination a','border-left-color','$border-color-1','','','.b-pagination'),(30611,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-left-color','$border-color-10','','','.b-slick'),(30612,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-left-color','$border-color-1','','',''),(30613,'watch-mobile','.w-socials > li','border-left-color','$border-color-10','','','.w-socials'),(30614,'watch-mobile','.w-currencies .currencies-title','border-left-color','$border-color-2','','','.w-currencies'),(30615,'watch-mobile','.w-compare-box-item .checkbox:checked + span','border-left-color','$border-color-5','','','.w-compare-box-item'),(30616,'watch-mobile','.w-compare-box-item .checkbox + span','border-left-color','$border-color-10','','','.w-compare-box-item'),(30617,'watch-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-color','$border-color-8','','','.b-compare'),(30618,'watch-mobile','.b-quantity .qty-box .smaller','border-left-color','$border-color-1','','','.b-quantity'),(30619,'watch-mobile','.b-quantity .qty-box .bigger','border-left-color','$border-color-1','','','.b-quantity'),(30620,'watch-mobile','.w-catalog-listing-look .grid','border-left-color','$border-color-1','','','.w-catalog-listing-look'),(30621,'watch-mobile','.w-catalog-listing-look .b2b','border-left-color','$border-color-1','','','.w-catalog-listing-look'),(30622,'watch-mobile','.btn-3','border-left-color','$border-color-2','','',''),(30623,'watch-mobile','.btn','border-left-color','$border-color-2','','',''),(30624,'watch-mobile','.b-bottom .popup-box','border-left-color','$border-color-10','','','.b-bottom'),(30625,'watch-mobile','.w-languages .select','border-left-color','$border-color-1','','','.w-languages'),(30626,'watch-mobile','.w-reviews .review','border-left-color','$border-color-9','3','','.w-reviews'),(30627,'watch-mobile','.b-form .required-error','border-left-color','$border-color-3','','','.b-form'),(30628,'watch-mobile','.b-data-table table.dataTable.no-footer','border-left-color','$border-color-1','','','.b-data-table'),(30629,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','$border-color-1','','','.b-dropdown'),(30630,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','$border-color-1','','','.b-dropdown'),(30631,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','$border-color-1','','','.b-dropdown'),(30632,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','$border-color-1','','','.b-dropdown'),(30633,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','$border-color-1','','','.b-dropdown'),(30634,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','$border-color-1','','','.b-dropdown'),(30635,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-left-color','$border-color-9','','','.b-menu-style-2'),(30636,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-left-color','$border-color-9','','','.b-menu-style-2'),(30637,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-left-color','$border-color-9','','','.b-menu-style-2'),(30638,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-left-color','$border-color-9','','','.b-menu-style-2'),(30639,'watch-mobile','.b-messages .content_management_attach button','border-left-color','$border-color-2','','','.b-messages'),(30640,'watch-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-color','$border-color-1','','','.b-messages'),(30641,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-color','$border-color-1','','','.b-select-suggest'),(30642,'watch-mobile','.b-select-suggest .select2-search input','border-left-color','$border-color-1','','','.b-select-suggest'),(30643,'watch-mobile','.b-select-suggest .select2-container .select2-choice','border-left-color','$border-color-1','','','.b-select-suggest'),(30644,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-color','$border-color-1','','','.b-select-suggest'),(30645,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-color','$border-color-1','','','.b-select-suggest'),(30646,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-color','$border-color-1','','','.b-select-suggest'),(30647,'watch-mobile','.b-select-suggest .select2-drop-active','border-left-color','$border-color-1','','','.b-select-suggest'),(30648,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-left-color','$border-color-1','','','.b-select-suggest'),(30649,'watch-mobile','.b-select-suggest .select2-drop','border-left-color','$border-color-1','','','.b-select-suggest'),(30650,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-color','$border-color-1','','','.b-select-suggest'),(30651,'watch-mobile','.b-trade-approval .steps-bar li ~ li a','border-left-color','$border-color-9','','','.b-trade-approval'),(30652,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-color','$border-color-1','','','.b-trade-approval'),(30653,'watch-mobile','.b-upload-file .snapshot','border-left-color','$border-color-8','','','.b-upload-file'),(30654,'watch-mobile','.b-upload-file .upload-file-template','border-left-color','$border-color-1','','','.b-upload-file'),(30655,'watch-mobile','.b-upload-files .upload-files','border-left-color','$border-color-1','','','.b-upload-files'),(30656,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-left-color','$border-color-1','','','.batchPr'),(30657,'watch-mobile','.batchPr .checkbox input + span','border-left-color','$border-color-1','','','.batchPr'),(30658,'watch-mobile','.batchPr .checkbox input + span','border-left-color','$border-color-1','','','.batchPr'),(30659,'watch-mobile','.batchPr .checkbox input:checked + span','border-left-color','$border-color-2','','','.batchPr'),(30660,'watch-mobile','.batchPr .w-batch-selected-products','border-left-color','$border-color-1','','','.batchPr'),(30669,'watch-mobile','.p-payer-order-confirmation .input-wrapper','border-left-color','$border-color-1','','','.p-payer-order-confirmation'),(30670,'watch-mobile','.p-payer-order-pay .input-wrapper','border-left-color','$border-color-1','','','.p-payer-order-pay'),(30671,'watch-mobile','.w-account-address-book .wrap','border-left-color','$border-color-10','','','.w-account-address-book'),(30672,'watch-mobile','.w-account-personal-catalog .list-switcher a','border-left-color','$border-color-1','2','','.w-account-personal-catalog'),(30673,'watch-mobile','.w-cart-compare .attributes-block td:nth-child(1)','border-left-color','$border-color-1','','','.w-cart-compare'),(30674,'watch-mobile','.w-cart-compare .price-block td:nth-child(1)','border-left-color','$border-color-1','','','.w-cart-compare'),(30675,'watch-mobile','.w-cart-compare .product-block td:nth-child(1)','border-left-color','$border-color-1','','','.w-cart-compare'),(30676,'watch-mobile','.w-cart-compare .cart-cell > div','border-left-color','$border-color-1','','','.w-cart-compare'),(30677,'watch-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-left-color','$border-color-9','','','.w-catalog-compare'),(30678,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','border-left-color','$border-color-1','2','','.w-catalog-compare'),(30679,'watch-mobile','.w-catalog-paging ','border-left-color','$border-color-1','2','','.w-catalog-paging'),(30680,'watch-mobile','.w-catalog-paging .prev','border-left-color','$border-color-1','','','.w-catalog-paging'),(30681,'watch-mobile','.w-catalog-paging .next','border-left-color','$border-color-1','','','.w-catalog-paging'),(30682,'watch-mobile','.w-catalog-paging .page-number','border-left-color','$border-color-1','','','.w-catalog-paging'),(30683,'watch-mobile','.w-catalog-paging .next-pages','border-left-color','$border-color-1','','','.w-catalog-paging'),(30684,'watch-mobile','.w-catalog-paging .prev-pages','border-left-color','$border-color-1','','','.w-catalog-paging'),(30685,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-color','$border-color-1','','','.w-catalog-paging'),(30686,'watch-mobile','.w-checkout-shipping-choice label:first-child span','border-left-color','$border-color-2','','','.w-checkout-shipping-choice'),(30687,'watch-mobile','.w-product-customers-activity .customers-activity','border-left-color','$border-color-1','','','.w-product-customers-activity'),(30688,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-left-color','$border-color-3','','','.w-promotions'),(30689,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-color','$border-color-3','','','.w-promotions'),(30690,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border-left-color','$border-color-3','','','.w-promotions'),(30691,'watch-mobile','.w-promotions .promo-salemaker .discount','border-left-color','$border-color-3','','','.w-promotions'),(30692,'watch-mobile','.w-reviews-content .review','border-left-color','$border-color-1','3','','.w-reviews-content'),(30693,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-color','$border-color-10','','','.w-upload-customer-id-upload-customer-id-form'),(30694,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-left-color','$border-color-1','','','.w-wedding-registry-widgets-photos'),(30695,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-left-color','$border-color-1','','','.w-wedding-registry-widgets-photos'),(30696,'watch-mobile','.b-data-table table.dataTable.no-footer','border-left-color_important','important','','','.b-data-table'),(30697,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(30698,'watch-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','border-left-width','2','','','.b-product-images'),(30699,'watch-mobile','.w-sale .sale-holder','border-left-width','2','','','.w-sale'),(30700,'watch-mobile','.w-product-wedding-registry-button .btn','border-left-width','2','3','','.w-product-wedding-registry-button'),(30701,'watch-mobile','.w-currencies .select','border-left-width','1','','','.w-currencies'),(30702,'watch-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-left-width','2','2','','.b-product-images'),(30703,'watch-mobile','.w-compare-box-item .checkbox + span','border-left-width','1','','','.w-compare-box-item'),(30704,'watch-mobile','.w-catalog-listing-look .b2b','border-left-width','1','','','.w-catalog-listing-look'),(30705,'watch-mobile','.w-catalog-listing-look .list','border-left-width','1','','','.w-catalog-listing-look'),(30706,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-width','1','','','.b-multi-page-checkout'),(30707,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-width','2','','','.p-blog-index'),(30708,'watch-mobile','textarea','border-left-width','2','','',''),(30709,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(30710,'watch-mobile','.btn','border-left-width','2','','',''),(30711,'watch-mobile','.btn-3','border-left-width','2','','',''),(30712,'watch-mobile','.b-info-popup .info-popup div','border-left-width','1','','','.b-info-popup'),(30713,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(30714,'watch-mobile','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(30715,'watch-mobile','.testimonials .review','border-left-width','10','3','',''),(30716,'watch-mobile','.b-pagination .pagination .prev-pages','border-left-width','1','','','.b-pagination'),(30717,'watch-mobile','.b-pagination .pagination .prev','border-left-width','1','','','.b-pagination'),(30718,'watch-mobile','.p-wedding-registry-manage .wr-search button','border-left-width','0','','','.p-wedding-registry-manage'),(30719,'watch-mobile','.b-pagination .pagination .page-number','border-left-width','1','','','.b-pagination'),(30720,'watch-mobile','.b-pagination .pagination .next-pages','border-left-width','1','','','.b-pagination'),(30721,'watch-mobile','.b-pagination .pagination .next','border-left-width','1','','','.b-pagination'),(30722,'watch-mobile','.b-pagination .pagination span','border-left-width','1','2','','.b-pagination'),(30725,'watch-mobile','.w-cart .cart-content','border-left-width','1','','','.w-cart'),(30726,'watch-mobile','.w-list-type-2_2 .button-wishlist button','border-left-width','0','','','.w-list-type-2_2'),(30727,'watch-mobile','.w-list-type-2_2 .button-wishlist','border-left-width','1','','','.w-list-type-2_2'),(30728,'watch-mobile','.w-product-wedding-registry-button .btn','border-left-width','2','4','','.w-product-wedding-registry-button'),(30729,'watch-mobile','.p-reviews-info .review-info-text','border-left-width','5','4','','.p-reviews-info'),(30730,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-left-width','2','3','','.b-form'),(30731,'watch-mobile','.p-wedding-registry-manage .links a + a','border-left-width','1','','','.p-wedding-registry-manage'),(30732,'watch-mobile','.b-pagination .pagination a','border-left-width','1','','','.b-pagination'),(30733,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-left-width','2','','','.b-slick'),(30734,'watch-mobile','.w-languages .select','border-left-width','1','','','.w-languages'),(30735,'watch-mobile','.w-search .search-input','border-left-width','0','','','.w-search'),(30736,'watch-mobile','.w-socials > li','border-left-width','1','','','.w-socials'),(30737,'watch-mobile','.w-currencies .currencies-title','border-left-width','2','','','.w-currencies'),(30738,'watch-mobile','.w-compare-box-item .checkbox:checked + span','border-left-width','1','','','.w-compare-box-item'),(30739,'watch-mobile','.b-slick .slick-vertical .slick-slide','border-left-width','1','','','.b-slick'),(30740,'watch-mobile','.b-info-popup .info-popup div','border-left-width','1','3','','.b-info-popup'),(30741,'watch-mobile','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(30742,'watch-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-width','1','','','.b-compare'),(30743,'watch-mobile','.w-catalog-listing-look .grid','border-left-width','1','','','.w-catalog-listing-look'),(30744,'watch-mobile','.b-quantity .qty-box .smaller','border-left-width','2','','','.b-quantity'),(30745,'watch-mobile','.b-quantity .qty-box .bigger','border-left-width','2','','','.b-quantity'),(30746,'watch-mobile','.b-autocomplete .ui-autocomplete li','border-left-width','1','','','.b-autocomplete'),(30747,'watch-mobile','.w-list-type-2 .button-wishlist button','border-left-width','0','','','.w-list-type-2'),(30748,'watch-mobile','.w-list-type-2 .button-wishlist','border-left-width','1','','','.w-list-type-2'),(30749,'watch-mobile','.w-list-type-1_3 .button-wishlist button','border-left-width','0','','','.w-list-type-1_3'),(30750,'watch-mobile','.w-list-type-1_3 .button-wishlist','border-left-width','1','','','.w-list-type-1_3'),(30751,'watch-mobile','.w-list-type-1_2 .button-wishlist button','border-left-width','0','','','.w-list-type-1_2'),(30752,'watch-mobile','.w-list-type-1_2 .button-wishlist','border-left-width','1','','','.w-list-type-1_2'),(30753,'watch-mobile','.b-bottom .popup-box','border-left-width','1','','','.b-bottom'),(30754,'watch-mobile','.w-list-type-1 .button-wishlist button','border-left-width','0','','','.w-list-type-1'),(30755,'watch-mobile','.w-filters .ui-slider','border-left-width','0','','','.w-filters'),(30756,'watch-mobile','.w-list-type-1 .button-wishlist','border-left-width','1','','','.w-list-type-1'),(30757,'watch-mobile','.w-filters .ui-slider-range','border-left-width','0','','','.w-filters'),(30758,'watch-mobile','.w-filters .ui-slider-handle','border-left-width','0','','','.w-filters'),(30759,'watch-mobile','.w-product-reviews .reviews-list .review','border-left-width','20','3','','.w-product-reviews'),(30760,'watch-mobile','.w-search .button-search','border-left-width','0','','','.w-search'),(30761,'watch-mobile','.w-reviews .review','border-left-width','10','3','','.w-reviews'),(30762,'watch-mobile','.b-form .required-error','border-left-width','1','','','.b-form'),(30763,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-left-width','2','','',''),(30764,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(30765,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(30766,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(30767,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(30768,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(30769,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(30770,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-left-width','1','','','.b-menu-style-2'),(30771,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-left-width','3','','','.b-menu-style-2'),(30772,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-left-width','1','','','.b-menu-style-2'),(30773,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-left-width','3','','','.b-menu-style-2'),(30774,'watch-mobile','.b-messages .content_management_attach button','border-left-width','1','','','.b-messages'),(30775,'watch-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-width','2','','','.b-messages'),(30776,'watch-mobile','.b-select-suggest .select2-container .select2-choice','border-left-width','2','','','.b-select-suggest'),(30777,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-width','1','','','.b-select-suggest'),(30778,'watch-mobile','.b-select-suggest .select2-search input','border-left-width','1','','','.b-select-suggest'),(30779,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(30780,'watch-mobile','.b-select-suggest .select2-drop','border-left-width','1','','','.b-select-suggest'),(30781,'watch-mobile','.b-select-suggest .select2-drop-active','border-left-width','1','','','.b-select-suggest'),(30782,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-width','1','','','.b-select-suggest'),(30783,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','border-left-width','0','','','.b-select-suggest'),(30784,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-left-width','1','','','.b-select-suggest'),(30785,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-width','1','','','.b-select-suggest'),(30786,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(30787,'watch-mobile','.b-trade-approval .steps-bar li ~ li a','border-left-width','1','','','.b-trade-approval'),(30788,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-width','2','','','.b-trade-approval'),(30789,'watch-mobile','.b-upload-file .upload-file-template','border-left-width','1','','','.b-upload-file'),(30790,'watch-mobile','.b-upload-file .snapshot','border-left-width','1','','','.b-upload-file'),(30791,'watch-mobile','.b-upload-files .upload-files','border-left-width','1','','','.b-upload-files'),(30792,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-left-width','1','','','.batchPr'),(30793,'watch-mobile','.batchPr .checkbox input + span','border-left-width','1','','','.batchPr'),(30794,'watch-mobile','.batchPr .checkbox input + span','border-left-width','1','','','.batchPr'),(30795,'watch-mobile','.batchPr .checkbox input:checked + span','border-left-width','1','','','.batchPr'),(30796,'watch-mobile','.batchPr .w-batch-selected-products','border-left-width','1','','','.batchPr'),(30805,'watch-mobile','.p-payer-order-confirmation .input-wrapper','border-left-width','2','','','.p-payer-order-confirmation'),(30806,'watch-mobile','.p-payer-order-pay .input-wrapper','border-left-width','2','','','.p-payer-order-pay'),(30807,'watch-mobile','.w-account-address-book .wrap','border-left-width','1','','','.w-account-address-book'),(30808,'watch-mobile','.w-account-personal-catalog .list-switcher a','border-left-width','1','2','','.w-account-personal-catalog'),(30809,'watch-mobile','.w-cart-compare .attributes-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(30810,'watch-mobile','.w-cart-compare .price-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(30811,'watch-mobile','.w-cart-compare .product-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(30812,'watch-mobile','.w-cart-compare .cart-cell > div','border-left-width','1','','','.w-cart-compare'),(30813,'watch-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-left-width','1','','','.w-catalog-compare'),(30814,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','border-left-width','1','2','','.w-catalog-compare'),(30815,'watch-mobile','.w-catalog-paging ','border-left-width','1','2','','.w-catalog-paging'),(30816,'watch-mobile','.w-catalog-paging .prev','border-left-width','1','','','.w-catalog-paging'),(30817,'watch-mobile','.w-catalog-paging .page-number','border-left-width','1','','','.w-catalog-paging'),(30818,'watch-mobile','.w-catalog-paging .next','border-left-width','1','','','.w-catalog-paging'),(30819,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-width','1','','','.w-catalog-paging'),(30820,'watch-mobile','.w-catalog-paging .next-pages','border-left-width','1','','','.w-catalog-paging'),(30821,'watch-mobile','.w-catalog-paging .prev-pages','border-left-width','1','','','.w-catalog-paging'),(30822,'watch-mobile','.w-checkout-shipping-choice label:first-child span','border-left-width','2','','','.w-checkout-shipping-choice'),(30823,'watch-mobile','.w-product-customers-activity .customers-activity','border-left-width','1','','','.w-product-customers-activity'),(30824,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-left-width','1','','','.w-promotions'),(30825,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-width','1','','','.w-promotions'),(30826,'watch-mobile','.w-promotions .promo-salemaker .discount','border-left-width','1','','','.w-promotions'),(30827,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border-left-width','1','','','.w-promotions'),(30828,'watch-mobile','.w-reviews-content .review','border-left-width','12','3','','.w-reviews-content'),(30829,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(30830,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-left-width','1','','','.w-wedding-registry-widgets-photos'),(30831,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-left-width','1','','','.w-wedding-registry-widgets-photos'),(30832,'watch-mobile','.w-sale .sale-holder','border-right-color','$border-color-10','','','.w-sale'),(30833,'watch-mobile','.w-product-wedding-registry-button .btn','border-right-color','$border-color-2','3','','.w-product-wedding-registry-button'),(30834,'watch-mobile','.w-currencies .select','border-right-color','$border-color-1','','','.w-currencies'),(30835,'watch-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-right-color','$border-color-10','2','','.b-product-images'),(30836,'watch-mobile','.b-pagination .pagination span','border-right-color','$border-color-1','2','','.b-pagination'),(30837,'watch-mobile','.w-catalog-listing-look .grid','border-right-color','$border-color-1','','','.w-catalog-listing-look'),(30838,'watch-mobile','.w-catalog-listing-look .list','border-right-color','$border-color-1','','','.w-catalog-listing-look'),(30839,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-color','$border-color-1','','','.b-multi-page-checkout'),(30840,'watch-mobile','textarea','border-right-color','$border-color-1','','',''),(30841,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-color','$border-color-1','','','.p-blog-index'),(30842,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-color','$border-color-10','','','.b-multi-page-checkout'),(30843,'watch-mobile','.b-info-popup .info-popup div','border-right-color','$border-color-1','','','.b-info-popup'),(30844,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-color','$border-color-2','','','.b-multi-page-checkout'),(30845,'watch-mobile','.w-promo-code .holder','border-right-color','$border-color-1','','','.w-promo-code'),(30846,'watch-mobile','.testimonials .review','border-right-color','transparent','3','',''),(30847,'watch-mobile','.b-pagination .pagination .prev-pages','border-right-color','$border-color-1','','','.b-pagination'),(30848,'watch-mobile','.b-pagination .pagination .prev','border-right-color','$border-color-1','','','.b-pagination'),(30849,'watch-mobile','.b-pagination .pagination .page-number','border-right-color','$border-color-1','','','.b-pagination'),(30850,'watch-mobile','.b-pagination .pagination .next-pages','border-right-color','$border-color-1','','','.b-pagination'),(30851,'watch-mobile','.b-pagination .pagination .next','border-right-color','$border-color-1','','','.b-pagination'),(30854,'watch-mobile','.w-cart .cart-content','border-right-color','$border-color-10','','','.w-cart'),(30855,'watch-mobile','.w-product-wedding-registry-button .btn','border-right-color','$border-color-2','4','','.w-product-wedding-registry-button'),(30856,'watch-mobile','.p-reviews-info .review-info-text','border-right-color','$border-color-9','4','','.p-reviews-info'),(30857,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-right-color','$border-color-1','3','','.b-form'),(30858,'watch-mobile','.b-pagination .pagination a','border-right-color','$border-color-1','','','.b-pagination'),(30859,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-right-color','$border-color-10','','','.b-slick'),(30860,'watch-mobile','.w-socials > li','border-right-color','$border-color-10','','','.w-socials'),(30861,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-right-color','$border-color-1','','',''),(30862,'watch-mobile','.w-currencies .currencies-title','border-right-color','$border-color-2','','','.w-currencies'),(30863,'watch-mobile','.w-compare-box-item .checkbox:checked + span','border-right-color','$border-color-5','','','.w-compare-box-item'),(30864,'watch-mobile','.w-compare-box-item .checkbox + span','border-right-color','$border-color-10','','','.w-compare-box-item'),(30865,'watch-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-color','$border-color-8','','','.b-compare'),(30866,'watch-mobile','.w-cart-products .checkout-attention-message','border-right-color','$border-color-3','','','.w-cart-products'),(30867,'watch-mobile','.b-quantity .qty-box .smaller','border-right-color','$border-color-1','','','.b-quantity'),(30868,'watch-mobile','.b-quantity .qty-box .bigger','border-right-color','$border-color-1','','','.b-quantity'),(30869,'watch-mobile','.w-catalog-listing-look .b2b','border-right-color','$border-color-1','','','.w-catalog-listing-look'),(30870,'watch-mobile','.btn-3','border-right-color','$border-color-2','','',''),(30871,'watch-mobile','.btn','border-right-color','$border-color-2','','',''),(30872,'watch-mobile','.b-bottom .popup-box','border-right-color','$border-color-10','','','.b-bottom'),(30873,'watch-mobile','.w-languages .select','border-right-color','$border-color-1','','','.w-languages'),(30874,'watch-mobile','.w-reviews .review','border-right-color','transparent','3','','.w-reviews'),(30875,'watch-mobile','.b-form .required-error','border-right-color','$border-color-3','','','.b-form'),(30876,'watch-mobile','.b-data-table table.dataTable.no-footer','border-right-color','$border-color-1','','','.b-data-table'),(30877,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','$border-color-1','','','.b-dropdown'),(30878,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','$border-color-1','','','.b-dropdown'),(30879,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','$border-color-1','','','.b-dropdown'),(30880,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','$border-color-1','','','.b-dropdown'),(30881,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','$border-color-1','','','.b-dropdown'),(30882,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','$border-color-1','','','.b-dropdown'),(30883,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-right-color','$border-color-9','','','.b-menu-style-2'),(30884,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-right-color','$border-color-9','','','.b-menu-style-2'),(30885,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-right-color','$border-color-9','','','.b-menu-style-2'),(30886,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-right-color','$border-color-9','','','.b-menu-style-2'),(30887,'watch-mobile','.b-messages .content_management_attach button','border-right-color','$border-color-2','','','.b-messages'),(30888,'watch-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-color','$border-color-1','','','.b-messages'),(30889,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-color','$border-color-1','','','.b-select-suggest'),(30890,'watch-mobile','.b-select-suggest .select2-search input','border-right-color','$border-color-1','','','.b-select-suggest'),(30891,'watch-mobile','.b-select-suggest .select2-container .select2-choice','border-right-color','$border-color-1','','','.b-select-suggest'),(30892,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-color','$border-color-1','','','.b-select-suggest'),(30893,'watch-mobile','.b-select-suggest .select2-drop','border-right-color','$border-color-1','','','.b-select-suggest'),(30894,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-color','$border-color-1','','','.b-select-suggest'),(30895,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-color','$border-color-1','','','.b-select-suggest'),(30896,'watch-mobile','.b-select-suggest .select2-drop-active','border-right-color','$border-color-1','','','.b-select-suggest'),(30897,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-right-color','$border-color-1','','','.b-select-suggest'),(30898,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-color','$border-color-1','','','.b-select-suggest'),(30899,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-color','$border-color-1','','','.b-trade-approval'),(30900,'watch-mobile','.b-upload-file .snapshot','border-right-color','$border-color-8','','','.b-upload-file'),(30901,'watch-mobile','.b-upload-file .upload-file-template','border-right-color','$border-color-1','','','.b-upload-file'),(30902,'watch-mobile','.b-upload-files .upload-files','border-right-color','$border-color-1','','','.b-upload-files'),(30903,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-right-color','$border-color-1','','','.batchPr'),(30904,'watch-mobile','.batchPr .checkbox input + span','border-right-color','$border-color-1','','','.batchPr'),(30905,'watch-mobile','.batchPr .checkbox input + span','border-right-color','$border-color-1','','','.batchPr'),(30906,'watch-mobile','.batchPr .w-batch-selected-products','border-right-color','$border-color-1','','','.batchPr'),(30907,'watch-mobile','.batchPr .checkbox input:checked + span','border-right-color','$border-color-2','','','.batchPr'),(30916,'watch-mobile','.p-payer-order-confirmation .input-wrapper','border-right-color','$border-color-1','','','.p-payer-order-confirmation'),(30917,'watch-mobile','.p-payer-order-pay .input-wrapper','border-right-color','$border-color-1','','','.p-payer-order-pay'),(30918,'watch-mobile','.w-account-address-book .btn-del','border-right-color','$border-color-10','','','.w-account-address-book'),(30919,'watch-mobile','.w-account-address-book .wrap','border-right-color','$border-color-10','','','.w-account-address-book'),(30920,'watch-mobile','.w-account-address-book .btn-edit','border-right-color','$border-color-10','','','.w-account-address-book'),(30921,'watch-mobile','.w-account-personal-catalog .list-switcher a','border-right-color','$border-color-1','2','','.w-account-personal-catalog'),(30922,'watch-mobile','.w-cart-compare .product-block td','border-right-color','$border-color-1','','','.w-cart-compare'),(30923,'watch-mobile','.w-cart-compare .attributes-block td','border-right-color','$border-color-1','','','.w-cart-compare'),(30924,'watch-mobile','.w-cart-compare .price-block td','border-right-color','$border-color-1','','','.w-cart-compare'),(30925,'watch-mobile','.w-cart-compare .cart-cell > div','border-right-color','$border-color-1','','','.w-cart-compare'),(30926,'watch-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-right-color','$border-color-9','','','.w-catalog-compare'),(30927,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','border-right-color','$border-color-1','2','','.w-catalog-compare'),(30928,'watch-mobile','.w-catalog-compare td:first-child','border-right-color','$border-color-1','','','.w-catalog-compare'),(30929,'watch-mobile','.w-catalog-paging ','border-right-color','$border-color-1','2','','.w-catalog-paging'),(30930,'watch-mobile','.w-catalog-paging .prev','border-right-color','$border-color-1','','','.w-catalog-paging'),(30931,'watch-mobile','.w-catalog-paging .next','border-right-color','$border-color-1','','','.w-catalog-paging'),(30932,'watch-mobile','.w-catalog-paging .next-pages','border-right-color','$border-color-1','','','.w-catalog-paging'),(30933,'watch-mobile','.w-catalog-paging .prev-pages','border-right-color','$border-color-1','','','.w-catalog-paging'),(30934,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-color','$border-color-1','','','.w-catalog-paging'),(30935,'watch-mobile','.w-catalog-paging .page-number','border-right-color','$border-color-1','','','.w-catalog-paging'),(30936,'watch-mobile','.w-checkout-shipping-choice label:last-child span','border-right-color','$border-color-2','','','.w-checkout-shipping-choice'),(30937,'watch-mobile','.w-product-customers-activity .customers-activity','border-right-color','$border-color-1','','','.w-product-customers-activity'),(30938,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-right-color','$border-color-3','','','.w-promotions'),(30939,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-color','$border-color-3','','','.w-promotions'),(30940,'watch-mobile','.w-promotions .promo-salemaker .discount','border-right-color','$border-color-3','','','.w-promotions'),(30941,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border-right-color','$border-color-3','','','.w-promotions'),(30942,'watch-mobile','.w-reviews-content .review','border-right-color','transparent','3','','.w-reviews-content'),(30943,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-color','$border-color-10','','','.w-upload-customer-id-upload-customer-id-form'),(30944,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-right-color','$border-color-1','','','.w-wedding-registry-widgets-photos'),(30945,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-right-color','$border-color-1','','','.w-wedding-registry-widgets-photos'),(30946,'watch-mobile','.b-data-table table.dataTable.no-footer','border-right-color_important','important','','','.b-data-table'),(30947,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(30948,'watch-mobile','.w-sale .sale-holder','border-right-width','2','','','.w-sale'),(30949,'watch-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','border-right-width','2','','','.b-product-images'),(30950,'watch-mobile','.w-product-wedding-registry-button .btn','border-right-width','2','3','','.w-product-wedding-registry-button'),(30951,'watch-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-right-width','2','2','','.b-product-images'),(30952,'watch-mobile','.w-currencies .select','border-right-width','1','','','.w-currencies'),(30953,'watch-mobile','.w-catalog-listing-look .b2b','border-right-width','1','','','.w-catalog-listing-look'),(30954,'watch-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-width','1','','','.b-compare'),(30955,'watch-mobile','.w-catalog-listing-look .list','border-right-width','1','','','.w-catalog-listing-look'),(30956,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-width','1','','','.b-multi-page-checkout'),(30957,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-width','2','','','.p-blog-index'),(30958,'watch-mobile','textarea','border-right-width','2','','',''),(30959,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(30960,'watch-mobile','.b-info-popup .info-popup div','border-right-width','1','','','.b-info-popup'),(30961,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(30962,'watch-mobile','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(30963,'watch-mobile','.testimonials .review','border-right-width','10','3','',''),(30964,'watch-mobile','.b-pagination .pagination .prev-pages','border-right-width','1','','','.b-pagination'),(30965,'watch-mobile','.b-pagination .pagination .prev','border-right-width','1','','','.b-pagination'),(30966,'watch-mobile','.p-wedding-registry-manage .wr-search button','border-right-width','0','','','.p-wedding-registry-manage'),(30967,'watch-mobile','.b-pagination .pagination .page-number','border-right-width','1','','','.b-pagination'),(30968,'watch-mobile','.b-pagination .pagination .next-pages','border-right-width','1','','','.b-pagination'),(30969,'watch-mobile','.b-pagination .pagination .next','border-right-width','1','','','.b-pagination'),(30970,'watch-mobile','.b-pagination .pagination span','border-right-width','1','2','','.b-pagination'),(30973,'watch-mobile','.w-cart .cart-content','border-right-width','1','','','.w-cart'),(30974,'watch-mobile','.w-list-type-2_2 .button-wishlist button','border-right-width','0','','','.w-list-type-2_2'),(30975,'watch-mobile','.w-product-wedding-registry-button .btn','border-right-width','2','4','','.w-product-wedding-registry-button'),(30976,'watch-mobile','.p-reviews-info .review-info-text','border-right-width','5','4','','.p-reviews-info'),(30977,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-right-width','2','3','','.b-form'),(30978,'watch-mobile','.b-pagination .pagination a','border-right-width','1','','','.b-pagination'),(30979,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-right-width','2','','','.b-slick'),(30980,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-right-width','2','','',''),(30981,'watch-mobile','.w-search .search-input','border-right-width','0','','','.w-search'),(30982,'watch-mobile','.w-currencies .currencies-title','border-right-width','2','','','.w-currencies'),(30983,'watch-mobile','.w-compare-box-item .checkbox:checked + span','border-right-width','1','','','.w-compare-box-item'),(30984,'watch-mobile','.w-compare-box-item .checkbox + span','border-right-width','1','','','.w-compare-box-item'),(30985,'watch-mobile','.b-slick .slick-vertical .slick-slide','border-right-width','1','','','.b-slick'),(30986,'watch-mobile','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(30987,'watch-mobile','.b-quantity .qty-box .bigger','border-right-width','2','','','.b-quantity'),(30988,'watch-mobile','.b-quantity .qty-box .smaller','border-right-width','2','','','.b-quantity'),(30989,'watch-mobile','.w-catalog-listing-look .grid','border-right-width','1','','','.w-catalog-listing-look'),(30990,'watch-mobile','.w-list-type-2 .button-wishlist button','border-right-width','0','','','.w-list-type-2'),(30991,'watch-mobile','.btn-3','border-right-width','2','','',''),(30992,'watch-mobile','.b-autocomplete .ui-autocomplete li','border-right-width','1','','','.b-autocomplete'),(30993,'watch-mobile','.btn','border-right-width','2','','',''),(30994,'watch-mobile','.w-list-type-1_3 .button-wishlist button','border-right-width','0','','','.w-list-type-1_3'),(30995,'watch-mobile','.w-list-type-1_2 .button-wishlist button','border-right-width','0','','','.w-list-type-1_2'),(30996,'watch-mobile','.b-bottom .popup-box','border-right-width','1','','','.b-bottom'),(30997,'watch-mobile','.w-list-type-1 .button-wishlist button','border-right-width','0','','','.w-list-type-1'),(30998,'watch-mobile','.w-filters .ui-slider','border-right-width','0','','','.w-filters'),(30999,'watch-mobile','.w-filters .ui-slider-handle','border-right-width','0','','','.w-filters'),(31000,'watch-mobile','.w-filters .ui-slider-range','border-right-width','0','','','.w-filters'),(31001,'watch-mobile','.w-languages .select','border-right-width','1','','','.w-languages'),(31002,'watch-mobile','.w-reviews .review','border-right-width','10','3','','.w-reviews'),(31003,'watch-mobile','.w-search .button-search','border-right-width','0','','','.w-search'),(31004,'watch-mobile','.w-socials > li','border-right-width','1','','','.w-socials'),(31005,'watch-mobile','.b-form .required-error','border-right-width','1','','','.b-form'),(31006,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(31007,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(31008,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(31009,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(31010,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(31011,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(31012,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-right-width','1','','','.b-menu-style-2'),(31013,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-right-width','3','','','.b-menu-style-2'),(31014,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-right-width','1','','','.b-menu-style-2'),(31015,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-right-width','3','','','.b-menu-style-2'),(31016,'watch-mobile','.b-messages .content_management_attach button','border-right-width','1','','','.b-messages'),(31017,'watch-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-width','2','','','.b-messages'),(31018,'watch-mobile','.b-select-suggest .select2-container .select2-choice','border-right-width','2','','','.b-select-suggest'),(31019,'watch-mobile','.b-select-suggest .select2-search input','border-right-width','1','','','.b-select-suggest'),(31020,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-width','1','','','.b-select-suggest'),(31021,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(31022,'watch-mobile','.b-select-suggest .select2-drop-active','border-right-width','1','','','.b-select-suggest'),(31023,'watch-mobile','.b-select-suggest .select2-drop','border-right-width','1','','','.b-select-suggest'),(31024,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-right-width','1','','','.b-select-suggest'),(31025,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-width','1','','','.b-select-suggest'),(31026,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-width','1','','','.b-select-suggest'),(31027,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(31028,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-width','2','','','.b-trade-approval'),(31029,'watch-mobile','.b-upload-file .snapshot','border-right-width','1','','','.b-upload-file'),(31030,'watch-mobile','.b-upload-file .upload-file-template','border-right-width','1','','','.b-upload-file'),(31031,'watch-mobile','.b-upload-files .upload-files','border-right-width','1','','','.b-upload-files'),(31032,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-right-width','1','','','.batchPr'),(31033,'watch-mobile','.batchPr .checkbox input + span','border-right-width','1','','','.batchPr'),(31034,'watch-mobile','.batchPr .checkbox input + span','border-right-width','1','','','.batchPr'),(31035,'watch-mobile','.batchPr .checkbox input:checked + span','border-right-width','1','','','.batchPr'),(31036,'watch-mobile','.batchPr .w-batch-selected-products','border-right-width','1','','','.batchPr'),(31045,'watch-mobile','.p-payer-order-confirmation .input-wrapper','border-right-width','2','','','.p-payer-order-confirmation'),(31046,'watch-mobile','.p-payer-order-pay .input-wrapper','border-right-width','2','','','.p-payer-order-pay'),(31047,'watch-mobile','.w-account-address-book .wrap','border-right-width','1','','','.w-account-address-book'),(31048,'watch-mobile','.w-account-address-book .btn-edit','border-right-width','1','','','.w-account-address-book'),(31049,'watch-mobile','.w-account-address-book .btn-del','border-right-width','1','','','.w-account-address-book'),(31050,'watch-mobile','.w-account-personal-catalog .list-switcher a','border-right-width','1','2','','.w-account-personal-catalog'),(31051,'watch-mobile','.w-cart-compare .attributes-block td','border-right-width','1','','','.w-cart-compare'),(31052,'watch-mobile','.w-cart-compare .cart-cell > div','border-right-width','1','','','.w-cart-compare'),(31053,'watch-mobile','.w-cart-compare .product-block td','border-right-width','1','','','.w-cart-compare'),(31054,'watch-mobile','.w-cart-compare .price-block td','border-right-width','1','','','.w-cart-compare'),(31055,'watch-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-right-width','1','','','.w-catalog-compare'),(31056,'watch-mobile','.w-catalog-compare td:first-child','border-right-width','1','','','.w-catalog-compare'),(31057,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','border-right-width','1','2','','.w-catalog-compare'),(31058,'watch-mobile','.w-catalog-paging ','border-right-width','1','2','','.w-catalog-paging'),(31059,'watch-mobile','.w-catalog-paging .prev','border-right-width','1','','','.w-catalog-paging'),(31060,'watch-mobile','.w-catalog-paging .page-number','border-right-width','1','','','.w-catalog-paging'),(31061,'watch-mobile','.w-catalog-paging .next','border-right-width','1','','','.w-catalog-paging'),(31062,'watch-mobile','.w-catalog-paging .next-pages','border-right-width','1','','','.w-catalog-paging'),(31063,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-width','1','','','.w-catalog-paging'),(31064,'watch-mobile','.w-catalog-paging .prev-pages','border-right-width','1','','','.w-catalog-paging'),(31065,'watch-mobile','.w-checkout-shipping-choice label:last-child span','border-right-width','2','','','.w-checkout-shipping-choice'),(31066,'watch-mobile','.w-product-customers-activity .customers-activity','border-right-width','1','','','.w-product-customers-activity'),(31067,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-right-width','1','','','.w-promotions'),(31068,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-width','1','','','.w-promotions'),(31069,'watch-mobile','.w-promotions .promo-salemaker .discount','border-right-width','1','','','.w-promotions'),(31070,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border-right-width','1','','','.w-promotions'),(31071,'watch-mobile','.w-reviews-content .review','border-right-width','12','3','','.w-reviews-content'),(31072,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(31073,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-right-width','1','','','.w-wedding-registry-widgets-photos'),(31074,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-right-width','1','','','.w-wedding-registry-widgets-photos'),(31078,'watch-mobile','.b-select-suggest .select2-drop-active','border-top','none','','','.b-select-suggest'),(31085,'watch-mobile','.w-catalog-listing-look .list','border-top-color','$border-color-1','','','.w-catalog-listing-look'),(31086,'watch-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-1','4','','.b-social-login'),(31087,'watch-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-1','3','','.b-social-login'),(31088,'watch-mobile','.w-sale .sale-holder','border-top-color','$border-color-10','','','.w-sale'),(31089,'watch-mobile','.w-menu-slider > ul > li > ul','border-top-color','$border-color-9','','','.w-menu-slider'),(31090,'watch-mobile','.w-product-wedding-registry-button .btn','border-top-color','$border-color-2','3','','.w-product-wedding-registry-button'),(31091,'watch-mobile','.w-product-sale-ends .left-text-left','border-top-color','$border-color-10','','','.w-product-sale-ends'),(31092,'watch-mobile','.w-product-sale-ends .left-text-right','border-top-color','$border-color-10','','','.w-product-sale-ends'),(31093,'watch-mobile','.w-cart-products .checkout-attention-message','border-top-color','$border-color-3','','','.w-cart-products'),(31094,'watch-mobile','.w-cart .cart-content','border-top-color','$border-color-10','','','.w-cart'),(31095,'watch-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-top-color','$border-color-10','2','','.b-product-images'),(31096,'watch-mobile','.b-pagination .pagination span','border-top-color','$border-color-1','2','','.b-pagination'),(31097,'watch-mobile','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-color','$border-color-1','','','.w-product-in-bundles'),(31098,'watch-mobile','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-color','$border-color-1','','','.w-product-bundle'),(31099,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-color','$border-color-1','','','.b-multi-page-checkout'),(31100,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-color','$border-color-1','','','.p-blog-index'),(31101,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-color','$border-color-10','','','.b-multi-page-checkout'),(31102,'watch-mobile','.btn-3','border-top-color','$border-color-2','','',''),(31103,'watch-mobile','.btn','border-top-color','$border-color-2','','',''),(31104,'watch-mobile','.b-info-popup .info-popup div','border-top-color','$border-color-1','','','.b-info-popup'),(31105,'watch-mobile','.w-menu .hided.menu ul li','border-top-color','$border-color-6','317','','.w-menu'),(31106,'watch-mobile','.b-info-popup .info-popup div','border-top-color','$border-color-1','3','','.b-info-popup'),(31107,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-color','$border-color-2','','','.b-multi-page-checkout'),(31109,'watch-mobile','.view-all','border-top-color','$border-color-1','3','',''),(31110,'watch-mobile','.p-wedding-registry-manage .remove','border-top-color','$border-color-1','','','.p-wedding-registry-manage'),(31111,'watch-mobile','.w-promo-code .holder','border-top-color','$border-color-1','','','.w-promo-code'),(31112,'watch-mobile','.testimonials .review','border-top-color','$border-color-1','3','',''),(31113,'watch-mobile','.b-pagination .pagination .page-number','border-top-color','$border-color-1','','','.b-pagination'),(31114,'watch-mobile','.b-pagination .pagination .prev-pages','border-top-color','$border-color-1','','','.b-pagination'),(31115,'watch-mobile','.b-pagination .pagination .prev','border-top-color','$border-color-1','','','.b-pagination'),(31116,'watch-mobile','.b-pagination .pagination .next-pages','border-top-color','$border-color-1','','','.b-pagination'),(31117,'watch-mobile','.b-pagination .pagination .next','border-top-color','$border-color-1','','','.b-pagination'),(31122,'watch-mobile','.w-list-type-2_2 .compare-box-item','border-top-color','$border-color-1','','','.w-list-type-2_2'),(31123,'watch-mobile','.w-list-type-2_2 .buttons','border-top-color','$border-color-1','','','.w-list-type-2_2'),(31124,'watch-mobile','.w-product-wedding-registry-button .btn','border-top-color','$border-color-2','4','','.w-product-wedding-registry-button'),(31125,'watch-mobile','.p-reviews-info .review-info-text','border-top-color','$border-color-9','4','','.p-reviews-info'),(31126,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-color','$border-color-1','3','','.b-form'),(31127,'watch-mobile','.b-form .form-buttons','border-top-color','$border-color-1','','','.b-form'),(31128,'watch-mobile','.p-wedding-registry-index .search-list','border-top-color','$border-color-1','3','','.p-wedding-registry-index'),(31129,'watch-mobile','.b-table .table .headings + tr ~ tr td','border-top-color','$border-color-1','','','.b-table'),(31130,'watch-mobile','.b-pagination .pagination a','border-top-color','$border-color-1','','','.b-pagination'),(31131,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-color','$border-color-10','','','.b-slick'),(31132,'watch-mobile','.w-languages .select','border-top-color','$border-color-1','','','.w-languages'),(31133,'watch-mobile','.w-socials > li','border-top-color','$border-color-10','','','.w-socials'),(31135,'watch-mobile','.w-currencies .select','border-top-color','$border-color-1','','','.w-currencies'),(31137,'watch-mobile','.w-currencies .currencies-title','border-top-color','$border-color-2','','','.w-currencies'),(31138,'watch-mobile','.w-compare-box-item .checkbox:checked + span','border-top-color','$border-color-5','','','.w-compare-box-item'),(31139,'watch-mobile','.w-compare-box-item .checkbox + span','border-top-color','$border-color-10','','','.w-compare-box-item'),(31140,'watch-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-color','$border-color-8','','','.b-compare'),(31141,'watch-mobile','.w-sale .left-text-left','border-top-color','$border-color-10','','','.w-sale'),(31142,'watch-mobile','.w-sale .left-text-right','border-top-color','$border-color-10','','','.w-sale'),(31143,'watch-mobile','.b-quantity .qty-box .smaller','border-top-color','$border-color-1','','','.b-quantity'),(31144,'watch-mobile','.b-quantity .qty-box .bigger','border-top-color','$border-color-1','','','.b-quantity'),(31145,'watch-mobile','.w-catalog-listing-look .b2b','border-top-color','$border-color-1','','','.w-catalog-listing-look'),(31146,'watch-mobile','.w-catalog-listing-look .grid','border-top-color','$border-color-1','','','.w-catalog-listing-look'),(31147,'watch-mobile','.w-list-type-2 .buttons','border-top-color','$border-color-1','','','.w-list-type-2'),(31148,'watch-mobile','.w-list-type-2 .compare-box-item','border-top-color','$border-color-1','','','.w-list-type-2'),(31149,'watch-mobile','.w-list-type-2 .item','border-top-color','$border-color-1','1','','.w-list-type-2'),(31150,'watch-mobile','.w-list-type-1_3 .compare-box-item','border-top-color','$border-color-1','','','.w-list-type-1_3'),(31151,'watch-mobile','.w-list-type-1_3 .buttons','border-top-color','$border-color-1','','','.w-list-type-1_3'),(31152,'watch-mobile','.w-list-type-1_2 .buttons','border-top-color','$border-color-1','','','.w-list-type-1_2'),(31153,'watch-mobile','.w-list-type-1_2 .compare-box-item','border-top-color','$border-color-1','','','.w-list-type-1_2'),(31154,'watch-mobile','.w-list-type-1 .compare-box-item','border-top-color','$border-color-1','','','.w-list-type-1'),(31155,'watch-mobile','.b-bottom .popup-box','border-top-color','$border-color-10','','','.b-bottom'),(31156,'watch-mobile','.w-list-type-1 .buttons','border-top-color','$border-color-1','','','.w-list-type-1'),(31157,'watch-mobile','.w-reviews .review','border-top-color','$border-color-9','3','','.w-reviews'),(31159,'watch-mobile','.b-form .required-error','border-top-color','$border-color-3','','','.b-form'),(31160,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-top-color','$border-color-1','','',''),(31161,'watch-mobile','textarea','border-top-color','$border-color-1','','',''),(31162,'watch-mobile','.b-info div + .info','border-top-color','$border-color-1','','','.b-info'),(31163,'watch-mobile','.b-products-listing .products-listing .compare','border-top-color','$border-color-1','','','.b-products-listing'),(31164,'watch-mobile','.b-data-table table.dataTable tbody td','border-top-color','$border-color-1','','','.b-data-table'),(31165,'watch-mobile','.b-data-table table.dataTable.no-footer','border-top-color','$border-color-1','','','.b-data-table'),(31166,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','$border-color-1','','','.b-dropdown'),(31167,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','$border-color-1','','','.b-dropdown'),(31168,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','$border-color-1','','','.b-dropdown'),(31169,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','$border-color-1','','','.b-dropdown'),(31170,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','$border-color-1','','','.b-dropdown'),(31171,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','$border-color-1','','','.b-dropdown'),(31172,'watch-mobile','.b-email .qty','border-top-color','$border-color-1','','','.b-email'),(31173,'watch-mobile','.b-email .name','border-top-color','$border-color-1','','','.b-email'),(31174,'watch-mobile','.b-email .totals-table','border-top-color','$border-color-1','','','.b-email'),(31175,'watch-mobile','.b-email .price','border-top-color','$border-color-1','','','.b-email'),(31176,'watch-mobile','.b-email .image','border-top-color','$border-color-1','','','.b-email'),(31177,'watch-mobile','.b-email .totals-table','border-top-color','$border-color-1','','','.b-email'),(31178,'watch-mobile','.b-email .image','border-top-color','$border-color-1','','','.b-email'),(31179,'watch-mobile','.b-email .price','border-top-color','$border-color-1','','','.b-email'),(31180,'watch-mobile','.b-email .model','border-top-color','$border-color-1','','','.b-email'),(31181,'watch-mobile','.b-email .name','border-top-color','$border-color-1','','','.b-email'),(31182,'watch-mobile','.b-email .image','border-top-color','$border-color-1','','','.b-email'),(31183,'watch-mobile','.b-email .model','border-top-color','$border-color-1','','','.b-email'),(31184,'watch-mobile','.b-email .image','border-top-color','$border-color-1','','','.b-email'),(31185,'watch-mobile','.b-email .price','border-top-color','$border-color-1','','','.b-email'),(31186,'watch-mobile','.b-email .price','border-top-color','$border-color-1','','','.b-email'),(31187,'watch-mobile','.b-email .qty','border-top-color','$border-color-1','','','.b-email'),(31188,'watch-mobile','.b-email .model','border-top-color','$border-color-1','','','.b-email'),(31189,'watch-mobile','.b-email .name','border-top-color','$border-color-1','','','.b-email'),(31190,'watch-mobile','.b-email .totals-table','border-top-color','$border-color-1','','','.b-email'),(31191,'watch-mobile','.b-email .price','border-top-color','$border-color-1','','','.b-email'),(31192,'watch-mobile','.b-email .name','border-top-color','$border-color-1','','','.b-email'),(31193,'watch-mobile','.b-email .qty','border-top-color','$border-color-1','','','.b-email'),(31194,'watch-mobile','.b-email .totals-table','border-top-color','$border-color-1','','','.b-email'),(31195,'watch-mobile','.b-email .image','border-top-color','$border-color-1','','','.b-email'),(31196,'watch-mobile','.b-email .name','border-top-color','$border-color-1','','','.b-email'),(31197,'watch-mobile','.b-email .totals-table','border-top-color','$border-color-1','','','.b-email'),(31198,'watch-mobile','.b-email .qty','border-top-color','$border-color-1','','','.b-email'),(31199,'watch-mobile','.b-email .qty','border-top-color','$border-color-1','','','.b-email'),(31200,'watch-mobile','.b-email .model','border-top-color','$border-color-1','','','.b-email'),(31201,'watch-mobile','.b-email .name','border-top-color','$border-color-1','','','.b-email'),(31202,'watch-mobile','.b-email .qty','border-top-color','$border-color-1','','','.b-email'),(31203,'watch-mobile','.b-email .model','border-top-color','$border-color-1','','','.b-email'),(31204,'watch-mobile','.b-email .price','border-top-color','$border-color-1','','','.b-email'),(31205,'watch-mobile','.b-email .totals-table','border-top-color','$border-color-1','','','.b-email'),(31206,'watch-mobile','.b-email .image','border-top-color','$border-color-1','','','.b-email'),(31207,'watch-mobile','.b-email .model','border-top-color','$border-color-1','','','.b-email'),(31208,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-top-color','$border-color-9','','','.b-menu-style-2'),(31209,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-top-color','$border-color-9','','','.b-menu-style-2'),(31210,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','border-top-color','$border-color-4','','','.b-menu-style-2'),(31211,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-top-color','$border-color-9','','','.b-menu-style-2'),(31212,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-top-color','$border-color-9','','','.b-menu-style-2'),(31213,'watch-mobile','.b-messages .messMenuButtonTop','border-top-color','$border-color-1','','','.b-messages'),(31214,'watch-mobile','.b-messages .msv_btn','border-top-color','$border-color-1','','','.b-messages'),(31215,'watch-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-color','$border-color-1','','','.b-messages'),(31216,'watch-mobile','.b-messages .email-heading','border-top-color','$border-color-1','','','.b-messages'),(31217,'watch-mobile','.b-messages .dataTable','border-top-color','$border-color-1','','','.b-messages'),(31218,'watch-mobile','.b-messages .messages-menu li + li','border-top-color','$border-color-1','','','.b-messages'),(31219,'watch-mobile','.b-messages .content_management_attach button','border-top-color','$border-color-2','','','.b-messages'),(31220,'watch-mobile','.b-messages .content_management_attach','border-top-color','$border-color-1','','','.b-messages'),(31221,'watch-mobile','.b-select-suggest .select2-container .select2-choice','border-top-color','$border-color-1','','','.b-select-suggest'),(31222,'watch-mobile','.b-select-suggest .select2-search input','border-top-color','$border-color-1','','','.b-select-suggest'),(31223,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-color','$border-color-1','','','.b-select-suggest'),(31224,'watch-mobile','.b-select-suggest .select2-drop-auto-width','border-top-color','$border-color-1','','','.b-select-suggest'),(31225,'watch-mobile','.b-select-suggest .select2-drop','border-top-color','$border-color-1','','','.b-select-suggest'),(31226,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-top-color','$border-color-1','','','.b-select-suggest'),(31227,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-color','$border-color-1','','','.b-select-suggest'),(31228,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-color','$border-color-1','','','.b-select-suggest'),(31229,'watch-mobile','.b-select-suggest .select2-drop-active','border-top-color','$border-color-1','','','.b-select-suggest'),(31230,'watch-mobile','.b-select-suggest .select2-drop.select2-drop-above','border-top-color','$border-color-1','','','.b-select-suggest'),(31231,'watch-mobile','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-color','$border-color-1','','','.b-select-suggest'),(31232,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-color','$border-color-1','','','.b-select-suggest'),(31233,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-color','$border-color-1','','','.b-select-suggest'),(31234,'watch-mobile','.b-table-list .table-list td','border-top-color','$border-color-1','','','.b-table-list'),(31235,'watch-mobile','.b-table-list .table-list td','border-top-color','$border-color-1','','','.b-table-list'),(31236,'watch-mobile','.b-table-list .table-list td','border-top-color','$border-color-1','','','.b-table-list'),(31237,'watch-mobile','.b-table-list .table-list td','border-top-color','$border-color-1','','','.b-table-list'),(31238,'watch-mobile','.b-table-list .table-list td','border-top-color','$border-color-1','','','.b-table-list'),(31239,'watch-mobile','.b-table-list .table-list td','border-top-color','$border-color-1','','','.b-table-list'),(31240,'watch-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','$border-color-1','','','.b-tracking-numbers'),(31241,'watch-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','$border-color-1','','','.b-tracking-numbers'),(31242,'watch-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','$border-color-1','','','.b-tracking-numbers'),(31243,'watch-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','$border-color-1','','','.b-tracking-numbers'),(31244,'watch-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','$border-color-1','','','.b-tracking-numbers'),(31245,'watch-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','$border-color-1','','','.b-tracking-numbers'),(31246,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-color','$border-color-1','','','.b-trade-approval'),(31247,'watch-mobile','.b-upload-file .upload-file-template','border-top-color','$border-color-1','','','.b-upload-file'),(31248,'watch-mobile','.b-upload-file .snapshot','border-top-color','$border-color-8','','','.b-upload-file'),(31249,'watch-mobile','.b-upload-files .upload-files','border-top-color','$border-color-1','','','.b-upload-files'),(31250,'watch-mobile','.b-upload-files .added-file','border-top-color','$border-color-1','','','.b-upload-files'),(31251,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-color','$border-color-1','','','.batchPr'),(31252,'watch-mobile','.batchPr .checkbox input + span','border-top-color','$border-color-1','','','.batchPr'),(31253,'watch-mobile','.batchPr .checkbox input + span','border-top-color','$border-color-1','','','.batchPr'),(31254,'watch-mobile','.batchPr .checkbox input:checked + span','border-top-color','$border-color-2','','','.batchPr'),(31255,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .item + .item','border-top-color','$border-color-1','','','.batchPr'),(31256,'watch-mobile','.batchPr .w-batch-selected-products','border-top-color','$border-color-1','','','.batchPr'),(31273,'watch-mobile','.p-payer-order-confirmation .input-wrapper','border-top-color','$border-color-1','','','.p-payer-order-confirmation'),(31274,'watch-mobile','.p-payer-order-pay .input-wrapper','border-top-color','$border-color-1','','','.p-payer-order-pay'),(31275,'watch-mobile','.w-account-address-book .wrap','border-top-color','$border-color-10','','','.w-account-address-book'),(31276,'watch-mobile','.w-account-personal-catalog .list-switcher a','border-top-color','$border-color-2','2','','.w-account-personal-catalog'),(31277,'watch-mobile','.w-account-subscription .subscription-variant + .subscription-variant','border-top-color','$border-color-10','','','.w-account-subscription'),(31278,'watch-mobile','.w-cart-compare .attributes-block td','border-top-color','$border-color-1','','','.w-cart-compare'),(31279,'watch-mobile','.w-cart-compare .price-block td','border-top-color','$border-color-1','','','.w-cart-compare'),(31280,'watch-mobile','.w-cart-compare .product-block td','border-top-color','$border-color-1','','','.w-cart-compare'),(31281,'watch-mobile','.w-cart-compare .cart-cell > div','border-top-color','$border-color-1','','','.w-cart-compare'),(31282,'watch-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-top-color','$border-color-9','','','.w-catalog-compare'),(31283,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','border-top-color','$border-color-2','2','','.w-catalog-compare'),(31284,'watch-mobile','.w-catalog-paging ','border-top-color','$border-color-1','2','','.w-catalog-paging'),(31285,'watch-mobile','.w-catalog-paging .prev','border-top-color','$border-color-1','','','.w-catalog-paging'),(31286,'watch-mobile','.w-catalog-paging .next','border-top-color','$border-color-1','','','.w-catalog-paging'),(31287,'watch-mobile','.w-catalog-paging .page-number','border-top-color','$border-color-1','','','.w-catalog-paging'),(31288,'watch-mobile','.w-catalog-paging .next-pages','border-top-color','$border-color-1','','','.w-catalog-paging'),(31289,'watch-mobile','.w-catalog-paging .prev-pages','border-top-color','$border-color-1','','','.w-catalog-paging'),(31290,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-color','$border-color-1','','','.w-catalog-paging'),(31291,'watch-mobile','.w-checkout-shipping .sub-item + .sub-item','border-top-color','$border-color-1','','','.w-checkout-shipping'),(31292,'watch-mobile','.w-checkout-shipping-choice span','border-top-color','$border-color-2','','','.w-checkout-shipping-choice'),(31293,'watch-mobile','.w-communication-new-topic td','border-top-color','$border-color-1','','','.w-communication-new-topic'),(31294,'watch-mobile','.w-communication-post .communication-post','border-top-color','$border-color-1','','','.w-communication-post'),(31295,'watch-mobile','.w-delivery-day .left-text-left','border-top-color','$border-color-1','','','.w-delivery-day'),(31296,'watch-mobile','.w-delivery-day .left-text-right','border-top-color','$border-color-1','','','.w-delivery-day'),(31297,'watch-mobile','.w-product-customers-activity .customers-activity','border-top-color','$border-color-1','','','.w-product-customers-activity'),(31298,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-color','$border-color-3','','','.w-promotions'),(31299,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-color','$border-color-3','','','.w-promotions'),(31300,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-color','$border-color-3','','','.w-promotions'),(31301,'watch-mobile','.w-promotions .promo-salemaker .discount','border-top-color','$border-color-3','','','.w-promotions'),(31302,'watch-mobile','.w-reviews-content .review','border-top-color','transparent','3','','.w-reviews-content'),(31303,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-color','$border-color-10','','','.w-upload-customer-id-upload-customer-id-form'),(31304,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-top-color','$border-color-1','','','.w-wedding-registry-widgets-photos'),(31305,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-top-color','$border-color-1','','','.w-wedding-registry-widgets-photos'),(31306,'watch-mobile','.w-wedding-registry-widgets-products .rating','border-top-color','$border-color-1','','','.w-wedding-registry-widgets-products'),(31307,'watch-mobile','.b-data-table table.dataTable.no-footer','border-top-color_important','important','','','.b-data-table'),(31308,'watch-mobile','.w-sale .left-count-days','border-top-left-radius','3','','','.w-sale'),(31309,'watch-mobile','.w-sale .badge','border-top-left-radius','50','','','.w-sale'),(31310,'watch-mobile','.w-product-wedding-registry-button .btn','border-top-left-radius','50','3','','.w-product-wedding-registry-button'),(31311,'watch-mobile','.w-product-sale-ends .left-count-days','border-top-left-radius','3','','','.w-product-sale-ends'),(31312,'watch-mobile','.w-product-sale-ends .left-count','border-top-left-radius','3','','','.w-product-sale-ends'),(31313,'watch-mobile','.w-product-sale-ends .left-count-hours','border-top-left-radius','3','','','.w-product-sale-ends'),(31314,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-left-radius','50','3','','.b-multi-page-checkout'),(31315,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-left-radius','50','','','.b-multi-page-checkout'),(31316,'watch-mobile','.p-blog-index .avatar','border-top-left-radius','50','','','.p-blog-index'),(31317,'watch-mobile','.w-product-wedding-registry-button .btn','border-top-left-radius','50','4','','.w-product-wedding-registry-button'),(31318,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-left-radius','50','3','','.b-form'),(31319,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(31320,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(31321,'watch-mobile','.b-switch .bootstrap-switch','border-top-left-radius','14','','','.b-switch'),(31322,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-top-left-radius','15','','','.b-fancybox'),(31323,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border-top-left-radius','30','303','','.w-list-type-1'),(31324,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-left-radius','50','','','.b-slick'),(31325,'watch-mobile','.b-fancybox .fancybox-skin','border-top-left-radius','4','','','.b-fancybox'),(31326,'watch-mobile','.b-fancybox .fancybox-nav span','border-top-left-radius','50','','','.b-fancybox'),(31327,'watch-mobile','.w-sale .left-count','border-top-left-radius','3','','','.w-sale'),(31328,'watch-mobile','.w-sale .left-count-hours','border-top-left-radius','3','','','.w-sale'),(31329,'watch-mobile','.btn-3','border-top-left-radius','24','','',''),(31330,'watch-mobile','.btn','border-top-left-radius','24','','',''),(31331,'watch-mobile','.btn-1','border-top-left-radius','20','','',''),(31332,'watch-mobile','.btn-2','border-top-left-radius','24','','',''),(31333,'watch-mobile','.b-products-listing .promos-info .promo-name','border-top-left-radius','0','','','.b-products-listing'),(31334,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.b-data-table'),(31335,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.b-data-table'),(31336,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-left-radius','5','','','.b-messages'),(31337,'watch-mobile','.b-trade-approval .steps-bar','border-top-left-radius','18','','','.b-trade-approval'),(31338,'watch-mobile','.b-upload-file .snapshot','border-top-left-radius','50','','','.b-upload-file'),(31339,'watch-mobile','.batchPr .checkbox input + span','border-top-left-radius','18','','','.batchPr'),(31340,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-top-left-radius','0','','','.batchPr'),(31341,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-left-radius','10','','','.batchPr'),(31342,'watch-mobile','.batchPr .btn-batch-remove','border-top-left-radius','100','','','.batchPr'),(31344,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.p-quick-order-index'),(31345,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.p-quick-order-index'),(31346,'watch-mobile','.w-account-address-book .wrap','border-top-left-radius','5','','','.w-account-address-book'),(31347,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-top-left-radius','0','','','.w-blog-widget-related-posts'),(31348,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-left-radius','0','','','.w-catalog-paging'),(31349,'watch-mobile','.w-checkout-shipping-choice label:last-child span','border-top-left-radius','0','','','.w-checkout-shipping-choice'),(31350,'watch-mobile','.w-checkout-shipping-choice label:first-child span','border-top-left-radius','16','','','.w-checkout-shipping-choice'),(31351,'watch-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-left-radius','3','','','.w-delivery-day'),(31352,'watch-mobile','.w-delivery-day .left-count','border-top-left-radius','3','','','.w-delivery-day'),(31353,'watch-mobile','.w-personal-gift-status-bar .progress-bar-content','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(31354,'watch-mobile','.w-personal-gift-status-bar .progress-bar','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(31355,'watch-mobile','.w-product-customers-activity .customers-activity','border-top-left-radius','10','','','.w-product-customers-activity'),(31356,'watch-mobile','.w-product-customers-activity .close','border-top-left-radius','50','','','.w-product-customers-activity'),(31357,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-left-radius','12','','','.w-promotions'),(31358,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-left-radius','12','','','.w-promotions'),(31359,'watch-mobile','.w-promotions .promo-salemaker .discount','border-top-left-radius','12','','','.w-promotions'),(31360,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-left-radius','12','','','.w-promotions'),(31361,'watch-mobile','.w-product-sale-ends .left-count-days','border-top-right-radius','3','','','.w-product-sale-ends'),(31362,'watch-mobile','.w-sale .left-count-hours','border-top-right-radius','3','','','.w-sale'),(31363,'watch-mobile','.w-sale .left-count','border-top-right-radius','3','','','.w-sale'),(31364,'watch-mobile','.w-sale .left-count-days','border-top-right-radius','3','','','.w-sale'),(31365,'watch-mobile','.w-sale .badge','border-top-right-radius','50','','','.w-sale'),(31366,'watch-mobile','.w-product-wedding-registry-button .btn','border-top-right-radius','50','3','','.w-product-wedding-registry-button'),(31367,'watch-mobile','.w-product-sale-ends .left-count','border-top-right-radius','3','','','.w-product-sale-ends'),(31368,'watch-mobile','.w-product-sale-ends .left-count-hours','border-top-right-radius','3','','','.w-product-sale-ends'),(31369,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-right-radius','50','3','','.b-multi-page-checkout'),(31370,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-right-radius','50','','','.b-multi-page-checkout'),(31371,'watch-mobile','.p-blog-index .avatar','border-top-right-radius','50','','','.p-blog-index'),(31372,'watch-mobile','.w-product-wedding-registry-button .btn','border-top-right-radius','50','4','','.w-product-wedding-registry-button'),(31373,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-right-radius','50','3','','.b-form'),(31374,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(31375,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(31376,'watch-mobile','.b-switch .bootstrap-switch','border-top-right-radius','14','','','.b-switch'),(31377,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-right-radius','50','','','.b-slick'),(31378,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border-top-right-radius','30','303','','.w-list-type-1'),(31379,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-top-right-radius','15','','','.b-fancybox'),(31380,'watch-mobile','.b-fancybox .fancybox-skin','border-top-right-radius','4','','','.b-fancybox'),(31381,'watch-mobile','.b-fancybox .fancybox-nav span','border-top-right-radius','50','','','.b-fancybox'),(31382,'watch-mobile','.btn-3','border-top-right-radius','24','','',''),(31383,'watch-mobile','.btn-2','border-top-right-radius','24','','',''),(31384,'watch-mobile','.btn-1','border-top-right-radius','20','','',''),(31385,'watch-mobile','.btn','border-top-right-radius','24','','',''),(31386,'watch-mobile','.b-products-listing .promos-info .promo-name','border-top-right-radius','8','','','.b-products-listing'),(31387,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.b-data-table'),(31388,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.b-data-table'),(31389,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-right-radius','5','','','.b-messages'),(31390,'watch-mobile','.b-trade-approval .steps-bar','border-top-right-radius','18','','','.b-trade-approval'),(31391,'watch-mobile','.b-upload-file .snapshot','border-top-right-radius','50','','','.b-upload-file'),(31392,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-right-radius','10','','','.batchPr'),(31393,'watch-mobile','.batchPr .checkbox input + span','border-top-right-radius','18','','','.batchPr'),(31394,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-top-right-radius','0','','','.batchPr'),(31395,'watch-mobile','.batchPr .btn-batch-remove','border-top-right-radius','100','','','.batchPr'),(31397,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.p-quick-order-index'),(31398,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.p-quick-order-index'),(31399,'watch-mobile','.w-account-address-book .wrap','border-top-right-radius','5','','','.w-account-address-book'),(31400,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-top-right-radius','0','','','.w-blog-widget-related-posts'),(31401,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-right-radius','0','','','.w-catalog-paging'),(31402,'watch-mobile','.w-checkout-shipping-choice label:first-child span','border-top-right-radius','0','','','.w-checkout-shipping-choice'),(31403,'watch-mobile','.w-checkout-shipping-choice label:last-child span','border-top-right-radius','16','','','.w-checkout-shipping-choice'),(31404,'watch-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-right-radius','3','','','.w-delivery-day'),(31405,'watch-mobile','.w-delivery-day .left-count','border-top-right-radius','3','','','.w-delivery-day'),(31406,'watch-mobile','.w-personal-gift-status-bar .progress-bar-content','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(31407,'watch-mobile','.w-personal-gift-status-bar .progress-bar','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(31408,'watch-mobile','.w-product-customers-activity .customers-activity','border-top-right-radius','10','','','.w-product-customers-activity'),(31409,'watch-mobile','.w-product-customers-activity .close','border-top-right-radius','50','','','.w-product-customers-activity'),(31410,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-right-radius','12','','','.w-promotions'),(31411,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-right-radius','12','','','.w-promotions'),(31412,'watch-mobile','.w-promotions .promo-salemaker .discount','border-top-right-radius','12','','','.w-promotions'),(31413,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-right-radius','12','','','.w-promotions'),(31414,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(31415,'watch-mobile','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(31416,'watch-mobile','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(31417,'watch-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','border-top-width','2','','','.b-product-images'),(31418,'watch-mobile','.w-sale .sale-holder','border-top-width','2','','','.w-sale'),(31419,'watch-mobile','.w-menu-slider > ul > li > ul','border-top-width','1','','','.w-menu-slider'),(31420,'watch-mobile','.w-product-wedding-registry-button .btn','border-top-width','2','3','','.w-product-wedding-registry-button'),(31421,'watch-mobile','.w-product-sale-ends .left-text-left','border-top-width','2','','','.w-product-sale-ends'),(31422,'watch-mobile','.w-product-sale-ends .left-text-right','border-top-width','2','','','.w-product-sale-ends'),(31423,'watch-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-top-width','2','2','','.b-product-images'),(31424,'watch-mobile','.w-compare-box-item .checkbox + span','border-top-width','1','','','.w-compare-box-item'),(31425,'watch-mobile','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(31426,'watch-mobile','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-bundle'),(31427,'watch-mobile','.w-catalog-listing-look .b2b','border-top-width','1','','','.w-catalog-listing-look'),(31428,'watch-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-width','1','','','.b-compare'),(31429,'watch-mobile','.w-catalog-listing-look .list','border-top-width','1','','','.w-catalog-listing-look'),(31430,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-width','1','','','.b-multi-page-checkout'),(31431,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-width','2','','','.p-blog-index'),(31432,'watch-mobile','.btn','border-top-width','2','','',''),(31433,'watch-mobile','.btn-3','border-top-width','2','','',''),(31434,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(31435,'watch-mobile','.view-all','border-top-width','1','3','',''),(31436,'watch-mobile','.b-info-popup .info-popup div','border-top-width','1','','','.b-info-popup'),(31437,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(31438,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','border-top-width','1','','','.b-multi-page-checkout'),(31439,'watch-mobile','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(31440,'watch-mobile','.testimonials .review','border-top-width','7','3','',''),(31441,'watch-mobile','.b-pagination .pagination .prev-pages','border-top-width','1','','','.b-pagination'),(31442,'watch-mobile','.b-pagination .pagination .prev','border-top-width','1','','','.b-pagination'),(31443,'watch-mobile','.b-pagination .pagination .page-number','border-top-width','1','','','.b-pagination'),(31444,'watch-mobile','.p-wedding-registry-manage .wr-search button','border-top-width','0','','','.p-wedding-registry-manage'),(31445,'watch-mobile','.b-pagination .pagination .next-pages','border-top-width','1','','','.b-pagination'),(31446,'watch-mobile','.b-pagination .pagination .next','border-top-width','1','','','.b-pagination'),(31447,'watch-mobile','.b-pagination .pagination span','border-top-width','1','2','','.b-pagination'),(31452,'watch-mobile','.w-list-type-2_2 .compare-box-item','border-top-width','1','','','.w-list-type-2_2'),(31453,'watch-mobile','.w-list-type-2_2 .button-wishlist button','border-top-width','0','','','.w-list-type-2_2'),(31454,'watch-mobile','.w-list-type-2_2 .buttons','border-top-width','1','','','.w-list-type-2_2'),(31455,'watch-mobile','.w-product-wedding-registry-button .btn','border-top-width','2','4','','.w-product-wedding-registry-button'),(31456,'watch-mobile','.p-wedding-registry-index .search-list','border-top-width','1','3','','.p-wedding-registry-index'),(31457,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-width','2','3','','.b-form'),(31458,'watch-mobile','.b-form .form-buttons','border-top-width','1','','','.b-form'),(31459,'watch-mobile','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(31460,'watch-mobile','.b-pagination .pagination a','border-top-width','1','','','.b-pagination'),(31461,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-width','2','','','.b-slick'),(31462,'watch-mobile','.w-languages .select','border-top-width','1','','','.w-languages'),(31463,'watch-mobile','.w-search .item + .item','border-top-width','1','','','.w-search'),(31464,'watch-mobile','.w-search .search-input','border-top-width','0','','','.w-search'),(31465,'watch-mobile','.w-socials > li','border-top-width','1','','','.w-socials'),(31467,'watch-mobile','.w-currencies .currencies-title','border-top-width','2','','','.w-currencies'),(31468,'watch-mobile','.w-currencies .select','border-top-width','1','','','.w-currencies'),(31469,'watch-mobile','.b-bottom .popup-buttons','border-top-width','1','','','.b-bottom'),(31470,'watch-mobile','.w-compare-box-item .checkbox:checked + span','border-top-width','1','','','.w-compare-box-item'),(31471,'watch-mobile','.b-slick .slick-vertical .slick-slide','border-top-width','1','','','.b-slick'),(31472,'watch-mobile','.w-menu .hided.menu ul li','border-top-width','1','317','','.w-menu'),(31473,'watch-mobile','.b-info-popup .info-popup div','border-top-width','1','3','','.b-info-popup'),(31474,'watch-mobile','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(31475,'watch-mobile','.w-catalog-listing-look .grid','border-top-width','1','','','.w-catalog-listing-look'),(31476,'watch-mobile','.w-sale .left-text-left','border-top-width','2','','','.w-sale'),(31477,'watch-mobile','.w-sale .left-text-right','border-top-width','2','','','.w-sale'),(31478,'watch-mobile','.b-quantity .qty-box .bigger','border-top-width','2','','','.b-quantity'),(31479,'watch-mobile','.b-quantity .qty-box .smaller','border-top-width','2','','','.b-quantity'),(31480,'watch-mobile','.w-cart .cart-content','border-top-width','1','','','.w-cart'),(31481,'watch-mobile','.p-reviews-info .review-info-text','border-top-width','5','4','','.p-reviews-info'),(31482,'watch-mobile','.w-list-type-2 .button-wishlist button','border-top-width','0','','','.w-list-type-2'),(31483,'watch-mobile','.w-list-type-2 .buttons','border-top-width','1','','','.w-list-type-2'),(31484,'watch-mobile','.w-list-type-2 .item','border-top-width','1','1','','.w-list-type-2'),(31485,'watch-mobile','.w-list-type-2 .compare-box-item','border-top-width','1','','','.w-list-type-2'),(31486,'watch-mobile','.b-autocomplete .ui-autocomplete li','border-top-width','1','','','.b-autocomplete'),(31487,'watch-mobile','.p-wedding-registry-manage .remove','border-top-width','1','','','.p-wedding-registry-manage'),(31488,'watch-mobile','.w-list-type-1_3 .compare-box-item','border-top-width','1','','','.w-list-type-1_3'),(31489,'watch-mobile','.w-list-type-1_3 .buttons','border-top-width','1','','','.w-list-type-1_3'),(31490,'watch-mobile','.w-list-type-1_3 .button-wishlist button','border-top-width','0','','','.w-list-type-1_3'),(31491,'watch-mobile','.w-list-type-1_2 .compare-box-item','border-top-width','1','','','.w-list-type-1_2'),(31492,'watch-mobile','.w-list-type-1_2 .buttons','border-top-width','1','','','.w-list-type-1_2'),(31493,'watch-mobile','.w-list-type-1_2 .button-wishlist button','border-top-width','0','','','.w-list-type-1_2'),(31494,'watch-mobile','.b-bottom .popup-box','border-top-width','1','','','.b-bottom'),(31495,'watch-mobile','.w-list-type-1 .compare-box-item','border-top-width','1','','','.w-list-type-1'),(31496,'watch-mobile','.w-list-type-1 .button-wishlist button','border-top-width','0','','','.w-list-type-1'),(31497,'watch-mobile','.w-filters .ui-slider-range','border-top-width','0','','','.w-filters'),(31498,'watch-mobile','.w-list-type-1 .buttons','border-top-width','1','','','.w-list-type-1'),(31499,'watch-mobile','.w-filters .ui-slider','border-top-width','0','','','.w-filters'),(31500,'watch-mobile','.w-filters .ui-slider-handle','border-top-width','0','','','.w-filters'),(31501,'watch-mobile','.w-reviews .review','border-top-width','7','3','','.w-reviews'),(31502,'watch-mobile','.w-search .button-search','border-top-width','0','','','.w-search'),(31503,'watch-mobile','.b-form .required-error','border-top-width','1','','','.b-form'),(31504,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-top-width','2','','',''),(31505,'watch-mobile','textarea','border-top-width','2','','',''),(31506,'watch-mobile','.b-info div + .info','border-top-width','1','','','.b-info'),(31507,'watch-mobile','.b-products-listing .products-listing .compare','border-top-width','1','','','.b-products-listing'),(31508,'watch-mobile','.b-data-table table.dataTable tbody td','border-top-width','1','','','.b-data-table'),(31509,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(31510,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(31511,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(31512,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(31513,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(31514,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(31515,'watch-mobile','.b-email .model','border-top-width','1','','','.b-email'),(31516,'watch-mobile','.b-email .model','border-top-width','1','','','.b-email'),(31517,'watch-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(31518,'watch-mobile','.b-email .name','border-top-width','1','','','.b-email'),(31519,'watch-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(31520,'watch-mobile','.b-email .name','border-top-width','1','','','.b-email'),(31521,'watch-mobile','.b-email .model','border-top-width','1','','','.b-email'),(31522,'watch-mobile','.b-email .price','border-top-width','1','','','.b-email'),(31523,'watch-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(31524,'watch-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(31525,'watch-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(31526,'watch-mobile','.b-email .price','border-top-width','1','','','.b-email'),(31527,'watch-mobile','.b-email .image','border-top-width','1','','','.b-email'),(31528,'watch-mobile','.b-email .image','border-top-width','1','','','.b-email'),(31529,'watch-mobile','.b-email .name','border-top-width','1','','','.b-email'),(31530,'watch-mobile','.b-email .name','border-top-width','1','','','.b-email'),(31531,'watch-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(31532,'watch-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(31533,'watch-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(31534,'watch-mobile','.b-email .name','border-top-width','1','','','.b-email'),(31535,'watch-mobile','.b-email .image','border-top-width','1','','','.b-email'),(31536,'watch-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(31537,'watch-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(31538,'watch-mobile','.b-email .model','border-top-width','1','','','.b-email'),(31539,'watch-mobile','.b-email .image','border-top-width','1','','','.b-email'),(31540,'watch-mobile','.b-email .name','border-top-width','1','','','.b-email'),(31541,'watch-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(31542,'watch-mobile','.b-email .price','border-top-width','1','','','.b-email'),(31543,'watch-mobile','.b-email .image','border-top-width','1','','','.b-email'),(31544,'watch-mobile','.b-email .price','border-top-width','1','','','.b-email'),(31545,'watch-mobile','.b-email .model','border-top-width','1','','','.b-email'),(31546,'watch-mobile','.b-email .image','border-top-width','1','','','.b-email'),(31547,'watch-mobile','.b-email .price','border-top-width','1','','','.b-email'),(31548,'watch-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(31549,'watch-mobile','.b-email .model','border-top-width','1','','','.b-email'),(31550,'watch-mobile','.b-email .price','border-top-width','1','','','.b-email'),(31551,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-top-width','1','','','.b-menu-style-2'),(31552,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-top-width','3','','','.b-menu-style-2'),(31553,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','border-top-width','1','','','.b-menu-style-2'),(31554,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-top-width','1','','','.b-menu-style-2'),(31555,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-top-width','3','','','.b-menu-style-2'),(31556,'watch-mobile','.b-messages .msv_btn','border-top-width','1','','','.b-messages'),(31557,'watch-mobile','.b-messages .email-heading','border-top-width','1','','','.b-messages'),(31558,'watch-mobile','.b-messages .dataTable','border-top-width','1','','','.b-messages'),(31559,'watch-mobile','.b-messages .messMenuButtonTop','border-top-width','1','','','.b-messages'),(31560,'watch-mobile','.b-messages .content_management_attach button','border-top-width','1','','','.b-messages'),(31561,'watch-mobile','.b-messages .messages-menu li + li','border-top-width','1','','','.b-messages'),(31562,'watch-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-width','2','','','.b-messages'),(31563,'watch-mobile','.b-messages .content_management_attach','border-top-width','1','','','.b-messages'),(31564,'watch-mobile','.b-select-suggest .select2-container .select2-choice','border-top-width','2','','','.b-select-suggest'),(31565,'watch-mobile','.b-select-suggest .select2-search input','border-top-width','1','','','.b-select-suggest'),(31566,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-width','1','','','.b-select-suggest'),(31567,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(31568,'watch-mobile','.b-select-suggest .select2-drop-auto-width','border-top-width','1','','','.b-select-suggest'),(31569,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-width','1','','','.b-select-suggest'),(31570,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-top-width','1','','','.b-select-suggest'),(31571,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-width','1','','','.b-select-suggest'),(31572,'watch-mobile','.b-select-suggest .select2-drop.select2-drop-above','border-top-width','1','','','.b-select-suggest'),(31573,'watch-mobile','.b-select-suggest .select2-drop-active','border-top-width','1','','','.b-select-suggest'),(31574,'watch-mobile','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-width','1','','','.b-select-suggest'),(31575,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(31576,'watch-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(31577,'watch-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(31578,'watch-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(31579,'watch-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(31580,'watch-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(31581,'watch-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(31582,'watch-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(31583,'watch-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(31584,'watch-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(31585,'watch-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(31586,'watch-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(31587,'watch-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(31588,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-width','2','','','.b-trade-approval'),(31589,'watch-mobile','.b-upload-file .snapshot','border-top-width','1','','','.b-upload-file'),(31590,'watch-mobile','.b-upload-file .upload-file-template','border-top-width','1','','','.b-upload-file'),(31591,'watch-mobile','.b-upload-files .upload-files','border-top-width','1','','','.b-upload-files'),(31592,'watch-mobile','.b-upload-files .added-file','border-top-width','1','','','.b-upload-files'),(31593,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-width','1','','','.batchPr'),(31594,'watch-mobile','.batchPr .checkbox input + span','border-top-width','1','','','.batchPr'),(31595,'watch-mobile','.batchPr .checkbox input + span','border-top-width','1','','','.batchPr'),(31596,'watch-mobile','.batchPr .checkbox input:checked + span','border-top-width','1','','','.batchPr'),(31597,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .item + .item','border-top-width','1','','','.batchPr'),(31598,'watch-mobile','.batchPr .w-batch-selected-products','border-top-width','1','','','.batchPr'),(31615,'watch-mobile','.p-payer-order-confirmation .input-wrapper','border-top-width','2','','','.p-payer-order-confirmation'),(31616,'watch-mobile','.p-payer-order-pay .input-wrapper','border-top-width','2','','','.p-payer-order-pay'),(31617,'watch-mobile','.w-account-address-book .wrap','border-top-width','1','','','.w-account-address-book'),(31618,'watch-mobile','.w-account-personal-catalog .list-switcher a','border-top-width','3','2','','.w-account-personal-catalog'),(31619,'watch-mobile','.w-account-subscription .subscription-variant + .subscription-variant','border-top-width','1','','','.w-account-subscription'),(31620,'watch-mobile','.w-cart-compare .attributes-block td','border-top-width','1','','','.w-cart-compare'),(31621,'watch-mobile','.w-cart-compare .price-block td','border-top-width','1','','','.w-cart-compare'),(31622,'watch-mobile','.w-cart-compare .product-block td','border-top-width','1','','','.w-cart-compare'),(31623,'watch-mobile','.w-cart-compare .cart-cell > div','border-top-width','1','','','.w-cart-compare'),(31624,'watch-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-top-width','1','','','.w-catalog-compare'),(31625,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','border-top-width','3','2','','.w-catalog-compare'),(31626,'watch-mobile','.w-catalog-paging .prev','border-top-width','1','','','.w-catalog-paging'),(31627,'watch-mobile','.w-catalog-paging .page-number','border-top-width','1','','','.w-catalog-paging'),(31628,'watch-mobile','.w-catalog-paging .next','border-top-width','1','','','.w-catalog-paging'),(31629,'watch-mobile','.w-catalog-paging ','border-top-width','1','2','','.w-catalog-paging'),(31630,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-width','1','','','.w-catalog-paging'),(31631,'watch-mobile','.w-catalog-paging .next-pages','border-top-width','1','','','.w-catalog-paging'),(31632,'watch-mobile','.w-catalog-paging .prev-pages','border-top-width','1','','','.w-catalog-paging'),(31633,'watch-mobile','.w-checkout-shipping .sub-item + .sub-item','border-top-width','1','','','.w-checkout-shipping'),(31634,'watch-mobile','.w-checkout-shipping-choice span','border-top-width','2','','','.w-checkout-shipping-choice'),(31635,'watch-mobile','.w-communication-new-topic td','border-top-width','1','','','.w-communication-new-topic'),(31636,'watch-mobile','.w-communication-post .communication-post','border-top-width','1','','','.w-communication-post'),(31637,'watch-mobile','.w-delivery-day .left-text-left','border-top-width','2','','','.w-delivery-day'),(31638,'watch-mobile','.w-delivery-day .left-text-right','border-top-width','2','','','.w-delivery-day'),(31639,'watch-mobile','.w-product-customers-activity .customers-activity','border-top-width','1','','','.w-product-customers-activity'),(31640,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-width','1','','','.w-promotions'),(31641,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-width','1','','','.w-promotions'),(31642,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-width','1','','','.w-promotions'),(31643,'watch-mobile','.w-promotions .promo-salemaker .discount','border-top-width','1','','','.w-promotions'),(31644,'watch-mobile','.w-reviews-content .review','border-top-width','8','3','','.w-reviews-content'),(31645,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(31646,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-top-width','1','','','.w-wedding-registry-widgets-photos'),(31647,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-top-width','1','','','.w-wedding-registry-widgets-photos'),(31648,'watch-mobile','.w-wedding-registry-widgets-products .rating','border-top-width','1','','','.w-wedding-registry-widgets-products'),(31649,'watch-mobile','.b-data-table table.dataTable thead td','border_important','important','','','.b-data-table'),(31650,'watch-mobile','.w-sale .left-count-days','border_radius_1_measure','px','','','.w-sale'),(31651,'watch-mobile','.w-sale .left-count-hours','border_radius_1_measure','px','','','.w-sale'),(31652,'watch-mobile','.w-sale .left-count','border_radius_1_measure','px','','','.w-sale'),(31653,'watch-mobile','.w-sale .badge','border_radius_1_measure','%','','','.w-sale'),(31654,'watch-mobile','.w-product-sale-ends .left-count','border_radius_1_measure','px','','','.w-product-sale-ends'),(31655,'watch-mobile','.w-product-sale-ends .left-count-hours','border_radius_1_measure','px','','','.w-product-sale-ends'),(31656,'watch-mobile','.w-product-sale-ends .left-count-days','border_radius_1_measure','px','','','.w-product-sale-ends'),(31657,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_1_measure','%','3','','.b-multi-page-checkout'),(31658,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_1_measure','%','','','.b-multi-page-checkout'),(31659,'watch-mobile','.p-blog-index .avatar','border_radius_1_measure','%','','','.p-blog-index'),(31660,'watch-mobile','.w-product-wedding-registry-button .btn','border_radius_1_measure','%','4','','.w-product-wedding-registry-button'),(31661,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_1_measure','%','3','','.b-form'),(31662,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(31663,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(31664,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_1_measure','px','','','.b-fancybox'),(31665,'watch-mobile','.b-switch .bootstrap-switch','border_radius_1_measure','px','','','.b-switch'),(31666,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_1_measure','%','','','.b-slick'),(31667,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border_radius_1_measure','px','303','','.w-list-type-1'),(31668,'watch-mobile','.btn-3','border_radius_1_measure','px','','',''),(31669,'watch-mobile','.btn-2','border_radius_1_measure','px','','',''),(31670,'watch-mobile','.btn-1','border_radius_1_measure','px','','',''),(31671,'watch-mobile','.btn','border_radius_1_measure','px','','',''),(31672,'watch-mobile','.b-fancybox .fancybox-skin','border_radius_1_measure','px','','','.b-fancybox'),(31673,'watch-mobile','.w-product-wedding-registry-button .btn','border_radius_1_measure','%','3','','.w-product-wedding-registry-button'),(31674,'watch-mobile','.b-fancybox .fancybox-nav span','border_radius_1_measure','%','','','.b-fancybox'),(31675,'watch-mobile','.b-products-listing .promos-info .promo-name','border_radius_1_measure','px','','','.b-products-listing'),(31676,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.b-data-table'),(31677,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.b-data-table'),(31678,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_1_measure','px','','','.b-messages'),(31679,'watch-mobile','.b-trade-approval .steps-bar','border_radius_1_measure','px','','','.b-trade-approval'),(31680,'watch-mobile','.b-upload-file .snapshot','border_radius_1_measure','%','','','.b-upload-file'),(31681,'watch-mobile','.batchPr .checkbox input + span','border_radius_1_measure','px','','','.batchPr'),(31682,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_1_measure','px','','','.batchPr'),(31683,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_1_measure','px','','','.batchPr'),(31684,'watch-mobile','.batchPr .btn-batch-remove','border_radius_1_measure','%','','','.batchPr'),(31686,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.p-quick-order-index'),(31687,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.p-quick-order-index'),(31688,'watch-mobile','.w-account-address-book .wrap','border_radius_1_measure','px','','','.w-account-address-book'),(31689,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_1_measure','px','','','.w-blog-widget-related-posts'),(31690,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_1_measure','px','','','.w-catalog-paging'),(31691,'watch-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(31692,'watch-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(31693,'watch-mobile','.w-delivery-day .left-count','border_radius_1_measure','px','','','.w-delivery-day'),(31694,'watch-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_1_measure','px','','','.w-delivery-day'),(31695,'watch-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(31696,'watch-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(31697,'watch-mobile','.w-product-customers-activity .customers-activity','border_radius_1_measure','px','','','.w-product-customers-activity'),(31698,'watch-mobile','.w-product-customers-activity .close','border_radius_1_measure','%','','','.w-product-customers-activity'),(31699,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_1_measure','px','','','.w-promotions'),(31700,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_1_measure','px','','','.w-promotions'),(31701,'watch-mobile','.w-promotions .promo-salemaker .discount','border_radius_1_measure','px','','','.w-promotions'),(31702,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_1_measure','px','','','.w-promotions'),(31703,'watch-mobile','.w-sale .left-count-days','border_radius_2_measure','px','','','.w-sale'),(31704,'watch-mobile','.w-sale .left-count','border_radius_2_measure','px','','','.w-sale'),(31705,'watch-mobile','.w-sale .left-count-hours','border_radius_2_measure','px','','','.w-sale'),(31706,'watch-mobile','.w-sale .badge','border_radius_2_measure','%','','','.w-sale'),(31707,'watch-mobile','.w-product-wedding-registry-button .btn','border_radius_2_measure','%','3','','.w-product-wedding-registry-button'),(31708,'watch-mobile','.w-product-sale-ends .left-count','border_radius_2_measure','px','','','.w-product-sale-ends'),(31709,'watch-mobile','.w-product-sale-ends .left-count-days','border_radius_2_measure','px','','','.w-product-sale-ends'),(31710,'watch-mobile','.w-product-sale-ends .left-count-hours','border_radius_2_measure','px','','','.w-product-sale-ends'),(31711,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_2_measure','%','3','','.b-multi-page-checkout'),(31712,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_2_measure','%','','','.b-multi-page-checkout'),(31713,'watch-mobile','.p-blog-index .avatar','border_radius_2_measure','%','','','.p-blog-index'),(31714,'watch-mobile','.w-product-wedding-registry-button .btn','border_radius_2_measure','%','4','','.w-product-wedding-registry-button'),(31715,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_2_measure','%','3','','.b-form'),(31716,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(31717,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(31718,'watch-mobile','.b-switch .bootstrap-switch','border_radius_2_measure','px','','','.b-switch'),(31719,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_2_measure','%','','','.b-slick'),(31720,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border_radius_2_measure','px','303','','.w-list-type-1'),(31721,'watch-mobile','.btn-3','border_radius_2_measure','px','','',''),(31722,'watch-mobile','.btn-2','border_radius_2_measure','px','','',''),(31723,'watch-mobile','.btn-1','border_radius_2_measure','px','','',''),(31724,'watch-mobile','.btn','border_radius_2_measure','px','','',''),(31725,'watch-mobile','.b-fancybox .fancybox-skin','border_radius_2_measure','px','','','.b-fancybox'),(31726,'watch-mobile','.b-fancybox .fancybox-nav span','border_radius_2_measure','%','','','.b-fancybox'),(31727,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_2_measure','px','','','.b-fancybox'),(31728,'watch-mobile','.b-products-listing .promos-info .promo-name','border_radius_2_measure','px','','','.b-products-listing'),(31729,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.b-data-table'),(31730,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.b-data-table'),(31731,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_2_measure','px','','','.b-messages'),(31732,'watch-mobile','.b-trade-approval .steps-bar','border_radius_2_measure','px','','','.b-trade-approval'),(31733,'watch-mobile','.b-upload-file .snapshot','border_radius_2_measure','%','','','.b-upload-file'),(31734,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_2_measure','px','','','.batchPr'),(31735,'watch-mobile','.batchPr .checkbox input + span','border_radius_2_measure','px','','','.batchPr'),(31736,'watch-mobile','.batchPr .btn-batch-remove','border_radius_2_measure','%','','','.batchPr'),(31737,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_2_measure','px','','','.batchPr'),(31739,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.p-quick-order-index'),(31740,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.p-quick-order-index'),(31741,'watch-mobile','.w-account-address-book .wrap','border_radius_2_measure','px','','','.w-account-address-book'),(31742,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_2_measure','px','','','.w-blog-widget-related-posts'),(31743,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_2_measure','px','','','.w-catalog-paging'),(31744,'watch-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(31745,'watch-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(31746,'watch-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_2_measure','px','','','.w-delivery-day'),(31747,'watch-mobile','.w-delivery-day .left-count','border_radius_2_measure','px','','','.w-delivery-day'),(31748,'watch-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(31749,'watch-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(31750,'watch-mobile','.w-product-customers-activity .customers-activity','border_radius_2_measure','px','','','.w-product-customers-activity'),(31751,'watch-mobile','.w-product-customers-activity .close','border_radius_2_measure','%','','','.w-product-customers-activity'),(31752,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_2_measure','px','','','.w-promotions'),(31753,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_2_measure','px','','','.w-promotions'),(31754,'watch-mobile','.w-promotions .promo-salemaker .discount','border_radius_2_measure','px','','','.w-promotions'),(31755,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_2_measure','px','','','.w-promotions'),(31756,'watch-mobile','.w-sale .left-count','border_radius_3_measure','px','','','.w-sale'),(31757,'watch-mobile','.w-sale .left-count-days','border_radius_3_measure','px','','','.w-sale'),(31758,'watch-mobile','.w-sale .badge','border_radius_3_measure','%','','','.w-sale'),(31759,'watch-mobile','.w-product-wedding-registry-button .btn','border_radius_3_measure','%','3','','.w-product-wedding-registry-button'),(31760,'watch-mobile','.w-product-sale-ends .left-count-days','border_radius_3_measure','px','','','.w-product-sale-ends'),(31761,'watch-mobile','.w-product-sale-ends .left-count','border_radius_3_measure','px','','','.w-product-sale-ends'),(31762,'watch-mobile','.w-product-sale-ends .left-count-hours','border_radius_3_measure','px','','','.w-product-sale-ends'),(31763,'watch-mobile','.b-fancybox .fancybox-nav span','border_radius_3_measure','%','','','.b-fancybox'),(31764,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_3_measure','%','3','','.b-multi-page-checkout'),(31765,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_3_measure','%','','','.b-multi-page-checkout'),(31766,'watch-mobile','.p-blog-index .avatar','border_radius_3_measure','%','','','.p-blog-index'),(31767,'watch-mobile','.w-product-wedding-registry-button .btn','border_radius_3_measure','%','4','','.w-product-wedding-registry-button'),(31768,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_3_measure','%','3','','.b-form'),(31769,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(31770,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(31771,'watch-mobile','.b-switch .bootstrap-switch','border_radius_3_measure','px','','','.b-switch'),(31772,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_3_measure','%','','','.b-slick'),(31773,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border_radius_3_measure','px','303','','.w-list-type-1'),(31774,'watch-mobile','.btn-3','border_radius_3_measure','px','','',''),(31775,'watch-mobile','.btn-2','border_radius_3_measure','px','','',''),(31776,'watch-mobile','.btn-1','border_radius_3_measure','px','','',''),(31777,'watch-mobile','.btn','border_radius_3_measure','px','','',''),(31778,'watch-mobile','.b-fancybox .fancybox-skin','border_radius_3_measure','px','','','.b-fancybox'),(31779,'watch-mobile','.w-sale .left-count-hours','border_radius_3_measure','px','','','.w-sale'),(31780,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_3_measure','px','','','.b-fancybox'),(31781,'watch-mobile','.b-products-listing .promos-info .promo-name','border_radius_3_measure','px','','','.b-products-listing'),(31782,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.b-data-table'),(31783,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.b-data-table'),(31784,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_3_measure','px','','','.b-messages'),(31785,'watch-mobile','.b-trade-approval .steps-bar','border_radius_3_measure','px','','','.b-trade-approval'),(31786,'watch-mobile','.b-upload-file .snapshot','border_radius_3_measure','%','','','.b-upload-file'),(31787,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_3_measure','px','','','.batchPr'),(31788,'watch-mobile','.batchPr .checkbox input + span','border_radius_3_measure','px','','','.batchPr'),(31789,'watch-mobile','.batchPr .btn-batch-remove','border_radius_3_measure','%','','','.batchPr'),(31790,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_3_measure','px','','','.batchPr'),(31792,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.p-quick-order-index'),(31793,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.p-quick-order-index'),(31794,'watch-mobile','.w-account-address-book .wrap','border_radius_3_measure','px','','','.w-account-address-book'),(31795,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_3_measure','px','','','.w-blog-widget-related-posts'),(31796,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_3_measure','px','','','.w-catalog-paging'),(31797,'watch-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(31798,'watch-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(31799,'watch-mobile','.w-delivery-day .left-count','border_radius_3_measure','px','','','.w-delivery-day'),(31800,'watch-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_3_measure','px','','','.w-delivery-day'),(31801,'watch-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(31802,'watch-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(31803,'watch-mobile','.w-product-customers-activity .customers-activity','border_radius_3_measure','px','','','.w-product-customers-activity'),(31804,'watch-mobile','.w-product-customers-activity .close','border_radius_3_measure','%','','','.w-product-customers-activity'),(31805,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_3_measure','px','','','.w-promotions'),(31806,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_3_measure','px','','','.w-promotions'),(31807,'watch-mobile','.w-promotions .promo-salemaker .discount','border_radius_3_measure','px','','','.w-promotions'),(31808,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_3_measure','px','','','.w-promotions'),(31809,'watch-mobile','.w-sale .left-count-days','border_radius_4_measure','px','','','.w-sale'),(31810,'watch-mobile','.w-sale .left-count-hours','border_radius_4_measure','px','','','.w-sale'),(31811,'watch-mobile','.w-sale .left-count','border_radius_4_measure','px','','','.w-sale'),(31812,'watch-mobile','.w-sale .badge','border_radius_4_measure','%','','','.w-sale'),(31813,'watch-mobile','.w-product-wedding-registry-button .btn','border_radius_4_measure','%','3','','.w-product-wedding-registry-button'),(31814,'watch-mobile','.w-product-wedding-registry-button .btn','border_radius_4_measure','%','4','','.w-product-wedding-registry-button'),(31815,'watch-mobile','.w-product-sale-ends .left-count','border_radius_4_measure','px','','','.w-product-sale-ends'),(31816,'watch-mobile','.w-product-sale-ends .left-count-days','border_radius_4_measure','px','','','.w-product-sale-ends'),(31817,'watch-mobile','.w-product-sale-ends .left-count-hours','border_radius_4_measure','px','','','.w-product-sale-ends'),(31818,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_4_measure','%','3','','.b-multi-page-checkout'),(31819,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_4_measure','%','','','.b-multi-page-checkout'),(31820,'watch-mobile','.p-blog-index .avatar','border_radius_4_measure','%','','','.p-blog-index'),(31821,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_4_measure','%','3','','.b-form'),(31822,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(31823,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(31824,'watch-mobile','.b-switch .bootstrap-switch','border_radius_4_measure','px','','','.b-switch'),(31825,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border_radius_4_measure','px','303','','.w-list-type-1'),(31826,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_4_measure','%','','','.b-slick'),(31827,'watch-mobile','.btn-3','border_radius_4_measure','px','','',''),(31828,'watch-mobile','.btn-2','border_radius_4_measure','px','','',''),(31829,'watch-mobile','.btn-1','border_radius_4_measure','px','','',''),(31830,'watch-mobile','.btn','border_radius_4_measure','px','','',''),(31831,'watch-mobile','.b-fancybox .fancybox-skin','border_radius_4_measure','px','','','.b-fancybox'),(31832,'watch-mobile','.b-fancybox .fancybox-nav span','border_radius_4_measure','%','','','.b-fancybox'),(31833,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_4_measure','px','','','.b-fancybox'),(31834,'watch-mobile','.b-products-listing .promos-info .promo-name','border_radius_4_measure','px','','','.b-products-listing'),(31835,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.b-data-table'),(31836,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.b-data-table'),(31837,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_4_measure','px','','','.b-messages'),(31838,'watch-mobile','.b-trade-approval .steps-bar','border_radius_4_measure','px','','','.b-trade-approval'),(31839,'watch-mobile','.b-upload-file .snapshot','border_radius_4_measure','%','','','.b-upload-file'),(31840,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_4_measure','px','','','.batchPr'),(31841,'watch-mobile','.batchPr .checkbox input + span','border_radius_4_measure','px','','','.batchPr'),(31842,'watch-mobile','.batchPr .btn-batch-remove','border_radius_4_measure','%','','','.batchPr'),(31843,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_4_measure','px','','','.batchPr'),(31845,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.p-quick-order-index'),(31846,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.p-quick-order-index'),(31847,'watch-mobile','.w-account-address-book .wrap','border_radius_4_measure','px','','','.w-account-address-book'),(31848,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_4_measure','px','','','.w-blog-widget-related-posts'),(31849,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_4_measure','px','','','.w-catalog-paging'),(31850,'watch-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(31851,'watch-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(31852,'watch-mobile','.w-delivery-day .left-count','border_radius_4_measure','px','','','.w-delivery-day'),(31853,'watch-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_4_measure','px','','','.w-delivery-day'),(31854,'watch-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(31855,'watch-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(31856,'watch-mobile','.w-product-customers-activity .customers-activity','border_radius_4_measure','px','','','.w-product-customers-activity'),(31857,'watch-mobile','.w-product-customers-activity .close','border_radius_4_measure','%','','','.w-product-customers-activity'),(31858,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_4_measure','px','','','.w-promotions'),(31859,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_4_measure','px','','','.w-promotions'),(31860,'watch-mobile','.w-promotions .promo-salemaker .discount','border_radius_4_measure','px','','','.w-promotions'),(31861,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_4_measure','px','','','.w-promotions'),(31862,'watch-mobile','.p-reviews-info .review-info-text','bottom','-10','4','','.p-reviews-info'),(31863,'watch-mobile','.b-info-popup .info-popup.top-left div','bottom','-11','3','','.b-info-popup'),(31864,'watch-mobile','.b-info-popup .info-popup.top-left div','bottom','30','','','.b-info-popup'),(31865,'watch-mobile','.testimonials .review','bottom','-13','3','',''),(31872,'watch-mobile','.w-list-type-2_2 .sale','bottom','0','','','.w-list-type-2_2'),(31873,'watch-mobile','.w-list-type-2_2 .sale','bottom','0','3','','.w-list-type-2_2'),(31874,'watch-mobile','.w-list-type-2 .sale','bottom','0','','','.w-list-type-2'),(31875,'watch-mobile','.w-list-type-2 .sale','bottom','0','4','','.w-list-type-2'),(31876,'watch-mobile','.w-list-type-2 .sale','bottom','0','3','','.w-list-type-2'),(31877,'watch-mobile','.w-banner .image-text-banner.bottom-center .text-banner','bottom','0','','','.w-banner'),(31878,'watch-mobile','.w-banner .image-text-banner.bottom-left .text-banner','bottom','0','','','.w-banner'),(31879,'watch-mobile','.w-banner .image-text-banner.bottom-right .text-banner','bottom','0','','','.w-banner'),(31880,'watch-mobile','.b-slick .slick-vertical button.slick-next','bottom','0','','','.b-slick'),(31881,'watch-mobile','.b-slick .slick-vertical button.slick-prev','bottom','auto','','','.b-slick'),(31882,'watch-mobile','.b-fancybox .fancybox-title-float-wrap','bottom','0','','','.b-fancybox'),(31883,'watch-mobile','.w-list-type-1_3 #add_all','bottom','20','','','.w-list-type-1_3'),(31884,'watch-mobile','.b-fancybox .fancybox-title-over-wrap','bottom','0','','','.b-fancybox'),(31885,'watch-mobile','.b-fancybox .fancybox-overlay-fixed','bottom','0','','','.b-fancybox'),(31886,'watch-mobile','.w-list-type-2_2 .sale','bottom','0','4','','.w-list-type-2_2'),(31887,'watch-mobile','.w-list-type-1_3 .sale','bottom','0','3','','.w-list-type-1_3'),(31888,'watch-mobile','.w-list-type-1_3 .sale','bottom','0','4','','.w-list-type-1_3'),(31889,'watch-mobile','.w-list-type-1_3 .sale','bottom','0','','','.w-list-type-1_3'),(31890,'watch-mobile','.w-list-type-1_2 .sale','bottom','0','','','.w-list-type-1_2'),(31891,'watch-mobile','.w-list-type-1_2 .sale','bottom','0','3','','.w-list-type-1_2'),(31892,'watch-mobile','.w-list-type-1_2 .sale','bottom','0','4','','.w-list-type-1_2'),(31893,'watch-mobile','.w-list-type-1 .sale','bottom','0','4','','.w-list-type-1'),(31894,'watch-mobile','.w-list-type-1 .sale','bottom','0','3','','.w-list-type-1'),(31895,'watch-mobile','.w-list-type-1 .sale','bottom','0','','','.w-list-type-1'),(31896,'watch-mobile','.w-product-reviews .reviews-list .review','bottom','-13','3','','.w-product-reviews'),(31897,'watch-mobile','.w-reviews .review','bottom','-13','3','','.w-reviews'),(31898,'watch-mobile','.b-upload-file .snapshot','bottom','5','','','.b-upload-file'),(31917,'watch-mobile','.p-quick-order-index .all-scroll-div','bottom','0','','','.p-quick-order-index'),(31918,'watch-mobile','.w-catalog-b2b-add-button ','bottom','0','','','.w-catalog-b2b-add-button'),(31919,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','bottom','-7','','','.w-checkout-shipping-choice'),(31920,'watch-mobile','.w-product-customers-activity .customers-activity','bottom','0','','','.w-product-customers-activity'),(31921,'watch-mobile','.w-product-customers-activity .customers-activity.closed','bottom','-1000','','','.w-product-customers-activity'),(31922,'watch-mobile','.w-menu .hided.menu ul ul','box-shadow','none','','','.w-menu'),(31923,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(31924,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','box-shadow','0 2px 9px 0 rgba(0, 0, 0, 0.2)','2','','.b-multi-page-checkout'),(31925,'watch-mobile','.b-fancybox .fancybox-opened .fancybox-skin','box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(31926,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','box-shadow','none','','','.batchPr'),(31927,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','box-shadow','none','','','.batchPr'),(31928,'watch-mobile','.w-catalog-compare .compare-fix-bar.fix-bar-fix','box-shadow','0 10px 10px -10px #cccccc','','','.w-catalog-compare'),(31929,'watch-mobile','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(31930,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','box-sizing','border-box','','','.b-switch'),(31931,'watch-mobile','.b-slick .slick-slider','box-sizing','border-box','','','.b-slick'),(31932,'watch-mobile','.b-fancybox .filter-listing-loader','box-sizing','content-box','','','.b-fancybox'),(31933,'watch-mobile','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','box-sizing','border-box','','','.b-select-suggest'),(31934,'watch-mobile','.b-info-popup .info-popup div','box_shadow_blur','10','','','.b-info-popup'),(31935,'watch-mobile','.b-datepicker .datepicker-dropdown','box_shadow_blur','10','','','.b-datepicker'),(31936,'watch-mobile','.w-account-address-book .wrap','box_shadow_blur','4','','','.w-account-address-book'),(31937,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur','5','','','.w-image-maps'),(31938,'watch-mobile','.w-product-customers-activity .customers-activity','box_shadow_blur','20','','','.w-product-customers-activity'),(31939,'watch-mobile','.b-info-popup .info-popup div','box_shadow_blur_measure','px','','','.b-info-popup'),(31940,'watch-mobile','.b-datepicker .datepicker-dropdown','box_shadow_blur_measure','px','','','.b-datepicker'),(31941,'watch-mobile','.w-account-address-book .wrap','box_shadow_blur_measure','px','','','.w-account-address-book'),(31942,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur_measure','px','','','.w-image-maps'),(31943,'watch-mobile','.w-product-customers-activity .customers-activity','box_shadow_blur_measure','px','','','.w-product-customers-activity'),(31944,'watch-mobile','.b-info-popup .info-popup div','box_shadow_color','#ccc','','','.b-info-popup'),(31945,'watch-mobile','.b-datepicker .datepicker-dropdown','box_shadow_color','#ccc','','','.b-datepicker'),(31946,'watch-mobile','.w-account-address-book .wrap','box_shadow_color','#c4c4c4','','','.w-account-address-book'),(31947,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_color','#ccc','','','.w-image-maps'),(31948,'watch-mobile','.w-product-customers-activity .customers-activity','box_shadow_color','#eee','','','.w-product-customers-activity'),(31949,'watch-mobile','.b-info-popup .info-popup div','box_shadow_left','0','','','.b-info-popup'),(31950,'watch-mobile','.b-datepicker .datepicker-dropdown','box_shadow_left','0','','','.b-datepicker'),(31951,'watch-mobile','.w-account-address-book .wrap','box_shadow_left','1','','','.w-account-address-book'),(31952,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left','0','','','.w-image-maps'),(31953,'watch-mobile','.w-product-customers-activity .customers-activity','box_shadow_left','0','','','.w-product-customers-activity'),(31954,'watch-mobile','.b-info-popup .info-popup div','box_shadow_left_measure','','','','.b-info-popup'),(31955,'watch-mobile','.b-datepicker .datepicker-dropdown','box_shadow_left_measure','','','','.b-datepicker'),(31956,'watch-mobile','.w-account-address-book .wrap','box_shadow_left_measure','px','','','.w-account-address-book'),(31957,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left_measure','','','','.w-image-maps'),(31958,'watch-mobile','.w-product-customers-activity .customers-activity','box_shadow_left_measure','','','','.w-product-customers-activity'),(31959,'watch-mobile','.b-info-popup .info-popup div','box_shadow_top','0','','','.b-info-popup'),(31960,'watch-mobile','.b-datepicker .datepicker-dropdown','box_shadow_top','0','','','.b-datepicker'),(31961,'watch-mobile','.w-account-address-book .wrap','box_shadow_top','1','','','.w-account-address-book'),(31962,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top','0','','','.w-image-maps'),(31963,'watch-mobile','.w-product-customers-activity .customers-activity','box_shadow_top','0','','','.w-product-customers-activity'),(31964,'watch-mobile','.b-info-popup .info-popup div','box_shadow_top_measure','','','','.b-info-popup'),(31965,'watch-mobile','.b-datepicker .datepicker-dropdown','box_shadow_top_measure','','','','.b-datepicker'),(31966,'watch-mobile','.w-account-address-book .wrap','box_shadow_top_measure','px','','','.w-account-address-book'),(31967,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top_measure','','','','.w-image-maps'),(31968,'watch-mobile','.w-product-customers-activity .customers-activity','box_shadow_top_measure','','','','.w-product-customers-activity'),(31969,'watch-mobile','.w-menu-big li','clear','none','','','.w-menu-big'),(31970,'watch-mobile','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(31971,'watch-mobile','.w-login-block .cols','clear','both','4','','.w-login-block'),(31972,'watch-mobile','.w-login-block .guest','clear','right','','','.w-login-block'),(31973,'watch-mobile','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(31974,'watch-mobile','.w-login-block .buttons','clear','none','','','.w-login-block'),(31975,'watch-mobile','.w-product-attributes .attributes','clear','both','4','','.w-product-attributes'),(31976,'watch-mobile','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(31977,'watch-mobile','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(31978,'watch-mobile','.w-cart a.item','clear','both','4','','.w-cart'),(31979,'watch-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','clear','both','','','.p-account-trade-form'),(31980,'watch-mobile','.w-categories .item:nth-child(4n + 1)','clear','both','','','.w-categories'),(31981,'watch-mobile','.w-categories .categories','clear','both','4','','.w-categories'),(31982,'watch-mobile','.b-pagination .pagination','clear','both','4','','.b-pagination'),(31983,'watch-mobile','.w-cart-shipping-estimator .shipping-estimator','clear','both','4','','.w-cart-shipping-estimator'),(31984,'watch-mobile','.w-list-type-1_2 .right-area','clear','both','4','','.w-list-type-1_2'),(31985,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','clear','both','4','','.b-multi-page-checkout'),(31986,'watch-mobile','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(31987,'watch-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','clear','none','','','.p-wedding-registry-manage'),(31988,'watch-mobile','.w-product-bonus-points > div','clear','both','4','','.w-product-bonus-points'),(31989,'watch-mobile','.w-product-configurator .pc_attr','clear','both','290','','.w-product-configurator'),(31990,'watch-mobile','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(31991,'watch-mobile','.w-product-configurator .pc_qty','clear','both','290','','.w-product-configurator'),(31993,'watch-mobile','.p-blog-index .w-blog-sidebar .wp-widget:nth-child(2n + 1)','clear','both','317','','.p-blog-index'),(31994,'watch-mobile','.p-blog-index .entry-content','clear','both','4','','.p-blog-index'),(31995,'watch-mobile','.p-blog-index .comment-meta','clear','both','4','','.p-blog-index'),(31996,'watch-mobile','.buttons','clear','both','','',''),(31997,'watch-mobile','.w-list-type-2_2 .qty-input','clear','left','','','.w-list-type-2_2'),(31998,'watch-mobile','.w-list-type-2_2 .compare-box-item','clear','both','','','.w-list-type-2_2'),(31999,'watch-mobile','.w-list-type-2_2 .item','clear','both','','','.w-list-type-2_2'),(32000,'watch-mobile','.buttons','clear','both','4','',''),(32001,'watch-mobile','.w-list-type-2_2 .item','clear','both','4','','.w-list-type-2_2'),(32002,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','clear','right','','','.w-list-type-2_2'),(32003,'watch-mobile','.w-list-type-2_2 .add-height','clear','both','4','','.w-list-type-2_2'),(32004,'watch-mobile','.w-list-type-2 .qty-input','clear','left','','','.w-list-type-2'),(32005,'watch-mobile','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(32006,'watch-mobile','.b-form .center-buttons','clear','both','','','.b-form'),(32007,'watch-mobile','.b-product-images .main-image-box','clear','both','4','','.b-product-images'),(32008,'watch-mobile','.w-top-categories .categories','clear','both','4','','.w-top-categories'),(32009,'watch-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(32010,'watch-mobile','.p-account-trade-form .widget','clear','both','','','.p-account-trade-form'),(32011,'watch-mobile','.b-slick .slick-track','clear','both','4','','.b-slick'),(32012,'watch-mobile','.p-account-trade-form .wd-line-row-2','clear','both','4','','.p-account-trade-form'),(32013,'watch-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','clear','left','','','.p-account-trade-form'),(32014,'watch-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(32015,'watch-mobile','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(32016,'watch-mobile','.w-list-type-1_3 .qty-input','clear','left','','','.w-list-type-1_3'),(32017,'watch-mobile','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(32018,'watch-mobile','.p-wedding-registry-share .add-row','clear','both','','','.p-wedding-registry-share'),(32019,'watch-mobile','.p-wedding-registry-share .address-row','clear','both','','','.p-wedding-registry-share'),(32020,'watch-mobile','.b-slick .slick-slide','clear','none','','','.b-slick'),(32021,'watch-mobile','.w-menu-horizontal li','clear','none','','','.w-menu-horizontal'),(32022,'watch-mobile','.b-form .addresses .address-item:nth-child(2n + 1)','clear','left','','','.b-form'),(32023,'watch-mobile','.b-form .columns','clear','both','4','','.b-form'),(32024,'watch-mobile','.b-form .columns .col-2:nth-child(2n + 1)','clear','left','','','.b-form'),(32025,'watch-mobile','.b-form .addresses','clear','both','4','','.b-form'),(32026,'watch-mobile','.w-cart-give-away .ga_name','clear','both','4','','.w-cart-give-away'),(32027,'watch-mobile','.w-cart-give-away .ga_column:nth-child(2n + 1)','clear','both','','','.w-cart-give-away'),(32028,'watch-mobile','.b-form .col-right + .col-left','clear','both','','','.b-form'),(32029,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','clear','right','','','.w-list-type-2'),(32030,'watch-mobile','.w-list-type-2 .compare-box-item','clear','both','','','.w-list-type-2'),(32031,'watch-mobile','.w-list-type-2 .add-height','clear','both','4','','.w-list-type-2'),(32032,'watch-mobile','.w-list-type-1_3 .item','clear','both','','','.w-list-type-1_3'),(32033,'watch-mobile','.w-list-type-1_3 .item','clear','both','4','','.w-list-type-1_3'),(32034,'watch-mobile','.w-list-type-1_3 .compare-box-item','clear','both','','','.w-list-type-1_3'),(32035,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','clear','right','','','.w-list-type-1_3'),(32036,'watch-mobile','.w-list-type-1_3 .attributes > .attributes','clear','both','4','','.w-list-type-1_3'),(32037,'watch-mobile','.w-list-type-1_3 .add-height','clear','both','4','','.w-list-type-1_3'),(32038,'watch-mobile','.w-list-type-1_2 .qty-input','clear','left','','','.w-list-type-1_2'),(32039,'watch-mobile','.w-list-type-1_2 .item','clear','both','','','.w-list-type-1_2'),(32040,'watch-mobile','.w-list-type-1_2 .item','clear','both','4','','.w-list-type-1_2'),(32041,'watch-mobile','.w-list-type-1_2 .compare-box-item','clear','both','','','.w-list-type-1_2'),(32042,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','clear','right','','','.w-list-type-1_2'),(32043,'watch-mobile','.w-list-type-1_2 .add-height','clear','both','4','','.w-list-type-1_2'),(32044,'watch-mobile','.w-list-type-1 .qty-input','clear','left','','','.w-list-type-1'),(32045,'watch-mobile','.w-list-type-1 .compare-box-item','clear','both','','','.w-list-type-1'),(32046,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','clear','right','','','.w-list-type-1'),(32047,'watch-mobile','.w-list-type-1 .add-height','clear','both','4','','.w-list-type-1'),(32048,'watch-mobile','.w-top-categories .item:nth-child(4n + 1)','clear','both','','','.w-top-categories'),(32049,'watch-mobile','.b-form .col-right','clear','right','','','.b-form'),(32050,'watch-mobile','.b-form .col-full','clear','both','','','.b-form'),(32051,'watch-mobile','.b-form .col-left','clear','left','','','.b-form'),(32052,'watch-mobile','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(32053,'watch-mobile','.b-form .requiredM','clear','both','','','.b-form'),(32054,'watch-mobile','.w-menu-style-1 li','clear','none','','','.w-menu-style-1'),(32055,'watch-mobile','.b-products-listing .BlockBox','clear','both','4','','.b-products-listing'),(32056,'watch-mobile','.b-products-listing .products-listing','clear','both','4','','.b-products-listing'),(32057,'watch-mobile','.b-products-listing .products-listing .mix-attributes','clear','bpth','4','','.b-products-listing'),(32058,'watch-mobile','.b-messages .dataTables_wrapper > .top','clear','both','4','','.b-messages'),(32059,'watch-mobile','.b-messages .dataTables_wrapper > .bottom','clear','both','4','','.b-messages'),(32060,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(32061,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(32062,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(32063,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(32064,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(32065,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(32066,'watch-mobile','.b-trade-approval .col-right','clear','right','','','.b-trade-approval'),(32067,'watch-mobile','.b-trade-approval .col-left','clear','left','','','.b-trade-approval'),(32068,'watch-mobile','.b-trade-approval .center-buttons','clear','both','','','.b-trade-approval'),(32069,'watch-mobile','.b-trade-approval .columns','clear','both','4','','.b-trade-approval'),(32070,'watch-mobile','.w-account-address-book .button-add','clear','both','','','.w-account-address-book'),(32071,'watch-mobile','.w-account-address-book .item:nth-child(2n + 1)','clear','both','','','.w-account-address-book'),(32072,'watch-mobile','.w-blog-widget-post-listing .post:nth-child(2n+1)','clear','both','','','.w-blog-widget-post-listing'),(32073,'watch-mobile','.w-blog-widget-post-listing .post:nth-child(3n+1)','clear','none','','','.w-blog-widget-post-listing'),(32074,'watch-mobile','.w-blog-widget-post-listing .products','clear','both','4','','.w-blog-widget-post-listing'),(32075,'watch-mobile','.w-blog-widget-post-share ','clear','both','','','.w-blog-widget-post-share'),(32076,'watch-mobile','.w-cart-compare .product .image','clear','both','','','.w-cart-compare'),(32077,'watch-mobile','.w-cart-compare .product','clear','both','4','','.w-cart-compare'),(32078,'watch-mobile','.w-cart-compare .buttons','clear','none','','','.w-cart-compare'),(32079,'watch-mobile','.w-cart-compare .product .name','clear','right','','','.w-cart-compare'),(32080,'watch-mobile','.w-catalog-compare .BlockBox','clear','both','','','.w-catalog-compare'),(32081,'watch-mobile','.w-checkout-billing-address .addresses','clear','both','4','','.w-checkout-billing-address'),(32082,'watch-mobile','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-billing-address'),(32083,'watch-mobile','.w-checkout-billing-address .btn-cancel','clear','both','','','.w-checkout-billing-address'),(32084,'watch-mobile','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-shipping-address'),(32085,'watch-mobile','.w-checkout-shipping-address .addresses','clear','both','4','','.w-checkout-shipping-address'),(32086,'watch-mobile','.w-checkout-shipping-address .btn-cancel','clear','both','','','.w-checkout-shipping-address'),(32087,'watch-mobile','.w-list-b2b .attributes','clear','both','4','','.w-list-b2b'),(32088,'watch-mobile','.w-list-b2b .mix-attributes','clear','both','','','.w-list-b2b'),(32089,'watch-mobile','.w-product-available-in-warehouses .content','clear','both','4','','.w-product-available-in-warehouses'),(32090,'watch-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(32091,'watch-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(32092,'watch-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(32093,'watch-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(32094,'watch-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(32095,'watch-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(32096,'watch-mobile','.w-promotions .prom-multi-discount','clear','both','4','','.w-promotions'),(32097,'watch-mobile','.w-wedding-registry-widgets-products .qty-input','clear','none','','','.w-wedding-registry-widgets-products'),(32098,'watch-mobile','.w-wedding-registry-widgets-search-form .button','clear','both','','','.w-wedding-registry-widgets-search-form'),(32099,'watch-mobile','.w-menu-big li','clear_important','important','','','.w-menu-big'),(32100,'watch-mobile','.w-menu-style-1 li','clear_important','important','','','.w-menu-style-1'),(32101,'watch-mobile','.b-slick .slick-slide','clear_important','important','','','.b-slick'),(32102,'watch-mobile','.w-menu-horizontal li','clear_important','important','','','.w-menu-horizontal'),(32103,'watch-mobile','.w-blog-widget-post-share ','clear_important','important','','','.w-blog-widget-post-share'),(32104,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip','rect(0 0 0 0)','','','.b-select-suggest'),(32105,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip_important','important','','','.b-select-suggest'),(32106,'watch-mobile','.w-menu .menu .menu-ico','color','inherit','','','.w-menu'),(32107,'watch-mobile','.w-menu-big a','color','inherit','','','.w-menu-big'),(32108,'watch-mobile','.w-bestsellers .item','color','$color-font-6','3','','.w-bestsellers'),(32109,'watch-mobile','.w-bestsellers .item:first-child .counter','color','$color-font-1','','','.w-bestsellers'),(32110,'watch-mobile','.w-bestsellers .counter','color','$color-font-6','','','.w-bestsellers'),(32111,'watch-mobile','.w-bestsellers .heading-3','color','$color-font-6','3','','.w-bestsellers'),(32112,'watch-mobile','.w-account .my-acc-link','color','$color-font-1','3','','.w-account'),(32113,'watch-mobile','a','color','inherit','','',''),(32114,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(32115,'watch-mobile','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','color','$color-font-1','','','.b-cookie-notice'),(32116,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','color','$color-font-2','','','.b-form'),(32117,'watch-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','color','$color-font-6','','','.b-form'),(32118,'watch-mobile','.w-sale .left-count-days-text','color','$color-font-1','','','.w-sale'),(32119,'watch-mobile','.w-product-sale-ends .ends','color','$attention-color','','','.w-product-sale-ends'),(32120,'watch-mobile','.w-sale .left-count-hours-text','color','$color-font-1','','','.w-sale'),(32121,'watch-mobile','.w-html_box .linkedin','color','$color-font-6','3','','.w-html_box'),(32122,'watch-mobile','.w-html_box .instagram','color','$color-font-9','3','','.w-html_box'),(32123,'watch-mobile','.w-html_box .stumbleupon','color','$attention-color','3','','.w-html_box'),(32124,'watch-mobile','.w-html_box .pinterest','color','$attention-color','3','','.w-html_box'),(32125,'watch-mobile','.w-html_box .twitter','color','$color-font-10','3','','.w-html_box'),(32126,'watch-mobile','.w-html_box .facebook','color','$color-font-6','3','','.w-html_box'),(32127,'watch-mobile','.w-sale .badge','color','$color-font-1','','','.w-sale'),(32128,'watch-mobile','.w-html_box .google-plus','color','$warning-color','3','','.w-html_box'),(32129,'watch-mobile','.w-menu-style-1 > ul','color','$color-font-1','','','.w-menu-style-1'),(32130,'watch-mobile','.w-menu-style-1 .menu-ico','color','$color-font-1','','','.w-menu-style-1'),(32131,'watch-mobile','.w-product-sale-ends .left-count-days-text','color','$color-font-1','','','.w-product-sale-ends'),(32132,'watch-mobile','.w-product-sale-ends .left-count-hours-text','color','$color-font-1','','','.w-product-sale-ends'),(32133,'watch-mobile','.w-cart .cart-box-link','color','$color-font-1','','','.w-cart'),(32134,'watch-mobile','.w-menu-horizontal a','color','inherit','','','.w-menu-horizontal'),(32135,'watch-mobile','.w-product-collection .save','color','$message-color','','','.w-product-collection'),(32140,'watch-mobile','.w-categories .name','color','$color-font-7','','','.w-categories'),(32141,'watch-mobile','.heading-3 .edit, h3 .edit','color','$color-font-6','','',''),(32142,'watch-mobile','.w-catalog-listing-look .list','color','$color-font-7','2','','.w-catalog-listing-look'),(32143,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','$color-font-7','','','.b-multi-page-checkout'),(32144,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','$color-font-8','','','.b-multi-page-checkout'),(32145,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','$color-font-6','4','','.b-multi-page-checkout'),(32146,'watch-mobile','.b-pass-strength span.strong-pass, .b-pass-strength span.pass-match','color','$message-color','','','.b-pass-strength'),(32147,'watch-mobile','.b-pass-strength span.bad-pass','color','$warning-color','','','.b-pass-strength'),(32148,'watch-mobile','.b-pass-strength .short-pass, .b-pass-strength .pass-strength, .b-pass-strength .pass-no-match','color','$attention-color','','','.b-pass-strength'),(32149,'watch-mobile','.b-pass-strength span.good-pass','color','$message-color','','','.b-pass-strength'),(32150,'watch-mobile','.w-reviews .date','color','$color-font-8','','','.w-reviews'),(32151,'watch-mobile','.w-quote .cart-box-link','color','$color-font-1','','','.w-quote'),(32152,'watch-mobile','.w-product-reviews .reviews-list .date','color','$color-font-8','','','.w-product-reviews'),(32153,'watch-mobile','.w-product-in-bundles .product-link','color','$color-font-7','','','.w-product-in-bundles'),(32154,'watch-mobile','.w-catalog-listing-look .list','color','$color-font-2','','','.w-catalog-listing-look'),(32155,'watch-mobile','.w-menu-slider > ul','color','$color-font-1','','','.w-menu-slider'),(32156,'watch-mobile','.w-catalog-listing-look .b2b','color','$color-font-2','','','.w-catalog-listing-look'),(32157,'watch-mobile','.p-blog-index .posted-on','color','$color-font-8','','','.p-blog-index'),(32158,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','$color-font-1','3','','.b-multi-page-checkout'),(32159,'watch-mobile','.p-blog-index .reply a','color','$color-font-6','','','.p-blog-index'),(32160,'watch-mobile','.p-blog-index .wp-widget li','color','$color-font-6','3','','.p-blog-index'),(32161,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','color','$color-font-2','','','.b-multi-page-checkout'),(32162,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading','color','$color-font-6','','','.b-multi-page-checkout'),(32163,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','color','$color-font-1','','','.b-multi-page-checkout'),(32164,'watch-mobile','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(32165,'watch-mobile','.p-wedding-registry-manage a.remove-btn','color','$color-font-7','1','','.p-wedding-registry-manage'),(32166,'watch-mobile','.p-wedding-registry-manage a.remove-btn','color','$color-font-8','','','.p-wedding-registry-manage'),(32167,'watch-mobile','.p-wedding-registry-share h1','color','$attention-color','4','','.p-wedding-registry-share'),(32168,'watch-mobile','.w-product-bonus-points > div > div','color','$color-font-6','','','.w-product-bonus-points'),(32171,'watch-mobile','.testimonials .date','color','$color-font-8','','',''),(32172,'watch-mobile','.testimonials .heading-3','color','$color-font-6','3','',''),(32173,'watch-mobile','.js-stock','color','$message-color','','',''),(32174,'watch-mobile','.testimonials .reviews-list .date','color','$color-font-8','','',''),(32175,'watch-mobile','.p-wedding-registry-manage .wr-search button','color','$color-font-6','3','','.p-wedding-registry-manage'),(32176,'watch-mobile','.b-pagination .pagination span','color','$color-font-1','2','','.b-pagination'),(32178,'watch-mobile','.p-blog-index .nav-next a','color','$color-font-8','3','','.p-blog-index'),(32179,'watch-mobile','.p-blog-index .nav-previous a','color','$color-font-8','3','','.p-blog-index'),(32180,'watch-mobile','.w-list-type-2_2 .sale','color','$attention-color','3','','.w-list-type-2_2'),(32181,'watch-mobile','.w-list-type-2_2 .price .specials','color','$attention-color','','','.w-list-type-2_2'),(32182,'watch-mobile','.w-list-type-2_2 .button-wishlist button','color','$color-font-6','','','.w-list-type-2_2'),(32183,'watch-mobile','.w-list-type-2_2 .button-view a','color','$color-font-6','','','.w-list-type-2_2'),(32184,'watch-mobile','.w-list-type-2 .sale','color','$attention-color','3','','.w-list-type-2'),(32185,'watch-mobile','.w-list-type-2 .price .specials','color','$attention-color','','','.w-list-type-2'),(32186,'watch-mobile','.p-reviews-info .review-info-text, .p-reviews-info .review-info-reviewed_by, .p-reviews-info .review-info-date','color','$color-font-7','','','.p-reviews-info'),(32187,'watch-mobile','.rating-1, .rating-2, .rating-3, .rating-4, .rating-5','color','$color-font-6','','',''),(32188,'watch-mobile','.w-chat .w-chat-box a','color','$color-font-1','3','','.w-chat'),(32189,'watch-mobile','.w-delivery-location-top-location-list .deliveryName a','color','$color-font-7','','','.w-delivery-location-top-location-list'),(32190,'watch-mobile','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(32191,'watch-mobile','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(32192,'watch-mobile','.p-wedding-registry-index .main-button','color','$color-font-6','4','','.p-wedding-registry-index'),(32193,'watch-mobile','.b-form .radio-button input[type=\"radio\"]:checked + span:before','color','$color-font-7','','','.b-form'),(32194,'watch-mobile','.p-wedding-registry-index .main-button','color','$color-font-6','3','','.p-wedding-registry-index'),(32195,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','color','$color-font-1','3','','.b-form'),(32196,'watch-mobile','.p-wedding-registry-manage .links a.share-registry','color','$color-font-6','4','','.p-wedding-registry-manage'),(32197,'watch-mobile','.p-wedding-registry-search h1','color','$attention-color','4','','.p-wedding-registry-search'),(32198,'watch-mobile','.p-wedding-registry-search h1','color','$attention-color','3','','.p-wedding-registry-search'),(32199,'watch-mobile','.p-wedding-registry-manage h1','color','$attention-color','4','','.p-wedding-registry-manage'),(32200,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','color','$color-font-1','','','.b-switch'),(32201,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','color','$color-font-1','','','.b-switch'),(32202,'watch-mobile','.b-fancybox .fancybox-title-outside-wrap','color','$color-font-1','','','.b-fancybox'),(32203,'watch-mobile','.w-tabs .accordion-heading','color','$color-font-6','2','','.w-tabs'),(32204,'watch-mobile','.w-list-type-1 .rating','color','$color-font-6','','','.w-list-type-1'),(32205,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','color','$color-font-2','','','.b-slick'),(32206,'watch-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','color','$color-font-6','','','.w-filters'),(32207,'watch-mobile','.w-filters .mobileCollapse','color','$color-font-1','4','','.w-filters'),(32209,'watch-mobile','.w-tabs .tab-a','color','$color-font-6','2','','.w-tabs'),(32210,'watch-mobile','.btn-1','color','$color-font-1','','',''),(32211,'watch-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','color','$color-font-2','','','.w-filters'),(32212,'watch-mobile','.w-currencies .select-link','color','$color-font-6','','','.w-currencies'),(32213,'watch-mobile','.w-filters .filter-box-head','color','$color-font-7','','','.w-filters'),(32214,'watch-mobile','.w-filters .head-filter-widget','color','$color-font-1','317','','.w-filters'),(32215,'watch-mobile','.w-currencies .current','color','$color-font-2','3','','.w-currencies'),(32216,'watch-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$color-font-2','3','','.w-contact-contacts'),(32217,'watch-mobile','.w-currencies .currencies-title','color','$color-font-6','','','.w-currencies'),(32218,'watch-mobile','.w-compare-box-item .checkbox:checked + span:before','color','$color-font-1','','','.w-compare-box-item'),(32219,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','color','$color-font-1','','','.b-fancybox'),(32221,'watch-mobile','.b-info .info a','color','$color-font-6','','','.b-info'),(32224,'watch-mobile','.w-menu-style-1 a','color','inherit','','','.w-menu-style-1'),(32225,'watch-mobile','.w-menu-mobile .menu-ico','color','$color-font-1','','','.w-menu-mobile'),(32226,'watch-mobile','.w-list-type-2_2 .sale','color','$color-font-1','4','','.w-list-type-2_2'),(32227,'watch-mobile','.b-fancybox .fancybox-title-over-wrap','color','$color-font-1','','','.b-fancybox'),(32230,'watch-mobile','.w-product-quantity .qty_packs .price_1','color','$color-font-2','4','','.w-product-quantity'),(32232,'watch-mobile','.b-fancybox .fancybox-skin','color','$color-font-7','','','.b-fancybox'),(32233,'watch-mobile','.b-form .inputRequirement','color','$attention-color','','','.b-form'),(32235,'watch-mobile','.w-sale .ends','color','$attention-color','','','.w-sale'),(32236,'watch-mobile','.w-sale .special-price','color','$attention-color','','','.w-sale'),(32237,'watch-mobile','.p-wedding-registry-share .invite-remove','color','$attention-color','','','.p-wedding-registry-share'),(32238,'watch-mobile','.w-menu-slider .menu-ico','color','$color-font-1','','','.w-menu-slider'),(32241,'watch-mobile','.w-text .customer-service','color','$color-font-6','3','','.w-text'),(32242,'watch-mobile','.w-text .customer-service b','color','$color-font-6','','','.w-text'),(32243,'watch-mobile','.w-top-categories .categories h2','color','inherit','','','.w-top-categories'),(32244,'watch-mobile','.w-categories .categories h2','color','inherit','','','.w-categories'),(32245,'watch-mobile','.b-rating #stars-default .glyphicon.coloron','color','$color-font-6','','','.b-rating'),(32246,'watch-mobile','.b-rating #stars-default .glyphicon','color','$color-font-2','','','.b-rating'),(32247,'watch-mobile','.b-quantity .qty-box .smaller','color','$color-font-6','','','.b-quantity'),(32248,'watch-mobile','.b-quantity .qty-box .bigger','color','$color-font-6','','','.b-quantity'),(32249,'watch-mobile','.b-fancybox .fancybox-nav span','color','$color-font-1','','','.b-fancybox'),(32250,'watch-mobile','.w-top-categories .name','color','$color-font-7','','','.w-top-categories'),(32251,'watch-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','color','$color-font-6','3','','.w-cart-discount-coupon'),(32253,'watch-mobile','.w-catalog-listing-look .grid','color','$color-font-7','2','','.w-catalog-listing-look'),(32254,'watch-mobile','.w-list-type-1_3 .price .specials','color','$attention-color','','','.w-list-type-1_3'),(32256,'watch-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','color','$color-font-6','3','','.w-cart-gift-certificate'),(32257,'watch-mobile','.w-catalog-listing-look .grid','color','$color-font-2','','','.w-catalog-listing-look'),(32259,'watch-mobile','.w-catalog-listing-look .b2b','color','$color-font-7','2','','.w-catalog-listing-look'),(32260,'watch-mobile','.price .specials','color','$attention-color','','',''),(32261,'watch-mobile','.w-list-type-2 .button-view a','color','$color-font-6','','','.w-list-type-2'),(32262,'watch-mobile','.w-list-type-1_3 .sale','color','$color-font-1','4','','.w-list-type-1_3'),(32263,'watch-mobile','.w-list-type-1_3 .sale','color','$attention-color','3','','.w-list-type-1_3'),(32264,'watch-mobile','.p-wedding-registry-view h1','color','$attention-color','4','','.p-wedding-registry-view'),(32265,'watch-mobile','.w-list-type-2 .button-wishlist button','color','$color-font-6','','','.w-list-type-2'),(32266,'watch-mobile','.price .special','color','$attention-color','','',''),(32267,'watch-mobile','.p-wedding-registry-manage h1','color','$attention-color','3','','.p-wedding-registry-manage'),(32268,'watch-mobile','.p-wedding-registry-share h1','color','$attention-color','3','','.p-wedding-registry-share'),(32269,'watch-mobile','.p-wedding-registry-view h1','color','$attention-color','3','','.p-wedding-registry-view'),(32270,'watch-mobile','.w-list-type-2 .sale','color','$color-font-1','4','','.w-list-type-2'),(32271,'watch-mobile','.btn-3','color','$color-font-6','','',''),(32272,'watch-mobile','.btn-2','color','$color-font-1','','',''),(32273,'watch-mobile','.btn','color','$color-font-6','','',''),(32274,'watch-mobile','.w-list-type-1_3 .button-wishlist button','color','$color-font-6','','','.w-list-type-1_3'),(32275,'watch-mobile','.w-list-type-1_3 .button-view a','color','$color-font-6','','','.w-list-type-1_3'),(32276,'watch-mobile','.w-list-type-1_2 .sale','color','$color-font-1','4','','.w-list-type-1_2'),(32277,'watch-mobile','.w-list-type-1_2 .price .specials','color','$attention-color','','','.w-list-type-1_2'),(32278,'watch-mobile','.w-list-type-1_2 .sale','color','$attention-color','3','','.w-list-type-1_2'),(32279,'watch-mobile','.b-bottom .pop-up-close','color','$color-font-8','','','.b-bottom'),(32280,'watch-mobile','.w-list-type-1_2 .button-wishlist button','color','$color-font-6','','','.w-list-type-1_2'),(32281,'watch-mobile','.b-bottom .pop-up-close','color','$color-font-8','1','','.b-bottom'),(32282,'watch-mobile','.w-list-type-1 .sale','color','$color-font-1','4','','.w-list-type-1'),(32283,'watch-mobile','.w-list-type-1 .sale','color','$attention-color','3','','.w-list-type-1'),(32284,'watch-mobile','.w-list-type-1_2 .button-view a','color','$color-font-6','','','.w-list-type-1_2'),(32285,'watch-mobile','.heading-4 .edit, h4 .edit','color','$color-font-6','','',''),(32286,'watch-mobile','.w-list-type-1 .button-wishlist button','color','$color-font-6','','','.w-list-type-1'),(32287,'watch-mobile','.w-filters .open','color','$color-font-6','3','','.w-filters'),(32288,'watch-mobile','.in-stock','color','$message-color','','',''),(32289,'watch-mobile','.out-stock','color','$attention-color','','',''),(32290,'watch-mobile','.transit','color','$color-font-9','','',''),(32291,'watch-mobile','.w-filters .view_more','color','$color-font-6','','','.w-filters'),(32292,'watch-mobile','.w-list-type-1 .button-view a','color','$color-font-6','','','.w-list-type-1'),(32293,'watch-mobile','.w-languages .current','color','$color-font-2','3','','.w-languages'),(32295,'watch-mobile','.w-reviews .reviews-list .date','color','$color-font-8','','','.w-reviews'),(32296,'watch-mobile','.w-reviews .heading-3','color','$color-font-6','3','','.w-reviews'),(32297,'watch-mobile','.w-search .button-search','color','$color-font-6','3','','.w-search'),(32298,'watch-mobile','.w-socials .post_item > div.fb_post_item','color','$color-font-6','3','','.w-socials'),(32299,'watch-mobile','.w-socials .post_item > div.tw_post_item','color','$color-font-10','3','','.w-socials'),(32300,'watch-mobile','.w-socials .post_item_name a','color','$color-font-7','','','.w-socials'),(32301,'watch-mobile','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(32302,'watch-mobile','.btn-del','color','$attention-color','4','',''),(32303,'watch-mobile','.b-form .required','color','$attention-color','','','.b-form'),(32304,'watch-mobile','.b-form .required-message','color','$attention-color','','','.b-form'),(32305,'watch-mobile','.b-form .middle-form label','color','$color-font-7','','','.b-form'),(32309,'watch-mobile','.b-info .info','color','$attention-color','','','.b-info'),(32310,'watch-mobile','.b-info-popup .info-popup','color','$attention-color','3','','.b-info-popup'),(32311,'watch-mobile','.b-products-listing .products-listing .bonus-points span:first-child','color','$color-font-6','','','.b-products-listing'),(32312,'watch-mobile','.b-products-listing .products-listing .bonus-points-cost','color','$color-font-6','3','','.b-products-listing'),(32313,'watch-mobile','.b-products-listing .products-listing .bonus-points-price','color','$color-font-6','3','','.b-products-listing'),(32314,'watch-mobile','.b-products-listing .products-listing .name a','color','$color-font-7','','','.b-products-listing'),(32315,'watch-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','color','$message-color','','','.b-products-listing'),(32316,'watch-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','color','$message-color','','','.b-products-listing'),(32317,'watch-mobile','.b-products-listing .products-listing h2','color','inherit','','','.b-products-listing'),(32318,'watch-mobile','.b-products-listing .promos-info .promo-name','color','$attention-color','','','.b-products-listing'),(32319,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','$color-font-7','','','.b-data-table'),(32320,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','$color-font-6','','','.b-data-table'),(32321,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','$color-font-6','1','','.b-data-table'),(32322,'watch-mobile','.b-delete-account .delete-box .delete-message','color','$attention-color','','','.b-delete-account'),(32323,'watch-mobile','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(32324,'watch-mobile','.b-email-editor .name a','color','$color-font-7','','','.b-email-editor'),(32325,'watch-mobile','.b-email-editor a','color','$color-font-7','','','.b-email-editor'),(32326,'watch-mobile','.b-email-editor .name a','color','$color-font-7','','','.b-email-editor'),(32327,'watch-mobile','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(32328,'watch-mobile','.b-email-editor .price','color','$color-font-6','','','.b-email-editor'),(32329,'watch-mobile','.b-email-editor .price','color','$color-font-6','','','.b-email-editor'),(32330,'watch-mobile','.b-email-editor .price','color','$color-font-6','','','.b-email-editor'),(32331,'watch-mobile','.b-email-editor a','color','$color-font-7','','','.b-email-editor'),(32332,'watch-mobile','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(32333,'watch-mobile','.b-email-editor .name a','color','$color-font-7','','','.b-email-editor'),(32334,'watch-mobile','.b-email-editor .price','color','$color-font-6','','','.b-email-editor'),(32335,'watch-mobile','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(32336,'watch-mobile','.b-email-editor .name a','color','$color-font-7','','','.b-email-editor'),(32337,'watch-mobile','.b-email-editor .name a','color','$color-font-7','','','.b-email-editor'),(32338,'watch-mobile','.b-email-editor a','color','$color-font-7','','','.b-email-editor'),(32339,'watch-mobile','.b-email-editor a','color','$color-font-7','','','.b-email-editor'),(32340,'watch-mobile','.b-email-editor .name a','color','$color-font-7','','','.b-email-editor'),(32341,'watch-mobile','.b-email-editor a','color','$color-font-7','','','.b-email-editor'),(32342,'watch-mobile','.b-email-editor a','color','$color-font-7','','','.b-email-editor'),(32343,'watch-mobile','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(32344,'watch-mobile','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(32345,'watch-mobile','.b-email-editor .price','color','$color-font-6','','','.b-email-editor'),(32346,'watch-mobile','.b-email-editor .price','color','$color-font-6','','','.b-email-editor'),(32347,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2','color','$color-font-7','','','.b-menu-style-1'),(32348,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','color','$color-font-6','','','.b-menu-style-1'),(32349,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','color','$color-font-1','','','.b-menu-style-2'),(32350,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','color','$color-font-1','','','.b-menu-style-2'),(32351,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','color','$color-font-6','','','.b-menu-style-2'),(32352,'watch-mobile','.b-messages .messMenuButton span','color','$color-font-6','','','.b-messages'),(32353,'watch-mobile','.b-messages .messages-menu li a','color','$color-font-7','','','.b-messages'),(32354,'watch-mobile','.b-messages .content_management_attach','color','$color-font-6','','','.b-messages'),(32355,'watch-mobile','.b-messages .content_management_attach button','color','$color-font-6','','','.b-messages'),(32356,'watch-mobile','.b-messages .select2-search-choice-close','color','$color-font-8','3','','.b-messages'),(32357,'watch-mobile','.b-personal-catalog-popup #personal_catalog_popup .show-all-lists','color','$color-font-6','','','.b-personal-catalog-popup'),(32358,'watch-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','color','$color-font-7','','','.b-select-suggest'),(32359,'watch-mobile','.b-select-suggest .select2-drop','color','$color-font-7','','','.b-select-suggest'),(32360,'watch-mobile','.b-select-suggest .select2-container .select2-choice','color','$color-font-7','','','.b-select-suggest'),(32361,'watch-mobile','.b-select-suggest .select2-results .select2-highlighted','color','$color-font-7','','','.b-select-suggest'),(32362,'watch-mobile','.b-select-suggest .select2-results .select2-highlighted ul','color','$color-font-7','','','.b-select-suggest'),(32363,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','color','$color-font-7','','','.b-select-suggest'),(32364,'watch-mobile','.b-select-suggest .select2-default','color','$color-font-8','','','.b-select-suggest'),(32365,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','color','$color-font-7','','','.b-select-suggest'),(32366,'watch-mobile','.b-trade-approval .steps-bar li.current a','color','$color-font-1','','','.b-trade-approval'),(32367,'watch-mobile','.b-trade-approval .middle-form label','color','$color-font-7','','','.b-trade-approval'),(32368,'watch-mobile','.b-upload-file .snapshot','color','$color-font-8','','','.b-upload-file'),(32369,'watch-mobile','.b-upload-files .remove-file','color','$attention-color','3','','.b-upload-files'),(32370,'watch-mobile','.b-warehouses-popup a.warehouses-popup-link','color','$color-font-7','','','.b-warehouses-popup'),(32371,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','color','$attention-color','','','.b-warehouses-popup'),(32372,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','color','$message-color','','','.b-warehouses-popup'),(32373,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','color','$color-font-6','','','.b-warehouses-popup'),(32374,'watch-mobile','.batchPr .checkbox input:checked + span:before','color','$color-font-1','','','.batchPr'),(32375,'watch-mobile','.batchPr .btn-batch-remove','color','$color-font-1','','','.batchPr'),(32376,'watch-mobile','.bell-ico .heading-2','color','$color-font-6','3','','.bell-ico'),(32377,'watch-mobile','.heading-ordered-items .heading-4','color','$color-font-6','3','','.heading-ordered-items'),(32378,'watch-mobile','.heading-saved-lists .heading-4','color','$color-font-6','3','','.heading-saved-lists'),(32379,'watch-mobile','.heading-settings .heading-4','color','$color-font-6','3','','.heading-settings'),(32410,'watch-mobile','.p-account-update .main-text a','color','$color-font-6','','','.p-account-update'),(32411,'watch-mobile','.p-account-update .main-text a','color','$color-font-6','','','.p-account-update'),(32412,'watch-mobile','.p-account-update .main-text a','color','$color-font-6','','','.p-account-update'),(32413,'watch-mobile','.p-account-update .main-text a','color','$color-font-6','','','.p-account-update'),(32414,'watch-mobile','.p-account-update .main-text a','color','$color-font-6','','','.p-account-update'),(32415,'watch-mobile','.p-account-update .main-text a','color','$color-font-6','','','.p-account-update'),(32418,'watch-mobile','.p-payer-order-confirmation .discount-ico','color','$color-font-6','3','','.p-payer-order-confirmation'),(32419,'watch-mobile','.p-payer-order-confirmation .ship-ico','color','$color-font-6','3','','.p-payer-order-confirmation'),(32420,'watch-mobile','.p-payer-order-confirmation .comment-ico','color','$color-font-6','3','','.p-payer-order-confirmation'),(32421,'watch-mobile','.p-payer-order-confirmation .order-ico','color','$color-font-6','3','','.p-payer-order-confirmation'),(32422,'watch-mobile','.p-payer-order-confirmation .pay-ico','color','$color-font-6','3','','.p-payer-order-confirmation'),(32423,'watch-mobile','.p-payer-order-pay .ship-ico','color','$color-font-6','3','','.p-payer-order-pay'),(32424,'watch-mobile','.p-payer-order-pay .pay-ico','color','$color-font-6','3','','.p-payer-order-pay'),(32425,'watch-mobile','.p-payer-order-pay .comment-ico','color','$color-font-6','3','','.p-payer-order-pay'),(32426,'watch-mobile','.p-payer-order-pay .order-ico','color','$color-font-6','3','','.p-payer-order-pay'),(32427,'watch-mobile','.p-payer-order-pay .discount-ico','color','$color-font-6','3','','.p-payer-order-pay'),(32428,'watch-mobile','.p-quick-order-index .all-scroll-div','color','$color-font-1','','','.p-quick-order-index'),(32429,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','$color-font-6','1','','.p-quick-order-index'),(32430,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','$color-font-6','','','.p-quick-order-index'),(32431,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','$color-font-7','','','.p-quick-order-index'),(32432,'watch-mobile','.p-quote-checkout-success .page-success .text-1','color','$color-font-6','3','','.p-quote-checkout-success'),(32433,'watch-mobile','.p-quote-checkout-success .page-success .text-1','color','$color-font-6','3','','.p-quote-checkout-success'),(32434,'watch-mobile','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(32435,'watch-mobile','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(32436,'watch-mobile','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(32437,'watch-mobile','.p-quote-checkout-success .page-success .text-1','color','$color-font-6','3','','.p-quote-checkout-success'),(32438,'watch-mobile','.p-quote-checkout-success .page-success .text-1','color','$color-font-6','3','','.p-quote-checkout-success'),(32439,'watch-mobile','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(32440,'watch-mobile','.p-quote-checkout-success .page-success .text-1','color','$color-font-6','3','','.p-quote-checkout-success'),(32441,'watch-mobile','.p-quote-checkout-success .page-success .text-1','color','$color-font-6','3','','.p-quote-checkout-success'),(32442,'watch-mobile','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(32443,'watch-mobile','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(32444,'watch-mobile','.p-sample-checkout-success .page-success .text-3','color','$attention-color','','','.p-sample-checkout-success'),(32445,'watch-mobile','.p-sample-checkout-success .page-success .text-1','color','$color-font-6','3','','.p-sample-checkout-success'),(32446,'watch-mobile','.savings-ico .heading-2','color','$message-color','3','','.savings-ico'),(32447,'watch-mobile','.shipping-ico .heading-2','color','$color-font-6','3','','.shipping-ico'),(32448,'watch-mobile','.shipping-ico .heading-2','color','$message-color','3','','.shipping-ico'),(32449,'watch-mobile','.shipping-ico .heading-2','color','$message-color','3','','.shipping-ico'),(32450,'watch-mobile','.w-account-address-book .add_item a.disabled-link','color','$color-font-2','','','.w-account-address-book'),(32451,'watch-mobile','.w-account-address-book .add_item a','color','$color-font-2','','','.w-account-address-book'),(32452,'watch-mobile','.w-account-personal-catalog .list-switcher a','color','$color-font-6','2','','.w-account-personal-catalog'),(32453,'watch-mobile','.w-blog-widget-categories-list a','color','$color-font-7','','','.w-blog-widget-categories-list'),(32454,'watch-mobile','.w-blog-widget-most-popular-posts a','color','$color-font-7','','','.w-blog-widget-most-popular-posts'),(32455,'watch-mobile','.w-blog-widget-post-comments-count span','color','$color-font-9','3','','.w-blog-widget-post-comments-count'),(32456,'watch-mobile','.w-blog-widget-post-date ','color','$color-font-7','','','.w-blog-widget-post-date'),(32457,'watch-mobile','.w-blog-widget-post-listing .post_comment','color','$color-font-9','3','','.w-blog-widget-post-listing'),(32458,'watch-mobile','.w-blog-widget-post-listing .post_tagged a','color','$color-font-7','','','.w-blog-widget-post-listing'),(32459,'watch-mobile','.w-blog-widget-post-listing .post_name a','color','$color-font-7','','','.w-blog-widget-post-listing'),(32460,'watch-mobile','.w-blog-widget-post-share .facebook-btn','color','$color-font-7','3','','.w-blog-widget-post-share'),(32461,'watch-mobile','.w-blog-widget-post-share .pinterest-btn','color','$color-font-7','3','','.w-blog-widget-post-share'),(32462,'watch-mobile','.w-blog-widget-post-share .twitter-btn','color','$color-font-7','3','','.w-blog-widget-post-share'),(32463,'watch-mobile','.w-blog-widget-post-share .printto','color','$color-font-9','3','','.w-blog-widget-post-share'),(32464,'watch-mobile','.w-blog-widget-post-share .mailto','color','$color-font-9','3','','.w-blog-widget-post-share'),(32465,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','color','$color-font-7','3','','.w-blog-widget-related-posts'),(32466,'watch-mobile','.w-blog-widget-related-posts .post_content a','color','$color-font-9','','','.w-blog-widget-related-posts'),(32467,'watch-mobile','.w-blog-widget-related-posts-by-category .post_content a','color','$color-font-7','','','.w-blog-widget-related-posts-by-category'),(32468,'watch-mobile','.w-blog-widget-tag-cloud a','color','$color-font-7','','','.w-blog-widget-tag-cloud'),(32469,'watch-mobile','.w-cart-bonus-points .title','color','$message-color','3','','.w-cart-bonus-points'),(32470,'watch-mobile','.w-cart-compare .product .name a','color','$color-font-7','','','.w-cart-compare'),(32471,'watch-mobile','.w-cart-compare .cart-name a','color','$color-font-7','','','.w-cart-compare'),(32472,'watch-mobile','.w-cart-compare .delete-cart','color','$color-font-7','3','','.w-cart-compare'),(32473,'watch-mobile','.w-cart-compare .product-actions .dropdown-toggle','color','$color-font-8','','','.w-cart-compare'),(32474,'watch-mobile','.w-cart-credit-amount .amount-title','color','$message-color','3','','.w-cart-credit-amount'),(32475,'watch-mobile','.w-cart-credit-amount #credit_modules_message.error','color','$attention-color','','','.w-cart-credit-amount'),(32476,'watch-mobile','.w-cart-credit-amount #credit_modules_message','color','$message-color','','','.w-cart-credit-amount'),(32477,'watch-mobile','.w-catalog-b2b-add-button ','color','$color-font-1','','','.w-catalog-b2b-add-button'),(32478,'watch-mobile','.w-catalog-compare .checkbox input:checked + span:before','color','$color-font-8','','','.w-catalog-compare'),(32479,'watch-mobile','.w-catalog-compare span.btn-preloader','color','$color-font-6','3','','.w-catalog-compare'),(32480,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','color','$color-font-6','2','','.w-catalog-compare'),(32481,'watch-mobile','.w-catalog-compare .cross-box .return','color','$color-font-6','','','.w-catalog-compare'),(32482,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','color','$color-font-6','3','','.w-catalog-compare'),(32483,'watch-mobile','.w-catalog-paging ','color','$color-font-1','2','','.w-catalog-paging'),(32484,'watch-mobile','.w-checkout-shipping-choice span','color','$color-font-6','','','.w-checkout-shipping-choice'),(32485,'watch-mobile','.w-checkout-shipping-choice input:checked + span','color','$color-font-1','','','.w-checkout-shipping-choice'),(32486,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','color','$color-font-7','','','.w-communication-new-topic'),(32487,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','color','$color-font-7','','','.w-communication-new-topic'),(32488,'watch-mobile','.w-coupons-and-vauchers-checkout #credit_modules_message.error','color','$attention-color','','','.w-coupons-and-vauchers-checkout'),(32489,'watch-mobile','.w-coupons-and-vauchers-checkout #credit_modules_message','color','$message-color','','','.w-coupons-and-vauchers-checkout'),(32490,'watch-mobile','.w-delivery-day .ends','color','$attention-color','','','.w-delivery-day'),(32491,'watch-mobile','.w-delivery-day .left-count-days-text, .w-delivery-day .left-count-hours-text, .w-delivery-day .left-count-minutes-text, .w-delivery-day .left-count-seconds-text','color','$color-font-1','','','.w-delivery-day'),(32492,'watch-mobile','.w-image-maps .float-items .item .description','color','$color-font-7','','','.w-image-maps'),(32493,'watch-mobile','.w-image-maps .categories-items .item .description','color','$color-font-7','','','.w-image-maps'),(32494,'watch-mobile','.w-image-maps .default-links .item .description','color','$color-font-7','','','.w-image-maps'),(32495,'watch-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','color','$color-font-8','3','','.w-multi-cart-actions'),(32496,'watch-mobile','.w-personal-gift-status-bar .end-date','color','$color-font-6','3','','.w-personal-gift-status-bar'),(32497,'watch-mobile','.w-personal-gift-status-bar .end-label','color','$color-font-6','','','.w-personal-gift-status-bar'),(32498,'watch-mobile','.w-personal-gift-status-bar .inform','color','$color-font-6','4','','.w-personal-gift-status-bar'),(32499,'watch-mobile','.w-personal-gift-status-bar .start-label','color','$color-font-6','','','.w-personal-gift-status-bar'),(32500,'watch-mobile','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(32501,'watch-mobile','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(32502,'watch-mobile','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(32503,'watch-mobile','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(32504,'watch-mobile','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(32505,'watch-mobile','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(32506,'watch-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','color','$warning-color','3','','.w-promotions'),(32507,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','color','$attention-color','','','.w-promotions'),(32508,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','color','$attention-color','','','.w-promotions'),(32509,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','color','$attention-color','','','.w-promotions'),(32510,'watch-mobile','.w-promotions .promo-salemaker .discount','color','$warning-color','','','.w-promotions'),(32511,'watch-mobile','.w-promotions .promo-cart-discount .item a','color','$color-font-7','','','.w-promotions'),(32512,'watch-mobile','.w-promotions .promo-salemaker .content a','color','$color-font-7','','','.w-promotions'),(32513,'watch-mobile','.w-promotions .specials_category .heading-3','color','$warning-color','','','.w-promotions'),(32514,'watch-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .specials_category .promo-conditions','color','$warning-color','3','','.w-promotions'),(32515,'watch-mobile','.w-promotions .specials_category .promo-salemaker .content a, .w-promotions .specials_category .promo-date','color','$warning-color','3','','.w-promotions'),(32516,'watch-mobile','.w-promotions .cart_discount .heading-3','color','$warning-color','','','.w-promotions'),(32517,'watch-mobile','.w-promotions .cart_discount .promo-date','color','$warning-color','3','','.w-promotions'),(32518,'watch-mobile','.w-promotions .prom-multi-discount .promo-range, .w-promotions .prom-multi-discount > .heading','color','$attention-color','3','','.w-promotions'),(32519,'watch-mobile','.w-promotions .multidiscount .promo-date, .w-promotions .multidiscount .heading-3','color','$attention-color','','','.w-promotions'),(32520,'watch-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','color','$color-font-7','','','.w-promotions'),(32521,'watch-mobile','.w-reviews-content .date','color','$color-font-2','','','.w-reviews-content'),(32522,'watch-mobile','.w-reviews-content .product-name a','color','$color-font-6','','','.w-reviews-content'),(32523,'watch-mobile','.w-social-links .google-plus','color','$attention-color','3','','.w-social-links'),(32524,'watch-mobile','.w-social-links .twitter','color','$color-font-10','3','','.w-social-links'),(32525,'watch-mobile','.w-social-links .stumbleupon','color','$attention-color','3','','.w-social-links'),(32526,'watch-mobile','.w-social-links .facebook','color','$color-font-6','3','','.w-social-links'),(32527,'watch-mobile','.w-social-links .linkedin','color','$color-font-6','3','','.w-social-links'),(32528,'watch-mobile','.w-social-links .instagram','color','$attention-color','3','','.w-social-links'),(32529,'watch-mobile','.w-social-links .pinterest','color','$attention-color','3','','.w-social-links'),(32530,'watch-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','color','$color-font-1','','','.w-taxable'),(32531,'watch-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','color','$color-font-1','','','.w-taxable'),(32532,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','color','$attention-color','','','.w-upload-customer-id-upload-customer-id-form'),(32533,'watch-mobile','.w-wedding-registry-widgets-delete-link a','color','$color-font-2','4','','.w-wedding-registry-widgets-delete-link'),(32534,'watch-mobile','.w-wedding-registry-widgets-manage-names .names-separator','color','$attention-color','','','.w-wedding-registry-widgets-manage-names'),(32535,'watch-mobile','.w-wedding-registry-widgets-products .remove-btn','color','$color-font-8','3','','.w-wedding-registry-widgets-products'),(32536,'watch-mobile','.w-wedding-registry-widgets-share-link a','color','$color-font-2','4','','.w-wedding-registry-widgets-share-link'),(32537,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','color','$color-font-2','','','.w-filters'),(32538,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','color','$color-font-7','','','.w-filters'),(32539,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.b-data-table'),(32540,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.b-data-table'),(32541,'watch-mobile','.b-select-suggest .select2-default','color_important','important','','','.b-select-suggest'),(32542,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.p-quick-order-index'),(32543,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.p-quick-order-index'),(32544,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','column-count','4','','','.b-menu-style-1'),(32545,'watch-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','content','\\f067','3','','.w-menu'),(32546,'watch-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','content','\\f068','3','','.w-menu'),(32547,'watch-mobile','.w-menu .menu .menu-ico','content','\\e91b','3','','.w-menu'),(32548,'watch-mobile','.w-menu-slider .close','content','\\f00d','3','','.w-menu-slider'),(32549,'watch-mobile','.w-bestsellers .item:first-child:before','content','\\e90c','','','.w-bestsellers'),(32550,'watch-mobile','.w-bestsellers .heading-3','content','\\e903','3','','.w-bestsellers'),(32551,'watch-mobile','.w-bestsellers .item','content','\\e90b','3','','.w-bestsellers'),(32552,'watch-mobile','.w-account .my-acc-link','content','\\f007','3','','.w-account'),(32553,'watch-mobile','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(32554,'watch-mobile','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(32555,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','content','\\f1db','','','.b-form'),(32556,'watch-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','content','\\f058','','','.b-form'),(32557,'watch-mobile','.w-login-block .cols','content','\\_','4','','.w-login-block'),(32558,'watch-mobile','.w-list-type-2_2 .sale','content','SALE','4','','.w-list-type-2_2'),(32559,'watch-mobile','.w-html_box .stumbleupon','content','\\f1a4','3','','.w-html_box'),(32560,'watch-mobile','.w-html_box .twitter','content','\\f099','3','','.w-html_box'),(32561,'watch-mobile','.w-html_box .linkedin','content','\\f0e1','3','','.w-html_box'),(32562,'watch-mobile','.w-html_box .instagram','content','\\f16d','3','','.w-html_box'),(32563,'watch-mobile','.w-html_box .pinterest','content','\\f0d2','3','','.w-html_box'),(32564,'watch-mobile','.w-html_box .facebook','content','\\f230','3','','.w-html_box'),(32565,'watch-mobile','.w-html_box .google-plus','content','\\f2b3','3','','.w-html_box'),(32566,'watch-mobile','.w-product-attributes .attributes','content','\\_','4','','.w-product-attributes'),(32567,'watch-mobile','.w-product-wedding-registry-button .btn','content','\\_','3','','.w-product-wedding-registry-button'),(32568,'watch-mobile','.w-cart a.item','content','\\_','4','','.w-cart'),(32569,'watch-mobile','.w-cart .cart-box-link','content','\\e90d','3','','.w-cart'),(32570,'watch-mobile','.w-cart .qty','content','\\274c','4','','.w-cart'),(32571,'watch-mobile','.w-categories .categories','content','\\_','4','','.w-categories'),(32572,'watch-mobile','.w-catalog-listing-look .list','content','\\f00b','3','','.w-catalog-listing-look'),(32573,'watch-mobile','.b-pagination .pagination .prev','content','\\f104','3','','.b-pagination'),(32574,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','content','\\e917','4','','.b-multi-page-checkout'),(32575,'watch-mobile','.b-pagination .pagination','content','\\_','4','','.b-pagination'),(32576,'watch-mobile','.b-pagination .pagination .next','content','\\f105','3','','.b-pagination'),(32577,'watch-mobile','.w-quote .cart-box-link','content','\\e90d','3','','.w-quote'),(32578,'watch-mobile','.b-product-images .main-image-box','content','\\_','4','','.b-product-images'),(32580,'watch-mobile','.w-cart-shipping-estimator .shipping-estimator','content','\\_','4','','.w-cart-shipping-estimator'),(32581,'watch-mobile','.w-list-type-2_2 .sale','content','\\e909','3','','.w-list-type-2_2'),(32582,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','content','\\f00c','3','','.b-multi-page-checkout'),(32583,'watch-mobile','.p-blog-index .nav-previous a','content','\\f137','3','','.p-blog-index'),(32584,'watch-mobile','.p-blog-index .wp-widget li','content','\\f111','3','','.p-blog-index'),(32585,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','content','\\_','4','','.b-multi-page-checkout'),(32587,'watch-mobile','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(32588,'watch-mobile','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(32589,'watch-mobile','.p-wedding-registry-manage .remove-btn','content','\\e913','3','','.p-wedding-registry-manage'),(32590,'watch-mobile','.p-wedding-registry-view h1','content','\\f004','4','','.p-wedding-registry-view'),(32591,'watch-mobile','.w-product-bonus-points > div','content','\\_','4','','.w-product-bonus-points'),(32592,'watch-mobile','.p-wedding-registry-view h1','content','\\f004','3','','.p-wedding-registry-view'),(32596,'watch-mobile','.js-stock-icon','content','\\f058','3','',''),(32597,'watch-mobile','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(32598,'watch-mobile','.testimonials .heading-3','content','\\e908','3','',''),(32599,'watch-mobile','.testimonials .review','content','\\_','3','',''),(32600,'watch-mobile','.p-wedding-registry-manage .wr-search button','content','\\e90a','3','','.p-wedding-registry-manage'),(32602,'watch-mobile','.p-blog-index .nav-next a','content','\\f138','3','','.p-blog-index'),(32603,'watch-mobile','.p-blog-index .entry-content','content','\\_','4','','.p-blog-index'),(32604,'watch-mobile','.p-blog-index .comment-meta','content','\\_','4','','.p-blog-index'),(32605,'watch-mobile','.w-list-type-2_2 .item','content','\\_','4','','.w-list-type-2_2'),(32606,'watch-mobile','.out-stock-icon','content','\\f10c','3','',''),(32607,'watch-mobile','.w-list-type-2_2 .button-wishlist button','content','\\e98e','4','','.w-list-type-2_2'),(32608,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-2_2'),(32609,'watch-mobile','.buttons','content','\\_','4','',''),(32610,'watch-mobile','.w-list-type-2_2 .button-view a','content','\\e98f','4','','.w-list-type-2_2'),(32611,'watch-mobile','.w-list-type-2_2 .add-height','content','\\_','4','','.w-list-type-2_2'),(32612,'watch-mobile','.w-product-personal-catalog-button .btn','content','\\f097','3','','.w-product-personal-catalog-button'),(32613,'watch-mobile','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(32614,'watch-mobile','.w-product-wedding-registry-button .btn','content','\\_','4','','.w-product-wedding-registry-button'),(32615,'watch-mobile','.w-product-bonus-points > div > div','content','\\f219','3','','.w-product-bonus-points'),(32616,'watch-mobile','.w-chat .w-chat-box a','content','\\f075','3','','.w-chat'),(32617,'watch-mobile','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(32618,'watch-mobile','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(32619,'watch-mobile','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(32620,'watch-mobile','.p-wedding-registry-index .search-list','content','\\_','3','','.p-wedding-registry-index'),(32621,'watch-mobile','.p-wedding-registry-index .main-button','content','\\f004','4','','.p-wedding-registry-index'),(32622,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','content','\\f00c','3','','.b-form'),(32623,'watch-mobile','.p-wedding-registry-index .main-button','content','\\f004','3','','.p-wedding-registry-index'),(32624,'watch-mobile','.p-wedding-registry-search h1','content','\\f004','4','','.p-wedding-registry-search'),(32625,'watch-mobile','.p-wedding-registry-manage .links a.share-registry','content','\\f14d','4','','.p-wedding-registry-manage'),(32626,'watch-mobile','.p-wedding-registry-search h1','content','\\f004','3','','.p-wedding-registry-search'),(32627,'watch-mobile','.p-wedding-registry-manage h1','content','\\f004','3','','.p-wedding-registry-manage'),(32628,'watch-mobile','.p-wedding-registry-manage h1','content','\\f004','4','','.p-wedding-registry-manage'),(32630,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','content',' ','3','','.b-switch'),(32631,'watch-mobile','.b-compare .clear_all','content','\\f00d','4','','.b-compare'),(32632,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','content',' ','3','','.b-switch'),(32633,'watch-mobile','.b-slick button.slick-prev','content','\\f053','3','','.b-slick'),(32634,'watch-mobile','.b-bottom .footerTitle','content','\\f067','290,4','','.b-bottom'),(32635,'watch-mobile','.b-slick button.slick-next','content','\\f054','3','','.b-slick'),(32636,'watch-mobile','.heading-3 .edit, h3 .edit','content','\\e917','4','',''),(32637,'watch-mobile','.w-list-type-1 .button-view a','content','\\e98f','4','','.w-list-type-1'),(32638,'watch-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','content','\\f1db','','','.w-filters'),(32639,'watch-mobile','.w-top-categories .categories','content','\\_','4','','.w-top-categories'),(32640,'watch-mobile','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(32642,'watch-mobile','.b-bottom .footerTitle','content','\\f068','290,2,4','','.b-bottom'),(32643,'watch-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','content','\\f058','','','.w-filters'),(32644,'watch-mobile','.w-currencies .current','content','\\e902','3','','.w-currencies'),(32645,'watch-mobile','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(32646,'watch-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(32647,'watch-mobile','.w-compare-box-item .checkbox:checked + span:before','content','\\f00c','','','.w-compare-box-item'),(32648,'watch-mobile','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(32649,'watch-mobile','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(32650,'watch-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','content','\\_','','','.w-compare-box-item'),(32651,'watch-mobile','.b-slick .slick-vertical button.slick-prev','content','\\f077','3','','.b-slick'),(32652,'watch-mobile','.b-slick .slick-track, .b-slick .slick-track:after','content','\\_','3','','.b-slick'),(32653,'watch-mobile','.b-slick .slick-vertical button.slick-next','content','\\f078','3','','.b-slick'),(32654,'watch-mobile','.p-account-trade-form .wd-line-row-2','content','\\_','4','','.p-account-trade-form'),(32656,'watch-mobile','.b-info-popup .info-popup','content','\\e918','3','','.b-info-popup'),(32658,'watch-mobile','.b-info-popup .info-popup div','content','\\_','3','','.b-info-popup'),(32663,'watch-mobile','.w-menu-mobile .menu-ico','content','\\e91b','3','','.w-menu-mobile'),(32665,'watch-mobile','.b-fancybox .fancybox-next span','content','\\e901','3','','.b-fancybox'),(32667,'watch-mobile','.w-product-quantity-discounts .quantity-discounts .count','content','+','4','','.w-product-quantity-discounts'),(32668,'watch-mobile','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(32669,'watch-mobile','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(32670,'watch-mobile','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(32671,'watch-mobile','.b-fancybox .fancybox-prev span','content','\\e900','3','','.b-fancybox'),(32672,'watch-mobile','.p-wedding-registry-share .invite-remove','content','\\e913','3','','.p-wedding-registry-share'),(32673,'watch-mobile','.w-text .customer-service','content','\\e907','3','','.w-text'),(32674,'watch-mobile','.b-rating .glyphicon-chevron-right','content','\\f105','3','','.b-rating'),(32675,'watch-mobile','.b-rating .glyphicon-calendar','content','\\f073','3','','.b-rating'),(32676,'watch-mobile','.b-rating .glyphicon-chevron-up','content','\\f106','3','','.b-rating'),(32677,'watch-mobile','.b-rating .glyphicon-time','content','\\f017','3','','.b-rating'),(32678,'watch-mobile','.b-rating .glyphicon-chevron-left','content','\\f104','3','','.b-rating'),(32679,'watch-mobile','.b-rating .glyphicon-chevron-down','content','\\f107','3','','.b-rating'),(32680,'watch-mobile','.b-rating #stars-default .glyphicon-star','content','\\e90f','3','','.b-rating'),(32681,'watch-mobile','.b-quantity .qty-box .smaller','content','-','3','','.b-quantity'),(32682,'watch-mobile','.b-quantity .qty-box .bigger','content','+','3','','.b-quantity'),(32683,'watch-mobile','.w-breadcrumb .breadcrumb-li + .breadcrumb-li','content','/','3','','.w-breadcrumb'),(32684,'watch-mobile','.b-fancybox .fancybox-close','content','\\f00d','3','','.b-fancybox'),(32685,'watch-mobile','.p-reviews-info .review-info-text','content','\\_','4','','.p-reviews-info'),(32686,'watch-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','content','\\e912','3','','.w-cart-discount-coupon'),(32691,'watch-mobile','.b-form .columns','content','\\_','4','','.b-form'),(32692,'watch-mobile','.b-form .addresses','content','\\_','4','','.b-form'),(32693,'watch-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(32694,'watch-mobile','.w-cart-give-away .ga_name','content','\\_','4','','.w-cart-give-away'),(32696,'watch-mobile','.w-catalog-listing-look .b2b','content','\\f0c9','3','','.w-catalog-listing-look'),(32697,'watch-mobile','.w-list-type-2 .button-wishlist button','content','\\e98e','4','','.w-list-type-2'),(32698,'watch-mobile','.w-list-type-1_3 .sale','content','SALE','4','','.w-list-type-1_3'),(32699,'watch-mobile','.w-list-type-1_3 .sale','content','\\e909','3','','.w-list-type-1_3'),(32700,'watch-mobile','.w-list-type-2 .add-height','content','\\_','4','','.w-list-type-2'),(32701,'watch-mobile','.w-list-type-2 .button-view a','content','\\e98f','4','','.w-list-type-2'),(32702,'watch-mobile','.transit-icon','content','\\f133','3','',''),(32703,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-2'),(32704,'watch-mobile','.in-stock-icon','content','\\f058','3','',''),(32705,'watch-mobile','.w-list-type-2 .sale','content','SALE','4','','.w-list-type-2'),(32706,'watch-mobile','.p-wedding-registry-share h1','content','\\f004','3','','.p-wedding-registry-share'),(32707,'watch-mobile','.w-catalog-listing-look .grid','content','\\f009','3','','.w-catalog-listing-look'),(32708,'watch-mobile','.view-all .btn','content','\\f054','4','',''),(32709,'watch-mobile','.view-all','content','\\_','3','',''),(32710,'watch-mobile','.p-wedding-registry-share h1','content','\\f004','4','','.p-wedding-registry-share'),(32711,'watch-mobile','.w-list-type-2 .sale','content','\\e909','3','','.w-list-type-2'),(32712,'watch-mobile','.w-list-type-1_3 .item','content','\\_','4','','.w-list-type-1_3'),(32713,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-1_3'),(32714,'watch-mobile','.w-list-type-1_3 .button-view a','content','\\e98f','4','','.w-list-type-1_3'),(32715,'watch-mobile','.w-list-type-1_3 .button-wishlist button','content','\\e98e','4','','.w-list-type-1_3'),(32716,'watch-mobile','.w-list-type-1_3 .attributes > .attributes','content','\\_','4','','.w-list-type-1_3'),(32717,'watch-mobile','.w-list-type-1_2 .sale','content','\\e909','3','','.w-list-type-1_2'),(32718,'watch-mobile','.w-list-type-1_3 .add-height','content','\\_','4','','.w-list-type-1_3'),(32719,'watch-mobile','.w-list-type-1_2 .sale','content','SALE','4','','.w-list-type-1_2'),(32720,'watch-mobile','.w-list-type-1_2 .right-area','content','\\_','4','','.w-list-type-1_2'),(32721,'watch-mobile','.w-list-type-1_2 .item','content','\\_','4','','.w-list-type-1_2'),(32722,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-1_2'),(32723,'watch-mobile','.w-list-type-1_2 .button-wishlist button','content','\\e98e','4','','.w-list-type-1_2'),(32724,'watch-mobile','.w-list-type-1_2 .button-view a','content','\\e98f','4','','.w-list-type-1_2'),(32725,'watch-mobile','.b-bottom .pop-up-close','content','\\f00d','3','','.b-bottom'),(32726,'watch-mobile','.w-list-type-1_2 .add-height','content','\\_','4','','.w-list-type-1_2'),(32727,'watch-mobile','.w-list-type-1 .sale','content','SALE','4','','.w-list-type-1'),(32728,'watch-mobile','.w-list-type-1 .sale','content','\\e909','3','','.w-list-type-1'),(32729,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-1'),(32730,'watch-mobile','.w-list-type-1 .button-wishlist button','content','\\e98e','4','','.w-list-type-1'),(32731,'watch-mobile','.heading-4 .edit, h4 .edit','content','\\e917','4','',''),(32732,'watch-mobile','.w-filters .open','content','\\f056','3','','.w-filters'),(32733,'watch-mobile','.w-filters .mobileCollapse','content','\\f056','2,4','','.w-filters'),(32734,'watch-mobile','.w-filters .mobileCollapse','content','\\f055','4','','.w-filters'),(32735,'watch-mobile','.w-filters .view_more','content','\\f061','4','','.w-filters'),(32736,'watch-mobile','.w-filters span.close','content','\\f055','3','','.w-filters'),(32737,'watch-mobile','.w-languages .current','content','\\e902','3','','.w-languages'),(32738,'watch-mobile','.w-list-type-1 .add-height','content','\\_','4','','.w-list-type-1'),(32739,'watch-mobile','.w-product-reviews .reviews-list .review','content','\\_','3','','.w-product-reviews'),(32740,'watch-mobile','.w-reviews .heading-3','content','\\e908','3','','.w-reviews'),(32741,'watch-mobile','.w-reviews .review','content','\\_','3','','.w-reviews'),(32742,'watch-mobile','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(32743,'watch-mobile','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(32744,'watch-mobile','.w-search .button-search','content','\\e90a','3','','.w-search'),(32745,'watch-mobile','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(32746,'watch-mobile','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(32747,'watch-mobile','.btn-del','content','\\f1f8','4','',''),(32750,'watch-mobile','.b-info .info','content','\\e918','3','','.b-info'),(32751,'watch-mobile','.b-products-listing .BlockBox','content','\\_','4','','.b-products-listing'),(32752,'watch-mobile','.b-products-listing .btn-preloader','content','\\f110','3','','.b-products-listing'),(32753,'watch-mobile','.b-products-listing .hover-box-content','content','\\_','3','','.b-products-listing'),(32754,'watch-mobile','.b-products-listing .loader','content','\\f110','4','','.b-products-listing'),(32755,'watch-mobile','.b-products-listing .loader','content','\\_','3','','.b-products-listing'),(32756,'watch-mobile','.b-products-listing .products-listing','content','\\_','4','','.b-products-listing'),(32757,'watch-mobile','.b-products-listing .products-listing .bonus-points-cost','content','\\f219','3','','.b-products-listing'),(32758,'watch-mobile','.b-products-listing .products-listing .bonus-points-price','content','\\f219','3','','.b-products-listing'),(32759,'watch-mobile','.b-products-listing .products-listing .btn-buy','content','\\e977','3','','.b-products-listing'),(32760,'watch-mobile','.b-products-listing .products-listing .mix-attributes','content','\\_','4','','.b-products-listing'),(32761,'watch-mobile','.b-products-listing .products-listing .qty-input.hidden','content','\\_','3','','.b-products-listing'),(32762,'watch-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','content','\\f004','','','.b-products-listing'),(32763,'watch-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','content','\\f08a','','','.b-products-listing'),(32764,'watch-mobile','.b-products-listing .products-listing a.btn.view-button','content','\\e991','3','','.b-products-listing'),(32765,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(32766,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(32767,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(32768,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(32769,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(32770,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(32771,'watch-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','content','\\f0c9','3','','.b-menu-burger_icon'),(32772,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(32773,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(32774,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(32775,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(32776,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(32777,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(32778,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(32779,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(32780,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(32781,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(32782,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','content','\\f107','4','','.b-menu-style-1'),(32783,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > .no-link','content','\\f105','4','','.b-menu-style-1'),(32784,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','content','\\f105 \\f105','4','','.b-menu-style-1'),(32785,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','content','\\f00d','3','','.b-menu-style-2'),(32786,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','content','\\_','3','','.b-menu-style-2'),(32787,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','content','\\f105','3','','.b-menu-style-2'),(32788,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','content','\\_','3','','.b-menu-style-2'),(32789,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','content','\\f104','3','','.b-menu-style-2'),(32790,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > .no-link','content','\\f107','4','','.b-menu-style-3'),(32791,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > .no-link','content','\\f105','3','','.b-menu-style-3'),(32792,'watch-mobile','.b-messages .select2-search-choice-close','content','\\e913','3','','.b-messages'),(32793,'watch-mobile','.b-messages .messBtnMenuDelete','content','\\e913','3','','.b-messages'),(32794,'watch-mobile','.b-messages span.starred::before','content','\\e90e','','','.b-messages'),(32795,'watch-mobile','.b-messages .dataTables_wrapper > .top','content','\\_','4','','.b-messages'),(32796,'watch-mobile','.b-messages .messBtnMenuUnread','content','\\f097','3','','.b-messages'),(32797,'watch-mobile','.b-messages .messBtnMenuStarred','content','\\e90e','3','','.b-messages'),(32798,'watch-mobile','.b-messages .icon-circle-with-cross::before','content','×','','','.b-messages'),(32799,'watch-mobile','.b-messages .dataTables_wrapper > .bottom','content','\\_','4','','.b-messages'),(32800,'watch-mobile','.b-preloader .preloader','content','\\f110','3','','.b-preloader'),(32801,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','content','\\25be','3','','.b-select-suggest'),(32802,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(32803,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(32804,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(32805,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(32806,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(32807,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(32808,'watch-mobile','.b-trade-approval .columns','content','\\_','4','','.b-trade-approval'),(32809,'watch-mobile','.b-upload-file .snapshot','content','\\f030','3','','.b-upload-file'),(32810,'watch-mobile','.b-upload-file .upload-file-wrap .upload-remove','content','\\e913','3','','.b-upload-file'),(32811,'watch-mobile','.b-upload-files .remove-file','content','\\f014','3','','.b-upload-files'),(32812,'watch-mobile','.b-warehouses-popup .warehouses-popup-link','content','\\f041','3','','.b-warehouses-popup'),(32813,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','content','\\f041','3','','.b-warehouses-popup'),(32814,'watch-mobile','.batchPr .btn-batch-remove','content','x','3','','.batchPr'),(32815,'watch-mobile','.batchPr .checkbox input:not(checked) + span:before','content','\\002B','','','.batchPr'),(32816,'watch-mobile','.batchPr .checkbox input:checked + span:before','content','\\f00c','','','.batchPr'),(32817,'watch-mobile','.bell-ico .heading-2','content','\\e9a7','3','','.bell-ico'),(32818,'watch-mobile','.heading-ordered-items .heading-4','content','\\e99b','3','','.heading-ordered-items'),(32819,'watch-mobile','.heading-saved-lists .heading-4','content','\\e99c','3','','.heading-saved-lists'),(32820,'watch-mobile','.heading-settings .heading-4','content','\\e99a','3','','.heading-settings'),(32847,'watch-mobile','.p-payer-order-confirmation .ship-ico','content','\\e94e','3','','.p-payer-order-confirmation'),(32848,'watch-mobile','.p-payer-order-confirmation .pay-ico','content','\\e99e','3','','.p-payer-order-confirmation'),(32849,'watch-mobile','.p-payer-order-confirmation .order-ico','content','\\e922','3','','.p-payer-order-confirmation'),(32850,'watch-mobile','.p-payer-order-confirmation .comment-ico','content','\\e99d','3','','.p-payer-order-confirmation'),(32851,'watch-mobile','.p-payer-order-confirmation .discount-ico','content','\\e95e','3','','.p-payer-order-confirmation'),(32852,'watch-mobile','.p-payer-order-pay .ship-ico','content','\\e94e','3','','.p-payer-order-pay'),(32853,'watch-mobile','.p-payer-order-pay .pay-ico','content','\\e99e','3','','.p-payer-order-pay'),(32854,'watch-mobile','.p-payer-order-pay .order-ico','content','\\e922','3','','.p-payer-order-pay'),(32855,'watch-mobile','.p-payer-order-pay .comment-ico','content','\\e99d','3','','.p-payer-order-pay'),(32856,'watch-mobile','.p-payer-order-pay .discount-ico','content','\\e95e','3','','.p-payer-order-pay'),(32857,'watch-mobile','.p-quick-order-index .paginate_button.next','content','\\f105','3','','.p-quick-order-index'),(32858,'watch-mobile','.p-quick-order-index .paginate_button.previous','content','\\f104','3','','.p-quick-order-index'),(32859,'watch-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(32860,'watch-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(32861,'watch-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(32862,'watch-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(32863,'watch-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(32864,'watch-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(32865,'watch-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(32866,'watch-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(32867,'watch-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(32868,'watch-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(32869,'watch-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(32870,'watch-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(32871,'watch-mobile','.p-sample-checkout-success .page-success .text-1','content','\\e916','3','','.p-sample-checkout-success'),(32872,'watch-mobile','.p-sample-checkout-success .page-success','content','\\_','0,3','','.p-sample-checkout-success'),(32873,'watch-mobile','.savings-ico .heading-2','content','\\e95e','3','','.savings-ico'),(32874,'watch-mobile','.shipping-ico .heading-2','content','\\e95e','3','','.shipping-ico'),(32875,'watch-mobile','.shipping-ico .heading-2','content','\\e94e','3','','.shipping-ico'),(32876,'watch-mobile','.shipping-ico .heading-2','content','\\e95e','3','','.shipping-ico'),(32877,'watch-mobile','.w-account-address-book .add_item a','content','\\f067','3','','.w-account-address-book'),(32878,'watch-mobile','.w-blog-widget-categories-list a','content','\\2022','3','','.w-blog-widget-categories-list'),(32879,'watch-mobile','.w-blog-widget-most-popular-posts a','content','\\2022','3','','.w-blog-widget-most-popular-posts'),(32880,'watch-mobile','.w-blog-widget-post-comments-count span','content','\\e645','3','','.w-blog-widget-post-comments-count'),(32881,'watch-mobile','.w-blog-widget-post-listing .post_comment','content','\\e645','3','','.w-blog-widget-post-listing'),(32882,'watch-mobile','.w-blog-widget-post-listing .post_date span + span','content','\\2022','3','','.w-blog-widget-post-listing'),(32883,'watch-mobile','.w-blog-widget-post-listing .products','content','\\_','4','','.w-blog-widget-post-listing'),(32884,'watch-mobile','.w-blog-widget-post-share ','content','\\_','4','','.w-blog-widget-post-share'),(32885,'watch-mobile','.w-blog-widget-post-share .facebook-btn','content','\\f09a','3','','.w-blog-widget-post-share'),(32886,'watch-mobile','.w-blog-widget-post-share .twitter-btn','content','\\f099','3','','.w-blog-widget-post-share'),(32887,'watch-mobile','.w-blog-widget-post-share .pinterest-btn','content','\\f231','3','','.w-blog-widget-post-share'),(32888,'watch-mobile','.w-blog-widget-post-share .mailto','content','\\e75a','3','','.w-blog-widget-post-share'),(32889,'watch-mobile','.w-blog-widget-post-share .printto','content','\\e681','3','','.w-blog-widget-post-share'),(32890,'watch-mobile','.w-cart-bonus-points .btn-remove','content','\\e913','3','','.w-cart-bonus-points'),(32891,'watch-mobile','.w-cart-bonus-points .title','content','\\f219','3','','.w-cart-bonus-points'),(32892,'watch-mobile','.w-cart-compare .product-actions .dropdown-toggle','content','\\f013','3','','.w-cart-compare'),(32893,'watch-mobile','.w-cart-compare .product','content','\\_','4','','.w-cart-compare'),(32894,'watch-mobile','.w-cart-compare .delete-cart','content','\\2573','3','','.w-cart-compare'),(32895,'watch-mobile','.w-cart-compare .atr-col','content','\\f070','3','','.w-cart-compare'),(32896,'watch-mobile','.w-cart-credit-amount .amount-title','content','\\e99f','3','','.w-cart-credit-amount'),(32897,'watch-mobile','.w-cart-credit-amount .btn-remove','content','\\e913','3','','.w-cart-credit-amount'),(32898,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','content','\\e90d','3','','.w-catalog-compare'),(32899,'watch-mobile','.w-catalog-compare td span + span','content','| ','3','','.w-catalog-compare'),(32900,'watch-mobile','.w-catalog-compare .checkbox input:checked + span:before','content','\\f014','','','.w-catalog-compare'),(32901,'watch-mobile','.w-catalog-paging .next','content','\\f105','3','','.w-catalog-paging'),(32902,'watch-mobile','.w-catalog-paging .prev','content','\\f104','3','','.w-catalog-paging'),(32903,'watch-mobile','.w-checkout-billing-address .addresses','content','\\_','4','','.w-checkout-billing-address'),(32904,'watch-mobile','.w-checkout-bonus-points .btn-remove','content','\\e913','3','','.w-checkout-bonus-points'),(32905,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','content','\\f10b','3','','.w-checkout-contact-information'),(32906,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','content','\\f095','3','','.w-checkout-contact-information'),(32907,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','content','\\f003','3','','.w-checkout-contact-information'),(32908,'watch-mobile','.w-checkout-create-account .account-benefits strong','content','\\e918','3','','.w-checkout-create-account'),(32909,'watch-mobile','.w-checkout-credit-amount .btn-remove','content','\\e913','3','','.w-checkout-credit-amount'),(32910,'watch-mobile','.w-checkout-shipping-address .addresses','content','\\_','4','','.w-checkout-shipping-address'),(32911,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','content','\\_','','','.w-checkout-shipping-choice'),(32912,'watch-mobile','.w-coupons-and-vauchers-checkout .btn-remove','content','\\e913','3','','.w-coupons-and-vauchers-checkout'),(32913,'watch-mobile','.w-list-b2b .attributes','content','\\_','4','','.w-list-b2b'),(32914,'watch-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','content','\\f013','3','','.w-multi-cart-actions'),(32915,'watch-mobile','.w-personal-gift-status-bar .inform','content','\\e6a0','4','','.w-personal-gift-status-bar'),(32916,'watch-mobile','.w-personal-gift-status-bar .end-date','content','\\e72b','3','','.w-personal-gift-status-bar'),(32917,'watch-mobile','.w-product-available-in-warehouses .content','content','\\_','4','','.w-product-available-in-warehouses'),(32918,'watch-mobile','.w-product-cross-sell .buy-all-checker','content','\\f14a','3','','.w-product-cross-sell'),(32919,'watch-mobile','.w-product-customers-activity .close','content','\\2715','3','','.w-product-customers-activity'),(32920,'watch-mobile','.w-promotions .prom-multi-discount','content','\\_','4','','.w-promotions'),(32921,'watch-mobile','.w-promotions .nextdiscount .heading','content','\\f07a','3','','.w-promotions'),(32922,'watch-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','content','\\_','3','','.w-promotions'),(32923,'watch-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','content','\\_','3','','.w-promotions'),(32924,'watch-mobile','.w-promotions .prom-multi-discount .promo-range .promo-prod-qty','content',',','4','','.w-promotions'),(32925,'watch-mobile','.w-promotions .prom-multi-discount > .heading','content','\\_','3','','.w-promotions'),(32926,'watch-mobile','.w-reviews-content .review','content','\\_','3','','.w-reviews-content'),(32927,'watch-mobile','.w-social-links .facebook','content','\\f09a','3','','.w-social-links'),(32928,'watch-mobile','.w-social-links .pinterest','content','\\f0d2','3','','.w-social-links'),(32929,'watch-mobile','.w-social-links .stumbleupon','content','\\f1a4','3','','.w-social-links'),(32930,'watch-mobile','.w-social-links .google-plus','content','\\f2b3','3','','.w-social-links'),(32931,'watch-mobile','.w-social-links .linkedin','content','\\f0e1','3','','.w-social-links'),(32932,'watch-mobile','.w-social-links .instagram','content','\\f16d','3','','.w-social-links'),(32933,'watch-mobile','.w-social-links .twitter','content','\\f099','3','','.w-social-links'),(32934,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','content','\\f1f8','3','','.w-upload-customer-id-upload-customer-id-form'),(32935,'watch-mobile','.w-wedding-registry-widgets-delete-link a','content','|','4','','.w-wedding-registry-widgets-delete-link'),(32936,'watch-mobile','.w-wedding-registry-widgets-manage-names .names-separator','content','\\f004','3','','.w-wedding-registry-widgets-manage-names'),(32937,'watch-mobile','.w-wedding-registry-widgets-products .remove-btn','content','\\e913','3','','.w-wedding-registry-widgets-products'),(32938,'watch-mobile','.w-wedding-registry-widgets-search-registry-button a','content','\\f002','3','','.w-wedding-registry-widgets-search-registry-button'),(32939,'watch-mobile','.w-wedding-registry-widgets-share-link a','content','|','4','','.w-wedding-registry-widgets-share-link'),(32940,'watch-mobile','.w-wedding-registry-widgets-share-link a','content','\\f045','3','','.w-wedding-registry-widgets-share-link'),(32941,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','content','\\f1db','','','.w-filters'),(32942,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','content','\\f058','','','.w-filters'),(32943,'watch-mobile','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(32944,'watch-mobile','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(32945,'watch-mobile','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(32946,'watch-mobile','.b-rating .glyphicon-chevron-right','content_important','important','3','','.b-rating'),(32947,'watch-mobile','.b-rating .glyphicon-time','content_important','important','3','','.b-rating'),(32948,'watch-mobile','.b-rating .glyphicon-chevron-down','content_important','important','3','','.b-rating'),(32949,'watch-mobile','.b-rating .glyphicon-chevron-left','content_important','important','3','','.b-rating'),(32950,'watch-mobile','.b-rating .glyphicon-calendar','content_important','important','3','','.b-rating'),(32951,'watch-mobile','.b-rating .glyphicon-chevron-up','content_important','important','3','','.b-rating'),(32952,'watch-mobile','.w-menu-big .show-all','cursor','pointer','','','.w-menu-big'),(32953,'watch-mobile','.w-menu .menu .menu-ico','cursor','pointer','','','.w-menu'),(32954,'watch-mobile','.w-menu-slider .close','cursor','pointer','','','.w-menu-slider'),(32955,'watch-mobile','.b-switch .bootstrap-switch','cursor','pointer','','','.b-switch'),(32956,'watch-mobile','.w-product-images img','cursor','pointer','','','.w-product-images'),(32957,'watch-mobile','.w-filters .filter-box-content ul li.view_items','cursor','pointer','','','.w-filters'),(32960,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','cursor','pointer','','','.b-multi-page-checkout'),(32961,'watch-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','cursor','pointer','','','.b-product-images'),(32964,'watch-mobile','.b-fancybox .fancybox-close','cursor','pointer','','','.b-fancybox'),(32965,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','cursor','pointer','3','','.b-form'),(32966,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor','default','','','.b-switch'),(32967,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor','default','','','.b-switch'),(32968,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor','default','','','.b-switch'),(32969,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','cursor','pointer','','','.b-switch'),(32970,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor','default','','','.b-switch'),(32971,'watch-mobile','.w-tabs .accordion-heading','cursor','pointer','','','.w-tabs'),(32972,'watch-mobile','.w-tabs .accordion-heading','cursor','default','2','','.w-tabs'),(32973,'watch-mobile','.b-slick button.slick-disabled','cursor','default','','','.b-slick'),(32974,'watch-mobile','.b-bottom .footerTitle','cursor','pointer','290','','.b-bottom'),(32975,'watch-mobile','.w-tabs .tab-a','cursor','default','2','','.w-tabs'),(32976,'watch-mobile','.w-tabs .tab-a','cursor','pointer','','','.w-tabs'),(32977,'watch-mobile','.w-filters .mobileCollapse','cursor','pointer','4','','.w-filters'),(32979,'watch-mobile','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(32980,'watch-mobile','.b-form .item-radio label','cursor','pointer','','','.b-form'),(32981,'watch-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','cursor','pointer','','','.b-product-images'),(32982,'watch-mobile','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(32983,'watch-mobile','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(32984,'watch-mobile','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(32985,'watch-mobile','.b-fancybox .fancybox-nav span','cursor','pointer','','','.b-fancybox'),(32986,'watch-mobile','.b-fancybox .fancybox-nav','cursor','pointer','','','.b-fancybox'),(32987,'watch-mobile','.b-form .item-radio.active label','cursor','default','','','.b-form'),(32988,'watch-mobile','.b-fancybox #fancybox-loading','cursor','pointer','','','.b-fancybox'),(32989,'watch-mobile','.b-autocomplete .ui-autocomplete li','cursor','pointer','','','.b-autocomplete'),(32990,'watch-mobile','.b-bottom .pop-up-close','cursor','pointer','','','.b-bottom'),(32991,'watch-mobile','.w-filters .open, .w-filters .close','cursor','pointer','','','.w-filters'),(32992,'watch-mobile','.w-filters .ui-slider-handle','cursor','pointer','','','.w-filters'),(32993,'watch-mobile','.b-form .addresses .address-item label','cursor','pointer','','','.b-form'),(32994,'watch-mobile','.b-products-listing .products-listing .wishlistButton .checkbox','cursor','pointer','','','.b-products-listing'),(32995,'watch-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','cursor','pointer','','','.b-menu-burger_icon'),(32996,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(32997,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(32998,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(32999,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(33000,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(33001,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','cursor','pointer','','','.b-menu-style-2'),(33002,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','cursor','pointer','','','.b-menu-style-2'),(33003,'watch-mobile','.b-messages .messMenuButton span','cursor','pointer','','','.b-messages'),(33004,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-chosen','cursor','default','','','.b-select-suggest'),(33005,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','1','','.b-select-suggest'),(33006,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','','','.b-select-suggest'),(33007,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','cursor','default','','','.b-select-suggest'),(33008,'watch-mobile','.b-select-suggest .select2-results .select2-disabled','cursor','default','','','.b-select-suggest'),(33009,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','cursor','pointer','','','.b-select-suggest'),(33010,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','cursor','default','','','.b-select-suggest'),(33011,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','cursor','text','','','.b-select-suggest'),(33012,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','cursor','default','','','.b-select-suggest'),(33013,'watch-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','cursor','default','','','.b-select-suggest'),(33014,'watch-mobile','.b-upload-file .snapshot','cursor','pointer','','','.b-upload-file'),(33015,'watch-mobile','.b-upload-files .remove-file','cursor','pointer','','','.b-upload-files'),(33016,'watch-mobile','.batchPr .batchSelect .checkbox','cursor','pointer','','','.batchPr'),(33017,'watch-mobile','.batchPr .btn-batch-remove','cursor','pointer','','','.batchPr'),(33018,'watch-mobile','.batchPr .batchSelect .checkbox','cursor','pointer','','','.batchPr'),(33031,'watch-mobile','.p-quick-order-index .filters .clear','cursor','pointer','','','.p-quick-order-index'),(33032,'watch-mobile','.w-account-personal-catalog .list-switcher a','cursor','pointer','','','.w-account-personal-catalog'),(33033,'watch-mobile','.w-account-personal-catalog .list-switcher a','cursor','default','2','','.w-account-personal-catalog'),(33034,'watch-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','cursor','pointer','','','.w-blog-widget-post-share'),(33035,'watch-mobile','.w-cart-bonus-points .btn-remove','cursor','pointer','','','.w-cart-bonus-points'),(33036,'watch-mobile','.w-cart-compare .atr-col','cursor','pointer','','','.w-cart-compare'),(33037,'watch-mobile','.w-cart-credit-amount .btn-remove','cursor','pointer','','','.w-cart-credit-amount'),(33038,'watch-mobile','.w-catalog-compare .compare label','cursor','pointer','','','.w-catalog-compare'),(33039,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','cursor','pointer','','','.w-catalog-compare'),(33040,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','cursor','default','2','','.w-catalog-compare'),(33041,'watch-mobile','.w-catalog-compare .cross-box .return','cursor','pointer','','','.w-catalog-compare'),(33042,'watch-mobile','.w-checkout-bonus-points .btn-remove','cursor','pointer','','','.w-checkout-bonus-points'),(33043,'watch-mobile','.w-checkout-credit-amount .btn-remove','cursor','pointer','','','.w-checkout-credit-amount'),(33044,'watch-mobile','.w-checkout-shipping-choice span','cursor','pointer','','','.w-checkout-shipping-choice'),(33045,'watch-mobile','.w-checkout-shipping-choice input:checked + span','cursor','default','','','.w-checkout-shipping-choice'),(33046,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','cursor','pointer','','','.w-communication-new-topic'),(33047,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','cursor','pointer','','','.w-communication-new-topic'),(33048,'watch-mobile','.w-coupons-and-vauchers-checkout .btn-remove','cursor','pointer','','','.w-coupons-and-vauchers-checkout'),(33049,'watch-mobile','.w-product-customers-activity .close','cursor','pointer','','','.w-product-customers-activity'),(33050,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','cursor','pointer','','','.w-upload-customer-id-upload-customer-id-form'),(33051,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor_important','important','','','.b-switch'),(33052,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor_important','important','','','.b-switch'),(33053,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor_important','important','','','.b-switch'),(33054,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor_important','important','','','.b-switch'),(33055,'watch-mobile','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(33056,'watch-mobile','.b-switch .bootstrap-switch','direction','ltr','','','.b-switch'),(33057,'watch-mobile','.w-menu-big li a, .w-menu-big li .no-link','display','inline-block','','','.w-menu-big'),(33058,'watch-mobile','.w-menu .hided.menu .menu-ico','display','block','','','.w-menu'),(33059,'watch-mobile','.w-menu-big li li li','display','block','','','.w-menu-big'),(33060,'watch-mobile','.w-menu .hided.menu a, .w-menu .hided.menu .no-link','display','block','','','.w-menu'),(33061,'watch-mobile','.w-menu-big li li a, .w-menu-big li li .no-link','display','block','','','.w-menu-big'),(33062,'watch-mobile','.w-menu .hided.menu ul li','display','block','','','.w-menu'),(33063,'watch-mobile','.w-menu .menu .menu-ico','display','none','','','.w-menu'),(33064,'watch-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','display','none','','','.w-menu'),(33065,'watch-mobile','.w-menu div.hided.menu .active + ul, .w-menu div.hided.menu .opened + ul','display','block','','','.w-menu'),(33066,'watch-mobile','.w-menu-big .hide-more.hide-more-disable, .w-menu-big .hide-more.hide-more-disable ~ li:not(.show-all)','display','block','','','.w-menu-big'),(33067,'watch-mobile','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','display','inline-block','','','.w-menu-horizontal'),(33068,'watch-mobile','.w-menu-slider > ul > li > ul > li','display','inline-block','','','.w-menu-slider'),(33069,'watch-mobile','.w-menu-big > ul > li > ul','display','none','','','.w-menu-big'),(33070,'watch-mobile','.w-menu-big > ul > li:hover > ul','display','block','','','.w-menu-big'),(33071,'watch-mobile','.w-menu-big .hide-more, .w-menu-big .hide-more ~ li:not(.show-all)','display','none','','','.w-menu-big'),(33072,'watch-mobile','.w-menu-big li','display','inline-block','','','.w-menu-big'),(33073,'watch-mobile','.w-bestsellers .counter','display','inline-block','','','.w-bestsellers'),(33074,'watch-mobile','.w-menu-slider > ul > li','display','inline-block','','','.w-menu-slider'),(33075,'watch-mobile','.w-menu-slider a, .w-menu-slider .no-link','display','inline-block','','','.w-menu-slider'),(33076,'watch-mobile','.w-account .my-acc-link','display','inline-block','3','','.w-account'),(33077,'watch-mobile','.w-menu-slider > ul > li > ul','display','none','','','.w-menu-slider'),(33078,'watch-mobile','.w-account .no-text','display','none','','','.w-account'),(33079,'watch-mobile','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(33080,'watch-mobile','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(33081,'watch-mobile','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(33082,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(33083,'watch-mobile','.b-form .checkbox-style:checked + .checkbox-span','display','inline-block','','','.b-form'),(33084,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','display','inline-block','','','.b-form'),(33085,'watch-mobile','.w-sale .btn','display','block','','','.w-sale'),(33086,'watch-mobile','.w-login-block .label','display','block','','','.w-login-block'),(33087,'watch-mobile','.w-login-block .cols','display','block','4','','.w-login-block'),(33088,'watch-mobile','.b-product-images .additional-images .item > div, .b-product-images .additional-videos .item > div','display','table-cell','','','.b-product-images'),(33089,'watch-mobile','.w-sale .left-count-days','display','block','','','.w-sale'),(33090,'watch-mobile','.w-sale .left-count','display','block','','','.w-sale'),(33091,'watch-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','display','block','','','.b-product-images'),(33092,'watch-mobile','.w-product-attributes .attributes','display','block','4','','.w-product-attributes'),(33093,'watch-mobile','.w-product-sale-ends .left-count-days','display','block','','','.w-product-sale-ends'),(33094,'watch-mobile','.w-product-sale-ends .left-count','display','block','','','.w-product-sale-ends'),(33095,'watch-mobile','.w-product-sale-ends .left-count-hours','display','block','','','.w-product-sale-ends'),(33096,'watch-mobile','.w-product-sale-ends .left-text-right','display','block','','','.w-product-sale-ends'),(33097,'watch-mobile','.w-product-sale-ends .left-text-left','display','block','','','.w-product-sale-ends'),(33098,'watch-mobile','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(33100,'watch-mobile','.w-filters .filter-widget-horizontal .filter-box','display','table-cell','','','.w-filters'),(33101,'watch-mobile','.w-filters .filter-widget-horizontal .content-filter-widget','display','table','','','.w-filters'),(33102,'watch-mobile','.w-cart .price','display','block','','','.w-cart'),(33103,'watch-mobile','.w-filters .filter-box-content ul li.view_items','display','block','','','.w-filters'),(33104,'watch-mobile','.w-cart .name','display','block','','','.w-cart'),(33105,'watch-mobile','.w-cart .no-text','display','none','','','.w-cart'),(33106,'watch-mobile','.p-reviews-info .review-info-text','display','block','4','','.p-reviews-info'),(33107,'watch-mobile','.w-product-collection .together','display','block','','','.w-product-collection'),(33108,'watch-mobile','.w-menu-mobile .menu-slider .open','display','block','','','.w-menu-mobile'),(33109,'watch-mobile','.w-menu-mobile .menu-ico','display','block','','','.w-menu-mobile'),(33110,'watch-mobile','.w-menu-mobile .menu-slider','display','none','','','.w-menu-mobile'),(33111,'watch-mobile','.w-categories .categories','display','flex','','','.w-categories'),(33112,'watch-mobile','.b-price-box .price-box .title','display','inline-block','','','.b-price-box'),(33113,'watch-mobile','.w-quote .no-text','display','none','299','','.w-quote'),(33115,'watch-mobile','.w-categories .item','display','inline-block','','','.w-categories'),(33116,'watch-mobile','.w-categories .categories','display','block','4','','.w-categories'),(33117,'watch-mobile','.w-compare-box-item .checkbox + span','display','inline-block','','','.w-compare-box-item'),(33118,'watch-mobile','.w-categories .name','display','block','','','.w-categories'),(33119,'watch-mobile','.w-categories .image','display','block','','','.w-categories'),(33120,'watch-mobile','.w-catalog-listing-look .listing-look-title','display','inline-block','','','.w-catalog-listing-look'),(33121,'watch-mobile','.b-pagination .pagination','display','block','4','','.b-pagination'),(33122,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','block','','','.b-multi-page-checkout'),(33123,'watch-mobile','.b-pass-strength .pass-strength','display','block','','','.b-pass-strength'),(33124,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','inline-block','4','','.b-multi-page-checkout'),(33125,'watch-mobile','.b-price-box .price-box .price','display','inline-block','','','.b-price-box'),(33126,'watch-mobile','.w-quote .cart-box-link','display','inline-block','3','','.w-quote'),(33127,'watch-mobile','.w-quote .strong','display','block','','','.w-quote'),(33128,'watch-mobile','.w-quote .no-text','display','inline-block','','','.w-quote'),(33129,'watch-mobile','.w-quote .cart-box-link','display','block','','','.w-quote'),(33130,'watch-mobile','.w-product-properties li','display','table-cell','','','.w-product-properties'),(33131,'watch-mobile','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(33132,'watch-mobile','.b-product-images .main-image-box','display','block','4','','.b-product-images'),(33133,'watch-mobile','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(33134,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','display','inline-block','3','','.b-multi-page-checkout'),(33135,'watch-mobile','.b-compare .compare_select_items','display','inline-block','','','.b-compare'),(33136,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .count','display','none','','','.b-multi-page-checkout'),(33137,'watch-mobile','.w-catalog-listing-look .list','display','inline-block','','','.w-catalog-listing-look'),(33138,'watch-mobile','.w-catalog-listing-look .b2b','display','inline-block','','','.w-catalog-listing-look'),(33139,'watch-mobile','.price .old','display','block','','',''),(33140,'watch-mobile','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(33141,'watch-mobile','.w-cart-shipping-estimator .shipping-estimator','display','block','4','','.w-cart-shipping-estimator'),(33142,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .edit','display','none','','','.b-multi-page-checkout'),(33143,'watch-mobile','.p-blog-index .post-title','display','block','','','.p-blog-index'),(33144,'watch-mobile','.p-blog-index .comment-form p label','display','inline-block','','','.p-blog-index'),(33146,'watch-mobile','.p-blog-index .post-list .comments-link','display','none','','','.p-blog-index'),(33147,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','display','inline-block','','','.b-multi-page-checkout'),(33148,'watch-mobile','.b-info-popup .info-popup div','display','none','','','.b-info-popup'),(33149,'watch-mobile','.b-info-popup .info-popup:hover div','display','block','','','.b-info-popup'),(33150,'watch-mobile','.w-filters .content-filter-widget','display','none','317','','.w-filters'),(33151,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','display','block','4','','.b-multi-page-checkout'),(33152,'watch-mobile','.w-promo-code .promo-text-2','display','none','291','','.w-promo-code'),(33153,'watch-mobile','.w-promo-code .holder','display','block','4','','.w-promo-code'),(33154,'watch-mobile','.w-product-bonus-points > div','display','block','4','','.w-product-bonus-points'),(33155,'watch-mobile','.p-wedding-registry-manage a.remove-btn','display','inline-block','','','.p-wedding-registry-manage'),(33161,'watch-mobile','.w-product-configurator .item-content > div','display','block','290','','.w-product-configurator'),(33162,'watch-mobile','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(33163,'watch-mobile','.w-product-configurator .item-content','display','block','290','','.w-product-configurator'),(33164,'watch-mobile','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(33165,'watch-mobile','.testimonials .review','display','block','3','',''),(33166,'watch-mobile','.b-pagination .pagination .paging','display','inline-block','','','.b-pagination'),(33167,'watch-mobile','.b-pagination .pagination .prev','display','inline-block','','','.b-pagination'),(33168,'watch-mobile','.b-pagination .pagination .prev-pages','display','inline-block','','','.b-pagination'),(33169,'watch-mobile','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(33170,'watch-mobile','.b-pagination .pagination .page-number','display','inline-block','','','.b-pagination'),(33171,'watch-mobile','.b-pagination .pagination .next-pages','display','inline-block','','','.b-pagination'),(33172,'watch-mobile','.b-pagination .pagination .next','display','inline-block','','','.b-pagination'),(33173,'watch-mobile','.b-pagination .pagination span','display','inline-block','2','','.b-pagination'),(33187,'watch-mobile','.p-blog-index .entry-content','display','block','4','','.p-blog-index'),(33189,'watch-mobile','.p-blog-index .nav-links .screen-reader-text','display','block','','','.p-blog-index'),(33190,'watch-mobile','.p-blog-index .comment-author .says','display','none','','','.p-blog-index'),(33191,'watch-mobile','.p-blog-index .comment-meta','display','block','4','','.p-blog-index'),(33192,'watch-mobile','.w-list-type-2_2 .qty-input label','display','none','','','.w-list-type-2_2'),(33193,'watch-mobile','.w-list-type-2_2 .price .old','display','block','','','.w-list-type-2_2'),(33194,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','display','block','3','','.w-list-type-2_2'),(33195,'watch-mobile','.w-list-type-2_2 .item','display','block','4','','.w-list-type-2_2'),(33196,'watch-mobile','.w-list-type-2_2 .button-view a','display','block','','','.w-list-type-2_2'),(33197,'watch-mobile','.buttons','display','block','4','',''),(33198,'watch-mobile','.w-list-type-2_2 .add-height','display','block','4','','.w-list-type-2_2'),(33199,'watch-mobile','.w-list-type-2 .qty-input label','display','none','','','.w-list-type-2'),(33200,'watch-mobile','.w-list-type-2 .price .old','display','block','','','.w-list-type-2'),(33201,'watch-mobile','.personal-buttons > div','display','flex','','','.personal-buttons'),(33202,'watch-mobile','.w-account a.my-acc-link','display','inline-block','','','.w-account'),(33203,'watch-mobile','.p-reviews-info .review_by span','display','inline-block','','','.p-reviews-info'),(33204,'watch-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','display','block','','','.b-fancybox'),(33205,'watch-mobile','.w-menu-horizontal ul ul li','display','block','','','.w-menu-horizontal'),(33206,'watch-mobile','.w-menu-horizontal ul li:hover > ul','display','block','','','.w-menu-horizontal'),(33207,'watch-mobile','.w-menu-horizontal ul ul','display','none','','','.w-menu-horizontal'),(33208,'watch-mobile','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(33209,'watch-mobile','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(33210,'watch-mobile','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(33211,'watch-mobile','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(33212,'watch-mobile','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(33213,'watch-mobile','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(33214,'watch-mobile','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(33215,'watch-mobile','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(33216,'watch-mobile','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(33217,'watch-mobile','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(33218,'watch-mobile','.p-wedding-registry-index .search-list label','display','block','','','.p-wedding-registry-index'),(33219,'watch-mobile','.b-form .form-inputs label > span','display','inline-block','','','.b-form'),(33220,'watch-mobile','.p-wedding-registry-manage .links a','display','inline-block','','','.p-wedding-registry-manage'),(33221,'watch-mobile','.p-wedding-registry-search #searchform-status','display','flex','','','.p-wedding-registry-search'),(33222,'watch-mobile','.p-wedding-registry-search .search-form','display','flex','','','.p-wedding-registry-search'),(33223,'watch-mobile','.b-pagination .pagination a','display','inline-block','','','.b-pagination'),(33224,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(33225,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(33226,'watch-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','display','inline-block','','','.b-compare'),(33227,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display','inline-block','','','.b-switch'),(33228,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container','display','inline-block','','','.b-switch'),(33229,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display','inline-block','','','.b-switch'),(33230,'watch-mobile','.b-switch .bootstrap-switch','display','inline-block','','','.b-switch'),(33231,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','display','inline-block','','','.b-fancybox'),(33232,'watch-mobile','.b-form .middle-form .col-gender label','display','inline-block','','','.b-form'),(33233,'watch-mobile','.w-tabs .accordion-heading','display','block','','','.w-tabs'),(33234,'watch-mobile','.w-currencies .select-link','display','block','299','','.w-currencies'),(33235,'watch-mobile','.w-languages .lang-link','display','block','299','','.w-languages'),(33236,'watch-mobile','.b-bottom .footerTitle ~ div','display','none','290','','.b-bottom'),(33237,'watch-mobile','.w-filters .input-checkbox:checked + .checkbox-span','display','inline-block','','','.w-filters'),(33238,'watch-mobile','.w-catalog-listing-look .grid','display','inline-block','','','.w-catalog-listing-look'),(33239,'watch-mobile','.w-list-type-1 .button-view a','display','block','','','.w-list-type-1'),(33240,'watch-mobile','.w-top-categories .categories','display','block','4','','.w-top-categories'),(33241,'watch-mobile','.w-tabs .tab-li','display','table-cell','','','.w-tabs'),(33242,'watch-mobile','.w-top-categories .item','display','inline-block','','','.w-top-categories'),(33243,'watch-mobile','.w-tabs .tab-a','display','block','','','.w-tabs'),(33245,'watch-mobile','.w-search .item','display','block','','','.w-search'),(33246,'watch-mobile','.w-search .name','display','block','','','.w-search'),(33247,'watch-mobile','.b-product-images .additional-images .item, .b-product-images .additional-videos .item','display','table','','','.b-product-images'),(33248,'watch-mobile','.w-banner .sliderItems a + a, .w-banner .sliderItems a + img, .w-banner .sliderItems img + a, .w-banner .sliderItems img + img','display','none','','','.w-banner'),(33249,'watch-mobile','.w-list-type-1_3 .price .old','display','block','','','.w-list-type-1_3'),(33250,'watch-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','display','inline-block','','','.w-filters'),(33251,'watch-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','display','table-cell','','','.w-banner'),(33252,'watch-mobile','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','display','table','','','.w-banner'),(33253,'watch-mobile','.p-account-trade-form .wl-td label','display','inline-block','','','.p-account-trade-form'),(33255,'watch-mobile','.p-quote-cart-index .cart-popup .gift-wrap','display','none','','','.p-quote-cart-index'),(33256,'watch-mobile','.p-shopping-cart-index .cart-popup .gift-wrap','display','none','','','.p-shopping-cart-index'),(33257,'watch-mobile','.w-currencies .select','display','none','','','.w-currencies'),(33258,'watch-mobile','.w-currencies .currencies-title','display','block','','','.w-currencies'),(33259,'watch-mobile','.w-currencies .currencies:hover .select','display','block','','','.w-currencies'),(33260,'watch-mobile','.w-currencies .currencies','display','inline-block','','','.w-currencies'),(33261,'watch-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(33262,'watch-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(33263,'watch-mobile','.b-slick .slick-slider','display','block','','','.b-slick'),(33264,'watch-mobile','.b-slick .slick-track','display','block','','','.b-slick'),(33265,'watch-mobile','.b-slick .slick-vertical .slick-slide','display','block','','','.b-slick'),(33266,'watch-mobile','.b-slick .slick-track, .b-slick .slick-track:after','display','table','3','','.b-slick'),(33267,'watch-mobile','.p-account-trade-form .wd-line-row-2','display','block','4','','.p-account-trade-form'),(33268,'watch-mobile','.b-info-popup .info-popup','display','inline-block','3','','.b-info-popup'),(33269,'watch-mobile','.b-info-popup .info-popup','display','inline-block','','','.b-info-popup'),(33271,'watch-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','display','inline-block','','','.w-menu-style-1'),(33273,'watch-mobile','.w-menu-style-1 li','display','inline-block','','','.w-menu-style-1'),(33274,'watch-mobile','.w-account .account-dropdown','display','none','','','.w-account'),(33277,'watch-mobile','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(33278,'watch-mobile','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(33279,'watch-mobile','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(33280,'watch-mobile','.w-product-quantity-discounts .quantity-discounts .count','display','inline-block','','','.w-product-quantity-discounts'),(33281,'watch-mobile','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(33282,'watch-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(33283,'watch-mobile','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(33284,'watch-mobile','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(33285,'watch-mobile','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(33286,'watch-mobile','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(33287,'watch-mobile','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(33288,'watch-mobile','.w-menu-style-1 ul ul li','display','block','','','.w-menu-style-1'),(33289,'watch-mobile','.w-menu-style-1 ul li:hover > ul','display','block','','','.w-menu-style-1'),(33290,'watch-mobile','.w-menu-style-1 ul ul','display','none','','','.w-menu-style-1'),(33291,'watch-mobile','.w-menu-style-1 li li a, .w-menu-style-1 li li .no-link','display','block','','','.w-menu-style-1'),(33292,'watch-mobile','.b-fancybox .fancybox-overlay','display','none','','','.b-fancybox'),(33293,'watch-mobile','.w-sale .left-text-right','display','block','','','.w-sale'),(33294,'watch-mobile','.w-sale .left-count-hours','display','block','','','.w-sale'),(33295,'watch-mobile','.w-sale .left-text-left','display','block','','','.w-sale'),(33296,'watch-mobile','.w-sale .special-price','display','block','','','.w-sale'),(33297,'watch-mobile','.w-sale .text','display','block','','','.w-sale'),(33298,'watch-mobile','.w-sale .special-price-text','display','none','','','.w-sale'),(33299,'watch-mobile','.w-text .customer-service b','display','block','','','.w-text'),(33300,'watch-mobile','.w-top-categories .categories','display','flex','','','.w-top-categories'),(33301,'watch-mobile','.w-banner .carousel-text','display','flex','','','.w-banner'),(33302,'watch-mobile','.b-slick .slick-slide.slick-loading img','display','none','','','.b-slick'),(33303,'watch-mobile','.b-slick .slick-slide','display','none','','','.b-slick'),(33304,'watch-mobile','.b-slick .slick-arrow.slick-hidden','display','none','','','.b-slick'),(33305,'watch-mobile','.b-slick .slick-initialized .slick-slide','display','block','','','.b-slick'),(33306,'watch-mobile','.b-slick .slick-list','display','block','','','.b-slick'),(33307,'watch-mobile','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(33308,'watch-mobile','.b-rating #stars-default .glyphicon','display','inline-block','','','.b-rating'),(33309,'watch-mobile','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(33310,'watch-mobile','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(33311,'watch-mobile','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(33312,'watch-mobile','.w-cart .cart-box.hover-box .cart-content','display','none','','','.w-cart'),(33313,'watch-mobile','.w-cart .cart-box.hover-box:hover .cart-content','display','block','','','.w-cart'),(33314,'watch-mobile','.w-cart .cart-box-link','display','block','','','.w-cart'),(33315,'watch-mobile','.w-cart .strong','display','block','','','.w-cart'),(33316,'watch-mobile','.w-filters .mobileCollapse','display','inline-block','317','','.w-filters'),(33317,'watch-mobile','.w-menu-horizontal li','display','inline-block','','','.w-menu-horizontal'),(33318,'watch-mobile','.w-menu-horizontal li li a, .w-menu-horizontal li li .no-link','display','block','','','.w-menu-horizontal'),(33319,'watch-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','display','inline-block','3','','.w-cart-discount-coupon'),(33320,'watch-mobile','.w-cart .cart-box-link','display','inline-block','3','','.w-cart'),(33322,'watch-mobile','.w-list-type-1_3 .qty-input label','display','none','','','.w-list-type-1_3'),(33326,'watch-mobile','.b-form .columns','display','block','4','','.b-form'),(33327,'watch-mobile','.b-form .addresses','display','block','4','','.b-form'),(33329,'watch-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(33330,'watch-mobile','.w-cart a.item','display','block','','','.w-cart'),(33331,'watch-mobile','.b-datepicker .picker-switch','display','none','','','.b-datepicker'),(33332,'watch-mobile','.w-cart a.item','display','block','4','','.w-cart'),(33333,'watch-mobile','.w-cart-give-away .ga_name','display','block','4','','.w-cart-give-away'),(33335,'watch-mobile','.w-list-type-2 .button-view a','display','block','','','.w-list-type-2'),(33336,'watch-mobile','.w-list-type-2 .add-height','display','block','4','','.w-list-type-2'),(33337,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','display','block','3','','.w-list-type-2'),(33338,'watch-mobile','.w-list-type-1_3 .item','display','block','4','','.w-list-type-1_3'),(33339,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','display','block','3','','.w-list-type-1_3'),(33340,'watch-mobile','.w-list-type-1_3 .button-view a','display','block','','','.w-list-type-1_3'),(33341,'watch-mobile','.w-list-type-1_3 .attributes > .attributes','display','block','4','','.w-list-type-1_3'),(33342,'watch-mobile','.w-list-type-1_3 .add-height','display','block','4','','.w-list-type-1_3'),(33343,'watch-mobile','.w-list-type-1_2 .right-area','display','block','4','','.w-list-type-1_2'),(33344,'watch-mobile','.w-list-type-1_2 .qty-input label','display','none','','','.w-list-type-1_2'),(33345,'watch-mobile','.w-list-type-1_2 .item','display','block','4','','.w-list-type-1_2'),(33346,'watch-mobile','.w-list-type-1_2 .price .old','display','block','','','.w-list-type-1_2'),(33347,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','display','block','3','','.w-list-type-1_2'),(33348,'watch-mobile','.w-list-type-1_2 .button-view a','display','block','','','.w-list-type-1_2'),(33349,'watch-mobile','.w-list-type-1_2 .add-height','display','block','4','','.w-list-type-1_2'),(33350,'watch-mobile','.w-list-type-1 .qty-input label','display','none','','','.w-list-type-1'),(33351,'watch-mobile','.w-list-type-1 .price .old','display','block','','','.w-list-type-1'),(33352,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','display','block','3','','.w-list-type-1'),(33353,'watch-mobile','.w-filters .mobileCollapse','display','none','','','.w-filters'),(33354,'watch-mobile','.w-languages .select','display','none','','','.w-languages'),(33355,'watch-mobile','.w-languages .languages:hover .select','display','block','','','.w-languages'),(33356,'watch-mobile','.w-languages .languages','display','inline-block','','','.w-languages'),(33357,'watch-mobile','.w-list-type-1 .add-height','display','block','4','','.w-list-type-1'),(33358,'watch-mobile','.b-form .addresses .address-item span','display','block','','','.b-form'),(33359,'watch-mobile','.w-tabs > .block > .box .heading-2, .w-tabs > .block > .box .heading-3, .w-tabs > .block > .box .heading-4','display','none','','','.w-tabs'),(33360,'watch-mobile','.w-top-categories .name','display','block','','','.w-top-categories'),(33361,'watch-mobile','.w-tabs .tab-navigation','display','table','','','.w-tabs'),(33362,'watch-mobile','.w-product-reviews .reviews-list .review','display','block','3','','.w-product-reviews'),(33363,'watch-mobile','.w-top-categories .image','display','block','','','.w-top-categories'),(33364,'watch-mobile','.w-reviews .review','display','block','3','','.w-reviews'),(33365,'watch-mobile','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(33366,'watch-mobile','.w-search .items-title','display','block','','','.w-search'),(33367,'watch-mobile','.b-form .middle-form label','display','block','','','.b-form'),(33368,'watch-mobile','.b-form .payment-method .item-radio label','display','block','','','.b-form'),(33369,'watch-mobile','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','display','inline-block','','','.b-form'),(33370,'watch-mobile','.b-form .payment-method .item-radio label span','display','block','','','.b-form'),(33371,'watch-mobile','.b-form .payment-method .sub-item span','display','block','','','.b-form'),(33372,'watch-mobile','.b-info .info','display','inline-block','3','','.b-info'),(33373,'watch-mobile','.w-cart .cart-content','display','none','','','.w-cart'),(33374,'watch-mobile','.b-products-listing .BlockBox','display','block','4','','.b-products-listing'),(33375,'watch-mobile','.b-products-listing .btn-preloader','display','inline-block','3','','.b-products-listing'),(33376,'watch-mobile','.b-products-listing .hide','display','none','','','.b-products-listing'),(33377,'watch-mobile','.b-products-listing .hover-box-content','display','none','','','.b-products-listing'),(33378,'watch-mobile','.b-products-listing .hover-box:hover .hover-box-content','display','block','','','.b-products-listing'),(33379,'watch-mobile','.b-products-listing .loader','display','inline-block','4','','.b-products-listing'),(33380,'watch-mobile','.b-products-listing .products-listing','display','block','4','','.b-products-listing'),(33381,'watch-mobile','.b-products-listing .products-listing .attribute-qty-block','display','flex','','','.b-products-listing'),(33382,'watch-mobile','.b-products-listing .products-listing .attribute-qty-blocks','display','flex','','','.b-products-listing'),(33383,'watch-mobile','.b-products-listing .products-listing .bonus-points','display','flex','','','.b-products-listing'),(33384,'watch-mobile','.b-products-listing .products-listing .btn-buy','display','inline-block','3','','.b-products-listing'),(33385,'watch-mobile','.b-products-listing .products-listing .compare','display','block','','','.b-products-listing'),(33386,'watch-mobile','.b-products-listing .products-listing .compare label','display','inline','','','.b-products-listing'),(33387,'watch-mobile','.b-products-listing .products-listing .item','display','inline-block','','','.b-products-listing'),(33388,'watch-mobile','.b-products-listing .products-listing .mix-attributes','display','block','4','','.b-products-listing'),(33389,'watch-mobile','.b-products-listing .products-listing.align-left .item','display','block','','','.b-products-listing'),(33390,'watch-mobile','.b-products-listing .products-listing.align-right .item','display','block','','','.b-products-listing'),(33391,'watch-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','display','block','','','.b-products-listing'),(33392,'watch-mobile','.b-products-listing .promos-info .promo-item','display','flex','','','.b-products-listing'),(33393,'watch-mobile','.b-products-listing .select-attributes','display','flex','','','.b-products-listing'),(33394,'watch-mobile','.b-products-listing .show-ofstock-products .headerStock','display','inline-block','','','.b-products-listing'),(33395,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.b-data-table'),(33396,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.b-data-table'),(33397,'watch-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(33398,'watch-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(33399,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(33400,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(33401,'watch-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(33402,'watch-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(33403,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(33404,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(33405,'watch-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(33406,'watch-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(33407,'watch-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(33408,'watch-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(33409,'watch-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(33410,'watch-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(33411,'watch-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(33412,'watch-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(33413,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(33414,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(33415,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','display','inline','','','.b-h-inline'),(33416,'watch-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .menu-content','display','none','','','.b-menu-burger_icon'),(33417,'watch-mobile','.b-menu-burger_icon .bi-opened .menu-style[data-burger_icon] .menu-content','display','block','','','.b-menu-burger_icon'),(33418,'watch-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','display','block','','','.b-menu-burger_icon'),(33419,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','display','block','','','.b-menu-lev_display-slide'),(33420,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','display','block','','','.b-menu-lev_display-slide'),(33421,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','display','block','','','.b-menu-lev_display-slide'),(33422,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','display','block','','','.b-menu-lev_display-slide'),(33423,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','display','block','','','.b-menu-lev_display-slide'),(33424,'watch-mobile','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(33425,'watch-mobile','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(33426,'watch-mobile','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(33427,'watch-mobile','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(33428,'watch-mobile','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(33429,'watch-mobile','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(33430,'watch-mobile','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(33431,'watch-mobile','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(33432,'watch-mobile','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(33433,'watch-mobile','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(33434,'watch-mobile','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(33435,'watch-mobile','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(33436,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-2','display','none','','','.b-menu-lev_vis'),(33437,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(33438,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-3','display','none','','','.b-menu-lev_vis'),(33439,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(33440,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-4','display','none','','','.b-menu-lev_vis'),(33441,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(33442,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-5','display','none','','','.b-menu-lev_vis'),(33443,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(33444,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-6','display','none','','','.b-menu-lev_vis'),(33445,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(33446,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(33447,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-2','display','none','','','.b-menu-lev_vis'),(33448,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(33449,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-3','display','none','','','.b-menu-lev_vis'),(33450,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(33451,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-4','display','none','','','.b-menu-lev_vis'),(33452,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(33453,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-5','display','none','','','.b-menu-lev_vis'),(33454,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(33455,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-6','display','none','','','.b-menu-lev_vis'),(33456,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(33457,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1','display','none','','','.b-menu-lev_vis-click_icon'),(33458,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(33459,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-3','display','none','','','.b-menu-lev_vis-click_icon'),(33460,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(33461,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-4','display','none','','','.b-menu-lev_vis-click_icon'),(33462,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(33463,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-5','display','none','','','.b-menu-lev_vis-click_icon'),(33464,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(33465,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-6','display','none','','','.b-menu-lev_vis-click_icon'),(33466,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display','block','','','.b-menu-open_from-left'),(33467,'watch-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul','display','flex','','','.b-menu-position'),(33468,'watch-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(33469,'watch-mobile','.b-menu-style picture','display','none','','','.b-menu-style'),(33470,'watch-mobile','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display','none','','','.b-menu-style'),(33471,'watch-mobile','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display','none','','','.b-menu-style'),(33472,'watch-mobile','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display','none','','','.b-menu-style'),(33473,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','display','flex','','','.b-menu-style-1'),(33474,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .component-item','display','none','','','.b-menu-style-1'),(33475,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','display','inline-block','','','.b-menu-style-1'),(33476,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','display','block','','','.b-menu-style-1'),(33477,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','display','block','','','.b-menu-style-2'),(33478,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','display','block','','','.b-menu-style-2'),(33479,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','display','flex','','','.b-menu-style-2'),(33480,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .languages','display','flex','','','.b-menu-style-2'),(33481,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','display','block','','','.b-menu-style-2'),(33482,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies','display','flex','','','.b-menu-style-2'),(33483,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','display','flex','','','.b-menu-style-2'),(33484,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','display','block','','','.b-menu-style-3'),(33485,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .component-item','display','none','','','.b-menu-style-3'),(33486,'watch-mobile','.b-messages .messMenuButton span','display','inline-block','','','.b-messages'),(33487,'watch-mobile','.b-messages .msv_to_cc div span','display','inline-block','','','.b-messages'),(33488,'watch-mobile','.b-messages span.starred::before','display','inline-block','','','.b-messages'),(33489,'watch-mobile','.b-messages .messBtnMenuStarred','display','inline-block','3','','.b-messages'),(33490,'watch-mobile','.b-messages .dataTables_wrapper > .top','display','block','4','','.b-messages'),(33491,'watch-mobile','.b-messages .messBtnMenuDelete','display','inline-block','3','','.b-messages'),(33492,'watch-mobile','.b-messages .messBtnMenuUnread','display','inline-block','3','','.b-messages'),(33493,'watch-mobile','.b-messages .messages-menu li a','display','block','','','.b-messages'),(33494,'watch-mobile','.b-messages .content_management_attach button','display','inline-block','','','.b-messages'),(33495,'watch-mobile','.b-messages .email-line','display','flex','','','.b-messages'),(33496,'watch-mobile','.b-messages .dataTables_wrapper > .bottom','display','block','4','','.b-messages'),(33497,'watch-mobile','.b-preloader .preloader','display','inline-block','3','','.b-preloader'),(33498,'watch-mobile','.b-select-suggest .select2-container .select2-choice','display','block','','','.b-select-suggest'),(33499,'watch-mobile','.b-select-suggest .select2-container.select2-allowclear .select2-choice abbr','display','inline-block','','','.b-select-suggest'),(33500,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','display','none','','','.b-select-suggest'),(33501,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','3','','.b-select-suggest'),(33502,'watch-mobile','.b-select-suggest .select2-results .select2-disabled','display','list-item','','','.b-select-suggest'),(33503,'watch-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','display','block','','','.b-select-suggest'),(33504,'watch-mobile','.b-select-suggest .select2-display-none','display','none','','','.b-select-suggest'),(33505,'watch-mobile','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','display','list-item','','','.b-select-suggest'),(33506,'watch-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice abbr','display','none','','','.b-select-suggest'),(33507,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','display','none','','','.b-select-suggest'),(33508,'watch-mobile','.b-select-suggest .select2-more-results','display','list-item','','','.b-select-suggest'),(33509,'watch-mobile','.b-select-suggest .select2-results li','display','list-item','','','.b-select-suggest'),(33510,'watch-mobile','.b-select-suggest .select2-results .select2-selected','display','none','','','.b-select-suggest'),(33511,'watch-mobile','.b-select-suggest .select2-search','display','inline-block','','','.b-select-suggest'),(33512,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','','','.b-select-suggest'),(33513,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','display','inline-block','','','.b-select-suggest'),(33514,'watch-mobile','.b-select-suggest .select2-container','display','inline-block','','','.b-select-suggest'),(33515,'watch-mobile','.b-select-suggest .select2-search-choice-close','display','block','','','.b-select-suggest'),(33516,'watch-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','display','list-item','','','.b-select-suggest'),(33517,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(33518,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(33519,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(33520,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(33521,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(33522,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(33523,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(33524,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(33525,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(33526,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(33527,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(33528,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(33529,'watch-mobile','.b-trade-approval .steps-bar','display','table','','','.b-trade-approval'),(33530,'watch-mobile','.b-trade-approval .steps-bar li','display','table-cell','','','.b-trade-approval'),(33531,'watch-mobile','.b-trade-approval .steps-bar li a','display','block','','','.b-trade-approval'),(33532,'watch-mobile','.b-trade-approval .middle-form label','display','block','','','.b-trade-approval'),(33533,'watch-mobile','.b-trade-approval .columns','display','block','4','','.b-trade-approval'),(33534,'watch-mobile','.b-upload-file .upload-file-template','display','inline-block','','','.b-upload-file'),(33535,'watch-mobile','.b-upload-files .attach-active-holder','display','block','','','.b-upload-files'),(33536,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','display','inline-block','','','.b-warehouses-popup'),(33537,'watch-mobile','.batchPr .checkbox input:not(checked) + span:before','display','none','','','.batchPr'),(33538,'watch-mobile','.batchPr .checkbox input:checked + span:before','display','inline-block','','','.batchPr'),(33539,'watch-mobile','.batchPr .batchSelect .checkbox','display','inline-block','','','.batchPr'),(33540,'watch-mobile','.batchPr .btn-batch-remove','display','block','3','','.batchPr'),(33541,'watch-mobile','.batchPr .checkbox input + span','display','block','','','.batchPr'),(33542,'watch-mobile','.batchPr .batch-selected-products-list','display','none','','','.batchPr'),(33543,'watch-mobile','.batchPr .checkbox input','display','none','','','.batchPr'),(33544,'watch-mobile','.batchPr .w-batch-selected-products .item:hover .btn-batch-remove','display','block','','','.batchPr'),(33545,'watch-mobile','.batchPr .btn-batch-remove','display','none','','','.batchPr'),(33546,'watch-mobile','.batchPr .w-batch-products .radio-attributes .option-color, .batchPr .w-batch-products .radio-attributes span[itemprop=\"price\"]','display','none','','','.batchPr'),(33547,'watch-mobile','.batchPr .products-listing .radio-attributes label','display','inline-block','','','.batchPr'),(33634,'watch-mobile','.p-quick-order-index .quick-order-total','display','flex','','','.p-quick-order-index'),(33635,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.p-quick-order-index'),(33636,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.p-quick-order-index'),(33637,'watch-mobile','.p-quick-order-index ul.token-input-list','display','inline-block','','','.p-quick-order-index'),(33638,'watch-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(33639,'watch-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(33640,'watch-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(33641,'watch-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(33642,'watch-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(33643,'watch-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(33644,'watch-mobile','.p-sample-checkout-success .page-success .text-1','display','block','3','','.p-sample-checkout-success'),(33645,'watch-mobile','.w-account-address-book .wrap','display','flex','','','.w-account-address-book'),(33646,'watch-mobile','.w-account-address-book .default-address','display','inline-block','','','.w-account-address-book'),(33647,'watch-mobile','.w-account-address-book .address-book','display','flex','','','.w-account-address-book'),(33648,'watch-mobile','.w-account-address-book .add_item a','display','flex','','','.w-account-address-book'),(33649,'watch-mobile','.w-account-address-book .btn-edit','display','none','3','','.w-account-address-book'),(33650,'watch-mobile','.w-account-address-book .add_item a','display','block','3','','.w-account-address-book'),(33651,'watch-mobile','.w-account-customer-additional-field .field-type-checkbox label','display','inline-block','','','.w-account-customer-additional-field'),(33652,'watch-mobile','.w-account-customer-additional-field .field-type-text','display','flex','','','.w-account-customer-additional-field'),(33653,'watch-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(33654,'watch-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(33655,'watch-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(33656,'watch-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(33657,'watch-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(33658,'watch-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(33659,'watch-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(33660,'watch-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(33661,'watch-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(33662,'watch-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(33663,'watch-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(33664,'watch-mobile','.w-account-personal-catalog .list-switcher','display','flex','','','.w-account-personal-catalog'),(33665,'watch-mobile','.w-account-subscription .send-email','display','block','','','.w-account-subscription'),(33666,'watch-mobile','.w-account-subscription .subscription-variant','display','flex','','','.w-account-subscription'),(33667,'watch-mobile','.w-blog-widget-categories-list a','display','inline-block','3','','.w-blog-widget-categories-list'),(33668,'watch-mobile','.w-blog-widget-categories-list a','display','block','','','.w-blog-widget-categories-list'),(33669,'watch-mobile','.w-blog-widget-most-popular-posts a','display','block','','','.w-blog-widget-most-popular-posts'),(33670,'watch-mobile','.w-blog-widget-most-popular-posts a','display','inline-block','3','','.w-blog-widget-most-popular-posts'),(33671,'watch-mobile','.w-blog-widget-post-comments-count span','display','inline-block','','','.w-blog-widget-post-comments-count'),(33672,'watch-mobile','.w-blog-widget-post-listing .post_comment','display','none','','','.w-blog-widget-post-listing'),(33673,'watch-mobile','.w-blog-widget-post-listing .post_date span + span','display','inline-block','3','','.w-blog-widget-post-listing'),(33674,'watch-mobile','.w-blog-widget-post-listing .products','display','block','4','','.w-blog-widget-post-listing'),(33675,'watch-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','display','inline-block','','','.w-blog-widget-post-share'),(33676,'watch-mobile','.w-blog-widget-post-title h1','display','none','4','','.w-blog-widget-post-title'),(33677,'watch-mobile','.w-blog-widget-post-title h1','display','none','3','','.w-blog-widget-post-title'),(33678,'watch-mobile','.w-blog-widget-related-posts .post_content a','display','block','','','.w-blog-widget-related-posts'),(33679,'watch-mobile','.w-blog-widget-related-posts-by-category .post_content a','display','block','','','.w-blog-widget-related-posts-by-category'),(33680,'watch-mobile','.w-blog-widget-related-posts-by-category .post_img img','display','inline-block','','','.w-blog-widget-related-posts-by-category'),(33681,'watch-mobile','.w-blog-widget-tag-cloud a','display','inline-block','','','.w-blog-widget-tag-cloud'),(33682,'watch-mobile','.w-cart-bonus-points .btn-remove','display','inline-block','','','.w-cart-bonus-points'),(33683,'watch-mobile','.w-cart-compare .product-actions .dropdown-toggle','display','none','4','','.w-cart-compare'),(33684,'watch-mobile','.w-cart-compare .js-cart_totals_container b','display','block','','','.w-cart-compare'),(33685,'watch-mobile','.w-cart-compare .product','display','block','4','','.w-cart-compare'),(33686,'watch-mobile','.w-cart-compare .delete-cart','display','inline-block','','','.w-cart-compare'),(33687,'watch-mobile','.w-cart-credit-amount .btn-remove','display','inline-block','','','.w-cart-credit-amount'),(33688,'watch-mobile','.w-cart-up-sell h3','display','none','','','.w-cart-up-sell'),(33689,'watch-mobile','.w-catalog-additional-images li','display','inline-block','','','.w-catalog-additional-images'),(33690,'watch-mobile','.w-catalog-b2b-add-button ','display','none','','','.w-catalog-b2b-add-button'),(33691,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','display','inline-block','3','','.w-catalog-compare'),(33692,'watch-mobile','.w-catalog-compare td span','display','inline','','','.w-catalog-compare'),(33693,'watch-mobile','.w-catalog-compare .product-listing','display','flex','','','.w-catalog-compare'),(33694,'watch-mobile','.w-catalog-compare .promos-info','display','none','','','.w-catalog-compare'),(33695,'watch-mobile','.w-catalog-compare .item .compare a','display','none','','','.w-catalog-compare'),(33696,'watch-mobile','.w-catalog-compare .cross-box .different-all','display','flex','','','.w-catalog-compare'),(33697,'watch-mobile','.w-catalog-compare .cross-box','display','flex','','','.w-catalog-compare'),(33698,'watch-mobile','.w-catalog-items-on-page .items-on-page','display','flex','','','.w-catalog-items-on-page'),(33699,'watch-mobile','.w-catalog-paging .page-number','display','inline-block','','','.w-catalog-paging'),(33700,'watch-mobile','.w-catalog-paging .next','display','inline-block','','','.w-catalog-paging'),(33701,'watch-mobile','.w-catalog-paging .paging-item','display','inline-block','','','.w-catalog-paging'),(33702,'watch-mobile','.w-catalog-paging ','display','inline-block','2','','.w-catalog-paging'),(33703,'watch-mobile','.w-catalog-paging .paging-holder','display','inline-block','','','.w-catalog-paging'),(33704,'watch-mobile','.w-catalog-paging .prev','display','inline-block','','','.w-catalog-paging'),(33705,'watch-mobile','.w-catalog-paging .next-pages','display','inline-block','','','.w-catalog-paging'),(33706,'watch-mobile','.w-catalog-paging .prev-pages','display','inline-block','','','.w-catalog-paging'),(33707,'watch-mobile','.w-catalog-paging .paging','display','inline-block','','','.w-catalog-paging'),(33708,'watch-mobile','.w-checkout-billing-address .genders-title label','display','inline-block','','','.w-checkout-billing-address'),(33709,'watch-mobile','.w-checkout-billing-address .genders-title > div','display','inline-block','','','.w-checkout-billing-address'),(33710,'watch-mobile','.w-checkout-billing-address .addresses','display','block','4','','.w-checkout-billing-address'),(33711,'watch-mobile','.w-checkout-billing-address .edit-ab','display','inline-block','','','.w-checkout-billing-address'),(33712,'watch-mobile','.w-checkout-billing-address .addresses .address-item label','display','block','','','.w-checkout-billing-address'),(33713,'watch-mobile','.w-checkout-bonus-points .btn-remove','display','inline-block','','','.w-checkout-bonus-points'),(33714,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','display','inline-block','3','','.w-checkout-contact-information'),(33715,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','display','inline-block','3','','.w-checkout-contact-information'),(33716,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','display','inline-block','3','','.w-checkout-contact-information'),(33717,'watch-mobile','.w-checkout-create-account .columns .col-2:nth-child(2n)','display','none','','','.w-checkout-create-account'),(33718,'watch-mobile','.w-checkout-credit-amount .btn-remove','display','inline-block','','','.w-checkout-credit-amount'),(33719,'watch-mobile','.w-checkout-shipping .sub-item','display','block','','','.w-checkout-shipping'),(33720,'watch-mobile','.w-checkout-shipping-address .edit-ab','display','inline-block','','','.w-checkout-shipping-address'),(33721,'watch-mobile','.w-checkout-shipping-address .addresses .address-item label','display','block','','','.w-checkout-shipping-address'),(33722,'watch-mobile','.w-checkout-shipping-address .change-ab','display','inline-block','','','.w-checkout-shipping-address'),(33723,'watch-mobile','.w-checkout-shipping-address .genders-title > div','display','inline-block','','','.w-checkout-shipping-address'),(33724,'watch-mobile','.w-checkout-shipping-address .addresses','display','block','4','','.w-checkout-shipping-address'),(33725,'watch-mobile','.w-checkout-shipping-address .genders-title label','display','inline-block','','','.w-checkout-shipping-address'),(33726,'watch-mobile','.w-checkout-shipping-choice #shippingchoice-choice','display','flex','','','.w-checkout-shipping-choice'),(33727,'watch-mobile','.w-checkout-shipping-choice span','display','flex','','','.w-checkout-shipping-choice'),(33728,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','display','block','','','.w-checkout-shipping-choice'),(33729,'watch-mobile','.w-checkout-shipping-choice input','display','none','','','.w-checkout-shipping-choice'),(33730,'watch-mobile','.w-checkout-terms .required-message-wrap','display','inline-block','','','.w-checkout-terms'),(33731,'watch-mobile','.w-communication-new-topic #communication_group_holder + .columns','display','flex','','','.w-communication-new-topic'),(33732,'watch-mobile','.w-communication-new-topic .middle-form .col-2 label > span','display','block','','','.w-communication-new-topic'),(33733,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','display','inline-block','','','.w-communication-new-topic'),(33734,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','','','.w-communication-new-topic'),(33735,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','3','','.w-communication-new-topic'),(33736,'watch-mobile','.w-communication-post .communication-post-author','display','flex','','','.w-communication-post'),(33737,'watch-mobile','.w-coupons-and-vauchers-checkout .btn-remove','display','inline-block','','','.w-coupons-and-vauchers-checkout'),(33738,'watch-mobile','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(33739,'watch-mobile','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(33740,'watch-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','display','block','','','.w-delivery-day'),(33741,'watch-mobile','.w-delivery-day .time-left','display','flex','','','.w-delivery-day'),(33742,'watch-mobile','.w-delivery-day .left-count','display','block','','','.w-delivery-day'),(33743,'watch-mobile','.w-delivery-day .left-text-left','display','block','','','.w-delivery-day'),(33744,'watch-mobile','.w-delivery-day .left-text-right','display','block','','','.w-delivery-day'),(33745,'watch-mobile','.w-image-maps .categories-items .item .description','display','block','','','.w-image-maps'),(33746,'watch-mobile','.w-image-maps .categories-items .item .title','display','block','','','.w-image-maps'),(33747,'watch-mobile','.w-image-maps .default-links .item','display','block','1','','.w-image-maps'),(33748,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','display','none','','','.w-image-maps'),(33749,'watch-mobile','.w-image-maps .float-items .item .description','display','block','','','.w-image-maps'),(33750,'watch-mobile','.w-image-maps .float-items .item .title','display','block','','','.w-image-maps'),(33751,'watch-mobile','.w-image-maps .products-items .item-holder','display','block','1','','.w-image-maps'),(33752,'watch-mobile','.w-image-maps .svg-wrap','display','inline-block','','','.w-image-maps'),(33753,'watch-mobile','.w-image-maps .categories-items .item','display','block','1','','.w-image-maps'),(33754,'watch-mobile','.w-image-maps .float-items .item','display','block','1','','.w-image-maps'),(33755,'watch-mobile','.w-image-maps .default-links .item .title','display','block','','','.w-image-maps'),(33756,'watch-mobile','.w-image-maps .default-links .item .description','display','block','','','.w-image-maps'),(33757,'watch-mobile','.w-list-b2b .attributes','display','block','4','','.w-list-b2b'),(33758,'watch-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','display','inline-block','','','.w-multi-cart-actions'),(33759,'watch-mobile','.w-multi-cart-actions .cart-actions','display','inline-block','','','.w-multi-cart-actions'),(33760,'watch-mobile','.w-neighbour-checkout .text','display','inline-block','','','.w-neighbour-checkout'),(33761,'watch-mobile','.w-personal-gift-status-bar .timeline','display','flex','','','.w-personal-gift-status-bar'),(33762,'watch-mobile','.w-personal-gift-status-bar .inform','display','inline-block','4','','.w-personal-gift-status-bar'),(33763,'watch-mobile','.w-personal-gift-status-bar .end-date','display','inline-block','3','','.w-personal-gift-status-bar'),(33764,'watch-mobile','.w-product-available-in-warehouses .content','display','block','4','','.w-product-available-in-warehouses'),(33765,'watch-mobile','.w-product-available-in-warehouses .warehouse-item','display','inline-block','','','.w-product-available-in-warehouses'),(33766,'watch-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(33767,'watch-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(33768,'watch-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(33769,'watch-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(33770,'watch-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(33771,'watch-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(33772,'watch-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(33773,'watch-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(33774,'watch-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(33775,'watch-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(33776,'watch-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(33777,'watch-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(33778,'watch-mobile','.w-promotions .prom-multi-discount .products','display','grid','','','.w-promotions'),(33779,'watch-mobile','.w-promotions .prom-multi-discount .list','display','grid','','','.w-promotions'),(33780,'watch-mobile','.w-promotions .nextdiscount .item-holder','display','flex','','','.w-promotions'),(33781,'watch-mobile','.w-promotions .nextdiscount .promo-for-each','display','inline-block','','','.w-promotions'),(33782,'watch-mobile','.w-promotions .promo-cart-discount .item a','display','block','','','.w-promotions'),(33783,'watch-mobile','.w-promotions .promo-cart-discount .content','display','flex','','','.w-promotions'),(33784,'watch-mobile','.w-promotions .promo-cart-discount .slave','display','flex','','','.w-promotions'),(33785,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','display','inline-block','','','.w-promotions'),(33786,'watch-mobile','.w-promotions .promo-cart-discount','display','flex','','','.w-promotions'),(33787,'watch-mobile','.w-promotions .promo-content > .personalgift','display','none','','','.w-promotions'),(33788,'watch-mobile','.w-promotions .promo-date > div','display','inline-block','','','.w-promotions'),(33789,'watch-mobile','.w-promotions .promo-salemaker .discount','display','inline-block','','','.w-promotions'),(33790,'watch-mobile','.w-promotions .promo-salemaker .content','display','flex','','','.w-promotions'),(33791,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','display','inline-block','','','.w-promotions'),(33792,'watch-mobile','.w-promotions .promo-salemaker','display','flex','','','.w-promotions'),(33793,'watch-mobile','.w-promotions .prom-multi-discount .promo-range > div','display','inline-block','','','.w-promotions'),(33794,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','display','inline-block','','','.w-promotions'),(33795,'watch-mobile','.w-promotions .icon','display','inline-block','','','.w-promotions'),(33796,'watch-mobile','.w-promotions .promo-salemaker .content a.name','display','block','','','.w-promotions'),(33797,'watch-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','display','block','','','.w-promotions'),(33798,'watch-mobile','.w-promotions .heading-3','display','inline-block','','','.w-promotions'),(33799,'watch-mobile','.w-promotions .prom-multi-discount','display','block','4','','.w-promotions'),(33800,'watch-mobile','.w-promotions .nextdiscount .content','display','grid','','','.w-promotions'),(33801,'watch-mobile','.w-reviews-content .item','display','grid','','','.w-reviews-content'),(33802,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul','display','flex','','','.w-sitemap-delivery-location'),(33803,'watch-mobile','.w-social-links .name, .w-social-links .image','display','none','','','.w-social-links'),(33804,'watch-mobile','.w-taxable select','display','inline-block','','','.w-taxable'),(33805,'watch-mobile','.w-taxable form','display','flex','','','.w-taxable'),(33806,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','display','flex','','','.w-upload-customer-id-upload-customer-id-form'),(33807,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details ~ div','display','none','','','.w-upload-customer-id-upload-customer-id-form'),(33808,'watch-mobile','.w-wedding-registry-widgets-photos .upload-file-wrap','display','flex','','','.w-wedding-registry-widgets-photos'),(33809,'watch-mobile','.w-wedding-registry-widgets-search-registry-button a','display','inline-block','3','','.w-wedding-registry-widgets-search-registry-button'),(33810,'watch-mobile','.w-wedding-registry-widgets-share-link a','display','inline-block','3','','.w-wedding-registry-widgets-share-link'),(33811,'watch-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(33812,'watch-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(33813,'watch-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(33814,'watch-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(33815,'watch-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(33816,'watch-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(33817,'watch-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(33819,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','display','inline-block','','','.w-filters'),(33820,'watch-mobile','.w-filters .filter-box-content ul li.view_items','display_important','important','','','.w-filters'),(33821,'watch-mobile','.w-menu-mobile .menu-ico','display_important','important','','','.w-menu-mobile'),(33822,'watch-mobile','.w-cart .cart-box.hover-box:hover .cart-content','display_important','important','','','.w-cart'),(33823,'watch-mobile','.w-menu-horizontal ul ul li','display_important','important','','','.w-menu-horizontal'),(33824,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display_important','important','','','.b-switch'),(33825,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display_important','important','','','.b-switch'),(33826,'watch-mobile','.w-menu-style-1 ul ul li','display_important','important','','','.w-menu-style-1'),(33827,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display_important','important','','','.b-menu-open_from-left'),(33828,'watch-mobile','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display_important','important','','','.b-menu-style'),(33829,'watch-mobile','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display_important','important','','','.b-menu-style'),(33830,'watch-mobile','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display_important','important','','','.b-menu-style'),(33832,'watch-mobile','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','fill','rgba(255, 255, 255, 0)','','','.w-image-maps'),(33833,'watch-mobile','.w-image-maps rect.no-items, .w-image-maps circle.no-items, .w-image-maps polygon.no-items','fill','rgba(150, 150, 150, 0.7)','','','.w-image-maps'),(33834,'watch-mobile','.w-image-maps polygon:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(33835,'watch-mobile','.w-image-maps rect:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(33836,'watch-mobile','.w-image-maps circle:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(33837,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','filter','alpha(opacity=50)','','','.b-switch'),(33838,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','filter','alpha(opacity=50)','','','.b-switch'),(33839,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','filter','alpha(opacity=50)','','','.b-switch'),(33840,'watch-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','filter','alpha(opacity=0)','','','.b-switch'),(33841,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','filter','progid','','','.b-select-suggest'),(33842,'watch-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','filter','none','','','.b-select-suggest'),(33843,'watch-mobile','.b-select-suggest .select2-dropdown-open .select2-choice','filter','progid','','','.b-select-suggest'),(33844,'watch-mobile','.b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choice, .b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choices','filter','progid','','','.b-select-suggest'),(33845,'watch-mobile','.b-select-suggest .select2-drop-mask','filter','alpha(opacity=0)','','','.b-select-suggest'),(33846,'watch-mobile','.b-select-suggest .select2-container.select2-drop-above .select2-choice','filter','progid','','','.b-select-suggest'),(33847,'watch-mobile','.b-select-suggest .select2-container .select2-choice','filter','progid','','','.b-select-suggest'),(33848,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','filter','progid','','','.b-select-suggest'),(33849,'watch-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-basis','0','','','.b-menu-position'),(33850,'watch-mobile','.w-account-address-book .wrap','flex-direction','column','','','.w-account-address-book'),(33851,'watch-mobile','.w-account-address-book .add_item a','flex-direction','column','','','.w-account-address-book'),(33852,'watch-mobile','.w-catalog-compare .cross-box','flex-direction','column','','','.w-catalog-compare'),(33853,'watch-mobile','.w-promotions .promo-cart-discount .slave','flex-direction','column','','','.w-promotions'),(33854,'watch-mobile','.p-wedding-registry-search .search-form > div','flex-grow','2','','','.p-wedding-registry-search'),(33855,'watch-mobile','.p-wedding-registry-search #searchform-status label','flex-grow','1','','','.p-wedding-registry-search'),(33856,'watch-mobile','.p-wedding-registry-search .button','flex-grow','1','','','.p-wedding-registry-search'),(33857,'watch-mobile','.b-products-listing .products-listing .attribute-qty-block > span','flex-grow','1','','','.b-products-listing'),(33858,'watch-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-grow','1','','','.b-menu-position'),(33859,'watch-mobile','.b-messages .email-line > div','flex-grow','1','','','.b-messages'),(33860,'watch-mobile','.w-account-customer-additional-field .field-type-text label','flex-grow','1','','','.w-account-customer-additional-field'),(33861,'watch-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-grow','1','','','.w-account-customer-additional-field'),(33862,'watch-mobile','.w-account-personal-catalog .list-switcher a','flex-grow','1','','','.w-account-personal-catalog'),(33863,'watch-mobile','.w-account-subscription .title','flex-grow','1','','','.w-account-subscription'),(33864,'watch-mobile','.w-catalog-compare .product-listing > div','flex-grow','1','','','.w-catalog-compare'),(33865,'watch-mobile','.w-delivery-day .time-left > span','flex-grow','1','','','.w-delivery-day'),(33866,'watch-mobile','.w-promotions .prom-multi-discount .promo-product, .w-promotions .prom-multi-discount .promo-category-item','flex-grow','1','','','.w-promotions'),(33867,'watch-mobile','.b-products-listing .select-attributes .item-title','flex-shrink','0','','','.b-products-listing'),(33868,'watch-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-shrink','1','','','.b-menu-position'),(33869,'watch-mobile','.w-account-customer-additional-field .field-type-text label','flex-shrink','0','','','.w-account-customer-additional-field'),(33870,'watch-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-shrink','0','','','.w-account-customer-additional-field'),(33871,'watch-mobile','.w-catalog-compare .cross-box','flex-shrink','0','','','.w-catalog-compare'),(33872,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','flex-shrink','0','','','.w-upload-customer-id-upload-customer-id-form'),(33873,'watch-mobile','.w-categories .categories','flex-wrap','wrap','','','.w-categories'),(33874,'watch-mobile','.personal-buttons > div','flex-wrap','wrap','','','.personal-buttons'),(33875,'watch-mobile','.w-top-categories .categories','flex-wrap','wrap','','','.w-top-categories'),(33876,'watch-mobile','.b-products-listing .products-listing .attribute-qty-blocks','flex-wrap','wrap','','','.b-products-listing'),(33877,'watch-mobile','.w-account-address-book .address-book','flex-wrap','wrap','','','.w-account-address-book'),(33878,'watch-mobile','.w-communication-new-topic #communication_group_holder + .columns','flex-wrap','wrap','','','.w-communication-new-topic'),(33879,'watch-mobile','.w-promotions .promo-cart-discount .content','flex-wrap','wrap','','','.w-promotions'),(33880,'watch-mobile','.w-promotions .promo-salemaker .content','flex-wrap','wrap','','','.w-promotions'),(33881,'watch-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','float','right','3','','.w-menu'),(33882,'watch-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','float','none','','','.w-menu'),(33883,'watch-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','float','right','3','','.w-menu'),(33884,'watch-mobile','.w-menu .hided.menu ul li','float','none','','','.w-menu'),(33885,'watch-mobile','.w-menu-horizontal .box','float','none','','','.w-menu-horizontal'),(33886,'watch-mobile','.w-menu-big li','float','none','','','.w-menu-big'),(33887,'watch-mobile','.w-menu-style-1 .box','float','none','','','.w-menu-style-1'),(33888,'watch-mobile','.b-slick [dir=\'rtl\'] .slick-slide','float','right','','','.b-slick'),(33889,'watch-mobile','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(33890,'watch-mobile','.w-login-block .returning','float','left','','','.w-login-block'),(33891,'watch-mobile','.w-login-block .new','float','right','','','.w-login-block'),(33892,'watch-mobile','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(33893,'watch-mobile','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(33894,'watch-mobile','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(33895,'watch-mobile','.w-login-block .guest','float','right','','','.w-login-block'),(33896,'watch-mobile','.w-sale .holder-1','float','right','','','.w-sale'),(33897,'watch-mobile','.w-sale .image','float','left','','','.w-sale'),(33898,'watch-mobile','.w-sale .holder-2','float','left','','','.w-sale'),(33899,'watch-mobile','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(33900,'watch-mobile','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(33901,'watch-mobile','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(33902,'watch-mobile','.w-product-sale-ends .left-count','float','left','','','.w-product-sale-ends'),(33903,'watch-mobile','.w-product-sale-ends .left-text-right','float','left','','','.w-product-sale-ends'),(33904,'watch-mobile','.w-product-collection .current-product','float','left','','','.w-product-collection'),(33905,'watch-mobile','.w-product-collection .right-area','float','left','','','.w-product-collection'),(33906,'watch-mobile','.w-product-sale-ends .left-text-left','float','left','','','.w-product-sale-ends'),(33907,'watch-mobile','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(33908,'watch-mobile','.w-cart .image','float','left','','','.w-cart'),(33909,'watch-mobile','.w-cart .cart-box','float','right','','','.w-cart'),(33910,'watch-mobile','.w-compare-box-item .cb_title','float','left','','','.w-compare-box-item'),(33911,'watch-mobile','.w-compare-box-item .cb_check','float','right','','','.w-compare-box-item'),(33912,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','float','right','','','.b-multi-page-checkout'),(33913,'watch-mobile','.b-pagination .pagination .left-area','float','left','','','.b-pagination'),(33914,'watch-mobile','.b-pagination .pagination .right-area','float','right','','','.b-pagination'),(33915,'watch-mobile','.w-product-quantity .product-quantity-label','float','left','','','.w-product-quantity'),(33916,'watch-mobile','.w-product-in-bundles .bundle_item','float','left','','','.w-product-in-bundles'),(33918,'watch-mobile','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(33919,'watch-mobile','.w-product-bundle .bundle_item','float','left','','','.w-product-bundle'),(33920,'watch-mobile','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(33923,'watch-mobile','.p-blog-index .wp-widget li','float','left','3','','.p-blog-index'),(33926,'watch-mobile','.p-blog-index .post-thumbnail','float','left','','','.p-blog-index'),(33927,'watch-mobile','.w-list-type-1_2 .right-area .right-area-2','float','left','','','.w-list-type-1_2'),(33928,'watch-mobile','.w-list-type-1_2 .right-area .name','float','left','','','.w-list-type-1_2'),(33929,'watch-mobile','.w-list-type-1_2 .right-area','float','right','291','','.w-list-type-1_2'),(33930,'watch-mobile','.w-list-type-1_2 .right-area .name','float','none','291','','.w-list-type-1_2'),(33931,'watch-mobile','.w-list-type-1_2 .right-area .right-area-2','float','none','291','','.w-list-type-1_2'),(33932,'watch-mobile','.w-list-type-1_2 .image','float','none','291','','.w-list-type-1_2'),(33933,'watch-mobile','.w-list-type-2 .button-wishlist','float','right','','','.w-list-type-2'),(33934,'watch-mobile','.b-info-popup .password-info .info-popup','float','right','','','.b-info-popup'),(33935,'watch-mobile','.w-promo-code .btn','float','right','','','.w-promo-code'),(33936,'watch-mobile','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(33937,'watch-mobile','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(33938,'watch-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','float','right','','','.p-wedding-registry-manage'),(33939,'watch-mobile','.w-product-bonus-points > div > div','float','left','','','.w-product-bonus-points'),(33940,'watch-mobile','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(33943,'watch-mobile','.w-product-configurator .item-content > div','float','left','290','','.w-product-configurator'),(33944,'watch-mobile','.p-wedding-registry-manage .qty-input','float','left','','','.p-wedding-registry-manage'),(33945,'watch-mobile','.p-wedding-registry-manage a.remove-btn','float','right','','','.p-wedding-registry-manage'),(33946,'watch-mobile','.p-blog-index .nav-previous','float','left','','','.p-blog-index'),(33947,'watch-mobile','.p-blog-index .w-blog-sidebar .wp-widget','float','left','317','','.p-blog-index'),(33948,'watch-mobile','.p-blog-index .nav-previous a','float','left','3','','.p-blog-index'),(33949,'watch-mobile','.p-blog-index .nav-next a','float','right','3','','.p-blog-index'),(33950,'watch-mobile','.p-blog-index .nav-next','float','right','','','.p-blog-index'),(33951,'watch-mobile','.p-blog-index .comment-metadata','float','right','','','.p-blog-index'),(33952,'watch-mobile','.p-blog-index .comment-author','float','left','','','.p-blog-index'),(33953,'watch-mobile','.w-list-type-1_3 .right-area .right-area-2','float','left','','','.w-list-type-1_3'),(33954,'watch-mobile','.w-list-type-2_2 .rating-count','float','right','','','.w-list-type-2_2'),(33955,'watch-mobile','.w-list-type-2_2 .price','float','left','','','.w-list-type-2_2'),(33956,'watch-mobile','.w-list-type-2_2 .rating','float','right','','','.w-list-type-2_2'),(33957,'watch-mobile','.w-list-type-2_2 .qty-input','float','left','','','.w-list-type-2_2'),(33958,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','float','right','','','.w-list-type-2_2'),(33959,'watch-mobile','.w-list-type-2_2 .button-wishlist button','float','right','4','','.w-list-type-2_2'),(33960,'watch-mobile','.w-list-type-2_2 .image','float','left','','','.w-list-type-2_2'),(33961,'watch-mobile','.buttons .left-buttons','float','left','','',''),(33962,'watch-mobile','.w-list-type-2_2 .button-view a','float','right','4','','.w-list-type-2_2'),(33963,'watch-mobile','.w-list-type-2_2 .button-wishlist','float','right','','','.w-list-type-2_2'),(33964,'watch-mobile','.buttons .right-buttons','float','right','','',''),(33965,'watch-mobile','.w-list-type-2 .price','float','left','','','.w-list-type-2'),(33966,'watch-mobile','.w-list-type-2 .rating-count','float','right','','','.w-list-type-2'),(33967,'watch-mobile','.w-brands .brands-listing > div','float','left','','','.w-brands'),(33968,'watch-mobile','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(33969,'watch-mobile','.b-compare .compare-box-btn','float','right','','','.b-compare'),(33970,'watch-mobile','.b-compare .col-two label, .b-compare .col-two select','float','left','','','.b-compare'),(33971,'watch-mobile','.heading-4 .right-text, h4 .right-text','float','right','','',''),(33972,'watch-mobile','.w-socials > li','float','left','','','.w-socials'),(33973,'watch-mobile','.b-product-images .additional-images, .b-product-images .additional-videos','float','right','','','.b-product-images'),(33974,'watch-mobile','.w-socials .post_item_img','float','left','','','.w-socials'),(33975,'watch-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(33976,'watch-mobile','.w-list-type-1 .button-view a','float','right','4','','.w-list-type-1'),(33977,'watch-mobile','.w-list-type-1 .button-wishlist','float','right','','','.w-list-type-1'),(33978,'watch-mobile','.w-filters .handle-to','float','right','','','.w-filters'),(33979,'watch-mobile','.w-filters .handle-from','float','left','','','.w-filters'),(33980,'watch-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(33981,'watch-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(33982,'watch-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(33983,'watch-mobile','.w-menu-style-1 li','float','none','','','.w-menu-style-1'),(33984,'watch-mobile','.p-reviews-info .review-info-image','float','left','','','.p-reviews-info'),(33985,'watch-mobile','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(33986,'watch-mobile','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(33987,'watch-mobile','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(33988,'watch-mobile','.w-list-type-1_3 .rating','float','right','','','.w-list-type-1_3'),(33989,'watch-mobile','.w-list-type-1_3 .rating-count','float','right','','','.w-list-type-1_3'),(33990,'watch-mobile','.w-list-type-1_3 .qty-input','float','left','','','.w-list-type-1_3'),(33991,'watch-mobile','.w-sale .left-text-left','float','left','','','.w-sale'),(33992,'watch-mobile','.w-sale .left-text-right','float','left','','','.w-sale'),(33993,'watch-mobile','.w-sale .left-count','float','left','','','.w-sale'),(33994,'watch-mobile','.b-form .terms-login .bootstrap-switch','float','right','','','.b-form'),(33995,'watch-mobile','.b-slick .slick-slide','float','left','','','.b-slick'),(33996,'watch-mobile','.b-quantity .qty-input label','float','left','','','.b-quantity'),(33998,'watch-mobile','.w-list-type-1_3 .right-area .right-area-2','float','none','291','','.w-list-type-1_3'),(33999,'watch-mobile','.w-list-type-1_3 .right-area .name','float','none','291','','.w-list-type-1_3'),(34000,'watch-mobile','.w-list-type-1_3 .right-area','float','right','291','','.w-list-type-1_3'),(34001,'watch-mobile','.w-menu-horizontal li','float','none','','','.w-menu-horizontal'),(34002,'watch-mobile','.w-cart-order-total.box','float','right','','','.w-cart-order-total'),(34003,'watch-mobile','.w-cart-discount-coupon .gift-code button','float','right','','','.w-cart-discount-coupon'),(34006,'watch-mobile','.b-form .discount-box button','float','right','','','.b-form'),(34008,'watch-mobile','.b-form .col-right','float','right','','','.b-form'),(34010,'watch-mobile','.b-form .columns .col-2','float','left','','','.b-form'),(34012,'watch-mobile','.w-cart-gift-certificate .gift-code button','float','right','','','.w-cart-gift-certificate'),(34013,'watch-mobile','.w-cart-give-away .ga_attributes > div','float','left','','','.w-cart-give-away'),(34014,'watch-mobile','.w-cart-give-away .ga_column','float','left','','','.w-cart-give-away'),(34015,'watch-mobile','.w-cart-give-away .ga_price .checkBoxWrap','float','right','','','.w-cart-give-away'),(34016,'watch-mobile','.w-cart-give-away .ga_img','float','left','','','.w-cart-give-away'),(34017,'watch-mobile','.w-list-type-1_3 .right-area','float','right','','','.w-list-type-1_3'),(34018,'watch-mobile','.b-form .addresses .address-item input[type=\"radio\"]','float','left','','','.b-form'),(34019,'watch-mobile','.w-list-type-1_3 .right-area .name','float','left','','','.w-list-type-1_3'),(34020,'watch-mobile','.w-list-type-1_3 .image','float','none','291','','.w-list-type-1_3'),(34021,'watch-mobile','.w-list-type-2 .button-wishlist button','float','right','4','','.w-list-type-2'),(34022,'watch-mobile','.w-list-type-2 .button-view a','float','right','4','','.w-list-type-2'),(34023,'watch-mobile','.w-list-type-2 .rating','float','right','','','.w-list-type-2'),(34024,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','float','right','','','.w-list-type-2'),(34025,'watch-mobile','.w-list-type-2 .qty-input','float','left','','','.w-list-type-2'),(34026,'watch-mobile','.w-list-type-1_3 .price','float','left','','','.w-list-type-1_3'),(34027,'watch-mobile','.w-list-type-1_3 .image','float','left','','','.w-list-type-1_3'),(34028,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','float','right','','','.w-list-type-1_3'),(34029,'watch-mobile','.heading-3 .right-text, h3 .right-text','float','right','','',''),(34030,'watch-mobile','.w-list-type-1_3 .button-wishlist button','float','right','4','','.w-list-type-1_3'),(34031,'watch-mobile','.w-list-type-1_3 .button-view a','float','right','4','','.w-list-type-1_3'),(34032,'watch-mobile','.w-list-type-1_3 .button-wishlist','float','right','','','.w-list-type-1_3'),(34033,'watch-mobile','.w-list-type-1_3 .attributes > .attributes > div','float','left','','','.w-list-type-1_3'),(34034,'watch-mobile','.w-list-type-1_2 .right-area','float','right','','','.w-list-type-1_2'),(34035,'watch-mobile','.w-list-type-1_2 .rating','float','right','','','.w-list-type-1_2'),(34036,'watch-mobile','.w-list-type-1_2 .rating-count','float','right','','','.w-list-type-1_2'),(34037,'watch-mobile','.w-list-type-1_2 .qty-input','float','left','','','.w-list-type-1_2'),(34038,'watch-mobile','.w-list-type-1_2 .price','float','left','','','.w-list-type-1_2'),(34039,'watch-mobile','.w-list-type-1_2 .image','float','left','','','.w-list-type-1_2'),(34040,'watch-mobile','.w-list-type-1_2 .button-wishlist button','float','right','4','','.w-list-type-1_2'),(34041,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','float','right','','','.w-list-type-1_2'),(34042,'watch-mobile','.w-list-type-1_2 .button-view a','float','right','4','','.w-list-type-1_2'),(34043,'watch-mobile','.w-list-type-1_2 .button-view','float','left','','','.w-list-type-1_2'),(34044,'watch-mobile','.w-list-type-1_2 .button-wishlist','float','right','','','.w-list-type-1_2'),(34045,'watch-mobile','.w-list-type-1 .rating-count','float','right','','','.w-list-type-1'),(34046,'watch-mobile','.w-list-type-1 .rating','float','right','','','.w-list-type-1'),(34047,'watch-mobile','.w-list-type-1 .qty-input','float','left','','','.w-list-type-1'),(34048,'watch-mobile','.w-list-type-1 .price','float','left','','','.w-list-type-1'),(34049,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','float','right','','','.w-list-type-1'),(34050,'watch-mobile','.heading-3 .edit, h3 .edit','float','right','','',''),(34051,'watch-mobile','.w-list-type-1 .button-wishlist button','float','right','4','','.w-list-type-1'),(34052,'watch-mobile','.heading-4 .edit, h4 .edit','float','right','','',''),(34053,'watch-mobile','.b-form .col-left','float','left','','','.b-form'),(34054,'watch-mobile','.b-form .addresses .address-item','float','left','','','.b-form'),(34055,'watch-mobile','.w-search .image','float','left','','','.w-search'),(34057,'watch-mobile','.b-form .payment-method .item-radio input','float','left','','','.b-form'),(34058,'watch-mobile','.b-form .shipping-method .input','float','right','','','.b-form'),(34059,'watch-mobile','.b-form .shipping-method .cost','float','right','','','.b-form'),(34063,'watch-mobile','.b-info .info','float','left','3','','.b-info'),(34064,'watch-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','float','right','','','.b-products-listing'),(34065,'watch-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','float','right','','','.b-products-listing'),(34066,'watch-mobile','.b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockBox.type-14 > .col, .b-products-listing .BlockBox.type-15 > .col, .b-products-listing .BlockBox.type-16 > .col','float','left','','','.b-products-listing'),(34067,'watch-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','float','right','','','.b-products-listing'),(34068,'watch-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','float','right','','','.b-products-listing'),(34069,'watch-mobile','.b-products-listing .BlockBox.type-2 > .col, .b-products-listing .BlockBox.type-3 > .col, .b-products-listing .BlockBox.type-4 > .col, .b-products-listing .BlockBox.type-5 > .col, .b-products-listing .BlockBox.type-6 > .col','float','left','','','.b-products-listing'),(34070,'watch-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','float','right','','','.b-products-listing'),(34071,'watch-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','float','right','','','.b-products-listing'),(34072,'watch-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','float','right','','','.b-products-listing'),(34073,'watch-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','float','right','','','.b-products-listing'),(34074,'watch-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','float','right','','','.b-products-listing'),(34075,'watch-mobile','.b-products-listing .BlockBox.type-7 > .col, .b-products-listing .BlockBox.type-8 > .col, .b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col','float','left','','','.b-products-listing'),(34076,'watch-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','float','right','','','.b-products-listing'),(34077,'watch-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','float','right','','','.b-products-listing'),(34078,'watch-mobile','.b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col, .b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockB','float','left','','','.b-products-listing'),(34079,'watch-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','float','right','','','.b-products-listing'),(34080,'watch-mobile','.b-products-listing .products-listing .attribute-qty-block > span','float','left','','','.b-products-listing'),(34081,'watch-mobile','.b-products-listing .products-listing .bonus-points-cost','float','left','3','','.b-products-listing'),(34082,'watch-mobile','.b-products-listing .products-listing .bonus-points-price','float','left','3','','.b-products-listing'),(34083,'watch-mobile','.b-products-listing .products-listing .compare input + span','float','right','','','.b-products-listing'),(34084,'watch-mobile','.b-products-listing .products-listing .item','float','none','','','.b-products-listing'),(34085,'watch-mobile','.b-products-listing .products-listing .mult-qty-input','float','right','','','.b-products-listing'),(34086,'watch-mobile','.b-products-listing .products-listing .radio-attributes .item-title','float','left','','','.b-products-listing'),(34087,'watch-mobile','.b-products-listing .products-listing a.btn.view-button','float','right','3','','.b-products-listing'),(34088,'watch-mobile','.b-products-listing .products-listing.align-left .item','float','left','','','.b-products-listing'),(34089,'watch-mobile','.b-products-listing .products-listing.align-right .item','float','right','','','.b-products-listing'),(34090,'watch-mobile','.b-products-listing .wedding-registry-count','float','right','','','.b-products-listing'),(34091,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(34092,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(34093,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(34094,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(34095,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(34096,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > .no-link','float','right','3','','.b-menu-style-3'),(34097,'watch-mobile','.b-messages .msv_btn .btn','float','right','','','.b-messages'),(34098,'watch-mobile','.b-messages .messages-menu li span','float','right','','','.b-messages'),(34099,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices li','float','left','','','.b-select-suggest'),(34100,'watch-mobile','.b-sub-totals .historyTotal table','float','right','','','.b-sub-totals'),(34101,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(34102,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(34103,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(34104,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(34105,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(34106,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(34107,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(34108,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(34109,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(34110,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(34111,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(34112,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(34113,'watch-mobile','.b-trade-approval .col-right','float','right','','','.b-trade-approval'),(34114,'watch-mobile','.b-trade-approval .col-left','float','left','','','.b-trade-approval'),(34115,'watch-mobile','.b-trade-approval .col-3','float','left','','','.b-trade-approval'),(34116,'watch-mobile','.b-upload-files .remove-file','float','right','','','.b-upload-files'),(34117,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','float','left','3','','.b-warehouses-popup'),(34118,'watch-mobile','.batchPr .w-batch-products .products-listing .image','float','left','','','.batchPr'),(34119,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(2)','float','none','','','.batchPr'),(34120,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','float','left','','','.batchPr'),(34127,'watch-mobile','.p-payer-order-confirmation .dob-hide label','float','left','','','.p-payer-order-confirmation'),(34128,'watch-mobile','.p-payer-order-confirmation .dob-hide > div','float','right','','','.p-payer-order-confirmation'),(34129,'watch-mobile','.p-payer-order-pay .dob-hide > div','float','right','','','.p-payer-order-pay'),(34130,'watch-mobile','.p-payer-order-pay .dob-hide label','float','left','','','.p-payer-order-pay'),(34131,'watch-mobile','.w-account-addresses-list .addsess-suggestion-item','float','left','','','.w-account-addresses-list'),(34132,'watch-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','float','left','','','.w-account-addresses-list'),(34133,'watch-mobile','.w-blog-widget-post-date ','float','none','','','.w-blog-widget-post-date'),(34134,'watch-mobile','.w-blog-widget-post-image ','float','none','','','.w-blog-widget-post-image'),(34135,'watch-mobile','.w-blog-widget-post-listing .post','float','left','','','.w-blog-widget-post-listing'),(34136,'watch-mobile','.w-blog-widget-post-share ','float','none','','','.w-blog-widget-post-share'),(34137,'watch-mobile','.w-blog-widget-post-title ','float','none','','','.w-blog-widget-post-title'),(34138,'watch-mobile','.w-blog-widget-related-posts .post','float','left','','','.w-blog-widget-related-posts'),(34139,'watch-mobile','.w-blog-widget-related-posts-by-category .post','float','left','','','.w-blog-widget-related-posts-by-category'),(34140,'watch-mobile','.w-cart-compare .product .image','float','left','','','.w-cart-compare'),(34141,'watch-mobile','.w-cart-compare .product-actions','float','right','','','.w-cart-compare'),(34142,'watch-mobile','.w-cart-compare .buttons','float','right','','','.w-cart-compare'),(34143,'watch-mobile','.w-cart-compare .js-cart_totals_container','float','left','','','.w-cart-compare'),(34144,'watch-mobile','.w-catalog-compare .compare label','float','right','','','.w-catalog-compare'),(34145,'watch-mobile','.w-catalog-compare .buyButton','float','right','','','.w-catalog-compare'),(34146,'watch-mobile','.w-checkout-billing-address .btn-cancel','float','left','','','.w-checkout-billing-address'),(34147,'watch-mobile','.w-checkout-billing-address .addresses .address-item','float','left','','','.w-checkout-billing-address'),(34148,'watch-mobile','.w-checkout-billing-address .add-ab','float','left','','','.w-checkout-billing-address'),(34149,'watch-mobile','.w-checkout-billing-address .bootstrap-switch','float','right','','','.w-checkout-billing-address'),(34150,'watch-mobile','.w-checkout-contact-information .btn-save','float','right','','','.w-checkout-contact-information'),(34151,'watch-mobile','.w-checkout-create-account .newsletter-switcher .bootstrap-switch','float','right','','','.w-checkout-create-account'),(34152,'watch-mobile','.w-checkout-create-account .create-account-switcher','float','right','','','.w-checkout-create-account'),(34153,'watch-mobile','.w-checkout-gdpr .candlestick-wrapper','float','right','','','.w-checkout-gdpr'),(34154,'watch-mobile','.w-checkout-shipping-address .add-ab','float','left','','','.w-checkout-shipping-address'),(34155,'watch-mobile','.w-checkout-shipping-address .btn-cancel','float','left','','','.w-checkout-shipping-address'),(34156,'watch-mobile','.w-checkout-shipping-address .addresses .address-item','float','left','','','.w-checkout-shipping-address'),(34157,'watch-mobile','.w-delivery-day .left-count','float','left','','','.w-delivery-day'),(34158,'watch-mobile','.w-delivery-day .left-text-left','float','left','','','.w-delivery-day'),(34159,'watch-mobile','.w-delivery-day .left-text-right','float','left','','','.w-delivery-day'),(34160,'watch-mobile','.w-list-b2b .select-attributes:nth-child(2n)','float','right','','','.w-list-b2b'),(34161,'watch-mobile','.w-list-b2b .select-attributes','float','left','','','.w-list-b2b'),(34162,'watch-mobile','.w-neighbour-checkout .bootstrap-switch','float','right','','','.w-neighbour-checkout'),(34163,'watch-mobile','.w-product-cross-sell .buy-all-checker','float','left','','','.w-product-cross-sell'),(34164,'watch-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(34165,'watch-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(34166,'watch-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(34167,'watch-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(34168,'watch-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(34169,'watch-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(34170,'watch-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(34171,'watch-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(34172,'watch-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(34173,'watch-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(34174,'watch-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(34175,'watch-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(34176,'watch-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(34177,'watch-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(34178,'watch-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(34179,'watch-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(34180,'watch-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(34181,'watch-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(34182,'watch-mobile','.w-wedding-registry-widgets-products .rating','float','none','','','.w-wedding-registry-widgets-products'),(34183,'watch-mobile','.w-wedding-registry-widgets-products .price','float','left','','','.w-wedding-registry-widgets-products'),(34184,'watch-mobile','.w-wedding-registry-widgets-products .qty-input','float','right','','','.w-wedding-registry-widgets-products'),(34185,'watch-mobile','.w-wedding-registry-widgets-search-form .button','float','right','','','.w-wedding-registry-widgets-search-form'),(34186,'watch-mobile','.w-filters .fsl_handle > div','float','left','','','.w-filters'),(34187,'watch-mobile','.p-wedding-registry-manage .qty-input','float_important','important','','','.p-wedding-registry-manage'),(34188,'watch-mobile','.b-slick .slick-slide','float_important','important','','','.b-slick'),(34189,'watch-mobile','.w-blog-widget-post-share ','float_important','important','','','.w-blog-widget-post-share'),(34190,'watch-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','font-family','FontAwesome','3','','.w-menu'),(34191,'watch-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','font-family','FontAwesome','3','','.w-menu'),(34192,'watch-mobile','.w-menu .menu .menu-ico','font-family','$font-icons-2','3','','.w-menu'),(34193,'watch-mobile','.w-menu-slider .close','font-family','FontAwesome','3','','.w-menu-slider'),(34194,'watch-mobile','.w-bestsellers .item','font-family','$font-icons-2','3','','.w-bestsellers'),(34195,'watch-mobile','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(34196,'watch-mobile','.w-bestsellers .heading-3','font-family','$font-icons-2','3','','.w-bestsellers'),(34197,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','font-family','FontAwesome','3','','.b-slick'),(34198,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(34199,'watch-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','font-family','$font-icons-1','','','.b-form'),(34200,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-family','$font-icons-1','','','.b-form'),(34201,'watch-mobile','.w-html_box .socials','font-family','FontAwesome','','','.w-html_box'),(34202,'watch-mobile','.w-product-wedding-registry-button .btn','font-family','$font-2','','','.w-product-wedding-registry-button'),(34203,'watch-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','$font-icons-2','3','','.w-cart-gift-certificate'),(34205,'watch-mobile','.w-categories .name','font-family','$font-1','','','.w-categories'),(34206,'watch-mobile','.heading-3 .edit, h3 .edit','font-family','$font-2','','',''),(34207,'watch-mobile','.w-catalog-listing-look .list','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(34208,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-family','$font-icons-2','4','','.b-multi-page-checkout'),(34209,'watch-mobile','.b-pagination .pagination .next','font-family','$font-icons-1','3','','.b-pagination'),(34210,'watch-mobile','.b-pagination .pagination .prev','font-family','$font-icons-1','3','','.b-pagination'),(34211,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-family','FontAwesome','3','','.b-multi-page-checkout'),(34212,'watch-mobile','.p-blog-index .nav-previous a','font-family','$font-icons-1','3','','.p-blog-index'),(34213,'watch-mobile','.p-blog-index .wp-widget li','font-family','$font-icons-1','3','','.p-blog-index'),(34214,'watch-mobile','.p-blog-index .post-title','font-family','$font-1','','','.p-blog-index'),(34215,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-family','$font-1','','','.b-multi-page-checkout'),(34216,'watch-mobile','.w-list-type-2 .button-view a','font-family','$font-icons-2','4','','.w-list-type-2'),(34217,'watch-mobile','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(34218,'watch-mobile','.p-wedding-registry-manage .remove-btn','font-family','trueloaded','3','','.p-wedding-registry-manage'),(34219,'watch-mobile','.p-wedding-registry-view h1','font-family','FontAwesome','4','','.p-wedding-registry-view'),(34221,'watch-mobile','.js-stock-icon','font-family','$font-icons-1','3','',''),(34222,'watch-mobile','.testimonials .heading-3','font-family','$font-icons-2','3','',''),(34223,'watch-mobile','.p-wedding-registry-manage .wr-search button','font-family','trueloaded','3','','.p-wedding-registry-manage'),(34227,'watch-mobile','.p-blog-index .nav-next a','font-family','$font-icons-1','3','','.p-blog-index'),(34228,'watch-mobile','.p-blog-index .author','font-family','$font-1','','','.p-blog-index'),(34229,'watch-mobile','.no-found','font-family','$font-1','','',''),(34230,'watch-mobile','.w-list-type-2_2 .price','font-family','$font-1','','','.w-list-type-2_2'),(34231,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','font-family','$font-icons-2','3','','.w-list-type-2_2'),(34232,'watch-mobile','.w-list-type-2_2 .button-wishlist button','font-family','$font-2','','','.w-list-type-2_2'),(34233,'watch-mobile','.w-list-type-2_2 .button-view a','font-family','$font-icons-2','4','','.w-list-type-2_2'),(34234,'watch-mobile','.w-list-type-2 .sale','font-family','$font-icons-2','3','','.w-list-type-2'),(34235,'watch-mobile','.w-list-type-2 .price','font-family','$font-1','','','.w-list-type-2'),(34236,'watch-mobile','.price','font-family','$font-1','','',''),(34237,'watch-mobile','.w-product-personal-catalog-button .btn','font-family','$font-icons-1','3','','.w-product-personal-catalog-button'),(34238,'watch-mobile','.w-product-wishlist-button .btn','font-family','$font-2','','','.w-product-wishlist-button'),(34239,'watch-mobile','.w-list-type-2_2 .button-wishlist button','font-family','$font-icons-2','4','','.w-list-type-2_2'),(34240,'watch-mobile','.w-product-bonus-points > div > div','font-family','FontAwesome','3','','.w-product-bonus-points'),(34241,'watch-mobile','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(34242,'watch-mobile','.w-product-personal-catalog-button .btn','font-family','$font-2','','','.w-product-personal-catalog-button'),(34243,'watch-mobile','.w-chat .w-chat-box a','font-family','FontAwesome','3','','.w-chat'),(34244,'watch-mobile','.w-delivery-location-location-list .deliveryListParrent','font-family','$font-1','','','.w-delivery-location-location-list'),(34245,'watch-mobile','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(34246,'watch-mobile','.p-wedding-registry-index .main-button','font-family','FontAwesome','3','','.p-wedding-registry-index'),(34247,'watch-mobile','.p-wedding-registry-index .main-button','font-family','FontAwesome','4','','.p-wedding-registry-index'),(34248,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','font-family','FontAwesome','3','','.b-form'),(34249,'watch-mobile','.p-wedding-registry-index .search-list label','font-family','$font-1','','','.p-wedding-registry-index'),(34250,'watch-mobile','.p-wedding-registry-manage .links a.share-registry','font-family','FontAwesome','4','','.p-wedding-registry-manage'),(34251,'watch-mobile','.p-wedding-registry-search h1','font-family','FontAwesome','3','','.p-wedding-registry-search'),(34252,'watch-mobile','.p-wedding-registry-search h1','font-family','FontAwesome','4','','.p-wedding-registry-search'),(34253,'watch-mobile','.p-wedding-registry-share h1','font-family','FontAwesome','3','','.p-wedding-registry-share'),(34254,'watch-mobile','.p-wedding-registry-manage h1','font-family','FontAwesome','3','','.p-wedding-registry-manage'),(34256,'watch-mobile','.b-compare .clear_all','font-family','$font-icons-1','4','','.b-compare'),(34257,'watch-mobile','.w-account .my-acc-link','font-family','$font-icons-1','3','','.w-account'),(34258,'watch-mobile','.w-tabs .accordion-heading','font-family','$font-1','','','.w-tabs'),(34259,'watch-mobile','.b-bottom .footerTitle','font-family','FontAwesome','290,4','','.b-bottom'),(34260,'watch-mobile','.w-filters .head-filter-widget','font-family','$font-1','','','.w-filters'),(34261,'watch-mobile','.heading-4 .right-text, h4 .right-text','font-family','$font-2','','',''),(34262,'watch-mobile','.w-list-type-1 .button-view a','font-family','$font-icons-2','4','','.w-list-type-1'),(34263,'watch-mobile','.w-search .button-search','font-family','$font-icons-2','3','','.w-search'),(34264,'watch-mobile','.w-tabs .tab-a','font-family','$font-1','','','.w-tabs'),(34265,'watch-mobile','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(34267,'watch-mobile','.w-list-type-1_3 .price','font-family','$font-1','','','.w-list-type-1_3'),(34268,'watch-mobile','body','font-family','$font-2','','',''),(34269,'watch-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','font-family','$font-icons-1','','','.w-filters'),(34270,'watch-mobile','.w-filters .filter-box-head','font-family','$font-1','','','.w-filters'),(34271,'watch-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','$font-icons-2','3','','.w-contact-contacts'),(34272,'watch-mobile','.w-currencies .current','font-family','$font-icons-2','3','','.w-currencies'),(34273,'watch-mobile','.w-compare-box-item .checkbox:checked + span:before','font-family','$font-icons-1','','','.w-compare-box-item'),(34274,'watch-mobile','.b-info-popup .info-popup','font-family','$font-icons-2','3','','.b-info-popup'),(34278,'watch-mobile','.w-menu-mobile .menu-ico','font-family','$font-icons-2','3','','.w-menu-mobile'),(34280,'watch-mobile','.b-fancybox .fancybox-nav span','font-family','trueloaded','','','.b-fancybox'),(34281,'watch-mobile','.heading-2, h2','font-family','$font-1','','',''),(34283,'watch-mobile','.p-wedding-registry-share .invite-remove','font-family','trueloaded','3','','.p-wedding-registry-share'),(34284,'watch-mobile','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(34285,'watch-mobile','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(34286,'watch-mobile','.w-categories .categories h2','font-family','inherit','','','.w-categories'),(34287,'watch-mobile','.w-top-categories .categories h2','font-family','inherit','','','.w-top-categories'),(34288,'watch-mobile','.b-rating .glyphicon','font-family','FontAwesome','','','.b-rating'),(34289,'watch-mobile','.b-rating #stars-default .glyphicon','font-family','$font-icons-2','','','.b-rating'),(34290,'watch-mobile','.w-cart .cart-box-link','font-family','$font-icons-2','3','','.w-cart'),(34291,'watch-mobile','.b-fancybox .fancybox-close','font-family','FontAwesome','3','','.b-fancybox'),(34292,'watch-mobile','.btn-3','font-family','$font-1','','',''),(34293,'watch-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','font-family','$font-icons-2','3','','.w-cart-discount-coupon'),(34294,'watch-mobile','.btn','font-family','$font-1','','',''),(34295,'watch-mobile','.w-top-categories .name','font-family','$font-1','','','.w-top-categories'),(34297,'watch-mobile','.heading-4, h4','font-family','$font-1','','',''),(34298,'watch-mobile','h1','font-family','$font-1','','',''),(34299,'watch-mobile','.w-catalog-listing-look .b2b','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(34300,'watch-mobile','.heading-3, h3','font-family','$font-1','','',''),(34303,'watch-mobile','.w-list-type-2_2 .sale','font-family','$font-icons-2','3','','.w-list-type-2_2'),(34305,'watch-mobile','.w-cart-give-away .ga_qty','font-family','$font-1','','','.w-cart-give-away'),(34306,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','font-family','$font-icons-2','3','','.w-list-type-2'),(34307,'watch-mobile','.w-list-type-2 .button-wishlist button','font-family','$font-2','','','.w-list-type-2'),(34308,'watch-mobile','.w-list-type-1_3 .sale','font-family','$font-icons-2','3','','.w-list-type-1_3'),(34309,'watch-mobile','.w-list-type-2 .button-wishlist button','font-family','$font-icons-2','4','','.w-list-type-2'),(34310,'watch-mobile','.w-catalog-listing-look .grid','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(34311,'watch-mobile','.view-all .btn','font-family','$font-icons-1','4','',''),(34312,'watch-mobile','.p-wedding-registry-share h1','font-family','FontAwesome','4','','.p-wedding-registry-share'),(34313,'watch-mobile','.p-wedding-registry-manage h1','font-family','FontAwesome','4','','.p-wedding-registry-manage'),(34314,'watch-mobile','.btn-2','font-family','$font-1','','',''),(34315,'watch-mobile','.p-wedding-registry-view h1','font-family','FontAwesome','3','','.p-wedding-registry-view'),(34316,'watch-mobile','.btn-1','font-family','$font-1','','',''),(34317,'watch-mobile','.heading-3 .edit, h3 .edit','font-family','$font-icons-2','4','',''),(34318,'watch-mobile','.w-list-type-1_3 .button-wishlist button','font-family','$font-icons-2','4','','.w-list-type-1_3'),(34319,'watch-mobile','.w-list-type-1_3 .button-wishlist button','font-family','$font-2','','','.w-list-type-1_3'),(34320,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','font-family','$font-icons-2','3','','.w-list-type-1_3'),(34321,'watch-mobile','.w-list-type-1_3 .button-view a','font-family','$font-icons-2','4','','.w-list-type-1_3'),(34322,'watch-mobile','.w-list-type-1_2 .sale','font-family','$font-icons-2','3','','.w-list-type-1_2'),(34323,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','font-family','$font-icons-2','3','','.w-list-type-1_2'),(34324,'watch-mobile','.w-list-type-1_2 .price','font-family','$font-1','','','.w-list-type-1_2'),(34325,'watch-mobile','.w-list-type-1_2 .button-wishlist button','font-family','$font-2','','','.w-list-type-1_2'),(34326,'watch-mobile','.w-list-type-1_2 .button-wishlist button','font-family','$font-icons-2','4','','.w-list-type-1_2'),(34327,'watch-mobile','.b-bottom .pop-up-close','font-family','$font-icons-1','3','','.b-bottom'),(34328,'watch-mobile','.w-list-type-1 .sale','font-family','$font-icons-2','3','','.w-list-type-1'),(34329,'watch-mobile','.w-list-type-1_2 .button-view a','font-family','$font-icons-2','4','','.w-list-type-1_2'),(34330,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','font-family','$font-icons-2','3','','.w-list-type-1'),(34331,'watch-mobile','.w-filters .mobileCollapse','font-family','$font-icons-1','4','','.w-filters'),(34332,'watch-mobile','.w-list-type-1 .button-wishlist button','font-family','$font-2','','','.w-list-type-1'),(34333,'watch-mobile','.transit-icon','font-family','$font-icons-1','3','',''),(34334,'watch-mobile','.w-list-type-1 .button-wishlist button','font-family','$font-icons-2','4','','.w-list-type-1'),(34335,'watch-mobile','.in-stock-icon','font-family','$font-icons-1','3','',''),(34336,'watch-mobile','.w-filters .open','font-family','$font-icons-1','3','','.w-filters'),(34337,'watch-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-family','$font-icons-1','','','.w-filters'),(34338,'watch-mobile','.heading-4 .edit, h4 .edit','font-family','$font-icons-2','4','',''),(34339,'watch-mobile','.heading-4 .edit, h4 .edit','font-family','$font-2','','',''),(34340,'watch-mobile','.w-filters span.close','font-family','$font-icons-1','3','','.w-filters'),(34341,'watch-mobile','.w-filters .view_more','font-family','$font-icons-1','4','','.w-filters'),(34342,'watch-mobile','.out-stock-icon','font-family','$font-icons-1','3','',''),(34343,'watch-mobile','.w-languages .current','font-family','$font-icons-2','3','','.w-languages'),(34344,'watch-mobile','.w-reviews .heading-3','font-family','$font-icons-2','3','','.w-reviews'),(34345,'watch-mobile','.w-quote .cart-box-link','font-family','$font-icons-2','3','','.w-quote'),(34346,'watch-mobile','.btn-del','font-family','$font-icons-1','4','',''),(34348,'watch-mobile','.b-info .info','font-family','$font-icons-2','3','','.b-info'),(34349,'watch-mobile','.b-info .info strong','font-family','$font-1','','','.b-info'),(34350,'watch-mobile','.b-products-listing .btn-preloader','font-family','FontAwesome','3','','.b-products-listing'),(34351,'watch-mobile','.b-products-listing .loader','font-family','FontAwesome','4','','.b-products-listing'),(34352,'watch-mobile','.b-products-listing .products-listing .bonus-points-cost','font-family','FontAwesome','3','','.b-products-listing'),(34353,'watch-mobile','.b-products-listing .products-listing .bonus-points-price','font-family','FontAwesome','3','','.b-products-listing'),(34354,'watch-mobile','.b-products-listing .products-listing .btn-buy','font-family','trueloaded','3','','.b-products-listing'),(34355,'watch-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-family','FontAwesome','','','.b-products-listing'),(34356,'watch-mobile','.b-products-listing .products-listing a.btn.view-button','font-family','trueloaded','3','','.b-products-listing'),(34357,'watch-mobile','.b-products-listing .products-listing h2','font-family','inherit','','','.b-products-listing'),(34358,'watch-mobile','.b-data-table table.dataTable thead td','font-family','$font-1','','','.b-data-table'),(34359,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(34360,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(34361,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(34362,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(34363,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(34364,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(34365,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-family','inherit','','','.b-h-inline'),(34366,'watch-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','font-family','FontAwesome','3','','.b-menu-burger_icon'),(34367,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','font-family','FontAwesome','4','','.b-menu-style-1'),(34368,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > .no-link','font-family','FontAwesome','4','','.b-menu-style-1'),(34369,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','font-family','FontAwesome','4','','.b-menu-style-1'),(34370,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','font-family','FontAwesome','3','','.b-menu-style-2'),(34371,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','font-family','FontAwesome','3','','.b-menu-style-2'),(34372,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-family','FontAwesome','3','','.b-menu-style-2'),(34373,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > .no-link','font-family','FontAwesome','4','','.b-menu-style-3'),(34374,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > .no-link','font-family','FontAwesome','3','','.b-menu-style-3'),(34375,'watch-mobile','.b-messages .select2-search-choice-close','font-family','trueloaded','3','','.b-messages'),(34376,'watch-mobile','.b-messages .messBtnMenuUnread','font-family','FontAwesome','3','','.b-messages'),(34377,'watch-mobile','.b-messages .messBtnMenuDelete','font-family','trueloaded','3','','.b-messages'),(34378,'watch-mobile','.b-messages span.starred::before','font-family','trueloaded','','','.b-messages'),(34379,'watch-mobile','.b-messages .messBtnMenuStarred','font-family','trueloaded','3','','.b-messages'),(34380,'watch-mobile','.b-messages .content_management_attach span','font-family','$font-2','','','.b-messages'),(34381,'watch-mobile','.b-preloader .preloader','font-family','FontAwesome','3','','.b-preloader'),(34382,'watch-mobile','.b-select-suggest .select2-search input','font-family','$font-2','','','.b-select-suggest'),(34383,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-family','$font-2','','','.b-select-suggest'),(34384,'watch-mobile','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(34385,'watch-mobile','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(34386,'watch-mobile','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(34387,'watch-mobile','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(34388,'watch-mobile','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(34389,'watch-mobile','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(34390,'watch-mobile','.b-upload-file .snapshot','font-family','FontAwesome','3','','.b-upload-file'),(34391,'watch-mobile','.b-upload-file .upload-file-wrap .upload-remove','font-family','trueloaded','3','','.b-upload-file'),(34392,'watch-mobile','.b-upload-files .remove-file','font-family','FontAwesome','3','','.b-upload-files'),(34393,'watch-mobile','.b-warehouses-popup .warehouses-popup-link','font-family','FontAwesome','3','','.b-warehouses-popup'),(34394,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','font-family','FontAwesome','3','','.b-warehouses-popup'),(34395,'watch-mobile','.batchPr .checkbox input:checked + span:before','font-family','$font-icons-1','','','.batchPr'),(34396,'watch-mobile','.bell-ico .heading-2','font-family','trueloaded','3','','.bell-ico'),(34397,'watch-mobile','.heading-ordered-items .heading-4','font-family','trueloaded','3','','.heading-ordered-items'),(34398,'watch-mobile','.heading-saved-lists .heading-4','font-family','trueloaded','3','','.heading-saved-lists'),(34399,'watch-mobile','.heading-settings .heading-4','font-family','trueloaded','3','','.heading-settings'),(34420,'watch-mobile','.p-payer-order-confirmation .discount-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(34421,'watch-mobile','.p-payer-order-confirmation .ship-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(34422,'watch-mobile','.p-payer-order-confirmation .comment-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(34423,'watch-mobile','.p-payer-order-confirmation .order-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(34424,'watch-mobile','.p-payer-order-confirmation .pay-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(34425,'watch-mobile','.p-payer-order-pay .order-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(34426,'watch-mobile','.p-payer-order-pay .pay-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(34427,'watch-mobile','.p-payer-order-pay .comment-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(34428,'watch-mobile','.p-payer-order-pay .discount-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(34429,'watch-mobile','.p-payer-order-pay .ship-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(34430,'watch-mobile','.p-quick-order-index .paginate_button.next','font-family','FontAwesome','3','','.p-quick-order-index'),(34431,'watch-mobile','.p-quick-order-index .paginate_button.previous','font-family','FontAwesome','3','','.p-quick-order-index'),(34432,'watch-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(34433,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(34434,'watch-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(34435,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(34436,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(34437,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(34438,'watch-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(34439,'watch-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(34440,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(34441,'watch-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(34442,'watch-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(34443,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(34444,'watch-mobile','.p-sample-checkout-success .page-success .text-1, .p-sample-checkout-success .page-success .text-2, .p-sample-checkout-success .page-success .text-3','font-family','$font-1','','','.p-sample-checkout-success'),(34445,'watch-mobile','.p-sample-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-sample-checkout-success'),(34446,'watch-mobile','.savings-ico .heading-2','font-family','trueloaded','3','','.savings-ico'),(34447,'watch-mobile','.shipping-ico .heading-2','font-family','trueloaded','3','','.shipping-ico'),(34448,'watch-mobile','.shipping-ico .heading-2','font-family','trueloaded','3','','.shipping-ico'),(34449,'watch-mobile','.shipping-ico .heading-2','font-family','trueloaded','3','','.shipping-ico'),(34450,'watch-mobile','.w-account-address-book .add_item a','font-family','$font-icons-1','3','','.w-account-address-book'),(34451,'watch-mobile','.w-account-personal-catalog .list-switcher a','font-family','$font-1','','','.w-account-personal-catalog'),(34452,'watch-mobile','.w-blog-widget-post-listing .post_name','font-family','$font-1','','','.w-blog-widget-post-listing'),(34453,'watch-mobile','.w-blog-widget-post-share .pinterest-btn','font-family','FontAwesome','3','','.w-blog-widget-post-share'),(34454,'watch-mobile','.w-blog-widget-post-share .facebook-btn','font-family','FontAwesome','3','','.w-blog-widget-post-share'),(34455,'watch-mobile','.w-blog-widget-post-share .twitter-btn','font-family','FontAwesome','3','','.w-blog-widget-post-share'),(34456,'watch-mobile','.w-cart-bonus-points .title','font-family','FontAwesome','3','','.w-cart-bonus-points'),(34457,'watch-mobile','.w-cart-bonus-points .btn-remove','font-family','trueloaded','3','','.w-cart-bonus-points'),(34458,'watch-mobile','.w-cart-compare .price-cell','font-family','$font-1','','','.w-cart-compare'),(34459,'watch-mobile','.w-cart-compare .cart-name a','font-family','$font-1','','','.w-cart-compare'),(34460,'watch-mobile','.w-cart-compare .atr-col','font-family','FontAwesome','3','','.w-cart-compare'),(34461,'watch-mobile','.w-cart-compare .product-actions .dropdown-toggle','font-family','FontAwesome','3','','.w-cart-compare'),(34462,'watch-mobile','.w-cart-credit-amount .amount-title','font-family','trueloaded','3','','.w-cart-credit-amount'),(34463,'watch-mobile','.w-cart-credit-amount .btn-remove','font-family','trueloaded','3','','.w-cart-credit-amount'),(34464,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-family','$font-icons-2','3','','.w-catalog-compare'),(34465,'watch-mobile','.w-catalog-paging .next','font-family','FontAwesome','3','','.w-catalog-paging'),(34466,'watch-mobile','.w-catalog-paging .prev','font-family','FontAwesome','3','','.w-catalog-paging'),(34467,'watch-mobile','.w-checkout-bonus-points .btn-remove','font-family','trueloaded','3','','.w-checkout-bonus-points'),(34468,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','font-family','FontAwesome','3','','.w-checkout-contact-information'),(34469,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','font-family','FontAwesome','3','','.w-checkout-contact-information'),(34470,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','font-family','FontAwesome','3','','.w-checkout-contact-information'),(34471,'watch-mobile','.w-checkout-create-account .account-benefits strong','font-family','trueloaded','3','','.w-checkout-create-account'),(34472,'watch-mobile','.w-checkout-credit-amount .btn-remove','font-family','trueloaded','3','','.w-checkout-credit-amount'),(34473,'watch-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-family','$font-1','','','.w-communication-new-topic'),(34474,'watch-mobile','.w-coupons-and-vauchers-checkout .btn-remove','font-family','trueloaded','3','','.w-coupons-and-vauchers-checkout'),(34475,'watch-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','font-family','FontAwesome','3','','.w-multi-cart-actions'),(34476,'watch-mobile','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-family','$font-1','','','.w-multi-cart-cart-switcher'),(34477,'watch-mobile','.w-product-cross-sell .buy-all-checker','font-family','FontAwesome','3','','.w-product-cross-sell'),(34478,'watch-mobile','.w-promotions .nextdiscount .heading','font-family','FontAwesome','3','','.w-promotions'),(34479,'watch-mobile','.w-social-links a','font-family','FontAwesome','','','.w-social-links'),(34480,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-family','FontAwesome','3','','.w-upload-customer-id-upload-customer-id-form'),(34481,'watch-mobile','.w-wedding-registry-widgets-manage-names .names-separator','font-family','FontAwesome','3','','.w-wedding-registry-widgets-manage-names'),(34482,'watch-mobile','.w-wedding-registry-widgets-products .remove-btn','font-family','trueloaded','3','','.w-wedding-registry-widgets-products'),(34483,'watch-mobile','.w-wedding-registry-widgets-search-registry-button a','font-family','FontAwesome','3','','.w-wedding-registry-widgets-search-registry-button'),(34484,'watch-mobile','.w-wedding-registry-widgets-share-link a','font-family','FontAwesome','3','','.w-wedding-registry-widgets-share-link'),(34485,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','font-family','$font-icons-1','','','.w-filters'),(34486,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','font-family','$font-icons-1','','','.w-filters'),(34487,'watch-mobile','.b-rating .glyphicon','font-family_important','important','','','.b-rating'),(34488,'watch-mobile','.b-rating #stars-default .glyphicon','font-family_important','important','','','.b-rating'),(34489,'watch-mobile','.w-bestsellers .item','font-size','32','3','','.w-bestsellers'),(34490,'watch-mobile','.w-bestsellers .heading-3','font-size','50','3','','.w-bestsellers'),(34491,'watch-mobile','.w-account .my-acc-link','font-size','30','3','','.w-account'),(34492,'watch-mobile','.b-switch .bootstrap-switch','font-size','16','','','.b-switch'),(34493,'watch-mobile','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(34494,'watch-mobile','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(34495,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','20','3','','.b-slick'),(34496,'watch-mobile','.w-list-type-1 .rating-count','font-size','14','','','.w-list-type-1'),(34497,'watch-mobile','.w-tabs .accordion-heading','font-size','20','','','.w-tabs'),(34498,'watch-mobile','.w-list-type-1 .price','font-size','20','','','.w-list-type-1'),(34499,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(34500,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-size','18','','','.b-form'),(34501,'watch-mobile','.w-product-sale-ends .ends','font-size','26','','','.w-product-sale-ends'),(34502,'watch-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','font-size','18','','','.b-form'),(34503,'watch-mobile','.w-sale .left-count-days','font-size','40','','','.w-sale'),(34504,'watch-mobile','.w-sale .left-count-hours','font-size','40','','','.w-sale'),(34505,'watch-mobile','.w-menu-slider .menu-ico','font-size','23','','','.w-menu-slider'),(34506,'watch-mobile','.w-menu-horizontal .menu-ico','font-size','23','','','.w-menu-horizontal'),(34507,'watch-mobile','.w-sale .name','font-size','20','','','.w-sale'),(34508,'watch-mobile','.w-list-type-2_2 .title','font-size','16','','','.w-list-type-2_2'),(34509,'watch-mobile','.w-sale .percents','font-size','30','','','.w-sale'),(34510,'watch-mobile','.w-sale .badge','font-size','20','','','.w-sale'),(34511,'watch-mobile','.w-html_box .socials a','font-size','26','','','.w-html_box'),(34512,'watch-mobile','.w-menu-style-1 .menu-ico','font-size','23','','','.w-menu-style-1'),(34513,'watch-mobile','.w-menu-style-1 > ul','font-size','16','','','.w-menu-style-1'),(34514,'watch-mobile','.w-product-sale-ends .left-count-hours','font-size','40','','','.w-product-sale-ends'),(34515,'watch-mobile','.w-product-sale-ends .left-count-days','font-size','40','','','.w-product-sale-ends'),(34516,'watch-mobile','.w-product-sale-ends .left-text-right','font-size','24','','','.w-product-sale-ends'),(34517,'watch-mobile','.w-product-sale-ends .left-text-left','font-size','24','','','.w-product-sale-ends'),(34518,'watch-mobile','.w-cart .cart-box-link','font-size','30','3','','.w-cart'),(34520,'watch-mobile','.w-product-collection .right-area .special','font-size','30','','','.w-product-collection'),(34521,'watch-mobile','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(34522,'watch-mobile','.w-product-personal-catalog-button .btn','font-size','14','','','.w-product-personal-catalog-button'),(34523,'watch-mobile','.w-html_box .socials a','font-size','30','290','','.w-html_box'),(34529,'watch-mobile','.p-account-trade-form .address-wrapp','font-size','14','','','.p-account-trade-form'),(34530,'watch-mobile','.w-compare-box-item .cb_title','font-size','16','','','.w-compare-box-item'),(34531,'watch-mobile','.w-categories .name','font-size','18','','','.w-categories'),(34532,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-size','0.7','4','','.b-multi-page-checkout'),(34533,'watch-mobile','.w-cart-give-away .ga_qty','font-size','17','290','','.w-cart-give-away'),(34534,'watch-mobile','.b-price-box .price-box .price-row.total','font-size','24','','','.b-price-box'),(34535,'watch-mobile','.b-price-box .price-box','font-size','18','','','.b-price-box'),(34536,'watch-mobile','.w-cart-checkout-btn a','font-size','17','290','','.w-cart-checkout-btn'),(34537,'watch-mobile','.w-product-reviews .reviews-list .date','font-size','14','','','.w-product-reviews'),(34538,'watch-mobile','.w-product-reviews .reviews-list span','font-size','22','','','.w-product-reviews'),(34539,'watch-mobile','.w-reviews .date','font-size','14','','','.w-reviews'),(34540,'watch-mobile','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(34541,'watch-mobile','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(34542,'watch-mobile','.w-product-properties li','font-size','14','','','.w-product-properties'),(34543,'watch-mobile','.w-product-in-bundles .product-link','font-size','16','','','.w-product-in-bundles'),(34544,'watch-mobile','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(34545,'watch-mobile','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(34546,'watch-mobile','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(34547,'watch-mobile','.price .old','font-size','0.8','','',''),(34550,'watch-mobile','.p-blog-index .post-title','font-size','20','','','.p-blog-index'),(34551,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','font-size','14','','','.p-blog-index'),(34553,'watch-mobile','.p-blog-index .wp-widget li','font-size','8','3','','.p-blog-index'),(34554,'watch-mobile','.w-filters .head-filter-widget','font-size','21','298','','.w-filters'),(34555,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-size','24','','','.b-multi-page-checkout'),(34556,'watch-mobile','.b-info-popup .info-popup div','font-size','14','','','.b-info-popup'),(34557,'watch-mobile','.w-promo-code .holder','font-size','30','320,3','','.w-promo-code'),(34558,'watch-mobile','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(34559,'watch-mobile','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(34560,'watch-mobile','.p-wedding-registry-manage a.remove-btn','font-size','22','','','.p-wedding-registry-manage'),(34562,'watch-mobile','.w-product-bonus-points > div','font-size','14','','','.w-product-bonus-points'),(34570,'watch-mobile','.testimonials .date','font-size','14','','',''),(34572,'watch-mobile','.testimonials .heading-3','font-size','37','3','',''),(34573,'watch-mobile','.js-stock','font-size','14','','',''),(34574,'watch-mobile','.testimonials .rating','font-size','22','','',''),(34575,'watch-mobile','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(34576,'watch-mobile','.testimonials .reviews-list span','font-size','22','','',''),(34577,'watch-mobile','.testimonials .reviews-list .date','font-size','14','','',''),(34578,'watch-mobile','.b-bottom .confirm-popup .confirm-text','font-size','20','','','.b-bottom'),(34579,'watch-mobile','.b-pagination .pagination .prev','font-size','20','3','','.b-pagination'),(34580,'watch-mobile','.p-wedding-registry-manage .wr-search button','font-size','23','3','','.p-wedding-registry-manage'),(34581,'watch-mobile','.b-pagination .pagination .next','font-size','20','3','','.b-pagination'),(34583,'watch-mobile','.p-blog-index .nav-previous a','font-size','40','3','','.p-blog-index'),(34584,'watch-mobile','.p-blog-index .nav-next a','font-size','40','3','','.p-blog-index'),(34585,'watch-mobile','.p-blog-index .comment-metadata','font-size','14','','','.p-blog-index'),(34586,'watch-mobile','.p-blog-index .author','font-size','20','','','.p-blog-index'),(34587,'watch-mobile','.no-found','font-size','1.4','','',''),(34588,'watch-mobile','.w-list-type-2_2 .sale','font-size','19','3','','.w-list-type-2_2'),(34589,'watch-mobile','.w-list-type-2_2 .price .old','font-size','18','','','.w-list-type-2_2'),(34590,'watch-mobile','.w-list-type-2_2 .properties','font-size','13','','','.w-list-type-2_2'),(34591,'watch-mobile','.w-list-type-2_2 .price','font-size','24','','','.w-list-type-2_2'),(34592,'watch-mobile','.w-list-type-2_2 .products-model','font-size','13','','','.w-list-type-2_2'),(34593,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','font-size','28','3','','.w-list-type-2_2'),(34594,'watch-mobile','.w-list-type-2 .title','font-size','16','','','.w-list-type-2'),(34595,'watch-mobile','.w-list-type-2_2 .button-view a','font-size','16','','','.w-list-type-2_2'),(34596,'watch-mobile','.w-list-type-2 .price .old','font-size','18','','','.w-list-type-2'),(34597,'watch-mobile','.w-list-type-2 .products-model','font-size','13','','','.w-list-type-2'),(34598,'watch-mobile','.w-list-type-2 .price','font-size','24','','','.w-list-type-2'),(34599,'watch-mobile','.w-product-wedding-registry-button .btn','font-size','14','','','.w-product-wedding-registry-button'),(34600,'watch-mobile','.w-product-personal-catalog-button .btn','font-size','21','3','','.w-product-personal-catalog-button'),(34601,'watch-mobile','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(34602,'watch-mobile','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(34603,'watch-mobile','.w-list-type-2_2 .button-wishlist button','font-size','16','','','.w-list-type-2_2'),(34604,'watch-mobile','.b-fancybox .fancybox-close','font-size','26','','','.b-fancybox'),(34605,'watch-mobile','.p-reviews-info .review_by .rating-1, .p-reviews-info .review_by .rating-2, .p-reviews-info .review_by .rating-3, .p-reviews-info .review_by .rating-4, .p-reviews-info .review_by .rating-5','font-size','20','','','.p-reviews-info'),(34606,'watch-mobile','.p-reviews-info .reviews-info h1','font-size','30','','','.p-reviews-info'),(34607,'watch-mobile','.w-list-type-2_2 .sale','font-size','17','4','','.w-list-type-2_2'),(34608,'watch-mobile','.w-delivery-location-top-location-list .deliveryName a','font-size','21','','','.w-delivery-location-top-location-list'),(34609,'watch-mobile','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(34610,'watch-mobile','.w-chat .w-chat-box a','font-size','20','3','','.w-chat'),(34611,'watch-mobile','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(34612,'watch-mobile','.b-bottom .alert-message','font-size','18','','','.b-bottom'),(34613,'watch-mobile','.p-wedding-registry-index .search-list label','font-size','24','','','.p-wedding-registry-index'),(34614,'watch-mobile','.p-wedding-registry-index .main-button','font-size','20','4','','.p-wedding-registry-index'),(34615,'watch-mobile','.p-wedding-registry-index .main-button','font-size','20','3','','.p-wedding-registry-index'),(34616,'watch-mobile','.p-wedding-registry-manage .links a','font-size','16','','','.p-wedding-registry-manage'),(34617,'watch-mobile','.p-wedding-registry-manage .links','font-size','0','','','.p-wedding-registry-manage'),(34618,'watch-mobile','.p-wedding-registry-manage .links a.share-registry','font-size','20','','','.p-wedding-registry-manage'),(34619,'watch-mobile','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(34620,'watch-mobile','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(34621,'watch-mobile','.p-wedding-registry-manage .wedding-date','font-size','20','','','.p-wedding-registry-manage'),(34622,'watch-mobile','.p-wedding-registry-search h1','font-size','22','4','','.p-wedding-registry-search'),(34623,'watch-mobile','.p-wedding-registry-search h1','font-size','22','3','','.p-wedding-registry-search'),(34626,'watch-mobile','.p-wedding-registry-manage h1','font-size','22','3','','.p-wedding-registry-manage'),(34627,'watch-mobile','.p-wedding-registry-share h1','font-size','22','3','','.p-wedding-registry-share'),(34629,'watch-mobile','.b-compare .clear_all','font-size','16','4','','.b-compare'),(34630,'watch-mobile','.b-bottom .popup-heading','font-size','16','','','.b-bottom'),(34631,'watch-mobile','.b-compare .compare-head','font-size','22','','','.b-compare'),(34632,'watch-mobile','.w-chat .w-chat-box a','font-size','30','303,3','','.w-chat'),(34633,'watch-mobile','.w-quote .cart-box-link','font-size','30','299,3','','.w-quote'),(34634,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','0','','','.b-slick'),(34635,'watch-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(34636,'watch-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','font-size','28','','','.w-filters'),(34637,'watch-mobile','.w-list-type-1_3 .price .old','font-size','18','','','.w-list-type-1_3'),(34638,'watch-mobile','.w-list-type-1_3 .properties','font-size','13','','','.w-list-type-1_3'),(34639,'watch-mobile','.w-list-type-1_3 .products-model','font-size','13','','','.w-list-type-1_3'),(34642,'watch-mobile','.w-tabs .tab-a','font-size','20','','','.w-tabs'),(34643,'watch-mobile','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(34645,'watch-mobile','.heading-4, h4','font-size','18','','',''),(34646,'watch-mobile','.p-account-trade-form .widget h3','font-size','24','','','.p-account-trade-form'),(34647,'watch-mobile','.p-quote-cart-index .cart-page .empty','font-size','24','','','.p-quote-cart-index'),(34649,'watch-mobile','.p-shopping-cart-index .cart-page .empty','font-size','24','','','.p-shopping-cart-index'),(34650,'watch-mobile','.b-price-box .price-box .price-row.total','font-size','20','319','','.b-price-box'),(34651,'watch-mobile','.w-filters .head-filter-widget','font-size','24','','','.w-filters'),(34653,'watch-mobile','.w-currencies .current','font-size','26','3','','.w-currencies'),(34654,'watch-mobile','.w-filters .filter-box-head','font-size','20','','','.w-filters'),(34655,'watch-mobile','.heading-4 .right-text, h4 .right-text','font-size','16','','',''),(34656,'watch-mobile','.w-compare-box-item .checkbox:checked + span:before','font-size','18','','','.w-compare-box-item'),(34657,'watch-mobile','.heading-3 .edit, h3 .edit','font-size','16','','',''),(34658,'watch-mobile','.p-reviews-info .review-info-reviewed_by, .review-info-date','font-size','14','','','.p-reviews-info'),(34660,'watch-mobile','.p-account-subscription-historyinfo .order_history_table th','font-size','16','','','.p-account-subscription-historyinfo'),(34661,'watch-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-size','24','','','.p-account-subscription-historyinfo'),(34668,'watch-mobile','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(34669,'watch-mobile','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(34670,'watch-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(34671,'watch-mobile','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(34672,'watch-mobile','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(34673,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','font-size','14','','',''),(34674,'watch-mobile','.heading-3, h3','font-size','20','','',''),(34680,'watch-mobile','.p-wedding-registry-share .invite-remove','font-size','20','','','.p-wedding-registry-share'),(34681,'watch-mobile','.w-sale .left-text-right','font-size','24','','','.w-sale'),(34682,'watch-mobile','.w-sale .ends','font-size','26','','','.w-sale'),(34683,'watch-mobile','.w-sale .left-text-left','font-size','24','','','.w-sale'),(34684,'watch-mobile','.w-sale .old','font-size','45','','','.w-sale'),(34685,'watch-mobile','.w-sale .special-price','font-size','70','','','.w-sale'),(34686,'watch-mobile','.w-text .customer-service','font-size','21','3','','.w-text'),(34687,'watch-mobile','.w-text .customer-service','font-size','13','','','.w-text'),(34688,'watch-mobile','.b-page-name .page-name','font-size','20','','','.b-page-name'),(34689,'watch-mobile','.w-text .customer-service b','font-size','18','','','.w-text'),(34690,'watch-mobile','.w-top-categories .categories h2','font-size','inherit','','','.w-top-categories'),(34691,'watch-mobile','.w-categories .categories h2','font-size','inherit','','','.w-categories'),(34692,'watch-mobile','.b-form .cart-popup .price','font-size','18','','','.b-form'),(34693,'watch-mobile','.b-quantity .qty-box .smaller','font-size','31','','','.b-quantity'),(34694,'watch-mobile','.b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(34695,'watch-mobile','.w-tabs .tab-a','font-size','16','291','','.w-tabs'),(34696,'watch-mobile','h1','font-size','26','291','',''),(34697,'watch-mobile','.b-fancybox .fancybox-nav span','font-size','34','','','.b-fancybox'),(34698,'watch-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','font-size','22','3','','.w-cart-discount-coupon'),(34699,'watch-mobile','.w-cart-discount-coupon .gift-code p','font-size','13','','','.w-cart-discount-coupon'),(34700,'watch-mobile','.w-filters .head-filter-widget > span','font-size','18','303','','.w-filters'),(34701,'watch-mobile','.w-cart .cart-total','font-size','1.2','','','.w-cart'),(34703,'watch-mobile','.heading-2, h2','font-size','24','','',''),(34704,'watch-mobile','h1','font-size','32','','',''),(34709,'watch-mobile','.b-form #payment_method .title','font-size','16','','','.b-form'),(34710,'watch-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(34711,'watch-mobile','.w-menu-mobile .menu-ico','font-size','23','','','.w-menu-mobile'),(34712,'watch-mobile','.w-cart .qty','font-size','0.6','4','','.w-cart'),(34713,'watch-mobile','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(34714,'watch-mobile','.w-cart-give-away .ga_qty','font-size','20','','','.w-cart-give-away'),(34715,'watch-mobile','.w-cart-give-away .ga_name','font-size','16','','','.w-cart-give-away'),(34716,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','font-size','28','3','','.w-list-type-2'),(34717,'watch-mobile','.w-list-type-2 .button-view a','font-size','16','','','.w-list-type-2'),(34718,'watch-mobile','.w-list-type-1_3 .title','font-size','16','','','.w-list-type-1_3'),(34719,'watch-mobile','.w-list-type-2 .properties','font-size','13','','','.w-list-type-2'),(34720,'watch-mobile','.w-list-type-2 .button-wishlist button','font-size','16','','','.w-list-type-2'),(34721,'watch-mobile','.p-wedding-registry-manage h1','font-size','22','4','','.p-wedding-registry-manage'),(34722,'watch-mobile','.price','font-size','24','','',''),(34723,'watch-mobile','.w-list-type-1_3 .sale','font-size','17','4','','.w-list-type-1_3'),(34724,'watch-mobile','.view-all .btn','font-size','0.8','4','',''),(34725,'watch-mobile','.w-list-type-1_3 .sale','font-size','19','3','','.w-list-type-1_3'),(34726,'watch-mobile','.w-list-type-2 .sale','font-size','17','4','','.w-list-type-2'),(34727,'watch-mobile','.p-wedding-registry-view h1','font-size','22','3','','.p-wedding-registry-view'),(34728,'watch-mobile','.p-wedding-registry-view h1','font-size','22','4','','.p-wedding-registry-view'),(34729,'watch-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','font-size','14','','','.p-wedding-registry-manage'),(34730,'watch-mobile','.w-list-type-2 .sale','font-size','19','3','','.w-list-type-2'),(34731,'watch-mobile','.p-wedding-registry-share h1','font-size','22','4','','.p-wedding-registry-share'),(34732,'watch-mobile','.btn','font-size','16','','',''),(34733,'watch-mobile','.heading-3 .right-text, h3 .right-text','font-size','16','','',''),(34734,'watch-mobile','.btn-2','font-size','20','','',''),(34735,'watch-mobile','.btn-3','font-size','20','','',''),(34736,'watch-mobile','.btn-1','font-size','16','','',''),(34737,'watch-mobile','.w-list-type-1_3 .price','font-size','24','','','.w-list-type-1_3'),(34738,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','font-size','28','3','','.w-list-type-1_3'),(34739,'watch-mobile','.w-list-type-1_3 .button-wishlist button','font-size','16','','','.w-list-type-1_3'),(34740,'watch-mobile','.w-list-type-1_3 .button-view a','font-size','16','','','.w-list-type-1_3'),(34741,'watch-mobile','.w-list-type-1_2 .sale','font-size','19','3','','.w-list-type-1_2'),(34742,'watch-mobile','.w-list-type-1_2 .sale','font-size','17','4','','.w-list-type-1_2'),(34743,'watch-mobile','.w-list-type-1_2 .title','font-size','16','','','.w-list-type-1_2'),(34744,'watch-mobile','.w-list-type-1_2 .products-model','font-size','13','','','.w-list-type-1_2'),(34745,'watch-mobile','.w-list-type-1_2 .price .old','font-size','18','','','.w-list-type-1_2'),(34746,'watch-mobile','.w-list-type-1_2 .price','font-size','24','','','.w-list-type-1_2'),(34747,'watch-mobile','.w-list-type-1_2 .properties','font-size','13','','','.w-list-type-1_2'),(34748,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','font-size','28','3','','.w-list-type-1_2'),(34749,'watch-mobile','.w-list-type-1 .sale','font-size','17','4','','.w-list-type-1'),(34750,'watch-mobile','.w-list-type-1_2 .button-wishlist button','font-size','16','','','.w-list-type-1_2'),(34751,'watch-mobile','.b-bottom .pop-up-close','font-size','25','','','.b-bottom'),(34752,'watch-mobile','.b-bottom .footerTitle','font-size','24','','','.b-bottom'),(34753,'watch-mobile','.w-list-type-1 .rating','font-size','12','','','.w-list-type-1'),(34754,'watch-mobile','.w-list-type-1 .title','font-size','16','','','.w-list-type-1'),(34755,'watch-mobile','.w-list-type-1 .products-model','font-size','13','','','.w-list-type-1'),(34756,'watch-mobile','.w-list-type-1_2 .button-view a','font-size','16','','','.w-list-type-1_2'),(34757,'watch-mobile','.w-list-type-1 .sale','font-size','19','3','','.w-list-type-1'),(34758,'watch-mobile','.w-list-type-1 .properties','font-size','13','','','.w-list-type-1'),(34759,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','font-size','28','3','','.w-list-type-1'),(34760,'watch-mobile','.heading-3 .edit, h3 .edit','font-size','14','4','',''),(34761,'watch-mobile','.heading-4 .edit, h4 .edit','font-size','16','','',''),(34762,'watch-mobile','.transit','font-size','14','','',''),(34763,'watch-mobile','.out-stock','font-size','14','','',''),(34764,'watch-mobile','.w-list-type-1 .button-wishlist button','font-size','16','','','.w-list-type-1'),(34765,'watch-mobile','.in-stock','font-size','14','','',''),(34766,'watch-mobile','.w-filters .mobileCollapse','font-size','20','4','','.w-filters'),(34767,'watch-mobile','.w-filters .view_more','font-size','16','4','','.w-filters'),(34768,'watch-mobile','.w-list-type-1 .button-view a','font-size','16','','','.w-list-type-1'),(34769,'watch-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-size','28','','','.w-filters'),(34770,'watch-mobile','.w-languages .current','font-size','26','3','','.w-languages'),(34771,'watch-mobile','.w-top-categories .name','font-size','18','','','.w-top-categories'),(34772,'watch-mobile','.w-reviews .heading-3','font-size','37','3','','.w-reviews'),(34773,'watch-mobile','.w-quote .cart-box-link','font-size','1.5','3','','.w-quote'),(34774,'watch-mobile','.w-reviews .rating','font-size','22','','','.w-reviews'),(34775,'watch-mobile','.w-search .button-search','font-size','23','3','','.w-search'),(34776,'watch-mobile','.w-reviews .reviews-list span','font-size','22','','','.w-reviews'),(34777,'watch-mobile','.w-reviews .reviews-list .date','font-size','14','','','.w-reviews'),(34778,'watch-mobile','.w-search .search-input','font-size','14','','','.w-search'),(34779,'watch-mobile','.b-form .middle-form .middle-rating span','font-size','26','','','.b-form'),(34780,'watch-mobile','.b-form .required-message','font-size','14','','','.b-form'),(34781,'watch-mobile','.b-info .info','font-size','30','3','','.b-info'),(34785,'watch-mobile','.b-info .info strong','font-size','18','','','.b-info'),(34786,'watch-mobile','.b-info-popup .info-popup','font-size','30','3','','.b-info-popup'),(34787,'watch-mobile','.b-products-listing .btn-preloader','font-size','24','3','','.b-products-listing'),(34788,'watch-mobile','.b-products-listing .loader','font-size','30','4','','.b-products-listing'),(34789,'watch-mobile','.b-products-listing .products-listing .attribute-qty-block','font-size','14','','','.b-products-listing'),(34790,'watch-mobile','.b-products-listing .products-listing .bonusPoints','font-size','13','','','.b-products-listing'),(34791,'watch-mobile','.b-products-listing .products-listing .btn-buy','font-size','20','3','','.b-products-listing'),(34792,'watch-mobile','.b-products-listing .products-listing .model','font-size','14','','','.b-products-listing'),(34793,'watch-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','font-size','20','','','.b-products-listing'),(34794,'watch-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-size','20','','','.b-products-listing'),(34795,'watch-mobile','.b-products-listing .products-listing h2','font-size','inherit','','','.b-products-listing'),(34796,'watch-mobile','.b-products-listing .promos-info .promo-name','font-size','14','','','.b-products-listing'),(34797,'watch-mobile','.b-products-listing .wedding-registry-count','font-size','14','','','.b-products-listing'),(34798,'watch-mobile','.b-products-listing .products-listing .out-stock','font-size','11','','','.b-products-listing'),(34799,'watch-mobile','.b-products-listing .products-listing .name','font-size','14','','','.b-products-listing'),(34800,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.b-data-table'),(34801,'watch-mobile','.b-data-table table.dataTable thead td','font-size','16','','','.b-data-table'),(34802,'watch-mobile','.b-email .qty','font-size','14','','','.b-email'),(34803,'watch-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(34804,'watch-mobile','.b-email .model','font-size','14','','','.b-email'),(34805,'watch-mobile','.b-email .qty','font-size','14','','','.b-email'),(34806,'watch-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(34807,'watch-mobile','.b-email .model','font-size','14','','','.b-email'),(34808,'watch-mobile','.b-email .name','font-size','14','','','.b-email'),(34809,'watch-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(34810,'watch-mobile','.b-email .name','font-size','14','','','.b-email'),(34811,'watch-mobile','.b-email .model','font-size','14','','','.b-email'),(34812,'watch-mobile','.b-email .model','font-size','14','','','.b-email'),(34813,'watch-mobile','.b-email .name','font-size','14','','','.b-email'),(34814,'watch-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(34815,'watch-mobile','.b-email .qty','font-size','14','','','.b-email'),(34816,'watch-mobile','.b-email .qty','font-size','14','','','.b-email'),(34817,'watch-mobile','.b-email .qty','font-size','14','','','.b-email'),(34818,'watch-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(34819,'watch-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(34820,'watch-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(34821,'watch-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(34822,'watch-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(34823,'watch-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(34824,'watch-mobile','.b-email .price','font-size','14','','','.b-email'),(34825,'watch-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(34826,'watch-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(34827,'watch-mobile','.b-email .name','font-size','14','','','.b-email'),(34828,'watch-mobile','.b-email .price','font-size','14','','','.b-email'),(34829,'watch-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(34830,'watch-mobile','.b-email .qty','font-size','14','','','.b-email'),(34831,'watch-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(34832,'watch-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(34833,'watch-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(34834,'watch-mobile','.b-email .price','font-size','14','','','.b-email'),(34835,'watch-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(34836,'watch-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(34837,'watch-mobile','.b-email .price','font-size','14','','','.b-email'),(34838,'watch-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(34839,'watch-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(34840,'watch-mobile','.b-email .price','font-size','14','','','.b-email'),(34841,'watch-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(34842,'watch-mobile','.b-email .price','font-size','14','','','.b-email'),(34843,'watch-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(34844,'watch-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(34845,'watch-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(34846,'watch-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(34847,'watch-mobile','.b-email .model','font-size','14','','','.b-email'),(34848,'watch-mobile','.b-email .name','font-size','14','','','.b-email'),(34849,'watch-mobile','.b-email .name','font-size','14','','','.b-email'),(34850,'watch-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(34851,'watch-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(34852,'watch-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(34853,'watch-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(34854,'watch-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(34855,'watch-mobile','.b-email .model','font-size','14','','','.b-email'),(34856,'watch-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(34857,'watch-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(34858,'watch-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(34859,'watch-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(34860,'watch-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(34861,'watch-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(34862,'watch-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(34863,'watch-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(34864,'watch-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(34865,'watch-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(34866,'watch-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(34867,'watch-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(34868,'watch-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(34869,'watch-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(34870,'watch-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(34871,'watch-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(34872,'watch-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(34873,'watch-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(34874,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-size','inherit','','','.b-h-inline'),(34875,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(34876,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(34877,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(34878,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(34879,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(34880,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(34881,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(34882,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(34883,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(34884,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev63_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(34885,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','font-size','16','','','.b-menu-style-1'),(34886,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','font-size','18','','','.b-menu-style-1'),(34887,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','font-size','14','','','.b-menu-style-2'),(34888,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','font-size','14','','','.b-menu-style-2'),(34889,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','font-size','26','','','.b-menu-style-2'),(34890,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','font-size','20','3','','.b-menu-style-2'),(34891,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-size','20','3','','.b-menu-style-2'),(34892,'watch-mobile','.b-messages .content-messages .heading-2','font-size','26','','','.b-messages'),(34893,'watch-mobile','.b-messages span.starred::before','font-size','16','','','.b-messages'),(34894,'watch-mobile','.b-messages .messBtnMenuStarred','font-size','22','3','','.b-messages'),(34895,'watch-mobile','.b-messages .messBtnMenuDelete','font-size','22','3','','.b-messages'),(34896,'watch-mobile','.b-messages .messBtnMenuUnread','font-size','22','3','','.b-messages'),(34897,'watch-mobile','.b-messages .messMenuButton span','font-size','14','','','.b-messages'),(34898,'watch-mobile','.b-messages .content_management_attach button','font-size','14','','','.b-messages'),(34899,'watch-mobile','.b-messages .content_management_attach','font-size','14','','','.b-messages'),(34900,'watch-mobile','.b-messages .content_management_attach span','font-size','16','','','.b-messages'),(34901,'watch-mobile','.b-messages .select2-search-choice-close','font-size','11','3','','.b-messages'),(34902,'watch-mobile','.b-preloader .preloader','font-size','40','3','','.b-preloader'),(34903,'watch-mobile','.b-select-suggest .select2-search-choice-close','font-size','1','','','.b-select-suggest'),(34904,'watch-mobile','.b-select-suggest .select2-search input','font-size','1','','','.b-select-suggest'),(34905,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','font-size','1','','','.b-select-suggest'),(34906,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-size','100','','','.b-select-suggest'),(34907,'watch-mobile','.b-sub-totals .historyTotal table td','font-size','18','','','.b-sub-totals'),(34908,'watch-mobile','.b-sub-totals .historyTotal table tr:last-child td','font-size','24','','','.b-sub-totals'),(34909,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(34910,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(34911,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(34912,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(34913,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(34914,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(34915,'watch-mobile','.b-trade-approval .middle-form label','font-size','16','','','.b-trade-approval'),(34916,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','font-size','14','','','.b-trade-approval'),(34917,'watch-mobile','.b-upload-file .snapshot','font-size','18','','','.b-upload-file'),(34918,'watch-mobile','.b-warehouses-popup .warehouses-popup .heading','font-size','18','','','.b-warehouses-popup'),(34919,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','font-size','14','','','.b-warehouses-popup'),(34920,'watch-mobile','.b-warehouses-popup a.warehouses-popup-link','font-size','14','','','.b-warehouses-popup'),(34921,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-name','font-size','16','','','.b-warehouses-popup'),(34922,'watch-mobile','.batchPr .w-batch-products .products-listing .name a','font-size','16','','','.batchPr'),(34923,'watch-mobile','.batchPr .w-batch-products .products-listing .price','font-size','16','','','.batchPr'),(34924,'watch-mobile','.batchPr .btn-batch-remove','font-size','17','3','','.batchPr'),(34925,'watch-mobile','.batchPr .batchSelect .checkbox','font-size','18','','','.batchPr'),(34926,'watch-mobile','.batchPr .batchSelect','font-size','12','','','.batchPr'),(34927,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .name a, .batchPr .w-batch-selected-products .products-listing .price','font-size','14','','','.batchPr'),(34928,'watch-mobile','.batchPr .checkbox input:checked + span:before','font-size','18','','','.batchPr'),(34929,'watch-mobile','.batchPr .batch-selected-products-empty','font-size','20','','','.batchPr'),(34930,'watch-mobile','.batchPr .checkbox input:not(checked) + span:before','font-size','32','','','.batchPr'),(34931,'watch-mobile','.batchPr .batch-selected-products-total','font-size','20','','','.batchPr'),(34932,'watch-mobile','.batchPr .btn-batch-remove','font-size','0','','','.batchPr'),(34933,'watch-mobile','.bell-ico .heading-2','font-size','32','3','','.bell-ico'),(34934,'watch-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(34935,'watch-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(34936,'watch-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(34937,'watch-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(34938,'watch-mobile','.heading-ordered-items .heading-4','font-size','28','3','','.heading-ordered-items'),(34939,'watch-mobile','.heading-saved-lists .heading-4','font-size','28','3','','.heading-saved-lists'),(34940,'watch-mobile','.heading-settings .heading-4','font-size','28','3','','.heading-settings'),(35013,'watch-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(35014,'watch-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(35015,'watch-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(35016,'watch-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(35017,'watch-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(35018,'watch-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(35023,'watch-mobile','.p-payer-order-confirmation .ship-ico','font-size','30','3','','.p-payer-order-confirmation'),(35024,'watch-mobile','.p-payer-order-confirmation .comment-ico','font-size','30','3','','.p-payer-order-confirmation'),(35025,'watch-mobile','.p-payer-order-confirmation .order-ico','font-size','36','3','','.p-payer-order-confirmation'),(35026,'watch-mobile','.p-payer-order-confirmation .pay-ico','font-size','30','3','','.p-payer-order-confirmation'),(35027,'watch-mobile','.p-payer-order-confirmation .discount-ico','font-size','30','3','','.p-payer-order-confirmation'),(35028,'watch-mobile','.p-payer-order-pay .ship-ico','font-size','30','3','','.p-payer-order-pay'),(35029,'watch-mobile','.p-payer-order-pay .pay-ico','font-size','30','3','','.p-payer-order-pay'),(35030,'watch-mobile','.p-payer-order-pay .discount-ico','font-size','30','3','','.p-payer-order-pay'),(35031,'watch-mobile','.p-payer-order-pay .comment-ico','font-size','30','3','','.p-payer-order-pay'),(35032,'watch-mobile','.p-payer-order-pay .order-ico','font-size','36','3','','.p-payer-order-pay'),(35033,'watch-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-size','14','','','.p-quick-order-index'),(35034,'watch-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','font-size','13','','','.p-quick-order-index'),(35035,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.next','font-size','0','','','.p-quick-order-index'),(35036,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.previous','font-size','0','','','.p-quick-order-index'),(35037,'watch-mobile','.p-quick-order-index .dataTables_info','font-size','14','','','.p-quick-order-index'),(35038,'watch-mobile','.p-quick-order-index .value','font-size','20','','','.p-quick-order-index'),(35039,'watch-mobile','.p-quick-order-index .in-stock, .p-quick-order-index .out-stock','font-size','12','','','.p-quick-order-index'),(35040,'watch-mobile','.p-quick-order-index .stock','font-size','12','','','.p-quick-order-index'),(35041,'watch-mobile','.p-quick-order-index .paginate_button.previous','font-size','20','3','','.p-quick-order-index'),(35042,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.p-quick-order-index'),(35043,'watch-mobile','.p-quick-order-index .paginate_button.next','font-size','20','3','','.p-quick-order-index'),(35044,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(35045,'watch-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(35046,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(35047,'watch-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(35048,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(35049,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(35050,'watch-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(35051,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(35052,'watch-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(35053,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(35054,'watch-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(35055,'watch-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(35056,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(35057,'watch-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(35058,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(35059,'watch-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(35060,'watch-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(35061,'watch-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(35062,'watch-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(35063,'watch-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(35064,'watch-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(35065,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(35066,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(35067,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(35068,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(35069,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(35070,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(35071,'watch-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(35072,'watch-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(35073,'watch-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(35074,'watch-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(35075,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(35076,'watch-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(35077,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(35078,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(35079,'watch-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(35080,'watch-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(35081,'watch-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(35082,'watch-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(35083,'watch-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(35084,'watch-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(35085,'watch-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(35086,'watch-mobile','.p-sample-checkout-success .page-success .text-1','font-size','80','3','','.p-sample-checkout-success'),(35087,'watch-mobile','.p-sample-checkout-success .page-success .text-3','font-size','27','','','.p-sample-checkout-success'),(35088,'watch-mobile','.p-sample-checkout-success .page-success .text-2','font-size','34','','','.p-sample-checkout-success'),(35089,'watch-mobile','.p-sample-checkout-success .page-success .text-2','font-size','30','','','.p-sample-checkout-success'),(35090,'watch-mobile','.p-sample-checkout-success .page-success .text-1','font-size','60','','','.p-sample-checkout-success'),(35091,'watch-mobile','.p-sample-checkout-success .page-success .text-1','font-size','40','','','.p-sample-checkout-success'),(35092,'watch-mobile','.savings-ico .heading-2','font-size','32','3','','.savings-ico'),(35093,'watch-mobile','.shipping-ico .heading-2','font-size','32','3','','.shipping-ico'),(35094,'watch-mobile','.shipping-ico .heading-2','font-size','32','3','','.shipping-ico'),(35095,'watch-mobile','.shipping-ico .heading-2','font-size','32','3','','.shipping-ico'),(35096,'watch-mobile','.w-account-address-book .address-buttons','font-size','14','','','.w-account-address-book'),(35097,'watch-mobile','.w-account-address-book .add_item a','font-size','25','','','.w-account-address-book'),(35098,'watch-mobile','.w-account-addresses-list .addsess-suggestion-item','font-size','14','','','.w-account-addresses-list'),(35099,'watch-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(35100,'watch-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(35101,'watch-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(35102,'watch-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(35103,'watch-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(35104,'watch-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(35105,'watch-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(35106,'watch-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(35107,'watch-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(35108,'watch-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(35109,'watch-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(35110,'watch-mobile','.w-account-personal-catalog .list-switcher a','font-size','20','','','.w-account-personal-catalog'),(35111,'watch-mobile','.w-blog-widget-categories-list a','font-size','14','','','.w-blog-widget-categories-list'),(35112,'watch-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','font-size','15','','','.w-blog-widget-most-popular-posts'),(35113,'watch-mobile','.w-blog-widget-most-popular-posts a','font-size','14','','','.w-blog-widget-most-popular-posts'),(35114,'watch-mobile','.w-blog-widget-post-comments-count span','font-size','14','3','','.w-blog-widget-post-comments-count'),(35115,'watch-mobile','.w-blog-widget-post-date ','font-size','14','','','.w-blog-widget-post-date'),(35116,'watch-mobile','.w-blog-widget-post-linked-products .heading-2','font-size','22','','','.w-blog-widget-post-linked-products'),(35117,'watch-mobile','.w-blog-widget-post-listing .post_date','font-size','14','','','.w-blog-widget-post-listing'),(35118,'watch-mobile','.w-blog-widget-post-listing .post_name a','font-size','22','','','.w-blog-widget-post-listing'),(35119,'watch-mobile','.w-blog-widget-post-share .facebook-btn','font-size','22','3','','.w-blog-widget-post-share'),(35120,'watch-mobile','.w-blog-widget-post-share .mailto','font-size','26','3','','.w-blog-widget-post-share'),(35121,'watch-mobile','.w-blog-widget-post-share .printto','font-size','26','3','','.w-blog-widget-post-share'),(35122,'watch-mobile','.w-blog-widget-post-share .twitter-btn','font-size','22','3','','.w-blog-widget-post-share'),(35123,'watch-mobile','.w-blog-widget-post-share .pinterest-btn','font-size','22','3','','.w-blog-widget-post-share'),(35124,'watch-mobile','.w-blog-widget-post-title h1','font-size','32','','','.w-blog-widget-post-title'),(35125,'watch-mobile','.w-blog-widget-post-title h1','font-size','24','','','.w-blog-widget-post-title'),(35126,'watch-mobile','.w-blog-widget-post-title ','font-size','24','','','.w-blog-widget-post-title'),(35127,'watch-mobile','.w-blog-widget-related-posts .post_content a','font-size','20','','','.w-blog-widget-related-posts'),(35128,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','font-size','18','3','','.w-blog-widget-related-posts'),(35129,'watch-mobile','.w-blog-widget-related-posts-by-category .post_content a','font-size','18','','','.w-blog-widget-related-posts-by-category'),(35130,'watch-mobile','.w-blog-widget-tag-cloud a','font-size','12','','','.w-blog-widget-tag-cloud'),(35131,'watch-mobile','.w-cart-bonus-points .text','font-size','14','','','.w-cart-bonus-points'),(35132,'watch-mobile','.w-cart-bonus-points .title','font-size','14','3','','.w-cart-bonus-points'),(35133,'watch-mobile','.w-cart-bonus-points .btn-remove','font-size','12','','','.w-cart-bonus-points'),(35134,'watch-mobile','.w-cart-cart-tabs .w-tabs .tab-a','font-size','12','','','.w-cart-cart-tabs'),(35135,'watch-mobile','.w-cart-compare .attributes-label','font-size','14','','','.w-cart-compare'),(35136,'watch-mobile','.w-cart-compare .product-actions .dropdown-toggle','font-size','18','3','','.w-cart-compare'),(35137,'watch-mobile','.w-cart-compare .js-cart_totals_container','font-size','14','','','.w-cart-compare'),(35138,'watch-mobile','.w-cart-compare .cart-name a','font-size','17','','','.w-cart-compare'),(35139,'watch-mobile','.w-cart-compare .product-actions','font-size','12','','','.w-cart-compare'),(35140,'watch-mobile','.w-cart-compare .delete-cart','font-size','12','','','.w-cart-compare'),(35141,'watch-mobile','.w-cart-compare .js-cart_totals_container b','font-size','16','','','.w-cart-compare'),(35142,'watch-mobile','.w-cart-compare .atr-col','font-size','20','3','','.w-cart-compare'),(35143,'watch-mobile','.w-cart-compare .attributes-cell','font-size','14','','','.w-cart-compare'),(35144,'watch-mobile','.w-cart-compare .dropdown li','font-size','14','','','.w-cart-compare'),(35145,'watch-mobile','.w-cart-compare .product .name a','font-size','14','','','.w-cart-compare'),(35146,'watch-mobile','.w-cart-compare .price-label','font-size','14','','','.w-cart-compare'),(35147,'watch-mobile','.w-cart-compare .price-cell','font-size','18','','','.w-cart-compare'),(35148,'watch-mobile','.w-cart-credit-amount .text','font-size','14','','','.w-cart-credit-amount'),(35149,'watch-mobile','.w-cart-credit-amount .btn-remove','font-size','12','','','.w-cart-credit-amount'),(35150,'watch-mobile','.w-catalog-compare .checkbox input:checked + span:before','font-size','24','','','.w-catalog-compare'),(35151,'watch-mobile','.w-catalog-compare .model','font-size','14','','','.w-catalog-compare'),(35152,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-size','26','3','','.w-catalog-compare'),(35153,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','font-size','0','','','.w-catalog-compare'),(35154,'watch-mobile','.w-catalog-compare .item .compare','font-size','0','','','.w-catalog-compare'),(35155,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','font-size','15','','','.w-catalog-compare'),(35156,'watch-mobile','.w-catalog-compare .name','font-size','12','','','.w-catalog-compare'),(35157,'watch-mobile','.w-catalog-paging .next','font-size','20','3','','.w-catalog-paging'),(35158,'watch-mobile','.w-catalog-paging .prev','font-size','20','3','','.w-catalog-paging'),(35159,'watch-mobile','.w-checkout-bonus-points .btn-remove','font-size','12','','','.w-checkout-bonus-points'),(35160,'watch-mobile','.w-checkout-create-account .account-benefits','font-size','0.8','','','.w-checkout-create-account'),(35161,'watch-mobile','.w-checkout-create-account .account-benefits strong','font-size','18','3','','.w-checkout-create-account'),(35162,'watch-mobile','.w-checkout-credit-amount .btn-remove','font-size','12','','','.w-checkout-credit-amount'),(35163,'watch-mobile','.w-checkout-shipping-choice span','font-size','14','','','.w-checkout-shipping-choice'),(35164,'watch-mobile','.w-checkout-terms .terms-box','font-size','13','','','.w-checkout-terms'),(35165,'watch-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-size','14','','','.w-communication-new-topic'),(35166,'watch-mobile','.w-communication-new-topic td.date-purchased','font-size','14','','','.w-communication-new-topic'),(35167,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','font-size','31','','','.w-communication-new-topic'),(35168,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','font-size','31','','','.w-communication-new-topic'),(35169,'watch-mobile','.w-communication-post .communication-post-attach','font-size','14','','','.w-communication-post'),(35170,'watch-mobile','.w-communication-post .communication-post-date','font-size','14','','','.w-communication-post'),(35171,'watch-mobile','.w-coupons-and-vauchers-checkout .btn-remove','font-size','12','','','.w-coupons-and-vauchers-checkout'),(35172,'watch-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-size','40','','','.w-delivery-day'),(35173,'watch-mobile','.w-delivery-day .ends','font-size','26','','','.w-delivery-day'),(35174,'watch-mobile','.w-delivery-day .left-text-left','font-size','24','','','.w-delivery-day'),(35175,'watch-mobile','.w-delivery-day .left-text-right','font-size','24','','','.w-delivery-day'),(35176,'watch-mobile','.w-delivery-day .title','font-size','18','','','.w-delivery-day'),(35177,'watch-mobile','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-size','24','','','.w-multi-cart-cart-switcher'),(35178,'watch-mobile','.w-personal-gift-status-bar .end-label','font-size','14','','','.w-personal-gift-status-bar'),(35179,'watch-mobile','.w-personal-gift-status-bar .start-label','font-size','14','','','.w-personal-gift-status-bar'),(35180,'watch-mobile','.w-personal-gift-status-bar .inform','font-size','24','4','','.w-personal-gift-status-bar'),(35181,'watch-mobile','.w-personal-gift-status-bar .end-date','font-size','22','3','','.w-personal-gift-status-bar'),(35182,'watch-mobile','.w-personal-gift-status-bar .inform','font-size','14','','','.w-personal-gift-status-bar'),(35183,'watch-mobile','.w-personal-gift-status-bar .end-date','font-size','14','','','.w-personal-gift-status-bar'),(35184,'watch-mobile','.w-product-available-in-warehouses .heading','font-size','18','','','.w-product-available-in-warehouses'),(35185,'watch-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(35186,'watch-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(35187,'watch-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(35188,'watch-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(35189,'watch-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(35190,'watch-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(35191,'watch-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(35192,'watch-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(35193,'watch-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(35194,'watch-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(35195,'watch-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(35196,'watch-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(35197,'watch-mobile','.w-product-customers-activity .customers-activity','font-size','16','','','.w-product-customers-activity'),(35198,'watch-mobile','.w-promotions .prom-multi-discount .promo-group','font-size','16','','','.w-promotions'),(35199,'watch-mobile','.w-promotions .nextdiscount .item-holder .name','font-size','14','','','.w-promotions'),(35200,'watch-mobile','.w-promotions .prom-multi-discount .heading','font-size','26','','','.w-promotions'),(35201,'watch-mobile','.w-promotions .nextdiscount .heading','font-size','18','3','','.w-promotions'),(35202,'watch-mobile','.w-promotions .nextdiscount .heading','font-size','26','','','.w-promotions'),(35203,'watch-mobile','.w-promotions .promo-cart-discount .item a','font-size','14','','','.w-promotions'),(35204,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','font-size','13','','','.w-promotions'),(35205,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','font-size','16','','','.w-promotions'),(35206,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','font-size','13','','','.w-promotions'),(35207,'watch-mobile','.w-promotions .promo-salemaker .content a','font-size','14','','','.w-promotions'),(35208,'watch-mobile','.w-promotions .promo-item','font-size','24','','','.w-promotions'),(35209,'watch-mobile','.w-promotions .promo-salemaker .discount','font-size','13','','','.w-promotions'),(35210,'watch-mobile','.w-promotions .heading-3','font-size','48','','','.w-promotions'),(35211,'watch-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','font-size','14','','','.w-promotions'),(35212,'watch-mobile','.w-promotions .nextdiscount .promo-for-each','font-size','14','','','.w-promotions'),(35213,'watch-mobile','.w-quote-products .empty','font-size','24','','','.w-quote-products'),(35214,'watch-mobile','.w-reviews-content .rating','font-size','18','','','.w-reviews-content'),(35215,'watch-mobile','.w-reviews-content .date','font-size','13','','','.w-reviews-content'),(35216,'watch-mobile','.w-social-links a','font-size','26','','','.w-social-links'),(35217,'watch-mobile','.w-social-links a','font-size','30','','','.w-social-links'),(35218,'watch-mobile','.w-taxable .bootstrap-switch .bootstrap-switch-label','font-size','0','','','.w-taxable'),(35219,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-size','20','','','.w-upload-customer-id-upload-customer-id-form'),(35220,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-template','font-size','18','','','.w-upload-customer-id-upload-customer-id-form'),(35221,'watch-mobile','.w-wedding-registry-widgets-products .remove','font-size','24','','','.w-wedding-registry-widgets-products'),(35222,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','font-size','28','','','.w-filters'),(35223,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','font-size','28','','','.w-filters'),(35224,'watch-mobile','.b-rating #stars-default .glyphicon','font-style','normal','','','.b-rating'),(35225,'watch-mobile','.b-select-suggest .select2-results li em','font-style','normal','','','.b-select-suggest'),(35226,'watch-mobile','.w-bestsellers .counter','font-weight','600','','','.w-bestsellers'),(35227,'watch-mobile','.w-bestsellers .heading-3','font-weight','400','3','','.w-bestsellers'),(35228,'watch-mobile','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(35229,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(35230,'watch-mobile','.w-sale .left-count-hours','font-weight','600','','','.w-sale'),(35231,'watch-mobile','.w-sale .left-count-days','font-weight','600','','','.w-sale'),(35232,'watch-mobile','.w-sale .left-text-right','font-weight','600','','','.w-sale'),(35233,'watch-mobile','.w-sale .special-price','font-weight','600','','','.w-sale'),(35234,'watch-mobile','.w-list-type-2_2 .sale','font-weight','600','4','','.w-list-type-2_2'),(35235,'watch-mobile','.w-list-type-2_2 .title','font-weight','700','','','.w-list-type-2_2'),(35236,'watch-mobile','.w-sale .name','font-weight','bold','','','.w-sale'),(35237,'watch-mobile','.w-menu-slider > ul > li > ul > li > a','font-weight','700','','','.w-menu-slider'),(35238,'watch-mobile','.w-product-sale-ends .left-count-days','font-weight','600','','','.w-product-sale-ends'),(35239,'watch-mobile','.w-product-sale-ends .ends-date','font-weight','600','','','.w-product-sale-ends'),(35240,'watch-mobile','.w-product-sale-ends .left-count-hours','font-weight','600','','','.w-product-sale-ends'),(35241,'watch-mobile','.w-product-sale-ends .left-text-left','font-weight','600','','','.w-product-sale-ends'),(35242,'watch-mobile','.w-product-sale-ends .left-text-right','font-weight','600','','','.w-product-sale-ends'),(35243,'watch-mobile','.w-product-collection .title','font-weight','bold','','','.w-product-collection'),(35244,'watch-mobile','.w-product-collection .together','font-weight','700','','','.w-product-collection'),(35245,'watch-mobile','.w-cart .cart-total','font-weight','600','','','.w-cart'),(35246,'watch-mobile','.w-cart .price','font-weight','600','','','.w-cart'),(35247,'watch-mobile','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(35251,'watch-mobile','.b-pass-strength .pass-strength span','font-weight','bold','','','.b-pass-strength'),(35252,'watch-mobile','.b-price-box .price-box .price-row.total','font-weight','700','','','.b-price-box'),(35253,'watch-mobile','.w-reviews .name','font-weight','700','','','.w-reviews'),(35254,'watch-mobile','.w-product-reviews .reviews-list span','font-weight','400','','','.w-product-reviews'),(35255,'watch-mobile','.w-quote .strong','font-weight','400','','','.w-quote'),(35256,'watch-mobile','.w-product-reviews .reviews-list .name','font-weight','700','','','.w-product-reviews'),(35257,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-weight','normal','3','','.b-multi-page-checkout'),(35258,'watch-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','font-weight','bold','','','.p-wedding-registry-manage'),(35260,'watch-mobile','.w-product-bonus-points > div','font-weight','bold','','','.w-product-bonus-points'),(35265,'watch-mobile','.js-stock','font-weight','700','','',''),(35266,'watch-mobile','.testimonials .heading-3','font-weight','400','3','',''),(35267,'watch-mobile','.testimonials .name','font-weight','700','','',''),(35268,'watch-mobile','.testimonials .rating','font-weight','400','','',''),(35269,'watch-mobile','.testimonials .reviews-list .name','font-weight','700','','',''),(35270,'watch-mobile','.testimonials .reviews-list span','font-weight','400','','',''),(35271,'watch-mobile','.b-pagination .pagination span','font-weight','700','2','','.b-pagination'),(35272,'watch-mobile','.p-blog-index .nav-links .screen-reader-text','font-weight','700','','','.p-blog-index'),(35273,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-2_2'),(35274,'watch-mobile','.w-list-type-2 .title','font-weight','700','','','.w-list-type-2'),(35275,'watch-mobile','.w-product-wedding-registry-button .btn','font-weight','700','','','.w-product-wedding-registry-button'),(35276,'watch-mobile','.w-product-personal-catalog-button .btn','font-weight','normal','3','','.w-product-personal-catalog-button'),(35277,'watch-mobile','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(35278,'watch-mobile','.w-product-personal-catalog-button .btn','font-weight','700','','','.w-product-personal-catalog-button'),(35279,'watch-mobile','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(35280,'watch-mobile','.w-list-type-2_2 .button-view a','font-weight','700','','','.w-list-type-2_2'),(35281,'watch-mobile','.w-list-type-2_2 .button-wishlist button','font-weight','700','','','.w-list-type-2_2'),(35282,'watch-mobile','.w-delivery-location-top-location-list .deliveryName a','font-weight','bold','','','.w-delivery-location-top-location-list'),(35283,'watch-mobile','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(35284,'watch-mobile','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(35285,'watch-mobile','.b-bottom .alert-message','font-weight','bold','','','.b-bottom'),(35286,'watch-mobile','.p-wedding-registry-manage .links a.share-registry','font-weight','600','','','.p-wedding-registry-manage'),(35287,'watch-mobile','.p-wedding-registry-manage .wedding-date','font-weight','600','','','.p-wedding-registry-manage'),(35288,'watch-mobile','.b-table .table .headings td','font-weight','600','','','.b-table'),(35289,'watch-mobile','.b-pagination .pagination a','font-weight','700','','','.b-pagination'),(35291,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','font-weight','600','','','.b-switch'),(35292,'watch-mobile','.b-bottom .popup-heading','font-weight','bold','','','.b-bottom'),(35293,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','font-weight','600','','','.b-switch'),(35294,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','font-weight','bold','','','.b-fancybox'),(35295,'watch-mobile','.heading-2, h2','font-weight','400','','',''),(35297,'watch-mobile','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(35298,'watch-mobile','.btn-2','font-weight','600','','',''),(35299,'watch-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','font-weight','normal','','','.p-account-trade-form'),(35300,'watch-mobile','.p-account-trade-form .widget h3','font-weight','normal','','','.p-account-trade-form'),(35302,'watch-mobile','.p-quote-cart-index .cart-page .empty','font-weight','700','','','.p-quote-cart-index'),(35304,'watch-mobile','.p-shopping-cart-index .cart-page .empty','font-weight','700','','','.p-shopping-cart-index'),(35305,'watch-mobile','.w-currencies .currencies-title','font-weight','700','','','.w-currencies'),(35306,'watch-mobile','.p-account-trade-form .address-wrapp b','font-weight','600','','','.p-account-trade-form'),(35307,'watch-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-weight','normal','','','.p-account-subscription-historyinfo'),(35308,'watch-mobile','.p-reviews-info .review-info-reviewed_by','font-weight','bold','','','.p-reviews-info'),(35309,'watch-mobile','.w-sale .left-text-left','font-weight','600','','','.w-sale'),(35310,'watch-mobile','.w-sale .ends-date','font-weight','600','','','.w-sale'),(35312,'watch-mobile','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(35313,'watch-mobile','.w-top-categories .categories h2','font-weight','inherit','','','.w-top-categories'),(35314,'watch-mobile','.w-categories .categories h2','font-weight','inherit','','','.w-categories'),(35315,'watch-mobile','.b-rating #stars-default .glyphicon','font-weight','400','','','.b-rating'),(35319,'watch-mobile','.b-form #payment_method .title','font-weight','bold','','','.b-form'),(35320,'watch-mobile','.w-cart .strong','font-weight','400','','','.w-cart'),(35321,'watch-mobile','.w-cart-give-away .ga_price','font-weight','700','','','.w-cart-give-away'),(35322,'watch-mobile','.w-list-type-1_3 .sale','font-weight','600','4','','.w-list-type-1_3'),(35323,'watch-mobile','.w-list-type-1_3 .title','font-weight','700','','','.w-list-type-1_3'),(35324,'watch-mobile','.w-list-type-2 .button-view a','font-weight','700','','','.w-list-type-2'),(35325,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-2'),(35326,'watch-mobile','.w-list-type-2 .sale','font-weight','600','4','','.w-list-type-2'),(35327,'watch-mobile','.w-list-type-2 .button-wishlist button','font-weight','700','','','.w-list-type-2'),(35328,'watch-mobile','h1','font-weight','400','','',''),(35329,'watch-mobile','.w-currencies .select-link','font-weight','700','','','.w-currencies'),(35330,'watch-mobile','.btn-1','font-weight','600','','',''),(35331,'watch-mobile','.btn-3','font-weight','600','','',''),(35332,'watch-mobile','.btn','font-weight','600','','',''),(35333,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-1_3'),(35334,'watch-mobile','.w-list-type-1_3 .button-view a','font-weight','700','','','.w-list-type-1_3'),(35335,'watch-mobile','.w-list-type-1_3 .button-wishlist button','font-weight','700','','','.w-list-type-1_3'),(35336,'watch-mobile','.w-list-type-1_2 .title','font-weight','700','','','.w-list-type-1_2'),(35337,'watch-mobile','.w-list-type-1_2 .sale','font-weight','600','4','','.w-list-type-1_2'),(35338,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-1_2'),(35339,'watch-mobile','.b-bottom .footerTitle','font-weight','700','','','.b-bottom'),(35340,'watch-mobile','.w-list-type-1_2 .button-wishlist button','font-weight','700','','','.w-list-type-1_2'),(35341,'watch-mobile','.w-list-type-1_2 .button-view a','font-weight','700','','','.w-list-type-1_2'),(35342,'watch-mobile','.w-list-type-1 .sale','font-weight','600','4','','.w-list-type-1'),(35343,'watch-mobile','.heading-4 .right-text, h4 .right-text','font-weight','400','','',''),(35344,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-1'),(35345,'watch-mobile','.heading-4 .edit, h4 .edit','font-weight','400','','',''),(35346,'watch-mobile','.w-list-type-1 .button-wishlist button','font-weight','700','','','.w-list-type-1'),(35347,'watch-mobile','.out-stock','font-weight','700','','',''),(35348,'watch-mobile','.in-stock','font-weight','700','','',''),(35349,'watch-mobile','.transit','font-weight','700','','',''),(35350,'watch-mobile','.w-filters .view_more','font-weight','400','4','','.w-filters'),(35351,'watch-mobile','.w-list-type-1 .button-view a','font-weight','700','','','.w-list-type-1'),(35352,'watch-mobile','.w-reviews .reviews-list .name','font-weight','700','','','.w-reviews'),(35353,'watch-mobile','.w-reviews .heading-3','font-weight','400','3','','.w-reviews'),(35354,'watch-mobile','.w-reviews .rating','font-weight','400','','','.w-reviews'),(35355,'watch-mobile','.w-reviews .reviews-list span','font-weight','400','','','.w-reviews'),(35358,'watch-mobile','.b-info .info strong','font-weight','400','','','.b-info'),(35359,'watch-mobile','.b-products-listing .products-listing .bonus-points span:first-child','font-weight','bold','','','.b-products-listing'),(35360,'watch-mobile','.b-products-listing .products-listing .btn-buy','font-weight','400','3','','.b-products-listing'),(35361,'watch-mobile','.b-products-listing .products-listing .name a','font-weight','bold','','','.b-products-listing'),(35362,'watch-mobile','.b-products-listing .products-listing a.btn.view-button','font-weight','bold','','','.b-products-listing'),(35363,'watch-mobile','.b-products-listing .products-listing h2','font-weight','inherit','','','.b-products-listing'),(35364,'watch-mobile','.b-products-listing .promos-info .promo-name','font-weight','500','','','.b-products-listing'),(35365,'watch-mobile','.b-products-listing .wedding-registry-count','font-weight','bold','','','.b-products-listing'),(35366,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.b-data-table'),(35367,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.b-data-table'),(35368,'watch-mobile','.b-data-table table.dataTable thead td','font-weight','700','','','.b-data-table'),(35369,'watch-mobile','.b-delete-account .delete-box .delete-message','font-weight','normal','','','.b-delete-account'),(35370,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-weight','inherit','','','.b-h-inline'),(35371,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','font-weight','600','','','.b-menu-style-1'),(35372,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','font-weight','600','','','.b-menu-style-1'),(35373,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','font-weight','600','','','.b-menu-style-2'),(35374,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','font-weight','600','','','.b-menu-style-2'),(35375,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-weight','600','','','.b-menu-style-2'),(35376,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-weight','300','3','','.b-menu-style-2'),(35377,'watch-mobile','.b-messages span.starred::before','font-weight','normal','','','.b-messages'),(35378,'watch-mobile','.b-messages .messMenuButton span','font-weight','600','','','.b-messages'),(35379,'watch-mobile','.b-messages .messBtnMenuDelete','font-weight','normal','3','','.b-messages'),(35380,'watch-mobile','.b-messages .messBtnMenuStarred','font-weight','normal','3','','.b-messages'),(35381,'watch-mobile','.b-messages .messBtnMenuUnread','font-weight','normal','3','','.b-messages'),(35382,'watch-mobile','.b-messages .messages-menu li a','font-weight','bold','2','','.b-messages'),(35383,'watch-mobile','.b-messages .content_management_attach','font-weight','600','','','.b-messages'),(35384,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','font-weight','600','','','.b-messages'),(35385,'watch-mobile','.b-personal-catalog-popup #personal_catalog_popup','font-weight','normal','','','.b-personal-catalog-popup'),(35386,'watch-mobile','.b-select-suggest .select2-results li.select2-result-with-children > .select2-result-label','font-weight','bold','','','.b-select-suggest'),(35387,'watch-mobile','.b-sub-totals .historyTotal table tr:last-child td','font-weight','bold','','','.b-sub-totals'),(35388,'watch-mobile','.b-trade-approval .middle-form label','font-weight','600','','','.b-trade-approval'),(35389,'watch-mobile','.b-warehouses-popup .warehouses-popup .heading','font-weight','bold','','','.b-warehouses-popup'),(35390,'watch-mobile','.b-warehouses-popup a.warehouses-popup-link','font-weight','bold','','','.b-warehouses-popup'),(35391,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','font-weight','bold','','','.b-warehouses-popup'),(35392,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','font-weight','bold','','','.b-warehouses-popup'),(35393,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-name','font-weight','bold','','','.b-warehouses-popup'),(35394,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','font-weight','bold','','','.b-warehouses-popup'),(35395,'watch-mobile','.batchPr .batch-selected-products-empty','font-weight','600','','','.batchPr'),(35396,'watch-mobile','.batchPr .batch-selected-products-total','font-weight','600','','','.batchPr'),(35397,'watch-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(35398,'watch-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(35399,'watch-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(35400,'watch-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(35437,'watch-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(35438,'watch-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(35439,'watch-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(35440,'watch-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(35441,'watch-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(35442,'watch-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(35444,'watch-mobile','.p-payer-order-confirmation .cardinfo-label','font-weight','bold','','','.p-payer-order-confirmation'),(35445,'watch-mobile','.p-payer-order-pay .cardinfo-label','font-weight','bold','','','.p-payer-order-pay'),(35446,'watch-mobile','.p-quick-order-index .dataTables_info','font-weight','500','','','.p-quick-order-index'),(35447,'watch-mobile','.p-quick-order-index .value','font-weight','bold','','','.p-quick-order-index'),(35448,'watch-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-weight','600','','','.p-quick-order-index'),(35449,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.p-quick-order-index'),(35450,'watch-mobile','.p-quick-order-index .filters label','font-weight','700','','','.p-quick-order-index'),(35451,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.p-quick-order-index'),(35452,'watch-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(35453,'watch-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(35454,'watch-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(35455,'watch-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(35456,'watch-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(35457,'watch-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(35458,'watch-mobile','.w-account-address-book .name','font-weight','bold','','','.w-account-address-book'),(35459,'watch-mobile','.w-account-address-book .address-buttons','font-weight','600','','','.w-account-address-book'),(35460,'watch-mobile','.w-account-address-book .add_item a','font-weight','bold','','','.w-account-address-book'),(35461,'watch-mobile','.w-blog-widget-post-listing .post_name','font-weight','400','','','.w-blog-widget-post-listing'),(35462,'watch-mobile','.w-blog-widget-tag-cloud a','font-weight','700','','','.w-blog-widget-tag-cloud'),(35463,'watch-mobile','.w-cart-bonus-points .title','font-weight','bold','','','.w-cart-bonus-points'),(35464,'watch-mobile','.w-cart-compare .cart-name a','font-weight','600','','','.w-cart-compare'),(35465,'watch-mobile','.w-cart-compare .atr-col','font-weight','normal','3','','.w-cart-compare'),(35466,'watch-mobile','.w-cart-compare .js-cart_totals_container b','font-weight','600','','','.w-cart-compare'),(35467,'watch-mobile','.w-cart-compare .atr-col','font-weight','600','','','.w-cart-compare'),(35468,'watch-mobile','.w-cart-credit-amount .amount-title','font-weight','bold','','','.w-cart-credit-amount'),(35469,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-weight','normal','3','','.w-catalog-compare'),(35470,'watch-mobile','.w-catalog-paging ','font-weight','700','2','','.w-catalog-paging'),(35471,'watch-mobile','.w-checkout-billing-address .genders-title > div','font-weight','bold','','','.w-checkout-billing-address'),(35472,'watch-mobile','.w-checkout-billing-address .btn-cancel','font-weight','500','','','.w-checkout-billing-address'),(35473,'watch-mobile','.w-checkout-billing-address .add-ab','font-weight','500','','','.w-checkout-billing-address'),(35474,'watch-mobile','.w-checkout-billing-address .edit-ab','font-weight','500','','','.w-checkout-billing-address'),(35475,'watch-mobile','.w-checkout-bonus-points .title','font-weight','bold','','','.w-checkout-bonus-points'),(35476,'watch-mobile','.w-checkout-contact-information .contact-info-buttons a','font-weight','500','','','.w-checkout-contact-information'),(35477,'watch-mobile','.w-checkout-create-account .account-benefits strong','font-weight','normal','','','.w-checkout-create-account'),(35478,'watch-mobile','.w-checkout-credit-amount .amount-title','font-weight','bold','','','.w-checkout-credit-amount'),(35479,'watch-mobile','.w-checkout-shipping-address .change-ab','font-weight','500','','','.w-checkout-shipping-address'),(35480,'watch-mobile','.w-checkout-shipping-address .genders-title > div','font-weight','bold','','','.w-checkout-shipping-address'),(35481,'watch-mobile','.w-checkout-shipping-choice span','font-weight','600','','','.w-checkout-shipping-choice'),(35482,'watch-mobile','.w-checkout-totals .ot_code_ot_subtotal','font-weight','bold','','','.w-checkout-totals'),(35483,'watch-mobile','.w-communication-post .communication-post-author-name','font-weight','bold','','','.w-communication-post'),(35484,'watch-mobile','.w-coupons-and-vauchers-checkout .title','font-weight','bold','','','.w-coupons-and-vauchers-checkout'),(35485,'watch-mobile','.w-delayed-despatch-checkout .heading','font-weight','bold','','','.w-delayed-despatch-checkout'),(35486,'watch-mobile','.w-delayed-despatch-checkout-confirm .heading','font-weight','bold','','','.w-delayed-despatch-checkout-confirm'),(35487,'watch-mobile','.w-delayed-despatch-checkout-confirm .heading','font-weight','600','','','.w-delayed-despatch-checkout-confirm'),(35488,'watch-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-weight','600','','','.w-delivery-day'),(35489,'watch-mobile','.w-delivery-day .ends-date','font-weight','600','','','.w-delivery-day'),(35490,'watch-mobile','.w-delivery-day .title','font-weight','bold','','','.w-delivery-day'),(35491,'watch-mobile','.w-delivery-day .left-text-left','font-weight','600','','','.w-delivery-day'),(35492,'watch-mobile','.w-delivery-day .left-text-right','font-weight','600','','','.w-delivery-day'),(35493,'watch-mobile','.w-image-maps .categories-items .item .title','font-weight','700','','','.w-image-maps'),(35494,'watch-mobile','.w-image-maps .float-items .item .title','font-weight','700','','','.w-image-maps'),(35495,'watch-mobile','.w-image-maps .default-links .item .title','font-weight','700','','','.w-image-maps'),(35496,'watch-mobile','.w-multi-cart-actions .cart-actions','font-weight','600','','','.w-multi-cart-actions'),(35497,'watch-mobile','.w-multi-cart-cart-switcher .cart-label','font-weight','600','','','.w-multi-cart-cart-switcher'),(35498,'watch-mobile','.w-multi-cart-cart-switcher .dropdown-menu a','font-weight','bold','','','.w-multi-cart-cart-switcher'),(35499,'watch-mobile','.w-neighbour-checkout .text','font-weight','bold','','','.w-neighbour-checkout'),(35500,'watch-mobile','.w-personal-gift-status-bar .end-date b','font-weight','bold','','','.w-personal-gift-status-bar'),(35501,'watch-mobile','.w-personal-gift-status-bar .start-label','font-weight','bold','','','.w-personal-gift-status-bar'),(35502,'watch-mobile','.w-personal-gift-status-bar .inform b','font-weight','bold','','','.w-personal-gift-status-bar'),(35503,'watch-mobile','.w-personal-gift-status-bar .end-label','font-weight','bold','','','.w-personal-gift-status-bar'),(35504,'watch-mobile','.w-product-available-in-warehouses .warehouse-name','font-weight','bold','','','.w-product-available-in-warehouses'),(35505,'watch-mobile','.w-product-available-in-warehouses .heading','font-weight','bold','','','.w-product-available-in-warehouses'),(35506,'watch-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(35507,'watch-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(35508,'watch-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(35509,'watch-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(35510,'watch-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(35511,'watch-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(35512,'watch-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(35513,'watch-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(35514,'watch-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(35515,'watch-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(35516,'watch-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(35517,'watch-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(35518,'watch-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(35519,'watch-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(35520,'watch-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(35521,'watch-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(35522,'watch-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(35523,'watch-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(35524,'watch-mobile','.w-promotions .prom-multi-discount .heading','font-weight','300','','','.w-promotions'),(35525,'watch-mobile','.w-promotions .promo-cart-discount .master .heading','font-weight','300','','','.w-promotions'),(35526,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder .value','font-weight','bold','','','.w-promotions'),(35527,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty .value','font-weight','bold','','','.w-promotions'),(35528,'watch-mobile','.w-promotions .promo-date','font-weight','500','','','.w-promotions'),(35529,'watch-mobile','.w-promotions .promo-salemaker .promo-conditions','font-weight','300','','','.w-promotions'),(35530,'watch-mobile','.w-promotions .promo-cart-discount .slave .heading','font-weight','300','','','.w-promotions'),(35531,'watch-mobile','.w-promotions .promo-salemaker .discount .value','font-weight','700','','','.w-promotions'),(35532,'watch-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading','font-weight','300','','','.w-promotions'),(35533,'watch-mobile','.w-promotions .prom-multi-discount .promo-range .value','font-weight','bold','','','.w-promotions'),(35534,'watch-mobile','.w-promotions .heading-3','font-weight','bold','','','.w-promotions'),(35535,'watch-mobile','.w-quote-products .empty','font-weight','700','','','.w-quote-products'),(35536,'watch-mobile','.w-reviews-content .author','font-weight','bold','','','.w-reviews-content'),(35537,'watch-mobile','.w-reviews-content .product-name a','font-weight','bold','','','.w-reviews-content'),(35538,'watch-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','font-weight','normal','','','.w-taxable'),(35539,'watch-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','font-weight','normal','','','.w-taxable'),(35540,'watch-mobile','.w-wedding-registry-widgets-delete-link a','font-weight','normal','4','','.w-wedding-registry-widgets-delete-link'),(35541,'watch-mobile','.w-wedding-registry-widgets-products .rating','font-weight','bold','','','.w-wedding-registry-widgets-products'),(35542,'watch-mobile','.w-wedding-registry-widgets-share-link a','font-weight','normal','4','','.w-wedding-registry-widgets-share-link'),(35543,'watch-mobile','.w-cart .qty','font_size_measure','em','4','','.w-cart'),(35544,'watch-mobile','.w-cart .cart-total','font_size_measure','em','','','.w-cart'),(35545,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font_size_measure','em','4','','.b-multi-page-checkout'),(35546,'watch-mobile','.w-quote .cart-box-link','font_size_measure','em','3','','.w-quote'),(35547,'watch-mobile','.no-found','font_size_measure','em','','',''),(35548,'watch-mobile','.view-all .btn','font_size_measure','em','4','',''),(35549,'watch-mobile','.price .old','font_size_measure','em','','',''),(35550,'watch-mobile','.b-select-suggest .select2-search input','font_size_measure','em','','','.b-select-suggest'),(35551,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font_size_measure','%','','','.b-select-suggest'),(35552,'watch-mobile','.w-checkout-create-account .account-benefits','font_size_measure','em','','','.w-checkout-create-account'),(35553,'watch-mobile','.w-promotions .prom-multi-discount .list','grid-auto-flow','dense','','','.w-promotions'),(35554,'watch-mobile','.w-account-personal-catalog div .price','grid-column','4 / 5','','','.w-account-personal-catalog'),(35555,'watch-mobile','.w-promotions .prom-multi-discount .promo-group-2','grid-column','span 2','','','.w-promotions'),(35556,'watch-mobile','.w-promotions .prom-multi-discount .promo-group-3','grid-column','span 3','','','.w-promotions'),(35557,'watch-mobile','.w-promotions .prom-multi-discount .promo-group-4','grid-column','span 4','','','.w-promotions'),(35558,'watch-mobile','.w-reviews-content .product-name','grid-column','2/4','','','.w-reviews-content'),(35559,'watch-mobile','.w-reviews-content .product-image','grid-column','1','','','.w-reviews-content'),(35560,'watch-mobile','.w-reviews-content .review','grid-column','2/4','','','.w-reviews-content'),(35561,'watch-mobile','.w-reviews-content .rating','grid-column','2','','','.w-reviews-content'),(35562,'watch-mobile','.w-reviews-content .author','grid-column','2/4','','','.w-reviews-content'),(35563,'watch-mobile','.w-reviews-content .date','grid-column','3','','','.w-reviews-content'),(35564,'watch-mobile','.w-promotions .content','grid-column-end','3','','','.w-promotions'),(35565,'watch-mobile','.w-promotions .content','grid-column-start','1','','','.w-promotions'),(35566,'watch-mobile','.w-promotions .condition','grid-column-start','2','','','.w-promotions'),(35567,'watch-mobile','.w-promotions .heading','grid-column-start','1','','','.w-promotions'),(35568,'watch-mobile','.w-promotions .prom-multi-discount .products','grid-gap','4px','','','.w-promotions'),(35569,'watch-mobile','.w-promotions .prom-multi-discount .list','grid-gap','20px','','','.w-promotions'),(35570,'watch-mobile','.w-promotions .nextdiscount .content','grid-gap','3px','','','.w-promotions'),(35571,'watch-mobile','.w-account-personal-catalog div .price','grid-row','1 / 2','','','.w-account-personal-catalog'),(35572,'watch-mobile','.w-reviews-content .product-image','grid-row','1/6','','','.w-reviews-content'),(35573,'watch-mobile','.w-reviews-content .product-name','grid-row','2','','','.w-reviews-content'),(35574,'watch-mobile','.w-reviews-content .review','grid-row','3','','','.w-reviews-content'),(35575,'watch-mobile','.w-reviews-content .date','grid-row','1','','','.w-reviews-content'),(35576,'watch-mobile','.w-reviews-content .author','grid-row','4','','','.w-reviews-content'),(35577,'watch-mobile','.w-reviews-content .rating','grid-row','1','','','.w-reviews-content'),(35578,'watch-mobile','.w-promotions .heading','grid-row-start','1','','','.w-promotions'),(35579,'watch-mobile','.w-promotions .condition','grid-row-start','1','','','.w-promotions'),(35580,'watch-mobile','.w-promotions .content','grid-row-start','2','','','.w-promotions'),(35581,'watch-mobile','.w-promotions .nextdiscount .content','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(35582,'watch-mobile','.w-promotions .prom-multi-discount .promo-group-4 .products','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(35583,'watch-mobile','.w-promotions .prom-multi-discount .products','grid-template-columns','1fr','','','.w-promotions'),(35584,'watch-mobile','.w-promotions .prom-multi-discount .promo-group-3 .products','grid-template-columns','1fr 1fr 1fr','','','.w-promotions'),(35585,'watch-mobile','.w-promotions .prom-multi-discount .promo-group-2 .products','grid-template-columns','1fr 1fr','','','.w-promotions'),(35586,'watch-mobile','.w-promotions .prom-multi-discount .list','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(35587,'watch-mobile','.w-reviews-content .item','grid-template-columns','170px 1fr 1fr','','','.w-reviews-content'),(35588,'watch-mobile','.w-bestsellers .item','height','32','3','','.w-bestsellers'),(35589,'watch-mobile','.b-fancybox .fancybox-close','height','36','','','.b-fancybox'),(35590,'watch-mobile','.w-bestsellers .counter','height','32','','','.w-bestsellers'),(35591,'watch-mobile','.b-switch .bootstrap-switch','height','28','','','.b-switch'),(35592,'watch-mobile','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(35593,'watch-mobile','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(35594,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','height','18','','','.b-form'),(35595,'watch-mobile','.b-form .checkbox-style:checked + .checkbox-span','height','18','','','.b-form'),(35596,'watch-mobile','.w-menu-slider .menu-ico','height','54','','','.w-menu-slider'),(35597,'watch-mobile','.w-menu-horizontal .menu-ico','height','54','','','.w-menu-horizontal'),(35598,'watch-mobile','.w-list-type-2_2 .sale','height','19','4','','.w-list-type-2_2'),(35599,'watch-mobile','.w-sale .badge','height','80','','','.w-sale'),(35600,'watch-mobile','.w-menu-style-1 .menu-ico','height','48','','','.w-menu-style-1'),(35601,'watch-mobile','.w-menu-mobile .menu-slider .open','height','100','','','.w-menu-mobile'),(35602,'watch-mobile','.w-product-wedding-registry-button .btn','height','18','3','','.w-product-wedding-registry-button'),(35603,'watch-mobile','.w-product-wedding-registry-button .btn','height','18','4','','.w-product-wedding-registry-button'),(35604,'watch-mobile','.w-compare-box-item .checkbox','height','22','','','.w-compare-box-item'),(35605,'watch-mobile','.w-compare-box-item .checkbox + span','height','24','','','.w-compare-box-item'),(35606,'watch-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','height','auto','','','.b-product-images'),(35607,'watch-mobile','.w-catalog-listing-look .list','height','31','','','.w-catalog-listing-look'),(35608,'watch-mobile','.w-catalog-listing-look .b2b','height','31','','','.w-catalog-listing-look'),(35609,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','height','35','3','','.b-multi-page-checkout'),(35610,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','height','35','','','.p-blog-index'),(35611,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','height','33','','','.b-multi-page-checkout'),(35612,'watch-mobile','.b-pagination .pagination .prev','height','30','','','.b-pagination'),(35613,'watch-mobile','.b-pagination .pagination .prev-pages','height','30','','','.b-pagination'),(35614,'watch-mobile','.p-wedding-registry-manage .wr-search button','height','30','','','.p-wedding-registry-manage'),(35615,'watch-mobile','.b-pagination .pagination .page-number','height','30','','','.b-pagination'),(35616,'watch-mobile','.b-pagination .pagination .next-pages','height','30','','','.b-pagination'),(35617,'watch-mobile','.b-pagination .pagination .next','height','30','','','.b-pagination'),(35618,'watch-mobile','.b-pagination .pagination span','height','30','2','','.b-pagination'),(35621,'watch-mobile','.w-list-type-2_2 .sale','height','19','3','','.w-list-type-2_2'),(35622,'watch-mobile','.w-list-type-2_2 .sale','height','19','','','.w-list-type-2_2'),(35623,'watch-mobile','.w-list-type-2 .sale','height','19','3','','.w-list-type-2'),(35624,'watch-mobile','.w-list-type-2 .sale','height','19','','','.w-list-type-2'),(35625,'watch-mobile','.w-list-type-2 .sale','height','19','4','','.w-list-type-2'),(35626,'watch-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height','100','','','.b-fancybox'),(35627,'watch-mobile','.b-fancybox .fancybox-nav','height','100','','','.b-fancybox'),(35628,'watch-mobile','.w-product-promotions select','height','29','','','.w-product-promotions'),(35629,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','height','30','3','','.b-form'),(35630,'watch-mobile','.b-pagination .pagination a','height','30','','','.b-pagination'),(35631,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','height','20','3','','.b-switch'),(35632,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','height','20','3','','.b-switch'),(35633,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','height','28','','','.b-switch'),(35634,'watch-mobile','.w-list-type-1 .image img','height','auto','','','.w-list-type-1'),(35635,'watch-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','height','40','','','.b-quantity'),(35636,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','height','40','','','.b-slick'),(35637,'watch-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height','100','','','.w-banner'),(35638,'watch-mobile','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height','100','','','.w-banner'),(35639,'watch-mobile','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height','100','','','.w-banner'),(35640,'watch-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','height','24','','','.w-filters'),(35641,'watch-mobile','.w-filters .input-checkbox:checked + .checkbox-span','height','24','','','.w-filters'),(35642,'watch-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','height','22','','','.w-compare-box-item'),(35643,'watch-mobile','.b-slick .slick-vertical .slick-slide','height','auto','','','.b-slick'),(35644,'watch-mobile','.b-info-popup .info-popup','height','2','','','.b-info-popup'),(35645,'watch-mobile','.b-info-popup .info-popup div','height','20','3','','.b-info-popup'),(35646,'watch-mobile','.w-menu-mobile .menu-ico','height','48','','','.w-menu-mobile'),(35647,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','height','50','303','','.b-slick'),(35648,'watch-mobile','.w-banner .carousel-text','height','100','','','.w-banner'),(35649,'watch-mobile','.b-slick .slick-slide','height','100','','','.b-slick'),(35650,'watch-mobile','.b-quantity .qty-box .smaller','height','35','','','.b-quantity'),(35651,'watch-mobile','.b-quantity .qty-box .bigger','height','35','','','.b-quantity'),(35652,'watch-mobile','.b-fancybox #fancybox-loading div','height','44','','','.b-fancybox'),(35653,'watch-mobile','.w-product-images .item-div','height','80','320','','.w-product-images'),(35654,'watch-mobile','.b-fancybox .fancybox-nav span','height','40','','','.b-fancybox'),(35655,'watch-mobile','.w-product-images .item','height','80','320','','.w-product-images'),(35656,'watch-mobile','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','height','25','','','.b-datepicker'),(35657,'watch-mobile','.w-catalog-listing-look .grid','height','31','','','.w-catalog-listing-look'),(35658,'watch-mobile','.w-list-type-1_3 .sale','height','19','4','','.w-list-type-1_3'),(35659,'watch-mobile','.w-list-type-1_3 .sale','height','19','','','.w-list-type-1_3'),(35660,'watch-mobile','.w-list-type-1_3 .sale','height','19','3','','.w-list-type-1_3'),(35661,'watch-mobile','.b-autocomplete .ui-autocomplete','height','300','','','.b-autocomplete'),(35662,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','height','40','','',''),(35663,'watch-mobile','.w-list-type-1_2 .sale','height','19','3','','.w-list-type-1_2'),(35664,'watch-mobile','.w-list-type-1_2 .sale','height','19','4','','.w-list-type-1_2'),(35665,'watch-mobile','.w-list-type-1_2 .sale','height','19','','','.w-list-type-1_2'),(35666,'watch-mobile','.b-bottom .pop-up-close','height','31','','','.b-bottom'),(35667,'watch-mobile','.w-list-type-1 .sale','height','19','4','','.w-list-type-1'),(35668,'watch-mobile','.w-list-type-1 .sale','height','19','','','.w-list-type-1'),(35669,'watch-mobile','.w-list-type-1 .sale','height','19','3','','.w-list-type-1'),(35670,'watch-mobile','.w-filters .ui-slider','height','7','','','.w-filters'),(35671,'watch-mobile','.w-filters .ui-slider-range','height','6','','','.w-filters'),(35672,'watch-mobile','.w-filters .ui-slider-handle','height','18','','','.w-filters'),(35673,'watch-mobile','.w-search .button-search','height','44','','','.w-search'),(35675,'watch-mobile','.b-form .hide-billing-address','height','100','','','.b-form'),(35676,'watch-mobile','.b-products-listing .btn-preloader','height','24','3','','.b-products-listing'),(35677,'watch-mobile','.b-products-listing .hover-box-content','height','20','3','','.b-products-listing'),(35678,'watch-mobile','.b-products-listing .loader','height','30','4','','.b-products-listing'),(35679,'watch-mobile','.b-products-listing .loader','height','100','3','','.b-products-listing'),(35680,'watch-mobile','.b-products-listing .products-listing .qty-input.hidden','height','100','3','','.b-products-listing'),(35681,'watch-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','height','auto','','','.b-products-listing'),(35682,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.b-data-table'),(35683,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.b-data-table'),(35684,'watch-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(35685,'watch-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(35686,'watch-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(35687,'watch-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(35688,'watch-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(35689,'watch-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(35690,'watch-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','height','30','','','.b-menu-burger_icon'),(35691,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(35692,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(35693,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(35694,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(35695,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(35696,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height','100','','','.b-menu-open_from-left'),(35697,'watch-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(35698,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','height','28','','','.b-menu-style-2'),(35699,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','height','50','','','.b-menu-style-2'),(35700,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','height','24','','','.b-menu-style-2'),(35701,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','height','16','3','','.b-menu-style-2'),(35702,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','height','28','','','.b-menu-style-2'),(35703,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','height','16','3','','.b-menu-style-2'),(35704,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','height','24','','','.b-menu-style-2'),(35705,'watch-mobile','.b-messages .select2-container-multi input.select2-input','height','31','','','.b-messages'),(35706,'watch-mobile','.b-preloader .preloader','height','100','','','.b-preloader'),(35707,'watch-mobile','.b-preloader .preloader','height','40','3','','.b-preloader'),(35708,'watch-mobile','.b-select-suggest .select2-search input','height','auto','','','.b-select-suggest'),(35709,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height','100','','','.b-select-suggest'),(35710,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height','1','','','.b-select-suggest'),(35711,'watch-mobile','.b-select-suggest .select2-drop-mask','height','auto','','','.b-select-suggest'),(35712,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','height','12','','','.b-select-suggest'),(35713,'watch-mobile','.b-select-suggest .select2-measure-scrollbar','height','100','','','.b-select-suggest'),(35714,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','height','100','','','.b-select-suggest'),(35715,'watch-mobile','.b-select-suggest .select2-search-choice-close','height','13','','','.b-select-suggest'),(35716,'watch-mobile','.b-select-suggest .select2-container .select2-choice','height','35','','','.b-select-suggest'),(35717,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','height','35','','','.b-trade-approval'),(35718,'watch-mobile','.b-upload-file .snapshot','height','38','','','.b-upload-file'),(35719,'watch-mobile','.b-upload-file .upload-file-template','height','150','','','.b-upload-file'),(35720,'watch-mobile','.batchPr .checkbox input + span','height','36','','','.batchPr'),(35721,'watch-mobile','.batchPr .batchSelect .checkbox','height','36','','','.batchPr'),(35722,'watch-mobile','.batchPr .checkbox input + span','height','32','','','.batchPr'),(35723,'watch-mobile','.batchPr .batch-selected-products-list','height','304','','','.batchPr'),(35724,'watch-mobile','.batchPr .checkbox input:not(checked) + span:before','height','30','','','.batchPr'),(35725,'watch-mobile','.batchPr .btn-batch-remove','height','20','','','.batchPr'),(35733,'watch-mobile','.p-payer-order-confirmation .input-wrapper','height','35','','','.p-payer-order-confirmation'),(35734,'watch-mobile','.p-payer-order-pay .input-wrapper','height','35','','','.p-payer-order-pay'),(35735,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.p-quick-order-index'),(35736,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.p-quick-order-index'),(35737,'watch-mobile','.w-account-address-book .wrap','height','100','','','.w-account-address-book'),(35738,'watch-mobile','.w-account-address-book .add_item a','height','100','','','.w-account-address-book'),(35739,'watch-mobile','.w-account-subscription .info-popup','height','15','','','.w-account-subscription'),(35740,'watch-mobile','.w-blog-widget-post-share ','height','26','4','','.w-blog-widget-post-share'),(35741,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','height','35','','','.w-blog-widget-related-posts'),(35742,'watch-mobile','.w-catalog-compare span.btn-preloader','height','24','','','.w-catalog-compare'),(35743,'watch-mobile','.w-catalog-paging .prev','height','30','','','.w-catalog-paging'),(35744,'watch-mobile','.w-catalog-paging .paging-holder','height','30','','','.w-catalog-paging'),(35745,'watch-mobile','.w-catalog-paging ','height','30','2','','.w-catalog-paging'),(35746,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height','30','','','.w-catalog-paging'),(35747,'watch-mobile','.w-catalog-paging .next','height','30','','','.w-catalog-paging'),(35748,'watch-mobile','.w-catalog-paging .page-number','height','30','','','.w-catalog-paging'),(35749,'watch-mobile','.w-catalog-paging .next-pages','height','30','','','.w-catalog-paging'),(35750,'watch-mobile','.w-catalog-paging .prev-pages','height','30','','','.w-catalog-paging'),(35751,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','height','10','','','.w-checkout-shipping-choice'),(35752,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','height','30','','','.w-communication-new-topic'),(35753,'watch-mobile','.w-communication-new-topic #communication_group_holder select','height','35','','','.w-communication-new-topic'),(35754,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','height','36','','','.w-communication-new-topic'),(35755,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','height','36','','','.w-communication-new-topic'),(35756,'watch-mobile','.w-image-maps .svg-wrap svg','height','100','','','.w-image-maps'),(35757,'watch-mobile','.w-personal-gift-status-bar .progress-bar','height','8','','','.w-personal-gift-status-bar'),(35758,'watch-mobile','.w-personal-gift-status-bar .progress-bar-content','height','8','','','.w-personal-gift-status-bar'),(35759,'watch-mobile','.w-product-customers-activity .close','height','30','','','.w-product-customers-activity'),(35760,'watch-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(35761,'watch-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(35762,'watch-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(35763,'watch-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(35764,'watch-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(35765,'watch-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(35766,'watch-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(35767,'watch-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(35768,'watch-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(35769,'watch-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(35770,'watch-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(35771,'watch-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(35772,'watch-mobile','.w-promotions .prom-multi-discount .products','height','calc(100% - 25px)','','','.w-promotions'),(35773,'watch-mobile','.w-promotions .prom-multi-discount .image img','height','auto','','','.w-promotions'),(35774,'watch-mobile','.w-promotions .promo-cart-discount .image img','height','auto','','','.w-promotions'),(35775,'watch-mobile','.w-promotions .promo-salemaker .image img','height','auto','','','.w-promotions'),(35776,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','height','150','','','.w-upload-customer-id-upload-customer-id-form'),(35777,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','height','100','','','.w-upload-customer-id-upload-customer-id-form'),(35778,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','height','144','','','.w-wedding-registry-widgets-photos'),(35779,'watch-mobile','.w-wedding-registry-widgets-photos .upload-file-template','height','144','','','.w-wedding-registry-widgets-photos'),(35780,'watch-mobile','.b-quantity .qty-box input[type=\'text\']','height','40','','','.b-quantity'),(35781,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','height','24','','','.w-filters'),(35782,'watch-mobile','.b-select-suggest .select2-search input','height_important','important','','','.b-select-suggest'),(35783,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height_important','important','','','.b-select-suggest'),(35784,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height_important','important','','','.w-catalog-paging'),(35785,'watch-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height_measure','%','','','.b-fancybox'),(35786,'watch-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height_measure','%','','','.w-banner'),(35787,'watch-mobile','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height_measure','%','','','.w-banner'),(35788,'watch-mobile','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height_measure','%','','','.w-banner'),(35789,'watch-mobile','.w-menu-mobile .menu-slider .open','height_measure','vh','','','.w-menu-mobile'),(35790,'watch-mobile','.w-banner .carousel-text','height_measure','%','','','.w-banner'),(35791,'watch-mobile','.b-slick .slick-slide','height_measure','%','','','.b-slick'),(35792,'watch-mobile','.b-fancybox .fancybox-nav','height_measure','%','','','.b-fancybox'),(35793,'watch-mobile','.b-form .hide-billing-address','height_measure','%','','','.b-form'),(35794,'watch-mobile','.b-products-listing .loader','height_measure','%','3','','.b-products-listing'),(35795,'watch-mobile','.b-products-listing .products-listing .qty-input.hidden','height_measure','%','3','','.b-products-listing'),(35796,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height_measure','vh','','','.b-menu-open_from-left'),(35797,'watch-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(35798,'watch-mobile','.b-preloader .preloader','height_measure','%','','','.b-preloader'),(35799,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height_measure','%','','','.b-select-suggest'),(35800,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','height_measure','%','','','.b-select-suggest'),(35801,'watch-mobile','.w-account-address-book .wrap','height_measure','%','','','.w-account-address-book'),(35802,'watch-mobile','.w-account-address-book .add_item a','height_measure','%','','','.w-account-address-book'),(35803,'watch-mobile','.w-image-maps .svg-wrap svg','height_measure','%','','','.w-image-maps'),(35804,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(35805,'watch-mobile','.personal-buttons > div','justify-content','space-around','','','.personal-buttons'),(35806,'watch-mobile','.w-banner .carousel .top-right','justify-content','flex-end','','','.w-banner'),(35807,'watch-mobile','.w-banner .carousel .top-center','justify-content','center','','','.w-banner'),(35808,'watch-mobile','.w-banner .carousel .middle-center','justify-content','center','','','.w-banner'),(35809,'watch-mobile','.w-banner .carousel .bottom-left','justify-content','flex-start','','','.w-banner'),(35810,'watch-mobile','.w-banner .carousel .bottom-center','justify-content','center','','','.w-banner'),(35811,'watch-mobile','.w-banner .carousel .top-left','justify-content','flex-start','','','.w-banner'),(35812,'watch-mobile','.w-banner .carousel .middle-right','justify-content','flex-end','','','.w-banner'),(35813,'watch-mobile','.w-banner .carousel .bottom-right','justify-content','flex-end','','','.w-banner'),(35814,'watch-mobile','.w-banner .carousel .middle-left','justify-content','flex-start','','','.w-banner'),(35815,'watch-mobile','.b-products-listing .products-listing .attribute-qty-blocks','justify-content','space-between','','','.b-products-listing'),(35816,'watch-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(35817,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','justify-content','space-between','','','.b-menu-style-1'),(35818,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(35819,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(35820,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(35821,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(35822,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(35823,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(35824,'watch-mobile','.p-quick-order-index .quick-order-total','justify-content','space-between','','','.p-quick-order-index'),(35825,'watch-mobile','.w-account-address-book .wrap','justify-content','space-between','','','.w-account-address-book'),(35826,'watch-mobile','.w-account-address-book .add_item a','justify-content','center','','','.w-account-address-book'),(35827,'watch-mobile','.w-catalog-compare .cross-box','justify-content','flex-end','','','.w-catalog-compare'),(35828,'watch-mobile','.w-checkout-shipping-choice span','justify-content','center','','','.w-checkout-shipping-choice'),(35829,'watch-mobile','.w-communication-post .communication-post-author','justify-content','space-between','','','.w-communication-post'),(35830,'watch-mobile','.w-personal-gift-status-bar .timeline','justify-content','center','','','.w-personal-gift-status-bar'),(35831,'watch-mobile','.w-promotions .prom-multi-discount .products','justify-content','space-between','','','.w-promotions'),(35832,'watch-mobile','.w-promotions .promo-salemaker .content','justify-content','center','','','.w-promotions'),(35833,'watch-mobile','.w-promotions .promo-cart-discount .content','justify-content','center','','','.w-promotions'),(35834,'watch-mobile','.w-menu-horizontal > ul > li > ul','left','0','','','.w-menu-horizontal'),(35835,'watch-mobile','.w-menu-slider > ul > li > ul','left','0','','','.w-menu-slider'),(35836,'watch-mobile','.w-menu-big > ul > li > ul','left','0','','','.w-menu-big'),(35837,'watch-mobile','.w-bestsellers .heading-3','left','0','3','','.w-bestsellers'),(35838,'watch-mobile','.w-menu-style-1 > ul > li > ul','left','0','','','.w-menu-style-1'),(35839,'watch-mobile','.w-sale .badge','left','10','','','.w-sale'),(35840,'watch-mobile','.w-product-wedding-registry-button .btn','left','0','3','','.w-product-wedding-registry-button'),(35841,'watch-mobile','.w-product-wedding-registry-button .btn','left','13','4','','.w-product-wedding-registry-button'),(35845,'watch-mobile','.w-product-reviews .reviews-list .review','left','10','3','','.w-product-reviews'),(35847,'watch-mobile','.b-info-popup .info-popup div','left','40','','','.b-info-popup'),(35848,'watch-mobile','.w-promo-code .holder','left','12','320,3','','.w-promo-code'),(35849,'watch-mobile','.w-menu-mobile .menu-slider .open','left','0','','','.w-menu-mobile'),(35850,'watch-mobile','.b-info-popup .info-popup.top-left div','left','auto','','','.b-info-popup'),(35851,'watch-mobile','.b-info-popup .info-popup.top-left div','left','auto','3','','.b-info-popup'),(35852,'watch-mobile','.w-promo-code .holder','left','20','3','','.w-promo-code'),(35857,'watch-mobile','.testimonials .review','left','10','3','',''),(35858,'watch-mobile','.testimonials .heading-3','left','0','3','',''),(35863,'watch-mobile','.w-product-personal-catalog-button .btn','left','0','3','','.w-product-personal-catalog-button'),(35864,'watch-mobile','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(35865,'watch-mobile','.p-wedding-registry-index .search-list','left','50','3','','.p-wedding-registry-index'),(35866,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no','left','-100','','','.b-form'),(35867,'watch-mobile','.p-wedding-registry-search h1','left','-10','3','','.p-wedding-registry-search'),(35868,'watch-mobile','.p-wedding-registry-manage h1','left','-10','3','','.p-wedding-registry-manage'),(35869,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','left','2','3','','.b-switch'),(35870,'watch-mobile','.w-filters .ui-slider','left','14','','','.w-filters'),(35871,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','left','2','3','','.b-switch'),(35872,'watch-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','left','0','','','.b-switch'),(35873,'watch-mobile','.b-slick button.slick-next','left','auto','','','.b-slick'),(35874,'watch-mobile','.b-slick button.slick-prev','left','0','','','.b-slick'),(35876,'watch-mobile','.w-search .suggest','left','-25','','','.w-search'),(35877,'watch-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','left','0','','','.w-banner'),(35878,'watch-mobile','.w-banner .image-text-banner.top-left .text-banner','left','0','','','.w-banner'),(35879,'watch-mobile','.w-banner .image-text-banner.bottom-left .text-banner','left','0','','','.w-banner'),(35880,'watch-mobile','.w-banner .banner img + img','left','0','','','.w-banner'),(35881,'watch-mobile','.w-currencies .select','left','0','','','.w-currencies'),(35882,'watch-mobile','.b-slick .slick-track','left','0','','','.b-slick'),(35883,'watch-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left','50','','','.b-slick'),(35885,'watch-mobile','.b-info-popup .info-popup div','left','-11','3','','.b-info-popup'),(35886,'watch-mobile','.b-fancybox .fancybox-title-over-wrap','left','0','','','.b-fancybox'),(35887,'watch-mobile','.b-fancybox .fancybox-tmp','left','-99999','','','.b-fancybox'),(35888,'watch-mobile','.b-fancybox .fancybox-wrap','left','0','','','.b-fancybox'),(35889,'watch-mobile','.b-fancybox .fancybox-prev span','left','10','','','.b-fancybox'),(35890,'watch-mobile','.b-fancybox .fancybox-overlay','left','0','','','.b-fancybox'),(35891,'watch-mobile','.b-fancybox .fancybox-prev','left','0','','','.b-fancybox'),(35893,'watch-mobile','.w-text .customer-service','left','0','3','','.w-text'),(35894,'watch-mobile','.w-banner .carousel-text','left','0','','','.w-banner'),(35895,'watch-mobile','.p-reviews-info .review-info-text','left','11','4','','.p-reviews-info'),(35897,'watch-mobile','.b-form .hide-billing-address','left','0','','','.b-form'),(35898,'watch-mobile','.b-fancybox #fancybox-loading','left','50','','','.b-fancybox'),(35899,'watch-mobile','.view-all','left','0','3','',''),(35900,'watch-mobile','.p-wedding-registry-share h1','left','-10','3','','.p-wedding-registry-share'),(35901,'watch-mobile','.p-wedding-registry-view h1','left','-10','3','','.p-wedding-registry-view'),(35902,'watch-mobile','.w-languages .select','left','-1','','','.w-languages'),(35903,'watch-mobile','.w-reviews .review','left','10','3','','.w-reviews'),(35904,'watch-mobile','.w-reviews .heading-3','left','0','3','','.w-reviews'),(35908,'watch-mobile','.b-products-listing .hover-box-content','left','20','3','','.b-products-listing'),(35909,'watch-mobile','.b-products-listing .hover-box-content','left','0','','','.b-products-listing'),(35910,'watch-mobile','.b-products-listing .loader','left','calc(50% - 15px)','4','','.b-products-listing'),(35911,'watch-mobile','.b-products-listing .loader','left','0','3','','.b-products-listing'),(35912,'watch-mobile','.b-products-listing .products-listing .promos-info','left','0','','','.b-products-listing'),(35913,'watch-mobile','.b-products-listing .products-listing .qty-input.hidden','left','0','3','','.b-products-listing'),(35914,'watch-mobile','.b-products-listing .promo','left','0','','','.b-products-listing'),(35915,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(35916,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(35917,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(35918,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(35919,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(35920,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(35921,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','left','0','','','.b-menu-lev_display-down'),(35922,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','left','0','','','.b-menu-lev_display-down'),(35923,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','left','0','','','.b-menu-lev_display-down'),(35924,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','left','0','','','.b-menu-lev_display-down'),(35925,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','left','0','','','.b-menu-lev_display-down'),(35926,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left','100','','','.b-menu-lev_display-lra'),(35927,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left','100','','','.b-menu-lev_display-lra'),(35928,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left','100','','','.b-menu-lev_display-lra'),(35929,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left','100','','','.b-menu-lev_display-lra'),(35930,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left','100','','','.b-menu-lev_display-lra'),(35931,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','left','auto','','','.b-menu-lev_display-lra'),(35932,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','left','auto','','','.b-menu-lev_display-lra'),(35933,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','left','auto','','','.b-menu-lev_display-lra'),(35934,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','left','auto','','','.b-menu-lev_display-lra'),(35935,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','left','auto','','','.b-menu-lev_display-lra'),(35936,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left','100','','','.b-menu-lev_display-right'),(35937,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left','100','','','.b-menu-lev_display-right'),(35938,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left','100','','','.b-menu-lev_display-right'),(35939,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left','100','','','.b-menu-lev_display-right'),(35940,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left','100','','','.b-menu-lev_display-right'),(35941,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left','100','','','.b-menu-lev_display-slide'),(35942,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left','100','','','.b-menu-lev_display-slide'),(35943,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left','100','','','.b-menu-lev_display-slide'),(35944,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left','100','','','.b-menu-lev_display-slide'),(35945,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left','100','','','.b-menu-lev_display-slide'),(35946,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left','-110','','','.b-menu-open_from-left'),(35947,'watch-mobile','.b-menu-open_from-left .bi-opened .menu-style[data-open_from=\"left\"] .menu-content','left','0','','','.b-menu-open_from-left'),(35948,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','left','0','','','.b-menu-style-1'),(35949,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','left','0','','','.b-menu-style-2'),(35950,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','left','0','','','.b-menu-style-2'),(35951,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','left','20','3','','.b-menu-style-2'),(35952,'watch-mobile','.b-preloader .preloader','left','0','','','.b-preloader'),(35953,'watch-mobile','.b-preloader .preloader','left','calc(50% - 20px)','3','','.b-preloader'),(35954,'watch-mobile','.b-select-suggest .select2-container-multi .select2-search-choice-close','left','3','','','.b-select-suggest'),(35955,'watch-mobile','.b-select-suggest .select2-drop-mask','left','0','','','.b-select-suggest'),(35956,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left','0','','','.b-select-suggest'),(35957,'watch-mobile','.b-select-suggest .select2-measure-scrollbar','left','-10000','','','.b-select-suggest'),(35958,'watch-mobile','.batchPr .checkbox input:checked + span:before','left','0','','','.batchPr'),(35959,'watch-mobile','.batchPr .w-batch-products .products-listing .slick-prev','left','-10','','','.batchPr'),(35960,'watch-mobile','.batchPr .checkbox input:not(checked) + span:before','left','1','','','.batchPr'),(36005,'watch-mobile','.p-quick-order-index .all-scroll-div','left','0','','','.p-quick-order-index'),(36006,'watch-mobile','.w-blog-widget-categories-list a','left','0','3','','.w-blog-widget-categories-list'),(36007,'watch-mobile','.w-blog-widget-most-popular-posts a','left','0','3','','.w-blog-widget-most-popular-posts'),(36008,'watch-mobile','.w-blog-widget-post-comments-count span','left','0','3','','.w-blog-widget-post-comments-count'),(36009,'watch-mobile','.w-blog-widget-post-linked-products button.slick-prev','left','10','','','.w-blog-widget-post-linked-products'),(36010,'watch-mobile','.w-blog-widget-post-listing .post_comment','left','0','3','','.w-blog-widget-post-listing'),(36011,'watch-mobile','.w-blog-widget-post-share','left','112','0,4','','.w-blog-widget-post-share'),(36012,'watch-mobile','.w-blog-widget-related-posts button.slick-prev','left','13','','','.w-blog-widget-related-posts'),(36013,'watch-mobile','.w-blog-widget-related-posts-by-category button.slick-prev','left','13','','','.w-blog-widget-related-posts-by-category'),(36014,'watch-mobile','.w-cart-compare .dropdown .dropdown-menu','left','auto','','','.w-cart-compare'),(36015,'watch-mobile','.w-catalog-b2b-add-button ','left','0','','','.w-catalog-b2b-add-button'),(36016,'watch-mobile','.w-checkout-billing-address .addresses .address-item label input','left','0','','','.w-checkout-billing-address'),(36017,'watch-mobile','.w-checkout-shipping-address .addresses .address-item label input','left','0','','','.w-checkout-shipping-address'),(36018,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','left','50','','','.w-checkout-shipping-choice'),(36019,'watch-mobile','.w-checkout-terms .required-message','left','0','','','.w-checkout-terms'),(36020,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','left','0','','','.w-image-maps'),(36021,'watch-mobile','.w-image-maps .svg-wrap svg','left','0','','','.w-image-maps'),(36022,'watch-mobile','.w-multi-cart-actions .dropdown .dropdown-menu','left','auto','','','.w-multi-cart-actions'),(36023,'watch-mobile','.w-reviews-content .review','left','15','3','','.w-reviews-content'),(36024,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(36025,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(36026,'watch-mobile','.w-wedding-registry-widgets-delete-link a','left','-3','4','','.w-wedding-registry-widgets-delete-link'),(36027,'watch-mobile','.w-wedding-registry-widgets-share-link a','left','-3','4','','.w-wedding-registry-widgets-share-link'),(36028,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left_important','important','','','.b-select-suggest'),(36029,'watch-mobile','.p-wedding-registry-index .search-list','left_measure','%','3','','.p-wedding-registry-index'),(36030,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no','left_measure','vw','','','.b-form'),(36031,'watch-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left_measure','%','','','.b-slick'),(36033,'watch-mobile','.b-fancybox #fancybox-loading','left_measure','%','','','.b-fancybox'),(36035,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left_measure','%','','','.b-menu-lev_display-lra'),(36036,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left_measure','%','','','.b-menu-lev_display-lra'),(36037,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left_measure','%','','','.b-menu-lev_display-lra'),(36038,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left_measure','%','','','.b-menu-lev_display-lra'),(36039,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left_measure','%','','','.b-menu-lev_display-lra'),(36040,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left_measure','%','','','.b-menu-lev_display-right'),(36041,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left_measure','%','','','.b-menu-lev_display-right'),(36042,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left_measure','%','','','.b-menu-lev_display-right'),(36043,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left_measure','%','','','.b-menu-lev_display-right'),(36044,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left_measure','%','','','.b-menu-lev_display-right'),(36045,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left_measure','vw','','','.b-menu-lev_display-slide'),(36046,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left_measure','vw','','','.b-menu-lev_display-slide'),(36047,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left_measure','vw','','','.b-menu-lev_display-slide'),(36048,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left_measure','vw','','','.b-menu-lev_display-slide'),(36049,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left_measure','vw','','','.b-menu-lev_display-slide'),(36050,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left_measure','vw','','','.b-menu-open_from-left'),(36051,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','left_measure','%','','','.w-checkout-shipping-choice'),(36052,'watch-mobile','.w-menu-slider .close','line-height','10','','','.w-menu-slider'),(36053,'watch-mobile','.w-bestsellers .counter','line-height','34','','','.w-bestsellers'),(36054,'watch-mobile','.w-bestsellers .item','line-height','33','3','','.w-bestsellers'),(36055,'watch-mobile','.w-bestsellers .heading-3','line-height','1','3','','.w-bestsellers'),(36056,'watch-mobile','.w-account .my-acc-link','line-height','39','3','','.w-account'),(36057,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line-height','18','','','.b-form'),(36058,'watch-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','line-height','18','','','.b-form'),(36059,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','line-height','22','','','.b-form'),(36060,'watch-mobile','.w-product-sale-ends .ends','line-height','1','','','.w-product-sale-ends'),(36061,'watch-mobile','.w-menu-slider .menu-ico','line-height','54','','','.w-menu-slider'),(36062,'watch-mobile','.w-list-type-2_2 .sale','line-height','22','4','','.w-list-type-2_2'),(36063,'watch-mobile','.w-menu-horizontal .menu-ico','line-height','54','','','.w-menu-horizontal'),(36064,'watch-mobile','.w-sale .name','line-height','1.2','','','.w-sale'),(36065,'watch-mobile','.w-sale .badge','line-height','27','','','.w-sale'),(36066,'watch-mobile','.w-menu-style-1 .menu-ico','line-height','48','','','.w-menu-style-1'),(36067,'watch-mobile','.w-cart .cart-box-link','line-height','38','3','','.w-cart'),(36068,'watch-mobile','.b-fancybox .fancybox-nav span','line-height','40','','','.b-fancybox'),(36071,'watch-mobile','.w-quote .cart-box-link','line-height','0.75','3','','.w-quote'),(36072,'watch-mobile','.w-reviews .heading-3','line-height','1','3','','.w-reviews'),(36073,'watch-mobile','.w-catalog-listing-look .list','line-height','30','','','.w-catalog-listing-look'),(36074,'watch-mobile','.w-catalog-listing-look .b2b','line-height','30','','','.w-catalog-listing-look'),(36075,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line-height','35','3','','.b-multi-page-checkout'),(36076,'watch-mobile','.w-product-personal-catalog-button .btn','line-height','14','','','.w-product-personal-catalog-button'),(36078,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line-height','31','','','.b-multi-page-checkout'),(36079,'watch-mobile','.b-info-popup .info-popup div','line-height','1.7','','','.b-info-popup'),(36080,'watch-mobile','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(36081,'watch-mobile','.testimonials .heading-3','line-height','1','3','',''),(36082,'watch-mobile','.b-pagination .pagination .prev','line-height','26','3','','.b-pagination'),(36083,'watch-mobile','.b-pagination .pagination .prev','line-height','30','','','.b-pagination'),(36084,'watch-mobile','.b-pagination .pagination .prev-pages','line-height','30','','','.b-pagination'),(36085,'watch-mobile','.b-pagination .pagination .page-number','line-height','30','','','.b-pagination'),(36086,'watch-mobile','.p-wedding-registry-manage .wr-search button','line-height','1.3','3','','.p-wedding-registry-manage'),(36087,'watch-mobile','.b-pagination .pagination .next-pages','line-height','30','','','.b-pagination'),(36088,'watch-mobile','.b-pagination .pagination .next','line-height','26','3','','.b-pagination'),(36089,'watch-mobile','.b-pagination .pagination span','line-height','30','2','','.b-pagination'),(36090,'watch-mobile','.b-pagination .pagination .next','line-height','30','','','.b-pagination'),(36094,'watch-mobile','.p-blog-index .nav-previous a','line-height','50','3','','.p-blog-index'),(36095,'watch-mobile','.p-blog-index .nav-next a','line-height','50','3','','.p-blog-index'),(36096,'watch-mobile','.w-list-type-2_2 .price','line-height','100','','','.w-list-type-2_2'),(36097,'watch-mobile','.w-list-type-2_2 .sale','line-height','19','3','','.w-list-type-2_2'),(36098,'watch-mobile','.w-list-type-2_2 .description','line-height','120','','','.w-list-type-2_2'),(36099,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','line-height','34','3','','.w-list-type-2_2'),(36100,'watch-mobile','.w-list-type-2_2 .button-wishlist button','line-height','28','','','.w-list-type-2_2'),(36101,'watch-mobile','.w-list-type-2_2 .button-view a','line-height','28','','','.w-list-type-2_2'),(36102,'watch-mobile','.w-list-type-2 .sale','line-height','19','3','','.w-list-type-2'),(36103,'watch-mobile','.w-product-personal-catalog-button .btn','line-height','1','3','','.w-product-personal-catalog-button'),(36104,'watch-mobile','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(36105,'watch-mobile','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(36106,'watch-mobile','.w-product-wedding-registry-button .btn','line-height','14','','','.w-product-wedding-registry-button'),(36107,'watch-mobile','.b-fancybox .fancybox-close','line-height','1','','','.b-fancybox'),(36108,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','line-height','30','3','','.b-form'),(36109,'watch-mobile','.p-wedding-registry-manage .links a.share-registry','line-height','30','','','.p-wedding-registry-manage'),(36110,'watch-mobile','.p-wedding-registry-manage .links a','line-height','20','','','.p-wedding-registry-manage'),(36111,'watch-mobile','.b-pagination .pagination a','line-height','30','','','.b-pagination'),(36112,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line-height','30','','','.b-switch'),(36113,'watch-mobile','.w-quote .cart-box-link','line-height','39','299,3','','.w-quote'),(36114,'watch-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','line-height','40','','','.b-quantity'),(36115,'watch-mobile','.b-switch .bootstrap-switch','line-height','28','','','.b-switch'),(36116,'watch-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line-height','36','','','.b-slick'),(36117,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','38','','','.b-slick'),(36118,'watch-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','line-height','22','','','.w-filters'),(36120,'watch-mobile','.btn','line-height','20','','',''),(36121,'watch-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','line-height','22','','','.w-filters'),(36122,'watch-mobile','.w-currencies .current','line-height','1','3','','.w-currencies'),(36123,'watch-mobile','.w-currencies .currencies-title','line-height','15','','','.w-currencies'),(36124,'watch-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line-height','24','','','.w-compare-box-item'),(36125,'watch-mobile','.p-account-subscription-historyinfo .order_history_table th','line-height','16','','','.p-account-subscription-historyinfo'),(36126,'watch-mobile','.b-info-popup .info-popup div','line-height','30','3','','.b-info-popup'),(36128,'watch-mobile','.b-info-popup .info-popup','line-height','2','','','.b-info-popup'),(36129,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','line-height','24','','','.b-fancybox'),(36130,'watch-mobile','.w-menu-mobile .menu-ico','line-height','48','','','.w-menu-mobile'),(36131,'watch-mobile','.w-sale .ends','line-height','1','','','.w-sale'),(36132,'watch-mobile','.w-sale .old','line-height','0.8','','','.w-sale'),(36133,'watch-mobile','.w-sale .special-price','line-height','0.8','','','.w-sale'),(36134,'watch-mobile','.w-text .customer-service b','line-height','18','','','.w-text'),(36135,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','48','303','','.b-slick'),(36136,'watch-mobile','.b-form .cart-popup .price','line-height','35','','','.b-form'),(36137,'watch-mobile','.b-quantity .qty-box .bigger','line-height','35','','','.b-quantity'),(36138,'watch-mobile','.b-quantity .qty-box .smaller','line-height','35','','','.b-quantity'),(36139,'watch-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','line-height','16','3','','.w-cart-discount-coupon'),(36141,'watch-mobile','.b-form .form-inputs div.required-message','line-height','1.3','','','.b-form'),(36143,'watch-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(36144,'watch-mobile','.w-catalog-listing-look .grid','line-height','30','','','.w-catalog-listing-look'),(36145,'watch-mobile','.w-list-type-2 .button-wishlist button','line-height','28','','','.w-list-type-2'),(36146,'watch-mobile','.w-list-type-1_3 .sale','line-height','19','3','','.w-list-type-1_3'),(36147,'watch-mobile','.w-list-type-2 .sale','line-height','22','4','','.w-list-type-2'),(36148,'watch-mobile','.w-list-type-2 .description','line-height','120','','','.w-list-type-2'),(36149,'watch-mobile','.w-list-type-2 .price','line-height','100','','','.w-list-type-2'),(36150,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','line-height','34','3','','.w-list-type-2'),(36151,'watch-mobile','.w-list-type-1_3 .sale','line-height','22','4','','.w-list-type-1_3'),(36152,'watch-mobile','.w-list-type-2 .button-view a','line-height','28','','','.w-list-type-2'),(36153,'watch-mobile','.btn-3','line-height','20','','',''),(36154,'watch-mobile','.w-list-type-1_3 .description','line-height','120','','','.w-list-type-1_3'),(36155,'watch-mobile','.w-list-type-1_3 .price','line-height','100','','','.w-list-type-1_3'),(36156,'watch-mobile','.btn-2','line-height','20','','',''),(36157,'watch-mobile','.btn-1','line-height','24','','',''),(36158,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','line-height','34','3','','.w-list-type-1_3'),(36159,'watch-mobile','.w-list-type-1_3 .button-view a','line-height','28','','','.w-list-type-1_3'),(36160,'watch-mobile','.w-list-type-1_3 .button-wishlist button','line-height','28','','','.w-list-type-1_3'),(36161,'watch-mobile','.w-list-type-1_2 .sale','line-height','19','3','','.w-list-type-1_2'),(36162,'watch-mobile','.w-list-type-1_2 .description','line-height','120','','','.w-list-type-1_2'),(36163,'watch-mobile','.w-list-type-1_2 .sale','line-height','22','4','','.w-list-type-1_2'),(36164,'watch-mobile','.w-list-type-1_2 .price','line-height','100','','','.w-list-type-1_2'),(36165,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','line-height','34','3','','.w-list-type-1_2'),(36166,'watch-mobile','.w-list-type-1_2 .button-wishlist button','line-height','28','','','.w-list-type-1_2'),(36167,'watch-mobile','.b-bottom .pop-up-close','line-height','25','','','.b-bottom'),(36168,'watch-mobile','.w-list-type-1_2 .button-view a','line-height','28','','','.w-list-type-1_2'),(36169,'watch-mobile','.w-list-type-1 .sale','line-height','22','4','','.w-list-type-1'),(36170,'watch-mobile','.w-list-type-1 .sale','line-height','19','3','','.w-list-type-1'),(36171,'watch-mobile','.heading-4 .edit, h4 .edit','line-height','20','','',''),(36172,'watch-mobile','.w-list-type-1 .description','line-height','120','','','.w-list-type-1'),(36173,'watch-mobile','.heading-3 .edit, h3 .edit','line-height','20','','',''),(36174,'watch-mobile','.heading-4 .right-text, h4 .right-text','line-height','20','','',''),(36175,'watch-mobile','.heading-3 .right-text, h3 .right-text','line-height','20','','',''),(36176,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','line-height','34','3','','.w-list-type-1'),(36177,'watch-mobile','.w-list-type-1 .price','line-height','100','','','.w-list-type-1'),(36178,'watch-mobile','.w-list-type-1 .button-wishlist button','line-height','28','','','.w-list-type-1'),(36179,'watch-mobile','.w-list-type-1 .button-view a','line-height','28','','','.w-list-type-1'),(36180,'watch-mobile','.w-languages .current','line-height','1','3','','.w-languages'),(36182,'watch-mobile','.w-search .button-search','line-height','1.3','3','','.w-search'),(36183,'watch-mobile','.w-socials .post_item > div','line-height','19','','','.w-socials'),(36184,'watch-mobile','.b-info .info','line-height','1','3','','.b-info'),(36185,'watch-mobile','.b-products-listing .btn-preloader','line-height','24','3','','.b-products-listing'),(36186,'watch-mobile','.b-products-listing .loader','line-height','30','4','','.b-products-listing'),(36187,'watch-mobile','.b-products-listing .products-listing .btn-buy','line-height','10','3','','.b-products-listing'),(36188,'watch-mobile','.b-products-listing .products-listing .btn-preloader','line-height','8','','','.b-products-listing'),(36189,'watch-mobile','.b-products-listing .products-listing .name a','line-height','1.5','','','.b-products-listing'),(36190,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.b-data-table'),(36191,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.b-data-table'),(36192,'watch-mobile','.b-data-table table.dataTable thead td','line-height','1.5','','','.b-data-table'),(36193,'watch-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line-height','30','','','.b-menu-burger_icon'),(36194,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(36195,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(36196,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(36197,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(36198,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(36199,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','line-height','1.2','','','.b-menu-style-1'),(36200,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','line-height','24','','','.b-menu-style-2'),(36201,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','line-height','24','','','.b-menu-style-2'),(36202,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','line-height','50','','','.b-menu-style-2'),(36203,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','line-height','16','3','','.b-menu-style-2'),(36204,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','line-height','16','3','','.b-menu-style-2'),(36205,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','line-height','1.2','','','.b-menu-style-3'),(36206,'watch-mobile','.b-messages span.starred::before','line-height','10','','','.b-messages'),(36207,'watch-mobile','.b-messages .messBtnMenuStarred','line-height','10','3','','.b-messages'),(36208,'watch-mobile','.b-messages .messBtnMenuDelete','line-height','10','3','','.b-messages'),(36209,'watch-mobile','.b-messages .messBtnMenuUnread','line-height','10','3','','.b-messages'),(36210,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line-height','14','','','.b-messages'),(36211,'watch-mobile','.b-preloader .preloader','line-height','40','3','','.b-preloader'),(36212,'watch-mobile','.b-select-suggest .select2-container .select2-choice','line-height','26','','','.b-select-suggest'),(36213,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line-height','13','','','.b-select-suggest'),(36214,'watch-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(36215,'watch-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(36216,'watch-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(36217,'watch-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(36218,'watch-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(36219,'watch-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(36220,'watch-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(36221,'watch-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(36222,'watch-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(36223,'watch-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(36224,'watch-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(36225,'watch-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(36226,'watch-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(36227,'watch-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(36228,'watch-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(36229,'watch-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(36230,'watch-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(36231,'watch-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(36232,'watch-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','line-height','1.3','','','.b-trade-approval'),(36233,'watch-mobile','.b-upload-file .snapshot','line-height','38','','','.b-upload-file'),(36234,'watch-mobile','.batchPr .btn-batch-remove','line-height','1','3','','.batchPr'),(36235,'watch-mobile','.batchPr .batchSelect .checkbox','line-height','36','','','.batchPr'),(36236,'watch-mobile','.batchPr .checkbox input:not(checked) + span:before','line-height','33','','','.batchPr'),(36237,'watch-mobile','.batchPr .btn-batch-remove','line-height','0','','','.batchPr'),(36238,'watch-mobile','.bell-ico .heading-2','line-height','10','3','','.bell-ico'),(36239,'watch-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(36240,'watch-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(36241,'watch-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(36242,'watch-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(36269,'watch-mobile','.p-payer-order-confirmation .ship-ico','line-height','20','3','','.p-payer-order-confirmation'),(36270,'watch-mobile','.p-payer-order-confirmation .discount-ico','line-height','20','3','','.p-payer-order-confirmation'),(36271,'watch-mobile','.p-payer-order-confirmation .comment-ico','line-height','20','3','','.p-payer-order-confirmation'),(36272,'watch-mobile','.p-payer-order-confirmation .order-ico','line-height','20','3','','.p-payer-order-confirmation'),(36273,'watch-mobile','.p-payer-order-confirmation .pay-ico','line-height','20','3','','.p-payer-order-confirmation'),(36274,'watch-mobile','.p-payer-order-pay .pay-ico','line-height','20','3','','.p-payer-order-pay'),(36275,'watch-mobile','.p-payer-order-pay .order-ico','line-height','20','3','','.p-payer-order-pay'),(36276,'watch-mobile','.p-payer-order-pay .ship-ico','line-height','20','3','','.p-payer-order-pay'),(36277,'watch-mobile','.p-payer-order-pay .comment-ico','line-height','20','3','','.p-payer-order-pay'),(36278,'watch-mobile','.p-payer-order-pay .discount-ico','line-height','20','3','','.p-payer-order-pay'),(36279,'watch-mobile','.p-quick-order-index .paginate_button.previous','line-height','26','3','','.p-quick-order-index'),(36280,'watch-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','line-height','1.2','','','.p-quick-order-index'),(36281,'watch-mobile','.p-quick-order-index .stock','line-height','1.2','','','.p-quick-order-index'),(36282,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.p-quick-order-index'),(36283,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.p-quick-order-index'),(36284,'watch-mobile','.p-quick-order-index .paginate_button.next','line-height','26','3','','.p-quick-order-index'),(36285,'watch-mobile','.savings-ico .heading-2','line-height','10','3','','.savings-ico'),(36286,'watch-mobile','.shipping-ico .heading-2','line-height','10','3','','.shipping-ico'),(36287,'watch-mobile','.shipping-ico .heading-2','line-height','10','3','','.shipping-ico'),(36288,'watch-mobile','.shipping-ico .heading-2','line-height','10','3','','.shipping-ico'),(36289,'watch-mobile','.w-blog-widget-categories-list a','line-height','1','3','','.w-blog-widget-categories-list'),(36290,'watch-mobile','.w-blog-widget-most-popular-posts a','line-height','1','3','','.w-blog-widget-most-popular-posts'),(36291,'watch-mobile','.w-blog-widget-post-listing .post_date span + span','line-height','1','3','','.w-blog-widget-post-listing'),(36292,'watch-mobile','.w-blog-widget-post-listing .post_name','line-height','1.2','','','.w-blog-widget-post-listing'),(36293,'watch-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','line-height','1','','','.w-blog-widget-post-share'),(36294,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','line-height','35','','','.w-blog-widget-related-posts'),(36295,'watch-mobile','.w-cart-compare .compare-table','line-height','1.3','','','.w-cart-compare'),(36296,'watch-mobile','.w-cart-compare .delete-cart','line-height','1','','','.w-cart-compare'),(36297,'watch-mobile','.w-cart-compare .price-cell','line-height','22','','','.w-cart-compare'),(36298,'watch-mobile','.w-cart-compare .js-cart_totals_container','line-height','1.2','','','.w-cart-compare'),(36299,'watch-mobile','.w-cart-compare .attributes-cell','line-height','22','','','.w-cart-compare'),(36300,'watch-mobile','.w-cart-compare .cart-name a','line-height','1.2','','','.w-cart-compare'),(36301,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line-height','24','3','','.w-catalog-compare'),(36302,'watch-mobile','.w-catalog-compare td','line-height','1.5','','','.w-catalog-compare'),(36303,'watch-mobile','.w-catalog-compare span.btn-preloader','line-height','24','3','','.w-catalog-compare'),(36304,'watch-mobile','.w-catalog-paging .next','line-height','26','3','','.w-catalog-paging'),(36305,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line-height','30','','','.w-catalog-paging'),(36306,'watch-mobile','.w-catalog-paging .next','line-height','30','','','.w-catalog-paging'),(36307,'watch-mobile','.w-catalog-paging ','line-height','30','2','','.w-catalog-paging'),(36308,'watch-mobile','.w-catalog-paging .next-pages','line-height','30','','','.w-catalog-paging'),(36309,'watch-mobile','.w-catalog-paging .page-number','line-height','30','','','.w-catalog-paging'),(36310,'watch-mobile','.w-catalog-paging .prev-pages','line-height','30','','','.w-catalog-paging'),(36311,'watch-mobile','.w-catalog-paging .prev','line-height','30','','','.w-catalog-paging'),(36312,'watch-mobile','.w-catalog-paging .prev','line-height','26','3','','.w-catalog-paging'),(36313,'watch-mobile','.w-checkout-billing-address .addresses .address-item label','line-height','1.3','','','.w-checkout-billing-address'),(36314,'watch-mobile','.w-checkout-create-account .account-benefits strong','line-height','16','3','','.w-checkout-create-account'),(36315,'watch-mobile','.w-checkout-shipping-address .addresses .address-item label','line-height','1.3','','','.w-checkout-shipping-address'),(36316,'watch-mobile','.w-checkout-shipping-choice span','line-height','19','','','.w-checkout-shipping-choice'),(36317,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','35','3','','.w-communication-new-topic'),(36318,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line-height','36','','','.w-communication-new-topic'),(36319,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','40','','','.w-communication-new-topic'),(36320,'watch-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','line-height','1.2','','','.w-communication-new-topic'),(36321,'watch-mobile','.w-delivery-day .ends','line-height','1','','','.w-delivery-day'),(36322,'watch-mobile','.w-multi-cart-cart-switcher .cart-label','line-height','20','','','.w-multi-cart-cart-switcher'),(36323,'watch-mobile','.w-personal-gift-status-bar .end-date','line-height','14','3','','.w-personal-gift-status-bar'),(36324,'watch-mobile','.w-personal-gift-status-bar .inform','line-height','14','4','','.w-personal-gift-status-bar'),(36325,'watch-mobile','.w-product-customers-activity .close','line-height','32','','','.w-product-customers-activity'),(36326,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','line-height','23','','','.w-promotions'),(36327,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','line-height','23','','','.w-promotions'),(36328,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','line-height','23','','','.w-promotions'),(36329,'watch-mobile','.w-promotions .promo-salemaker .discount','line-height','23','','','.w-promotions'),(36330,'watch-mobile','.w-promotions .heading-3','line-height','1','','','.w-promotions'),(36331,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','line-height','22','','','.w-filters'),(36332,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','line-height','22','','','.w-filters'),(36333,'watch-mobile','.w-menu-slider .close','line_height_measure','px','','','.w-menu-slider'),(36334,'watch-mobile','.w-catalog-listing-look .list','line_height_measure','px','','','.w-catalog-listing-look'),(36335,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','line_height_measure','px','','','.b-form'),(36336,'watch-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','line_height_measure','px','','','.b-form'),(36337,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line_height_measure','px','','','.b-form'),(36338,'watch-mobile','.w-sale .badge','line_height_measure','px','','','.w-sale'),(36339,'watch-mobile','.w-product-wedding-registry-button .btn','line_height_measure','px','','','.w-product-wedding-registry-button'),(36342,'watch-mobile','.w-bestsellers .item','line_height_measure','px','3','','.w-bestsellers'),(36343,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line_height_measure','px','3','','.b-multi-page-checkout'),(36344,'watch-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-discount-coupon'),(36345,'watch-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(36346,'watch-mobile','.w-catalog-listing-look .b2b','line_height_measure','px','','','.w-catalog-listing-look'),(36347,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line_height_measure','px','','','.b-multi-page-checkout'),(36348,'watch-mobile','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(36349,'watch-mobile','.b-pagination .pagination .prev-pages','line_height_measure','px','','','.b-pagination'),(36350,'watch-mobile','.b-pagination .pagination .prev','line_height_measure','px','3','','.b-pagination'),(36351,'watch-mobile','.b-pagination .pagination .prev','line_height_measure','px','','','.b-pagination'),(36352,'watch-mobile','.b-pagination .pagination .next-pages','line_height_measure','px','','','.b-pagination'),(36353,'watch-mobile','.b-pagination .pagination .page-number','line_height_measure','px','','','.b-pagination'),(36354,'watch-mobile','.b-pagination .pagination .next','line_height_measure','px','3','','.b-pagination'),(36355,'watch-mobile','.b-pagination .pagination .next','line_height_measure','px','','','.b-pagination'),(36357,'watch-mobile','.b-pagination .pagination span','line_height_measure','px','2','','.b-pagination'),(36361,'watch-mobile','.p-blog-index .nav-previous a','line_height_measure','px','3','','.p-blog-index'),(36362,'watch-mobile','.p-blog-index .nav-next a','line_height_measure','px','3','','.p-blog-index'),(36363,'watch-mobile','.w-list-type-2_2 .price','line_height_measure','%','','','.w-list-type-2_2'),(36364,'watch-mobile','.w-list-type-2_2 .description','line_height_measure','%','','','.w-list-type-2_2'),(36365,'watch-mobile','.w-product-personal-catalog-button .btn','line_height_measure','px','','','.w-product-personal-catalog-button'),(36366,'watch-mobile','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(36367,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','line_height_measure','px','3','','.b-form'),(36368,'watch-mobile','.p-wedding-registry-manage .links a','line_height_measure','px','','','.p-wedding-registry-manage'),(36369,'watch-mobile','.p-wedding-registry-manage .links a.share-registry','line_height_measure','px','','','.p-wedding-registry-manage'),(36370,'watch-mobile','.b-pagination .pagination a','line_height_measure','px','','','.b-pagination'),(36371,'watch-mobile','.b-switch .bootstrap-switch','line_height_measure','px','','','.b-switch'),(36372,'watch-mobile','.w-quote .cart-box-link','line_height_measure','px','299,3','','.w-quote'),(36373,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line_height_measure','px','','','.b-switch'),(36374,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','line_height_measure','px','','','.b-fancybox'),(36375,'watch-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(36376,'watch-mobile','.w-catalog-listing-look .grid','line_height_measure','px','','','.w-catalog-listing-look'),(36377,'watch-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line_height_measure','px','','','.b-slick'),(36378,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','','','.b-slick'),(36380,'watch-mobile','.p-account-subscription-historyinfo .order_history_table th','line_height_measure','px','','','.p-account-subscription-historyinfo'),(36381,'watch-mobile','.b-info-popup .info-popup','line_height_measure','px','','','.b-info-popup'),(36383,'watch-mobile','.w-menu-mobile .menu-ico','line_height_measure','px','','','.w-menu-mobile'),(36384,'watch-mobile','.w-list-type-1_3 .price','line_height_measure','%','','','.w-list-type-1_3'),(36385,'watch-mobile','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(36386,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','303','','.b-slick'),(36387,'watch-mobile','.b-form .cart-popup .price','line_height_measure','px','','','.b-form'),(36388,'watch-mobile','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(36389,'watch-mobile','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(36390,'watch-mobile','.w-cart .cart-box-link','line_height_measure','px','3','','.w-cart'),(36391,'watch-mobile','.w-menu-style-1 .menu-ico','line_height_measure','px','','','.w-menu-style-1'),(36392,'watch-mobile','.w-account .my-acc-link','line_height_measure','px','3','','.w-account'),(36393,'watch-mobile','.b-fancybox .fancybox-nav span','line_height_measure','px','','','.b-fancybox'),(36394,'watch-mobile','.btn','line_height_measure','px','','',''),(36397,'watch-mobile','.btn-3','line_height_measure','px','','',''),(36398,'watch-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','line_height_measure','px','','','.w-filters'),(36399,'watch-mobile','.btn-1','line_height_measure','px','','',''),(36400,'watch-mobile','.heading-4 .right-text, h4 .right-text','line_height_measure','px','','',''),(36401,'watch-mobile','.heading-3 .edit, h3 .edit','line_height_measure','px','','',''),(36402,'watch-mobile','.btn-2','line_height_measure','px','','',''),(36403,'watch-mobile','.w-currencies .currencies-title','line_height_measure','px','','','.w-currencies'),(36404,'watch-mobile','.w-list-type-1 .sale','line_height_measure','px','4','','.w-list-type-1'),(36405,'watch-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','line_height_measure','px','','','.w-filters'),(36406,'watch-mobile','.w-list-type-1_2 .button-wishlist button','line_height_measure','px','','','.w-list-type-1_2'),(36407,'watch-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line_height_measure','px','','','.w-compare-box-item'),(36408,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-1_2'),(36409,'watch-mobile','.w-list-type-1 .button-view a','line_height_measure','px','','','.w-list-type-1'),(36410,'watch-mobile','.w-list-type-1 .sale','line_height_measure','px','3','','.w-list-type-1'),(36411,'watch-mobile','.w-list-type-1_3 .button-view a','line_height_measure','px','','','.w-list-type-1_3'),(36412,'watch-mobile','.w-list-type-1 .button-wishlist button','line_height_measure','px','','','.w-list-type-1'),(36413,'watch-mobile','.w-list-type-1_2 .button-view a','line_height_measure','px','','','.w-list-type-1_2'),(36414,'watch-mobile','.w-list-type-1_2 .sale','line_height_measure','px','4','','.w-list-type-1_2'),(36415,'watch-mobile','.w-list-type-1_3 .sale','line_height_measure','px','3','','.w-list-type-1_3'),(36416,'watch-mobile','.w-menu-slider .menu-ico','line_height_measure','px','','','.w-menu-slider'),(36417,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-1'),(36418,'watch-mobile','.w-list-type-2 .button-wishlist button','line_height_measure','px','','','.w-list-type-2'),(36419,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-1_3'),(36420,'watch-mobile','.w-list-type-2 .button-view a','line_height_measure','px','','','.w-list-type-2'),(36421,'watch-mobile','.w-list-type-1_3 .button-wishlist button','line_height_measure','px','','','.w-list-type-1_3'),(36422,'watch-mobile','.w-list-type-1_3 .sale','line_height_measure','px','4','','.w-list-type-1_3'),(36423,'watch-mobile','.w-list-type-1_2 .sale','line_height_measure','px','3','','.w-list-type-1_2'),(36424,'watch-mobile','.w-list-type-2_2 .sale','line_height_measure','px','3','','.w-list-type-2_2'),(36425,'watch-mobile','.w-list-type-2_2 .sale','line_height_measure','px','4','','.w-list-type-2_2'),(36426,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-2'),(36427,'watch-mobile','.w-list-type-2_2 .button-wishlist button','line_height_measure','px','','','.w-list-type-2_2'),(36428,'watch-mobile','.w-menu-horizontal .menu-ico','line_height_measure','px','','','.w-menu-horizontal'),(36429,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-2_2'),(36430,'watch-mobile','.w-list-type-2 .sale','line_height_measure','px','4','','.w-list-type-2'),(36431,'watch-mobile','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(36432,'watch-mobile','.w-list-type-2 .sale','line_height_measure','px','3','','.w-list-type-2'),(36433,'watch-mobile','.w-list-type-2_2 .button-view a','line_height_measure','px','','','.w-list-type-2_2'),(36434,'watch-mobile','.heading-4 .edit, h4 .edit','line_height_measure','px','','',''),(36436,'watch-mobile','.heading-3 .right-text, h3 .right-text','line_height_measure','px','','',''),(36437,'watch-mobile','.w-list-type-2 .description','line_height_measure','%','','','.w-list-type-2'),(36438,'watch-mobile','.w-list-type-2 .price','line_height_measure','%','','','.w-list-type-2'),(36439,'watch-mobile','.w-list-type-1_3 .description','line_height_measure','%','','','.w-list-type-1_3'),(36440,'watch-mobile','.w-list-type-1_2 .price','line_height_measure','%','','','.w-list-type-1_2'),(36441,'watch-mobile','.w-list-type-1_2 .description','line_height_measure','%','','','.w-list-type-1_2'),(36442,'watch-mobile','.b-bottom .pop-up-close','line_height_measure','px','','','.b-bottom'),(36443,'watch-mobile','.w-list-type-1 .price','line_height_measure','%','','','.w-list-type-1'),(36444,'watch-mobile','.w-list-type-1 .description','line_height_measure','%','','','.w-list-type-1'),(36445,'watch-mobile','.w-bestsellers .counter','line_height_measure','px','','','.w-bestsellers'),(36446,'watch-mobile','.b-info-popup .info-popup div','line_height_measure','px','3','','.b-info-popup'),(36447,'watch-mobile','.b-products-listing .btn-preloader','line_height_measure','px','3','','.b-products-listing'),(36448,'watch-mobile','.b-products-listing .loader','line_height_measure','px','4','','.b-products-listing'),(36449,'watch-mobile','.b-products-listing .products-listing .btn-buy','line_height_measure','px','3','','.b-products-listing'),(36450,'watch-mobile','.b-products-listing .products-listing .btn-preloader','line_height_measure','px','','','.b-products-listing'),(36451,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.b-data-table'),(36452,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.b-data-table'),(36453,'watch-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line_height_measure','px','','','.b-menu-burger_icon'),(36454,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(36455,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(36456,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(36457,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(36458,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(36459,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','line_height_measure','px','','','.b-menu-style-2'),(36460,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','line_height_measure','px','','','.b-menu-style-2'),(36461,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','line_height_measure','px','','','.b-menu-style-2'),(36462,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','line_height_measure','px','3','','.b-menu-style-2'),(36463,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','line_height_measure','px','3','','.b-menu-style-2'),(36464,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-messages'),(36465,'watch-mobile','.b-messages span.starred::before','line_height_measure','px','','','.b-messages'),(36466,'watch-mobile','.b-messages .messBtnMenuStarred','line_height_measure','px','3','','.b-messages'),(36467,'watch-mobile','.b-messages .messBtnMenuDelete','line_height_measure','px','3','','.b-messages'),(36468,'watch-mobile','.b-messages .messBtnMenuUnread','line_height_measure','px','3','','.b-messages'),(36469,'watch-mobile','.b-preloader .preloader','line_height_measure','px','3','','.b-preloader'),(36470,'watch-mobile','.b-select-suggest .select2-container .select2-choice','line_height_measure','px','','','.b-select-suggest'),(36471,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-select-suggest'),(36472,'watch-mobile','.b-upload-file .snapshot','line_height_measure','px','','','.b-upload-file'),(36473,'watch-mobile','.batchPr .batchSelect .checkbox','line_height_measure','px','','','.batchPr'),(36474,'watch-mobile','.batchPr .checkbox input:not(checked) + span:before','line_height_measure','px','','','.batchPr'),(36475,'watch-mobile','.bell-ico .heading-2','line_height_measure','px','3','','.bell-ico'),(36501,'watch-mobile','.p-payer-order-confirmation .discount-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(36502,'watch-mobile','.p-payer-order-confirmation .comment-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(36503,'watch-mobile','.p-payer-order-confirmation .pay-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(36504,'watch-mobile','.p-payer-order-confirmation .ship-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(36505,'watch-mobile','.p-payer-order-confirmation .order-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(36506,'watch-mobile','.p-payer-order-pay .ship-ico','line_height_measure','px','3','','.p-payer-order-pay'),(36507,'watch-mobile','.p-payer-order-pay .pay-ico','line_height_measure','px','3','','.p-payer-order-pay'),(36508,'watch-mobile','.p-payer-order-pay .order-ico','line_height_measure','px','3','','.p-payer-order-pay'),(36509,'watch-mobile','.p-payer-order-pay .comment-ico','line_height_measure','px','3','','.p-payer-order-pay'),(36510,'watch-mobile','.p-payer-order-pay .discount-ico','line_height_measure','px','3','','.p-payer-order-pay'),(36511,'watch-mobile','.p-quick-order-index .paginate_button.next','line_height_measure','px','3','','.p-quick-order-index'),(36512,'watch-mobile','.p-quick-order-index .paginate_button.previous','line_height_measure','px','3','','.p-quick-order-index'),(36513,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.p-quick-order-index'),(36514,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.p-quick-order-index'),(36515,'watch-mobile','.savings-ico .heading-2','line_height_measure','px','3','','.savings-ico'),(36516,'watch-mobile','.shipping-ico .heading-2','line_height_measure','px','3','','.shipping-ico'),(36517,'watch-mobile','.shipping-ico .heading-2','line_height_measure','px','3','','.shipping-ico'),(36518,'watch-mobile','.shipping-ico .heading-2','line_height_measure','px','3','','.shipping-ico'),(36519,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','line_height_measure','px','','','.w-blog-widget-related-posts'),(36520,'watch-mobile','.w-cart-compare .attributes-cell','line_height_measure','px','','','.w-cart-compare'),(36521,'watch-mobile','.w-cart-compare .price-cell','line_height_measure','px','','','.w-cart-compare'),(36522,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line_height_measure','px','3','','.w-catalog-compare'),(36523,'watch-mobile','.w-catalog-compare span.btn-preloader','line_height_measure','px','3','','.w-catalog-compare'),(36524,'watch-mobile','.w-catalog-paging ','line_height_measure','px','2','','.w-catalog-paging'),(36525,'watch-mobile','.w-catalog-paging .next','line_height_measure','px','','','.w-catalog-paging'),(36526,'watch-mobile','.w-catalog-paging .prev','line_height_measure','px','','','.w-catalog-paging'),(36527,'watch-mobile','.w-catalog-paging .next','line_height_measure','px','3','','.w-catalog-paging'),(36528,'watch-mobile','.w-catalog-paging .next-pages','line_height_measure','px','','','.w-catalog-paging'),(36529,'watch-mobile','.w-catalog-paging .prev-pages','line_height_measure','px','','','.w-catalog-paging'),(36530,'watch-mobile','.w-catalog-paging .page-number','line_height_measure','px','','','.w-catalog-paging'),(36531,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line_height_measure','px','','','.w-catalog-paging'),(36532,'watch-mobile','.w-catalog-paging .prev','line_height_measure','px','3','','.w-catalog-paging'),(36533,'watch-mobile','.w-checkout-create-account .account-benefits strong','line_height_measure','px','3','','.w-checkout-create-account'),(36534,'watch-mobile','.w-checkout-shipping-choice span','line_height_measure','px','','','.w-checkout-shipping-choice'),(36535,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line_height_measure','px','','','.w-communication-new-topic'),(36536,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','3','','.w-communication-new-topic'),(36537,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','','','.w-communication-new-topic'),(36538,'watch-mobile','.w-multi-cart-cart-switcher .cart-label','line_height_measure','px','','','.w-multi-cart-cart-switcher'),(36539,'watch-mobile','.w-personal-gift-status-bar .end-date','line_height_measure','px','3','','.w-personal-gift-status-bar'),(36540,'watch-mobile','.w-personal-gift-status-bar .inform','line_height_measure','px','4','','.w-personal-gift-status-bar'),(36541,'watch-mobile','.w-product-customers-activity .close','line_height_measure','px','','','.w-product-customers-activity'),(36542,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','line_height_measure','px','','','.w-promotions'),(36543,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','line_height_measure','px','','','.w-promotions'),(36544,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','line_height_measure','px','','','.w-promotions'),(36545,'watch-mobile','.w-promotions .promo-salemaker .discount','line_height_measure','px','','','.w-promotions'),(36546,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','line_height_measure','px','','','.w-filters'),(36547,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','line_height_measure','px','','','.w-filters'),(36548,'watch-mobile','.w-menu-big ul','list-style','none','','','.w-menu-big'),(36549,'watch-mobile','.w-menu-slider ul, .w-menu-slider li','list-style','none','','','.w-menu-slider'),(36550,'watch-mobile','.w-menu-horizontal ul','list-style','none','','','.w-menu-horizontal'),(36551,'watch-mobile','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(36552,'watch-mobile','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(36553,'watch-mobile','.p-blog-index .wp-widget ul','list-style','none','','','.p-blog-index'),(36554,'watch-mobile','.p-blog-index .wp-widget li','list-style','none','','','.p-blog-index'),(36555,'watch-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','list-style','none','','','.p-blog-index'),(36556,'watch-mobile','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(36557,'watch-mobile','.w-account ul, .w-account li','list-style','none','','','.w-account'),(36558,'watch-mobile','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(36559,'watch-mobile','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(36560,'watch-mobile','.w-tabs .tab-navigation','list-style','none','','','.w-tabs'),(36561,'watch-mobile','.w-filters .filter-ul-content','list-style','none','','','.w-filters'),(36562,'watch-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(36563,'watch-mobile','.w-menu-style-1 ul','list-style','none','','','.w-menu-style-1'),(36564,'watch-mobile','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(36566,'watch-mobile','.b-autocomplete .ui-autocomplete','list-style','none','','','.b-autocomplete'),(36567,'watch-mobile','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(36571,'watch-mobile','.b-info .info ul','list-style','disc inside','','','.b-info'),(36572,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(36573,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(36574,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(36575,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(36576,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(36577,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(36578,'watch-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','list-style','none','','','.b-menu-style'),(36579,'watch-mobile','.b-messages .messages-menu ul','list-style','none','','','.b-messages'),(36580,'watch-mobile','.b-select-suggest .select2-results li','list-style','none','','','.b-select-suggest'),(36581,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices li','list-style','none','','','.b-select-suggest'),(36582,'watch-mobile','.p-quick-order-index ul.token-input-list','list-style','none','','','.p-quick-order-index'),(36583,'watch-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','list-style','none','','','.w-catalog-additional-images'),(36584,'watch-mobile','.w-sitemap-delivery-location > ul','list-style','none','','','.w-sitemap-delivery-location'),(36585,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul','list-style','none','','','.w-sitemap-delivery-location'),(36586,'watch-mobile','.w-filters .filter-box-content ul','list-style','none','','','.w-filters'),(36587,'watch-mobile','.b-product-images .additional-horizontal .additional-images .item, .b-product-images .additional-horizontal .additional-videos .item','margin','0 auto','','','.b-product-images'),(36588,'watch-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','margin','0 auto','','','.b-product-images'),(36589,'watch-mobile','.w-delivery-location-top-location-list .deliveryName','margin','5px auto','','','.w-delivery-location-top-location-list'),(36590,'watch-mobile','.p-wedding-registry-manage .wr-search','margin','0 auto 20px','','','.p-wedding-registry-manage'),(36591,'watch-mobile','.p-wedding-registry-index .middle-box','margin','0 auto','','','.p-wedding-registry-index'),(36592,'watch-mobile','.b-form .middle-form','margin','0 auto','','','.b-form'),(36593,'watch-mobile','.b-messages .msv_btn .btn','margin','0px auto 0px','','','.b-messages'),(36594,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','margin','3px auto 3px','','','.b-select-suggest'),(36595,'watch-mobile','.b-select-suggest .select2-results','margin','4px auto 4px','','','.b-select-suggest'),(36596,'watch-mobile','.b-trade-approval .middle-form','margin','0 auto','','','.b-trade-approval'),(36597,'watch-mobile','.w-blog-widget-tag-cloud a','margin','0px auto 4px','','','.w-blog-widget-tag-cloud'),(36598,'watch-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','margin','0 auto','','','.w-catalog-b2b-add-button'),(36599,'watch-mobile','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(36600,'watch-mobile','.w-menu-big li','margin-bottom','0','','','.w-menu-big'),(36601,'watch-mobile','.w-menu .hided.menu ul li','margin-bottom','0','','','.w-menu'),(36602,'watch-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-bottom','0','','','.w-menu'),(36603,'watch-mobile','.w-menu-big ul','margin-bottom','0','','','.w-menu-big'),(36604,'watch-mobile','.w-bestsellers .heading-3','margin-bottom','10','','','.w-bestsellers'),(36605,'watch-mobile','.w-menu-slider ul, .w-menu-slider li','margin-bottom','0','','','.w-menu-slider'),(36606,'watch-mobile','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(36607,'watch-mobile','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(36608,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(36609,'watch-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-bottom','0','','','.b-cookie-notice'),(36610,'watch-mobile','.b-form .bootstrap-switch','margin-bottom','15','','','.b-form'),(36611,'watch-mobile','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','margin-bottom','15','','','.b-form'),(36612,'watch-mobile','.b-form .checkbox-style','margin-bottom','0','','','.b-form'),(36613,'watch-mobile','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(36614,'watch-mobile','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(36615,'watch-mobile','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(36616,'watch-mobile','.w-product-sale-ends .ends','margin-bottom','20','','','.w-product-sale-ends'),(36617,'watch-mobile','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(36618,'watch-mobile','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(36619,'watch-mobile','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(36620,'watch-mobile','.w-product-sale-ends .left','margin-bottom','30','','','.w-product-sale-ends'),(36621,'watch-mobile','.w-list-type-2_2 .title','margin-bottom','10','','','.w-list-type-2_2'),(36622,'watch-mobile','.w-sale .name','margin-bottom','20','','','.w-sale'),(36623,'watch-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','margin-bottom','0','','','.b-product-images'),(36624,'watch-mobile','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(36625,'watch-mobile','.w-filters .filter-ul-content','margin-bottom','0','','','.w-filters'),(36626,'watch-mobile','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(36627,'watch-mobile','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(36628,'watch-mobile','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(36632,'watch-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','margin-bottom','10','','','.p-account-trade-form'),(36633,'watch-mobile','.b-price-box .checkout-index .price-box, .b-price-box .checkout-confirmation .price-box','margin-bottom','20','','','.b-price-box'),(36634,'watch-mobile','.w-product-attributes .select-box:nth-child(2n+1)','margin-bottom','20','','','.w-product-attributes'),(36635,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','margin-bottom','5','','','.b-multi-page-checkout'),(36636,'watch-mobile','.p-blog-index .wp-widget','margin-bottom','20','','','.p-blog-index'),(36637,'watch-mobile','.p-blog-index .nav-previous','margin-bottom','20','315','','.p-blog-index'),(36638,'watch-mobile','.p-blog-index .post_body','margin-bottom','30','','','.p-blog-index'),(36639,'watch-mobile','.p-blog-index .autor_name_data','margin-bottom','10','','','.p-blog-index'),(36640,'watch-mobile','.w-list-type-1_2 .image','margin-bottom','10','291','','.w-list-type-1_2'),(36641,'watch-mobile','.w-socials .post_item_img','margin-bottom','0','','','.w-socials'),(36642,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-bottom','0','','','.b-multi-page-checkout'),(36643,'watch-mobile','.w-search .search-input','margin-bottom','0','','','.w-search'),(36644,'watch-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(36645,'watch-mobile','.w-delivery-location-top-location-list .deliveryList','margin-bottom','0','','','.w-delivery-location-top-location-list'),(36646,'watch-mobile','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(36647,'watch-mobile','.w-delivery-location-top-location-list','margin-bottom','25','','','.w-delivery-location-top-location-list'),(36651,'watch-mobile','.p-sample-checkout-index .price-box','margin-bottom','20','','','.p-sample-checkout-index'),(36652,'watch-mobile','.testimonials .name','margin-bottom','20','','',''),(36653,'watch-mobile','.p-sample-checkout-index .buttons','margin-bottom','20','','','.p-sample-checkout-index'),(36654,'watch-mobile','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(36655,'watch-mobile','.b-pagination .pagination','margin-bottom','20','','','.b-pagination'),(36656,'watch-mobile','.testimonials .heading-3','margin-bottom','10','','',''),(36657,'watch-mobile','.testimonials .reviews-list .name','margin-bottom','20','','',''),(36658,'watch-mobile','.b-bottom .confirm-popup .buttons .btn','margin-bottom','0','','','.b-bottom'),(36662,'watch-mobile','.p-blog-index .comment-form p','margin-bottom','20','','','.p-blog-index'),(36663,'watch-mobile','.p-blog-index .comments-area article','margin-bottom','10','','','.p-blog-index'),(36664,'watch-mobile','.pop-up-content .buttons .left-buttons','margin-bottom','15','291','',''),(36665,'watch-mobile','.w-list-type-2_2 .price','margin-bottom','10','','','.w-list-type-2_2'),(36666,'watch-mobile','.w-list-type-2_2 .qty-input','margin-bottom','10','','','.w-list-type-2_2'),(36667,'watch-mobile','.w-list-type-2_2 .properties','margin-bottom','5','','','.w-list-type-2_2'),(36668,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-2_2'),(36669,'watch-mobile','.w-list-type-2_2 .description','margin-bottom','5','','','.w-list-type-2_2'),(36670,'watch-mobile','.w-list-type-2 .title','margin-bottom','10','','','.w-list-type-2'),(36671,'watch-mobile','.w-list-type-2 .qty-input','margin-bottom','10','','','.w-list-type-2'),(36672,'watch-mobile','.w-list-type-2 .properties','margin-bottom','5','','','.w-list-type-2'),(36673,'watch-mobile','.w-list-type-2 .price','margin-bottom','10','','','.w-list-type-2'),(36674,'watch-mobile','.personal-buttons > div > div','margin-bottom','20','','','.personal-buttons'),(36675,'watch-mobile','.w-bestsellers .item','margin-bottom','12','','','.w-bestsellers'),(36676,'watch-mobile','.b-fancybox .fancybox-error','margin-bottom','0','','','.b-fancybox'),(36677,'watch-mobile','.w-account ul, .w-account li','margin-bottom','0','','','.w-account'),(36678,'watch-mobile','.w-menu-horizontal ul','margin-bottom','0','','','.w-menu-horizontal'),(36679,'watch-mobile','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(36680,'watch-mobile','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(36681,'watch-mobile','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(36682,'watch-mobile','.w-delivery-location-top-location-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-top-location-list'),(36683,'watch-mobile','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(36684,'watch-mobile','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(36685,'watch-mobile','.b-form #shipping-address .radio-buttons','margin-bottom','10','','','.b-form'),(36686,'watch-mobile','.b-form .radio-buttons','margin-bottom','20','','','.b-form'),(36687,'watch-mobile','.p-quote-cart-index .w-quote-checkout-btn','margin-bottom','20','','','.p-quote-cart-index'),(36688,'watch-mobile','.p-wedding-registry-index .main-content','margin-bottom','20','','','.p-wedding-registry-index'),(36689,'watch-mobile','.p-wedding-registry-index .search-list','margin-bottom','10','','','.p-wedding-registry-index'),(36690,'watch-mobile','.b-form .form-inputs label > span','margin-bottom','3','','','.b-form'),(36691,'watch-mobile','.p-wedding-registry-index .search-list label','margin-bottom','10','','','.p-wedding-registry-index'),(36692,'watch-mobile','.b-form .addresses','margin-bottom','20','','','.b-form'),(36693,'watch-mobile','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(36694,'watch-mobile','.p-wedding-registry-manage .wedding-date','margin-bottom','30','','','.p-wedding-registry-manage'),(36695,'watch-mobile','.p-wedding-registry-search .result-table','margin-bottom','50','','','.p-wedding-registry-search'),(36696,'watch-mobile','.p-wedding-registry-search .search-form','margin-bottom','30','','','.p-wedding-registry-search'),(36706,'watch-mobile','.b-compare .clear_all','margin-bottom','0','4','','.b-compare'),(36707,'watch-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin-bottom','0','','','.b-compare'),(36708,'watch-mobile','.b-compare .col-two','margin-bottom','15','','','.b-compare'),(36709,'watch-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-bottom','0','','','.b-switch'),(36714,'watch-mobile','.w-top-categories .categories','margin-bottom','0','292','','.w-top-categories'),(36716,'watch-mobile','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(36717,'watch-mobile','.w-breadcrumb .breadcrumb-li','margin-bottom','0','','','.w-breadcrumb'),(36718,'watch-mobile','.w-list-type-1_3 .qty-input','margin-bottom','10','','','.w-list-type-1_3'),(36719,'watch-mobile','.heading-3, h3','margin-bottom','10','','',''),(36720,'watch-mobile','.heading-2, h2','margin-bottom','15','','',''),(36721,'watch-mobile','h1','margin-bottom','18','','',''),(36722,'watch-mobile','.heading-4, h4','margin-bottom','5','','',''),(36723,'watch-mobile','.w-list-type-1_3 .properties','margin-bottom','5','','','.w-list-type-1_3'),(36724,'watch-mobile','.w-tabs .tab-li','margin-bottom','0','','','.w-tabs'),(36725,'watch-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-bottom','0','','','.b-form'),(36726,'watch-mobile','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(36727,'watch-mobile','.w-top-categories .categories','margin-bottom','0','','','.w-top-categories'),(36728,'watch-mobile','.w-tabs .tab-navigation','margin-bottom','0','','','.w-tabs'),(36729,'watch-mobile','.p-account-trade-form .widget h3','margin-bottom','10','','','.p-account-trade-form'),(36730,'watch-mobile','.p-account-trade-form .widget','margin-bottom','20','','','.p-account-trade-form'),(36731,'watch-mobile','.p-blog-index .nav-previous a','margin-bottom','0','3','','.p-blog-index'),(36732,'watch-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-bottom','0','','','.p-blog-index'),(36733,'watch-mobile','.p-blog-index .wp-widget li','margin-bottom','0','3','','.p-blog-index'),(36734,'watch-mobile','.p-account-trade-form .wl-td','margin-bottom','10','','','.p-account-trade-form'),(36735,'watch-mobile','.p-blog-index .post-thumbnail','margin-bottom','20','','','.p-blog-index'),(36737,'watch-mobile','.p-blog-index .wp-widget ul','margin-bottom','0','','','.p-blog-index'),(36738,'watch-mobile','.p-blog-index .wp-widget li','margin-bottom','0','','','.p-blog-index'),(36739,'watch-mobile','.p-blog-index .nav-next a','margin-bottom','0','3','','.p-blog-index'),(36742,'watch-mobile','.p-reviews-info .review-info-content','margin-bottom','20','','','.p-reviews-info'),(36743,'watch-mobile','.p-reviews-info .review-info-reviewed_by','margin-bottom','0','','','.p-reviews-info'),(36744,'watch-mobile','.p-reviews-info .review-info-text','margin-bottom','20','','','.p-reviews-info'),(36745,'watch-mobile','.p-reviews-info .review-info-image','margin-bottom','0','','','.p-reviews-info'),(36746,'watch-mobile','.p-reviews-info .reviews-info h1','margin-bottom','10','','','.p-reviews-info'),(36750,'watch-mobile','.w-filters .filter-box-head','margin-bottom','15','','','.w-filters'),(36752,'watch-mobile','.b-fancybox .fancybox-title-float-wrap','margin-bottom','-35','','','.b-fancybox'),(36753,'watch-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','margin-bottom','10','','','.p-account-trade-form'),(36754,'watch-mobile','.p-account-trade-form .trade-form-area','margin-bottom','20','','','.p-account-trade-form'),(36755,'watch-mobile','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(36756,'watch-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-bottom','8','','','.p-account-subscription-historyinfo'),(36761,'watch-mobile','.w-html_box .socials a','margin-bottom','0','','','.w-html_box'),(36762,'watch-mobile','.w-info-content p','margin-bottom','10','','','.w-info-content'),(36763,'watch-mobile','.w-filters .input-checkbox','margin-bottom','0','','','.w-filters'),(36767,'watch-mobile','.w-categories .categories','margin-bottom','0','','','.w-categories'),(36768,'watch-mobile','.w-cart-discount-coupon .gift-code p','margin-bottom','0','','','.w-cart-discount-coupon'),(36769,'watch-mobile','.w-cart-give-away .ga_attributes > div','margin-bottom','1','','','.w-cart-give-away'),(36770,'watch-mobile','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(36771,'watch-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(36772,'watch-mobile','.w-product-in-bundles .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(36773,'watch-mobile','.w-product-quantity .qty_packs .price_1','margin-bottom','0','4','','.w-product-quantity'),(36774,'watch-mobile','.w-product-configurator .pc_row','margin-bottom','20','','','.w-product-configurator'),(36775,'watch-mobile','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(36776,'watch-mobile','.w-product-bundle .bundle_item','margin-bottom','0','','','.w-product-bundle'),(36777,'watch-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(36778,'watch-mobile','.w-product-bundle .bundle_item + .bundle_item','margin-bottom','0','','','.w-product-bundle'),(36779,'watch-mobile','.w-menu-style-1 ul','margin-bottom','0','','','.w-menu-style-1'),(36780,'watch-mobile','.w-menu-style-1 li','margin-bottom','0','','','.w-menu-style-1'),(36781,'watch-mobile','.w-sale .ends','margin-bottom','20','','','.w-sale'),(36782,'watch-mobile','.w-sale .left','margin-bottom','30','','','.w-sale'),(36783,'watch-mobile','.w-product-reviews .reviews-list','margin-bottom','10','','','.w-product-reviews'),(36784,'watch-mobile','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(36785,'watch-mobile','.w-categories .categories h2','margin-bottom','0','','','.w-categories'),(36786,'watch-mobile','.w-top-categories .categories h2','margin-bottom','0','','','.w-top-categories'),(36787,'watch-mobile','.b-form .col-full-padding','margin-bottom','10','','','.b-form'),(36788,'watch-mobile','.b-form .terms-login .bootstrap-switch','margin-bottom','0','','','.b-form'),(36789,'watch-mobile','.b-form .col-full-margin','margin-bottom','10','','','.b-form'),(36790,'watch-mobile','.b-slick .slick-list','margin-bottom','0','','','.b-slick'),(36791,'watch-mobile','.w-socials > li','margin-bottom','10','','','.w-socials'),(36792,'watch-mobile','.w-list-type-1_3 .image','margin-bottom','10','291','','.w-list-type-1_3'),(36793,'watch-mobile','.w-menu-horizontal li','margin-bottom','0','','','.w-menu-horizontal'),(36794,'watch-mobile','.w-list-type-1_3 .price','margin-bottom','10','','','.w-list-type-1_3'),(36795,'watch-mobile','.b-form #frmCheckout','margin-bottom','20','','','.b-form'),(36796,'watch-mobile','.w-categories .categories','margin-bottom','0','290','','.w-categories'),(36797,'watch-mobile','.w-categories .categories','margin-bottom','0','292','','.w-categories'),(36798,'watch-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-bottom','0','','','.b-fancybox'),(36799,'watch-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-bottom','0','','','.b-fancybox'),(36800,'watch-mobile','.w-cart-give-away .ga_wrapper','margin-bottom','25','','','.w-cart-give-away'),(36801,'watch-mobile','.w-top-categories .categories','margin-bottom','0','290','','.w-top-categories'),(36802,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-2'),(36803,'watch-mobile','.w-list-type-1_3 .title','margin-bottom','10','','','.w-list-type-1_3'),(36804,'watch-mobile','.w-list-type-2 .image','margin-bottom','20','','','.w-list-type-2'),(36805,'watch-mobile','.w-list-type-2 .description','margin-bottom','5','','','.w-list-type-2'),(36806,'watch-mobile','.w-list-type-1_3 .description','margin-bottom','5','','','.w-list-type-1_3'),(36807,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-1_3'),(36808,'watch-mobile','.w-list-type-1_3 .attributes > .attributes > div','margin-bottom','5','','','.w-list-type-1_3'),(36809,'watch-mobile','.w-list-type-1_2 .title','margin-bottom','10','','','.w-list-type-1_2'),(36810,'watch-mobile','.w-list-type-1_2 .qty-input','margin-bottom','10','','','.w-list-type-1_2'),(36811,'watch-mobile','.w-list-type-1_2 .price','margin-bottom','10','','','.w-list-type-1_2'),(36812,'watch-mobile','.w-list-type-1_2 .properties','margin-bottom','5','','','.w-list-type-1_2'),(36813,'watch-mobile','.w-list-type-1_2 .description','margin-bottom','5','','','.w-list-type-1_2'),(36814,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-1_2'),(36815,'watch-mobile','.b-bottom .content-item','margin-bottom','20','','','.b-bottom'),(36816,'watch-mobile','.b-bottom .pop-up-content .buttons','margin-bottom','0','','','.b-bottom'),(36817,'watch-mobile','.w-list-type-1 .title','margin-bottom','10','','','.w-list-type-1'),(36818,'watch-mobile','.w-list-type-1 .description','margin-bottom','5','','','.w-list-type-1'),(36819,'watch-mobile','.w-list-type-1 .price','margin-bottom','10','','','.w-list-type-1'),(36820,'watch-mobile','.w-list-type-1 .qty-input','margin-bottom','10','','','.w-list-type-1'),(36821,'watch-mobile','.w-list-type-1 .properties','margin-bottom','5','','','.w-list-type-1'),(36822,'watch-mobile','.w-list-type-1 .image','margin-bottom','20','','','.w-list-type-1'),(36823,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-1'),(36824,'watch-mobile','.w-filters .ui-slider','margin-bottom','0','','','.w-filters'),(36825,'watch-mobile','.w-reviews .heading-3','margin-bottom','10','','','.w-reviews'),(36826,'watch-mobile','.w-reviews .name','margin-bottom','20','','','.w-reviews'),(36827,'watch-mobile','.w-product-reviews .reviews-list .name','margin-bottom','20','','','.w-product-reviews'),(36828,'watch-mobile','.w-reviews .reviews-list .name','margin-bottom','20','','','.w-reviews'),(36829,'watch-mobile','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(36830,'watch-mobile','.b-form .payment-method .item-radio','margin-bottom','5','','','.b-form'),(36831,'watch-mobile','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','margin-bottom','15','','','.b-form'),(36832,'watch-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin-bottom','10','','','.b-form'),(36833,'watch-mobile','.b-form .required-message-wrap','margin-bottom','0','','','.b-form'),(36834,'watch-mobile','.b-form .required-message','margin-bottom','0','','','.b-form'),(36835,'watch-mobile','.b-info .info li','margin-bottom','0','','','.b-info'),(36836,'watch-mobile','.b-info .info ul','margin-bottom','0','','','.b-info'),(36837,'watch-mobile','.b-products-listing .products-listing .bonusPoints','margin-bottom','7','','','.b-products-listing'),(36838,'watch-mobile','.b-products-listing .products-listing .description','margin-bottom','5','','','.b-products-listing'),(36839,'watch-mobile','.b-products-listing .products-listing .description ul','margin-bottom','0','','','.b-products-listing'),(36840,'watch-mobile','.b-products-listing .products-listing .model','margin-bottom','5','','','.b-products-listing'),(36841,'watch-mobile','.b-products-listing .products-listing .mult-qty-input','margin-bottom','3','','','.b-products-listing'),(36842,'watch-mobile','.b-products-listing .products-listing .name','margin-bottom','5','','','.b-products-listing'),(36843,'watch-mobile','.b-products-listing .products-listing h2','margin-bottom','0','','','.b-products-listing'),(36844,'watch-mobile','.b-products-listing .promos-info','margin-bottom','-30','','','.b-products-listing'),(36845,'watch-mobile','.b-products-listing .select-attributes','margin-bottom','10','','','.b-products-listing'),(36846,'watch-mobile','.b-products-listing .select-attributes select','margin-bottom','0','','','.b-products-listing'),(36847,'watch-mobile','.b-products-listing .wedding-registry-count','margin-bottom','10','','','.b-products-listing'),(36848,'watch-mobile','.b-delete-account .delete-box > div','margin-bottom','10','','','.b-delete-account'),(36849,'watch-mobile','.b-delete-account .delete-box span','margin-bottom','0','','','.b-delete-account'),(36850,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(36851,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(36852,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(36853,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(36854,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(36855,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(36856,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-bottom','0','','','.b-h-inline'),(36857,'watch-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-bottom','0','','','.b-menu-style'),(36858,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','margin-bottom','5','','','.b-menu-style-1'),(36859,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages','margin-bottom','10','','','.b-menu-style-2'),(36860,'watch-mobile','.b-messages .messMenuButtonTop','margin-bottom','-39','','','.b-messages'),(36861,'watch-mobile','.b-messages .dataTables_wrapper > .top','margin-bottom','8','','','.b-messages'),(36862,'watch-mobile','.b-messages .messages-menu ul','margin-bottom','0','','','.b-messages'),(36863,'watch-mobile','.b-messages .messages-sidebar .heading-2','margin-bottom','20','','','.b-messages'),(36864,'watch-mobile','.b-messages .messages-sidebar .btn-2','margin-bottom','20','','','.b-messages'),(36865,'watch-mobile','.b-messages .messages-menu li','margin-bottom','0','','','.b-messages'),(36866,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-bottom','5','','','.b-messages'),(36867,'watch-mobile','.b-personal-catalog-popup #personal_catalog_popup .lists-message-box','margin-bottom','20','','','.b-personal-catalog-popup'),(36868,'watch-mobile','.b-select-suggest .select2-search input','margin-bottom','0','','','.b-select-suggest'),(36869,'watch-mobile','.b-select-suggest .select2-search','margin-bottom','0','','','.b-select-suggest'),(36870,'watch-mobile','.b-select-suggest .select2-drop-mask','margin-bottom','0','','','.b-select-suggest'),(36871,'watch-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-bottom','0','','','.b-select-suggest'),(36872,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-bottom','0','','','.b-select-suggest'),(36873,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-bottom','0','','','.b-select-suggest'),(36874,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-bottom','0','','','.b-select-suggest'),(36875,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-bottom','1','','','.b-select-suggest'),(36876,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','margin-bottom','0','','','.b-select-suggest'),(36877,'watch-mobile','.b-select-suggest .select2-container','margin-bottom','0','','','.b-select-suggest'),(36878,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(36879,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(36880,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(36881,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(36882,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(36883,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(36884,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(36885,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(36886,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(36887,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(36888,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(36889,'watch-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(36890,'watch-mobile','.b-trade-approval .steps-bar','margin-bottom','25','','','.b-trade-approval'),(36891,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','margin-bottom','15','','','.b-trade-approval'),(36892,'watch-mobile','.b-trade-approval .middle-form textarea','margin-bottom','15','','','.b-trade-approval'),(36893,'watch-mobile','.b-upload-files .upload-files','margin-bottom','20','','','.b-upload-files'),(36894,'watch-mobile','.b-warehouses-popup .warehouses-popup .heading','margin-bottom','20','','','.b-warehouses-popup'),(36895,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-bottom','20','','','.b-warehouses-popup'),(36896,'watch-mobile','.batchPr .w-batch-selected-products .products-listing','margin-bottom','0','','','.batchPr'),(36897,'watch-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(36898,'watch-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(36899,'watch-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(36900,'watch-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(36937,'watch-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(36938,'watch-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(36939,'watch-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(36940,'watch-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(36941,'watch-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(36942,'watch-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(36944,'watch-mobile','.p-payer-order-confirmation .input-wrapper','margin-bottom','10','','','.p-payer-order-confirmation'),(36945,'watch-mobile','.p-payer-order-confirmation .dob-hide','margin-bottom','-10','','','.p-payer-order-confirmation'),(36946,'watch-mobile','.p-payer-order-pay .input-wrapper','margin-bottom','10','','','.p-payer-order-pay'),(36947,'watch-mobile','.p-payer-order-pay .dob-hide','margin-bottom','-10','','','.p-payer-order-pay'),(36948,'watch-mobile','.p-quick-order-index ul.token-input-list','margin-bottom','0','','','.p-quick-order-index'),(36949,'watch-mobile','.p-quick-order-index .filters','margin-bottom','20','','','.p-quick-order-index'),(36950,'watch-mobile','.w-account-address-book .name','margin-bottom','5','','','.w-account-address-book'),(36951,'watch-mobile','.w-account-address-book .address-wrapper','margin-bottom','20','','','.w-account-address-book'),(36952,'watch-mobile','.w-account-address-book .address-book','margin-bottom','0','','','.w-account-address-book'),(36953,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(36954,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(36955,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(36956,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(36957,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(36958,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(36959,'watch-mobile','.w-account-customer-additional-field .field-type-text','margin-bottom','10','','','.w-account-customer-additional-field'),(36960,'watch-mobile','.w-account-customer-additional-field .field-type-checkbox','margin-bottom','10','','','.w-account-customer-additional-field'),(36961,'watch-mobile','.w-account-personal-catalog .list-switcher','margin-bottom','20','','','.w-account-personal-catalog'),(36962,'watch-mobile','.w-account-subscription .send-email','margin-bottom','20','','','.w-account-subscription'),(36963,'watch-mobile','.w-account-subscription .subscription-list','margin-bottom','20','','','.w-account-subscription'),(36964,'watch-mobile','.w-blog-widget-post-image ','margin-bottom','20','','','.w-blog-widget-post-image'),(36965,'watch-mobile','.w-blog-widget-post-linked-products .heading-2','margin-bottom','25','','','.w-blog-widget-post-linked-products'),(36966,'watch-mobile','.w-blog-widget-post-listing .post_content','margin-bottom','40','','','.w-blog-widget-post-listing'),(36967,'watch-mobile','.w-blog-widget-post-listing .post_date span + span','margin-bottom','0','3','','.w-blog-widget-post-listing'),(36968,'watch-mobile','.w-blog-widget-post-listing .post_name','margin-bottom','10','','','.w-blog-widget-post-listing'),(36969,'watch-mobile','.w-blog-widget-post-listing ','margin-bottom','0','','','.w-blog-widget-post-listing'),(36970,'watch-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-bottom','0','','','.w-blog-widget-post-share'),(36971,'watch-mobile','.w-blog-widget-post-title ','margin-bottom','20','','','.w-blog-widget-post-title'),(36972,'watch-mobile','.w-blog-widget-post-title h1','margin-bottom','0','','','.w-blog-widget-post-title'),(36973,'watch-mobile','.w-cart-cart-tabs .w-tabs .tab-navigation','margin-bottom','25','','','.w-cart-cart-tabs'),(36974,'watch-mobile','.w-cart-compare .product .image','margin-bottom','10','','','.w-cart-compare'),(36975,'watch-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(36976,'watch-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(36977,'watch-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(36978,'watch-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(36979,'watch-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(36980,'watch-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(36981,'watch-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-bottom','0','','','.w-catalog-additional-images'),(36982,'watch-mobile','.w-catalog-compare .cross-box .return','margin-bottom','30','','','.w-catalog-compare'),(36983,'watch-mobile','.w-catalog-items-on-page select','margin-bottom','0','','','.w-catalog-items-on-page'),(36984,'watch-mobile','.w-checkout-billing-address .addresses .address-item','margin-bottom','10','','','.w-checkout-billing-address'),(36985,'watch-mobile','.w-checkout-billing-address .same-address','margin-bottom','10','','','.w-checkout-billing-address'),(36986,'watch-mobile','.w-checkout-billing-address .genders-title','margin-bottom','5','','','.w-checkout-billing-address'),(36987,'watch-mobile','.w-checkout-create-account .heading-2','margin-bottom','0','','','.w-checkout-create-account'),(36988,'watch-mobile','.w-checkout-gdpr .privacy-row','margin-bottom','0','','','.w-checkout-gdpr'),(36989,'watch-mobile','.w-checkout-gdpr .col-left','margin-bottom','20','','','.w-checkout-gdpr'),(36990,'watch-mobile','.w-checkout-shipping-address #shippingchoice-choice','margin-bottom','10','','','.w-checkout-shipping-address'),(36991,'watch-mobile','.w-checkout-shipping-address .genders-title','margin-bottom','5','','','.w-checkout-shipping-address'),(36992,'watch-mobile','.w-checkout-shipping-address .addresses .address-item','margin-bottom','10','','','.w-checkout-shipping-address'),(36993,'watch-mobile','.w-communication-new-topic #communication_group_holder input, .w-communication-new-topic select','margin-bottom','0','','','.w-communication-new-topic'),(36994,'watch-mobile','.w-communication-new-topic #rmaProductReturnButtonFilterHolder','margin-bottom','30','','','.w-communication-new-topic'),(36995,'watch-mobile','.w-communication-new-topic .privacy-row','margin-bottom','10','','','.w-communication-new-topic'),(36996,'watch-mobile','.w-communication-new-topic .text-container','margin-bottom','20','','','.w-communication-new-topic'),(36997,'watch-mobile','.w-communication-post .communication-post','margin-bottom','5','','','.w-communication-post'),(36998,'watch-mobile','.w-communication-post .communication-post-message','margin-bottom','20','','','.w-communication-post'),(36999,'watch-mobile','.w-communication-post .text-container','margin-bottom','20','','','.w-communication-post'),(37000,'watch-mobile','.w-delivery-day .time-left','margin-bottom','30','','','.w-delivery-day'),(37001,'watch-mobile','.w-delivery-day .ends','margin-bottom','20','','','.w-delivery-day'),(37002,'watch-mobile','.w-image-maps .categories-items .item .title','margin-bottom','10','','','.w-image-maps'),(37003,'watch-mobile','.w-image-maps .float-items .item .title','margin-bottom','10','','','.w-image-maps'),(37004,'watch-mobile','.w-image-maps .default-links .item .title','margin-bottom','10','','','.w-image-maps'),(37005,'watch-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(37006,'watch-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(37007,'watch-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(37008,'watch-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(37009,'watch-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(37010,'watch-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(37011,'watch-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(37012,'watch-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(37013,'watch-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(37014,'watch-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(37015,'watch-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(37016,'watch-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(37017,'watch-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(37018,'watch-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(37019,'watch-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(37020,'watch-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(37021,'watch-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(37022,'watch-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(37023,'watch-mobile','.w-promotions .prom-multi-discount .heading','margin-bottom','10','','','.w-promotions'),(37024,'watch-mobile','.w-promotions .nextdiscount .promo-for-each','margin-bottom','10','','','.w-promotions'),(37025,'watch-mobile','.w-promotions .nextdiscount .heading','margin-bottom','20','','','.w-promotions'),(37026,'watch-mobile','.w-promotions .promo-cart-discount .master .heading','margin-bottom','10','','','.w-promotions'),(37027,'watch-mobile','.w-promotions .promo-cart-discount .master .item','margin-bottom','12','','','.w-promotions'),(37028,'watch-mobile','.w-promotions .promo-date','margin-bottom','10','','','.w-promotions'),(37029,'watch-mobile','.w-promotions .promo-item','margin-bottom','30','','','.w-promotions'),(37030,'watch-mobile','.w-promotions .promo-salemaker .item','margin-bottom','2','','','.w-promotions'),(37031,'watch-mobile','.w-promotions .promo-cart-discount .slave .item','margin-bottom','2','','','.w-promotions'),(37032,'watch-mobile','.w-promotions .heading-3','margin-bottom','20','','','.w-promotions'),(37033,'watch-mobile','.w-reviews-content .reviews-list','margin-bottom','20','','','.w-reviews-content'),(37034,'watch-mobile','.w-sitemap-delivery-location > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(37035,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(37036,'watch-mobile','.w-social-links a','margin-bottom','0','','','.w-social-links'),(37037,'watch-mobile','.w-taxable select','margin-bottom','0','','','.w-taxable'),(37038,'watch-mobile','.w-taxable label','margin-bottom','0','','','.w-taxable'),(37039,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','margin-bottom','20','','','.w-upload-customer-id-upload-customer-id-form'),(37040,'watch-mobile','.w-wedding-registry-widgets-products .select-box, .w-wedding-registry-widgets-products .name','margin-bottom','10','','','.w-wedding-registry-widgets-products'),(37041,'watch-mobile','.w-filters .filter-box-content ul li','margin-bottom','10','','','.w-filters'),(37042,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-bottom','0','','','.w-filters'),(37043,'watch-mobile','.w-list-type-1_3 .rating-count','margin-left','5','','','.w-list-type-1_3'),(37044,'watch-mobile','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(37045,'watch-mobile','.w-menu .hided.menu ul li','margin-left','0','','','.w-menu'),(37046,'watch-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-left','0','','','.w-menu'),(37047,'watch-mobile','.w-catalog-listing-look .list','margin-left','5','','','.w-catalog-listing-look'),(37048,'watch-mobile','.w-menu-big li','margin-left','0','','','.w-menu-big'),(37049,'watch-mobile','.w-menu-big ul','margin-left','0','','','.w-menu-big'),(37050,'watch-mobile','.w-menu-slider ul, .w-menu-slider li','margin-left','0','','','.w-menu-slider'),(37051,'watch-mobile','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(37052,'watch-mobile','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(37053,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(37054,'watch-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-left','0','','','.b-cookie-notice'),(37055,'watch-mobile','.b-form .checkbox-style','margin-left','0','','','.b-form'),(37056,'watch-mobile','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(37057,'watch-mobile','.w-product-sale-ends .left-count','margin-left','2','','','.w-product-sale-ends'),(37058,'watch-mobile','.w-product-sale-ends .left-text-right','margin-left','2','','','.w-product-sale-ends'),(37059,'watch-mobile','.w-filters .input-checkbox','margin-left','0','','','.w-filters'),(37060,'watch-mobile','.w-filters .filter-ul-content','margin-left','0','','','.w-filters'),(37061,'watch-mobile','.w-categories .categories','margin-left','-20','','','.w-categories'),(37062,'watch-mobile','.w-cart .image','margin-left','-90','','','.w-cart'),(37068,'watch-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-left','0','','','.p-account-subscription-historyinfo'),(37069,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','margin-left','15','4','','.b-multi-page-checkout'),(37070,'watch-mobile','.w-cart-give-away .ga_column','margin-left','0','290','','.w-cart-give-away'),(37071,'watch-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','margin-left','1','','','.b-product-images'),(37072,'watch-mobile','.w-list-type-1_2 .right-area .right-area-2','margin-left','2','','','.w-list-type-1_2'),(37073,'watch-mobile','.w-list-type-1_2 .right-area .right-area-2','margin-left','0','291','','.w-list-type-1_2'),(37074,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-left','0','','','.b-multi-page-checkout'),(37075,'watch-mobile','.w-search .search-input','margin-left','0','','','.w-search'),(37076,'watch-mobile','.w-socials .post_item_img','margin-left','0','','','.w-socials'),(37077,'watch-mobile','.w-delivery-location-top-location-list','margin-left','0','','','.w-delivery-location-top-location-list'),(37078,'watch-mobile','.w-delivery-location-top-location-list .deliveryList','margin-left','-1','','','.w-delivery-location-top-location-list'),(37079,'watch-mobile','.b-form .columns .col-2:nth-child(2n)','margin-left','0','320','','.b-form'),(37083,'watch-mobile','.b-pagination .pagination span','margin-left','5','2','','.b-pagination'),(37084,'watch-mobile','.b-pagination .pagination .prev-pages','margin-left','5','','','.b-pagination'),(37085,'watch-mobile','.b-pagination .pagination .page-number','margin-left','5','','','.b-pagination'),(37086,'watch-mobile','.b-pagination .pagination .prev','margin-left','5','','','.b-pagination'),(37087,'watch-mobile','.b-bottom .confirm-popup .buttons .btn','margin-left','20','','','.b-bottom'),(37088,'watch-mobile','.b-pagination .pagination .next-pages','margin-left','5','','','.b-pagination'),(37089,'watch-mobile','.b-pagination .pagination .next','margin-left','5','','','.b-pagination'),(37091,'watch-mobile','.w-list-type-1_3 .right-area .right-area-2','margin-left','2','','','.w-list-type-1_3'),(37092,'watch-mobile','.w-list-type-2_2 .rating-count','margin-left','5','','','.w-list-type-2_2'),(37093,'watch-mobile','.w-list-type-2 .rating-count','margin-left','5','','','.w-list-type-2'),(37094,'watch-mobile','.buttons .right-buttons .btn','margin-left','10','','',''),(37095,'watch-mobile','.w-account ul, .w-account li','margin-left','0','','','.w-account'),(37096,'watch-mobile','.b-fancybox .fancybox-error','margin-left','0','','','.b-fancybox'),(37097,'watch-mobile','.w-menu-horizontal ul','margin-left','0','','','.w-menu-horizontal'),(37098,'watch-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(37099,'watch-mobile','.w-delivery-location-top-location-list .deliveryList ul','margin-left','0','','','.w-delivery-location-top-location-list'),(37100,'watch-mobile','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(37101,'watch-mobile','.w-chat .w-chat-box','margin-left','5','','','.w-chat'),(37102,'watch-mobile','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(37103,'watch-mobile','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(37104,'watch-mobile','.p-quote-cart-index .w-quote-checkout-btn','margin-left','0','','','.p-quote-cart-index'),(37105,'watch-mobile','.p-wedding-registry-index .search-list','margin-left','-75','3','','.p-wedding-registry-index'),(37106,'watch-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-left','0','','','.b-form'),(37107,'watch-mobile','.p-wedding-registry-manage .links a.share-registry','margin-left','10','4','','.p-wedding-registry-manage'),(37108,'watch-mobile','.p-wedding-registry-manage .links a.share-registry','margin-left','30','','','.p-wedding-registry-manage'),(37109,'watch-mobile','.b-pagination .pagination a','margin-left','5','','','.b-pagination'),(37117,'watch-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin-left','0','','','.b-compare'),(37118,'watch-mobile','.b-compare .clear_all','margin-left','7','4','','.b-compare'),(37119,'watch-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-left','0','','','.b-switch'),(37120,'watch-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-left','-20','','','.b-slick'),(37123,'watch-mobile','.w-top-categories .categories','margin-left','-10','292','','.w-top-categories'),(37124,'watch-mobile','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(37126,'watch-mobile','.w-tabs .tab-navigation','margin-left','0','','','.w-tabs'),(37127,'watch-mobile','.w-top-categories .categories','margin-left','-20','','','.w-top-categories'),(37128,'watch-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-left','0','','','.p-blog-index'),(37129,'watch-mobile','.p-blog-index .nav-next a','margin-left','0','3','','.p-blog-index'),(37130,'watch-mobile','.p-blog-index .wp-widget li','margin-left','-15','3','','.p-blog-index'),(37131,'watch-mobile','.p-blog-index .post-thumbnail','margin-left','0','','','.p-blog-index'),(37132,'watch-mobile','.p-blog-index .nav-previous a','margin-left','-50','3','','.p-blog-index'),(37133,'watch-mobile','.p-blog-index .wp-widget ul','margin-left','0','','','.p-blog-index'),(37135,'watch-mobile','.p-blog-index .wp-widget li','margin-left','0','','','.p-blog-index'),(37136,'watch-mobile','.p-reviews-info .review-info-content','margin-left','0','','','.p-reviews-info'),(37137,'watch-mobile','.p-reviews-info .review-info-text','margin-left','0','','','.p-reviews-info'),(37138,'watch-mobile','.p-reviews-info .review-info-reviewed_by','margin-left','0','','','.p-reviews-info'),(37139,'watch-mobile','.p-reviews-info .reviews-info h1','margin-left','0','','','.p-reviews-info'),(37140,'watch-mobile','.p-reviews-info .review-info-image','margin-left','0','','','.p-reviews-info'),(37144,'watch-mobile','.w-top-categories .categories','margin-left','0','290','','.w-top-categories'),(37145,'watch-mobile','.heading-3 .edit, h3 .edit','margin-left','10','4','',''),(37146,'watch-mobile','.b-slick .slick-track','margin-left','auto','','','.b-slick'),(37147,'watch-mobile','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(37148,'watch-mobile','.p-account-trade-form .trade-form-area .btn','margin-left','30','','','.p-account-trade-form'),(37153,'watch-mobile','.w-html_box .socials a','margin-left','5','','','.w-html_box'),(37154,'watch-mobile','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(37155,'watch-mobile','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(37156,'watch-mobile','.w-cart-discount-coupon .gift-code p','margin-left','0','','','.w-cart-discount-coupon'),(37157,'watch-mobile','.w-breadcrumb .breadcrumb-li','margin-left','0','','','.w-breadcrumb'),(37158,'watch-mobile','.w-cart-give-away .ga_attributes > div','margin-left','1','','','.w-cart-give-away'),(37159,'watch-mobile','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(37160,'watch-mobile','.w-product-quantity .qty_packs .price_1','margin-left','15','4','','.w-product-quantity'),(37161,'watch-mobile','.w-product-in-bundles .bundle_item','margin-left','0','','','.w-product-in-bundles'),(37162,'watch-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin-left','2','','','.w-product-in-bundles'),(37163,'watch-mobile','.w-product-bundle .bundle_item + .bundle_item','margin-left','2','','','.w-product-bundle'),(37164,'watch-mobile','.w-product-bundle .bundle_item','margin-left','0','','','.w-product-bundle'),(37165,'watch-mobile','.w-menu-style-1 ul','margin-left','0','','','.w-menu-style-1'),(37166,'watch-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(37167,'watch-mobile','.w-menu-style-1 li','margin-left','0','','','.w-menu-style-1'),(37168,'watch-mobile','.w-sale .left-count','margin-left','2','','','.w-sale'),(37169,'watch-mobile','.w-sale .left-text-right','margin-left','2','','','.w-sale'),(37170,'watch-mobile','.w-product-reviews .reviews-list','margin-left','0','','','.w-product-reviews'),(37171,'watch-mobile','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(37172,'watch-mobile','.w-top-categories .categories h2','margin-left','0','','','.w-top-categories'),(37173,'watch-mobile','.w-categories .categories h2','margin-left','0','','','.w-categories'),(37174,'watch-mobile','.b-form .terms-login .bootstrap-switch','margin-left','0','','','.b-form'),(37175,'watch-mobile','.b-slick .slick-list','margin-left','0','','','.b-slick'),(37176,'watch-mobile','.w-socials > li','margin-left','10','','','.w-socials'),(37177,'watch-mobile','.w-list-type-1_3 .right-area .right-area-2','margin-left','0','291','','.w-list-type-1_3'),(37178,'watch-mobile','.b-fancybox #fancybox-loading','margin-left','-22','','','.b-fancybox'),(37179,'watch-mobile','.w-menu-horizontal li','margin-left','0','','','.w-menu-horizontal'),(37180,'watch-mobile','.w-cart-discount-coupon .gift-code button','margin-left','15','','','.w-cart-discount-coupon'),(37181,'watch-mobile','.b-form .addresses .address-item:nth-child(2n)','margin-left','4','','','.b-form'),(37182,'watch-mobile','.b-form .discount-box button','margin-left','15','','','.b-form'),(37183,'watch-mobile','.w-catalog-listing-look .b2b','margin-left','5','','','.w-catalog-listing-look'),(37184,'watch-mobile','.w-categories .categories','margin-left','-10','292','','.w-categories'),(37185,'watch-mobile','.b-form #frmCheckout','margin-left','0','','','.b-form'),(37186,'watch-mobile','.w-categories .categories','margin-left','0','290','','.w-categories'),(37187,'watch-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-left','0','','','.b-fancybox'),(37188,'watch-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-left','0','','','.b-fancybox'),(37189,'watch-mobile','.w-cart-gift-certificate .gift-code button','margin-left','15','','','.w-cart-gift-certificate'),(37190,'watch-mobile','.w-cart-give-away .ga_column','margin-left','2','','','.w-cart-give-away'),(37191,'watch-mobile','.view-all .btn','margin-left','10','4','',''),(37192,'watch-mobile','.w-list-type-1_2 .rating-count','margin-left','5','','','.w-list-type-1_2'),(37193,'watch-mobile','.b-bottom .pop-up-content .buttons','margin-left','0','','','.b-bottom'),(37194,'watch-mobile','.heading-3 .right-text, h3 .right-text','margin-left','10','','',''),(37195,'watch-mobile','.heading-4 .right-text, h4 .right-text','margin-left','10','','',''),(37196,'watch-mobile','.w-list-type-1 .rating-count','margin-left','5','','','.w-list-type-1'),(37197,'watch-mobile','.heading-4 .edit, h4 .edit','margin-left','10','4','',''),(37198,'watch-mobile','.w-filters .view_more','margin-left','5','4','','.w-filters'),(37199,'watch-mobile','.b-form .columns .col-2:nth-child(2n)','margin-left','4','','','.b-form'),(37200,'watch-mobile','.w-tabs .tab-li','margin-left','0','','','.w-tabs'),(37201,'watch-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin-left','0','','','.b-form'),(37202,'watch-mobile','.b-form .required-message-wrap','margin-left','0','','','.b-form'),(37203,'watch-mobile','.b-form .required-message','margin-left','0','','','.b-form'),(37204,'watch-mobile','.b-info .info','margin-left','-40','3','','.b-info'),(37205,'watch-mobile','.b-info .info ul','margin-left','0','','','.b-info'),(37206,'watch-mobile','.b-info .info li','margin-left','0','','','.b-info'),(37208,'watch-mobile','.b-products-listing .products-listing .bonus-points-cost','margin-left','-20','3','','.b-products-listing'),(37209,'watch-mobile','.b-products-listing .products-listing .bonus-points-price','margin-left','-20','3','','.b-products-listing'),(37210,'watch-mobile','.b-products-listing .products-listing .description ul','margin-left','0','','','.b-products-listing'),(37211,'watch-mobile','.b-products-listing .products-listing h2','margin-left','0','','','.b-products-listing'),(37212,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.b-data-table'),(37213,'watch-mobile','.b-delete-account .delete-box span','margin-left','10','','','.b-delete-account'),(37214,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(37215,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(37216,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(37217,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(37218,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(37219,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(37220,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(37221,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(37222,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(37223,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(37224,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(37225,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(37226,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-left','0','','','.b-h-inline'),(37227,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(37228,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(37229,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(37230,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(37231,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(37232,'watch-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-left','0','','','.b-menu-style'),(37233,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','margin-left','5','4','','.b-menu-style-1'),(37234,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','margin-left','10','4','','.b-menu-style-1'),(37235,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > .no-link','margin-left','5','4','','.b-menu-style-3'),(37236,'watch-mobile','.b-messages .msv_content','margin-left','0','','','.b-messages'),(37237,'watch-mobile','.b-messages .msv_history','margin-left','0','','','.b-messages'),(37238,'watch-mobile','.b-messages .messages-menu ul','margin-left','0','','','.b-messages'),(37239,'watch-mobile','.b-messages .messages-menu li','margin-left','0','','','.b-messages'),(37240,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-left','5','','','.b-messages'),(37241,'watch-mobile','.b-select-suggest .select2-drop-mask','margin-left','0','','','.b-select-suggest'),(37242,'watch-mobile','.b-select-suggest .select2-search','margin-left','0','','','.b-select-suggest'),(37243,'watch-mobile','.b-select-suggest .select2-search input','margin-left','0','','','.b-select-suggest'),(37244,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-left','0','','','.b-select-suggest'),(37245,'watch-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-left','0','','','.b-select-suggest'),(37246,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-left','0','','','.b-select-suggest'),(37247,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-left','0','','','.b-select-suggest'),(37248,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-left','0','','','.b-select-suggest'),(37249,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','margin-left','0','','','.b-select-suggest'),(37250,'watch-mobile','.b-select-suggest .select2-container','margin-left','0','','','.b-select-suggest'),(37251,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(37252,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(37253,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(37254,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(37255,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(37256,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(37257,'watch-mobile','.b-trade-approval .steps-bar','margin-left','0','','','.b-trade-approval'),(37258,'watch-mobile','.b-trade-approval .col-3 + .col-3','margin-left','3','','','.b-trade-approval'),(37259,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','0','','','.b-warehouses-popup'),(37260,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','-17','3','','.b-warehouses-popup'),(37261,'watch-mobile','.batchPr .w-batch-selected-products .products-listing','margin-left','0','','','.batchPr'),(37292,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','margin-left','5','','','.p-quick-order-index'),(37293,'watch-mobile','.p-quick-order-index ul.token-input-list','margin-left','5','','','.p-quick-order-index'),(37294,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.p-quick-order-index'),(37295,'watch-mobile','.p-quick-order-index .filters .clear','margin-left','15','','','.p-quick-order-index'),(37296,'watch-mobile','.w-account-address-book .address-book','margin-left','-10','','','.w-account-address-book'),(37297,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(37298,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(37299,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(37300,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(37301,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(37302,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(37303,'watch-mobile','.w-account-personal-catalog .list-switcher','margin-left','0','','','.w-account-personal-catalog'),(37304,'watch-mobile','.w-blog-widget-post-listing .post_date span + span','margin-left','10','3','','.w-blog-widget-post-listing'),(37305,'watch-mobile','.w-blog-widget-post-listing ','margin-left','0','','','.w-blog-widget-post-listing'),(37306,'watch-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-left','8','','','.w-blog-widget-post-share'),(37307,'watch-mobile','.w-blog-widget-post-share a.mailto','margin-left','32','','','.w-blog-widget-post-share'),(37308,'watch-mobile','.w-blog-widget-post-title h1','margin-left','0','','','.w-blog-widget-post-title'),(37309,'watch-mobile','.w-blog-widget-related-posts .products','margin-left','-15','','','.w-blog-widget-related-posts'),(37310,'watch-mobile','.w-blog-widget-related-posts-by-category .products','margin-left','-15','','','.w-blog-widget-related-posts-by-category'),(37311,'watch-mobile','.w-cart-bonus-points .btn-remove','margin-left','-30','','','.w-cart-bonus-points'),(37312,'watch-mobile','.w-cart-compare .product .image','margin-left','0','','','.w-cart-compare'),(37313,'watch-mobile','.w-cart-credit-amount .btn-remove','margin-left','-30','','','.w-cart-credit-amount'),(37314,'watch-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(37315,'watch-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(37316,'watch-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(37317,'watch-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(37318,'watch-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(37319,'watch-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(37320,'watch-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-left','0','','','.w-catalog-additional-images'),(37321,'watch-mobile','.w-catalog-b2b-add-button .add-b2b-products','margin-left','50','','','.w-catalog-b2b-add-button'),(37322,'watch-mobile','.w-catalog-items-on-page select','margin-left','10','','','.w-catalog-items-on-page'),(37323,'watch-mobile','.w-catalog-paging .next','margin-left','2','','','.w-catalog-paging'),(37324,'watch-mobile','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-billing-address'),(37325,'watch-mobile','.w-checkout-bonus-points .btn-remove','margin-left','-30','','','.w-checkout-bonus-points'),(37326,'watch-mobile','.w-checkout-credit-amount .btn-remove','margin-left','-30','','','.w-checkout-credit-amount'),(37327,'watch-mobile','.w-checkout-gdpr .bootstrap-switch','margin-left','25','','','.w-checkout-gdpr'),(37328,'watch-mobile','.w-checkout-gdpr .privacy-row','margin-left','0','','','.w-checkout-gdpr'),(37329,'watch-mobile','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-shipping-address'),(37330,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','margin-left','-5','','','.w-checkout-shipping-choice'),(37331,'watch-mobile','.w-coupons-and-vauchers-checkout .btn-remove','margin-left','-30','','','.w-coupons-and-vauchers-checkout'),(37332,'watch-mobile','.w-delivery-day .left-count','margin-left','2','','','.w-delivery-day'),(37333,'watch-mobile','.w-delivery-day .left-text-right','margin-left','2','','','.w-delivery-day'),(37334,'watch-mobile','.w-promotions .promo-cart-discount .master .item','margin-left','12','','','.w-promotions'),(37335,'watch-mobile','.w-promotions .promo-salemaker .item','margin-left','2','','','.w-promotions'),(37336,'watch-mobile','.w-promotions .promo-cart-discount .slave .item','margin-left','2','','','.w-promotions'),(37337,'watch-mobile','.w-sitemap-delivery-location > ul','margin-left','0','','','.w-sitemap-delivery-location'),(37338,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-left','0','','','.w-sitemap-delivery-location'),(37339,'watch-mobile','.w-social-links a','margin-left','5','','','.w-social-links'),(37340,'watch-mobile','.w-taxable select','margin-left','5','','','.w-taxable'),(37341,'watch-mobile','.w-taxable label','margin-left','5','','','.w-taxable'),(37342,'watch-mobile','.b-quantity .qty-box input[type=\'text\']','margin-left','3','','','.b-quantity'),(37343,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-left','0','','','.w-filters'),(37344,'watch-mobile','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(37345,'watch-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-right','0','','','.w-menu'),(37346,'watch-mobile','.w-menu .hided.menu ul li','margin-right','0','','','.w-menu'),(37347,'watch-mobile','.w-menu-big li','margin-right','0','','','.w-menu-big'),(37348,'watch-mobile','.w-menu-big ul','margin-right','0','','','.w-menu-big'),(37349,'watch-mobile','.w-menu-slider ul, .w-menu-slider li','margin-right','0','','','.w-menu-slider'),(37350,'watch-mobile','.w-bestsellers .counter','margin-right','15','','','.w-bestsellers'),(37351,'watch-mobile','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(37352,'watch-mobile','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(37353,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(37354,'watch-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-right','0','','','.b-cookie-notice'),(37355,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','margin-right','5','','','.b-form'),(37356,'watch-mobile','.b-form .checkbox-style:checked + .checkbox-span','margin-right','5','','','.b-form'),(37357,'watch-mobile','.b-form .checkbox-style','margin-right','0','','','.b-form'),(37358,'watch-mobile','.w-filters .filter-ul-content','margin-right','0','','','.w-filters'),(37362,'watch-mobile','.w-catalog-listing-look .listing-look-title','margin-right','10','','','.w-catalog-listing-look'),(37363,'watch-mobile','.w-cart-give-away .ga_column','margin-right','0','290','','.w-cart-give-away'),(37364,'watch-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','margin-right','1','','','.b-product-images'),(37365,'watch-mobile','.w-list-type-1_2 .image','margin-right','0','291','','.w-list-type-1_2'),(37366,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-right','0','','','.b-multi-page-checkout'),(37367,'watch-mobile','.w-search .search-input','margin-right','0','','','.w-search'),(37368,'watch-mobile','.w-socials .post_item_img','margin-right','10','','','.w-socials'),(37369,'watch-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(37370,'watch-mobile','.w-delivery-location-top-location-list .deliveryList','margin-right','-1','','','.w-delivery-location-top-location-list'),(37371,'watch-mobile','.w-delivery-location-top-location-list','margin-right','0','','','.w-delivery-location-top-location-list'),(37375,'watch-mobile','.js-stock-icon','margin-right','3','3','',''),(37376,'watch-mobile','.b-bottom .confirm-popup .buttons .btn','margin-right','20','','','.b-bottom'),(37378,'watch-mobile','.p-blog-index .avatar','margin-right','10','','','.p-blog-index'),(37379,'watch-mobile','.p-blog-index .author','margin-right','20','','','.p-blog-index'),(37380,'watch-mobile','.w-list-type-2_2 .image','margin-right','20','','','.w-list-type-2_2'),(37381,'watch-mobile','.buttons .left-buttons .btn','margin-right','10','','',''),(37382,'watch-mobile','.w-product-bonus-points > div > div','margin-right','5','3','','.w-product-bonus-points'),(37383,'watch-mobile','.w-account ul, .w-account li','margin-right','0','','','.w-account'),(37384,'watch-mobile','.b-fancybox .fancybox-error','margin-right','0','','','.b-fancybox'),(37385,'watch-mobile','.w-delivery-location-top-location-list .deliveryList ul','margin-right','0','','','.w-delivery-location-top-location-list'),(37386,'watch-mobile','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(37387,'watch-mobile','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(37388,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','margin-right','5','3','','.b-form'),(37389,'watch-mobile','.p-quote-cart-index .w-quote-checkout-btn','margin-right','0','','','.p-quote-cart-index'),(37390,'watch-mobile','.b-form .radio-buttons .radio-button','margin-right','30','','','.b-form'),(37391,'watch-mobile','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(37401,'watch-mobile','.b-compare .clear_all','margin-right','0','4','','.b-compare'),(37402,'watch-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin-right','5','','','.b-compare'),(37403,'watch-mobile','.b-compare .compare-box-btn','margin-right','20','','','.b-compare'),(37404,'watch-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-right','0','','','.b-switch'),(37405,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','margin-right','-100','','','.b-fancybox'),(37407,'watch-mobile','.w-filters .input-checkbox:checked + .checkbox-span','margin-right','10','','','.w-filters'),(37410,'watch-mobile','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(37411,'watch-mobile','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(37412,'watch-mobile','.w-breadcrumb .breadcrumb-li','margin-right','0','','','.w-breadcrumb'),(37415,'watch-mobile','.w-top-categories .categories','margin-right','-20','','','.w-top-categories'),(37416,'watch-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-right','0','','','.p-blog-index'),(37417,'watch-mobile','.p-blog-index .nav-previous a','margin-right','0','3','','.p-blog-index'),(37418,'watch-mobile','.p-blog-index .post-thumbnail','margin-right','40','','','.p-blog-index'),(37419,'watch-mobile','.p-blog-index .wp-widget li','margin-right','0','','','.p-blog-index'),(37420,'watch-mobile','.p-blog-index .nav-next a','margin-right','-50','3','','.p-blog-index'),(37421,'watch-mobile','.p-blog-index .wp-widget li','margin-right','0','3','','.p-blog-index'),(37422,'watch-mobile','.p-blog-index .wp-widget ul','margin-right','0','','','.p-blog-index'),(37423,'watch-mobile','.p-reviews-info .review-info-text','margin-right','0','','','.p-reviews-info'),(37424,'watch-mobile','.p-reviews-info .review-info-content','margin-right','0','','','.p-reviews-info'),(37425,'watch-mobile','.p-reviews-info .review-info-image','margin-right','20','','','.p-reviews-info'),(37426,'watch-mobile','.p-reviews-info .review-info-reviewed_by','margin-right','6','','','.p-reviews-info'),(37427,'watch-mobile','.p-reviews-info .reviews-info h1','margin-right','0','','','.p-reviews-info'),(37429,'watch-mobile','.w-top-categories .categories','margin-right','0','290','','.w-top-categories'),(37430,'watch-mobile','.b-slick .slick-track','margin-right','auto','','','.b-slick'),(37431,'watch-mobile','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(37433,'watch-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-right','0','','','.p-account-subscription-historyinfo'),(37436,'watch-mobile','.w-filters .input-checkbox','margin-right','0','','','.w-filters'),(37437,'watch-mobile','.w-html_box .socials a','margin-right','5','','','.w-html_box'),(37438,'watch-mobile','.w-categories .categories','margin-right','-20','','','.w-categories'),(37439,'watch-mobile','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(37440,'watch-mobile','.w-cart-discount-coupon .gift-code p','margin-right','0','','','.w-cart-discount-coupon'),(37441,'watch-mobile','.w-cart-give-away .ga_attributes > div','margin-right','1','','','.w-cart-give-away'),(37442,'watch-mobile','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(37443,'watch-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin-right','0','','','.w-product-in-bundles'),(37444,'watch-mobile','.w-product-quantity .qty_packs .price_1','margin-right','25','4','','.w-product-quantity'),(37445,'watch-mobile','.w-product-in-bundles .bundle_item','margin-right','2','','','.w-product-in-bundles'),(37446,'watch-mobile','.w-product-bundle .bundle_item','margin-right','2','','','.w-product-bundle'),(37447,'watch-mobile','.w-product-bundle .bundle_item + .bundle_item','margin-right','0','','','.w-product-bundle'),(37448,'watch-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(37449,'watch-mobile','.w-menu-style-1 ul','margin-right','0','','','.w-menu-style-1'),(37450,'watch-mobile','.w-menu-style-1 li','margin-right','0','','','.w-menu-style-1'),(37451,'watch-mobile','.w-product-reviews .reviews-list','margin-right','0','','','.w-product-reviews'),(37452,'watch-mobile','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(37453,'watch-mobile','.w-top-categories .categories h2','margin-right','0','','','.w-top-categories'),(37454,'watch-mobile','.w-categories .categories h2','margin-right','0','','','.w-categories'),(37455,'watch-mobile','.b-form .terms-login .bootstrap-switch','margin-right','-80','','','.b-form'),(37456,'watch-mobile','.b-slick .slick-list','margin-right','0','','','.b-slick'),(37457,'watch-mobile','.w-socials > li','margin-right','10','','','.w-socials'),(37458,'watch-mobile','.w-list-type-1_3 .image','margin-right','0','291','','.w-list-type-1_3'),(37459,'watch-mobile','.w-menu-horizontal li','margin-right','0','','','.w-menu-horizontal'),(37460,'watch-mobile','.w-menu-horizontal ul','margin-right','0','','','.w-menu-horizontal'),(37461,'watch-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','margin-right','10','3','','.w-cart-discount-coupon'),(37462,'watch-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-right','0','','','.b-form'),(37463,'watch-mobile','.w-categories .categories','margin-right','0','290','','.w-categories'),(37464,'watch-mobile','.w-categories .categories','margin-right','-10','292','','.w-categories'),(37465,'watch-mobile','.b-form #frmCheckout','margin-right','0','','','.b-form'),(37466,'watch-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-right','0','','','.b-fancybox'),(37467,'watch-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-right','0','','','.b-fancybox'),(37468,'watch-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(37469,'watch-mobile','.w-cart-give-away .ga_column','margin-right','2','','','.w-cart-give-away'),(37470,'watch-mobile','.w-cart-give-away .ga_img','margin-right','2','','','.w-cart-give-away'),(37471,'watch-mobile','.out-stock-icon','margin-right','3','3','',''),(37472,'watch-mobile','.w-list-type-1_3 .image','margin-right','20','','','.w-list-type-1_3'),(37473,'watch-mobile','.w-list-type-1_3 .attributes > .attributes > div','margin-right','5','','','.w-list-type-1_3'),(37474,'watch-mobile','.w-list-type-1_2 .image','margin-right','20','','','.w-list-type-1_2'),(37475,'watch-mobile','.b-bottom .pop-up-content .buttons','margin-right','0','','','.b-bottom'),(37476,'watch-mobile','.w-filters .open','margin-right','10','3','','.w-filters'),(37477,'watch-mobile','.transit-icon','margin-right','3','3','',''),(37478,'watch-mobile','.in-stock-icon','margin-right','3','3','',''),(37479,'watch-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','margin-right','10','','','.w-filters'),(37480,'watch-mobile','.w-tabs .tab-li','margin-right','0','','','.w-tabs'),(37481,'watch-mobile','.w-tabs .tab-navigation','margin-right','0','','','.w-tabs'),(37482,'watch-mobile','.w-top-categories .categories','margin-right','-10','292','','.w-top-categories'),(37483,'watch-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin-right','10','','','.b-form'),(37484,'watch-mobile','.b-form .required-message','margin-right','0','','','.b-form'),(37485,'watch-mobile','.b-form .required-message-wrap','margin-right','0','','','.b-form'),(37486,'watch-mobile','.b-info .info ul','margin-right','0','','','.b-info'),(37487,'watch-mobile','.b-info .info li','margin-right','0','','','.b-info'),(37489,'watch-mobile','.b-products-listing .products-listing .bonus-points-cost','margin-right','5','3','','.b-products-listing'),(37490,'watch-mobile','.b-products-listing .products-listing .bonus-points-cost','margin-right','10','','','.b-products-listing'),(37491,'watch-mobile','.b-products-listing .products-listing .bonus-points-price','margin-right','10','','','.b-products-listing'),(37492,'watch-mobile','.b-products-listing .products-listing .btn-buy','margin-right','10','3','','.b-products-listing'),(37493,'watch-mobile','.b-products-listing .products-listing .description ul','margin-right','0','','','.b-products-listing'),(37494,'watch-mobile','.b-products-listing .products-listing .radio-attributes label','margin-right','10','','','.b-products-listing'),(37495,'watch-mobile','.b-products-listing .products-listing h2','margin-right','0','','','.b-products-listing'),(37496,'watch-mobile','.b-delete-account .delete-box span','margin-right','10','','','.b-delete-account'),(37497,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(37498,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(37499,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(37500,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(37501,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(37502,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(37503,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-right','0','','','.b-h-inline'),(37504,'watch-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-right','0','','','.b-menu-style'),(37505,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','margin-right','10','','','.b-menu-style-2'),(37506,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','margin-right','10','','','.b-menu-style-2'),(37507,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','margin-right','10','3','','.b-menu-style-2'),(37508,'watch-mobile','.b-messages span.starred::before','margin-right','8','','','.b-messages'),(37509,'watch-mobile','.b-messages .msv_content','margin-right','0','','','.b-messages'),(37510,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-right','5','','','.b-messages'),(37511,'watch-mobile','.b-messages .msv_history','margin-right','0','','','.b-messages'),(37512,'watch-mobile','.b-messages .messBtnMenuUnread','margin-right','8','3','','.b-messages'),(37513,'watch-mobile','.b-messages .messBtnMenuDelete','margin-right','8','3','','.b-messages'),(37514,'watch-mobile','.b-messages .messBtnMenuStarred','margin-right','8','3','','.b-messages'),(37515,'watch-mobile','.b-messages .messages-menu ul','margin-right','0','','','.b-messages'),(37516,'watch-mobile','.b-messages .messages-menu li','margin-right','0','','','.b-messages'),(37517,'watch-mobile','.b-messages .content_management_attach span::before','margin-right','5','','','.b-messages'),(37518,'watch-mobile','.b-messages .content_management_attach span','margin-right','10','','','.b-messages'),(37519,'watch-mobile','.b-select-suggest .select2-search','margin-right','0','','','.b-select-suggest'),(37520,'watch-mobile','.b-select-suggest .select2-drop-mask','margin-right','0','','','.b-select-suggest'),(37521,'watch-mobile','.b-select-suggest .select2-search input','margin-right','0','','','.b-select-suggest'),(37522,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-right','0','','','.b-select-suggest'),(37523,'watch-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-right','0','','','.b-select-suggest'),(37524,'watch-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','margin-right','26','','','.b-select-suggest'),(37525,'watch-mobile','.b-select-suggest .select2-container.select2-allowclear .select2-choice .select2-chosen','margin-right','42','','','.b-select-suggest'),(37526,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-right','0','','','.b-select-suggest'),(37527,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-right','0','','','.b-select-suggest'),(37528,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-right','0','','','.b-select-suggest'),(37529,'watch-mobile','.b-select-suggest .select2-container','margin-right','0','','','.b-select-suggest'),(37530,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','margin-right','0','','','.b-select-suggest'),(37531,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(37532,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(37533,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(37534,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(37535,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(37536,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(37537,'watch-mobile','.b-trade-approval .steps-bar','margin-right','0','','','.b-trade-approval'),(37538,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-right','20','','','.b-warehouses-popup'),(37539,'watch-mobile','.b-warehouses-popup .warehouses-popup-link','margin-right','5','3','','.b-warehouses-popup'),(37540,'watch-mobile','.batchPr .w-batch-selected-products .products-listing','margin-right','0','','','.batchPr'),(37541,'watch-mobile','.bell-ico .heading-2','margin-right','10','3','','.bell-ico'),(37542,'watch-mobile','.heading-ordered-items .heading-4','margin-right','5','3','','.heading-ordered-items'),(37543,'watch-mobile','.heading-saved-lists .heading-4','margin-right','5','3','','.heading-saved-lists'),(37544,'watch-mobile','.heading-settings .heading-4','margin-right','5','3','','.heading-settings'),(37575,'watch-mobile','.p-payer-order-confirmation .ship-ico','margin-right','10','3','','.p-payer-order-confirmation'),(37576,'watch-mobile','.p-payer-order-confirmation .discount-ico','margin-right','10','3','','.p-payer-order-confirmation'),(37577,'watch-mobile','.p-payer-order-confirmation .comment-ico','margin-right','10','3','','.p-payer-order-confirmation'),(37578,'watch-mobile','.p-payer-order-confirmation .pay-ico','margin-right','10','3','','.p-payer-order-confirmation'),(37579,'watch-mobile','.p-payer-order-confirmation .order-ico','margin-right','10','3','','.p-payer-order-confirmation'),(37580,'watch-mobile','.p-payer-order-pay .ship-ico','margin-right','10','3','','.p-payer-order-pay'),(37581,'watch-mobile','.p-payer-order-pay .order-ico','margin-right','10','3','','.p-payer-order-pay'),(37582,'watch-mobile','.p-payer-order-pay .pay-ico','margin-right','10','3','','.p-payer-order-pay'),(37583,'watch-mobile','.p-payer-order-pay .comment-ico','margin-right','10','3','','.p-payer-order-pay'),(37584,'watch-mobile','.p-payer-order-pay .discount-ico','margin-right','10','3','','.p-payer-order-pay'),(37585,'watch-mobile','.p-quick-order-index ul.token-input-list','margin-right','30','','','.p-quick-order-index'),(37586,'watch-mobile','.savings-ico .heading-2','margin-right','10','3','','.savings-ico'),(37587,'watch-mobile','.shipping-ico .heading-2','margin-right','10','3','','.shipping-ico'),(37588,'watch-mobile','.shipping-ico .heading-2','margin-right','10','3','','.shipping-ico'),(37589,'watch-mobile','.shipping-ico .heading-2','margin-right','10','3','','.shipping-ico'),(37590,'watch-mobile','.w-account-address-book .address-book','margin-right','-10','','','.w-account-address-book'),(37591,'watch-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','margin-right','10','','','.w-account-addresses-list'),(37592,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(37593,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(37594,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(37595,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(37596,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(37597,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(37598,'watch-mobile','.w-account-personal-catalog .list-switcher','margin-right','0','','','.w-account-personal-catalog'),(37599,'watch-mobile','.w-account-subscription .info-popup','margin-right','20','','','.w-account-subscription'),(37600,'watch-mobile','.w-blog-widget-post-image ','margin-right','0','','','.w-blog-widget-post-image'),(37601,'watch-mobile','.w-blog-widget-post-listing .post_date span + span','margin-right','10','3','','.w-blog-widget-post-listing'),(37602,'watch-mobile','.w-blog-widget-post-listing .post_view','margin-right','15','','','.w-blog-widget-post-listing'),(37603,'watch-mobile','.w-blog-widget-post-listing ','margin-right','0','','','.w-blog-widget-post-listing'),(37604,'watch-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-right','8','','','.w-blog-widget-post-share'),(37605,'watch-mobile','.w-blog-widget-post-title h1','margin-right','0','','','.w-blog-widget-post-title'),(37606,'watch-mobile','.w-blog-widget-related-posts .products','margin-right','-15','','','.w-blog-widget-related-posts'),(37607,'watch-mobile','.w-blog-widget-related-posts-by-category .products','margin-right','-15','','','.w-blog-widget-related-posts-by-category'),(37608,'watch-mobile','.w-cart-compare .product .image','margin-right','10','','','.w-cart-compare'),(37609,'watch-mobile','.w-cart-compare .product-actions .dropdown-toggle','margin-right','8','3','','.w-cart-compare'),(37610,'watch-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(37611,'watch-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(37612,'watch-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(37613,'watch-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(37614,'watch-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(37615,'watch-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(37616,'watch-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-right','0','','','.w-catalog-additional-images'),(37617,'watch-mobile','.w-catalog-items-on-page select','margin-right','10','','','.w-catalog-items-on-page'),(37618,'watch-mobile','.w-catalog-paging .prev','margin-right','5','','','.w-catalog-paging'),(37619,'watch-mobile','.w-checkout-billing-address .genders-title label','margin-right','20','','','.w-checkout-billing-address'),(37620,'watch-mobile','.w-checkout-billing-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-billing-address'),(37621,'watch-mobile','.w-checkout-billing-address .btn-cancel','margin-right','20','','','.w-checkout-billing-address'),(37622,'watch-mobile','.w-checkout-create-account .account-benefits strong','margin-right','5','3','','.w-checkout-create-account'),(37623,'watch-mobile','.w-checkout-gdpr .privacy-row','margin-right','0','','','.w-checkout-gdpr'),(37624,'watch-mobile','.w-checkout-shipping-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-shipping-address'),(37625,'watch-mobile','.w-checkout-shipping-address .genders-title label','margin-right','20','','','.w-checkout-shipping-address'),(37626,'watch-mobile','.w-checkout-shipping-address .btn-cancel','margin-right','20','','','.w-checkout-shipping-address'),(37627,'watch-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','margin-right','10','3','','.w-multi-cart-actions'),(37628,'watch-mobile','.w-product-cross-sell .buy-all-checker','margin-right','5','','','.w-product-cross-sell'),(37629,'watch-mobile','.w-promotions .nextdiscount .heading','margin-right','10','3','','.w-promotions'),(37630,'watch-mobile','.w-promotions .promo-cart-discount .master .item','margin-right','12','','','.w-promotions'),(37631,'watch-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','margin-right','5','3','','.w-promotions'),(37632,'watch-mobile','.w-promotions .promo-cart-discount .slave .item','margin-right','2','','','.w-promotions'),(37633,'watch-mobile','.w-promotions .promo-salemaker .item','margin-right','2','','','.w-promotions'),(37634,'watch-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','margin-right','5','3','','.w-promotions'),(37635,'watch-mobile','.w-promotions .prom-multi-discount > .heading','margin-right','5','3','','.w-promotions'),(37636,'watch-mobile','.w-promotions .icon','margin-right','15','','','.w-promotions'),(37637,'watch-mobile','.w-sitemap-delivery-location > ul','margin-right','0','','','.w-sitemap-delivery-location'),(37638,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-right','0','','','.w-sitemap-delivery-location'),(37639,'watch-mobile','.w-social-links a','margin-right','5','','','.w-social-links'),(37640,'watch-mobile','.w-taxable input[type=\"checkbox\"]','margin-right','5','','','.w-taxable'),(37641,'watch-mobile','.w-taxable label','margin-right','5','','','.w-taxable'),(37642,'watch-mobile','.w-taxable select','margin-right','0','','','.w-taxable'),(37643,'watch-mobile','.w-wedding-registry-widgets-photos .upload-file-template','margin-right','20','','','.w-wedding-registry-widgets-photos'),(37644,'watch-mobile','.w-wedding-registry-widgets-search-registry-button a','margin-right','10','3','','.w-wedding-registry-widgets-search-registry-button'),(37645,'watch-mobile','.w-wedding-registry-widgets-share-link a','margin-right','5','3','','.w-wedding-registry-widgets-share-link'),(37646,'watch-mobile','.b-quantity .qty-box input[type=\'text\']','margin-right','3','','','.b-quantity'),(37647,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-right','0','','','.w-filters'),(37648,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','margin-right','10','','','.w-filters'),(37649,'watch-mobile','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(37650,'watch-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-top','0','','','.w-menu'),(37651,'watch-mobile','.w-menu .hided.menu ul li','margin-top','0','','','.w-menu'),(37652,'watch-mobile','.w-menu-big ul','margin-top','0','','','.w-menu-big'),(37653,'watch-mobile','.w-menu-big li','margin-top','0','','','.w-menu-big'),(37654,'watch-mobile','.w-menu-slider ul, .w-menu-slider li','margin-top','0','','','.w-menu-slider'),(37655,'watch-mobile','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(37656,'watch-mobile','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(37657,'watch-mobile','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(37658,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(37659,'watch-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-top','0','','','.b-cookie-notice'),(37660,'watch-mobile','.b-form .checkbox-style','margin-top','0','','','.b-form'),(37661,'watch-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','margin-top','0','','','.b-product-images'),(37662,'watch-mobile','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(37663,'watch-mobile','.w-filters .filter-ul-content','margin-top','0','','','.w-filters'),(37664,'watch-mobile','.w-menu-horizontal li','margin-top','0','','','.w-menu-horizontal'),(37669,'watch-mobile','.w-list-type-1_2 .right-area .right-area-2','margin-top','15','291','','.w-list-type-1_2'),(37670,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-top','0','','','.b-multi-page-checkout'),(37671,'watch-mobile','.w-socials > li','margin-top','10','','','.w-socials'),(37672,'watch-mobile','.w-socials .post_item_img','margin-top','0','','','.w-socials'),(37673,'watch-mobile','.w-search .search-input','margin-top','0','','','.w-search'),(37675,'watch-mobile','.w-delivery-location-top-location-list','margin-top','25','','','.w-delivery-location-top-location-list'),(37676,'watch-mobile','.w-delivery-location-top-location-list .deliveryList','margin-top','0','','','.w-delivery-location-top-location-list'),(37680,'watch-mobile','.b-bottom .confirm-popup .buttons .btn','margin-top','0','','','.b-bottom'),(37682,'watch-mobile','.w-account ul, .w-account li','margin-top','0','','','.w-account'),(37683,'watch-mobile','.b-fancybox .fancybox-error','margin-top','0','','','.b-fancybox'),(37684,'watch-mobile','.w-menu-horizontal ul','margin-top','0','','','.w-menu-horizontal'),(37685,'watch-mobile','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(37686,'watch-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(37687,'watch-mobile','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(37688,'watch-mobile','.w-delivery-location-top-location-list .deliveryList ul','margin-top','0','','','.w-delivery-location-top-location-list'),(37689,'watch-mobile','.b-form .wedding-form .heading-2','margin-top','10','','','.b-form'),(37690,'watch-mobile','.p-quote-cart-index .w-quote-checkout-btn','margin-top','20','','','.p-quote-cart-index'),(37691,'watch-mobile','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(37700,'watch-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin-top','0','','','.b-compare'),(37701,'watch-mobile','.b-compare .clear_all','margin-top','0','4','','.b-compare'),(37702,'watch-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-top','0','','','.b-switch'),(37703,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','margin-top','-20','','','.b-slick'),(37704,'watch-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-top','0','','','.b-slick'),(37709,'watch-mobile','.w-cart-discount-coupon .gift-code p','margin-top','0','','','.w-cart-discount-coupon'),(37710,'watch-mobile','.w-breadcrumb .breadcrumb-li','margin-top','0','','','.w-breadcrumb'),(37711,'watch-mobile','.w-tabs .tab-li','margin-top','0','','','.w-tabs'),(37712,'watch-mobile','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(37714,'watch-mobile','.w-tabs .tab-navigation','margin-top','0','','','.w-tabs'),(37715,'watch-mobile','.w-top-categories .categories','margin-top','0','292','','.w-top-categories'),(37716,'watch-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-top','0','','','.p-blog-index'),(37717,'watch-mobile','.p-blog-index .wp-widget ul','margin-top','0','','','.p-blog-index'),(37718,'watch-mobile','.p-blog-index .wp-widget li','margin-top','5','3','','.p-blog-index'),(37719,'watch-mobile','.p-blog-index .nav-previous a','margin-top','0','3','','.p-blog-index'),(37720,'watch-mobile','.p-blog-index .wp-widget li','margin-top','0','','','.p-blog-index'),(37721,'watch-mobile','.p-blog-index .post-thumbnail','margin-top','0','','','.p-blog-index'),(37722,'watch-mobile','.p-blog-index .nav-next a','margin-top','0','3','','.p-blog-index'),(37723,'watch-mobile','.p-reviews-info .reviews-info h1','margin-top','0','','','.p-reviews-info'),(37724,'watch-mobile','.p-reviews-info .review-info-image','margin-top','0','','','.p-reviews-info'),(37725,'watch-mobile','.p-reviews-info .review-info-content','margin-top','0','','','.p-reviews-info'),(37726,'watch-mobile','.p-reviews-info .review-info-reviewed_by','margin-top','0','','','.p-reviews-info'),(37727,'watch-mobile','.p-reviews-info .review-info-text','margin-top','0','','','.p-reviews-info'),(37729,'watch-mobile','.w-top-categories .categories','margin-top','0','290','','.w-top-categories'),(37731,'watch-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-top','0','','','.p-account-subscription-historyinfo'),(37733,'watch-mobile','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(37737,'watch-mobile','.w-filters .input-checkbox','margin-top','0','','','.w-filters'),(37738,'watch-mobile','.w-html_box .socials a','margin-top','0','','','.w-html_box'),(37739,'watch-mobile','.b-fancybox .fancybox-title-outside-wrap','margin-top','10','','','.b-fancybox'),(37741,'watch-mobile','.b-fancybox .fancybox-nav span','margin-top','-18','','','.b-fancybox'),(37742,'watch-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-top','0','','','.b-fancybox'),(37743,'watch-mobile','.w-categories .categories','margin-top','0','','','.w-categories'),(37744,'watch-mobile','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(37745,'watch-mobile','.w-cart-give-away .ga_attributes > div','margin-top','1','','','.w-cart-give-away'),(37746,'watch-mobile','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(37747,'watch-mobile','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(37748,'watch-mobile','.w-product-quantity .qty_packs .price_1','margin-top','0','4','','.w-product-quantity'),(37749,'watch-mobile','.w-product-in-bundles .bundle_item','margin-top','0','','','.w-product-in-bundles'),(37750,'watch-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin-top','0','','','.w-product-in-bundles'),(37751,'watch-mobile','.w-product-bundle .bundle_item','margin-top','0','','','.w-product-bundle'),(37752,'watch-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(37753,'watch-mobile','.w-product-bundle .bundle_item + .bundle_item','margin-top','0','','','.w-product-bundle'),(37754,'watch-mobile','.w-menu-style-1 ul','margin-top','0','','','.w-menu-style-1'),(37755,'watch-mobile','.w-menu-style-1 li','margin-top','0','','','.w-menu-style-1'),(37756,'watch-mobile','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(37757,'watch-mobile','.w-product-reviews .reviews-list','margin-top','10','','','.w-product-reviews'),(37758,'watch-mobile','.w-top-categories .categories h2','margin-top','0','','','.w-top-categories'),(37759,'watch-mobile','.w-categories .categories h2','margin-top','0','','','.w-categories'),(37760,'watch-mobile','.b-form .terms-login .bootstrap-switch','margin-top','0','','','.b-form'),(37761,'watch-mobile','.b-slick .slick-list','margin-top','0','','','.b-slick'),(37762,'watch-mobile','.b-fancybox #fancybox-loading','margin-top','-22','','','.b-fancybox'),(37763,'watch-mobile','.w-list-type-1_3 .right-area .right-area-2','margin-top','15','291','','.w-list-type-1_3'),(37764,'watch-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-top','0','','','.b-form'),(37765,'watch-mobile','.w-categories .categories','margin-top','0','290','','.w-categories'),(37766,'watch-mobile','.w-categories .categories','margin-top','0','292','','.w-categories'),(37767,'watch-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-top','0','','','.b-fancybox'),(37768,'watch-mobile','.b-form #frmCheckout','margin-top','20','','','.b-form'),(37769,'watch-mobile','.b-bottom .pop-up-content .buttons','margin-top','15','','','.b-bottom'),(37770,'watch-mobile','.w-filters .ui-slider','margin-top','5','','','.w-filters'),(37772,'watch-mobile','.w-top-categories .categories','margin-top','0','','','.w-top-categories'),(37773,'watch-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin-top','0','','','.b-form'),(37774,'watch-mobile','.b-form .required-message','margin-top','0','','','.b-form'),(37775,'watch-mobile','.b-form .required-message-wrap','margin-top','0','','','.b-form'),(37776,'watch-mobile','.b-info .info','margin-top','-8','3','','.b-info'),(37777,'watch-mobile','.b-info .info ul','margin-top','0','','','.b-info'),(37778,'watch-mobile','.b-info .info li','margin-top','0','','','.b-info'),(37779,'watch-mobile','.b-products-listing .products-listing .description ul','margin-top','0','','','.b-products-listing'),(37780,'watch-mobile','.b-products-listing .products-listing h2','margin-top','0','','','.b-products-listing'),(37781,'watch-mobile','.b-delete-account .delete-box span','margin-top','10','','','.b-delete-account'),(37782,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(37783,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(37784,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(37785,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(37786,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(37787,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(37788,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-top','0','','','.b-h-inline'),(37789,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(37790,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(37791,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(37792,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(37793,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(37794,'watch-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-top','0','','','.b-menu-style'),(37795,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','margin-top','-8','3','','.b-menu-style-2'),(37796,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','margin-top','-10','3','','.b-menu-style-2'),(37797,'watch-mobile','.b-messages .msv_content','margin-top','15','','','.b-messages'),(37798,'watch-mobile','.b-messages .msv_btn','margin-top','10','','','.b-messages'),(37799,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-top','0','','','.b-messages'),(37800,'watch-mobile','.b-messages .msv_history','margin-top','15','','','.b-messages'),(37801,'watch-mobile','.b-messages .messages-menu ul','margin-top','0','','','.b-messages'),(37802,'watch-mobile','.b-messages .messages-menu li','margin-top','0','','','.b-messages'),(37803,'watch-mobile','.b-select-suggest .select2-search input','margin-top','0','','','.b-select-suggest'),(37804,'watch-mobile','.b-select-suggest .select2-drop-mask','margin-top','0','','','.b-select-suggest'),(37805,'watch-mobile','.b-select-suggest .select2-drop.select2-drop-above .select2-search input','margin-top','4','','','.b-select-suggest'),(37806,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-top','0','','','.b-select-suggest'),(37807,'watch-mobile','.b-select-suggest .select2-drop','margin-top','-1','','','.b-select-suggest'),(37808,'watch-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-top','0','','','.b-select-suggest'),(37809,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-top','0','','','.b-select-suggest'),(37810,'watch-mobile','.b-select-suggest .select2-drop.select2-drop-above','margin-top','1','','','.b-select-suggest'),(37811,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-top','1','','','.b-select-suggest'),(37812,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-top','0','','','.b-select-suggest'),(37813,'watch-mobile','.b-select-suggest .select2-search','margin-top','0','','','.b-select-suggest'),(37814,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','margin-top','0','','','.b-select-suggest'),(37815,'watch-mobile','.b-select-suggest .select2-container','margin-top','0','','','.b-select-suggest'),(37816,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(37817,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(37818,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(37819,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(37820,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(37821,'watch-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(37822,'watch-mobile','.b-trade-approval .steps-bar','margin-top','0','','','.b-trade-approval'),(37823,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-top','0','','','.b-warehouses-popup'),(37824,'watch-mobile','.batchPr .w-batch-selected-products .products-listing','margin-top','0','','','.batchPr'),(37861,'watch-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(37862,'watch-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(37863,'watch-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(37864,'watch-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(37865,'watch-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(37866,'watch-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(37867,'watch-mobile','.p-payer-order-confirmation .dob-hide','margin-top','20','','','.p-payer-order-confirmation'),(37868,'watch-mobile','.p-payer-order-pay .dob-hide','margin-top','20','','','.p-payer-order-pay'),(37869,'watch-mobile','.p-quick-order-index .dataTables_info','margin-top','5','','','.p-quick-order-index'),(37870,'watch-mobile','.p-quick-order-index ul.token-input-list','margin-top','0','','','.p-quick-order-index'),(37871,'watch-mobile','.w-account-address-book .address-book','margin-top','0','','','.w-account-address-book'),(37872,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(37873,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(37874,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(37875,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(37876,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(37877,'watch-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(37878,'watch-mobile','.w-account-personal-catalog .list-switcher','margin-top','0','','','.w-account-personal-catalog'),(37879,'watch-mobile','.w-blog-widget-categories-list div ~ div','margin-top','10','','','.w-blog-widget-categories-list'),(37880,'watch-mobile','.w-blog-widget-post-listing .post_date span + span','margin-top','0','3','','.w-blog-widget-post-listing'),(37881,'watch-mobile','.w-blog-widget-post-listing ','margin-top','0','','','.w-blog-widget-post-listing'),(37882,'watch-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-top','0','','','.w-blog-widget-post-share'),(37883,'watch-mobile','.w-blog-widget-post-title h1','margin-top','0','','','.w-blog-widget-post-title'),(37884,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','margin-top','-17','','','.w-blog-widget-related-posts'),(37885,'watch-mobile','.w-cart-compare .product .image','margin-top','0','','','.w-cart-compare'),(37886,'watch-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(37887,'watch-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(37888,'watch-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(37889,'watch-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(37890,'watch-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(37891,'watch-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(37892,'watch-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-top','0','','','.w-catalog-additional-images'),(37893,'watch-mobile','.w-catalog-items-on-page select','margin-top','0','','','.w-catalog-items-on-page'),(37894,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top','0','','','.w-catalog-paging'),(37895,'watch-mobile','.w-checkout-billing-address .bootstrap-switch','margin-top','-2','','','.w-checkout-billing-address'),(37896,'watch-mobile','.w-checkout-contact-information .contact-info-buttons','margin-top','5','','','.w-checkout-contact-information'),(37897,'watch-mobile','.w-checkout-gdpr .privacy-row','margin-top','0','','','.w-checkout-gdpr'),(37898,'watch-mobile','.w-checkout-gdpr .bootstrap-switch','margin-top','0','','','.w-checkout-gdpr'),(37899,'watch-mobile','.w-checkout-shipping-address .change-ab','margin-top','5','','','.w-checkout-shipping-address'),(37900,'watch-mobile','.w-communication-new-topic .files-box','margin-top','50','','','.w-communication-new-topic'),(37901,'watch-mobile','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(37902,'watch-mobile','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(37903,'watch-mobile','.w-multi-cart-cart-switcher .cart-label','margin-top','-20','','','.w-multi-cart-cart-switcher'),(37904,'watch-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(37905,'watch-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(37906,'watch-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(37907,'watch-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(37908,'watch-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(37909,'watch-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(37910,'watch-mobile','.w-product-customers-activity .buttons','margin-top','10','','','.w-product-customers-activity'),(37911,'watch-mobile','.w-promotions .promo-cart-discount .master .image','margin-top','-16','','','.w-promotions'),(37912,'watch-mobile','.w-promotions .promo-cart-discount .master .item','margin-top','12','','','.w-promotions'),(37913,'watch-mobile','.w-promotions .promo-cart-discount .slave .item','margin-top','2','','','.w-promotions'),(37914,'watch-mobile','.w-promotions .promo-salemaker .content','margin-top','-18','','','.w-promotions'),(37915,'watch-mobile','.w-promotions .promo-salemaker .item','margin-top','2','','','.w-promotions'),(37916,'watch-mobile','.w-sitemap-delivery-location > ul','margin-top','0','','','.w-sitemap-delivery-location'),(37917,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-top','0','','','.w-sitemap-delivery-location'),(37918,'watch-mobile','.w-social-links a','margin-top','0','','','.w-social-links'),(37919,'watch-mobile','.w-taxable select','margin-top','0','','','.w-taxable'),(37920,'watch-mobile','.w-taxable label','margin-top','0','','','.w-taxable'),(37921,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-template .btn','margin-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(37922,'watch-mobile','.w-wedding-registry-widgets-products .rating','margin-top','15','','','.w-wedding-registry-widgets-products'),(37923,'watch-mobile','.w-wedding-registry-widgets-search-form .button','margin-top','-46','','','.w-wedding-registry-widgets-search-form'),(37924,'watch-mobile','.w-multi-cart-save-cart .copy-cart','margin-top','10','','','.w-multi-cart-save-cart'),(37925,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-top','0','','','.w-filters'),(37926,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top_important','important','','','.w-catalog-paging'),(37927,'watch-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(37928,'watch-mobile','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(37929,'watch-mobile','.w-cart-give-away .ga_attributes > div','margin_bottom_measure','%','','','.w-cart-give-away'),(37930,'watch-mobile','.p-quick-order-index ul.token-input-list','margin_bottom_measure','pt','','','.p-quick-order-index'),(37931,'watch-mobile','.w-sale .left-count','margin_left_measure','%','','','.w-sale'),(37932,'watch-mobile','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(37933,'watch-mobile','.w-product-sale-ends .left-count','margin_left_measure','%','','','.w-product-sale-ends'),(37934,'watch-mobile','.w-product-sale-ends .left-text-right','margin_left_measure','%','','','.w-product-sale-ends'),(37935,'watch-mobile','.w-list-type-1_2 .right-area .right-area-2','margin_left_measure','%','','','.w-list-type-1_2'),(37936,'watch-mobile','.w-delivery-location-top-location-list .deliveryList','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(37937,'watch-mobile','.w-list-type-1_3 .right-area .right-area-2','margin_left_measure','%','','','.w-list-type-1_3'),(37938,'watch-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(37939,'watch-mobile','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(37942,'watch-mobile','.w-cart-give-away .ga_attributes > div','margin_left_measure','%','','','.w-cart-give-away'),(37943,'watch-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin_left_measure','%','','','.w-product-in-bundles'),(37944,'watch-mobile','.w-product-bundle .bundle_item + .bundle_item','margin_left_measure','%','','','.w-product-bundle'),(37945,'watch-mobile','.w-sale .left-text-right','margin_left_measure','%','','','.w-sale'),(37946,'watch-mobile','.w-cart-give-away .ga_column','margin_left_measure','%','','','.w-cart-give-away'),(37947,'watch-mobile','.b-form .columns .col-2:nth-child(2n)','margin_left_measure','%','','','.b-form'),(37948,'watch-mobile','.b-form .addresses .address-item:nth-child(2n)','margin_left_measure','%','','','.b-form'),(37949,'watch-mobile','.b-trade-approval .col-3 + .col-3','margin_left_measure','%','','','.b-trade-approval'),(37950,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_left_measure','pt','','','.b-warehouses-popup'),(37951,'watch-mobile','.p-quick-order-index ul.token-input-list','margin_left_measure','pt','','','.p-quick-order-index'),(37952,'watch-mobile','.w-delivery-day .left-count','margin_left_measure','%','','','.w-delivery-day'),(37953,'watch-mobile','.w-delivery-day .left-text-right','margin_left_measure','%','','','.w-delivery-day'),(37954,'watch-mobile','.w-taxable select','margin_left_measure','pt','','','.w-taxable'),(37955,'watch-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(37956,'watch-mobile','.w-delivery-location-top-location-list .deliveryList','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(37957,'watch-mobile','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(37959,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','margin_right_measure','%','','','.b-fancybox'),(37960,'watch-mobile','.w-cart-give-away .ga_attributes > div','margin_right_measure','%','','','.w-cart-give-away'),(37961,'watch-mobile','.w-product-in-bundles .bundle_item','margin_right_measure','%','','','.w-product-in-bundles'),(37962,'watch-mobile','.w-product-bundle .bundle_item','margin_right_measure','%','','','.w-product-bundle'),(37963,'watch-mobile','.w-cart-give-away .ga_column','margin_right_measure','%','','','.w-cart-give-away'),(37964,'watch-mobile','.w-cart-give-away .ga_img','margin_right_measure','%','','','.w-cart-give-away'),(37965,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_right_measure','pt','','','.b-warehouses-popup'),(37966,'watch-mobile','.p-quick-order-index ul.token-input-list','margin_right_measure','pt','','','.p-quick-order-index'),(37967,'watch-mobile','.w-taxable select','margin_right_measure','pt','','','.w-taxable'),(37968,'watch-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(37969,'watch-mobile','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(37970,'watch-mobile','.w-cart-give-away .ga_attributes > div','margin_top_measure','%','','','.w-cart-give-away'),(37971,'watch-mobile','.p-quick-order-index ul.token-input-list','margin_top_measure','pt','','','.p-quick-order-index'),(37972,'watch-mobile','.w-sale .image img','max-height','300','','','.w-sale'),(37973,'watch-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','max-height','130','','','.b-product-images'),(37974,'watch-mobile','.w-product-images img','max-height','450','','','.w-product-images'),(37975,'watch-mobile','.b-fancybox .fancybox-image','max-height','100','','','.b-fancybox'),(37976,'watch-mobile','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(37977,'watch-mobile','.w-list-type-1 .image img','max-height','150','','','.w-list-type-1'),(37979,'watch-mobile','.b-fancybox .fancybox-tmp','max-height','99999','','','.b-fancybox'),(37980,'watch-mobile','.w-product-images .item-img','max-height','70','320','','.w-product-images'),(37981,'watch-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-height','100','','','.b-products-listing'),(37982,'watch-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(37983,'watch-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(37984,'watch-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(37985,'watch-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(37986,'watch-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(37987,'watch-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(37988,'watch-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','max-height','0','','','.b-menu-burger_icon'),(37989,'watch-mobile','.b-menu-burger_icon .bi-opened .menu-style[data-open_from=\"top\"] .menu-content','max-height','2000','','','.b-menu-burger_icon'),(37990,'watch-mobile','.b-select-suggest .select2-results','max-height','200','','','.b-select-suggest'),(37991,'watch-mobile','.batchPr .w-batch-products .products-listing .image img','max-height','80','','','.batchPr'),(37992,'watch-mobile','.batchPr .w-batch-selected-products .image img','max-height','40','','','.batchPr'),(37993,'watch-mobile','.batchPr .w-batch-products .image img','max-height','160','','','.batchPr'),(37994,'watch-mobile','.w-blog-widget-post-listing .post_image img','max-height','232','','','.w-blog-widget-post-listing'),(37995,'watch-mobile','.w-blog-widget-related-posts-by-category .post_img img','max-height','167','','','.w-blog-widget-related-posts-by-category'),(37996,'watch-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(37997,'watch-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(37998,'watch-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(37999,'watch-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(38000,'watch-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(38001,'watch-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(38002,'watch-mobile','.w-promotions .prom-multi-discount .image img','max-height','80','','','.w-promotions'),(38003,'watch-mobile','.w-promotions .promo-cart-discount .image img','max-height','80','','','.w-promotions'),(38004,'watch-mobile','.w-promotions .promo-salemaker .image img','max-height','80','','','.w-promotions'),(38005,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-height','100','','','.w-upload-customer-id-upload-customer-id-form'),(38006,'watch-mobile','.w-menu .hided.menu ul ul','max-width','none','','','.w-menu'),(38007,'watch-mobile','.w-product-images img','max-width','100','','','.w-product-images'),(38008,'watch-mobile','.p-blog-index .post-thumbnail','max-width','40','','','.p-blog-index'),(38009,'watch-mobile','.w-list-type-1_2 .image','max-width','100','291','','.w-list-type-1_2'),(38010,'watch-mobile','.p-wedding-registry-manage .wr-search','max-width','100','','','.p-wedding-registry-manage'),(38011,'watch-mobile','.p-blog-index .avatar','max-width','28','','','.p-blog-index'),(38012,'watch-mobile','.b-fancybox .fancybox-image','max-width','100','','','.b-fancybox'),(38013,'watch-mobile','.p-wedding-registry-index .middle-box','max-width','600','','','.p-wedding-registry-index'),(38014,'watch-mobile','.p-wedding-registry-index .main-content','max-width','none','','','.p-wedding-registry-index'),(38015,'watch-mobile','.b-bottom .popup-credit-amount .popup-box','max-width','960','','','.b-bottom'),(38016,'watch-mobile','textarea','max-width','100','','',''),(38017,'watch-mobile','.b-fancybox .fancybox-tmp','max-width','99999','','','.b-fancybox'),(38018,'watch-mobile','.w-product-video .frame-video iframe','max-width','100','','','.w-product-video'),(38019,'watch-mobile','.w-product-images .item-img','max-width','70','320','','.w-product-images'),(38020,'watch-mobile','.main-width, .type-1 > .block','max-width','1250','','',''),(38021,'watch-mobile','.w-list-type-1_3 .image','max-width','100','291','','.w-list-type-1_3'),(38022,'watch-mobile','.w-list-type-1_2 .image','max-width','170','','','.w-list-type-1_2'),(38023,'watch-mobile','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(38024,'watch-mobile','.b-form .middle-form','max-width','560','','','.b-form'),(38025,'watch-mobile','div.cart-popup','max-width','95','','',''),(38026,'watch-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-width','100','','','.b-products-listing'),(38027,'watch-mobile','.b-products-listing .promo','max-width','30','','','.b-products-listing'),(38028,'watch-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(38029,'watch-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(38030,'watch-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(38031,'watch-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(38032,'watch-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(38033,'watch-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(38034,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max-width','100','','','.b-menu-lev_display-slide'),(38035,'watch-mobile','.b-trade-approval .middle-form','max-width','560','','','.b-trade-approval'),(38036,'watch-mobile','.b-upload-files .attached-block','max-width','300','','','.b-upload-files'),(38037,'watch-mobile','.batchPr .w-batch-products .products-listing .image','max-width','100','','','.batchPr'),(38038,'watch-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','max-width','1250','','','.w-catalog-b2b-add-button'),(38039,'watch-mobile','.w-checkout-create-btn .btn-2','max-width','100','','','.w-checkout-create-btn'),(38040,'watch-mobile','.w-checkout-guest-btn .btn-2','max-width','100','','','.w-checkout-guest-btn'),(38041,'watch-mobile','.w-login-register .middle-form','max-width','100','','','.w-login-register'),(38042,'watch-mobile','.w-login-returning .middle-form','max-width','100','','','.w-login-returning'),(38043,'watch-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(38044,'watch-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(38045,'watch-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(38046,'watch-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(38047,'watch-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(38048,'watch-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(38049,'watch-mobile','.w-promotions .heading-3','max-width','calc(100% - 100px)','','','.w-promotions'),(38050,'watch-mobile','.w-promotions .promo-cart-discount .master .item','max-width','calc(50% - 24px)','','','.w-promotions'),(38051,'watch-mobile','.w-promotions .promo-cart-discount .slave .item','max-width','calc(50% - 4px)','','','.w-promotions'),(38052,'watch-mobile','.w-promotions .promo-salemaker .item','max-width','calc(50% - 4px)','','','.w-promotions'),(38053,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-width','100','','','.w-upload-customer-id-upload-customer-id-form'),(38054,'watch-mobile','.b-fancybox .fancybox-image','max_height_measure','%','','','.b-fancybox'),(38055,'watch-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_height_measure','%','','','.b-products-listing'),(38056,'watch-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(38057,'watch-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(38058,'watch-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(38059,'watch-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(38060,'watch-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(38061,'watch-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(38062,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(38063,'watch-mobile','.w-product-video .frame-video iframe','max_width_measure','%','','','.w-product-video'),(38064,'watch-mobile','.w-product-images img','max_width_measure','%','','','.w-product-images'),(38065,'watch-mobile','.p-blog-index .post-thumbnail','max_width_measure','%','','','.p-blog-index'),(38066,'watch-mobile','.w-list-type-1_2 .image','max_width_measure','%','291','','.w-list-type-1_2'),(38067,'watch-mobile','.p-wedding-registry-manage .wr-search','max_width_measure','%','','','.p-wedding-registry-manage'),(38068,'watch-mobile','.b-fancybox .fancybox-image','max_width_measure','%','','','.b-fancybox'),(38069,'watch-mobile','.w-list-type-1_3 .image','max_width_measure','%','291','','.w-list-type-1_3'),(38070,'watch-mobile','textarea','max_width_measure','%','','',''),(38071,'watch-mobile','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(38072,'watch-mobile','div.cart-popup','max_width_measure','%','','',''),(38073,'watch-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_width_measure','%','','','.b-products-listing'),(38074,'watch-mobile','.b-products-listing .promo','max_width_measure','%','','','.b-products-listing'),(38075,'watch-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(38076,'watch-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(38077,'watch-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(38078,'watch-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(38079,'watch-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(38080,'watch-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(38081,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max_width_measure','vw','','','.b-menu-lev_display-slide'),(38082,'watch-mobile','.w-checkout-create-btn .btn-2','max_width_measure','%','','','.w-checkout-create-btn'),(38083,'watch-mobile','.w-checkout-guest-btn .btn-2','max_width_measure','%','','','.w-checkout-guest-btn'),(38084,'watch-mobile','.w-login-register .middle-form','max_width_measure','%','','','.w-login-register'),(38085,'watch-mobile','.w-login-returning .middle-form','max_width_measure','%','','','.w-login-returning'),(38086,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(38087,'watch-mobile','.w-search .search-input','min-height','35','','','.w-search'),(38088,'watch-mobile','.w-currencies .current','min-height','31','','','.w-currencies'),(38089,'watch-mobile','.b-slick .slick-slide','min-height','1','','','.b-slick'),(38090,'watch-mobile','.w-cart-discount-coupon .gift-code p','min-height','45','','','.w-cart-discount-coupon'),(38091,'watch-mobile','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(38092,'watch-mobile','.w-languages .current','min-height','31','','','.w-languages'),(38093,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','min-height','40','','','.b-menu-style-1'),(38094,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1','min-height','35','','','.b-menu-style-1'),(38095,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1','min-height','35','','','.b-menu-style-3'),(38096,'watch-mobile','.b-select-suggest .select2-search input','min-height','26','','','.b-select-suggest'),(38097,'watch-mobile','.b-select-suggest .select2-drop-mask','min-height','100','','','.b-select-suggest'),(38098,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','min-height','26','','','.b-select-suggest'),(38099,'watch-mobile','.b-select-suggest .select2-search','min-height','26','','','.b-select-suggest'),(38100,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','min-height','1','','','.b-select-suggest'),(38101,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','min-height','0','','','.batchPr'),(38102,'watch-mobile','.batchPr .w-batch-selected-products','min-height','0','','','.batchPr'),(38103,'watch-mobile','.batchPr .w-batch-products .products-listing .product-holder','min-height_important','important','','','.batchPr'),(38104,'watch-mobile','.batchPr .w-batch-selected-products','min-height_important','important','','','.batchPr'),(38105,'watch-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','min-width','150','','','.w-menu-horizontal'),(38106,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','min-width','150','','','.w-menu-style-1'),(38107,'watch-mobile','.w-menu-style-1 > ul > li > ul > li ul','min-width','150','','','.w-menu-style-1'),(38108,'watch-mobile','.b-pagination .pagination .prev','min-width','30','','','.b-pagination'),(38109,'watch-mobile','.b-bottom .confirm-popup .buttons .btn','min-width','120','','','.b-bottom'),(38110,'watch-mobile','.b-pagination .pagination .prev-pages','min-width','30','','','.b-pagination'),(38111,'watch-mobile','.b-pagination .pagination .page-number','min-width','30','','','.b-pagination'),(38112,'watch-mobile','.b-pagination .pagination .next-pages','min-width','30','','','.b-pagination'),(38113,'watch-mobile','.b-pagination .pagination span','min-width','30','2','','.b-pagination'),(38114,'watch-mobile','.b-pagination .pagination .next','min-width','30','','','.b-pagination'),(38115,'watch-mobile','.b-pagination .pagination a','min-width','30','','','.b-pagination'),(38116,'watch-mobile','.b-bottom .popup-box.popupCompare','min-width','800','','','.b-bottom'),(38117,'watch-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(38118,'watch-mobile','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(38119,'watch-mobile','.w-menu-horizontal > ul > li > ul > li','min-width','150','','','.w-menu-horizontal'),(38120,'watch-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','min-width','70','','','.b-form'),(38121,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.b-data-table'),(38122,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.b-data-table'),(38123,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','min-width','200','','','.b-menu-lev_display-down'),(38124,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','min-width','200','','','.b-menu-lev_display-down'),(38125,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','min-width','200','','','.b-menu-lev_display-down'),(38126,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','min-width','200','','','.b-menu-lev_display-down'),(38127,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','min-width','200','','','.b-menu-lev_display-down'),(38128,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','min-width','200','','','.b-menu-lev_display-left'),(38129,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','min-width','200','','','.b-menu-lev_display-left'),(38130,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','min-width','200','','','.b-menu-lev_display-left'),(38131,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','min-width','200','','','.b-menu-lev_display-left'),(38132,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','min-width','200','','','.b-menu-lev_display-left'),(38133,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','min-width','200','','','.b-menu-lev_display-lra'),(38134,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','min-width','200','','','.b-menu-lev_display-lra'),(38135,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','min-width','200','','','.b-menu-lev_display-lra'),(38136,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','min-width','200','','','.b-menu-lev_display-lra'),(38137,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','min-width','200','','','.b-menu-lev_display-lra'),(38138,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','min-width','200','','','.b-menu-lev_display-right'),(38139,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','min-width','200','','','.b-menu-lev_display-right'),(38140,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','min-width','200','','','.b-menu-lev_display-right'),(38141,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','min-width','200','','','.b-menu-lev_display-right'),(38142,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','min-width','200','','','.b-menu-lev_display-right'),(38143,'watch-mobile','.b-select-suggest .select2-drop-mask','min-width','100','','','.b-select-suggest'),(38144,'watch-mobile','.p-quick-order-index .al_incart, .p-quick-order-index .al-incart','min-width','60','','','.p-quick-order-index'),(38145,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.p-quick-order-index'),(38146,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.p-quick-order-index'),(38147,'watch-mobile','.w-catalog-paging .prev','min-width','30','','','.w-catalog-paging'),(38148,'watch-mobile','.w-catalog-paging ','min-width','30','2','','.w-catalog-paging'),(38149,'watch-mobile','.w-catalog-paging .next','min-width','30','','','.w-catalog-paging'),(38150,'watch-mobile','.w-catalog-paging .page-number','min-width','30','','','.w-catalog-paging'),(38151,'watch-mobile','.w-catalog-paging .next-pages','min-width','30','','','.w-catalog-paging'),(38152,'watch-mobile','.w-catalog-paging .prev-pages','min-width','30','','','.w-catalog-paging'),(38153,'watch-mobile','.w-communication-new-topic #communication_group_holder table table','min-width','0','','','.w-communication-new-topic'),(38154,'watch-mobile','.w-communication-new-topic .quantity','min-width','70','','','.w-communication-new-topic'),(38155,'watch-mobile','.w-communication-new-topic #communication_group_holder table','min-width','800','','','.w-communication-new-topic'),(38156,'watch-mobile','.w-communication-post .btn-submit','min-width','200','','','.w-communication-post'),(38157,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','min_height_measure','em','','','.b-select-suggest'),(38158,'watch-mobile','.b-select-suggest .select2-drop-mask','min_height_measure','%','','','.b-select-suggest'),(38159,'watch-mobile','.b-select-suggest .select2-drop-mask','min_width_measure','%','','','.b-select-suggest'),(38160,'watch-mobile','.w-filters .input-checkbox','opacity','0','','','.w-filters'),(38163,'watch-mobile','.b-pagination .pagination .paging span.prev, .b-pagination .pagination .paging span.next','opacity','0.3','','','.b-pagination'),(38164,'watch-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','opacity','0','','','.b-switch'),(38165,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','opacity','0.5','','','.b-switch'),(38166,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','opacity','0.5','','','.b-switch'),(38167,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','opacity','0.5','','','.b-switch'),(38168,'watch-mobile','.b-slick button.slick-disabled','opacity','0.3','','','.b-slick'),(38169,'watch-mobile','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(38170,'watch-mobile','.b-form .checkbox-style','opacity','0','','','.b-form'),(38171,'watch-mobile','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(38172,'watch-mobile','.b-form .hide-billing-address','opacity','0.7','','','.b-form'),(38173,'watch-mobile','.b-fancybox #fancybox-loading','opacity','0.8','','','.b-fancybox'),(38174,'watch-mobile','.b-products-listing .products-listing .qty-input.hidden','opacity','0.7','3','','.b-products-listing'),(38175,'watch-mobile','.b-select-suggest .select2-drop-mask','opacity','0','','','.b-select-suggest'),(38182,'watch-mobile','.p-quick-order-index .paginate_button.next.disabled','opacity','0.3','3','','.p-quick-order-index'),(38183,'watch-mobile','.p-quick-order-index .paginate_button.previous.disabled','opacity','0.3','3','','.p-quick-order-index'),(38184,'watch-mobile','.w-catalog-paging .paging span.prev, .w-catalog-paging .paging span.next','opacity','0.3','','','.w-catalog-paging'),(38185,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','opacity','0','','','.w-filters'),(38186,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition','order','2','','','.w-promotions'),(38187,'watch-mobile','.w-promotions .promo-cart-discount .slave .content','order','3','','','.w-promotions'),(38188,'watch-mobile','.w-promotions .promo-cart-discount .slave .heading','order','1','','','.w-promotions'),(38189,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-focused','outline','0','','','.b-switch'),(38190,'watch-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','outline','none','','','.b-fancybox'),(38191,'watch-mobile','.b-slick .slick-list:focus','outline','none','','','.b-slick'),(38192,'watch-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','outline','none','','','.b-fancybox'),(38193,'watch-mobile','.b-product-images .additional-images div:focus, .b-product-images .additional-videos div:focus','outline','none','','','.b-product-images'),(38194,'watch-mobile','.b-select-suggest .select2-search-choice-close','outline','none','','','.b-select-suggest'),(38195,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','outline','0','','','.b-select-suggest'),(38196,'watch-mobile','.b-select-suggest .select2-container-active .select2-choice, .b-select-suggest .select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(38197,'watch-mobile','.b-select-suggest .select2-search input','outline','0','','','.b-select-suggest'),(38198,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline','0','','','.b-select-suggest'),(38199,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(38200,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','outline','0','','','.b-select-suggest'),(38201,'watch-mobile','.batchPr .products-listing .item','outline','none','','','.batchPr'),(38202,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline_important','important','','','.b-select-suggest'),(38203,'watch-mobile','.w-list-type-2_2 .compare-box-item','overflow','hidden','','','.w-list-type-2_2'),(38204,'watch-mobile','.b-switch .bootstrap-switch','overflow','hidden','','','.b-switch'),(38205,'watch-mobile','.w-product-sale-ends .left','overflow','hidden','','','.w-product-sale-ends'),(38206,'watch-mobile','.w-sale .sale-holder','overflow','hidden','','','.w-sale'),(38207,'watch-mobile','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(38208,'watch-mobile','.w-cart .no-text','overflow','hidden','','','.w-cart'),(38210,'watch-mobile','.w-quote .no-text','overflow','hidden','','','.w-quote'),(38211,'watch-mobile','.w-product-images .img-holder','overflow','hidden','','','.w-product-images'),(38213,'watch-mobile','.p-blog-index .nav-links','overflow','hidden','','','.p-blog-index'),(38214,'watch-mobile','.w-list-type-2_2 .buttons','overflow','hidden','','','.w-list-type-2_2'),(38215,'watch-mobile','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(38216,'watch-mobile','.b-fancybox .fancybox-inner','overflow','hidden','','','.b-fancybox'),(38217,'watch-mobile','.b-fancybox .fancybox-lock','overflow','hidden','','','.b-fancybox'),(38218,'watch-mobile','.b-fancybox .fancybox-lock .fancybox-overlay','overflow','auto','','','.b-fancybox'),(38219,'watch-mobile','.b-fancybox .fancybox-lock body','overflow','hidden','','','.b-fancybox'),(38220,'watch-mobile','.b-compare .col-two','overflow','hidden','','','.b-compare'),(38221,'watch-mobile','.b-compare .compare-box-item','overflow','hidden','','','.b-compare'),(38222,'watch-mobile','.w-search .suggest','overflow','auto','','','.w-search'),(38223,'watch-mobile','.w-search .item','overflow','hidden','','','.w-search'),(38224,'watch-mobile','.w-list-type-1_2 .compare-box-item','overflow','hidden','','','.w-list-type-1_2'),(38225,'watch-mobile','.w-banner .banner .image-box','overflow','hidden','','','.w-banner'),(38226,'watch-mobile','.p-account-trade-form .widget','overflow','hidden','','','.p-account-trade-form'),(38228,'watch-mobile','.w-list-type-2 .compare-box-item','overflow','hidden','','','.w-list-type-2'),(38229,'watch-mobile','.w-list-type-1_3 .compare-box-item','overflow','hidden','','','.w-list-type-1_3'),(38230,'watch-mobile','.w-list-type-1 .compare-box-item','overflow','hidden','','','.w-list-type-1'),(38231,'watch-mobile','.b-fancybox .fancybox-tmp','overflow','visible','','','.b-fancybox'),(38232,'watch-mobile','.w-menu-mobile .menu-slider .open','overflow','auto','','','.w-menu-mobile'),(38233,'watch-mobile','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(38234,'watch-mobile','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(38235,'watch-mobile','.p-reviews-info .review-info-head','overflow','hidden','','','.p-reviews-info'),(38236,'watch-mobile','.b-fancybox .fancybox-overlay','overflow','hidden','','','.b-fancybox'),(38237,'watch-mobile','.w-sale .left','overflow','hidden','','','.w-sale'),(38238,'watch-mobile','.b-slick .slick-list','overflow','hidden','','','.b-slick'),(38239,'watch-mobile','.w-cart-discount-coupon .gift-code .input-apple > div','overflow','hidden','','','.w-cart-discount-coupon'),(38243,'watch-mobile','.w-cart-give-away .ga_ovr','overflow','hidden','','','.w-cart-give-away'),(38244,'watch-mobile','.w-cart-give-away .ga_wrapper','overflow','hidden','','','.w-cart-give-away'),(38245,'watch-mobile','.w-list-type-2 .buttons','overflow','hidden','','','.w-list-type-2'),(38246,'watch-mobile','.b-autocomplete .ui-autocomplete','overflow','auto','','','.b-autocomplete'),(38247,'watch-mobile','.w-list-type-1_3 .buttons','overflow','hidden','','','.w-list-type-1_3'),(38248,'watch-mobile','.w-list-type-1_3 .attributes > .attributes','overflow','hidden','','','.w-list-type-1_3'),(38249,'watch-mobile','.w-list-type-1_2 .buttons','overflow','hidden','','','.w-list-type-1_2'),(38250,'watch-mobile','.w-list-type-1 .buttons','overflow','hidden','','','.w-list-type-1'),(38251,'watch-mobile','.b-form .addresses .address-item span','overflow','hidden','','','.b-form'),(38252,'watch-mobile','.b-form .discount-box .inp','overflow','hidden','','','.b-form'),(38253,'watch-mobile','.b-form .payment-method .item-radio label span','overflow','hidden','','','.b-form'),(38255,'watch-mobile','.b-products-listing .btn-preloader','overflow','hidden','3','','.b-products-listing'),(38256,'watch-mobile','.b-products-listing .loader','overflow','hidden','4','','.b-products-listing'),(38257,'watch-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','overflow','hidden','','','.b-menu-burger_icon'),(38258,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','overflow','auto','','','.b-menu-lev_display-width'),(38259,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','overflow','auto','','','.b-menu-lev_display-width'),(38260,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','overflow','auto','','','.b-menu-lev_display-width'),(38261,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','overflow','auto','','','.b-menu-lev_display-width'),(38262,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','overflow','auto','','','.b-menu-lev_display-width'),(38263,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','overflow','auto','','','.b-menu-lev_display-width_cont'),(38264,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','overflow','auto','','','.b-menu-lev_display-width_cont'),(38265,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','overflow','auto','','','.b-menu-lev_display-width_cont'),(38266,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','overflow','auto','','','.b-menu-lev_display-width_cont'),(38267,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','overflow','auto','','','.b-menu-lev_display-width_cont'),(38268,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','overflow','auto','','','.b-menu-open_from-left'),(38269,'watch-mobile','.b-preloader .preloader','overflow','hidden','3','','.b-preloader'),(38270,'watch-mobile','.b-select-suggest .select2-container .select2-choice','overflow','hidden','','','.b-select-suggest'),(38271,'watch-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','overflow','hidden','','','.b-select-suggest'),(38272,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow','hidden','','','.b-select-suggest'),(38273,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','overflow','hidden','','','.b-select-suggest'),(38274,'watch-mobile','.b-select-suggest .select2-measure-scrollbar','overflow','scroll','','','.b-select-suggest'),(38275,'watch-mobile','.b-trade-approval .steps-bar','overflow','hidden','','','.b-trade-approval'),(38276,'watch-mobile','.b-upload-files .attach-active-holder','overflow','hidden','','','.b-upload-files'),(38277,'watch-mobile','.b-upload-files .attached-block','overflow','hidden','','','.b-upload-files'),(38278,'watch-mobile','.b-upload-files .attach-block','overflow','hidden','','','.b-upload-files'),(38279,'watch-mobile','.b-upload-files .added-file','overflow','hidden','','','.b-upload-files'),(38280,'watch-mobile','.batchPr .w-batch-products .products-listing .image + .type-1','overflow','hidden','','','.batchPr'),(38281,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','overflow','hidden','','','.batchPr'),(38282,'watch-mobile','.batchPr .batch-selected-products-list','overflow','auto','','','.batchPr'),(38283,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(2)','overflow','hidden','','','.batchPr'),(38290,'watch-mobile','.p-quick-order-index .top','overflow','hidden','','','.p-quick-order-index'),(38291,'watch-mobile','.p-quick-order-index .bottom','overflow','hidden','','','.p-quick-order-index'),(38292,'watch-mobile','.w-account-addresses-list ','overflow','hidden','','','.w-account-addresses-list'),(38293,'watch-mobile','.w-blog-widget-post-linked-products .heading-2','overflow','hidden','','','.w-blog-widget-post-linked-products'),(38294,'watch-mobile','.w-blog-widget-related-posts ','overflow','hidden','','','.w-blog-widget-related-posts'),(38295,'watch-mobile','.w-blog-widget-related-posts-by-category ','overflow','hidden','','','.w-blog-widget-related-posts-by-category'),(38296,'watch-mobile','.w-cart-compare .product .name','overflow','hidden','','','.w-cart-compare'),(38297,'watch-mobile','.w-catalog-compare .compare','overflow','hidden','','','.w-catalog-compare'),(38298,'watch-mobile','.w-catalog-paging .paging-holder','overflow','hidden','','','.w-catalog-paging'),(38299,'watch-mobile','.w-catalog-paging .paging-holder.slick-slider','overflow','visible','','','.w-catalog-paging'),(38300,'watch-mobile','.w-checkout-shipping-choice #shippingchoice-choice','overflow','hidden','','','.w-checkout-shipping-choice'),(38301,'watch-mobile','.w-checkout-shipping-choice input','overflow','hidden','','','.w-checkout-shipping-choice'),(38302,'watch-mobile','.w-communication-new-topic #communication_group_holder','overflow','auto','','','.w-communication-new-topic'),(38303,'watch-mobile','.w-delivery-day .time-left','overflow','hidden','','','.w-delivery-day'),(38304,'watch-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','overflow','hidden','','','.w-promotions'),(38305,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','overflow','hidden','','','.w-wedding-registry-widgets-photos'),(38306,'watch-mobile','.b-compare .compare_list','overflow-x','hidden','','','.b-compare'),(38307,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-x','hidden','','','.b-menu-lev_display-slide'),(38308,'watch-mobile','.b-select-suggest .select2-results','overflow-x','hidden','','','.b-select-suggest'),(38309,'watch-mobile','.b-compare .compare_list','overflow-y','auto','','','.b-compare'),(38310,'watch-mobile','.b-fancybox .fancybox-lock-test','overflow-y','hidden','','','.b-fancybox'),(38311,'watch-mobile','.b-fancybox .fancybox-lock .fancybox-overlay','overflow-y','scroll','','','.b-fancybox'),(38312,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-y','auto','','','.b-menu-lev_display-slide'),(38313,'watch-mobile','.b-select-suggest .select2-results','overflow-y','auto','','','.b-select-suggest'),(38314,'watch-mobile','.b-fancybox .fancybox-lock-test','overflow-y_important','important','','','.b-fancybox'),(38315,'watch-mobile','.b-fancybox .fancybox-lock','overflow_important','important','','','.b-fancybox'),(38316,'watch-mobile','.b-fancybox .fancybox-lock body','overflow_important','important','','','.b-fancybox'),(38317,'watch-mobile','.b-fancybox .fancybox-tmp','overflow_important','important','','','.b-fancybox'),(38318,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow_important','important','','','.b-select-suggest'),(38319,'watch-mobile','.w-list-type-1_3 .compare-box-item','padding-bottom','7','','','.w-list-type-1_3'),(38320,'watch-mobile','.w-list-type-2 .compare-box-item','padding-bottom','7','','','.w-list-type-2'),(38321,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-2'),(38322,'watch-mobile','.w-list-type-2_2.products-listing','padding-bottom','20','','','.w-list-type-2_2'),(38323,'watch-mobile','.w-list-type-1_3 .item','padding-bottom','20','','','.w-list-type-1_3'),(38324,'watch-mobile','.w-list-type-2_2 .compare-box-item','padding-bottom','7','','','.w-list-type-2_2'),(38325,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-2_2'),(38326,'watch-mobile','.w-list-type-2.products-listing','padding-bottom','20','','','.w-list-type-2'),(38327,'watch-mobile','.w-list-type-2 .item','padding-bottom','21','','','.w-list-type-2'),(38328,'watch-mobile','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(38329,'watch-mobile','.w-list-type-3.products-listing','padding-bottom','20','','','.w-list-type-3'),(38330,'watch-mobile','.w-menu .hided.menu ul li','padding-bottom','0','','','.w-menu'),(38331,'watch-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-bottom','0','','','.w-menu'),(38332,'watch-mobile','.w-menu-slider > ul > li > a','padding-bottom','5','','','.w-menu-slider'),(38333,'watch-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-bottom','2','','','.w-menu-horizontal'),(38334,'watch-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','6','','','.w-menu-horizontal'),(38335,'watch-mobile','.w-menu-big ul','padding-bottom','0','','','.w-menu-big'),(38336,'watch-mobile','.w-menu-horizontal > ul > li > ul > li','padding-bottom','2','','','.w-menu-horizontal'),(38337,'watch-mobile','.w-menu-slider > ul > li > ul > li','padding-bottom','10','','','.w-menu-slider'),(38338,'watch-mobile','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(38339,'watch-mobile','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(38340,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-bottom','0','','','.b-slick'),(38341,'watch-mobile','.w-top-categories .item','padding-bottom','30','290','','.w-top-categories'),(38342,'watch-mobile','.w-menu-slider ul, .w-menu-slider li','padding-bottom','0','','','.w-menu-slider'),(38343,'watch-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','5','','','.w-menu-style-1'),(38344,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(38345,'watch-mobile','.b-bottom .popup-simple','padding-bottom','20','','','.b-bottom'),(38346,'watch-mobile','.b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .buttons','padding-bottom','10','','','.b-cookie-notice'),(38347,'watch-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.bottom .text','padding-bottom','5','','','.b-cookie-notice'),(38348,'watch-mobile','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(38349,'watch-mobile','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(38350,'watch-mobile','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(38351,'watch-mobile','.w-product-wedding-registry-button .btn','padding-bottom','0','','','.w-product-wedding-registry-button'),(38352,'watch-mobile','.w-search .items-title','padding-bottom','5','','','.w-search'),(38353,'watch-mobile','.w-sale .holder-2','padding-bottom','20','','','.w-sale'),(38354,'watch-mobile','.w-sale .left-count','padding-bottom','0','','','.w-sale'),(38355,'watch-mobile','.w-list-type-1_2 .button-wishlist button','padding-bottom','10','','','.w-list-type-1_2'),(38356,'watch-mobile','.w-product-sale-ends .left-text-left','padding-bottom','24','','','.w-product-sale-ends'),(38357,'watch-mobile','.w-product-sale-ends .left-text-right','padding-bottom','24','','','.w-product-sale-ends'),(38358,'watch-mobile','.w-currencies .select-link','padding-bottom','5','','','.w-currencies'),(38359,'watch-mobile','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(38360,'watch-mobile','.w-currencies .current','padding-bottom','3','','','.w-currencies'),(38361,'watch-mobile','.w-categories .name','padding-bottom','3','','','.w-categories'),(38362,'watch-mobile','.w-categories .item','padding-bottom','30','','','.w-categories'),(38363,'watch-mobile','.w-filters .filter-ul-content','padding-bottom','0','','','.w-filters'),(38378,'watch-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-bottom','10','','','.p-account-subscription-historyinfo'),(38379,'watch-mobile','.b-bottom .popup-buttons','padding-bottom','15','','','.b-bottom'),(38380,'watch-mobile','.w-product-images .img-holder','padding-bottom','20','','','.w-product-images'),(38381,'watch-mobile','.b-bottom .popup-content','padding-bottom','15','','','.b-bottom'),(38382,'watch-mobile','.b-compare .compare_pagination','padding-bottom','10','','','.b-compare'),(38383,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-bottom','20','','','.b-multi-page-checkout'),(38384,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-bottom','6','','','.b-multi-page-checkout'),(38385,'watch-mobile','.w-sale .holder-1','padding-bottom','20','','','.w-sale'),(38387,'watch-mobile','.b-info-popup .info-popup div','padding-bottom','10','','','.b-info-popup'),(38390,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-bottom','0','','','.b-multi-page-checkout'),(38391,'watch-mobile','.w-search .search-input','padding-bottom','5','','','.w-search'),(38392,'watch-mobile','.w-socials > li','padding-bottom','15','','','.w-socials'),(38393,'watch-mobile','.w-promo-code .holder','padding-bottom','20','320','','.w-promo-code'),(38394,'watch-mobile','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(38395,'watch-mobile','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(38396,'watch-mobile','.p-wedding-registry-manage a.remove-btn','padding-bottom','5','','','.p-wedding-registry-manage'),(38403,'watch-mobile','.w-filters .head-filter-widget','padding-bottom','0','317','','.w-filters'),(38404,'watch-mobile','.w-product-configurator .pc_attr','padding-bottom','5','290','','.w-product-configurator'),(38405,'watch-mobile','.w-product-configurator .pc_item','padding-bottom','10','299','','.w-product-configurator'),(38406,'watch-mobile','.testimonials .name','padding-bottom','5','','',''),(38407,'watch-mobile','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(38409,'watch-mobile','.testimonials .heading-3','padding-bottom','10','','',''),(38410,'watch-mobile','.testimonials .review','padding-bottom','10','','',''),(38411,'watch-mobile','.testimonials .reviews-list .name','padding-bottom','5','','',''),(38412,'watch-mobile','.b-bottom .confirm-popup .buttons','padding-bottom','30','','','.b-bottom'),(38413,'watch-mobile','.b-bottom .confirm-popup .confirm-text','padding-bottom','30','','','.b-bottom'),(38423,'watch-mobile','.btn-1','padding-bottom','4','','',''),(38424,'watch-mobile','.btn','padding-bottom','8','','',''),(38425,'watch-mobile','.btn-2','padding-bottom','12','','',''),(38426,'watch-mobile','.p-blog-index .comment-list','padding-bottom','30','','','.p-blog-index'),(38427,'watch-mobile','.p-blog-index .comments-area article','padding-bottom','10','','','.p-blog-index'),(38428,'watch-mobile','.btn-3','padding-bottom','10','','',''),(38429,'watch-mobile','.w-list-type-2_2 .buttons','padding-bottom','3','','','.w-list-type-2_2'),(38430,'watch-mobile','.no-found','padding-bottom','20','','',''),(38431,'watch-mobile','.w-list-type-2_2 .item','padding-bottom','20','','','.w-list-type-2_2'),(38432,'watch-mobile','.w-list-type-2_2 .button-wishlist button','padding-bottom','10','','','.w-list-type-2_2'),(38433,'watch-mobile','.w-product-personal-catalog-button .btn','padding-bottom','0','','','.w-product-personal-catalog-button'),(38434,'watch-mobile','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(38435,'watch-mobile','.w-account ul, .w-account li','padding-bottom','0','','','.w-account'),(38436,'watch-mobile','.b-fancybox .fancybox-error','padding-bottom','15','','','.b-fancybox'),(38437,'watch-mobile','.w-menu-horizontal ul','padding-bottom','0','','','.w-menu-horizontal'),(38438,'watch-mobile','.w-chat .w-chat-box','padding-bottom','2','','','.w-chat'),(38439,'watch-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-bottom','0','','','.w-delivery-location-top-location-list'),(38440,'watch-mobile','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(38441,'watch-mobile','.p-wedding-registry-index .middle-box','padding-bottom','30','','','.p-wedding-registry-index'),(38442,'watch-mobile','.p-wedding-registry-index .main-content','padding-bottom','70','','','.p-wedding-registry-index'),(38443,'watch-mobile','.p-wedding-registry-index .main-button','padding-bottom','0','4','','.p-wedding-registry-index'),(38444,'watch-mobile','.p-wedding-registry-index .main-button','padding-bottom','40','','','.p-wedding-registry-index'),(38445,'watch-mobile','.p-wedding-registry-index .main-button','padding-bottom','0','3','','.p-wedding-registry-index'),(38446,'watch-mobile','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(38447,'watch-mobile','.b-form .form-buttons','padding-bottom','50','','','.b-form'),(38448,'watch-mobile','.p-wedding-registry-manage .links a','padding-bottom','0','','','.p-wedding-registry-manage'),(38449,'watch-mobile','.b-bottom .alert-message','padding-bottom','20','','','.b-bottom'),(38450,'watch-mobile','.p-wedding-registry-manage .links','padding-bottom','10','','','.p-wedding-registry-manage'),(38451,'watch-mobile','.p-wedding-registry-share .middle-form > input','padding-bottom','0','','','.p-wedding-registry-share'),(38452,'watch-mobile','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(38453,'watch-mobile','.b-table .table td','padding-bottom','15','','','.b-table'),(38454,'watch-mobile','.header2 .ccc','padding-bottom','10','','',''),(38462,'watch-mobile','.b-bottom .popup-heading','padding-bottom','12','','','.b-bottom'),(38463,'watch-mobile','.b-compare .col-gender','padding-bottom','10','','','.b-compare'),(38464,'watch-mobile','.b-compare .col-two label','padding-bottom','5','','','.b-compare'),(38465,'watch-mobile','.b-compare .compare-head','padding-bottom','0','','','.b-compare'),(38466,'watch-mobile','.b-compare .compare-box-item','padding-bottom','10','','','.b-compare'),(38467,'watch-mobile','.b-compare .column_wrapper','padding-bottom','10','','','.b-compare'),(38468,'watch-mobile','.w-quote .cart-box-link','padding-bottom','5','299','','.w-quote'),(38469,'watch-mobile','.w-tabs .accordion-heading','padding-bottom','6','2','','.w-tabs'),(38470,'watch-mobile','.w-languages .current','padding-bottom','13','299','','.w-languages'),(38471,'watch-mobile','.w-currencies .select-link','padding-bottom','12','299','','.w-currencies'),(38472,'watch-mobile','.w-tabs .accordion-heading','padding-bottom','8','','','.w-tabs'),(38473,'watch-mobile','.w-languages .lang-link','padding-bottom','13','299','','.w-languages'),(38474,'watch-mobile','.w-currencies .current','padding-bottom','14','299','','.w-currencies'),(38475,'watch-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','12','299','','.w-menu-horizontal'),(38476,'watch-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','12','303','','.w-menu-style-1'),(38477,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-bottom','8','303','','.w-list-type-1'),(38479,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-bottom','12','303','','.w-menu-style-1'),(38480,'watch-mobile','.b-bottom .footerTitle','padding-bottom','9','290','','.b-bottom'),(38483,'watch-mobile','.w-cart .cart-total','padding-bottom','10','','','.w-cart'),(38484,'watch-mobile','.w-cart .cart-content','padding-bottom','5','','','.w-cart'),(38485,'watch-mobile','.w-cart .cart-box-link','padding-bottom','5','','','.w-cart'),(38486,'watch-mobile','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(38487,'watch-mobile','.w-product-reviews .reviews-list .name','padding-bottom','5','','','.w-product-reviews'),(38488,'watch-mobile','.w-reviews .name','padding-bottom','5','','','.w-reviews'),(38489,'watch-mobile','.w-tabs .tab-a','padding-bottom','6','2','','.w-tabs'),(38490,'watch-mobile','.w-bestsellers .heading-3','padding-bottom','15','','','.w-bestsellers'),(38491,'watch-mobile','.w-account a.my-acc-link','padding-bottom','5','','','.w-account'),(38492,'watch-mobile','.w-list-type-1_3 .item','padding-bottom','20','1','','.w-list-type-1_3'),(38493,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-1_2'),(38494,'watch-mobile','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(38495,'watch-mobile','.w-tabs .tab-navigation','padding-bottom','0','','','.w-tabs'),(38496,'watch-mobile','.p-account-trade-form .widget','padding-bottom','20','','','.p-account-trade-form'),(38497,'watch-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-bottom','0','','','.p-blog-index'),(38498,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-bottom','5','','','.p-blog-index'),(38499,'watch-mobile','.p-blog-index .nav-links','padding-bottom','20','','','.p-blog-index'),(38501,'watch-mobile','.p-blog-index .wp-widget li','padding-bottom','10','','','.p-blog-index'),(38502,'watch-mobile','.p-blog-index .wp-widget ul','padding-bottom','0','','','.p-blog-index'),(38506,'watch-mobile','.p-quote-cart-index .cart-page .empty','padding-bottom','100','','','.p-quote-cart-index'),(38507,'watch-mobile','.p-reviews-info .review-info-image','padding-bottom','20','','','.p-reviews-info'),(38508,'watch-mobile','.p-reviews-info .review-info-content','padding-bottom','20','','','.p-reviews-info'),(38509,'watch-mobile','.p-quote-cart-index .cart-popup .cart-page, .p-quote-cart-index .cart-popup .wishlist-page','padding-bottom','10','','','.p-quote-cart-index'),(38510,'watch-mobile','.p-reviews-info .review-info-text','padding-bottom','10','','','.p-reviews-info'),(38511,'watch-mobile','.p-reviews-info .reviews-info .buttons','padding-bottom','20','','','.p-reviews-info'),(38512,'watch-mobile','.p-shopping-cart-index .cart-popup .cart-page, .p-shopping-cart-index .cart-popup .wishlist-page','padding-bottom','10','','','.p-shopping-cart-index'),(38513,'watch-mobile','.p-shopping-cart-index .cart-page .empty','padding-bottom','100','','','.p-shopping-cart-index'),(38516,'watch-mobile','.w-filters .filter-box-content','padding-bottom','20','','','.w-filters'),(38517,'watch-mobile','.w-filters .filter-box-head','padding-bottom','5','','','.w-filters'),(38518,'watch-mobile','.w-filters .filter-li-content','padding-bottom','15','','','.w-filters'),(38519,'watch-mobile','.b-slick .slick-vertical button.slick-next','padding-bottom','0','3','','.b-slick'),(38520,'watch-mobile','.b-slick .slick-vertical button.slick-prev','padding-bottom','0','3','','.b-slick'),(38521,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-bottom','2','','','.b-fancybox'),(38522,'watch-mobile','.p-account-trade-form .trade-form-area','padding-bottom','20','','','.p-account-trade-form'),(38523,'watch-mobile','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(38524,'watch-mobile','.b-info .info ul','padding-bottom','0','','','.b-info'),(38525,'watch-mobile','.w-product-configurator .pc_item','padding-bottom','10','','','.w-product-configurator'),(38530,'watch-mobile','.w-list-type-2 .item','padding-bottom','20','1','','.w-list-type-2'),(38531,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-1_3'),(38532,'watch-mobile','.w-list-type-1_2 .compare-box-item','padding-bottom','7','','','.w-list-type-1_2'),(38533,'watch-mobile','.w-list-type-1 .item','padding-bottom','20','','','.w-list-type-1'),(38534,'watch-mobile','.w-list-type-1 .compare-box-item','padding-bottom','7','','','.w-list-type-1'),(38535,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-1'),(38536,'watch-mobile','.w-list-type-1 ','padding-bottom','20','','','.w-list-type-1'),(38537,'watch-mobile','.w-list-type-1_2.products-listing','padding-bottom','20','','','.w-list-type-1_2'),(38538,'watch-mobile','.w-filters .head-filter-widget','padding-bottom','10','','','.w-filters'),(38539,'watch-mobile','.w-languages .lang-link','padding-bottom','5','','','.w-languages'),(38540,'watch-mobile','.w-languages .current','padding-bottom','3','','','.w-languages'),(38541,'watch-mobile','.w-filters .ui-slider-range','padding-bottom','0','','','.w-filters'),(38542,'watch-mobile','.w-filters .fsl_handle','padding-bottom','15','','','.w-filters'),(38543,'watch-mobile','.b-fancybox .fancybox-title-over-wrap','padding-bottom','10','','','.b-fancybox'),(38544,'watch-mobile','.w-currencies .currencies-title','padding-bottom','0','','','.w-currencies'),(38545,'watch-mobile','.w-categories .image','padding-bottom','75','','','.w-categories'),(38546,'watch-mobile','.w-cart a.item','padding-bottom','5','','','.w-cart'),(38547,'watch-mobile','.w-breadcrumb .breadcrumb-li','padding-bottom','0','','','.w-breadcrumb'),(38548,'watch-mobile','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(38549,'watch-mobile','.b-compare .popupCompare .pop-up-content','padding-bottom','10','','','.b-compare'),(38550,'watch-mobile','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(38551,'watch-mobile','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(38552,'watch-mobile','.w-reviews .heading-3','padding-bottom','10','','','.w-reviews'),(38553,'watch-mobile','.w-product-sale-ends .left-count','padding-bottom','0','','','.w-product-sale-ends'),(38554,'watch-mobile','.w-product-reviews .reviews-list .review','padding-bottom','10','','','.w-product-reviews'),(38555,'watch-mobile','.w-quote .cart-box-link','padding-bottom','5','','','.w-quote'),(38556,'watch-mobile','.w-reviews .review','padding-bottom','10','','','.w-reviews'),(38557,'watch-mobile','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(38558,'watch-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(38559,'watch-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(38560,'watch-mobile','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(38561,'watch-mobile','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(38562,'watch-mobile','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(38563,'watch-mobile','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(38564,'watch-mobile','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(38565,'watch-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(38566,'watch-mobile','.w-menu-style-1 ul','padding-bottom','0','','','.w-menu-style-1'),(38567,'watch-mobile','.w-sale .left-text-right','padding-bottom','24','','','.w-sale'),(38568,'watch-mobile','.w-sale .left-text-left','padding-bottom','24','','','.w-sale'),(38569,'watch-mobile','.w-tabs .accordion-heading','padding-bottom','9','290','','.w-tabs'),(38570,'watch-mobile','.w-top-categories .categories h2','padding-bottom','0','','','.w-top-categories'),(38571,'watch-mobile','.w-categories .categories h2','padding-bottom','0','','','.w-categories'),(38572,'watch-mobile','.w-banner .carousel-text > span','padding-bottom','20','','','.w-banner'),(38573,'watch-mobile','.b-form .col-full-padding','padding-bottom','30','','','.b-form'),(38574,'watch-mobile','.b-slick .slick-list','padding-bottom','0','','','.b-slick'),(38575,'watch-mobile','.w-tabs .tab-li','padding-bottom','0','','','.w-tabs'),(38576,'watch-mobile','.w-tabs .tab-a','padding-bottom','8','','','.w-tabs'),(38578,'watch-mobile','.w-categories .item','padding-bottom','30','290','','.w-categories'),(38579,'watch-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-bottom','0','','','.b-fancybox'),(38580,'watch-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-bottom','0','','','.b-fancybox'),(38581,'watch-mobile','.w-cart-give-away .ga_column','padding-bottom','15','','','.w-cart-give-away'),(38582,'watch-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-bottom','4','','','.b-compare'),(38583,'watch-mobile','.w-product-images .images','padding-bottom','20','320','','.w-product-images'),(38586,'watch-mobile','.w-list-type-2 .buttons','padding-bottom','3','','','.w-list-type-2'),(38587,'watch-mobile','.w-list-type-2 .button-wishlist button','padding-bottom','10','','','.w-list-type-2'),(38588,'watch-mobile','.b-autocomplete .ui-autocomplete','padding-bottom','0','','','.b-autocomplete'),(38589,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','padding-bottom','5','','',''),(38590,'watch-mobile','textarea','padding-bottom','5','','',''),(38591,'watch-mobile','.w-list-type-1_3 .buttons','padding-bottom','3','','','.w-list-type-1_3'),(38592,'watch-mobile','.w-list-type-1_3 .button-wishlist button','padding-bottom','10','','','.w-list-type-1_3'),(38593,'watch-mobile','.b-autocomplete .ui-autocomplete li','padding-bottom','3','','','.b-autocomplete'),(38594,'watch-mobile','.w-list-type-1_2 .item','padding-bottom','20','','','.w-list-type-1_2'),(38595,'watch-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-bottom','10','','','.b-bottom'),(38596,'watch-mobile','.w-list-type-1_2 .buttons','padding-bottom','3','','','.w-list-type-1_2'),(38597,'watch-mobile','.b-bottom .pop-up-close','padding-bottom','1','','','.b-bottom'),(38598,'watch-mobile','.b-bottom .pop-up-info','padding-bottom','20','','','.b-bottom'),(38599,'watch-mobile','.heading-4, h4','padding-bottom','3','','',''),(38600,'watch-mobile','.w-list-type-1 .buttons','padding-bottom','3','','','.w-list-type-1'),(38601,'watch-mobile','.w-list-type-1 .button-wishlist button','padding-bottom','10','','','.w-list-type-1'),(38602,'watch-mobile','.b-bottom .popup-box-wrap','padding-bottom','10','','','.b-bottom'),(38603,'watch-mobile','.b-form .center-buttons','padding-bottom','20','','','.b-form'),(38604,'watch-mobile','.w-reviews .reviews-list .name','padding-bottom','5','','','.w-reviews'),(38605,'watch-mobile','.w-top-categories .name','padding-bottom','3','','','.w-top-categories'),(38607,'watch-mobile','.w-top-categories .image','padding-bottom','75','','','.w-top-categories'),(38608,'watch-mobile','.w-tabs > .block','padding-bottom','20','','','.w-tabs'),(38609,'watch-mobile','.w-top-categories .item','padding-bottom','30','','','.w-top-categories'),(38610,'watch-mobile','.b-form .middle-form','padding-bottom','20','','','.b-form'),(38611,'watch-mobile','.b-form .payment-method .item-radio label','padding-bottom','5','','','.b-form'),(38612,'watch-mobile','.b-form .required-message','padding-bottom','0','','','.b-form'),(38613,'watch-mobile','.b-form .shipping-method .input','padding-bottom','0','','','.b-form'),(38614,'watch-mobile','.b-form .required-message-wrap','padding-bottom','0','','','.b-form'),(38615,'watch-mobile','.b-info .info','padding-bottom','15','','','.b-info'),(38616,'watch-mobile','.b-info .info li','padding-bottom','0','','','.b-info'),(38617,'watch-mobile','.b-products-listing .in-cart','padding-bottom','4','','','.b-products-listing'),(38618,'watch-mobile','.b-products-listing .products-listing .btn-buy','padding-bottom','4','','','.b-products-listing'),(38619,'watch-mobile','.b-products-listing .products-listing .buyButton .btn','padding-bottom','4','','','.b-products-listing'),(38620,'watch-mobile','.b-products-listing .products-listing .compare','padding-bottom','6','','','.b-products-listing'),(38621,'watch-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-bottom','6','','','.b-products-listing'),(38622,'watch-mobile','.b-products-listing .products-listing a.btn.view-button','padding-bottom','6','','','.b-products-listing'),(38623,'watch-mobile','.b-products-listing .products-listing h2','padding-bottom','0','','','.b-products-listing'),(38624,'watch-mobile','.b-products-listing .promos-info .promo-item','padding-bottom','3','','','.b-products-listing'),(38625,'watch-mobile','.b-products-listing .promos-info .promo-name','padding-bottom','3','','','.b-products-listing'),(38626,'watch-mobile','.b-products-listing .list-productlisting div.BlockBox.item-holder','padding-bottom','25','','','.b-products-listing'),(38627,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.b-data-table'),(38628,'watch-mobile','.b-data-table table.dataTable thead td','padding-bottom','10','','','.b-data-table'),(38629,'watch-mobile','.b-data-table table.dataTable tbody td','padding-bottom','10','','','.b-data-table'),(38630,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom','0','','','.b-data-table'),(38631,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(38632,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(38633,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(38634,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(38635,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(38636,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(38637,'watch-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(38638,'watch-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(38639,'watch-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(38640,'watch-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(38641,'watch-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(38642,'watch-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(38643,'watch-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(38644,'watch-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(38645,'watch-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(38646,'watch-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(38647,'watch-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(38648,'watch-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(38649,'watch-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(38650,'watch-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(38651,'watch-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(38652,'watch-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(38653,'watch-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(38654,'watch-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(38655,'watch-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(38656,'watch-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(38657,'watch-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(38658,'watch-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(38659,'watch-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(38660,'watch-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(38661,'watch-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(38662,'watch-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(38663,'watch-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(38664,'watch-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(38665,'watch-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(38666,'watch-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(38667,'watch-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(38668,'watch-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(38669,'watch-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(38670,'watch-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(38671,'watch-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(38672,'watch-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(38673,'watch-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(38674,'watch-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(38675,'watch-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(38676,'watch-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(38677,'watch-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(38678,'watch-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(38679,'watch-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(38680,'watch-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(38681,'watch-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(38682,'watch-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(38683,'watch-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(38684,'watch-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(38685,'watch-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(38686,'watch-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(38687,'watch-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(38688,'watch-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(38689,'watch-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(38690,'watch-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(38691,'watch-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(38692,'watch-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(38693,'watch-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(38694,'watch-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(38695,'watch-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(38696,'watch-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(38697,'watch-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(38698,'watch-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(38699,'watch-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(38700,'watch-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(38701,'watch-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(38702,'watch-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(38703,'watch-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(38704,'watch-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(38705,'watch-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(38706,'watch-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(38707,'watch-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(38708,'watch-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(38709,'watch-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(38710,'watch-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(38711,'watch-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(38712,'watch-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(38713,'watch-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(38714,'watch-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(38715,'watch-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(38716,'watch-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(38717,'watch-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(38718,'watch-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(38719,'watch-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(38720,'watch-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(38721,'watch-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(38722,'watch-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(38723,'watch-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(38724,'watch-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(38725,'watch-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(38726,'watch-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(38727,'watch-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(38728,'watch-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(38729,'watch-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(38730,'watch-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(38731,'watch-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(38732,'watch-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(38733,'watch-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(38734,'watch-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(38735,'watch-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(38736,'watch-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(38737,'watch-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(38738,'watch-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(38739,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-bottom','0','','','.b-h-inline'),(38740,'watch-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-bottom','0','','','.b-menu-style'),(38741,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-bottom','5','','','.b-menu-style-1'),(38742,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-bottom','5','','','.b-menu-style-1'),(38743,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-bottom','20','','','.b-menu-style-1'),(38744,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-bottom','0','','','.b-menu-style-1'),(38745,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-bottom','5','','','.b-menu-style-2'),(38746,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-bottom','5','','','.b-menu-style-2'),(38747,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-bottom','0','','','.b-menu-style-2'),(38748,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-bottom','0','','','.b-menu-style-2'),(38749,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-bottom','10','','','.b-menu-style-2'),(38750,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-bottom','0','','','.b-menu-style-2'),(38751,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-bottom','5','','','.b-menu-style-2'),(38752,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-bottom','10','','','.b-menu-style-2'),(38753,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-bottom','5','','','.b-menu-style-2'),(38754,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-bottom','10','','','.b-menu-style-2'),(38755,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-bottom','5','','','.b-menu-style-3'),(38756,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','padding-bottom','5','','','.b-menu-style-3'),(38757,'watch-mobile','.b-messages .msv_btn','padding-bottom','12','','','.b-messages'),(38758,'watch-mobile','.b-messages .msv_content','padding-bottom','10','','','.b-messages'),(38759,'watch-mobile','.b-messages .msv_history','padding-bottom','10','','','.b-messages'),(38760,'watch-mobile','.b-messages .messMenuButton span','padding-bottom','10','','','.b-messages'),(38761,'watch-mobile','.b-messages .messages-menu ul','padding-bottom','0','','','.b-messages'),(38762,'watch-mobile','.b-messages .messages-menu li a','padding-bottom','8','','','.b-messages'),(38763,'watch-mobile','.b-messages .messages-menu li','padding-bottom','0','','','.b-messages'),(38764,'watch-mobile','.b-messages .content_management_attach button','padding-bottom','1','','','.b-messages'),(38765,'watch-mobile','.b-messages .email-heading','padding-bottom','15','','','.b-messages'),(38766,'watch-mobile','.b-messages .content_management_attach','padding-bottom','8','','','.b-messages'),(38767,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-bottom','5','','','.b-messages'),(38768,'watch-mobile','.b-messages .emailBtn','padding-bottom','10','','','.b-messages'),(38769,'watch-mobile','.b-messages .msv_to_cc','padding-bottom','10','','','.b-messages'),(38770,'watch-mobile','.b-messages .dataTables_wrapper > .bottom','padding-bottom','4','','','.b-messages'),(38771,'watch-mobile','.b-messages .emailLineTextArea textarea','padding-bottom','30','','','.b-messages'),(38772,'watch-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-bottom','20','','','.b-personal-catalog-popup'),(38773,'watch-mobile','.b-select-suggest .select2-container .select2-choice','padding-bottom','0','','','.b-select-suggest'),(38774,'watch-mobile','.b-select-suggest .select2-search input','padding-bottom','4','','','.b-select-suggest'),(38775,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(38776,'watch-mobile','.b-select-suggest .select2-drop-mask','padding-bottom','0','','','.b-select-suggest'),(38777,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-bottom','0','','','.b-select-suggest'),(38778,'watch-mobile','.b-select-suggest .select2-results','padding-bottom','0','','','.b-select-suggest'),(38779,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-bottom','0','','','.b-select-suggest'),(38780,'watch-mobile','.b-select-suggest .select2-locked','padding-bottom','3','','','.b-select-suggest'),(38781,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-bottom','0','','','.b-select-suggest'),(38782,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-bottom','5','','','.b-select-suggest'),(38783,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(38784,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','padding-bottom','4','','','.b-select-suggest'),(38785,'watch-mobile','.b-sub-totals .historyTotal td','padding-bottom','2','','','.b-sub-totals'),(38786,'watch-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(38787,'watch-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(38788,'watch-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(38789,'watch-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(38790,'watch-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(38791,'watch-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(38792,'watch-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(38793,'watch-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(38794,'watch-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(38795,'watch-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(38796,'watch-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(38797,'watch-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(38798,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(38799,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(38800,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(38801,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(38802,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(38803,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(38804,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(38805,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(38806,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(38807,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(38808,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(38809,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(38810,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(38811,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(38812,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(38813,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(38814,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(38815,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(38816,'watch-mobile','.b-trade-approval .steps-bar li a','padding-bottom','7','','','.b-trade-approval'),(38817,'watch-mobile','.b-trade-approval .middle-form','padding-bottom','20','','','.b-trade-approval'),(38818,'watch-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-bottom','5','','','.b-trade-approval'),(38819,'watch-mobile','.b-trade-approval .steps-bar','padding-bottom','0','','','.b-trade-approval'),(38820,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-bottom','6','','','.b-trade-approval'),(38821,'watch-mobile','.b-trade-approval .center-buttons','padding-bottom','20','','','.b-trade-approval'),(38822,'watch-mobile','.b-upload-file .upload-file-template','padding-bottom','25','','','.b-upload-file'),(38823,'watch-mobile','.b-upload-files .added-file','padding-bottom','5','','','.b-upload-files'),(38824,'watch-mobile','.b-upload-files .upload-files','padding-bottom','10','','','.b-upload-files'),(38825,'watch-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-bottom','20','','','.b-warehouses-popup'),(38826,'watch-mobile','.batchPr .w-batch-products .products-listing .image','padding-bottom','0','','','.batchPr'),(38827,'watch-mobile','.batchPr .w-batch-products','padding-bottom','0','','','.batchPr'),(38828,'watch-mobile','.batchPr > .block:nth-child(2)','padding-bottom','12','','','.batchPr'),(38829,'watch-mobile','.batchPr .w-batch-selected-products','padding-bottom','15','','','.batchPr'),(38830,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-bottom','0','','','.batchPr'),(38831,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-bottom','10','','','.batchPr'),(38832,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-bottom','0','','','.batchPr'),(38833,'watch-mobile','.batchPr ','padding-bottom','0','','','.batchPr'),(38834,'watch-mobile','.batchPr .batch-selected-products-empty','padding-bottom','10','','','.batchPr'),(38835,'watch-mobile','.batchPr .batch-selected-products-total','padding-bottom','10','','','.batchPr'),(38836,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-bottom','0','','','.batchPr'),(38837,'watch-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-bottom','15','','','.batchPr'),(38838,'watch-mobile','.batchPr .w-batch-products .products-listing .image','padding-bottom','10','','','.batchPr'),(38839,'watch-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(38840,'watch-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(38841,'watch-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(38842,'watch-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(38921,'watch-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(38922,'watch-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(38923,'watch-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(38924,'watch-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(38925,'watch-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(38926,'watch-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(38931,'watch-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-bottom','8','','','.p-quick-order-index'),(38932,'watch-mobile','.p-quick-order-index .bottom','padding-bottom','10','','','.p-quick-order-index'),(38933,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.p-quick-order-index'),(38934,'watch-mobile','.p-quick-order-index ul.token-input-list','padding-bottom','0','','','.p-quick-order-index'),(38935,'watch-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-bottom','7','','','.p-quick-order-index'),(38936,'watch-mobile','.p-quick-order-index .all-scroll-div','padding-bottom','10','','','.p-quick-order-index'),(38937,'watch-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(38938,'watch-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(38939,'watch-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(38940,'watch-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(38941,'watch-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(38942,'watch-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(38943,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(38944,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(38945,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(38946,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(38947,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(38948,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(38949,'watch-mobile','.w-account-address-book .item','padding-bottom','20','','','.w-account-address-book'),(38950,'watch-mobile','.w-account-address-book .wrap','padding-bottom','15','','','.w-account-address-book'),(38951,'watch-mobile','.w-account-address-book .btn-del','padding-bottom','0','','','.w-account-address-book'),(38952,'watch-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-bottom','20','','','.w-account-addresses-list'),(38953,'watch-mobile','.w-account-personal-catalog .list-switcher','padding-bottom','0','','','.w-account-personal-catalog'),(38954,'watch-mobile','.w-account-personal-catalog .list-switcher a','padding-bottom','12','','','.w-account-personal-catalog'),(38955,'watch-mobile','.w-account-subscription .subscription-variant','padding-bottom','10','','','.w-account-subscription'),(38956,'watch-mobile','.w-blog-widget-categories-list ','padding-bottom','25','','','.w-blog-widget-categories-list'),(38957,'watch-mobile','.w-blog-widget-most-popular-posts ','padding-bottom','20','','','.w-blog-widget-most-popular-posts'),(38958,'watch-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-bottom','10','','','.w-blog-widget-most-popular-posts'),(38959,'watch-mobile','.w-blog-widget-post-listing .post','padding-bottom','0','','','.w-blog-widget-post-listing'),(38960,'watch-mobile','.w-blog-widget-post-listing .post_content','padding-bottom','20','','','.w-blog-widget-post-listing'),(38961,'watch-mobile','.w-blog-widget-post-listing .post_date','padding-bottom','10','','','.w-blog-widget-post-listing'),(38962,'watch-mobile','.w-blog-widget-post-listing .post_name','padding-bottom','10','','','.w-blog-widget-post-listing'),(38963,'watch-mobile','.w-blog-widget-post-listing .post','padding-bottom','0','','','.w-blog-widget-post-listing'),(38964,'watch-mobile','.w-blog-widget-post-title h1','padding-bottom','0','','','.w-blog-widget-post-title'),(38965,'watch-mobile','.w-blog-widget-post-title ','padding-bottom','20','','','.w-blog-widget-post-title'),(38966,'watch-mobile','.w-blog-widget-related-posts .post','padding-bottom','0','','','.w-blog-widget-related-posts'),(38967,'watch-mobile','.w-blog-widget-related-posts .post_content a','padding-bottom','20','','','.w-blog-widget-related-posts'),(38968,'watch-mobile','.w-blog-widget-related-posts ','padding-bottom','20','','','.w-blog-widget-related-posts'),(38969,'watch-mobile','.w-blog-widget-related-posts-by-category .post','padding-bottom','0','','','.w-blog-widget-related-posts-by-category'),(38970,'watch-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-bottom','20','','','.w-blog-widget-related-posts-by-category'),(38971,'watch-mobile','.w-blog-widget-tag-cloud ','padding-bottom','25','','','.w-blog-widget-tag-cloud'),(38972,'watch-mobile','.w-blog-widget-tag-cloud a','padding-bottom','10','','','.w-blog-widget-tag-cloud'),(38973,'watch-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-bottom','0','','','.w-cart-cart-tabs'),(38974,'watch-mobile','.w-cart-compare .attributes-label','padding-bottom','10','','','.w-cart-compare'),(38975,'watch-mobile','.w-cart-compare .cart-cell','padding-bottom','20','','','.w-cart-compare'),(38976,'watch-mobile','.w-cart-compare .price-cell','padding-bottom','8','','','.w-cart-compare'),(38977,'watch-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-bottom','5','','','.w-cart-compare'),(38978,'watch-mobile','.w-cart-compare .price-label','padding-bottom','10','','','.w-cart-compare'),(38979,'watch-mobile','.w-cart-compare .delete-cart','padding-bottom','10','','','.w-cart-compare'),(38980,'watch-mobile','.w-cart-compare .attributes-cell','padding-bottom','8','','','.w-cart-compare'),(38981,'watch-mobile','.w-cart-compare .product-actions','padding-bottom','0','','','.w-cart-compare'),(38982,'watch-mobile','.w-cart-compare .product','padding-bottom','10','','','.w-cart-compare'),(38983,'watch-mobile','.w-cart-compare .product-label','padding-bottom','15','','','.w-cart-compare'),(38984,'watch-mobile','.w-cart-compare .dropdown li','padding-bottom','5','','','.w-cart-compare'),(38985,'watch-mobile','.w-cart-up-sell .w-list-type-1','padding-bottom','0','','','.w-cart-up-sell'),(38986,'watch-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','0','1','','.w-cart-up-sell'),(38987,'watch-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','1','','','.w-cart-up-sell'),(38988,'watch-mobile','.w-catalog-additional-images li','padding-bottom','10','','','.w-catalog-additional-images'),(38989,'watch-mobile','.w-catalog-additional-images ul','padding-bottom','0','','','.w-catalog-additional-images'),(38990,'watch-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-bottom','5','','','.w-catalog-b2b-add-button'),(38991,'watch-mobile','.w-catalog-compare td','padding-bottom','10','','','.w-catalog-compare'),(38992,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-bottom','0','','','.w-catalog-compare'),(38993,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','padding-bottom','11','2','','.w-catalog-compare'),(38994,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','padding-bottom','10','','','.w-catalog-compare'),(38995,'watch-mobile','.w-catalog-paging .paging-item','padding-bottom','0','','','.w-catalog-paging'),(38996,'watch-mobile','.w-checkout-billing-address .same-address','padding-bottom','10','','','.w-checkout-billing-address'),(38997,'watch-mobile','.w-checkout-billing-address .edit-ab','padding-bottom','0','','','.w-checkout-billing-address'),(38998,'watch-mobile','.w-checkout-create-account .create-account','padding-bottom','10','','','.w-checkout-create-account'),(38999,'watch-mobile','.w-checkout-gdpr .privacy-row','padding-bottom','0','','','.w-checkout-gdpr'),(39000,'watch-mobile','.w-checkout-gdpr .terms-login','padding-bottom','0','','','.w-checkout-gdpr'),(39001,'watch-mobile','.w-checkout-shipping .sub-item','padding-bottom','5','','','.w-checkout-shipping'),(39002,'watch-mobile','.w-checkout-shipping-address .edit-ab','padding-bottom','0','','','.w-checkout-shipping-address'),(39003,'watch-mobile','.w-checkout-shipping-choice #shippingchoice-choice','padding-bottom','7','','','.w-checkout-shipping-choice'),(39004,'watch-mobile','.w-checkout-shipping-choice span','padding-bottom','4','','','.w-checkout-shipping-choice'),(39005,'watch-mobile','.w-checkout-shipping-choice span','padding-bottom','4','','','.w-checkout-shipping-choice'),(39006,'watch-mobile','.w-checkout-terms .required-message','padding-bottom','5','','','.w-checkout-terms'),(39007,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-bottom','5','','','.w-communication-new-topic'),(39008,'watch-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-bottom','0','','','.w-communication-new-topic'),(39009,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-bottom','5','','','.w-communication-new-topic'),(39010,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-bottom','0','','','.w-communication-new-topic'),(39011,'watch-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-bottom','10','','','.w-communication-new-topic'),(39012,'watch-mobile','.w-communication-post .communication-post','padding-bottom','5','','','.w-communication-post'),(39013,'watch-mobile','.w-communication-post .communication-post-author','padding-bottom','10','','','.w-communication-post'),(39014,'watch-mobile','.w-delivery-day .left-count','padding-bottom','0','','','.w-delivery-day'),(39015,'watch-mobile','.w-delivery-day .left-text-left','padding-bottom','24','','','.w-delivery-day'),(39016,'watch-mobile','.w-delivery-day .left-text-right','padding-bottom','24','','','.w-delivery-day'),(39017,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-bottom','10','','','.w-image-maps'),(39018,'watch-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-bottom','3','','','.w-multi-cart-actions'),(39019,'watch-mobile','.w-personal-gift-status-bar .inform','padding-bottom','0','4','','.w-personal-gift-status-bar'),(39020,'watch-mobile','.w-personal-gift-status-bar .end-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(39021,'watch-mobile','.w-personal-gift-status-bar .end-date','padding-bottom','0','3','','.w-personal-gift-status-bar'),(39022,'watch-mobile','.w-personal-gift-status-bar .start-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(39023,'watch-mobile','.w-personal-gift-status-bar .timeline','padding-bottom','16','','','.w-personal-gift-status-bar'),(39024,'watch-mobile','.w-product-available-in-warehouses .warehouse-item','padding-bottom','20','','','.w-product-available-in-warehouses'),(39025,'watch-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(39026,'watch-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(39027,'watch-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(39028,'watch-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(39029,'watch-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(39030,'watch-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(39031,'watch-mobile','.w-product-customers-activity .customers-activity','padding-bottom','20','','','.w-product-customers-activity'),(39032,'watch-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(39033,'watch-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(39034,'watch-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(39035,'watch-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(39036,'watch-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(39037,'watch-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(39038,'watch-mobile','.w-promotions .nextdiscount .promo-for-each','padding-bottom','2','','','.w-promotions'),(39039,'watch-mobile','.w-promotions .nextdiscount .content > div','padding-bottom','10','','','.w-promotions'),(39040,'watch-mobile','.w-promotions .promo-cart-discount .master .item','padding-bottom','20','','','.w-promotions'),(39041,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-bottom','0','','','.w-promotions'),(39042,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-bottom','0','','','.w-promotions'),(39043,'watch-mobile','.w-promotions .promo-cart-discount .slave .item','padding-bottom','20','','','.w-promotions'),(39044,'watch-mobile','.w-promotions .promo-cart-discount .slave .heading','padding-bottom','1','','','.w-promotions'),(39045,'watch-mobile','.w-promotions .promo-salemaker .discount','padding-bottom','0','','','.w-promotions'),(39046,'watch-mobile','.w-promotions .promo-item','padding-bottom','20','','','.w-promotions'),(39047,'watch-mobile','.w-promotions .promo-salemaker .item','padding-bottom','20','','','.w-promotions'),(39048,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','padding-bottom','0','','','.w-promotions'),(39049,'watch-mobile','.w-promotions .prom-multi-discount .promo-product','padding-bottom','20','','','.w-promotions'),(39050,'watch-mobile','.w-quote-products .empty','padding-bottom','100','','','.w-quote-products'),(39051,'watch-mobile','.w-reviews-content .review','padding-bottom','10','','','.w-reviews-content'),(39052,'watch-mobile','.w-reviews-content .product-name','padding-bottom','20','','','.w-reviews-content'),(39053,'watch-mobile','.w-reviews-content .item','padding-bottom','25','','','.w-reviews-content'),(39054,'watch-mobile','.w-reviews-content .author','padding-bottom','20','','','.w-reviews-content'),(39055,'watch-mobile','.w-reviews-content .rating','padding-bottom','10','','','.w-reviews-content'),(39056,'watch-mobile','.w-sitemap-delivery-location > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(39057,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(39058,'watch-mobile','.w-top-text .top-text','padding-bottom','5','','','.w-top-text'),(39059,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-bottom','17','','','.w-wedding-registry-widgets-photos'),(39060,'watch-mobile','.b-quantity .qty-box input[type=\'text\']','padding-bottom','5','','','.b-quantity'),(39061,'watch-mobile','.w-filters .filter-box-content ul','padding-bottom','20','','','.w-filters'),(39062,'watch-mobile','.p-blog-index .comment-list','padding-bottom_important','important','','','.p-blog-index'),(39063,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom_important','important','','','.b-data-table'),(39064,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom_important','important','','','.b-data-table'),(39065,'watch-mobile','.b-data-table table.dataTable thead td','padding-bottom_important','important','','','.b-data-table'),(39066,'watch-mobile','.b-data-table table.dataTable tbody td','padding-bottom_important','important','','','.b-data-table'),(39067,'watch-mobile','.batchPr .w-batch-products','padding-bottom_important','important','','','.batchPr'),(39068,'watch-mobile','.w-list-type-1_3 .item','padding-left','0','','','.w-list-type-1_3'),(39069,'watch-mobile','.w-list-type-1_3 .compare-box-item','padding-left','7','','','.w-list-type-1_3'),(39070,'watch-mobile','.w-list-type-1_3 .item','padding-left','0','1','','.w-list-type-1_3'),(39071,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','padding-left','15','','','.w-list-type-2'),(39072,'watch-mobile','.w-list-type-1_2.products-listing','padding-left','20','','','.w-list-type-1_2'),(39073,'watch-mobile','.w-list-type-2 .compare-box-item','padding-left','7','','','.w-list-type-2'),(39074,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','padding-left','15','','','.w-list-type-1_3'),(39075,'watch-mobile','.w-list-type-2_2.products-listing','padding-left','20','','','.w-list-type-2_2'),(39076,'watch-mobile','.w-list-type-2 .item','padding-left','21','','','.w-list-type-2'),(39077,'watch-mobile','.w-list-type-2.products-listing','padding-left','20','','','.w-list-type-2'),(39078,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','padding-left','15','','','.w-list-type-2_2'),(39079,'watch-mobile','.w-list-type-2 .item','padding-left','20','1','','.w-list-type-2'),(39080,'watch-mobile','.w-list-type-2_2 .compare-box-item','padding-left','7','','','.w-list-type-2_2'),(39081,'watch-mobile','.w-list-type-3.products-listing','padding-left','20','','','.w-list-type-3'),(39082,'watch-mobile','.w-menu .hided.menu ul li','padding-left','0','','','.w-menu'),(39083,'watch-mobile','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(39084,'watch-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-left','0','','','.w-menu'),(39085,'watch-mobile','.w-menu-slider > ul > li > a','padding-left','10','','','.w-menu-slider'),(39086,'watch-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','','','.w-menu-horizontal'),(39087,'watch-mobile','.w-menu-big ul','padding-left','0','','','.w-menu-big'),(39088,'watch-mobile','.w-menu-horizontal > ul > li > ul > li','padding-left','10','','','.w-menu-horizontal'),(39089,'watch-mobile','.w-menu-slider > ul > li > ul > li','padding-left','10','','','.w-menu-slider'),(39090,'watch-mobile','.w-menu-slider ul, .w-menu-slider li','padding-left','0','','','.w-menu-slider'),(39091,'watch-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','','','.w-menu-style-1'),(39092,'watch-mobile','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(39093,'watch-mobile','.w-top-categories .item','padding-left','10','290','','.w-top-categories'),(39094,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(39095,'watch-mobile','.b-bottom .popup-simple','padding-left','20','','','.b-bottom'),(39096,'watch-mobile','.b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .buttons','padding-left','10','','','.b-cookie-notice'),(39097,'watch-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.bottom .text','padding-left','10','','','.b-cookie-notice'),(39098,'watch-mobile','.w-login-block .new','padding-left','40','','','.w-login-block'),(39099,'watch-mobile','.w-login-block .guest','padding-left','40','','','.w-login-block'),(39100,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-left','20','','','.w-menu-style-1'),(39101,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','','','.w-menu-style-1'),(39102,'watch-mobile','.w-sale .holder-2','padding-left','20','','','.w-sale'),(39103,'watch-mobile','.w-product-wedding-registry-button .btn','padding-left','40','','','.w-product-wedding-registry-button'),(39104,'watch-mobile','.w-reviews .review','padding-left','10','','','.w-reviews'),(39105,'watch-mobile','.w-sale .left-count','padding-left','5','','','.w-sale'),(39106,'watch-mobile','.w-filters .head-filter-widget','padding-left','0','','','.w-filters'),(39107,'watch-mobile','.w-currencies .select-link','padding-left','10','','','.w-currencies'),(39108,'watch-mobile','.w-filters .filter-ul-content','padding-left','0','','','.w-filters'),(39109,'watch-mobile','.w-categories .name','padding-left','3','','','.w-categories'),(39110,'watch-mobile','.w-currencies .current','padding-left','10','','','.w-currencies'),(39111,'watch-mobile','.w-categories .image','padding-left','0','','','.w-categories'),(39112,'watch-mobile','.w-currencies .currencies-title','padding-left','4','','','.w-currencies'),(39113,'watch-mobile','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(39114,'watch-mobile','.w-cart .no-text','padding-left','10','','','.w-cart'),(39115,'watch-mobile','.w-cart .qty','padding-left','5','4','','.w-cart'),(39128,'watch-mobile','.b-bottom .popup-buttons','padding-left','15','','','.b-bottom'),(39129,'watch-mobile','.w-cart-checkout-btn a','padding-left','12','290','','.w-cart-checkout-btn'),(39130,'watch-mobile','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(39131,'watch-mobile','.w-quote .no-text','padding-left','10','','','.w-quote'),(39132,'watch-mobile','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(39133,'watch-mobile','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(39134,'watch-mobile','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(39135,'watch-mobile','.w-product-images .img-holder','padding-left','20','','','.w-product-images'),(39136,'watch-mobile','.b-compare .compare_pagination','padding-left','0','','','.b-compare'),(39137,'watch-mobile','.p-blog-index .comments-area ol ol','padding-left','20','315','','.p-blog-index'),(39138,'watch-mobile','.header2 .ccc','padding-left','10','','',''),(39139,'watch-mobile','.w-promo-code .holder','padding-left','20','320','','.w-promo-code'),(39140,'watch-mobile','.w-sale .holder-1','padding-left','20','','','.w-sale'),(39143,'watch-mobile','.w-search .search-input','padding-left','10','','','.w-search'),(39144,'watch-mobile','.w-search .items-title','padding-left','0','','','.w-search'),(39145,'watch-mobile','.w-socials > li','padding-left','15','','','.w-socials'),(39146,'watch-mobile','.b-info-popup .info-popup div','padding-left','15','','','.b-info-popup'),(39147,'watch-mobile','.w-menu .hided.menu li li a','padding-left','40','317','','.w-menu'),(39148,'watch-mobile','.w-menu .hided.menu li li li a','padding-left','60','317','','.w-menu'),(39149,'watch-mobile','.w-menu .hided.menu li a','padding-left','20','317','','.w-menu'),(39150,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-left','0','','','.b-multi-page-checkout'),(39151,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-left','10','','','.b-multi-page-checkout'),(39152,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-left','10','','','.b-multi-page-checkout'),(39154,'watch-mobile','.w-promo-code .heading-4','padding-left','30','320','','.w-promo-code'),(39155,'watch-mobile','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(39156,'watch-mobile','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(39157,'watch-mobile','.p-wedding-registry-manage a.remove-btn','padding-left','5','','','.p-wedding-registry-manage'),(39164,'watch-mobile','.testimonials .answer','padding-left','30','','',''),(39165,'watch-mobile','.w-product-configurator .pc_item','padding-left','0','299','','.w-product-configurator'),(39167,'watch-mobile','.w-product-configurator .pc_attr','padding-left','0','290','','.w-product-configurator'),(39168,'watch-mobile','.w-filters .head-filter-widget','padding-left','10','317','','.w-filters'),(39169,'watch-mobile','.testimonials .heading-3','padding-left','55','','',''),(39170,'watch-mobile','.b-pagination .pagination span','padding-left','5','2','','.b-pagination'),(39171,'watch-mobile','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(39172,'watch-mobile','.testimonials .review','padding-left','10','','',''),(39173,'watch-mobile','.b-pagination .pagination .page-number','padding-left','5','','','.b-pagination'),(39174,'watch-mobile','.b-pagination .pagination .prev-pages','padding-left','5','','','.b-pagination'),(39175,'watch-mobile','.b-pagination .pagination .prev','padding-left','5','','','.b-pagination'),(39176,'watch-mobile','.b-bottom .confirm-popup .confirm-text','padding-left','0','','','.b-bottom'),(39177,'watch-mobile','.b-pagination .pagination .next-pages','padding-left','5','','','.b-pagination'),(39178,'watch-mobile','.b-pagination .pagination .next','padding-left','5','','','.b-pagination'),(39183,'watch-mobile','.btn-2','padding-left','25','','',''),(39186,'watch-mobile','.p-blog-index .nav-previous','padding-left','50','','','.p-blog-index'),(39188,'watch-mobile','.btn','padding-left','12','','',''),(39189,'watch-mobile','.btn-1','padding-left','25','','',''),(39190,'watch-mobile','.p-blog-index .comments-area ol ol','padding-left','50','','','.p-blog-index'),(39191,'watch-mobile','.btn-3','padding-left','25','','',''),(39192,'watch-mobile','.w-product-personal-catalog-button .btn','padding-left','25','','','.w-product-personal-catalog-button'),(39193,'watch-mobile','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(39194,'watch-mobile','.w-account ul, .w-account li','padding-left','0','','','.w-account'),(39195,'watch-mobile','.b-fancybox .fancybox-error','padding-left','15','','','.b-fancybox'),(39196,'watch-mobile','.w-menu-horizontal ul','padding-left','0','','','.w-menu-horizontal'),(39197,'watch-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(39198,'watch-mobile','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(39199,'watch-mobile','.w-chat .w-chat-box','padding-left','12','','','.w-chat'),(39200,'watch-mobile','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(39201,'watch-mobile','.p-wedding-registry-index .main-button','padding-left','20','4','','.p-wedding-registry-index'),(39202,'watch-mobile','.p-wedding-registry-index .main-content','padding-left','0','','','.p-wedding-registry-index'),(39203,'watch-mobile','.p-wedding-registry-index .middle-box','padding-left','10','','','.p-wedding-registry-index'),(39204,'watch-mobile','.p-wedding-registry-index .main-button','padding-left','20','3','','.p-wedding-registry-index'),(39205,'watch-mobile','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(39206,'watch-mobile','.b-form .form-buttons','padding-left','0','','','.b-form'),(39207,'watch-mobile','.b-bottom .alert-message','padding-left','20','','','.b-bottom'),(39208,'watch-mobile','.p-wedding-registry-manage .links','padding-left','10','','','.p-wedding-registry-manage'),(39209,'watch-mobile','.p-wedding-registry-share .middle-form > input','padding-left','0','','','.p-wedding-registry-share'),(39210,'watch-mobile','.p-wedding-registry-manage .links a','padding-left','10','','','.p-wedding-registry-manage'),(39211,'watch-mobile','.p-wedding-registry-manage .links a.share-registry','padding-left','40','','','.p-wedding-registry-manage'),(39212,'watch-mobile','.b-table .table td','padding-left','15','','','.b-table'),(39213,'watch-mobile','.b-table .table .headings td','padding-left','10','','','.b-table'),(39214,'watch-mobile','.b-pagination .pagination a','padding-left','5','','','.b-pagination'),(39224,'watch-mobile','.b-compare .col-gender','padding-left','0','','','.b-compare'),(39225,'watch-mobile','.b-bottom .popup-heading','padding-left','15','','','.b-bottom'),(39226,'watch-mobile','.b-bottom .popup-content','padding-left','15','','','.b-bottom'),(39227,'watch-mobile','.b-compare .col-two label','padding-left','0','','','.b-compare'),(39228,'watch-mobile','.b-compare .compare-head','padding-left','10','','','.b-compare'),(39229,'watch-mobile','.b-compare .compare-box-item','padding-left','10','','','.b-compare'),(39230,'watch-mobile','.b-compare .column_wrapper','padding-left','10','','','.b-compare'),(39231,'watch-mobile','.w-languages .current','padding-left','10','299','','.w-languages'),(39232,'watch-mobile','.w-quote .cart-box-link','padding-left','14','299','','.w-quote'),(39233,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','padding-left','5','','','.b-switch'),(39234,'watch-mobile','.w-languages .lang-link','padding-left','10','299','','.w-languages'),(39235,'watch-mobile','.w-tabs .accordion-heading','padding-left','6','','','.w-tabs'),(39236,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-left','0','','','.b-slick'),(39238,'watch-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','303','','.w-menu-style-1'),(39239,'watch-mobile','.w-currencies .select-link','padding-left','10','299','','.w-currencies'),(39240,'watch-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','299','','.w-menu-horizontal'),(39241,'watch-mobile','.w-currencies .current','padding-left','10','299','','.w-currencies'),(39242,'watch-mobile','.b-slick button.slick-next','padding-left','4','3','','.b-slick'),(39243,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-left','18','303','','.w-list-type-1'),(39244,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','303','','.w-menu-style-1'),(39245,'watch-mobile','.b-bottom .footerTitle','padding-left','0','290','','.b-bottom'),(39249,'watch-mobile','.w-top-categories .name','padding-left','3','','','.w-top-categories'),(39250,'watch-mobile','.w-cart .cart-total','padding-left','0','','','.w-cart'),(39251,'watch-mobile','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(39252,'watch-mobile','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(39253,'watch-mobile','.w-breadcrumb .breadcrumb-li','padding-left','0','','','.w-breadcrumb'),(39254,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','padding-left','15','','','.w-list-type-1_2'),(39255,'watch-mobile','.w-bestsellers .heading-3','padding-left','55','','','.w-bestsellers'),(39256,'watch-mobile','.w-account a.my-acc-link','padding-left','17','','','.w-account'),(39257,'watch-mobile','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(39258,'watch-mobile','.w-tabs .tab-navigation','padding-left','0','','','.w-tabs'),(39259,'watch-mobile','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block','padding-left','10','292','',''),(39260,'watch-mobile','.w-top-categories .image','padding-left','0','','','.w-top-categories'),(39261,'watch-mobile','.p-account-trade-form .trade-form-area','padding-left','20','','','.p-account-trade-form'),(39262,'watch-mobile','.p-account-trade-form .widget','padding-left','0','','','.p-account-trade-form'),(39263,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-left','10','','','.p-blog-index'),(39264,'watch-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-left','0','','','.p-blog-index'),(39265,'watch-mobile','.p-blog-index .wp-widget li','padding-left','15','','','.p-blog-index'),(39267,'watch-mobile','.p-blog-index .nav-links','padding-left','0','','','.p-blog-index'),(39269,'watch-mobile','.p-quote-cart-index .cart-popup .cart-page, .p-quote-cart-index .cart-popup .wishlist-page','padding-left','20','','','.p-quote-cart-index'),(39270,'watch-mobile','.p-blog-index .wp-widget ul','padding-left','0','','','.p-blog-index'),(39272,'watch-mobile','.p-reviews-info .review-info-image','padding-left','20','','','.p-reviews-info'),(39273,'watch-mobile','.p-reviews-info .review-info-content','padding-left','20','','','.p-reviews-info'),(39274,'watch-mobile','.p-reviews-info .review-info-text','padding-left','10','','','.p-reviews-info'),(39275,'watch-mobile','.p-reviews-info .reviews-info .buttons','padding-left','0','','','.p-reviews-info'),(39276,'watch-mobile','.p-shopping-cart-index .cart-popup .cart-page, .p-shopping-cart-index .cart-popup .wishlist-page','padding-left','20','','','.p-shopping-cart-index'),(39280,'watch-mobile','.w-product-images .images','padding-left','0','320','','.w-product-images'),(39281,'watch-mobile','.b-bottom .popup-box-wrap','padding-left','10','','','.b-bottom'),(39282,'watch-mobile','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(39283,'watch-mobile','.b-slick .slick-vertical button.slick-prev','padding-left','0','3','','.b-slick'),(39284,'watch-mobile','.b-slick .slick-vertical button.slick-next','padding-left','0','3','','.b-slick'),(39285,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-left','20','','','.b-fancybox'),(39286,'watch-mobile','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(39287,'watch-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-left','10','','','.p-account-subscription-historyinfo'),(39288,'watch-mobile','.w-product-configurator .pc_item','padding-left','0','','','.w-product-configurator'),(39292,'watch-mobile','.w-list-type-1 .item','padding-left','5','','','.w-list-type-1'),(39293,'watch-mobile','.w-list-type-1 .compare-box-item','padding-left','7','','','.w-list-type-1'),(39294,'watch-mobile','.w-list-type-1_2 .compare-box-item','padding-left','7','','','.w-list-type-1_2'),(39295,'watch-mobile','.w-languages .lang-link','padding-left','10','','','.w-languages'),(39296,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-left','15','','','.w-list-type-1'),(39297,'watch-mobile','.w-filters .fsl_handle','padding-left','0','','','.w-filters'),(39298,'watch-mobile','.w-filters .ui-slider-range','padding-left','0','','','.w-filters'),(39299,'watch-mobile','.w-languages .current','padding-left','10','','','.w-languages'),(39300,'watch-mobile','.b-fancybox .fancybox-title-over-wrap','padding-left','10','','','.b-fancybox'),(39301,'watch-mobile','.b-fancybox .fancybox-next span','padding-left','4','3','','.b-fancybox'),(39302,'watch-mobile','.w-categories .item','padding-left','20','','','.w-categories'),(39303,'watch-mobile','.w-cart a.item','padding-left','90','','','.w-cart'),(39304,'watch-mobile','.w-cart .cart-content','padding-left','15','','','.w-cart'),(39305,'watch-mobile','.w-cart .cart-box-link','padding-left','14','','','.w-cart'),(39306,'watch-mobile','.b-compare .popupCompare .pop-up-content','padding-left','10','','','.b-compare'),(39307,'watch-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(39308,'watch-mobile','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(39309,'watch-mobile','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(39310,'watch-mobile','.w-quote .cart-box-link','padding-left','10','','','.w-quote'),(39311,'watch-mobile','.w-product-reviews .reviews-list .review','padding-left','10','','','.w-product-reviews'),(39312,'watch-mobile','.w-product-sale-ends .left-count','padding-left','5','','','.w-product-sale-ends'),(39313,'watch-mobile','.w-reviews .heading-3','padding-left','55','','','.w-reviews'),(39314,'watch-mobile','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(39315,'watch-mobile','.w-product-properties li','padding-left','0','','','.w-product-properties'),(39316,'watch-mobile','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(39317,'watch-mobile','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(39318,'watch-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(39319,'watch-mobile','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(39320,'watch-mobile','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(39321,'watch-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(39322,'watch-mobile','.w-menu-style-1 ul','padding-left','0','','','.w-menu-style-1'),(39323,'watch-mobile','.w-tabs .accordion-heading','padding-left','8','290','','.w-tabs'),(39324,'watch-mobile','.w-text .customer-service','padding-left','30','','','.w-text'),(39325,'watch-mobile','.w-categories .categories h2','padding-left','0','','','.w-categories'),(39326,'watch-mobile','.w-top-categories .categories h2','padding-left','0','','','.w-top-categories'),(39327,'watch-mobile','.w-banner .carousel-text > span','padding-left','20','','','.w-banner'),(39328,'watch-mobile','.b-slick .slick-list','padding-left','0','','','.b-slick'),(39329,'watch-mobile','.w-tabs .tab-li','padding-left','0','','','.w-tabs'),(39330,'watch-mobile','.w-tabs .tab-a','padding-left','6','','','.w-tabs'),(39331,'watch-mobile','.w-list-type-1 ','padding-left','0','','','.w-list-type-1'),(39332,'watch-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-left','10','','','.w-menu-horizontal'),(39335,'watch-mobile','.w-categories .item','padding-left','10','290','','.w-categories'),(39336,'watch-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-left','0','','','.b-fancybox'),(39337,'watch-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-left','0','','','.b-fancybox'),(39338,'watch-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-left','6','','','.b-compare'),(39339,'watch-mobile','.b-compare .popupCompare td.level-3:first-child','padding-left','18','','','.b-compare'),(39340,'watch-mobile','.b-compare .popupCompare td.level-2:first-child','padding-left','12','','','.b-compare'),(39341,'watch-mobile','.w-cart-give-away .ga_img','padding-left','1','','','.w-cart-give-away'),(39343,'watch-mobile','.b-autocomplete .ui-autocomplete','padding-left','0','','','.b-autocomplete'),(39344,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','padding-left','10','','',''),(39345,'watch-mobile','textarea','padding-left','10','','',''),(39346,'watch-mobile','.b-autocomplete .ui-autocomplete li','padding-left','10','','','.b-autocomplete'),(39347,'watch-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-left','20','','','.b-bottom'),(39348,'watch-mobile','.b-bottom .pop-up-close','padding-left','1','','','.b-bottom'),(39349,'watch-mobile','.b-bottom .pop-up-info','padding-left','20','','','.b-bottom'),(39350,'watch-mobile','.b-form .addresses .address-item span','padding-left','5','','','.b-form'),(39351,'watch-mobile','.b-form .center-buttons','padding-left','0','','','.b-form'),(39352,'watch-mobile','.w-reviews .reviews','padding-left','10','','','.w-reviews'),(39353,'watch-mobile','.w-top-categories .item','padding-left','20','','','.w-top-categories'),(39354,'watch-mobile','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-left','10','292','',''),(39355,'watch-mobile','.b-form .payment-method .item-radio label span','padding-left','5','','','.b-form'),(39356,'watch-mobile','.b-form .payment-method .item-radio label','padding-left','5','','','.b-form'),(39357,'watch-mobile','.b-form .middle-form','padding-left','0','','','.b-form'),(39358,'watch-mobile','.b-form .required-message-wrap','padding-left','0','','','.b-form'),(39359,'watch-mobile','.b-form .required-message','padding-left','3','','','.b-form'),(39361,'watch-mobile','.b-form .shipping-method .input','padding-left','10','','','.b-form'),(39362,'watch-mobile','.b-info .info','padding-left','40','','','.b-info'),(39363,'watch-mobile','.b-info .info ul','padding-left','0','','','.b-info'),(39364,'watch-mobile','.b-info .info li','padding-left','0','','','.b-info'),(39366,'watch-mobile','.b-products-listing .in-cart','padding-left','10','','','.b-products-listing'),(39367,'watch-mobile','.b-products-listing .products-listing .bonus-points-cost','padding-left','20','','','.b-products-listing'),(39368,'watch-mobile','.b-products-listing .products-listing .bonus-points-price','padding-left','20','','','.b-products-listing'),(39369,'watch-mobile','.b-products-listing .products-listing .btn-buy','padding-left','10','','','.b-products-listing'),(39370,'watch-mobile','.b-products-listing .products-listing .buyButton .btn','padding-left','10','','','.b-products-listing'),(39371,'watch-mobile','.b-products-listing .products-listing .compare','padding-left','6','','','.b-products-listing'),(39372,'watch-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-left','2','','','.b-products-listing'),(39373,'watch-mobile','.b-products-listing .products-listing a.btn.view-button','padding-left','0','','','.b-products-listing'),(39374,'watch-mobile','.b-products-listing .products-listing h2','padding-left','0','','','.b-products-listing'),(39375,'watch-mobile','.b-products-listing .promos-info .promo-item','padding-left','0','','','.b-products-listing'),(39376,'watch-mobile','.b-products-listing .promos-info .promo-name','padding-left','15','','','.b-products-listing'),(39377,'watch-mobile','.b-products-listing .list-productlisting div.BlockBox.item-holder','padding-left','10','','','.b-products-listing'),(39378,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.b-data-table'),(39379,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.b-data-table'),(39380,'watch-mobile','.b-data-table table.dataTable thead td','padding-left','20','','','.b-data-table'),(39381,'watch-mobile','.b-data-table table.dataTable tbody td','padding-left','20','','','.b-data-table'),(39382,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(39383,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(39384,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(39385,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(39386,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(39387,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(39388,'watch-mobile','.b-email .model','padding-left','10','','','.b-email'),(39389,'watch-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(39390,'watch-mobile','.b-email .price','padding-left','10','','','.b-email'),(39391,'watch-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(39392,'watch-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(39393,'watch-mobile','.b-email .image','padding-left','10','','','.b-email'),(39394,'watch-mobile','.b-email .price','padding-left','10','','','.b-email'),(39395,'watch-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(39396,'watch-mobile','.b-email .model','padding-left','10','','','.b-email'),(39397,'watch-mobile','.b-email .qty','padding-left','10','','','.b-email'),(39398,'watch-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(39399,'watch-mobile','.b-email .image','padding-left','10','','','.b-email'),(39400,'watch-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(39401,'watch-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(39402,'watch-mobile','.b-email .price','padding-left','10','','','.b-email'),(39403,'watch-mobile','.b-email .image','padding-left','10','','','.b-email'),(39404,'watch-mobile','.b-email .model','padding-left','10','','','.b-email'),(39405,'watch-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(39406,'watch-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(39407,'watch-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(39408,'watch-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(39409,'watch-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(39410,'watch-mobile','.b-email .model','padding-left','10','','','.b-email'),(39411,'watch-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(39412,'watch-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(39413,'watch-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(39414,'watch-mobile','.b-email .name','padding-left','10','','','.b-email'),(39415,'watch-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(39416,'watch-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(39417,'watch-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(39418,'watch-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(39419,'watch-mobile','.b-email .name','padding-left','10','','','.b-email'),(39420,'watch-mobile','.b-email .model','padding-left','10','','','.b-email'),(39421,'watch-mobile','.b-email .name','padding-left','10','','','.b-email'),(39422,'watch-mobile','.b-email .qty','padding-left','10','','','.b-email'),(39423,'watch-mobile','.b-email .image','padding-left','10','','','.b-email'),(39424,'watch-mobile','.b-email .name','padding-left','10','','','.b-email'),(39425,'watch-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(39426,'watch-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(39427,'watch-mobile','.b-email .qty','padding-left','10','','','.b-email'),(39428,'watch-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(39429,'watch-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(39430,'watch-mobile','.b-email .name','padding-left','10','','','.b-email'),(39431,'watch-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(39432,'watch-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(39433,'watch-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(39434,'watch-mobile','.b-email .model','padding-left','10','','','.b-email'),(39435,'watch-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(39436,'watch-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(39437,'watch-mobile','.b-email .name','padding-left','10','','','.b-email'),(39438,'watch-mobile','.b-email .qty','padding-left','10','','','.b-email'),(39439,'watch-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(39440,'watch-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(39441,'watch-mobile','.b-email .image','padding-left','10','','','.b-email'),(39442,'watch-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(39443,'watch-mobile','.b-email .image','padding-left','10','','','.b-email'),(39444,'watch-mobile','.b-email .price','padding-left','10','','','.b-email'),(39445,'watch-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(39446,'watch-mobile','.b-email .qty','padding-left','10','','','.b-email'),(39447,'watch-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(39448,'watch-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(39449,'watch-mobile','.b-email .price','padding-left','10','','','.b-email'),(39450,'watch-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(39451,'watch-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(39452,'watch-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(39453,'watch-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(39454,'watch-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(39455,'watch-mobile','.b-email .price','padding-left','10','','','.b-email'),(39456,'watch-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(39457,'watch-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(39458,'watch-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(39459,'watch-mobile','.b-email .qty','padding-left','10','','','.b-email'),(39460,'watch-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(39461,'watch-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(39462,'watch-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(39463,'watch-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(39464,'watch-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(39465,'watch-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(39466,'watch-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(39467,'watch-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(39468,'watch-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(39469,'watch-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(39470,'watch-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(39471,'watch-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(39472,'watch-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(39473,'watch-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(39474,'watch-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(39475,'watch-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(39476,'watch-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(39477,'watch-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(39478,'watch-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(39479,'watch-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(39480,'watch-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(39481,'watch-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(39482,'watch-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(39483,'watch-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(39484,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-left','0','','','.b-h-inline'),(39485,'watch-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-left','0','','','.b-menu-style'),(39486,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-left','5','','','.b-menu-style-1'),(39487,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-left','20','','','.b-menu-style-1'),(39488,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-left','20','','','.b-menu-style-1'),(39489,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-left','20','','','.b-menu-style-1'),(39490,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-left','0','','','.b-menu-style-2'),(39491,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-left','0','','','.b-menu-style-2'),(39492,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-left','0','','','.b-menu-style-2'),(39493,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-left','0','','','.b-menu-style-2'),(39494,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-left','20','','','.b-menu-style-2'),(39495,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-left','0','','','.b-menu-style-2'),(39496,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-left','20','','','.b-menu-style-2'),(39497,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-left','20','','','.b-menu-style-2'),(39498,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-left','20','','','.b-menu-style-2'),(39499,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-left','50','','','.b-menu-style-2'),(39500,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-left','5','','','.b-menu-style-3'),(39501,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','padding-left','20','','','.b-menu-style-3'),(39502,'watch-mobile','.b-messages .msv_btn','padding-left','0','','','.b-messages'),(39503,'watch-mobile','.b-messages .msv_content','padding-left','20','','','.b-messages'),(39504,'watch-mobile','.b-messages .msv_history','padding-left','20','','','.b-messages'),(39505,'watch-mobile','.b-messages .messMenuButton span','padding-left','15','','','.b-messages'),(39506,'watch-mobile','.b-messages .messages-menu ul','padding-left','0','','','.b-messages'),(39507,'watch-mobile','.b-messages .development-content .type-6 .content','padding-left','0','','','.b-messages'),(39508,'watch-mobile','.b-messages .messages-menu li a','padding-left','0','','','.b-messages'),(39509,'watch-mobile','.b-messages .content_management_attach button','padding-left','27','','','.b-messages'),(39510,'watch-mobile','.b-messages .messages-menu li','padding-left','0','','','.b-messages'),(39511,'watch-mobile','.b-messages .content_management_attach','padding-left','8','','','.b-messages'),(39512,'watch-mobile','.b-messages .email-heading','padding-left','15','','','.b-messages'),(39513,'watch-mobile','.b-messages .msv_to_cc','padding-left','15','','','.b-messages'),(39514,'watch-mobile','.b-messages .emailLineTextArea textarea','padding-left','10','','','.b-messages'),(39515,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-left','10','','','.b-messages'),(39516,'watch-mobile','.b-messages .emailBtn','padding-left','10','','','.b-messages'),(39517,'watch-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-left','0','','','.b-personal-catalog-popup'),(39518,'watch-mobile','.b-select-suggest .select2-container .select2-choice','padding-left','8','','','.b-select-suggest'),(39519,'watch-mobile','.b-select-suggest .select2-search input','padding-left','5','','','.b-select-suggest'),(39520,'watch-mobile','.b-select-suggest .select2-drop-mask','padding-left','0','','','.b-select-suggest'),(39521,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-left','5','','','.b-select-suggest'),(39522,'watch-mobile','.b-select-suggest .select2-results ul.select2-result-sub > li .select2-result-label','padding-left','20','','','.b-select-suggest'),(39523,'watch-mobile','.b-select-suggest .select2-results','padding-left','4','','','.b-select-suggest'),(39524,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-left','0','','','.b-select-suggest'),(39525,'watch-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','40','','','.b-select-suggest'),(39526,'watch-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','100','','','.b-select-suggest'),(39527,'watch-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','80','','','.b-select-suggest'),(39528,'watch-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','110','','','.b-select-suggest'),(39529,'watch-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','120','','','.b-select-suggest'),(39530,'watch-mobile','.b-select-suggest .select2-results ul.select2-result-sub','padding-left','0','','','.b-select-suggest'),(39531,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-left','0','','','.b-select-suggest'),(39532,'watch-mobile','.b-select-suggest .select2-locked','padding-left','5','','','.b-select-suggest'),(39533,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-left','0','','','.b-select-suggest'),(39534,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-left','18','','','.b-select-suggest'),(39535,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-left','5','','','.b-select-suggest'),(39536,'watch-mobile','.b-select-suggest .select2-search','padding-left','4','','','.b-select-suggest'),(39537,'watch-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','60','','','.b-select-suggest'),(39538,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','padding-left','7','','','.b-select-suggest'),(39539,'watch-mobile','.b-sub-totals .historyTotal td','padding-left','5','','','.b-sub-totals'),(39540,'watch-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(39541,'watch-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(39542,'watch-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(39543,'watch-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(39544,'watch-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(39545,'watch-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(39546,'watch-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(39547,'watch-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(39548,'watch-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(39549,'watch-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(39550,'watch-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(39551,'watch-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(39552,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(39553,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(39554,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(39555,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(39556,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(39557,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(39558,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(39559,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(39560,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(39561,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(39562,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(39563,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(39564,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(39565,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(39566,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(39567,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(39568,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(39569,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(39570,'watch-mobile','.b-trade-approval .steps-bar li a','padding-left','0','','','.b-trade-approval'),(39571,'watch-mobile','.b-trade-approval .middle-form','padding-left','0','','','.b-trade-approval'),(39572,'watch-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-left','5','','','.b-trade-approval'),(39573,'watch-mobile','.b-trade-approval .steps-bar','padding-left','12','','','.b-trade-approval'),(39574,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-left','10','','','.b-trade-approval'),(39575,'watch-mobile','.b-trade-approval .center-buttons','padding-left','0','','','.b-trade-approval'),(39576,'watch-mobile','.b-upload-file .upload-file-template','padding-left','1','','','.b-upload-file'),(39577,'watch-mobile','.b-upload-files .added-file','padding-left','0','','','.b-upload-files'),(39578,'watch-mobile','.b-upload-files .upload-files','padding-left','10','','','.b-upload-files'),(39579,'watch-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-left','20','','','.b-warehouses-popup'),(39580,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','padding-left','17','','','.b-warehouses-popup'),(39581,'watch-mobile','.batchPr .w-batch-products .products-listing .image','padding-left','0','','','.batchPr'),(39582,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-left','0','','','.batchPr'),(39583,'watch-mobile','.batchPr .w-batch-products','padding-left','0','','','.batchPr'),(39584,'watch-mobile','.batchPr > .block:nth-child(2)','padding-left','20','','','.batchPr'),(39585,'watch-mobile','.batchPr .w-batch-selected-products','padding-left','15','','','.batchPr'),(39586,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-left','0','','','.batchPr'),(39587,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-left','0','','','.batchPr'),(39588,'watch-mobile','.batchPr ','padding-left','0','','','.batchPr'),(39589,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-left','0','','','.batchPr'),(39590,'watch-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-left','0','','','.batchPr'),(39591,'watch-mobile','.batchPr .w-batch-products .products-listing .image','padding-left','0','','','.batchPr'),(39592,'watch-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(39593,'watch-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(39594,'watch-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(39595,'watch-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(39673,'watch-mobile','.p-quick-order-index .bottom','padding-left','0','','','.p-quick-order-index'),(39674,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.p-quick-order-index'),(39675,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.p-quick-order-index'),(39676,'watch-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-left','10','','','.p-quick-order-index'),(39677,'watch-mobile','.p-quick-order-index .all-scroll-div','padding-left','0','','','.p-quick-order-index'),(39678,'watch-mobile','.p-quick-order-index ul.token-input-list','padding-left','0','','','.p-quick-order-index'),(39679,'watch-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-left','10','','','.p-quick-order-index'),(39680,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(39681,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(39682,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(39683,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(39684,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(39685,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(39686,'watch-mobile','.w-account-address-book .item','padding-left','10','','','.w-account-address-book'),(39687,'watch-mobile','.w-account-address-book .wrap','padding-left','15','','','.w-account-address-book'),(39688,'watch-mobile','.w-account-address-book .btn-del','padding-left','7','','','.w-account-address-book'),(39689,'watch-mobile','.w-account-address-book .default-address','padding-left','7','','','.w-account-address-book'),(39690,'watch-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-left','0','','','.w-account-addresses-list'),(39691,'watch-mobile','.w-account-personal-catalog .list-switcher','padding-left','0','','','.w-account-personal-catalog'),(39692,'watch-mobile','.w-account-personal-catalog .list-switcher a','padding-left','6','','','.w-account-personal-catalog'),(39693,'watch-mobile','.w-account-subscription .subscription-variant','padding-left','10','','','.w-account-subscription'),(39694,'watch-mobile','.w-blog-widget-categories-list a','padding-left','15','','','.w-blog-widget-categories-list'),(39695,'watch-mobile','.w-blog-widget-most-popular-posts a','padding-left','15','','','.w-blog-widget-most-popular-posts'),(39696,'watch-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-left','0','','','.w-blog-widget-most-popular-posts'),(39697,'watch-mobile','.w-blog-widget-post-comments-count span','padding-left','22','','','.w-blog-widget-post-comments-count'),(39698,'watch-mobile','.w-blog-widget-post-listing .post','padding-left','33','','','.w-blog-widget-post-listing'),(39699,'watch-mobile','.w-blog-widget-post-listing .post_comment','padding-left','22','','','.w-blog-widget-post-listing'),(39700,'watch-mobile','.w-blog-widget-post-listing .post_name','padding-left','0','','','.w-blog-widget-post-listing'),(39701,'watch-mobile','.w-blog-widget-post-listing .post','padding-left','15','','','.w-blog-widget-post-listing'),(39702,'watch-mobile','.w-blog-widget-post-title ','padding-left','0','','','.w-blog-widget-post-title'),(39703,'watch-mobile','.w-blog-widget-post-title h1','padding-left','0','','','.w-blog-widget-post-title'),(39704,'watch-mobile','.w-blog-widget-related-posts .post','padding-left','15','','','.w-blog-widget-related-posts'),(39705,'watch-mobile','.w-blog-widget-related-posts .post_content a','padding-left','20','','','.w-blog-widget-related-posts'),(39706,'watch-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-left','20','','','.w-blog-widget-related-posts-by-category'),(39707,'watch-mobile','.w-blog-widget-related-posts-by-category .post','padding-left','15','','','.w-blog-widget-related-posts-by-category'),(39708,'watch-mobile','.w-blog-widget-related-posts-by-category ','padding-left','0','','','.w-blog-widget-related-posts-by-category'),(39709,'watch-mobile','.w-blog-widget-related-posts-by-category ','padding-left','15','','','.w-blog-widget-related-posts-by-category'),(39710,'watch-mobile','.w-blog-widget-tag-cloud a','padding-left','13','','','.w-blog-widget-tag-cloud'),(39711,'watch-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-left','0','','','.w-cart-cart-tabs'),(39712,'watch-mobile','.w-cart-compare .attributes-label','padding-left','10','','','.w-cart-compare'),(39713,'watch-mobile','.w-cart-compare .product .stock','padding-left','3','','','.w-cart-compare'),(39714,'watch-mobile','.w-cart-compare .product','padding-left','15','','','.w-cart-compare'),(39715,'watch-mobile','.w-cart-compare .cart-cell','padding-left','7','','','.w-cart-compare'),(39716,'watch-mobile','.w-cart-compare .price-cell','padding-left','20','','','.w-cart-compare'),(39717,'watch-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-left','0','','','.w-cart-compare'),(39718,'watch-mobile','.w-cart-compare .delete-cart','padding-left','10','','','.w-cart-compare'),(39719,'watch-mobile','.w-cart-compare .dropdown li','padding-left','10','','','.w-cart-compare'),(39720,'watch-mobile','.w-cart-compare .attributes-cell','padding-left','20','','','.w-cart-compare'),(39721,'watch-mobile','.w-cart-compare .price-label','padding-left','10','','','.w-cart-compare'),(39722,'watch-mobile','.w-cart-compare .product-label','padding-left','10','','','.w-cart-compare'),(39723,'watch-mobile','.w-cart-up-sell .w-list-type-1','padding-left','0','','','.w-cart-up-sell'),(39724,'watch-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-left','20','1','','.w-cart-up-sell'),(39725,'watch-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-left','21','','','.w-cart-up-sell'),(39726,'watch-mobile','.w-catalog-additional-images li','padding-left','10','','','.w-catalog-additional-images'),(39727,'watch-mobile','.w-catalog-additional-images ul','padding-left','0','','','.w-catalog-additional-images'),(39728,'watch-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-left','5','','','.w-catalog-b2b-add-button'),(39729,'watch-mobile','.w-catalog-compare td','padding-left','20','','','.w-catalog-compare'),(39730,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-left','0','','','.w-catalog-compare'),(39731,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','padding-left','5','2','','.w-catalog-compare'),(39732,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','padding-left','5','','','.w-catalog-compare'),(39733,'watch-mobile','.w-catalog-compare .cross-box .return','padding-left','20','','','.w-catalog-compare'),(39734,'watch-mobile','.w-catalog-paging .prev','padding-left','5','','','.w-catalog-paging'),(39735,'watch-mobile','.w-catalog-paging .next','padding-left','5','','','.w-catalog-paging'),(39736,'watch-mobile','.w-catalog-paging ','padding-left','5','2','','.w-catalog-paging'),(39737,'watch-mobile','.w-catalog-paging .paging-item','padding-left','2','','','.w-catalog-paging'),(39738,'watch-mobile','.w-catalog-paging .next-pages','padding-left','5','','','.w-catalog-paging'),(39739,'watch-mobile','.w-catalog-paging .prev-pages','padding-left','5','','','.w-catalog-paging'),(39740,'watch-mobile','.w-catalog-paging .page-number','padding-left','5','','','.w-catalog-paging'),(39741,'watch-mobile','.w-checkout-billing-address .same-address','padding-left','10','','','.w-checkout-billing-address'),(39742,'watch-mobile','.w-checkout-billing-address .edit-ab','padding-left','15','','','.w-checkout-billing-address'),(39743,'watch-mobile','.w-checkout-billing-address .addresses.address-main label','padding-left','0','','','.w-checkout-billing-address'),(39744,'watch-mobile','.w-checkout-billing-address .addresses .address-item label','padding-left','15','','','.w-checkout-billing-address'),(39745,'watch-mobile','.w-checkout-create-account .create-account','padding-left','0','','','.w-checkout-create-account'),(39746,'watch-mobile','.w-checkout-create-account .account-benefits ul','padding-left','20','','','.w-checkout-create-account'),(39747,'watch-mobile','.w-checkout-gdpr .terms-login','padding-left','0','','','.w-checkout-gdpr'),(39748,'watch-mobile','.w-checkout-gdpr .privacy-row','padding-left','0','','','.w-checkout-gdpr'),(39749,'watch-mobile','.w-checkout-shipping .sub-item','padding-left','0','','','.w-checkout-shipping'),(39750,'watch-mobile','.w-checkout-shipping-address .addresses.address-main label','padding-left','0','','','.w-checkout-shipping-address'),(39751,'watch-mobile','.w-checkout-shipping-address .addresses .address-item label','padding-left','15','','','.w-checkout-shipping-address'),(39752,'watch-mobile','.w-checkout-shipping-address .edit-ab','padding-left','15','','','.w-checkout-shipping-address'),(39753,'watch-mobile','.w-checkout-shipping-choice span','padding-left','0','','','.w-checkout-shipping-choice'),(39754,'watch-mobile','.w-checkout-shipping-choice span','padding-left','10','','','.w-checkout-shipping-choice'),(39755,'watch-mobile','.w-checkout-terms .required-message','padding-left','10','','','.w-checkout-terms'),(39756,'watch-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-left','10','','','.w-communication-new-topic'),(39757,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-left','5','','','.w-communication-new-topic'),(39758,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-left','5','','','.w-communication-new-topic'),(39759,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-left','10','','','.w-communication-new-topic'),(39760,'watch-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-left','0','','','.w-communication-new-topic'),(39761,'watch-mobile','.w-communication-post .communication-post-author','padding-left','0','','','.w-communication-post'),(39762,'watch-mobile','.w-delivery-day .left-count','padding-left','5','','','.w-delivery-day'),(39763,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-left','10','','','.w-image-maps'),(39764,'watch-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-left','0','','','.w-multi-cart-actions'),(39765,'watch-mobile','.w-personal-gift-status-bar .timeline','padding-left','10','','','.w-personal-gift-status-bar'),(39766,'watch-mobile','.w-personal-gift-status-bar .start-label','padding-left','30','','','.w-personal-gift-status-bar'),(39767,'watch-mobile','.w-personal-gift-status-bar .end-date','padding-left','5','3','','.w-personal-gift-status-bar'),(39768,'watch-mobile','.w-personal-gift-status-bar .end-label','padding-left','5','','','.w-personal-gift-status-bar'),(39769,'watch-mobile','.w-personal-gift-status-bar .inform','padding-left','5','4','','.w-personal-gift-status-bar'),(39770,'watch-mobile','.w-product-available-in-warehouses .warehouse-item','padding-left','0','','','.w-product-available-in-warehouses'),(39771,'watch-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(39772,'watch-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(39773,'watch-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(39774,'watch-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(39775,'watch-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(39776,'watch-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(39777,'watch-mobile','.w-product-customers-activity .customers-activity','padding-left','20','','','.w-product-customers-activity'),(39778,'watch-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(39779,'watch-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(39780,'watch-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(39781,'watch-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(39782,'watch-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(39783,'watch-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(39784,'watch-mobile','.w-promotions .nextdiscount .promo-for-each','padding-left','10','','','.w-promotions'),(39785,'watch-mobile','.w-promotions .promo-cart-discount .master .item','padding-left','20','','','.w-promotions'),(39786,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-left','20','','','.w-promotions'),(39787,'watch-mobile','.w-promotions .promo-cart-discount .slave','padding-left','15','','','.w-promotions'),(39788,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-left','20','','','.w-promotions'),(39789,'watch-mobile','.w-promotions .promo-salemaker .item','padding-left','20','','','.w-promotions'),(39790,'watch-mobile','.w-promotions .promo-salemaker .promo-manufacturers','padding-left','12','','','.w-promotions'),(39791,'watch-mobile','.w-promotions .promo-item','padding-left','40','','','.w-promotions'),(39792,'watch-mobile','.w-promotions .promo-salemaker .discount','padding-left','20','','','.w-promotions'),(39793,'watch-mobile','.w-promotions .promo-cart-discount .slave .item','padding-left','20','','','.w-promotions'),(39794,'watch-mobile','.w-promotions .prom-multi-discount .promo-product','padding-left','20','','','.w-promotions'),(39795,'watch-mobile','.w-promotions .nextdiscount .content > div','padding-left','10','','','.w-promotions'),(39796,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','padding-left','20','','','.w-promotions'),(39797,'watch-mobile','.w-reviews-content .author','padding-left','20','','','.w-reviews-content'),(39798,'watch-mobile','.w-reviews-content .item','padding-left','0','','','.w-reviews-content'),(39799,'watch-mobile','.w-reviews-content .review','padding-left','20','','','.w-reviews-content'),(39800,'watch-mobile','.w-sitemap-delivery-location > ul','padding-left','0','','','.w-sitemap-delivery-location'),(39801,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul ul','padding-left','20','','','.w-sitemap-delivery-location'),(39802,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-left','0','','','.w-sitemap-delivery-location'),(39803,'watch-mobile','.w-top-text .top-text','padding-left','10','','','.w-top-text'),(39804,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(39805,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-preview','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(39806,'watch-mobile','.w-wedding-registry-widgets-delete-link a','padding-left','12','','','.w-wedding-registry-widgets-delete-link'),(39807,'watch-mobile','.w-wedding-registry-widgets-photos ','padding-left','20','','','.w-wedding-registry-widgets-photos'),(39808,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-left','17','','','.w-wedding-registry-widgets-photos'),(39809,'watch-mobile','.w-wedding-registry-widgets-share-link a','padding-left','12','','','.w-wedding-registry-widgets-share-link'),(39810,'watch-mobile','.b-quantity .qty-box input[type=\'text\']','padding-left','3','','','.b-quantity'),(39811,'watch-mobile','.w-filters .filter-box-content ul','padding-left','0','','','.w-filters'),(39812,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left_important','important','','','.b-data-table'),(39813,'watch-mobile','.b-data-table table.dataTable thead td','padding-left_important','important','','','.b-data-table'),(39814,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left_important','important','','','.b-data-table'),(39815,'watch-mobile','.b-data-table table.dataTable tbody td','padding-left_important','important','','','.b-data-table'),(39816,'watch-mobile','.batchPr .w-batch-products','padding-left_important','important','','','.batchPr'),(39817,'watch-mobile','.w-list-type-2 .item','padding-right','21','','','.w-list-type-2'),(39818,'watch-mobile','.w-list-type-2 .compare-box-item','padding-right','7','','','.w-list-type-2'),(39819,'watch-mobile','.w-list-type-1_3 .item','padding-right','0','1','','.w-list-type-1_3'),(39820,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','padding-right','15','','','.w-list-type-2'),(39821,'watch-mobile','.w-list-type-1_3 .item','padding-right','0','','','.w-list-type-1_3'),(39822,'watch-mobile','.w-list-type-1_3 .compare-box-item','padding-right','7','','','.w-list-type-1_3'),(39823,'watch-mobile','.w-list-type-2_2 .compare-box-item','padding-right','7','','','.w-list-type-2_2'),(39824,'watch-mobile','.w-list-type-2.products-listing','padding-right','20','','','.w-list-type-2'),(39825,'watch-mobile','.w-list-type-2 .item','padding-right','20','1','','.w-list-type-2'),(39826,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','padding-right','15','','','.w-list-type-2_2'),(39827,'watch-mobile','.w-list-type-2_2.products-listing','padding-right','20','','','.w-list-type-2_2'),(39828,'watch-mobile','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(39829,'watch-mobile','.w-list-type-3.products-listing','padding-right','20','','','.w-list-type-3'),(39830,'watch-mobile','.w-menu .hided.menu ul li','padding-right','0','','','.w-menu'),(39831,'watch-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-right','0','','','.w-menu'),(39832,'watch-mobile','.w-menu-big ul','padding-right','0','','','.w-menu-big'),(39833,'watch-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','','','.w-menu-horizontal'),(39834,'watch-mobile','.w-menu-horizontal > ul > li > ul > li','padding-right','10','','','.w-menu-horizontal'),(39835,'watch-mobile','.w-menu-slider ul, .w-menu-slider li','padding-right','0','','','.w-menu-slider'),(39836,'watch-mobile','.w-menu-slider > ul > li > a','padding-right','10','','','.w-menu-slider'),(39837,'watch-mobile','.w-menu-slider > ul > li > ul > li','padding-right','50','','','.w-menu-slider'),(39838,'watch-mobile','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(39839,'watch-mobile','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(39840,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-right','0','','','.b-slick'),(39841,'watch-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','','','.w-menu-style-1'),(39842,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(39843,'watch-mobile','.b-bottom .popup-simple','padding-right','20','','','.b-bottom'),(39844,'watch-mobile','.b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .buttons','padding-right','10','','','.b-cookie-notice'),(39845,'watch-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.bottom .text','padding-right','10','','','.b-cookie-notice'),(39846,'watch-mobile','.w-login-block .returning','padding-right','40','','','.w-login-block'),(39847,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','','','.w-menu-style-1'),(39848,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-right','20','','','.w-menu-style-1'),(39849,'watch-mobile','.w-product-wedding-registry-button .btn','padding-right','0','','','.w-product-wedding-registry-button'),(39850,'watch-mobile','.w-sale .holder-2','padding-right','20','','','.w-sale'),(39851,'watch-mobile','.w-quote .cart-box-link','padding-right','10','','','.w-quote'),(39852,'watch-mobile','.w-filters .filter-widget-horizontal .filter-box','padding-right','20','','','.w-filters'),(39853,'watch-mobile','.w-categories .name','padding-right','3','','','.w-categories'),(39854,'watch-mobile','.w-filters .filter-ul-content','padding-right','0','','','.w-filters'),(39855,'watch-mobile','.w-currencies .currencies-title','padding-right','4','','','.w-currencies'),(39856,'watch-mobile','.w-currencies .current','padding-right','27','','','.w-currencies'),(39857,'watch-mobile','.w-currencies .select-link','padding-right','10','','','.w-currencies'),(39858,'watch-mobile','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(39859,'watch-mobile','.w-filters .ui-slider-range','padding-right','0','','','.w-filters'),(39860,'watch-mobile','.w-filters .fsl_handle','padding-right','0','','','.w-filters'),(39861,'watch-mobile','.w-top-categories .item','padding-right','10','290','','.w-top-categories'),(39875,'watch-mobile','.b-bottom .popup-buttons','padding-right','15','','','.b-bottom'),(39876,'watch-mobile','.w-cart-checkout-btn a','padding-right','12','290','','.w-cart-checkout-btn'),(39877,'watch-mobile','.w-product-reviews .reviews-list .name','padding-right','10','','','.w-product-reviews'),(39878,'watch-mobile','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(39879,'watch-mobile','.w-product-images .img-holder','padding-right','20','','','.w-product-images'),(39880,'watch-mobile','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(39881,'watch-mobile','.b-bottom .popup-content','padding-right','15','','','.b-bottom'),(39882,'watch-mobile','.b-compare .compare_pagination','padding-right','0','','','.b-compare'),(39884,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-right','10','','','.b-multi-page-checkout'),(39885,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-right','10','','','.b-multi-page-checkout'),(39887,'watch-mobile','.w-search .items-title','padding-right','0','','','.w-search'),(39888,'watch-mobile','.w-sale .holder-1','padding-right','20','','','.w-sale'),(39890,'watch-mobile','.w-socials > li','padding-right','15','','','.w-socials'),(39891,'watch-mobile','.b-info-popup .info-popup div','padding-right','15','','','.b-info-popup'),(39892,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-right','0','','','.b-multi-page-checkout'),(39893,'watch-mobile','.w-search .search-input','padding-right','40','','','.w-search'),(39894,'watch-mobile','.w-promo-code .holder','padding-right','20','320','','.w-promo-code'),(39896,'watch-mobile','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(39897,'watch-mobile','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(39898,'watch-mobile','.p-wedding-registry-manage a.remove-btn','padding-right','5','','','.p-wedding-registry-manage'),(39899,'watch-mobile','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(39908,'watch-mobile','.w-filters .head-filter-widget','padding-right','10','317','','.w-filters'),(39909,'watch-mobile','.w-product-configurator .pc_attr','padding-right','0','290','','.w-product-configurator'),(39910,'watch-mobile','.w-product-configurator .pc_item','padding-right','0','299','','.w-product-configurator'),(39911,'watch-mobile','.testimonials .name','padding-right','10','','',''),(39912,'watch-mobile','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(39913,'watch-mobile','.b-pagination .pagination span','padding-right','5','2','','.b-pagination'),(39914,'watch-mobile','.testimonials .heading-3','padding-right','0','','',''),(39915,'watch-mobile','.testimonials .review','padding-right','10','','',''),(39916,'watch-mobile','.b-pagination .pagination .prev-pages','padding-right','5','','','.b-pagination'),(39917,'watch-mobile','.testimonials .reviews-list .name','padding-right','10','','',''),(39918,'watch-mobile','.b-pagination .pagination .prev','padding-right','5','','','.b-pagination'),(39919,'watch-mobile','.b-bottom .confirm-popup .confirm-text','padding-right','0','','','.b-bottom'),(39920,'watch-mobile','.b-pagination .pagination .page-number','padding-right','5','','','.b-pagination'),(39921,'watch-mobile','.b-pagination .pagination .next-pages','padding-right','5','','','.b-pagination'),(39922,'watch-mobile','.b-pagination .pagination .next','padding-right','5','','','.b-pagination'),(39930,'watch-mobile','.btn','padding-right','12','','',''),(39931,'watch-mobile','.btn-1','padding-right','25','','',''),(39932,'watch-mobile','.btn-2','padding-right','25','','',''),(39933,'watch-mobile','.p-blog-index .nav-next','padding-right','50','','','.p-blog-index'),(39934,'watch-mobile','.btn-3','padding-right','25','','',''),(39935,'watch-mobile','.w-list-type-2_2 .button-view a','padding-right','10','','','.w-list-type-2_2'),(39936,'watch-mobile','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(39937,'watch-mobile','.w-product-personal-catalog-button .btn','padding-right','0','','','.w-product-personal-catalog-button'),(39938,'watch-mobile','.b-fancybox .fancybox-error','padding-right','15','','','.b-fancybox'),(39939,'watch-mobile','.w-menu-horizontal ul','padding-right','0','','','.w-menu-horizontal'),(39940,'watch-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-right','0','','','.w-delivery-location-top-location-list'),(39941,'watch-mobile','.w-chat .w-chat-box','padding-right','12','','','.w-chat'),(39942,'watch-mobile','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(39943,'watch-mobile','.b-bottom .alert-message','padding-right','20','','','.b-bottom'),(39944,'watch-mobile','.p-wedding-registry-index .middle-box','padding-right','10','','','.p-wedding-registry-index'),(39945,'watch-mobile','.p-wedding-registry-index .main-content','padding-right','0','','','.p-wedding-registry-index'),(39946,'watch-mobile','.p-wedding-registry-index .main-button','padding-right','20','3','','.p-wedding-registry-index'),(39947,'watch-mobile','.p-wedding-registry-index .main-button','padding-right','20','4','','.p-wedding-registry-index'),(39948,'watch-mobile','.b-form .form-buttons','padding-right','0','','','.b-form'),(39949,'watch-mobile','.p-wedding-registry-manage .links','padding-right','10','','','.p-wedding-registry-manage'),(39950,'watch-mobile','.p-wedding-registry-manage .links a','padding-right','10','','','.p-wedding-registry-manage'),(39951,'watch-mobile','.p-wedding-registry-search .search-list','padding-right','20','','','.p-wedding-registry-search'),(39952,'watch-mobile','.b-table .table td','padding-right','15','','','.b-table'),(39953,'watch-mobile','.b-table .table .headings td','padding-right','10','','','.b-table'),(39954,'watch-mobile','.p-wedding-registry-share .middle-form > input','padding-right','0','','','.p-wedding-registry-share'),(39955,'watch-mobile','.b-pagination .pagination a','padding-right','5','','','.b-pagination'),(39957,'watch-mobile','.header2 .ccc','padding-right','10','','',''),(39966,'watch-mobile','.b-compare .col-gender','padding-right','0','','','.b-compare'),(39967,'watch-mobile','.b-bottom .popup-heading','padding-right','15','','','.b-bottom'),(39968,'watch-mobile','.b-compare .column_wrapper','padding-right','10','','','.b-compare'),(39969,'watch-mobile','.b-compare .compare-box-item','padding-right','10','','','.b-compare'),(39970,'watch-mobile','.b-compare .col-two label','padding-right','0','','','.b-compare'),(39971,'watch-mobile','.b-compare .compare-head','padding-right','10','','','.b-compare'),(39972,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','padding-right','5','','','.b-switch'),(39973,'watch-mobile','.w-languages .lang-link','padding-right','10','299','','.w-languages'),(39974,'watch-mobile','.w-tabs .accordion-heading','padding-right','6','','','.w-tabs'),(39975,'watch-mobile','.w-quote .cart-box-link','padding-right','14','299','','.w-quote'),(39976,'watch-mobile','.w-currencies .select-link','padding-right','10','299','','.w-currencies'),(39977,'watch-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','299','','.w-menu-horizontal'),(39978,'watch-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','303','','.w-menu-style-1'),(39979,'watch-mobile','.w-languages .current','padding-right','27','299','','.w-languages'),(39980,'watch-mobile','.w-currencies .current','padding-right','27','299','','.w-currencies'),(39981,'watch-mobile','.b-slick button.slick-prev','padding-right','4','3','','.b-slick'),(39982,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-right','18','303','','.w-list-type-1'),(39983,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','303','','.w-menu-style-1'),(39984,'watch-mobile','.b-bottom .footerTitle','padding-right','0','290','','.b-bottom'),(39987,'watch-mobile','.w-cart .cart-content','padding-right','15','','','.w-cart'),(39988,'watch-mobile','.w-cart .cart-total','padding-right','0','','','.w-cart'),(39989,'watch-mobile','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(39990,'watch-mobile','.b-product-images .additional-vertical','padding-right','150','','','.b-product-images'),(39991,'watch-mobile','.w-bestsellers .heading-3','padding-right','0','','','.w-bestsellers'),(39992,'watch-mobile','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(39993,'watch-mobile','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(39994,'watch-mobile','.w-breadcrumb .breadcrumb-li','padding-right','0','','','.w-breadcrumb'),(39995,'watch-mobile','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-right','10','292','',''),(39996,'watch-mobile','.w-top-categories .image','padding-right','0','','','.w-top-categories'),(39997,'watch-mobile','.w-account a.my-acc-link','padding-right','17','','','.w-account'),(39999,'watch-mobile','.p-account-trade-form .trade-form-area','padding-right','20','','','.p-account-trade-form'),(40000,'watch-mobile','.p-account-trade-form .widget','padding-right','0','','','.p-account-trade-form'),(40001,'watch-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-right','0','','','.p-blog-index'),(40002,'watch-mobile','.p-blog-index .nav-links','padding-right','0','','','.p-blog-index'),(40003,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-right','10','','','.p-blog-index'),(40004,'watch-mobile','.p-blog-index .wp-widget ul','padding-right','0','','','.p-blog-index'),(40005,'watch-mobile','.p-blog-index .wp-widget li','padding-right','0','','','.p-blog-index'),(40008,'watch-mobile','.p-reviews-info .review-info-content','padding-right','20','','','.p-reviews-info'),(40010,'watch-mobile','.p-reviews-info .review-info-text','padding-right','10','','','.p-reviews-info'),(40011,'watch-mobile','.p-reviews-info .review-info-image','padding-right','20','','','.p-reviews-info'),(40012,'watch-mobile','.p-reviews-info .reviews-info .buttons','padding-right','0','','','.p-reviews-info'),(40013,'watch-mobile','.p-shopping-cart-index .cart-popup .cart-page, .p-shopping-cart-index .cart-popup .wishlist-page','padding-right','20','','','.p-shopping-cart-index'),(40016,'watch-mobile','.w-product-images .images','padding-right','0','320','','.w-product-images'),(40017,'watch-mobile','.w-filters .handle_tit','padding-right','5','','','.w-filters'),(40018,'watch-mobile','.b-slick .slick-vertical button.slick-next','padding-right','0','3','','.b-slick'),(40019,'watch-mobile','.b-slick .slick-vertical button.slick-prev','padding-right','0','3','','.b-slick'),(40020,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-right','20','','','.b-fancybox'),(40021,'watch-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-right','10','','','.p-account-subscription-historyinfo'),(40022,'watch-mobile','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(40026,'watch-mobile','.w-list-type-1 ','padding-right','0','','','.w-list-type-1'),(40027,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','padding-right','15','','','.w-list-type-1_3'),(40028,'watch-mobile','.w-list-type-1 .item','padding-right','5','','','.w-list-type-1'),(40029,'watch-mobile','.w-list-type-1_2.products-listing','padding-right','20','','','.w-list-type-1_2'),(40030,'watch-mobile','.w-list-type-1 .compare-box-item','padding-right','7','','','.w-list-type-1'),(40031,'watch-mobile','.w-list-type-1_2 .compare-box-item','padding-right','7','','','.w-list-type-1_2'),(40032,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-right','15','','','.w-list-type-1'),(40033,'watch-mobile','.w-languages .lang-link','padding-right','10','','','.w-languages'),(40034,'watch-mobile','.w-languages .current','padding-right','27','','','.w-languages'),(40035,'watch-mobile','.w-filters .head-filter-widget','padding-right','0','','','.w-filters'),(40036,'watch-mobile','.b-fancybox .fancybox-title-over-wrap','padding-right','10','','','.b-fancybox');
INSERT INTO `themes_styles` VALUES (40037,'watch-mobile','.p-quote-cart-index .cart-popup .cart-page, .p-quote-cart-index .cart-popup .wishlist-page','padding-right','20','','','.p-quote-cart-index'),(40038,'watch-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-right','0','','','.b-fancybox'),(40039,'watch-mobile','.w-categories .image','padding-right','0','','','.w-categories'),(40040,'watch-mobile','.w-categories .item','padding-right','20','','','.w-categories'),(40041,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','padding-right','15','','','.w-list-type-1_2'),(40042,'watch-mobile','.w-cart a.item','padding-right','0','','','.w-cart'),(40043,'watch-mobile','.w-cart .cart-box-link','padding-right','14','','','.w-cart'),(40044,'watch-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(40045,'watch-mobile','.b-compare .popupCompare .pop-up-content','padding-right','10','','','.b-compare'),(40046,'watch-mobile','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(40047,'watch-mobile','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(40048,'watch-mobile','.w-product-reviews .reviews-list .review','padding-right','10','','','.w-product-reviews'),(40049,'watch-mobile','.w-product-sale-ends .left-count','padding-right','5','','','.w-product-sale-ends'),(40050,'watch-mobile','.w-reviews .heading-3','padding-right','0','','','.w-reviews'),(40051,'watch-mobile','.w-reviews .review','padding-right','10','','','.w-reviews'),(40052,'watch-mobile','.w-sale .left-count','padding-right','5','','','.w-sale'),(40053,'watch-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(40054,'watch-mobile','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(40055,'watch-mobile','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(40056,'watch-mobile','.w-product-properties li','padding-right','5','','','.w-product-properties'),(40057,'watch-mobile','.w-product-configurator .pc_item','padding-right','20','','','.w-product-configurator'),(40058,'watch-mobile','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(40059,'watch-mobile','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(40060,'watch-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(40061,'watch-mobile','.w-menu-style-1 ul','padding-right','0','','','.w-menu-style-1'),(40062,'watch-mobile','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(40063,'watch-mobile','.b-fancybox .fancybox-prev span','padding-right','4','3','','.b-fancybox'),(40064,'watch-mobile','.p-wedding-registry-share .add-row','padding-right','40','','','.p-wedding-registry-share'),(40065,'watch-mobile','.p-wedding-registry-share .address-row','padding-right','40','','','.p-wedding-registry-share'),(40066,'watch-mobile','.w-tabs .accordion-heading','padding-right','8','290','','.w-tabs'),(40067,'watch-mobile','.w-top-categories .categories h2','padding-right','0','','','.w-top-categories'),(40068,'watch-mobile','.w-categories .categories h2','padding-right','0','','','.w-categories'),(40069,'watch-mobile','.w-banner .carousel-text > span','padding-right','20','','','.w-banner'),(40070,'watch-mobile','.b-form .terms-login','padding-right','80','','','.b-form'),(40071,'watch-mobile','.b-slick .slick-list','padding-right','0','','','.b-slick'),(40072,'watch-mobile','.w-tabs .tab-li','padding-right','0','','','.w-tabs'),(40073,'watch-mobile','.w-tabs .tab-a','padding-right','6','','','.w-tabs'),(40074,'watch-mobile','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(40075,'watch-mobile','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(40076,'watch-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-right','10','','','.w-menu-horizontal'),(40077,'watch-mobile','.w-cart .qty','padding-right','5','4','','.w-cart'),(40078,'watch-mobile','.w-account ul, .w-account li','padding-right','0','','','.w-account'),(40080,'watch-mobile','.w-categories .item','padding-right','10','290','','.w-categories'),(40081,'watch-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-right','0','','','.b-fancybox'),(40082,'watch-mobile','.w-cart-give-away .ga_img','padding-right','1','','','.w-cart-give-away'),(40083,'watch-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-right','6','','','.b-compare'),(40085,'watch-mobile','.w-list-type-2 .button-view a','padding-right','10','','','.w-list-type-2'),(40086,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','padding-right','10','','',''),(40087,'watch-mobile','.b-autocomplete .ui-autocomplete','padding-right','0','','','.b-autocomplete'),(40088,'watch-mobile','textarea','padding-right','10','','',''),(40089,'watch-mobile','.b-autocomplete .ui-autocomplete li','padding-right','10','','','.b-autocomplete'),(40090,'watch-mobile','.w-list-type-1_3 .button-view a','padding-right','10','','','.w-list-type-1_3'),(40091,'watch-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-right','20','','','.b-bottom'),(40092,'watch-mobile','.w-list-type-1_2 .button-view a','padding-right','10','','','.w-list-type-1_2'),(40093,'watch-mobile','.b-bottom .pop-up-close','padding-right','1','','','.b-bottom'),(40094,'watch-mobile','.b-bottom .pop-up-info','padding-right','20','','','.b-bottom'),(40095,'watch-mobile','.b-bottom .popup-box-wrap','padding-right','10','','','.b-bottom'),(40096,'watch-mobile','.w-list-type-1 .button-view a','padding-right','10','','','.w-list-type-1'),(40097,'watch-mobile','.b-form .center-buttons','padding-right','0','','','.b-form'),(40098,'watch-mobile','.w-reviews .name','padding-right','10','','','.w-reviews'),(40099,'watch-mobile','.w-reviews .reviews','padding-right','10','','','.w-reviews'),(40100,'watch-mobile','.w-reviews .reviews-list .name','padding-right','10','','','.w-reviews'),(40101,'watch-mobile','.w-top-categories .item','padding-right','20','','','.w-top-categories'),(40102,'watch-mobile','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block','padding-right','10','292','',''),(40104,'watch-mobile','.w-tabs .tab-navigation','padding-right','0','','','.w-tabs'),(40105,'watch-mobile','.w-top-categories .name','padding-right','3','','','.w-top-categories'),(40106,'watch-mobile','.b-form .middle-form','padding-right','0','','','.b-form'),(40107,'watch-mobile','.b-form .payment-method .item-radio label','padding-right','5','','','.b-form'),(40108,'watch-mobile','.b-form .shipping-method .input','padding-right','10','','','.b-form'),(40109,'watch-mobile','.b-form .required-message','padding-right','3','','','.b-form'),(40110,'watch-mobile','.b-form .required-message-wrap','padding-right','0','','','.b-form'),(40111,'watch-mobile','.b-info .info','padding-right','0','','','.b-info'),(40112,'watch-mobile','.b-info .info li','padding-right','0','','','.b-info'),(40113,'watch-mobile','.b-info .info ul','padding-right','0','','','.b-info'),(40115,'watch-mobile','.b-products-listing .in-cart','padding-right','10','','','.b-products-listing'),(40116,'watch-mobile','.b-products-listing .products-listing .btn-buy','padding-right','10','','','.b-products-listing'),(40117,'watch-mobile','.b-products-listing .products-listing .buyButton .btn','padding-right','10','','','.b-products-listing'),(40118,'watch-mobile','.b-products-listing .products-listing .compare','padding-right','6','','','.b-products-listing'),(40119,'watch-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-right','2','','','.b-products-listing'),(40120,'watch-mobile','.b-products-listing .products-listing a.btn.view-button','padding-right','0','','','.b-products-listing'),(40121,'watch-mobile','.b-products-listing .products-listing h2','padding-right','0','','','.b-products-listing'),(40122,'watch-mobile','.b-products-listing .promos-info .promo-item','padding-right','10','','','.b-products-listing'),(40123,'watch-mobile','.b-products-listing .promos-info .promo-name','padding-right','15','','','.b-products-listing'),(40124,'watch-mobile','.b-products-listing .list-productlisting div.BlockBox.item-holder','padding-right','10','','','.b-products-listing'),(40125,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.b-data-table'),(40126,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.b-data-table'),(40127,'watch-mobile','.b-data-table table.dataTable thead td','padding-right','20','','','.b-data-table'),(40128,'watch-mobile','.b-data-table table.dataTable tbody td','padding-right','20','','','.b-data-table'),(40129,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(40130,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(40131,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(40132,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(40133,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(40134,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(40135,'watch-mobile','.b-email .qty','padding-right','10','','','.b-email'),(40136,'watch-mobile','.b-email .price','padding-right','10','','','.b-email'),(40137,'watch-mobile','.b-email .price','padding-right','10','','','.b-email'),(40138,'watch-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(40139,'watch-mobile','.b-email .model','padding-right','10','','','.b-email'),(40140,'watch-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(40141,'watch-mobile','.b-email .model','padding-right','10','','','.b-email'),(40142,'watch-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(40143,'watch-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(40144,'watch-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(40145,'watch-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(40146,'watch-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(40147,'watch-mobile','.b-email .image','padding-right','10','','','.b-email'),(40148,'watch-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(40149,'watch-mobile','.b-email .price','padding-right','10','','','.b-email'),(40150,'watch-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(40151,'watch-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(40152,'watch-mobile','.b-email .qty','padding-right','10','','','.b-email'),(40153,'watch-mobile','.b-email .name','padding-right','10','','','.b-email'),(40154,'watch-mobile','.b-email .name','padding-right','10','','','.b-email'),(40155,'watch-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(40156,'watch-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(40157,'watch-mobile','.b-email .price','padding-right','10','','','.b-email'),(40158,'watch-mobile','.b-email .model','padding-right','10','','','.b-email'),(40159,'watch-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(40160,'watch-mobile','.b-email .model','padding-right','10','','','.b-email'),(40161,'watch-mobile','.b-email .price','padding-right','10','','','.b-email'),(40162,'watch-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(40163,'watch-mobile','.b-email .image','padding-right','10','','','.b-email'),(40164,'watch-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(40165,'watch-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(40166,'watch-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(40167,'watch-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(40168,'watch-mobile','.b-email .image','padding-right','10','','','.b-email'),(40169,'watch-mobile','.b-email .name','padding-right','10','','','.b-email'),(40170,'watch-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(40171,'watch-mobile','.b-email .image','padding-right','10','','','.b-email'),(40172,'watch-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(40173,'watch-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(40174,'watch-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(40175,'watch-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(40176,'watch-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(40177,'watch-mobile','.b-email .name','padding-right','10','','','.b-email'),(40178,'watch-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(40179,'watch-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(40180,'watch-mobile','.b-email .image','padding-right','10','','','.b-email'),(40181,'watch-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(40182,'watch-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(40183,'watch-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(40184,'watch-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(40185,'watch-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(40186,'watch-mobile','.b-email .qty','padding-right','10','','','.b-email'),(40187,'watch-mobile','.b-email .name','padding-right','10','','','.b-email'),(40188,'watch-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(40189,'watch-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(40190,'watch-mobile','.b-email .model','padding-right','10','','','.b-email'),(40191,'watch-mobile','.b-email .price','padding-right','10','','','.b-email'),(40192,'watch-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(40193,'watch-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(40194,'watch-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(40195,'watch-mobile','.b-email .qty','padding-right','10','','','.b-email'),(40196,'watch-mobile','.b-email .image','padding-right','10','','','.b-email'),(40197,'watch-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(40198,'watch-mobile','.b-email .name','padding-right','10','','','.b-email'),(40199,'watch-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(40200,'watch-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(40201,'watch-mobile','.b-email .qty','padding-right','10','','','.b-email'),(40202,'watch-mobile','.b-email .model','padding-right','10','','','.b-email'),(40203,'watch-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(40204,'watch-mobile','.b-email .qty','padding-right','10','','','.b-email'),(40205,'watch-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(40206,'watch-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(40207,'watch-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(40208,'watch-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(40209,'watch-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(40210,'watch-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(40211,'watch-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(40212,'watch-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(40213,'watch-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(40214,'watch-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(40215,'watch-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(40216,'watch-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(40217,'watch-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(40218,'watch-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(40219,'watch-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(40220,'watch-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(40221,'watch-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(40222,'watch-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(40223,'watch-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(40224,'watch-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(40225,'watch-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(40226,'watch-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(40227,'watch-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(40228,'watch-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(40229,'watch-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(40230,'watch-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(40231,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-right','0','','','.b-h-inline'),(40232,'watch-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-right','0','','','.b-menu-style'),(40233,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-right','5','','','.b-menu-style-1'),(40234,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-right','20','','','.b-menu-style-1'),(40235,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-right','20','','','.b-menu-style-1'),(40236,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-right','20','','','.b-menu-style-1'),(40237,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-right','20','','','.b-menu-style-2'),(40238,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-right','20','','','.b-menu-style-2'),(40239,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-right','0','','','.b-menu-style-2'),(40240,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-right','0','','','.b-menu-style-2'),(40241,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-right','20','','','.b-menu-style-2'),(40242,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-right','0','','','.b-menu-style-2'),(40243,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-right','20','','','.b-menu-style-2'),(40244,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-right','20','','','.b-menu-style-2'),(40245,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-right','50','','','.b-menu-style-2'),(40246,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-right','30','','','.b-menu-style-2'),(40247,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-right','5','','','.b-menu-style-3'),(40248,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','padding-right','20','','','.b-menu-style-3'),(40249,'watch-mobile','.b-messages .emailLineTextArea textarea','padding-right','10','','','.b-messages'),(40250,'watch-mobile','.b-messages .msv_btn','padding-right','0','','','.b-messages'),(40251,'watch-mobile','.b-messages .msv_content','padding-right','20','','','.b-messages'),(40252,'watch-mobile','.b-messages .development-content .type-6 .content','padding-right','40','','','.b-messages'),(40253,'watch-mobile','.b-messages .msv_history','padding-right','20','','','.b-messages'),(40254,'watch-mobile','.b-messages .messMenuButton span','padding-right','15','','','.b-messages'),(40255,'watch-mobile','.b-messages .messages-menu ul','padding-right','0','','','.b-messages'),(40256,'watch-mobile','.b-messages .messages-menu li a','padding-right','0','','','.b-messages'),(40257,'watch-mobile','.b-messages .messages-menu li','padding-right','0','','','.b-messages'),(40258,'watch-mobile','.b-messages .content_management_attach button','padding-right','27','','','.b-messages'),(40259,'watch-mobile','.b-messages .email-heading','padding-right','15','','','.b-messages'),(40260,'watch-mobile','.b-messages .content_management_attach','padding-right','8','','','.b-messages'),(40261,'watch-mobile','.b-messages .emailBtn','padding-right','10','','','.b-messages'),(40262,'watch-mobile','.b-messages .msv_to_cc','padding-right','15','','','.b-messages'),(40263,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-right','10','','','.b-messages'),(40264,'watch-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-right','0','','','.b-personal-catalog-popup'),(40265,'watch-mobile','.b-select-suggest .select2-search input','padding-right','20','','','.b-select-suggest'),(40266,'watch-mobile','.b-select-suggest .select2-search','padding-right','4','','','.b-select-suggest'),(40267,'watch-mobile','.b-select-suggest .select2-container .select2-choice','padding-right','0','','','.b-select-suggest'),(40268,'watch-mobile','.b-select-suggest .select2-drop-mask','padding-right','0','','','.b-select-suggest'),(40269,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-right','0','','','.b-select-suggest'),(40270,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(40271,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(40272,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-right','0','','','.b-select-suggest'),(40273,'watch-mobile','.b-select-suggest .select2-locked','padding-right','5','','','.b-select-suggest'),(40274,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-right','0','','','.b-select-suggest'),(40275,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-right','5','','','.b-select-suggest'),(40276,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','padding-right','7','','','.b-select-suggest'),(40277,'watch-mobile','.b-select-suggest .select2-results','padding-right','4','','','.b-select-suggest'),(40278,'watch-mobile','.b-sub-totals .historyTotal td','padding-right','5','','','.b-sub-totals'),(40279,'watch-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(40280,'watch-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(40281,'watch-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(40282,'watch-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(40283,'watch-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(40284,'watch-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(40285,'watch-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(40286,'watch-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(40287,'watch-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(40288,'watch-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(40289,'watch-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(40290,'watch-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(40291,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(40292,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(40293,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(40294,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(40295,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(40296,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(40297,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(40298,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(40299,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(40300,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(40301,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(40302,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(40303,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(40304,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(40305,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(40306,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(40307,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(40308,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(40309,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(40310,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(40311,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(40312,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(40313,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(40314,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(40315,'watch-mobile','.b-trade-approval .steps-bar li a','padding-right','0','','','.b-trade-approval'),(40316,'watch-mobile','.b-trade-approval .middle-form','padding-right','0','','','.b-trade-approval'),(40317,'watch-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-right','5','','','.b-trade-approval'),(40318,'watch-mobile','.b-trade-approval .steps-bar','padding-right','0','','','.b-trade-approval'),(40319,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-right','10','','','.b-trade-approval'),(40320,'watch-mobile','.b-trade-approval .center-buttons','padding-right','0','','','.b-trade-approval'),(40321,'watch-mobile','.b-upload-file .upload-file-template','padding-right','1','','','.b-upload-file'),(40322,'watch-mobile','.b-upload-files .added-file','padding-right','0','','','.b-upload-files'),(40323,'watch-mobile','.b-upload-files .upload-files','padding-right','10','','','.b-upload-files'),(40324,'watch-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-right','20','','','.b-warehouses-popup'),(40325,'watch-mobile','.batchPr .w-batch-products .products-listing .image','padding-right','15','','','.batchPr'),(40326,'watch-mobile','.batchPr .w-batch-products','padding-right','0','','','.batchPr'),(40327,'watch-mobile','.batchPr > .block:nth-child(2)','padding-right','0','','','.batchPr'),(40328,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-right','0','','','.batchPr'),(40329,'watch-mobile','.batchPr .w-batch-selected-products','padding-right','15','','','.batchPr'),(40330,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-right','0','','','.batchPr'),(40331,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-right','15','','','.batchPr'),(40332,'watch-mobile','.batchPr .w-batch-selected-products .item','padding-right','40','','','.batchPr'),(40333,'watch-mobile','.batchPr ','padding-right','0','','','.batchPr'),(40334,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-right','0','','','.batchPr'),(40335,'watch-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-right','0','','','.batchPr'),(40336,'watch-mobile','.batchPr .w-batch-products .products-listing .image','padding-right','0','','','.batchPr'),(40337,'watch-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(40338,'watch-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(40339,'watch-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(40340,'watch-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(40424,'watch-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-right','10','','','.p-quick-order-index'),(40425,'watch-mobile','.p-quick-order-index .all-scroll-div','padding-right','0','','','.p-quick-order-index'),(40426,'watch-mobile','.p-quick-order-index .bottom','padding-right','0','','','.p-quick-order-index'),(40427,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.p-quick-order-index'),(40428,'watch-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-right','10','','','.p-quick-order-index'),(40429,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.p-quick-order-index'),(40430,'watch-mobile','.p-quick-order-index ul.token-input-list','padding-right','0','','','.p-quick-order-index'),(40431,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(40432,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(40433,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(40434,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(40435,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(40436,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(40437,'watch-mobile','.w-account-address-book .item','padding-right','10','','','.w-account-address-book'),(40438,'watch-mobile','.w-account-address-book .btn-del','padding-right','7','','','.w-account-address-book'),(40439,'watch-mobile','.w-account-address-book .wrap','padding-right','15','','','.w-account-address-book'),(40440,'watch-mobile','.w-account-address-book .btn-edit','padding-right','7','','','.w-account-address-book'),(40441,'watch-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-right','20','','','.w-account-addresses-list'),(40442,'watch-mobile','.w-account-personal-catalog .list-switcher','padding-right','0','','','.w-account-personal-catalog'),(40443,'watch-mobile','.w-account-personal-catalog .list-switcher a','padding-right','6','','','.w-account-personal-catalog'),(40444,'watch-mobile','.w-account-subscription .subscription-variant','padding-right','10','','','.w-account-subscription'),(40445,'watch-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-right','0','','','.w-blog-widget-most-popular-posts'),(40446,'watch-mobile','.w-blog-widget-post-listing .post','padding-right','33','','','.w-blog-widget-post-listing'),(40447,'watch-mobile','.w-blog-widget-post-listing .post_name','padding-right','0','','','.w-blog-widget-post-listing'),(40448,'watch-mobile','.w-blog-widget-post-listing .post_view','padding-right','15','','','.w-blog-widget-post-listing'),(40449,'watch-mobile','.w-blog-widget-post-listing .post','padding-right','15','','','.w-blog-widget-post-listing'),(40450,'watch-mobile','.w-blog-widget-post-title h1','padding-right','0','','','.w-blog-widget-post-title'),(40451,'watch-mobile','.w-blog-widget-post-title ','padding-right','0','','','.w-blog-widget-post-title'),(40452,'watch-mobile','.w-blog-widget-related-posts ','padding-right','15','','','.w-blog-widget-related-posts'),(40453,'watch-mobile','.w-blog-widget-related-posts .post','padding-right','15','','','.w-blog-widget-related-posts'),(40454,'watch-mobile','.w-blog-widget-related-posts .post_content a','padding-right','20','','','.w-blog-widget-related-posts'),(40455,'watch-mobile','.w-blog-widget-related-posts ','padding-right','0','','','.w-blog-widget-related-posts'),(40456,'watch-mobile','.w-blog-widget-related-posts-by-category .post','padding-right','15','','','.w-blog-widget-related-posts-by-category'),(40457,'watch-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-right','20','','','.w-blog-widget-related-posts-by-category'),(40458,'watch-mobile','.w-blog-widget-tag-cloud a','padding-right','13','','','.w-blog-widget-tag-cloud'),(40459,'watch-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-right','0','','','.w-cart-cart-tabs'),(40460,'watch-mobile','.w-cart-compare .attributes-label','padding-right','10','','','.w-cart-compare'),(40461,'watch-mobile','.w-cart-compare .price-label','padding-right','10','','','.w-cart-compare'),(40462,'watch-mobile','.w-cart-compare .price-cell','padding-right','20','','','.w-cart-compare'),(40463,'watch-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-right','0','','','.w-cart-compare'),(40464,'watch-mobile','.w-cart-compare .delete-cart','padding-right','10','','','.w-cart-compare'),(40465,'watch-mobile','.w-cart-compare .attributes-cell','padding-right','20','','','.w-cart-compare'),(40466,'watch-mobile','.w-cart-compare .cart-cell','padding-right','7','','','.w-cart-compare'),(40467,'watch-mobile','.w-cart-compare .dropdown li','padding-right','10','','','.w-cart-compare'),(40468,'watch-mobile','.w-cart-compare .product-label','padding-right','10','','','.w-cart-compare'),(40469,'watch-mobile','.w-cart-compare .product','padding-right','15','','','.w-cart-compare'),(40470,'watch-mobile','.w-cart-compare .atr-col','padding-right','30','','','.w-cart-compare'),(40471,'watch-mobile','.w-cart-up-sell .w-list-type-1','padding-right','0','','','.w-cart-up-sell'),(40472,'watch-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-right','21','','','.w-cart-up-sell'),(40473,'watch-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-right','20','1','','.w-cart-up-sell'),(40474,'watch-mobile','.w-catalog-additional-images li','padding-right','10','','','.w-catalog-additional-images'),(40475,'watch-mobile','.w-catalog-additional-images ul','padding-right','0','','','.w-catalog-additional-images'),(40476,'watch-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-right','5','','','.w-catalog-b2b-add-button'),(40477,'watch-mobile','.w-catalog-compare td','padding-right','20','','','.w-catalog-compare'),(40478,'watch-mobile','.w-catalog-compare .image','padding-right','10','','','.w-catalog-compare'),(40479,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','padding-right','5','2','','.w-catalog-compare'),(40480,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','padding-right','5','','','.w-catalog-compare'),(40481,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-right','0','','','.w-catalog-compare'),(40482,'watch-mobile','.w-catalog-paging .paging-item','padding-right','2','','','.w-catalog-paging'),(40483,'watch-mobile','.w-catalog-paging .next','padding-right','5','','','.w-catalog-paging'),(40484,'watch-mobile','.w-catalog-paging .prev','padding-right','5','','','.w-catalog-paging'),(40485,'watch-mobile','.w-catalog-paging ','padding-right','5','2','','.w-catalog-paging'),(40486,'watch-mobile','.w-catalog-paging .next-pages','padding-right','5','','','.w-catalog-paging'),(40487,'watch-mobile','.w-catalog-paging .prev-pages','padding-right','5','','','.w-catalog-paging'),(40488,'watch-mobile','.w-catalog-paging .page-number','padding-right','5','','','.w-catalog-paging'),(40489,'watch-mobile','.w-checkout-billing-address .same-address','padding-right','10','','','.w-checkout-billing-address'),(40490,'watch-mobile','.w-checkout-billing-address .edit-ab','padding-right','0','','','.w-checkout-billing-address'),(40491,'watch-mobile','.w-checkout-billing-address .addresses .address-item label','padding-right','10','','','.w-checkout-billing-address'),(40492,'watch-mobile','.w-checkout-create-account .create-account','padding-right','0','','','.w-checkout-create-account'),(40493,'watch-mobile','.w-checkout-gdpr .privacy-row','padding-right','0','','','.w-checkout-gdpr'),(40494,'watch-mobile','.w-checkout-gdpr .terms-login','padding-right','0','','','.w-checkout-gdpr'),(40495,'watch-mobile','.w-checkout-shipping .sub-item','padding-right','0','','','.w-checkout-shipping'),(40496,'watch-mobile','.w-checkout-shipping-address .edit-ab','padding-right','0','','','.w-checkout-shipping-address'),(40497,'watch-mobile','.w-checkout-shipping-address .addresses .address-item label','padding-right','10','','','.w-checkout-shipping-address'),(40498,'watch-mobile','.w-checkout-shipping-choice span','padding-right','0','','','.w-checkout-shipping-choice'),(40499,'watch-mobile','.w-checkout-shipping-choice span','padding-right','10','','','.w-checkout-shipping-choice'),(40500,'watch-mobile','.w-checkout-terms .required-message','padding-right','10','','','.w-checkout-terms'),(40501,'watch-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-right','0','','','.w-communication-new-topic'),(40502,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-right','5','','','.w-communication-new-topic'),(40503,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-right','10','','','.w-communication-new-topic'),(40504,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-right','0','','','.w-communication-new-topic'),(40505,'watch-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-right','10','','','.w-communication-new-topic'),(40506,'watch-mobile','.w-communication-post .communication-post-author','padding-right','0','','','.w-communication-post'),(40507,'watch-mobile','.w-delivery-day .left-count','padding-right','5','','','.w-delivery-day'),(40508,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-right','10','','','.w-image-maps'),(40509,'watch-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-right','0','','','.w-multi-cart-actions'),(40510,'watch-mobile','.w-personal-gift-status-bar .end-label','padding-right','30','','','.w-personal-gift-status-bar'),(40511,'watch-mobile','.w-personal-gift-status-bar .start-label','padding-right','5','','','.w-personal-gift-status-bar'),(40512,'watch-mobile','.w-personal-gift-status-bar .timeline','padding-right','10','','','.w-personal-gift-status-bar'),(40513,'watch-mobile','.w-personal-gift-status-bar .end-date','padding-right','5','3','','.w-personal-gift-status-bar'),(40514,'watch-mobile','.w-personal-gift-status-bar .inform','padding-right','5','4','','.w-personal-gift-status-bar'),(40515,'watch-mobile','.w-product-available-in-warehouses .warehouse-item','padding-right','20','','','.w-product-available-in-warehouses'),(40516,'watch-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(40517,'watch-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(40518,'watch-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(40519,'watch-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(40520,'watch-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(40521,'watch-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(40522,'watch-mobile','.w-product-customers-activity .customers-activity','padding-right','20','','','.w-product-customers-activity'),(40523,'watch-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(40524,'watch-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(40525,'watch-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(40526,'watch-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(40527,'watch-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(40528,'watch-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(40529,'watch-mobile','.w-promotions .promo-cart-discount .master .item','padding-right','20','','','.w-promotions'),(40530,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-right','20','','','.w-promotions'),(40531,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-right','20','','','.w-promotions'),(40532,'watch-mobile','.w-promotions .promo-item','padding-right','40','','','.w-promotions'),(40533,'watch-mobile','.w-promotions .promo-date > div','padding-right','50','','','.w-promotions'),(40534,'watch-mobile','.w-promotions .promo-cart-discount .slave .item','padding-right','20','','','.w-promotions'),(40535,'watch-mobile','.w-promotions .promo-salemaker .discount','padding-right','20','','','.w-promotions'),(40536,'watch-mobile','.w-promotions .promo-salemaker .item','padding-right','20','','','.w-promotions'),(40537,'watch-mobile','.w-promotions .promo-salemaker .promo-categories','padding-right','12','','','.w-promotions'),(40538,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','padding-right','20','','','.w-promotions'),(40539,'watch-mobile','.w-promotions .heading','padding-right','10','','','.w-promotions'),(40540,'watch-mobile','.w-promotions .nextdiscount .promo-for-each','padding-right','20','','','.w-promotions'),(40541,'watch-mobile','.w-promotions .prom-multi-discount .promo-product','padding-right','20','','','.w-promotions'),(40542,'watch-mobile','.w-promotions .nextdiscount .content > div','padding-right','10','','','.w-promotions'),(40543,'watch-mobile','.w-promotions .nextdiscount .item-holder .image','padding-right','10','','','.w-promotions'),(40544,'watch-mobile','.w-promotions .master','padding-right','15','','','.w-promotions'),(40545,'watch-mobile','.w-reviews-content .item','padding-right','0','','','.w-reviews-content'),(40546,'watch-mobile','.w-reviews-content .author','padding-right','20','','','.w-reviews-content'),(40547,'watch-mobile','.w-reviews-content .review','padding-right','20','','','.w-reviews-content'),(40548,'watch-mobile','.w-reviews-content .product-image','padding-right','10','','','.w-reviews-content'),(40549,'watch-mobile','.w-sitemap-delivery-location > ul','padding-right','0','','','.w-sitemap-delivery-location'),(40550,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-right','0','','','.w-sitemap-delivery-location'),(40551,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul > li','padding-right','20','','','.w-sitemap-delivery-location'),(40552,'watch-mobile','.w-top-text .top-text','padding-right','10','','','.w-top-text'),(40553,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-right','17','','','.w-wedding-registry-widgets-photos'),(40554,'watch-mobile','.b-quantity .qty-box input[type=\'text\']','padding-right','3','','','.b-quantity'),(40555,'watch-mobile','.w-filters .filter-box-content ul','padding-right','0','','','.w-filters'),(40556,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right_important','important','','','.b-data-table'),(40557,'watch-mobile','.b-data-table table.dataTable thead td','padding-right_important','important','','','.b-data-table'),(40558,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right_important','important','','','.b-data-table'),(40559,'watch-mobile','.b-data-table table.dataTable tbody td','padding-right_important','important','','','.b-data-table'),(40560,'watch-mobile','.batchPr .w-batch-products','padding-right_important','important','','','.batchPr'),(40561,'watch-mobile','.w-list-type-2 .compare-box-item','padding-top','7','','','.w-list-type-2'),(40562,'watch-mobile','.w-list-type-1_3 .compare-box-item','padding-top','7','','','.w-list-type-1_3'),(40563,'watch-mobile','.w-list-type-1_3 .item','padding-top','20','1','','.w-list-type-1_3'),(40564,'watch-mobile','.w-list-type-1_3 .item','padding-top','20','','','.w-list-type-1_3'),(40565,'watch-mobile','.w-list-type-2 .item','padding-top','21','','','.w-list-type-2'),(40566,'watch-mobile','.w-list-type-3.products-listing','padding-top','20','','','.w-list-type-3'),(40567,'watch-mobile','.w-list-type-2.products-listing','padding-top','20','','','.w-list-type-2'),(40568,'watch-mobile','.w-list-type-2_2 .compare-box-item','padding-top','7','','','.w-list-type-2_2'),(40569,'watch-mobile','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(40570,'watch-mobile','.w-list-type-2_2.products-listing','padding-top','20','','','.w-list-type-2_2'),(40571,'watch-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','padding-top','0','','','.w-list-type-1_3'),(40572,'watch-mobile','.w-menu .hided.menu ul li','padding-top','0','','','.w-menu'),(40573,'watch-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-top','0','','','.w-menu'),(40574,'watch-mobile','.w-catalog-listing-look .listing-look-title','padding-top','4','','','.w-catalog-listing-look'),(40575,'watch-mobile','.w-menu-horizontal > ul > li > ul > li','padding-top','2','','','.w-menu-horizontal'),(40576,'watch-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','6','','','.w-menu-horizontal'),(40577,'watch-mobile','.w-menu-big ul','padding-top','0','','','.w-menu-big'),(40578,'watch-mobile','.w-menu-slider ul, .w-menu-slider li','padding-top','0','','','.w-menu-slider'),(40579,'watch-mobile','.w-menu-slider > ul > li > ul > li','padding-top','5','','','.w-menu-slider'),(40580,'watch-mobile','.w-menu-slider > ul > li > a','padding-top','5','','','.w-menu-slider'),(40581,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-top','0','','','.b-slick'),(40582,'watch-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','6','','','.w-menu-style-1'),(40583,'watch-mobile','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(40584,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(40585,'watch-mobile','.b-bottom .popup-simple','padding-top','20','','','.b-bottom'),(40586,'watch-mobile','.b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .buttons','padding-top','5','','','.b-cookie-notice'),(40587,'watch-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.bottom .text','padding-top','10','','','.b-cookie-notice'),(40588,'watch-mobile','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(40589,'watch-mobile','.w-product-wedding-registry-button .btn','padding-top','0','','','.w-product-wedding-registry-button'),(40590,'watch-mobile','.w-product-sale-ends .left-text-right','padding-top','24','','','.w-product-sale-ends'),(40591,'watch-mobile','.w-product-sale-ends .left-text-left','padding-top','24','','','.w-product-sale-ends'),(40592,'watch-mobile','.w-filters .ui-slider-range','padding-top','0','','','.w-filters'),(40593,'watch-mobile','.w-currencies .select-link','padding-top','5','','','.w-currencies'),(40594,'watch-mobile','.w-filters .fsl_handle','padding-top','20','','','.w-filters'),(40595,'watch-mobile','.w-categories .name','padding-top','3','','','.w-categories'),(40596,'watch-mobile','.w-currencies .current','padding-top','4','','','.w-currencies'),(40597,'watch-mobile','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(40598,'watch-mobile','.w-currencies .currencies-title','padding-top','3','','','.w-currencies'),(40599,'watch-mobile','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(40600,'watch-mobile','.w-top-categories .item','padding-top','5','290','','.w-top-categories'),(40614,'watch-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-top','10','','','.p-account-subscription-historyinfo'),(40615,'watch-mobile','.b-bottom .popup-buttons','padding-top','15','','','.b-bottom'),(40616,'watch-mobile','.b-price-box .checkout-index .price-box, .b-price-box .checkout-confirmation .price-box','padding-top','10','','','.b-price-box'),(40617,'watch-mobile','.w-tabs .accordion-heading','padding-top','9','290','','.w-tabs'),(40618,'watch-mobile','.w-product-quantity .product-quantity-label','padding-top','4','','','.w-product-quantity'),(40619,'watch-mobile','.b-compare .compare_pagination','padding-top','10','','','.b-compare'),(40622,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-top','20','','','.b-multi-page-checkout'),(40624,'watch-mobile','.w-sale .holder-2','padding-top','20','','','.w-sale'),(40625,'watch-mobile','.w-search .items-title','padding-top','10','','','.w-search'),(40626,'watch-mobile','.w-socials > li','padding-top','15','','','.w-socials'),(40628,'watch-mobile','.b-info-popup .info-popup div','padding-top','10','','','.b-info-popup'),(40629,'watch-mobile','.b-multi-page-checkout .multi-page-checkout','padding-top','20','','','.b-multi-page-checkout'),(40630,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-top','0','','','.b-multi-page-checkout'),(40631,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-top','8','','','.b-multi-page-checkout'),(40633,'watch-mobile','.w-promo-code .holder','padding-top','20','320','','.w-promo-code'),(40634,'watch-mobile','.w-search .search-input','padding-top','5','','','.w-search'),(40635,'watch-mobile','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(40636,'watch-mobile','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(40637,'watch-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','padding-top','5','','','.p-wedding-registry-manage'),(40638,'watch-mobile','.p-wedding-registry-manage a.remove-btn','padding-top','5','','','.p-wedding-registry-manage'),(40639,'watch-mobile','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(40640,'watch-mobile','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(40647,'watch-mobile','.w-filters .head-filter-widget','padding-top','0','317','','.w-filters'),(40649,'watch-mobile','.w-product-configurator .pc_item','padding-top','10','299','','.w-product-configurator'),(40651,'watch-mobile','.w-product-configurator .pc_attr','padding-top','5','290','','.w-product-configurator'),(40652,'watch-mobile','.testimonials .heading-3','padding-top','7','','',''),(40653,'watch-mobile','.testimonials .reviews-list .name','padding-top','5','','',''),(40654,'watch-mobile','.testimonials .reviews-list .answer .name','padding-top','10','','',''),(40655,'watch-mobile','.testimonials .name','padding-top','5','','',''),(40656,'watch-mobile','.testimonials .review','padding-top','10','','',''),(40658,'watch-mobile','.b-bottom .confirm-popup .confirm-text','padding-top','40','','','.b-bottom'),(40663,'watch-mobile','.btn','padding-top','8','','',''),(40666,'watch-mobile','.btn-1','padding-top','5','','',''),(40667,'watch-mobile','.btn-2','padding-top','14','','',''),(40668,'watch-mobile','.p-blog-index .comment-metadata','padding-top','4','','','.p-blog-index'),(40669,'watch-mobile','.btn-3','padding-top','12','','',''),(40670,'watch-mobile','.no-found','padding-top','20','','',''),(40671,'watch-mobile','.w-list-type-2_2 .buttons','padding-top','3','','','.w-list-type-2_2'),(40672,'watch-mobile','.w-list-type-2_2 .item','padding-top','20','','','.w-list-type-2_2'),(40673,'watch-mobile','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(40674,'watch-mobile','.w-product-personal-catalog-button .btn','padding-top','0','','','.w-product-personal-catalog-button'),(40675,'watch-mobile','.b-fancybox .fancybox-error','padding-top','15','','','.b-fancybox'),(40676,'watch-mobile','.w-menu-horizontal ul','padding-top','0','','','.w-menu-horizontal'),(40677,'watch-mobile','.w-chat .w-chat-box','padding-top','2','','','.w-chat'),(40678,'watch-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-top','0','','','.w-delivery-location-top-location-list'),(40679,'watch-mobile','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(40680,'watch-mobile','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(40681,'watch-mobile','.b-bottom .alert-message','padding-top','20','','','.b-bottom'),(40682,'watch-mobile','.p-wedding-registry-index .main-content','padding-top','70','','','.p-wedding-registry-index'),(40683,'watch-mobile','.p-wedding-registry-index .search-list','padding-top','20','','','.p-wedding-registry-index'),(40684,'watch-mobile','.p-wedding-registry-index .middle-box','padding-top','30','','','.p-wedding-registry-index'),(40685,'watch-mobile','.p-wedding-registry-index .main-button','padding-top','0','4','','.p-wedding-registry-index'),(40686,'watch-mobile','.p-wedding-registry-index .main-button','padding-top','0','3','','.p-wedding-registry-index'),(40687,'watch-mobile','.b-form .form-buttons','padding-top','17','','','.b-form'),(40688,'watch-mobile','.p-wedding-registry-manage .wedding-image','padding-top','15','','','.p-wedding-registry-manage'),(40689,'watch-mobile','.p-wedding-registry-manage .links','padding-top','10','','','.p-wedding-registry-manage'),(40690,'watch-mobile','.p-wedding-registry-manage .links a','padding-top','0','','','.p-wedding-registry-manage'),(40691,'watch-mobile','.p-wedding-registry-share .middle-form > input','padding-top','0','','','.p-wedding-registry-share'),(40692,'watch-mobile','.p-wedding-registry-share .wedding-image','padding-top','15','','','.p-wedding-registry-share'),(40693,'watch-mobile','.b-table .table td','padding-top','15','','','.b-table'),(40694,'watch-mobile','.b-table .table .headings td','padding-top','5','','','.b-table'),(40697,'watch-mobile','.header2 .ccc','padding-top','10','','',''),(40705,'watch-mobile','.b-bottom .popup-heading','padding-top','10','','','.b-bottom'),(40706,'watch-mobile','.b-compare .col-gender','padding-top','0','','','.b-compare'),(40707,'watch-mobile','.b-compare .col-two label','padding-top','5','','','.b-compare'),(40708,'watch-mobile','.b-compare .column_wrapper','padding-top','0','','','.b-compare'),(40709,'watch-mobile','.b-compare .compare-box-item','padding-top','10','','','.b-compare'),(40710,'watch-mobile','.b-compare .compare-head','padding-top','10','','','.b-compare'),(40711,'watch-mobile','.w-quote .cart-box-link','padding-top','5','299','','.w-quote'),(40712,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-top','8','303','','.w-list-type-1'),(40713,'watch-mobile','.w-tabs .accordion-heading','padding-top','6','','','.w-tabs'),(40714,'watch-mobile','.w-languages .current','padding-top','12','299','','.w-languages'),(40715,'watch-mobile','.w-languages .lang-link','padding-top','13','299','','.w-languages'),(40716,'watch-mobile','.w-currencies .current','padding-top','13','299','','.w-currencies'),(40717,'watch-mobile','.w-currencies .select-link','padding-top','12','299','','.w-currencies'),(40718,'watch-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','12','299','','.w-menu-horizontal'),(40719,'watch-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','12','303','','.w-menu-style-1'),(40720,'watch-mobile','.b-fancybox .fancybox-title-inside-wrap','padding-top','10','','','.b-fancybox'),(40721,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-top','12','303','','.w-menu-style-1'),(40722,'watch-mobile','.b-bottom .footerTitle','padding-top','9','290','','.b-bottom'),(40725,'watch-mobile','.w-top-categories .name','padding-top','3','','','.w-top-categories'),(40726,'watch-mobile','.w-cart .cart-total','padding-top','10','','','.w-cart'),(40727,'watch-mobile','.w-breadcrumb .breadcrumb-li','padding-top','0','','','.w-breadcrumb'),(40728,'watch-mobile','.w-cart .cart-content','padding-top','15','','','.w-cart'),(40729,'watch-mobile','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(40730,'watch-mobile','.w-list-type-1_2 .compare-box-item','padding-top','7','','','.w-list-type-1_2'),(40731,'watch-mobile','.w-product-reviews .reviews-list .name','padding-top','5','','','.w-product-reviews'),(40732,'watch-mobile','.b-form .center-buttons','padding-top','20','','','.b-form'),(40733,'watch-mobile','.w-bestsellers .heading-3','padding-top','7','','','.w-bestsellers'),(40734,'watch-mobile','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(40735,'watch-mobile','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(40736,'watch-mobile','.w-top-categories .image','padding-top','0','','','.w-top-categories'),(40737,'watch-mobile','.w-account a.my-acc-link','padding-top','5','','','.w-account'),(40738,'watch-mobile','.p-shopping-cart-index .cart-popup .cart-page, .p-shopping-cart-index .cart-popup .wishlist-page','padding-top','0','','','.p-shopping-cart-index'),(40739,'watch-mobile','.p-account-trade-form .widget','padding-top','10','','','.p-account-trade-form'),(40740,'watch-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-top','0','','','.p-blog-index'),(40741,'watch-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-top','5','','','.p-blog-index'),(40742,'watch-mobile','.p-blog-index .nav-links','padding-top','20','','','.p-blog-index'),(40743,'watch-mobile','.p-blog-index .wp-widget li','padding-top','0','','','.p-blog-index'),(40746,'watch-mobile','.p-blog-index .wp-widget ul','padding-top','0','','','.p-blog-index'),(40747,'watch-mobile','.p-quote-cart-index .cart-page .empty','padding-top','100','','','.p-quote-cart-index'),(40748,'watch-mobile','.p-quote-cart-index .cart-popup .cart-page, .p-quote-cart-index .cart-popup .wishlist-page','padding-top','0','','','.p-quote-cart-index'),(40749,'watch-mobile','.p-reviews-info .review-info-text','padding-top','10','','','.p-reviews-info'),(40750,'watch-mobile','.p-reviews-info .review-info-content','padding-top','20','','','.p-reviews-info'),(40751,'watch-mobile','.p-reviews-info .review-info-image','padding-top','20','','','.p-reviews-info'),(40753,'watch-mobile','.p-reviews-info .reviews-info .buttons','padding-top','0','','','.p-reviews-info'),(40754,'watch-mobile','.p-shopping-cart-index .cart-page .empty','padding-top','100','','','.p-shopping-cart-index'),(40756,'watch-mobile','.w-product-images .images','padding-top','10','320','','.w-product-images'),(40759,'watch-mobile','.b-slick .slick-vertical button.slick-next','padding-top','0','3','','.b-slick'),(40760,'watch-mobile','.b-slick .slick-vertical button.slick-prev','padding-top','0','3','','.b-slick'),(40761,'watch-mobile','.p-account-trade-form .trade-form-area','padding-top','20','','','.p-account-trade-form'),(40762,'watch-mobile','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(40763,'watch-mobile','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(40764,'watch-mobile','.b-info .info ul','padding-top','0','','','.b-info'),(40768,'watch-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','padding-top','0','','','.w-list-type-2'),(40769,'watch-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','padding-top','0','','','.w-list-type-2_2'),(40770,'watch-mobile','.w-list-type-1 ','padding-top','20','','','.w-list-type-1'),(40771,'watch-mobile','.w-list-type-1 .item','padding-top','0','','','.w-list-type-1'),(40772,'watch-mobile','.w-list-type-1_2.products-listing','padding-top','20','','','.w-list-type-1_2'),(40773,'watch-mobile','.w-list-type-2 .item','padding-top','20','1','','.w-list-type-2'),(40774,'watch-mobile','.w-list-type-1 .compare-box-item','padding-top','7','','','.w-list-type-1'),(40775,'watch-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-top','0','','','.w-list-type-1'),(40776,'watch-mobile','.w-languages .lang-link','padding-top','5','','','.w-languages'),(40777,'watch-mobile','.w-languages .current','padding-top','3','','','.w-languages'),(40778,'watch-mobile','.w-filters .head-filter-widget','padding-top','0','','','.w-filters'),(40779,'watch-mobile','.w-filters .filter-ul-content','padding-top','0','','','.w-filters'),(40780,'watch-mobile','.b-fancybox .fancybox-title-over-wrap','padding-top','10','','','.b-fancybox'),(40781,'watch-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-top','0','','','.b-fancybox'),(40782,'watch-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-top','0','','','.b-fancybox'),(40783,'watch-mobile','.w-categories .image','padding-top','0','','','.w-categories'),(40784,'watch-mobile','.w-categories .item','padding-top','5','','','.w-categories'),(40785,'watch-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','padding-top','0','','','.w-list-type-1_2'),(40786,'watch-mobile','.w-cart .cart-box-link','padding-top','5','','','.w-cart'),(40787,'watch-mobile','.w-cart a.item','padding-top','5','','','.w-cart'),(40788,'watch-mobile','.b-compare .popupCompare .pop-up-content','padding-top','0','','','.b-compare'),(40789,'watch-mobile','.b-bottom .popup-content','padding-top','15','','','.b-bottom'),(40790,'watch-mobile','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(40791,'watch-mobile','.w-product-sale-ends .left-count','padding-top','5','','','.w-product-sale-ends'),(40792,'watch-mobile','.w-sale .holder-1','padding-top','20','','','.w-sale'),(40793,'watch-mobile','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(40794,'watch-mobile','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(40795,'watch-mobile','.w-product-reviews .reviews-list .review','padding-top','10','','','.w-product-reviews'),(40796,'watch-mobile','.w-quote .cart-box-link','padding-top','5','','','.w-quote'),(40797,'watch-mobile','.w-sale .left-count','padding-top','5','','','.w-sale'),(40798,'watch-mobile','.w-reviews .review','padding-top','10','','','.w-reviews'),(40799,'watch-mobile','.w-reviews .heading-3','padding-top','7','','','.w-reviews'),(40800,'watch-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(40801,'watch-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(40802,'watch-mobile','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(40803,'watch-mobile','.w-product-properties li','padding-top','5','','','.w-product-properties'),(40804,'watch-mobile','.w-product-configurator .pc_item','padding-top','10','','','.w-product-configurator'),(40805,'watch-mobile','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(40806,'watch-mobile','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(40807,'watch-mobile','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(40808,'watch-mobile','.w-menu-style-1 ul','padding-top','0','','','.w-menu-style-1'),(40809,'watch-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(40811,'watch-mobile','.w-sale .left-text-left','padding-top','24','','','.w-sale'),(40812,'watch-mobile','.w-sale .left-text-right','padding-top','24','','','.w-sale'),(40813,'watch-mobile','.w-sale .text','padding-top','10','','','.w-sale'),(40814,'watch-mobile','.w-categories .categories h2','padding-top','0','','','.w-categories'),(40815,'watch-mobile','.w-top-categories .categories h2','padding-top','0','','','.w-top-categories'),(40816,'watch-mobile','.w-banner .carousel-text > span','padding-top','20','','','.w-banner'),(40817,'watch-mobile','.b-slick .slick-list','padding-top','0','','','.b-slick'),(40818,'watch-mobile','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(40819,'watch-mobile','.w-tabs .tab-li','padding-top','0','','','.w-tabs'),(40820,'watch-mobile','.w-tabs .tab-a','padding-top','6','','','.w-tabs'),(40821,'watch-mobile','.w-cart .buttons','padding-top','15','','','.w-cart'),(40822,'watch-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-top','2','','','.w-menu-horizontal'),(40823,'watch-mobile','.w-account ul, .w-account li','padding-top','0','','','.w-account'),(40824,'watch-mobile','h1','padding-top','20','','',''),(40826,'watch-mobile','.b-form .middle-form','padding-top','20','','','.b-form'),(40827,'watch-mobile','.w-categories .item','padding-top','5','290','','.w-categories'),(40828,'watch-mobile','.w-cart-give-away .ga_column','padding-top','15','','','.w-cart-give-away'),(40829,'watch-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-top','4','','','.b-compare'),(40831,'watch-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','padding-top','5','','',''),(40832,'watch-mobile','.w-list-type-2 .buttons','padding-top','3','','','.w-list-type-2'),(40833,'watch-mobile','.b-autocomplete .ui-autocomplete','padding-top','0','','','.b-autocomplete'),(40834,'watch-mobile','textarea','padding-top','5','','',''),(40835,'watch-mobile','.heading-3 .right-text, h3 .right-text','padding-top','3','','',''),(40836,'watch-mobile','.b-autocomplete .ui-autocomplete li','padding-top','3','','','.b-autocomplete'),(40837,'watch-mobile','.w-list-type-1_3 .buttons','padding-top','3','','','.w-list-type-1_3'),(40838,'watch-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-top','0','','','.b-bottom'),(40839,'watch-mobile','.w-list-type-1_2 .item','padding-top','20','','','.w-list-type-1_2'),(40840,'watch-mobile','.w-list-type-1_2 .buttons','padding-top','3','','','.w-list-type-1_2'),(40841,'watch-mobile','.b-bottom .pop-up-close','padding-top','1','','','.b-bottom'),(40842,'watch-mobile','.w-list-type-1_2 .button-view','padding-top','1','','','.w-list-type-1_2'),(40843,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-top','2','','','.b-fancybox'),(40844,'watch-mobile','.b-bottom .pop-up-info','padding-top','20','','','.b-bottom'),(40845,'watch-mobile','.heading-3 .edit, h3 .edit','padding-top','2','','',''),(40846,'watch-mobile','.w-list-type-1 .buttons','padding-top','3','','','.w-list-type-1'),(40847,'watch-mobile','.heading-4 .edit, h4 .edit','padding-top','2','','',''),(40848,'watch-mobile','.heading-4 .right-text, h4 .right-text','padding-top','4','','',''),(40849,'watch-mobile','.b-bottom .popup-box-wrap','padding-top','10','','','.b-bottom'),(40850,'watch-mobile','.w-reviews .name','padding-top','5','','','.w-reviews'),(40851,'watch-mobile','.w-reviews .reviews-list .name','padding-top','5','','','.w-reviews'),(40853,'watch-mobile','.w-top-categories .item','padding-top','5','','','.w-top-categories'),(40854,'watch-mobile','.w-tabs > .block','padding-top','20','','','.w-tabs'),(40855,'watch-mobile','.w-tabs .tab-navigation','padding-top','0','','','.w-tabs'),(40856,'watch-mobile','.b-form .payment-method .item-radio label','padding-top','5','','','.b-form'),(40857,'watch-mobile','.b-form .required-message-wrap','padding-top','0','','','.b-form'),(40858,'watch-mobile','.b-form .shipping-method .input','padding-top','0','','','.b-form'),(40859,'watch-mobile','.b-form .required-message','padding-top','0','','','.b-form'),(40860,'watch-mobile','.b-info .info','padding-top','20','','','.b-info'),(40861,'watch-mobile','.b-info .info li','padding-top','0','','','.b-info'),(40862,'watch-mobile','.b-products-listing .in-cart','padding-top','5','','','.b-products-listing'),(40863,'watch-mobile','.b-products-listing .products-listing .btn-buy','padding-top','5','','','.b-products-listing'),(40864,'watch-mobile','.b-products-listing .products-listing .buyButton .btn','padding-top','5','','','.b-products-listing'),(40865,'watch-mobile','.b-products-listing .products-listing .compare','padding-top','6','','','.b-products-listing'),(40866,'watch-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-top','4','','','.b-products-listing'),(40867,'watch-mobile','.b-products-listing .products-listing a.btn.view-button','padding-top','6','','','.b-products-listing'),(40868,'watch-mobile','.b-products-listing .products-listing h2','padding-top','0','','','.b-products-listing'),(40869,'watch-mobile','.b-products-listing .promos-info .promo-item','padding-top','3','','','.b-products-listing'),(40870,'watch-mobile','.b-products-listing .promos-info .promo-name','padding-top','3','','','.b-products-listing'),(40871,'watch-mobile','.b-products-listing .select-attributes .item-title','padding-top','2','','','.b-products-listing'),(40872,'watch-mobile','.b-products-listing .list-productlisting div.BlockBox.item-holder','padding-top','25','','','.b-products-listing'),(40873,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.b-data-table'),(40874,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top','0','','','.b-data-table'),(40875,'watch-mobile','.b-data-table table.dataTable thead td','padding-top','10','','','.b-data-table'),(40876,'watch-mobile','.b-data-table table.dataTable tbody td','padding-top','10','','','.b-data-table'),(40877,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(40878,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(40879,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(40880,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(40881,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(40882,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(40883,'watch-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(40884,'watch-mobile','.b-email .image','padding-top','5','','','.b-email'),(40885,'watch-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(40886,'watch-mobile','.b-email .qty','padding-top','5','','','.b-email'),(40887,'watch-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(40888,'watch-mobile','.b-email .image','padding-top','5','','','.b-email'),(40889,'watch-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(40890,'watch-mobile','.b-email .model','padding-top','5','','','.b-email'),(40891,'watch-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(40892,'watch-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(40893,'watch-mobile','.b-email .image','padding-top','5','','','.b-email'),(40894,'watch-mobile','.b-email .name','padding-top','5','','','.b-email'),(40895,'watch-mobile','.b-email .qty','padding-top','5','','','.b-email'),(40896,'watch-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(40897,'watch-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(40898,'watch-mobile','.b-email .model','padding-top','5','','','.b-email'),(40899,'watch-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(40900,'watch-mobile','.b-email .model','padding-top','5','','','.b-email'),(40901,'watch-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(40902,'watch-mobile','.b-email .qty','padding-top','5','','','.b-email'),(40903,'watch-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(40904,'watch-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(40905,'watch-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(40906,'watch-mobile','.b-email .model','padding-top','5','','','.b-email'),(40907,'watch-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(40908,'watch-mobile','.b-email .name','padding-top','5','','','.b-email'),(40909,'watch-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(40910,'watch-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(40911,'watch-mobile','.b-email .image','padding-top','5','','','.b-email'),(40912,'watch-mobile','.b-email .price','padding-top','5','','','.b-email'),(40913,'watch-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(40914,'watch-mobile','.b-email .name','padding-top','5','','','.b-email'),(40915,'watch-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(40916,'watch-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(40917,'watch-mobile','.b-email .model','padding-top','5','','','.b-email'),(40918,'watch-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(40919,'watch-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(40920,'watch-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(40921,'watch-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(40922,'watch-mobile','.b-email .name','padding-top','5','','','.b-email'),(40923,'watch-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(40924,'watch-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(40925,'watch-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(40926,'watch-mobile','.b-email .price','padding-top','5','','','.b-email'),(40927,'watch-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(40928,'watch-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(40929,'watch-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(40930,'watch-mobile','.b-email .price','padding-top','5','','','.b-email'),(40931,'watch-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(40932,'watch-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(40933,'watch-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(40934,'watch-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(40935,'watch-mobile','.b-email .price','padding-top','5','','','.b-email'),(40936,'watch-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(40937,'watch-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(40938,'watch-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(40939,'watch-mobile','.b-email .qty','padding-top','5','','','.b-email'),(40940,'watch-mobile','.b-email .model','padding-top','5','','','.b-email'),(40941,'watch-mobile','.b-email .price','padding-top','5','','','.b-email'),(40942,'watch-mobile','.b-email .image','padding-top','5','','','.b-email'),(40943,'watch-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(40944,'watch-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(40945,'watch-mobile','.b-email .name','padding-top','5','','','.b-email'),(40946,'watch-mobile','.b-email .image','padding-top','5','','','.b-email'),(40947,'watch-mobile','.b-email .name','padding-top','5','','','.b-email'),(40948,'watch-mobile','.b-email .qty','padding-top','5','','','.b-email'),(40949,'watch-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(40950,'watch-mobile','.b-email .price','padding-top','5','','','.b-email'),(40951,'watch-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(40952,'watch-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(40953,'watch-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(40954,'watch-mobile','.b-email .qty','padding-top','5','','','.b-email'),(40955,'watch-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(40956,'watch-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(40957,'watch-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(40958,'watch-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(40959,'watch-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(40960,'watch-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(40961,'watch-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(40962,'watch-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(40963,'watch-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(40964,'watch-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(40965,'watch-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(40966,'watch-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(40967,'watch-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(40968,'watch-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(40969,'watch-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(40970,'watch-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(40971,'watch-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(40972,'watch-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(40973,'watch-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(40974,'watch-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(40975,'watch-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(40976,'watch-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(40977,'watch-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(40978,'watch-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(40979,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-top','0','','','.b-h-inline'),(40980,'watch-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-top','0','','','.b-menu-style'),(40981,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-top','5','','','.b-menu-style-1'),(40982,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-top','5','','','.b-menu-style-1'),(40983,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-top','20','','','.b-menu-style-1'),(40984,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','padding-top','40','','','.b-menu-style-1'),(40985,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-top','0','','','.b-menu-style-1'),(40986,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-top','5','','','.b-menu-style-2'),(40987,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-top','5','','','.b-menu-style-2'),(40988,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-top','0','','','.b-menu-style-2'),(40989,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-top','0','','','.b-menu-style-2'),(40990,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-top','10','','','.b-menu-style-2'),(40991,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-top','0','','','.b-menu-style-2'),(40992,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-top','5','','','.b-menu-style-2'),(40993,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-top','10','','','.b-menu-style-2'),(40994,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-top','5','','','.b-menu-style-2'),(40995,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-html_box','padding-top','7','','','.b-menu-style-2'),(40996,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-top','10','','','.b-menu-style-2'),(40997,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-top','5','','','.b-menu-style-3'),(40998,'watch-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','padding-top','5','','','.b-menu-style-3'),(40999,'watch-mobile','.b-messages .msv_content','padding-top','10','','','.b-messages'),(41000,'watch-mobile','.b-messages .msv_btn','padding-top','12','','','.b-messages'),(41001,'watch-mobile','.b-messages .emailLineTextArea textarea','padding-top','30','','','.b-messages'),(41002,'watch-mobile','.b-messages .msv_history','padding-top','10','','','.b-messages'),(41003,'watch-mobile','.b-messages .messages-menu li','padding-top','0','','','.b-messages'),(41004,'watch-mobile','.b-messages .messages-menu ul','padding-top','0','','','.b-messages'),(41005,'watch-mobile','.b-messages .messMenuButton span','padding-top','10','','','.b-messages'),(41006,'watch-mobile','.b-messages .messages-menu li a','padding-top','10','','','.b-messages'),(41007,'watch-mobile','.b-messages .content_management_attach','padding-top','8','','','.b-messages'),(41008,'watch-mobile','.b-messages .content_management_attach button','padding-top','1','','','.b-messages'),(41009,'watch-mobile','.b-messages .email-heading','padding-top','15','','','.b-messages'),(41010,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-top','5','','','.b-messages'),(41011,'watch-mobile','.b-messages .messMenuButtonTop','padding-top','5','','','.b-messages'),(41012,'watch-mobile','.b-messages .msv_to_cc','padding-top','10','','','.b-messages'),(41013,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','padding-top','4','','','.b-messages'),(41014,'watch-mobile','.b-messages .emailBtn','padding-top','10','','','.b-messages'),(41015,'watch-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-top','20','','','.b-personal-catalog-popup'),(41016,'watch-mobile','.b-select-suggest .select2-container .select2-choice','padding-top','0','','','.b-select-suggest'),(41017,'watch-mobile','.b-select-suggest .select2-drop-mask','padding-top','0','','','.b-select-suggest'),(41018,'watch-mobile','.b-select-suggest .select2-search input','padding-top','4','','','.b-select-suggest'),(41019,'watch-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(41020,'watch-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','padding-top','4','','','.b-select-suggest'),(41021,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-top','0','','','.b-select-suggest'),(41022,'watch-mobile','.b-select-suggest .select2-results','padding-top','0','','','.b-select-suggest'),(41023,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','padding-top','3','3','','.b-select-suggest'),(41024,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','padding-top','3','','','.b-select-suggest'),(41025,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-top','0','','','.b-select-suggest'),(41026,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-top','5','','','.b-select-suggest'),(41027,'watch-mobile','.b-select-suggest .select2-locked','padding-top','3','','','.b-select-suggest'),(41028,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-top','0','','','.b-select-suggest'),(41029,'watch-mobile','.b-select-suggest .select2-drop-auto-width .select2-search','padding-top','4','','','.b-select-suggest'),(41030,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(41031,'watch-mobile','.b-sub-totals .historyTotal td','padding-top','2','','','.b-sub-totals'),(41032,'watch-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(41033,'watch-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(41034,'watch-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(41035,'watch-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(41036,'watch-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(41037,'watch-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(41038,'watch-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(41039,'watch-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(41040,'watch-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(41041,'watch-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(41042,'watch-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(41043,'watch-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(41044,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(41045,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(41046,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(41047,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(41048,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(41049,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(41050,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(41051,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(41052,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(41053,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(41054,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(41055,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(41056,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(41057,'watch-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(41058,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(41059,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(41060,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(41061,'watch-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(41062,'watch-mobile','.b-trade-approval .steps-bar li a','padding-top','7','','','.b-trade-approval'),(41063,'watch-mobile','.b-trade-approval .middle-form','padding-top','20','','','.b-trade-approval'),(41064,'watch-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-top','5','','','.b-trade-approval'),(41065,'watch-mobile','.b-trade-approval .steps-bar','padding-top','0','','','.b-trade-approval'),(41066,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-top','4','','','.b-trade-approval'),(41067,'watch-mobile','.b-trade-approval .center-buttons','padding-top','20','','','.b-trade-approval'),(41068,'watch-mobile','.b-upload-file .upload-file-template','padding-top','25','','','.b-upload-file'),(41069,'watch-mobile','.b-upload-files .upload-files','padding-top','0','','','.b-upload-files'),(41070,'watch-mobile','.b-upload-files .attached-block','padding-top','10','','','.b-upload-files'),(41071,'watch-mobile','.b-upload-files .added-file','padding-top','5','','','.b-upload-files'),(41072,'watch-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-top','20','','','.b-warehouses-popup'),(41073,'watch-mobile','.batchPr .w-batch-products .products-listing .image','padding-top','0','','','.batchPr'),(41074,'watch-mobile','.batchPr .w-batch-products .products-listing .image + .type-1','padding-top','5','','','.batchPr'),(41075,'watch-mobile','.batchPr .w-batch-products','padding-top','0','','','.batchPr'),(41076,'watch-mobile','.batchPr > .block:nth-child(2)','padding-top','12','','','.batchPr'),(41077,'watch-mobile','.batchPr .w-batch-selected-products','padding-top','15','','','.batchPr'),(41078,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-top','0','','','.batchPr'),(41079,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .item + .item','padding-top','10','','','.batchPr'),(41080,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-top','0','','','.batchPr'),(41081,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-top','0','','','.batchPr'),(41082,'watch-mobile','.batchPr ','padding-top','20','','','.batchPr'),(41083,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-top','0','','','.batchPr'),(41084,'watch-mobile','.batchPr .w-batch-products .products-listing .image','padding-top','0','','','.batchPr'),(41085,'watch-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-top','0','','','.batchPr'),(41086,'watch-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(41087,'watch-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(41088,'watch-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(41089,'watch-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(41174,'watch-mobile','.p-payer-order-confirmation .dob-hide label','padding-top','5','','','.p-payer-order-confirmation'),(41175,'watch-mobile','.p-payer-order-pay .dob-hide label','padding-top','5','','','.p-payer-order-pay'),(41176,'watch-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-top','8','','','.p-quick-order-index'),(41177,'watch-mobile','.p-quick-order-index .bottom','padding-top','10','','','.p-quick-order-index'),(41178,'watch-mobile','.p-quick-order-index .all-scroll-div','padding-top','10','','','.p-quick-order-index'),(41179,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.p-quick-order-index'),(41180,'watch-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-top','7','','','.p-quick-order-index'),(41181,'watch-mobile','.p-quick-order-index ul.token-input-list','padding-top','0','','','.p-quick-order-index'),(41182,'watch-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(41183,'watch-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(41184,'watch-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(41185,'watch-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(41186,'watch-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(41187,'watch-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(41188,'watch-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(41189,'watch-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(41190,'watch-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(41191,'watch-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(41192,'watch-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(41193,'watch-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(41194,'watch-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(41195,'watch-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(41196,'watch-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(41197,'watch-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(41198,'watch-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(41199,'watch-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(41200,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(41201,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(41202,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(41203,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(41204,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(41205,'watch-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(41206,'watch-mobile','.p-sample-checkout-success .page-success .text-1','padding-top','120','','','.p-sample-checkout-success'),(41207,'watch-mobile','.p-sample-checkout-success .page-success .text-1','padding-top','5','','','.p-sample-checkout-success'),(41208,'watch-mobile','.w-account-address-book .wrap','padding-top','15','','','.w-account-address-book'),(41209,'watch-mobile','.w-account-address-book .item','padding-top','0','','','.w-account-address-book'),(41210,'watch-mobile','.w-account-address-book .btn-del','padding-top','0','','','.w-account-address-book'),(41211,'watch-mobile','.w-account-address-book .name','padding-top','4','','','.w-account-address-book'),(41212,'watch-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-top','0','','','.w-account-addresses-list'),(41213,'watch-mobile','.w-account-personal-catalog .list-switcher','padding-top','0','','','.w-account-personal-catalog'),(41214,'watch-mobile','.w-account-personal-catalog .list-switcher a','padding-top','14','','','.w-account-personal-catalog'),(41215,'watch-mobile','.w-account-personal-catalog .list-switcher a','padding-top','12','2','','.w-account-personal-catalog'),(41216,'watch-mobile','.w-account-subscription .subscription-variant','padding-top','10','','','.w-account-subscription'),(41217,'watch-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-top','0','','','.w-blog-widget-most-popular-posts'),(41218,'watch-mobile','.w-blog-widget-post-listing .post','padding-top','0','','','.w-blog-widget-post-listing'),(41219,'watch-mobile','.w-blog-widget-post-listing .post_name','padding-top','10','','','.w-blog-widget-post-listing'),(41220,'watch-mobile','.w-blog-widget-post-listing .post','padding-top','0','','','.w-blog-widget-post-listing'),(41221,'watch-mobile','.w-blog-widget-post-share ','padding-top','15','','','.w-blog-widget-post-share'),(41222,'watch-mobile','.w-blog-widget-post-title ','padding-top','0','','','.w-blog-widget-post-title'),(41223,'watch-mobile','.w-blog-widget-post-title h1','padding-top','0','','','.w-blog-widget-post-title'),(41224,'watch-mobile','.w-blog-widget-related-posts .post','padding-top','0','','','.w-blog-widget-related-posts'),(41225,'watch-mobile','.w-blog-widget-related-posts .post_content a','padding-top','20','','','.w-blog-widget-related-posts'),(41226,'watch-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-top','20','','','.w-blog-widget-related-posts-by-category'),(41227,'watch-mobile','.w-blog-widget-related-posts-by-category .post','padding-top','0','','','.w-blog-widget-related-posts-by-category'),(41228,'watch-mobile','.w-blog-widget-tag-cloud a','padding-top','10','','','.w-blog-widget-tag-cloud'),(41229,'watch-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-top','0','','','.w-cart-cart-tabs'),(41230,'watch-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-top','5','','','.w-cart-compare'),(41231,'watch-mobile','.w-cart-compare .attributes-label','padding-top','10','','','.w-cart-compare'),(41232,'watch-mobile','.w-cart-compare .dropdown li','padding-top','5','','','.w-cart-compare'),(41233,'watch-mobile','.w-cart-compare .delete-cart','padding-top','10','','','.w-cart-compare'),(41234,'watch-mobile','.w-cart-compare .product','padding-top','10','','','.w-cart-compare'),(41235,'watch-mobile','.w-cart-compare .cart-cell','padding-top','0','','','.w-cart-compare'),(41236,'watch-mobile','.w-cart-compare .attributes-cell','padding-top','8','','','.w-cart-compare'),(41237,'watch-mobile','.w-cart-compare .price-label','padding-top','10','','','.w-cart-compare'),(41238,'watch-mobile','.w-cart-compare .price-cell','padding-top','8','','','.w-cart-compare'),(41239,'watch-mobile','.w-cart-compare .product-label','padding-top','15','','','.w-cart-compare'),(41240,'watch-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-top','1','','','.w-cart-up-sell'),(41241,'watch-mobile','.w-cart-up-sell .w-list-type-1','padding-top','0','','','.w-cart-up-sell'),(41242,'watch-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-top','0','1','','.w-cart-up-sell'),(41243,'watch-mobile','.w-catalog-additional-images li','padding-top','10','','','.w-catalog-additional-images'),(41244,'watch-mobile','.w-catalog-additional-images ul','padding-top','0','','','.w-catalog-additional-images'),(41245,'watch-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-top','5','','','.w-catalog-b2b-add-button'),(41246,'watch-mobile','.w-catalog-compare td','padding-top','10','','','.w-catalog-compare'),(41247,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','padding-top','12','','','.w-catalog-compare'),(41248,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','padding-top','10','2','','.w-catalog-compare'),(41249,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-top','0','','','.w-catalog-compare'),(41250,'watch-mobile','.w-catalog-items-on-page .before, .w-catalog-items-on-page .after','padding-top','5','','','.w-catalog-items-on-page'),(41251,'watch-mobile','.w-catalog-paging .paging-item','padding-top','0','','','.w-catalog-paging'),(41252,'watch-mobile','.w-checkout-billing-address .same-address','padding-top','10','','','.w-checkout-billing-address'),(41253,'watch-mobile','.w-checkout-billing-address .edit-ab','padding-top','5','','','.w-checkout-billing-address'),(41254,'watch-mobile','.w-checkout-create-account .create-account-switcher','padding-top','3','','','.w-checkout-create-account'),(41255,'watch-mobile','.w-checkout-create-account .create-account','padding-top','10','','','.w-checkout-create-account'),(41256,'watch-mobile','.w-checkout-gdpr .privacy-row','padding-top','0','','','.w-checkout-gdpr'),(41257,'watch-mobile','.w-checkout-gdpr .terms-login','padding-top','0','','','.w-checkout-gdpr'),(41258,'watch-mobile','.w-checkout-shipping .sub-item','padding-top','5','','','.w-checkout-shipping'),(41259,'watch-mobile','.w-checkout-shipping-address .buttons-under-drop .add-ab','padding-top','5','','','.w-checkout-shipping-address'),(41260,'watch-mobile','.w-checkout-shipping-address .edit-ab','padding-top','5','','','.w-checkout-shipping-address'),(41261,'watch-mobile','.w-checkout-shipping-choice span','padding-top','7','','','.w-checkout-shipping-choice'),(41262,'watch-mobile','.w-checkout-shipping-choice span','padding-top','7','','','.w-checkout-shipping-choice'),(41263,'watch-mobile','.w-checkout-terms .required-message','padding-top','5','','','.w-checkout-terms'),(41264,'watch-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-top','20','','','.w-communication-new-topic'),(41265,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-top','5','','','.w-communication-new-topic'),(41266,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-top','0','','','.w-communication-new-topic'),(41267,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-top','5','','','.w-communication-new-topic'),(41268,'watch-mobile','.w-communication-new-topic .topick-left-col','padding-top','24','','','.w-communication-new-topic'),(41269,'watch-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-top','10','','','.w-communication-new-topic'),(41270,'watch-mobile','.w-communication-post .communication-post-author','padding-top','10','','','.w-communication-post'),(41271,'watch-mobile','.w-delivery-day .left-count','padding-top','5','','','.w-delivery-day'),(41272,'watch-mobile','.w-delivery-day .left-text-left','padding-top','24','','','.w-delivery-day'),(41273,'watch-mobile','.w-delivery-day .left-text-right','padding-top','24','','','.w-delivery-day'),(41274,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-top','10','','','.w-image-maps'),(41275,'watch-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-top','3','','','.w-multi-cart-actions'),(41276,'watch-mobile','.w-multi-cart-cart-switcher .carts-switcher','padding-top','20','','','.w-multi-cart-cart-switcher'),(41277,'watch-mobile','.w-neighbour-checkout .neighbour-comment-box','padding-top','10','','','.w-neighbour-checkout'),(41278,'watch-mobile','.w-personal-gift-status-bar .start-label','padding-top','0','','','.w-personal-gift-status-bar'),(41279,'watch-mobile','.w-personal-gift-status-bar .end-label','padding-top','0','','','.w-personal-gift-status-bar'),(41280,'watch-mobile','.w-personal-gift-status-bar .timeline','padding-top','16','','','.w-personal-gift-status-bar'),(41281,'watch-mobile','.w-personal-gift-status-bar .inform','padding-top','0','4','','.w-personal-gift-status-bar'),(41282,'watch-mobile','.w-personal-gift-status-bar .end-date','padding-top','0','3','','.w-personal-gift-status-bar'),(41283,'watch-mobile','.w-product-available-in-warehouses .warehouse-item','padding-top','0','','','.w-product-available-in-warehouses'),(41284,'watch-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(41285,'watch-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(41286,'watch-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(41287,'watch-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(41288,'watch-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(41289,'watch-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(41290,'watch-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(41291,'watch-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(41292,'watch-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(41293,'watch-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(41294,'watch-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(41295,'watch-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(41296,'watch-mobile','.w-product-customers-activity .customers-activity','padding-top','35','','','.w-product-customers-activity'),(41297,'watch-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(41298,'watch-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(41299,'watch-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(41300,'watch-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(41301,'watch-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(41302,'watch-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(41303,'watch-mobile','.w-promotions .nextdiscount .content > div','padding-top','10','','','.w-promotions'),(41304,'watch-mobile','.w-promotions .promo-cart-discount .master .item','padding-top','0','','','.w-promotions'),(41305,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-top','0','','','.w-promotions'),(41306,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-top','0','','','.w-promotions'),(41307,'watch-mobile','.w-promotions .promo-salemaker .item','padding-top','20','','','.w-promotions'),(41308,'watch-mobile','.w-promotions .promo-salemaker .discount','padding-top','0','','','.w-promotions'),(41309,'watch-mobile','.w-promotions .promo-cart-discount .slave .item','padding-top','20','','','.w-promotions'),(41310,'watch-mobile','.w-promotions .promo-item','padding-top','30','','','.w-promotions'),(41311,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','padding-top','0','','','.w-promotions'),(41312,'watch-mobile','.w-promotions .prom-multi-discount .promo-product','padding-top','20','','','.w-promotions'),(41313,'watch-mobile','.w-promotions .nextdiscount .promo-for-each','padding-top','3','','','.w-promotions'),(41314,'watch-mobile','.w-quote-products .empty','padding-top','100','','','.w-quote-products'),(41315,'watch-mobile','.w-reviews-content .author','padding-top','0','','','.w-reviews-content'),(41316,'watch-mobile','.w-reviews-content .item','padding-top','20','','','.w-reviews-content'),(41317,'watch-mobile','.w-reviews-content .review','padding-top','20','','','.w-reviews-content'),(41318,'watch-mobile','.w-sitemap-delivery-location > ul','padding-top','0','','','.w-sitemap-delivery-location'),(41319,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-top','0','','','.w-sitemap-delivery-location'),(41320,'watch-mobile','.w-top-text .top-text','padding-top','5','','','.w-top-text'),(41321,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-template','padding-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(41322,'watch-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding-top','25','','','.w-wedding-registry-widgets-manage-banner'),(41323,'watch-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding-top','15','','','.w-wedding-registry-widgets-manage-banner'),(41324,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-top','17','','','.w-wedding-registry-widgets-photos'),(41325,'watch-mobile','.w-wedding-registry-widgets-products .price','padding-top','5','','','.w-wedding-registry-widgets-products'),(41326,'watch-mobile','.w-wedding-registry-widgets-products .rating','padding-top','10','','','.w-wedding-registry-widgets-products'),(41327,'watch-mobile','.w-wedding-registry-widgets-search-registry-button ','padding-top','5','','','.w-wedding-registry-widgets-search-registry-button'),(41328,'watch-mobile','.b-quantity .qty-box input[type=\'text\']','padding-top','5','','','.b-quantity'),(41329,'watch-mobile','.w-filters .filter-box-content ul','padding-top','0','','','.w-filters'),(41330,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top_important','important','','','.b-data-table'),(41331,'watch-mobile','.b-data-table table.dataTable thead td','padding-top_important','important','','','.b-data-table'),(41332,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top_important','important','','','.b-data-table'),(41333,'watch-mobile','.b-data-table table.dataTable tbody td','padding-top_important','important','','','.b-data-table'),(41334,'watch-mobile','.batchPr .w-batch-products','padding-top_important','important','','','.batchPr'),(41335,'watch-mobile','.w-categories .image','padding_bottom_measure','%','','','.w-categories'),(41336,'watch-mobile','.w-top-categories .image','padding_bottom_measure','%','','','.w-top-categories'),(41340,'watch-mobile','.w-cart-give-away .ga_img','padding_left_measure','%','','','.w-cart-give-away'),(41341,'watch-mobile','.b-upload-file .upload-file-template','padding_left_measure','%','','','.b-upload-file'),(41348,'watch-mobile','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(41350,'watch-mobile','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(41351,'watch-mobile','.w-cart-give-away .ga_img','padding_right_measure','%','','','.w-cart-give-away'),(41352,'watch-mobile','.b-upload-file .upload-file-template','padding_right_measure','%','','','.b-upload-file'),(41353,'watch-mobile','.p-wedding-registry-manage .wedding-image','padding_top_measure','%','','','.p-wedding-registry-manage'),(41354,'watch-mobile','.p-wedding-registry-share .wedding-image','padding_top_measure','%','','','.p-wedding-registry-share'),(41355,'watch-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding_top_measure','%','','','.w-wedding-registry-widgets-manage-banner'),(41356,'watch-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding_top_measure','%','','','.w-wedding-registry-widgets-manage-banner'),(41357,'watch-mobile','.b-slick .slick-slide.dragging img','pointer-events','none','','','.b-slick'),(41358,'watch-mobile','.w-list-type-1_3 #add_all','position','fixed','','','.w-list-type-1_3'),(41359,'watch-mobile','.w-menu .hided.menu > ul','position','absolute','','','.w-menu'),(41360,'watch-mobile','.w-menu .hided.menu','position','relative','','','.w-menu'),(41361,'watch-mobile','.w-menu .hided.menu ul li','position','static','','','.w-menu'),(41362,'watch-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','position','static','','','.w-menu'),(41363,'watch-mobile','.w-menu .menu .menu-ico','position','relative','','','.w-menu'),(41364,'watch-mobile','.w-menu-big','position','relative','','','.w-menu-big'),(41365,'watch-mobile','.w-menu-slider > ul','position','relative','','','.w-menu-slider'),(41366,'watch-mobile','.w-menu-big > ul > li > ul','position','absolute','','','.w-menu-big'),(41367,'watch-mobile','.w-menu-big li','position','static','','','.w-menu-big'),(41368,'watch-mobile','.w-menu-slider > ul > li > ul','position','absolute','','','.w-menu-slider'),(41369,'watch-mobile','.w-menu-slider .close','position','absolute','','','.w-menu-slider'),(41370,'watch-mobile','.w-bestsellers .counter','position','relative','','','.w-bestsellers'),(41371,'watch-mobile','.w-bestsellers .heading-3','position','relative','','','.w-bestsellers'),(41372,'watch-mobile','.w-bestsellers .item','position','relative','','','.w-bestsellers'),(41373,'watch-mobile','.w-bestsellers .item','position','absolute','3','','.w-bestsellers'),(41374,'watch-mobile','.w-banner .banner','position','relative','','','.w-banner'),(41375,'watch-mobile','.b-switch .bootstrap-switch','position','relative','','','.b-switch'),(41376,'watch-mobile','.w-list-type-1 .rating-count','position','relative','','','.w-list-type-1'),(41377,'watch-mobile','.w-bestsellers .heading-3','position','absolute','3','','.w-bestsellers'),(41378,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(41379,'watch-mobile','.w-filters .input-checkbox','position','absolute','','','.w-filters'),(41380,'watch-mobile','.w-list-type-2_2 .sale','position','absolute','4','','.w-list-type-2_2'),(41381,'watch-mobile','.w-sale .sale-holder','position','relative','','','.w-sale'),(41382,'watch-mobile','.w-sale .badge','position','absolute','','','.w-sale'),(41383,'watch-mobile','.w-product-wedding-registry-button .btn','position','absolute','3','','.w-product-wedding-registry-button'),(41384,'watch-mobile','.b-fancybox #fancybox-loading','position','fixed','','','.b-fancybox'),(41385,'watch-mobile','.w-menu-horizontal li','position','relative','','','.w-menu-horizontal'),(41386,'watch-mobile','.b-fancybox .fancybox-nav span','position','absolute','','','.b-fancybox'),(41392,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','position','relative','4','','.b-multi-page-checkout'),(41393,'watch-mobile','.b-pass-strength .pass-strength','position','relative','','','.b-pass-strength'),(41394,'watch-mobile','.b-pass-strength .pass-strength span','position','absolute','','','.b-pass-strength'),(41395,'watch-mobile','.w-reviews .heading-3','position','absolute','3','','.w-reviews'),(41396,'watch-mobile','.w-product-reviews .reviews-list .review','position','absolute','3','','.w-product-reviews'),(41397,'watch-mobile','.w-product-reviews .reviews-list .review','position','relative','','','.w-product-reviews'),(41398,'watch-mobile','.w-quote .cart-box','position','relative','','','.w-quote'),(41399,'watch-mobile','.w-product-reviews .reviews-list span','position','relative','','','.w-product-reviews'),(41400,'watch-mobile','.p-blog-index .author .avatar','position','relative','','','.p-blog-index'),(41401,'watch-mobile','.w-product-personal-catalog-button .btn','position','relative','','','.w-product-personal-catalog-button'),(41402,'watch-mobile','.b-info-popup .info-popup div','position','absolute','','','.b-info-popup'),(41403,'watch-mobile','.w-menu-mobile .menu-slider .open','position','fixed','','','.w-menu-mobile'),(41404,'watch-mobile','.w-promo-code .holder','position','relative','','','.w-promo-code'),(41405,'watch-mobile','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(41406,'watch-mobile','.p-wedding-registry-view h1','position','relative','3','','.p-wedding-registry-view'),(41411,'watch-mobile','.testimonials .heading-3','position','absolute','3','',''),(41412,'watch-mobile','.testimonials .heading-3','position','relative','','',''),(41413,'watch-mobile','.testimonials .rating','position','relative','','',''),(41414,'watch-mobile','.testimonials .review','position','relative','','',''),(41415,'watch-mobile','.testimonials .review','position','absolute','3','',''),(41416,'watch-mobile','.testimonials .reviews-list span','position','relative','','',''),(41417,'watch-mobile','.p-wedding-registry-manage .wr-search','position','relative','','','.p-wedding-registry-manage'),(41418,'watch-mobile','.p-wedding-registry-manage .wr-search button','position','absolute','','','.p-wedding-registry-manage'),(41429,'watch-mobile','.w-list-type-2_2 .sale','position','absolute','','','.w-list-type-2_2'),(41430,'watch-mobile','.w-list-type-2_2 .sale','position','absolute','3','','.w-list-type-2_2'),(41431,'watch-mobile','.w-list-type-2_2 .image','position','relative','','','.w-list-type-2_2'),(41432,'watch-mobile','.w-list-type-2 .sale','position','absolute','','','.w-list-type-2'),(41433,'watch-mobile','.w-list-type-2 .sale','position','absolute','3','','.w-list-type-2'),(41434,'watch-mobile','.w-product-wedding-registry-button .btn','position','absolute','4','','.w-product-wedding-registry-button'),(41435,'watch-mobile','.w-list-type-2 .sale','position','absolute','4','','.w-list-type-2'),(41436,'watch-mobile','.w-product-wedding-registry-button .btn','position','relative','','','.w-product-wedding-registry-button'),(41437,'watch-mobile','.w-product-personal-catalog-button .btn','position','absolute','3','','.w-product-personal-catalog-button'),(41438,'watch-mobile','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(41439,'watch-mobile','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(41440,'watch-mobile','.w-account a.my-acc-link','position','relative','','','.w-account'),(41441,'watch-mobile','.b-fancybox .fancybox-close','position','absolute','','','.b-fancybox'),(41442,'watch-mobile','.w-menu-horizontal ul ul','position','absolute','','','.w-menu-horizontal'),(41443,'watch-mobile','.b-fancybox .fancybox-nav','position','absolute','','','.b-fancybox'),(41444,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','position','relative','3','','.b-form'),(41445,'watch-mobile','.b-form .radio-button input[type=\"radio\"]','position','relative','','','.b-form'),(41446,'watch-mobile','.p-wedding-registry-index .search-list','position','absolute','3','','.p-wedding-registry-index'),(41447,'watch-mobile','.p-wedding-registry-index .search-list','position','relative','','','.p-wedding-registry-index'),(41448,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no','position','absolute','','','.b-form'),(41449,'watch-mobile','.b-form .radio-buttons .radio-button','position','relative','','','.b-form'),(41450,'watch-mobile','.b-form .form-buttons','position','relative','','','.b-form'),(41451,'watch-mobile','.p-wedding-registry-search h1','position','relative','4','','.p-wedding-registry-search'),(41453,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','position','relative','3','','.b-switch'),(41454,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','position','relative','3','','.b-switch'),(41455,'watch-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position','absolute','','','.b-switch'),(41456,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','position','absolute','','','.b-slick'),(41457,'watch-mobile','.b-bottom .footerTitle','position','absolute','290,4','','.b-bottom'),(41458,'watch-mobile','.b-bottom .footerTitle','position','relative','290','','.b-bottom'),(41459,'watch-mobile','.w-search .search','position','relative','','','.w-search'),(41460,'watch-mobile','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(41461,'watch-mobile','.w-search .suggest','position','absolute','','','.w-search'),(41462,'watch-mobile','.w-banner .image-text-banner','position','relative','','','.w-banner'),(41463,'watch-mobile','.w-banner .banner img + img','position','absolute','','','.w-banner'),(41464,'watch-mobile','.w-banner .image-text-banner .text-banner','position','absolute','','','.w-banner'),(41465,'watch-mobile','.w-currencies .current','position','relative','','','.w-currencies'),(41466,'watch-mobile','.w-currencies .select','position','absolute','','','.w-currencies'),(41467,'watch-mobile','.w-filters .head-filter-widget','position','relative','','','.w-filters'),(41468,'watch-mobile','.w-currencies .current','position','absolute','3','','.w-currencies'),(41469,'watch-mobile','.w-currencies .currencies','position','relative','','','.w-currencies'),(41470,'watch-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(41471,'watch-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','position','absolute','','','.w-compare-box-item'),(41472,'watch-mobile','.w-compare-box-item .checkbox:not(checked) + span','position','relative','','','.w-compare-box-item'),(41473,'watch-mobile','.w-compare-box-item .checkbox:not(checked)','position','absolute','','','.w-compare-box-item'),(41474,'watch-mobile','.b-slick .slick-slider','position','relative','','','.b-slick'),(41475,'watch-mobile','.b-slick .slick-track','position','relative','','','.b-slick'),(41478,'watch-mobile','.b-fancybox .fancybox-title-outside-wrap','position','relative','','','.b-fancybox'),(41479,'watch-mobile','.b-fancybox .fancybox-title','position','relative','','','.b-fancybox'),(41480,'watch-mobile','.b-fancybox .fancybox-title-float-wrap','position','absolute','','','.b-fancybox'),(41481,'watch-mobile','.b-info-popup .info-popup','position','relative','','','.b-info-popup'),(41484,'watch-mobile','.b-info-popup .info-popup div','position','absolute','3','','.b-info-popup'),(41485,'watch-mobile','.b-fancybox .fancybox-tmp','position','absolute','','','.b-fancybox'),(41486,'watch-mobile','.b-fancybox .fancybox-skin','position','relative','','','.b-fancybox'),(41487,'watch-mobile','.b-fancybox .fancybox-title-over-wrap','position','absolute','','','.b-fancybox'),(41488,'watch-mobile','.b-fancybox .fancybox-wrap','position','absolute','','','.b-fancybox'),(41489,'watch-mobile','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(41490,'watch-mobile','.w-menu-style-1 li','position','relative','','','.w-menu-style-1'),(41491,'watch-mobile','.w-menu-style-1 ul ul','position','absolute','','','.w-menu-style-1'),(41493,'watch-mobile','.b-fancybox .fancybox-overlay-fixed','position','fixed','','','.b-fancybox'),(41494,'watch-mobile','.b-fancybox .fancybox-overlay','position','absolute','','','.b-fancybox'),(41495,'watch-mobile','.b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner','position','relative','','','.b-fancybox'),(41497,'watch-mobile','.p-wedding-registry-share .invite-remove','position','absolute','','','.p-wedding-registry-share'),(41498,'watch-mobile','.p-wedding-registry-share .address-row','position','relative','','','.p-wedding-registry-share'),(41499,'watch-mobile','.w-text .customer-service','position','absolute','3','','.w-text'),(41500,'watch-mobile','.w-text .customer-service','position','relative','','','.w-text'),(41502,'watch-mobile','.w-banner .carousel-text','position','absolute','','','.w-banner'),(41503,'watch-mobile','.b-form .checkbox-style','position','absolute','','','.b-form'),(41504,'watch-mobile','.w-banner .carousel .item','position','relative','','','.w-banner'),(41505,'watch-mobile','.b-slick .slick-list','position','relative','','','.b-slick'),(41506,'watch-mobile','.b-rating #stars-default .glyphicon','position','relative','','','.b-rating'),(41507,'watch-mobile','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(41508,'watch-mobile','.w-cart .cart-box','position','relative','','','.w-cart'),(41509,'watch-mobile','.w-cart .cart-box.hover-box .cart-content','position','absolute','','','.w-cart'),(41510,'watch-mobile','.p-reviews-info .review-info-text','position','absolute','4','','.p-reviews-info'),(41511,'watch-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','position','relative','3','','.w-cart-discount-coupon'),(41512,'watch-mobile','.w-cart .cart-box-link','position','relative','','','.w-cart'),(41515,'watch-mobile','.b-form .addresses .address-item input[type=\"radio\"]','position','relative','','','.b-form'),(41517,'watch-mobile','.b-form .hide-billing-address','position','absolute','','','.b-form'),(41519,'watch-mobile','.b-form .discount-box input[type=\"text\"]','position','relative','','','.b-form'),(41520,'watch-mobile','.b-fancybox .filter-listing-preloader','position','absolute','','','.b-fancybox'),(41521,'watch-mobile','.b-fancybox .filter-listing-loader','position','absolute','','','.b-fancybox'),(41522,'watch-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(41523,'watch-mobile','.b-datepicker .datepicker-dropdown','position','absolute','','','.b-datepicker'),(41524,'watch-mobile','.b-form .columns .col-2','position','relative','','','.b-form'),(41525,'watch-mobile','.view-all','position','absolute','3','',''),(41526,'watch-mobile','.view-all','position','relative','','',''),(41527,'watch-mobile','.w-list-type-1_3 .sale','position','absolute','4','','.w-list-type-1_3'),(41528,'watch-mobile','.w-list-type-1_3 .sale','position','absolute','','','.w-list-type-1_3'),(41529,'watch-mobile','.w-list-type-1_3 .sale','position','absolute','3','','.w-list-type-1_3'),(41530,'watch-mobile','.w-list-type-2 .image','position','relative','','','.w-list-type-2'),(41531,'watch-mobile','.p-wedding-registry-manage h1','position','relative','3','','.p-wedding-registry-manage'),(41532,'watch-mobile','.p-wedding-registry-search h1','position','relative','3','','.p-wedding-registry-search'),(41533,'watch-mobile','.view-all .btn','position','relative','','',''),(41534,'watch-mobile','.b-autocomplete .ui-autocomplete','position','absolute','','','.b-autocomplete'),(41535,'watch-mobile','.p-wedding-registry-manage h1','position','relative','4','','.p-wedding-registry-manage'),(41536,'watch-mobile','.p-wedding-registry-view h1','position','relative','4','','.p-wedding-registry-view'),(41537,'watch-mobile','.p-wedding-registry-share h1','position','relative','4','','.p-wedding-registry-share'),(41538,'watch-mobile','.p-wedding-registry-share h1','position','relative','3','','.p-wedding-registry-share'),(41539,'watch-mobile','.w-list-type-1_3 .image','position','relative','','','.w-list-type-1_3'),(41540,'watch-mobile','.w-list-type-1_2 .sale','position','absolute','3','','.w-list-type-1_2'),(41541,'watch-mobile','.w-list-type-1_2 .sale','position','absolute','4','','.w-list-type-1_2'),(41542,'watch-mobile','.w-list-type-1_2 .sale','position','absolute','','','.w-list-type-1_2'),(41543,'watch-mobile','.w-list-type-1_2 .image','position','relative','','','.w-list-type-1_2'),(41544,'watch-mobile','.b-bottom .pop-up-close','position','absolute','','','.b-bottom'),(41545,'watch-mobile','.p-reviews-info .review-info-text','position','relative','','','.p-reviews-info'),(41546,'watch-mobile','.w-list-type-1 .sale','position','absolute','4','','.w-list-type-1'),(41547,'watch-mobile','.w-list-type-1 .sale','position','absolute','3','','.w-list-type-1'),(41548,'watch-mobile','.w-list-type-1 .sale','position','absolute','','','.w-list-type-1'),(41549,'watch-mobile','.w-list-type-1 .image','position','relative','','','.w-list-type-1'),(41550,'watch-mobile','.w-filters .mobileCollapse','position','absolute','','','.w-filters'),(41551,'watch-mobile','.w-languages .current','position','absolute','3','','.w-languages'),(41552,'watch-mobile','.w-languages .languages','position','relative','','','.w-languages'),(41553,'watch-mobile','.w-languages .select','position','absolute','','','.w-languages'),(41554,'watch-mobile','.w-languages .current','position','relative','','','.w-languages'),(41555,'watch-mobile','.b-form .billing-address','position','relative','','','.b-form'),(41556,'watch-mobile','.w-reviews .review','position','absolute','3','','.w-reviews'),(41557,'watch-mobile','.w-quote .cart-box-link','position','relative','','','.w-quote'),(41558,'watch-mobile','.w-reviews .heading-3','position','relative','','','.w-reviews'),(41559,'watch-mobile','.w-reviews .review','position','relative','','','.w-reviews'),(41560,'watch-mobile','.w-reviews .rating','position','relative','','','.w-reviews'),(41561,'watch-mobile','.w-search .button-search','position','absolute','','','.w-search'),(41562,'watch-mobile','.w-reviews .reviews-list span','position','relative','','','.w-reviews'),(41564,'watch-mobile','.b-form .payment-method .item-radio input','position','relative','','','.b-form'),(41565,'watch-mobile','.b-form .required-message','position','absolute','','','.b-form'),(41566,'watch-mobile','.b-info .info','position','relative','','','.b-info'),(41567,'watch-mobile','.b-form .required-message-wrap','position','relative','','','.b-form'),(41568,'watch-mobile','.b-form .shipping-method .input input','position','relative','','','.b-form'),(41569,'watch-mobile','.b-form .same-address','position','relative','','','.b-form'),(41570,'watch-mobile','.b-info .info','position','relative','3','','.b-info'),(41571,'watch-mobile','.b-info-popup .info-popup','position','relative','3','','.b-info-popup'),(41572,'watch-mobile','.b-products-listing .hover-box','position','relative','','','.b-products-listing'),(41573,'watch-mobile','.b-products-listing .hover-box-content','position','absolute','3','','.b-products-listing'),(41574,'watch-mobile','.b-products-listing .hover-box-content','position','absolute','','','.b-products-listing'),(41575,'watch-mobile','.b-products-listing .loader','position','absolute','4','','.b-products-listing'),(41576,'watch-mobile','.b-products-listing .loader','position','absolute','3','','.b-products-listing'),(41577,'watch-mobile','.b-products-listing .loader','position','relative','','','.b-products-listing'),(41578,'watch-mobile','.b-products-listing .products-listing .btn-buy','position','relative','3','','.b-products-listing'),(41579,'watch-mobile','.b-products-listing .products-listing .image','position','relative','','','.b-products-listing'),(41580,'watch-mobile','.b-products-listing .products-listing .promos-info','position','absolute','','','.b-products-listing'),(41581,'watch-mobile','.b-products-listing .products-listing .qty-input.hidden','position','absolute','3','','.b-products-listing'),(41582,'watch-mobile','.b-products-listing .products-listing .radio-attributes input','position','relative','','','.b-products-listing'),(41583,'watch-mobile','.b-products-listing .promo','position','absolute','','','.b-products-listing'),(41584,'watch-mobile','.b-products-listing .promo-icon','position','relative','','','.b-products-listing'),(41585,'watch-mobile','.b-products-listing .promos-info','position','relative','','','.b-products-listing'),(41586,'watch-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(41587,'watch-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(41588,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(41589,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(41590,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(41591,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(41592,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(41593,'watch-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(41594,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(41595,'watch-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(41596,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(41597,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(41598,'watch-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(41599,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(41600,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(41601,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(41602,'watch-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(41603,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(41604,'watch-mobile','.b-menu-burger_icon .menu-style[data-burger_icon]','position','relative','','','.b-menu-burger_icon'),(41605,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-1 > li','position','relative','','','.b-menu-lev_display-down'),(41606,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','position','absolute','','','.b-menu-lev_display-down'),(41607,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-2 > li','position','relative','','','.b-menu-lev_display-down'),(41608,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','position','absolute','','','.b-menu-lev_display-down'),(41609,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-3 > li','position','relative','','','.b-menu-lev_display-down'),(41610,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','position','absolute','','','.b-menu-lev_display-down'),(41611,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-4 > li','position','relative','','','.b-menu-lev_display-down'),(41612,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','position','absolute','','','.b-menu-lev_display-down'),(41613,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-5 > li','position','relative','','','.b-menu-lev_display-down'),(41614,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','position','absolute','','','.b-menu-lev_display-down'),(41615,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-1 > li','position','relative','','','.b-menu-lev_display-left'),(41616,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','position','absolute','','','.b-menu-lev_display-left'),(41617,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-2 > li','position','relative','','','.b-menu-lev_display-left'),(41618,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','position','absolute','','','.b-menu-lev_display-left'),(41619,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-3 > li','position','relative','','','.b-menu-lev_display-left'),(41620,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','position','absolute','','','.b-menu-lev_display-left'),(41621,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-4 > li','position','relative','','','.b-menu-lev_display-left'),(41622,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','position','absolute','','','.b-menu-lev_display-left'),(41623,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-5 > li','position','relative','','','.b-menu-lev_display-left'),(41624,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','position','absolute','','','.b-menu-lev_display-left'),(41625,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-1 > li','position','relative','','','.b-menu-lev_display-lra'),(41626,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','position','absolute','','','.b-menu-lev_display-lra'),(41627,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-2 > li','position','relative','','','.b-menu-lev_display-lra'),(41628,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','position','absolute','','','.b-menu-lev_display-lra'),(41629,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-3 > li','position','relative','','','.b-menu-lev_display-lra'),(41630,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','position','absolute','','','.b-menu-lev_display-lra'),(41631,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-4 > li','position','relative','','','.b-menu-lev_display-lra'),(41632,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','position','absolute','','','.b-menu-lev_display-lra'),(41633,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-5 > li','position','relative','','','.b-menu-lev_display-lra'),(41634,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','position','absolute','','','.b-menu-lev_display-lra'),(41635,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right'),(41636,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','position','absolute','','','.b-menu-lev_display-right'),(41637,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right'),(41638,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','position','absolute','','','.b-menu-lev_display-right'),(41639,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right'),(41640,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','position','absolute','','','.b-menu-lev_display-right'),(41641,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right'),(41642,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','position','absolute','','','.b-menu-lev_display-right'),(41643,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right'),(41644,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','position','absolute','','','.b-menu-lev_display-right'),(41645,'watch-mobile','.b-menu-lev_display-right_top .menu-style[data-lev2_display=\"right_top\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right_top'),(41646,'watch-mobile','.b-menu-lev_display-right_top .menu-style[data-lev3_display=\"right_top\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right_top'),(41647,'watch-mobile','.b-menu-lev_display-right_top .menu-style[data-lev4_display=\"right_top\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right_top'),(41648,'watch-mobile','.b-menu-lev_display-right_top .menu-style[data-lev5_display=\"right_top\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right_top'),(41649,'watch-mobile','.b-menu-lev_display-right_top .menu-style[data-lev6_display=\"right_top\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right_top'),(41650,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .level-1','position','relative','','','.b-menu-lev_display-slide'),(41651,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] .level-2','position','relative','','','.b-menu-lev_display-slide'),(41652,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','position','absolute','','','.b-menu-lev_display-slide'),(41653,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] .level-3','position','relative','','','.b-menu-lev_display-slide'),(41654,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','position','absolute','','','.b-menu-lev_display-slide'),(41655,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] .level-4','position','relative','','','.b-menu-lev_display-slide'),(41656,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','position','absolute','','','.b-menu-lev_display-slide'),(41657,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] .level-5','position','relative','','','.b-menu-lev_display-slide'),(41658,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','position','absolute','','','.b-menu-lev_display-slide'),(41659,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','position','absolute','','','.b-menu-lev_display-slide'),(41660,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width'),(41661,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','position','absolute','','','.b-menu-lev_display-width'),(41662,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width'),(41663,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','position','absolute','','','.b-menu-lev_display-width'),(41664,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width'),(41665,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','position','absolute','','','.b-menu-lev_display-width'),(41666,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width'),(41667,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','position','absolute','','','.b-menu-lev_display-width'),(41668,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width'),(41669,'watch-mobile','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','position','absolute','','','.b-menu-lev_display-width'),(41670,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width_cont'),(41671,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','position','absolute','','','.b-menu-lev_display-width_cont'),(41672,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width_cont'),(41673,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','position','absolute','','','.b-menu-lev_display-width_cont'),(41674,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width_cont'),(41675,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','position','absolute','','','.b-menu-lev_display-width_cont'),(41676,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width_cont'),(41677,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','position','absolute','','','.b-menu-lev_display-width_cont'),(41678,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width_cont'),(41679,'watch-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','position','absolute','','','.b-menu-lev_display-width_cont'),(41680,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(41681,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(41682,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(41683,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(41684,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(41685,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','position','fixed','','','.b-menu-open_from-left'),(41686,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','position','absolute','','','.b-menu-style-1'),(41687,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','position','static','','','.b-menu-style-2'),(41688,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','position','relative','','','.b-menu-style-2'),(41689,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','position','absolute','3','','.b-menu-style-2'),(41690,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','position','static','','','.b-menu-style-2'),(41691,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','position','relative','','','.b-menu-style-2'),(41692,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','position','absolute','3','','.b-menu-style-2'),(41693,'watch-mobile','.b-messages .messMenuButton span','position','relative','','','.b-messages'),(41694,'watch-mobile','.b-messages .messBtnMenuDelete','position','relative','3','','.b-messages'),(41695,'watch-mobile','.b-messages .messBtnMenuStarred','position','relative','3','','.b-messages'),(41696,'watch-mobile','.b-messages span.starred::before','position','relative','','','.b-messages'),(41697,'watch-mobile','.b-messages .messBtnMenuUnread','position','relative','3','','.b-messages'),(41698,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-messages'),(41699,'watch-mobile','.b-preloader .preloader','position','absolute','','','.b-preloader'),(41700,'watch-mobile','.b-preloader .preloader','position','absolute','3','','.b-preloader'),(41701,'watch-mobile','.b-select-suggest .select2-search','position','relative','','','.b-select-suggest'),(41702,'watch-mobile','.b-select-suggest .select2-container .select2-choice','position','relative','','','.b-select-suggest'),(41703,'watch-mobile','.b-select-suggest .select2-search-choice-close','position','absolute','','','.b-select-suggest'),(41704,'watch-mobile','.b-select-suggest .select2-drop-mask','position','fixed','','','.b-select-suggest'),(41705,'watch-mobile','.b-select-suggest .select2-drop','position','absolute','','','.b-select-suggest'),(41706,'watch-mobile','.b-select-suggest .select2-results','position','relative','','','.b-select-suggest'),(41707,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position','absolute','','','.b-select-suggest'),(41708,'watch-mobile','.b-select-suggest .select2-measure-scrollbar','position','absolute','','','.b-select-suggest'),(41709,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices','position','relative','','','.b-select-suggest'),(41710,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','position','absolute','','','.b-select-suggest'),(41711,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-select-suggest'),(41712,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','position','absolute','','','.b-select-suggest'),(41713,'watch-mobile','.b-select-suggest .select2-container','position','relative','','','.b-select-suggest'),(41714,'watch-mobile','.b-upload-file .snapshot','position','absolute','','','.b-upload-file'),(41715,'watch-mobile','.b-upload-file .upload-remove','position','absolute','','','.b-upload-file'),(41716,'watch-mobile','.b-upload-files .attach-active-holder .attach-file','position','absolute','','','.b-upload-files'),(41717,'watch-mobile','.batchPr .w-batch-products .item-holder','position','relative','','','.batchPr'),(41718,'watch-mobile','.batchPr .checkbox input:checked + span:before','position','static','','','.batchPr'),(41719,'watch-mobile','.batchPr .checkbox input + span','position','absolute','','','.batchPr'),(41720,'watch-mobile','.batchPr .batchSelect .checkbox','position','relative','','','.batchPr'),(41721,'watch-mobile','.batchPr .batchSelect','position','static','','','.batchPr'),(41722,'watch-mobile','.batchPr .w-batch-selected-products .item','position','relative','','','.batchPr'),(41723,'watch-mobile','.batchPr .checkbox input:not(checked) + span:before','position','absolute','','','.batchPr'),(41724,'watch-mobile','.batchPr .batchSelect','position','absolute','','','.batchPr'),(41725,'watch-mobile','.batchPr .btn-batch-remove','position','absolute','','','.batchPr'),(41726,'watch-mobile','.bell-ico .heading-2','position','relative','3','','.bell-ico'),(41727,'watch-mobile','.heading-ordered-items .heading-4','position','relative','3','','.heading-ordered-items'),(41728,'watch-mobile','.heading-saved-lists .heading-4','position','relative','3','','.heading-saved-lists'),(41729,'watch-mobile','.heading-settings .heading-4','position','relative','3','','.heading-settings'),(41804,'watch-mobile','.p-payer-order-confirmation .discount-ico','position','relative','3','','.p-payer-order-confirmation'),(41805,'watch-mobile','.p-payer-order-confirmation .comment-ico','position','relative','3','','.p-payer-order-confirmation'),(41806,'watch-mobile','.p-payer-order-confirmation .order-ico','position','relative','3','','.p-payer-order-confirmation'),(41807,'watch-mobile','.p-payer-order-pay .order-ico','position','relative','3','','.p-payer-order-pay'),(41808,'watch-mobile','.p-payer-order-pay .comment-ico','position','relative','3','','.p-payer-order-pay'),(41809,'watch-mobile','.p-payer-order-pay .discount-ico','position','relative','3','','.p-payer-order-pay'),(41810,'watch-mobile','.p-quick-order-index .all-scroll-div','position','fixed','','','.p-quick-order-index'),(41811,'watch-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(41812,'watch-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(41813,'watch-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(41814,'watch-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(41815,'watch-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(41816,'watch-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(41817,'watch-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(41818,'watch-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(41819,'watch-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(41820,'watch-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(41821,'watch-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(41822,'watch-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(41823,'watch-mobile','.p-sample-checkout-success .page-success > div','position','relative','','','.p-sample-checkout-success'),(41824,'watch-mobile','.p-sample-checkout-success .page-success','position','relative','','','.p-sample-checkout-success'),(41825,'watch-mobile','.savings-ico .heading-2','position','relative','3','','.savings-ico'),(41826,'watch-mobile','.shipping-ico .heading-2','position','relative','3','','.shipping-ico'),(41827,'watch-mobile','.shipping-ico .heading-2','position','relative','3','','.shipping-ico'),(41828,'watch-mobile','.shipping-ico .heading-2','position','relative','3','','.shipping-ico'),(41829,'watch-mobile','.w-account-address-book .heading-4','position','relative','','','.w-account-address-book'),(41830,'watch-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','position','relative','','','.w-account-addresses-list'),(41831,'watch-mobile','.w-blog-widget-categories-list a','position','relative','','','.w-blog-widget-categories-list'),(41832,'watch-mobile','.w-blog-widget-categories-list a','position','absolute','3','','.w-blog-widget-categories-list'),(41833,'watch-mobile','.w-blog-widget-most-popular-posts a','position','absolute','3','','.w-blog-widget-most-popular-posts'),(41834,'watch-mobile','.w-blog-widget-most-popular-posts a','position','relative','','','.w-blog-widget-most-popular-posts'),(41835,'watch-mobile','.w-blog-widget-post-comments-count span','position','relative','','','.w-blog-widget-post-comments-count'),(41836,'watch-mobile','.w-blog-widget-post-comments-count span','position','absolute','3','','.w-blog-widget-post-comments-count'),(41837,'watch-mobile','.w-blog-widget-post-linked-products .heading-2','position','relative','','','.w-blog-widget-post-linked-products'),(41838,'watch-mobile','.w-blog-widget-post-listing .post_comment','position','relative','','','.w-blog-widget-post-listing'),(41839,'watch-mobile','.w-blog-widget-post-listing .post_comment','position','absolute','3','','.w-blog-widget-post-listing'),(41840,'watch-mobile','.w-blog-widget-post-share ','position','absolute','4','','.w-blog-widget-post-share'),(41841,'watch-mobile','.w-blog-widget-post-share ','position','relative','','','.w-blog-widget-post-share'),(41842,'watch-mobile','.w-cart-bonus-points .btn-remove','position','relative','','','.w-cart-bonus-points'),(41843,'watch-mobile','.w-cart-bonus-points .title','position','relative','3','','.w-cart-bonus-points'),(41844,'watch-mobile','.w-cart-compare .remove-cart','position','absolute','','','.w-cart-compare'),(41845,'watch-mobile','.w-cart-compare .cart-cell > div','position','relative','','','.w-cart-compare'),(41846,'watch-mobile','.w-cart-compare .atr-col','position','absolute','3','','.w-cart-compare'),(41847,'watch-mobile','.w-cart-compare .atr-col','position','relative','','','.w-cart-compare'),(41848,'watch-mobile','.w-cart-credit-amount .btn-remove','position','relative','','','.w-cart-credit-amount'),(41849,'watch-mobile','.w-catalog-b2b-add-button ','position','fixed','','','.w-catalog-b2b-add-button'),(41850,'watch-mobile','.w-catalog-compare .compare .checkbox span','position','relative','','','.w-catalog-compare'),(41851,'watch-mobile','.w-catalog-paging .paging-holder','position','relative','','','.w-catalog-paging'),(41852,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','position','static','','','.w-catalog-paging'),(41853,'watch-mobile','.w-checkout-billing-address .addresses .address-item label','position','relative','','','.w-checkout-billing-address'),(41854,'watch-mobile','.w-checkout-billing-address .addresses .address-item label input','position','absolute','','','.w-checkout-billing-address'),(41855,'watch-mobile','.w-checkout-billing-address .genders-title input','position','relative','','','.w-checkout-billing-address'),(41856,'watch-mobile','.w-checkout-bonus-points .btn-remove','position','relative','','','.w-checkout-bonus-points'),(41857,'watch-mobile','.w-checkout-create-account .account-benefits strong','position','relative','3','','.w-checkout-create-account'),(41858,'watch-mobile','.w-checkout-credit-amount .btn-remove','position','relative','','','.w-checkout-credit-amount'),(41859,'watch-mobile','.w-checkout-shipping-address .addresses .address-item label input','position','absolute','','','.w-checkout-shipping-address'),(41860,'watch-mobile','.w-checkout-shipping-address .genders-title input','position','relative','','','.w-checkout-shipping-address'),(41861,'watch-mobile','.w-checkout-shipping-address .addresses .address-item label','position','relative','','','.w-checkout-shipping-address'),(41862,'watch-mobile','.w-checkout-shipping-choice input:checked + span','position','relative','','','.w-checkout-shipping-choice'),(41863,'watch-mobile','.w-checkout-shipping-choice input','position','absolute','','','.w-checkout-shipping-choice'),(41864,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','position','absolute','','','.w-checkout-shipping-choice'),(41865,'watch-mobile','.w-checkout-terms input[type=\"checkbox\"]','position','relative','','','.w-checkout-terms'),(41866,'watch-mobile','.w-checkout-terms .required-message-wrap','position','static','','','.w-checkout-terms'),(41867,'watch-mobile','.w-checkout-terms .terms-box','position','relative','','','.w-checkout-terms'),(41868,'watch-mobile','.w-coupons-and-vauchers-checkout .btn-remove','position','relative','','','.w-coupons-and-vauchers-checkout'),(41869,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','position','fixed','','','.w-image-maps'),(41870,'watch-mobile','.w-image-maps .svg-wrap svg','position','absolute','','','.w-image-maps'),(41871,'watch-mobile','.w-image-maps .svg-wrap','position','relative','','','.w-image-maps'),(41872,'watch-mobile','.w-multi-cart-actions .cart-actions','position','relative','','','.w-multi-cart-actions'),(41873,'watch-mobile','.w-neighbour-checkout .bootstrap-switch','position','relative','','','.w-neighbour-checkout'),(41874,'watch-mobile','.w-personal-gift-status-bar .inform','position','relative','4','','.w-personal-gift-status-bar'),(41875,'watch-mobile','.w-personal-gift-status-bar .end-date','position','relative','3','','.w-personal-gift-status-bar'),(41876,'watch-mobile','.w-product-customers-activity .customers-activity','position','fixed','','','.w-product-customers-activity'),(41877,'watch-mobile','.w-product-customers-activity .close','position','absolute','','','.w-product-customers-activity'),(41878,'watch-mobile','.w-promotions .prom-multi-discount .products','position','relative','','','.w-promotions'),(41879,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition','position','relative','','','.w-promotions'),(41880,'watch-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','position','relative','3','','.w-promotions'),(41881,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','position','relative','','','.w-promotions'),(41882,'watch-mobile','.w-promotions .promo-date','position','relative','','','.w-promotions'),(41883,'watch-mobile','.w-promotions .promo-cart-discount .slave .content','position','relative','','','.w-promotions'),(41884,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','position','relative','','','.w-promotions'),(41885,'watch-mobile','.w-promotions .promo-salemaker .discount','position','relative','','','.w-promotions'),(41886,'watch-mobile','.w-promotions .prom-multi-discount > .heading','position','relative','3','','.w-promotions'),(41887,'watch-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','position','relative','3','','.w-promotions'),(41888,'watch-mobile','.w-promotions .icon','position','relative','','','.w-promotions'),(41889,'watch-mobile','.w-reviews-content .review','position','absolute','3','','.w-reviews-content'),(41890,'watch-mobile','.w-reviews-content .review','position','relative','','','.w-reviews-content'),(41891,'watch-mobile','.w-taxable input[type=\"radio\"]','position','relative','','','.w-taxable'),(41892,'watch-mobile','.w-taxable input[type=\"checkbox\"]','position','relative','','','.w-taxable'),(41893,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(41894,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(41895,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(41896,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(41897,'watch-mobile','.w-wedding-registry-widgets-delete-link a','position','absolute','4','','.w-wedding-registry-widgets-delete-link'),(41898,'watch-mobile','.w-wedding-registry-widgets-delete-link a','position','relative','','','.w-wedding-registry-widgets-delete-link'),(41899,'watch-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','position','relative','','','.w-wedding-registry-widgets-manage-banner'),(41900,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','position','relative','','','.w-wedding-registry-widgets-photos'),(41901,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','position','relative','','','.w-wedding-registry-widgets-photos'),(41902,'watch-mobile','.w-wedding-registry-widgets-products .remove','position','absolute','','','.w-wedding-registry-widgets-products'),(41903,'watch-mobile','.w-wedding-registry-widgets-share-link a','position','relative','','','.w-wedding-registry-widgets-share-link'),(41904,'watch-mobile','.w-wedding-registry-widgets-share-link a','position','absolute','4','','.w-wedding-registry-widgets-share-link'),(41905,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','position','absolute','','','.w-filters'),(41906,'watch-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position_important','important','','','.b-switch'),(41907,'watch-mobile','.w-menu .hided.menu > ul','position_important','important','','','.w-menu'),(41908,'watch-mobile','.b-autocomplete .ui-autocomplete','position_important','important','','','.b-autocomplete'),(41909,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position_important','important','','','.b-select-suggest'),(41910,'watch-mobile','.w-checkout-billing-address .addresses .address-item label input','position_important','important','','','.w-checkout-billing-address'),(41911,'watch-mobile','.w-checkout-shipping-address .addresses .address-item label input','position_important','important','','','.w-checkout-shipping-address'),(41912,'watch-mobile','.w-menu-slider .close','right','10','','','.w-menu-slider'),(41913,'watch-mobile','.w-menu-big > ul > li > ul','right','0','','','.w-menu-big'),(41914,'watch-mobile','.w-list-type-2_2 .sale','right','0','4','','.w-list-type-2_2'),(41915,'watch-mobile','.b-fancybox .fancybox-next span','right','10','','','.b-fancybox'),(41916,'watch-mobile','.b-pass-strength .pass-strength span','right','10','','','.b-pass-strength'),(41917,'watch-mobile','.b-info-popup .info-popup.top-left div','right','13','3','','.b-info-popup'),(41918,'watch-mobile','.b-info-popup .info-popup.top-left div','right','-10','','','.b-info-popup'),(41919,'watch-mobile','.p-wedding-registry-view h1','right','-10','4','','.p-wedding-registry-view'),(41920,'watch-mobile','.p-wedding-registry-manage .wr-search button','right','5','','','.p-wedding-registry-manage'),(41923,'watch-mobile','.w-list-type-2_2 .sale','right','0','3','','.w-list-type-2_2'),(41924,'watch-mobile','.w-list-type-2_2 .sale','right','0','','','.w-list-type-2_2'),(41925,'watch-mobile','.w-list-type-2 .sale','right','0','','','.w-list-type-2'),(41926,'watch-mobile','.w-list-type-2 .sale','right','0','4','','.w-list-type-2'),(41927,'watch-mobile','.b-fancybox .fancybox-close','right','0','','','.b-fancybox'),(41928,'watch-mobile','.b-fancybox .fancybox-next','right','0','','','.b-fancybox'),(41929,'watch-mobile','.p-wedding-registry-search h1','right','-10','4','','.p-wedding-registry-search'),(41930,'watch-mobile','.b-bottom .footerTitle','right','0','290,4','','.b-bottom'),(41931,'watch-mobile','.b-slick button.slick-prev','right','auto','','','.b-slick'),(41932,'watch-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','right','auto','','','.b-slick'),(41933,'watch-mobile','.b-slick button.slick-next','right','0','','','.b-slick'),(41934,'watch-mobile','.w-socials .post_item > div','right','10','3','','.w-socials'),(41935,'watch-mobile','.w-banner .image-text-banner.top-right .text-banner','right','0','','','.w-banner'),(41936,'watch-mobile','.w-banner .image-text-banner.middle-right .text-banner','right','0','','','.w-banner'),(41937,'watch-mobile','.w-banner .image-text-banner.bottom-right .text-banner','right','0','','','.w-banner'),(41938,'watch-mobile','.w-currencies .current','right','0','3','','.w-currencies'),(41939,'watch-mobile','.b-fancybox .fancybox-title-float-wrap','right','50','','','.b-fancybox'),(41940,'watch-mobile','.w-list-type-1_3 #add_all','right','20','','','.w-list-type-1_3'),(41941,'watch-mobile','.b-fancybox .fancybox-overlay-fixed','right','0','','','.b-fancybox'),(41942,'watch-mobile','.p-wedding-registry-share .invite-remove','right','0','','','.p-wedding-registry-share'),(41943,'watch-mobile','.w-list-type-1_3 .sale','right','0','4','','.w-list-type-1_3'),(41944,'watch-mobile','.w-list-type-1_3 .sale','right','0','','','.w-list-type-1_3'),(41945,'watch-mobile','.p-wedding-registry-manage h1','right','-10','4','','.p-wedding-registry-manage'),(41946,'watch-mobile','.w-list-type-1_3 .sale','right','0','3','','.w-list-type-1_3'),(41947,'watch-mobile','.p-wedding-registry-share h1','right','-10','4','','.p-wedding-registry-share'),(41948,'watch-mobile','.w-list-type-2 .sale','right','0','3','','.w-list-type-2'),(41949,'watch-mobile','.w-list-type-1_2 .sale','right','0','3','','.w-list-type-1_2'),(41950,'watch-mobile','.w-list-type-1_2 .sale','right','0','4','','.w-list-type-1_2'),(41951,'watch-mobile','.w-list-type-1_2 .sale','right','0','','','.w-list-type-1_2'),(41952,'watch-mobile','.b-bottom .pop-up-close','right','6','','','.b-bottom'),(41953,'watch-mobile','.w-list-type-1 .sale','right','0','4','','.w-list-type-1'),(41954,'watch-mobile','.w-list-type-1 .sale','right','0','3','','.w-list-type-1'),(41955,'watch-mobile','.w-list-type-1 .sale','right','0','','','.w-list-type-1'),(41956,'watch-mobile','.w-filters .mobileCollapse','right','12','','','.w-filters'),(41957,'watch-mobile','.w-languages .current','right','0','3','','.w-languages'),(41958,'watch-mobile','.w-search .button-search','right','0','','','.w-search'),(41959,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right','100','','','.b-menu-lev_display-left'),(41960,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right','100','','','.b-menu-lev_display-left'),(41961,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right','100','','','.b-menu-lev_display-left'),(41962,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right','100','','','.b-menu-lev_display-left'),(41963,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right','100','','','.b-menu-lev_display-left'),(41964,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right','100','','','.b-menu-lev_display-lra'),(41965,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right','100','','','.b-menu-lev_display-lra'),(41966,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right','100','','','.b-menu-lev_display-lra'),(41967,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right','100','','','.b-menu-lev_display-lra'),(41968,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right','100','','','.b-menu-lev_display-lra'),(41969,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','right','10','3','','.b-menu-style-2'),(41970,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .parent > .no-link','right','40','3','','.b-menu-style-2'),(41971,'watch-mobile','.b-select-suggest .select2-search-choice-close','right','3','','','.b-select-suggest'),(41972,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','right','0','','','.b-select-suggest'),(41973,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','right','24','','','.b-select-suggest'),(41974,'watch-mobile','.b-upload-file .snapshot','right','5','','','.b-upload-file'),(41975,'watch-mobile','.b-upload-file .upload-remove','right','10','','','.b-upload-file'),(41976,'watch-mobile','.batchPr .w-batch-products .products-listing .slick-next','right','-10','','','.batchPr'),(41977,'watch-mobile','.batchPr .batchSelect','right','20','','','.batchPr'),(41978,'watch-mobile','.batchPr .btn-batch-remove','right','0','','','.batchPr'),(41987,'watch-mobile','.w-account-address-book .btn-del','right','0','','','.w-account-address-book'),(41988,'watch-mobile','.w-blog-widget-post-linked-products button.slick-next','right','10','','','.w-blog-widget-post-linked-products'),(41989,'watch-mobile','.w-blog-widget-post-share ','right','100','4','','.w-blog-widget-post-share'),(41990,'watch-mobile','.w-blog-widget-post-share','right','auto','0,4','','.w-blog-widget-post-share'),(41991,'watch-mobile','.w-blog-widget-related-posts button.slick-next','right','10','','','.w-blog-widget-related-posts'),(41992,'watch-mobile','.w-blog-widget-related-posts-by-category button.slick-next','right','10','','','.w-blog-widget-related-posts-by-category'),(41993,'watch-mobile','.w-cart-compare .dropdown .dropdown-menu','right','0','','','.w-cart-compare'),(41994,'watch-mobile','.w-cart-compare .atr-col','right','0','3','','.w-cart-compare'),(41995,'watch-mobile','.w-cart-compare .remove-cart','right','0','','','.w-cart-compare'),(41996,'watch-mobile','.w-multi-cart-actions .dropdown .dropdown-menu','right','0','','','.w-multi-cart-actions'),(41997,'watch-mobile','.w-product-customers-activity .customers-activity','right','20','','','.w-product-customers-activity'),(41998,'watch-mobile','.w-product-customers-activity .close','right','5','','','.w-product-customers-activity'),(41999,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','right','5','','','.w-upload-customer-id-upload-customer-id-form'),(42000,'watch-mobile','.w-wedding-registry-widgets-products .remove','right','0','','','.w-wedding-registry-widgets-products'),(42001,'watch-mobile','.b-fancybox .fancybox-title-float-wrap','right_measure','%','','','.b-fancybox'),(42002,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right_measure','%','','','.b-menu-lev_display-left'),(42003,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right_measure','%','','','.b-menu-lev_display-left'),(42004,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right_measure','%','','','.b-menu-lev_display-left'),(42005,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right_measure','%','','','.b-menu-lev_display-left'),(42006,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right_measure','%','','','.b-menu-lev_display-left'),(42007,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right_measure','%','','','.b-menu-lev_display-lra'),(42008,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right_measure','%','','','.b-menu-lev_display-lra'),(42009,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right_measure','%','','','.b-menu-lev_display-lra'),(42010,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right_measure','%','','','.b-menu-lev_display-lra'),(42011,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right_measure','%','','','.b-menu-lev_display-lra'),(42012,'watch-mobile','.b-info-popup .info-popup.top-left div','rotate','-135','3','','.b-info-popup'),(42013,'watch-mobile','.b-info-popup .info-popup div','rotate','-45','3','','.b-info-popup'),(42014,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','rotate','45','','','.w-checkout-shipping-choice'),(42015,'watch-mobile','.w-image-maps circle:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(42016,'watch-mobile','.w-image-maps rect:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(42017,'watch-mobile','.w-image-maps polygon:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(42018,'watch-mobile','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','stroke-width','0','','','.w-image-maps'),(42019,'watch-mobile','.w-tabs .tab-navigation','table-layout','fixed','','','.w-tabs'),(42020,'watch-mobile','.w-menu-big li a, .w-menu-big li .no-link','text-align','left','','','.w-menu-big'),(42021,'watch-mobile','.w-menu-big li li li','text-align','left','','','.w-menu-big'),(42022,'watch-mobile','.w-menu-slider > ul','text-align','center','','','.w-menu-slider'),(42023,'watch-mobile','.w-menu-slider .close','text-align','center','','','.w-menu-slider'),(42024,'watch-mobile','.w-menu-horizontal .box','text-align','center','','','.w-menu-horizontal'),(42025,'watch-mobile','.w-menu-slider > ul > li > ul','text-align','center','','','.w-menu-slider'),(42026,'watch-mobile','.w-bestsellers .item','text-align','center','3','','.w-bestsellers'),(42027,'watch-mobile','.w-menu-slider > ul > li > ul li','text-align','left','','','.w-menu-slider'),(42028,'watch-mobile','.w-bestsellers .counter','text-align','center','','','.w-bestsellers'),(42029,'watch-mobile','.b-social-login .social-login','text-align','center','','','.b-social-login'),(42030,'watch-mobile','.w-tabs .accordion-heading','text-align','center','','','.w-tabs'),(42031,'watch-mobile','.w-menu-style-1 .box','text-align','center','','','.w-menu-style-1'),(42032,'watch-mobile','.w-product-sale-ends .left','text-align','center','','','.w-product-sale-ends'),(42033,'watch-mobile','.w-sale .btn','text-align','center','','','.w-sale'),(42034,'watch-mobile','.w-login-block .buttons','text-align','right','','','.w-login-block'),(42035,'watch-mobile','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(42036,'watch-mobile','.w-menu-horizontal .menu-ico','text-align','center','','','.w-menu-horizontal'),(42037,'watch-mobile','.w-list-type-2_2 .sale','text-align','center','4','','.w-list-type-2_2'),(42038,'watch-mobile','.w-sale .image','text-align','center','','','.w-sale'),(42039,'watch-mobile','.w-sale .badge','text-align','center','','','.w-sale'),(42040,'watch-mobile','.w-menu-style-1 .menu-ico','text-align','center','','','.w-menu-style-1'),(42041,'watch-mobile','.w-menu-style-1 > ul','text-align','center','','','.w-menu-style-1'),(42042,'watch-mobile','.w-menu-slider .menu-ico','text-align','center','','','.w-menu-slider'),(42043,'watch-mobile','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(42044,'watch-mobile','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(42045,'watch-mobile','.w-product-collection .item','text-align','center','','','.w-product-collection'),(42046,'watch-mobile','.w-cart .price','text-align','right','','','.w-cart'),(42047,'watch-mobile','.b-fancybox .fancybox-nav span','text-align','center','','','.b-fancybox'),(42048,'watch-mobile','.p-reviews-info .review-info-image','text-align','center','','','.p-reviews-info'),(42049,'watch-mobile','.b-product-images .additional-images .item > div, .b-product-images .additional-videos .item > div','text-align','center','','','.b-product-images'),(42050,'watch-mobile','.w-product-buttons .btn, .w-product-buttons .btn-2, .w-product-buttons .btn-3, .w-product-buttons .btn-4','text-align','center','','','.w-product-buttons'),(42054,'watch-mobile','.w-categories .categories','text-align','center','','','.w-categories'),(42055,'watch-mobile','.w-categories .item','text-align','center','','','.w-categories'),(42056,'watch-mobile','.w-cart-checkout-btn a','text-align','center','290','','.w-cart-checkout-btn'),(42057,'watch-mobile','.b-price-box .price-box','text-align','right','','','.b-price-box'),(42058,'watch-mobile','.w-product-images .images','text-align','center','','','.w-product-images'),(42059,'watch-mobile','.w-success-continue-btn','text-align','center','291','','.w-success-continue-btn'),(42061,'watch-mobile','.w-catalog-listing-look .b2b','text-align','center','','','.w-catalog-listing-look'),(42062,'watch-mobile','.view-all','text-align','center','','',''),(42063,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','text-align','center','3','','.b-multi-page-checkout'),(42064,'watch-mobile','.w-list-type-1_2 .image','text-align','center','291','','.w-list-type-1_2'),(42065,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','text-align','center','','','.b-multi-page-checkout'),(42066,'watch-mobile','.b-multi-page-checkout .messageBox .info','text-align','left','','','.b-multi-page-checkout'),(42067,'watch-mobile','.p-wedding-registry-manage .remove','text-align','right','','','.p-wedding-registry-manage'),(42068,'watch-mobile','.w-delivery-location-top-location-list .deliveryName','text-align','center','','','.w-delivery-location-top-location-list'),(42075,'watch-mobile','.w-product-configurator .pc_qty','text-align','left','290','','.w-product-configurator'),(42076,'watch-mobile','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(42077,'watch-mobile','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(42078,'watch-mobile','.b-pagination .pagination .prev-pages','text-align','center','','','.b-pagination'),(42079,'watch-mobile','.b-bottom .confirm-popup .confirm-text','text-align','center','','','.b-bottom'),(42080,'watch-mobile','.b-bottom .confirm-popup .buttons','text-align','center','','','.b-bottom'),(42081,'watch-mobile','.b-pagination .pagination .prev','text-align','center','','','.b-pagination'),(42082,'watch-mobile','.b-pagination .pagination .page-number','text-align','center','','','.b-pagination'),(42083,'watch-mobile','.b-pagination .pagination .p-blog-index','text-align','right','','','.b-pagination'),(42084,'watch-mobile','.b-pagination .pagination .next','text-align','center','','','.b-pagination'),(42085,'watch-mobile','.b-pagination .pagination .next-pages','text-align','center','','','.b-pagination'),(42086,'watch-mobile','.b-pagination .pagination span','text-align','center','2','','.b-pagination'),(42090,'watch-mobile','.p-blog-index .nav-next','text-align','right','','','.p-blog-index'),(42091,'watch-mobile','.p-blog-index .form-submit','text-align','right','','','.p-blog-index'),(42092,'watch-mobile','.pop-up-content .buttons .btn-2','text-align','center','291','',''),(42093,'watch-mobile','.pop-up-content .buttons .btn','text-align','center','291','',''),(42094,'watch-mobile','.no-found','text-align','center','','',''),(42095,'watch-mobile','.w-list-type-2_2 .item','text-align','left','','','.w-list-type-2_2'),(42096,'watch-mobile','.w-list-type-2_2 .image','text-align','center','','','.w-list-type-2_2'),(42097,'watch-mobile','.w-list-type-2_2 .button-wishlist button','text-align','left','','','.w-list-type-2_2'),(42098,'watch-mobile','.w-list-type-2_2 .button-view a','text-align','left','','','.w-list-type-2_2'),(42099,'watch-mobile','.w-product-bonus-points > div > div','text-align','center','','','.w-product-bonus-points'),(42100,'watch-mobile','.w-account .account-title','text-align','center','','','.w-account'),(42101,'watch-mobile','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(42102,'watch-mobile','.b-fancybox .fancybox-close','text-align','center','','','.b-fancybox'),(42103,'watch-mobile','.w-menu-horizontal ul ul li','text-align','left','','','.w-menu-horizontal'),(42104,'watch-mobile','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(42105,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','text-align','center','3','','.b-form'),(42106,'watch-mobile','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(42107,'watch-mobile','.b-form .wedding-form .heading-2','text-align','left','','','.b-form'),(42108,'watch-mobile','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(42109,'watch-mobile','.p-quote-cart-index .w-quote-checkout-btn','text-align','right','','','.p-quote-cart-index'),(42110,'watch-mobile','.p-wedding-registry-index .middle-box','text-align','center','','','.p-wedding-registry-index'),(42111,'watch-mobile','.p-wedding-registry-manage .links','text-align','center','','','.p-wedding-registry-manage'),(42112,'watch-mobile','.b-bottom .alert-message','text-align','center','','','.b-bottom'),(42113,'watch-mobile','.p-wedding-registry-manage .wedding-date','text-align','center','','','.p-wedding-registry-manage'),(42114,'watch-mobile','.p-wedding-registry-share .heading-3','text-align','center','','','.p-wedding-registry-share'),(42115,'watch-mobile','.p-wedding-registry-search .result-table td:nth-child(4)','text-align','right','','','.p-wedding-registry-search'),(42116,'watch-mobile','.p-wedding-registry-search #searchform-status label','text-align','right','','','.p-wedding-registry-search'),(42117,'watch-mobile','.p-wedding-registry-search .button','text-align','right','','','.p-wedding-registry-search'),(42118,'watch-mobile','.b-pagination .pagination a','text-align','center','','','.b-pagination'),(42119,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','text-align','center','3','','.b-switch'),(42120,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','text-align','center','3','','.b-switch'),(42121,'watch-mobile','.b-compare .compare-head','text-align','left','','','.b-compare'),(42122,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-align','left','','','.b-switch'),(42123,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-label','text-align','center','','','.b-switch'),(42124,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-align','right','','','.b-switch'),(42125,'watch-mobile','.b-switch .bootstrap-switch','text-align','left','','','.b-switch'),(42126,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','text-align','center','','','.b-slick'),(42127,'watch-mobile','.b-form .center-buttons','text-align','center','','','.b-form'),(42128,'watch-mobile','.w-top-categories .item','text-align','center','','','.w-top-categories'),(42129,'watch-mobile','.w-top-categories .categories','text-align','center','','','.w-top-categories'),(42130,'watch-mobile','.w-search .suggest','text-align','left','','','.w-search'),(42131,'watch-mobile','.w-tabs .tab-a','text-align','center','','','.w-tabs'),(42133,'watch-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','text-align','center','','','.w-banner'),(42134,'watch-mobile','.p-account-trade-form .widget h3','text-align','center','','','.p-account-trade-form'),(42136,'watch-mobile','.p-quote-cart-index .cart-page .empty','text-align','center','','','.p-quote-cart-index'),(42137,'watch-mobile','.p-shopping-cart-index .cart-page .empty','text-align','center','','','.p-shopping-cart-index'),(42138,'watch-mobile','.w-filters .handle-to','text-align','right','','','.w-filters'),(42139,'watch-mobile','.w-compare-box-item .checkbox:checked + span:before','text-align','center','','','.w-compare-box-item'),(42140,'watch-mobile','.b-fancybox .fancybox-title-float-wrap','text-align','center','','','.b-fancybox'),(42141,'watch-mobile','.p-account-trade-form .trade-form-area','text-align','center','','','.p-account-trade-form'),(42142,'watch-mobile','.w-menu .hided.menu ul li','text-align','left','317','','.w-menu'),(42147,'watch-mobile','.w-menu-mobile .menu-ico','text-align','center','','','.w-menu-mobile'),(42150,'watch-mobile','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(42151,'watch-mobile','.w-catalog-listing-look .list','text-align','center','','','.w-catalog-listing-look'),(42152,'watch-mobile','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(42153,'watch-mobile','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(42154,'watch-mobile','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(42155,'watch-mobile','.w-menu-style-1 ul ul li','text-align','left','','','.w-menu-style-1'),(42157,'watch-mobile','.p-wedding-registry-share .add-row','text-align','right','','','.p-wedding-registry-share'),(42158,'watch-mobile','.w-sale .left','text-align','center','','','.w-sale'),(42159,'watch-mobile','.b-page-name .page-name','text-align','center','','','.b-page-name'),(42160,'watch-mobile','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(42161,'watch-mobile','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(42162,'watch-mobile','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(42163,'watch-mobile','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(42164,'watch-mobile','.w-list-type-1_3 .image','text-align','center','291','','.w-list-type-1_3'),(42165,'watch-mobile','.w-catalog-listing-look .grid','text-align','center','','','.w-catalog-listing-look'),(42167,'watch-mobile','.w-cart-give-away .ga_img','text-align','center','','','.w-cart-give-away'),(42168,'watch-mobile','.heading-2, h2','text-align','center','','',''),(42169,'watch-mobile','h1','text-align','center','','',''),(42170,'watch-mobile','.w-list-type-1_3 .sale','text-align','center','4','','.w-list-type-1_3'),(42171,'watch-mobile','.w-list-type-2 .button-view a','text-align','left','','','.w-list-type-2'),(42172,'watch-mobile','.w-list-type-2 .sale','text-align','center','4','','.w-list-type-2'),(42173,'watch-mobile','.w-list-type-2 .item','text-align','left','','','.w-list-type-2'),(42174,'watch-mobile','.w-list-type-2 .button-wishlist button','text-align','left','','','.w-list-type-2'),(42175,'watch-mobile','.w-list-type-1_3 .image','text-align','center','','','.w-list-type-1_3'),(42176,'watch-mobile','.w-list-type-1_3 .item','text-align','left','','','.w-list-type-1_3'),(42177,'watch-mobile','.w-list-type-1_3 .button-wishlist button','text-align','left','','','.w-list-type-1_3'),(42178,'watch-mobile','.w-list-type-1_3 .button-view a','text-align','left','','','.w-list-type-1_3'),(42179,'watch-mobile','.w-list-type-1_2 .sale','text-align','center','4','','.w-list-type-1_2'),(42180,'watch-mobile','.w-list-type-1_2 .item','text-align','left','','','.w-list-type-1_2'),(42181,'watch-mobile','.w-list-type-1_2 .image','text-align','center','','','.w-list-type-1_2'),(42182,'watch-mobile','.w-list-type-1_2 .button-wishlist button','text-align','left','','','.w-list-type-1_2'),(42183,'watch-mobile','.w-list-type-1_2 .button-view a','text-align','left','','','.w-list-type-1_2'),(42184,'watch-mobile','.b-bottom .pop-up-close','text-align','center','','','.b-bottom'),(42185,'watch-mobile','.w-list-type-1 .sale','text-align','center','4','','.w-list-type-1'),(42186,'watch-mobile','.w-list-type-1 .image a','text-align','center','','','.w-list-type-1'),(42187,'watch-mobile','.w-list-type-1 .image','text-align','center','','','.w-list-type-1'),(42188,'watch-mobile','.w-list-type-1 .item','text-align','left','','','.w-list-type-1'),(42189,'watch-mobile','.w-list-type-1 .button-wishlist button','text-align','left','','','.w-list-type-1'),(42190,'watch-mobile','.w-list-type-1 .button-view a','text-align','left','','','.w-list-type-1'),(42192,'watch-mobile','.b-products-listing .btn-choose-options','text-align','center','','','.b-products-listing'),(42193,'watch-mobile','.b-products-listing .products-listing','text-align','center','','','.b-products-listing'),(42194,'watch-mobile','.b-products-listing .products-listing .btn-buy','text-align','center','','','.b-products-listing'),(42195,'watch-mobile','.b-products-listing .products-listing .btn-preloader','text-align','center','','','.b-products-listing'),(42196,'watch-mobile','.b-products-listing .products-listing .buyButton .btn','text-align','center','','','.b-products-listing'),(42197,'watch-mobile','.b-products-listing .products-listing .image','text-align','center','','','.b-products-listing'),(42198,'watch-mobile','.b-products-listing .products-listing .in-cart','text-align','center','','','.b-products-listing'),(42199,'watch-mobile','.b-products-listing .products-listing .mult-qty-input','text-align','right','','','.b-products-listing'),(42200,'watch-mobile','.b-products-listing .products-listing .properties','text-align','left','','','.b-products-listing'),(42201,'watch-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','text-align','left','','','.b-products-listing'),(42202,'watch-mobile','.b-products-listing .show-ofstock-products','text-align','center','','','.b-products-listing'),(42203,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.b-data-table'),(42204,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.b-data-table'),(42205,'watch-mobile','.b-data-table .dt-body-center','text-align','center','','','.b-data-table'),(42206,'watch-mobile','.b-data-table table.dataTable tbody td:last-child','text-align','right','','','.b-data-table'),(42207,'watch-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(42208,'watch-mobile','.b-email .qty','text-align','center','','','.b-email'),(42209,'watch-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(42210,'watch-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(42211,'watch-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(42212,'watch-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(42213,'watch-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(42214,'watch-mobile','.b-email .price','text-align','right','','','.b-email'),(42215,'watch-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(42216,'watch-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(42217,'watch-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(42218,'watch-mobile','.b-email .price','text-align','right','','','.b-email'),(42219,'watch-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(42220,'watch-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(42221,'watch-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(42222,'watch-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(42223,'watch-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(42224,'watch-mobile','.b-email .price','text-align','right','','','.b-email'),(42225,'watch-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(42226,'watch-mobile','.b-email .price','text-align','right','','','.b-email'),(42227,'watch-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(42228,'watch-mobile','.b-email .price','text-align','right','','','.b-email'),(42229,'watch-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(42230,'watch-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(42231,'watch-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(42232,'watch-mobile','.b-email .model','text-align','center','','','.b-email'),(42233,'watch-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(42234,'watch-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(42235,'watch-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(42236,'watch-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(42237,'watch-mobile','.b-email .model','text-align','center','','','.b-email'),(42238,'watch-mobile','.b-email .model','text-align','center','','','.b-email'),(42239,'watch-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(42240,'watch-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(42241,'watch-mobile','.b-email .model','text-align','center','','','.b-email'),(42242,'watch-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(42243,'watch-mobile','.b-email .price','text-align','right','','','.b-email'),(42244,'watch-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(42245,'watch-mobile','.b-email .model','text-align','center','','','.b-email'),(42246,'watch-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(42247,'watch-mobile','.b-email .qty','text-align','center','','','.b-email'),(42248,'watch-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(42249,'watch-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(42250,'watch-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(42251,'watch-mobile','.b-email .qty','text-align','center','','','.b-email'),(42252,'watch-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(42253,'watch-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(42254,'watch-mobile','.b-email .qty','text-align','center','','','.b-email'),(42255,'watch-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(42256,'watch-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(42257,'watch-mobile','.b-email .model','text-align','center','','','.b-email'),(42258,'watch-mobile','.b-email .qty','text-align','center','','','.b-email'),(42259,'watch-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(42260,'watch-mobile','.b-email .qty','text-align','center','','','.b-email'),(42261,'watch-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(42262,'watch-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(42263,'watch-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(42264,'watch-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(42265,'watch-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(42266,'watch-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(42267,'watch-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(42268,'watch-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(42269,'watch-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(42270,'watch-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(42271,'watch-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(42272,'watch-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(42273,'watch-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(42274,'watch-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(42275,'watch-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(42276,'watch-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(42277,'watch-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(42278,'watch-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(42279,'watch-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(42280,'watch-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(42281,'watch-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(42282,'watch-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(42283,'watch-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(42284,'watch-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(42285,'watch-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','text-align','center','','','.b-menu-burger_icon'),(42286,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(42287,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(42288,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(42289,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(42290,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(42291,'watch-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(42292,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','text-align','center','','','.b-menu-style-2'),(42293,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','text-align','center','','','.b-menu-style-2'),(42294,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','text-align','right','','','.b-menu-style-2'),(42295,'watch-mobile','.b-messages .msv_to_cc, .b-messages .msv_btn','text-align','left','','','.b-messages'),(42296,'watch-mobile','.b-messages .msv_content','text-align','left','','','.b-messages'),(42297,'watch-mobile','.b-messages .attach-view','text-align','left','','','.b-messages'),(42298,'watch-mobile','.b-messages .msv_history','text-align','left','','','.b-messages'),(42299,'watch-mobile','.b-messages .development-content','text-align','left','','','.b-messages'),(42300,'watch-mobile','.b-messages .messages-sidebar .heading-2','text-align','center','','','.b-messages'),(42301,'watch-mobile','.b-messages .messages-sidebar .btn-2','text-align','center','','','.b-messages'),(42302,'watch-mobile','.b-messages .emailBtn','text-align','right','','','.b-messages'),(42303,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','text-align','left','','','.b-messages'),(42304,'watch-mobile','.b-personal-catalog-popup #personal_catalog_popup','text-align','left','','','.b-personal-catalog-popup'),(42305,'watch-mobile','.b-sub-totals .historyTotal table td','text-align','right','','','.b-sub-totals'),(42306,'watch-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(42307,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(42308,'watch-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(42309,'watch-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(42310,'watch-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(42311,'watch-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(42312,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(42313,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(42314,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(42315,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(42316,'watch-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(42317,'watch-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(42318,'watch-mobile','.b-trade-approval .steps-bar li','text-align','center','','','.b-trade-approval'),(42319,'watch-mobile','.b-trade-approval .steps-bar li a','text-align','center','','','.b-trade-approval'),(42320,'watch-mobile','.b-trade-approval .orders-table td:nth-child(1), .b-trade-approval .orders-table th:nth-child(1)','text-align','left','','','.b-trade-approval'),(42321,'watch-mobile','.b-trade-approval .orders-table td:nth-child(2)','text-align','right','','','.b-trade-approval'),(42322,'watch-mobile','.b-trade-approval .w-login-block label','text-align','left','','','.b-trade-approval'),(42323,'watch-mobile','.b-trade-approval .steps-bar','text-align','left','','','.b-trade-approval'),(42324,'watch-mobile','.b-trade-approval .center-buttons','text-align','center','','','.b-trade-approval'),(42325,'watch-mobile','.b-trade-approval .comments','text-align','left','','','.b-trade-approval'),(42326,'watch-mobile','.b-upload-file .upload-file-template','text-align','center','','','.b-upload-file'),(42327,'watch-mobile','.b-upload-file .snapshot','text-align','center','','','.b-upload-file'),(42328,'watch-mobile','.batchPr .w-batch-products .products-listing .image + .type-1','text-align','left','','','.batchPr'),(42329,'watch-mobile','.batchPr .checkbox input:not(checked) + span:before','text-align','center','','','.batchPr'),(42330,'watch-mobile','.batchPr .checkbox input + span','text-align','center','','','.batchPr'),(42331,'watch-mobile','.batchPr .btn-batch-remove','text-align','center','3','','.batchPr'),(42332,'watch-mobile','.batchPr .buttons','text-align','center','','','.batchPr'),(42333,'watch-mobile','.batchPr .batchSelect .checkbox','text-align','center','','','.batchPr'),(42334,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','text-align','left','','','.batchPr'),(42335,'watch-mobile','.batchPr .checkbox input:checked + span:before','text-align','center','','','.batchPr'),(42336,'watch-mobile','.batchPr .batch-selected-products-empty','text-align','center','','','.batchPr'),(42337,'watch-mobile','.batchPr .batch-selected-products-total','text-align','center','','','.batchPr'),(42381,'watch-mobile','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align','left','','','.p-quick-order-index'),(42382,'watch-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','text-align','center','','','.p-quick-order-index'),(42383,'watch-mobile','.p-quick-order-index .all-scroll-div td + td','text-align','right','','','.p-quick-order-index'),(42384,'watch-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','text-align','center','','','.p-quick-order-index'),(42385,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.p-quick-order-index'),(42386,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.p-quick-order-index'),(42387,'watch-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(42388,'watch-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(42389,'watch-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(42390,'watch-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(42391,'watch-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(42392,'watch-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(42393,'watch-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(42394,'watch-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(42395,'watch-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(42396,'watch-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(42397,'watch-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(42398,'watch-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(42399,'watch-mobile','.p-sample-checkout-success .page-success','text-align','center','','','.p-sample-checkout-success'),(42400,'watch-mobile','.w-account-address-book .button-add','text-align','right','','','.w-account-address-book'),(42401,'watch-mobile','.w-account-address-book .add_item a','text-align','center','','','.w-account-address-book'),(42402,'watch-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(42403,'watch-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(42404,'watch-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(42405,'watch-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(42406,'watch-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(42407,'watch-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(42408,'watch-mobile','.w-account-personal-catalog .list-switcher a','text-align','center','','','.w-account-personal-catalog'),(42409,'watch-mobile','.w-blog-widget-post-date ','text-align','center','','','.w-blog-widget-post-date'),(42410,'watch-mobile','.w-blog-widget-post-linked-products .heading-2','text-align','center','','','.w-blog-widget-post-linked-products'),(42411,'watch-mobile','.w-blog-widget-post-listing .post_date','text-align','center','','','.w-blog-widget-post-listing'),(42412,'watch-mobile','.w-blog-widget-post-listing .post_image','text-align','center','','','.w-blog-widget-post-listing'),(42413,'watch-mobile','.w-blog-widget-post-listing .post_name','text-align','center','','','.w-blog-widget-post-listing'),(42414,'watch-mobile','.w-blog-widget-post-title h1','text-align','center','','','.w-blog-widget-post-title'),(42415,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','text-align','center','','','.w-blog-widget-related-posts'),(42416,'watch-mobile','.w-blog-widget-related-posts-by-category .post_content a','text-align','center','','','.w-blog-widget-related-posts-by-category'),(42417,'watch-mobile','.w-blog-widget-related-posts-by-category .post_img','text-align','center','','','.w-blog-widget-related-posts-by-category'),(42418,'watch-mobile','.w-cart-bonus-points .btn-remove','text-align','center','','','.w-cart-bonus-points'),(42419,'watch-mobile','.w-cart-bonus-points .bonus_points_amount','text-align','center','','','.w-cart-bonus-points'),(42420,'watch-mobile','.w-cart-credit-amount input','text-align','center','','','.w-cart-credit-amount'),(42421,'watch-mobile','.w-cart-credit-amount .btn-remove','text-align','center','','','.w-cart-credit-amount'),(42422,'watch-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','text-align','center','','','.w-catalog-additional-images'),(42423,'watch-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','text-align','right','','','.w-catalog-b2b-add-button'),(42424,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','text-align','center','','','.w-catalog-compare'),(42425,'watch-mobile','.w-catalog-paging .prev','text-align','center','','','.w-catalog-paging'),(42426,'watch-mobile','.w-catalog-paging ','text-align','center','2','','.w-catalog-paging'),(42427,'watch-mobile','.w-catalog-paging .next','text-align','center','','','.w-catalog-paging'),(42428,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align','center','','','.w-catalog-paging'),(42429,'watch-mobile','.w-catalog-paging .p-blog-index','text-align','right','','','.w-catalog-paging'),(42430,'watch-mobile','.w-catalog-paging .page-number','text-align','center','','','.w-catalog-paging'),(42431,'watch-mobile','.w-catalog-paging .next-pages','text-align','center','','','.w-catalog-paging'),(42432,'watch-mobile','.w-catalog-paging .prev-pages','text-align','center','','','.w-catalog-paging'),(42433,'watch-mobile','.w-checkout-bonus-points .bonus_points_amount','text-align','center','','','.w-checkout-bonus-points'),(42434,'watch-mobile','.w-checkout-bonus-points .btn-remove','text-align','center','','','.w-checkout-bonus-points'),(42435,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','text-align','center','3','','.w-checkout-contact-information'),(42436,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','text-align','center','3','','.w-checkout-contact-information'),(42437,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','text-align','center','3','','.w-checkout-contact-information'),(42438,'watch-mobile','.w-checkout-credit-amount .btn-remove','text-align','center','','','.w-checkout-credit-amount'),(42439,'watch-mobile','.w-checkout-credit-amount .cot_gv_amount','text-align','center','','','.w-checkout-credit-amount'),(42440,'watch-mobile','.w-checkout-terms .required-message','text-align','left','','','.w-checkout-terms'),(42441,'watch-mobile','.w-checkout-terms .terms-box','text-align','left','','','.w-checkout-terms'),(42442,'watch-mobile','.w-communication-new-topic .quantity','text-align','center','','','.w-communication-new-topic'),(42443,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(5), .w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(7)','text-align','center','','','.w-communication-new-topic'),(42444,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','text-align','center','','','.w-communication-new-topic'),(42445,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','text-align','center','','','.w-communication-new-topic'),(42446,'watch-mobile','.w-communication-new-topic .orders-id','text-align','center','','','.w-communication-new-topic'),(42447,'watch-mobile','.w-communication-new-topic .model','text-align','center','','','.w-communication-new-topic'),(42448,'watch-mobile','.w-communication-new-topic .date-purchased','text-align','right','','','.w-communication-new-topic'),(42449,'watch-mobile','.w-communication-post .communication-post-attach','text-align','right','','','.w-communication-post'),(42450,'watch-mobile','.w-coupons-and-vauchers-checkout .btn-remove','text-align','center','','','.w-coupons-and-vauchers-checkout'),(42451,'watch-mobile','.w-delivery-day .time-left','text-align','center','','','.w-delivery-day'),(42452,'watch-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(42453,'watch-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(42454,'watch-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(42455,'watch-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(42456,'watch-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(42457,'watch-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(42458,'watch-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(42459,'watch-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(42460,'watch-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(42461,'watch-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(42462,'watch-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(42463,'watch-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(42464,'watch-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(42465,'watch-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(42466,'watch-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(42467,'watch-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(42468,'watch-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(42469,'watch-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(42470,'watch-mobile','.w-product-customers-activity .customers-activity','text-align','center','','','.w-product-customers-activity'),(42471,'watch-mobile','.w-product-customers-activity .close','text-align','center','','','.w-product-customers-activity'),(42472,'watch-mobile','.w-promotions .prom-multi-discount .heading','text-align','center','','','.w-promotions'),(42473,'watch-mobile','.w-promotions .promo-item','text-align','center','','','.w-promotions'),(42474,'watch-mobile','.w-promotions .promo-date','text-align','center','','','.w-promotions'),(42475,'watch-mobile','.w-quote-products .empty','text-align','center','','','.w-quote-products'),(42476,'watch-mobile','.w-reviews-content .date','text-align','right','','','.w-reviews-content'),(42477,'watch-mobile','.w-reviews-content .product-image','text-align','center','','','.w-reviews-content'),(42478,'watch-mobile','.w-top-text .top-text','text-align','center','','','.w-top-text'),(42479,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','text-align','center','','','.w-upload-customer-id-upload-customer-id-form'),(42480,'watch-mobile','.w-wedding-registry-widgets-products .rating','text-align','right','','','.w-wedding-registry-widgets-products'),(42481,'watch-mobile','.b-quantity .qty-box input[type=\'text\']','text-align','center','','','.b-quantity'),(42482,'watch-mobile','.w-success-continue-btn','text-align_important','important','291','','.w-success-continue-btn'),(42483,'watch-mobile','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align_important','important','','','.p-quick-order-index'),(42484,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align_important','important','','','.w-catalog-paging'),(42485,'watch-mobile','.w-tabs .accordion-heading','text-decoration','none','','','.w-tabs'),(42486,'watch-mobile','.w-html_box .socials a','text-decoration','none','1','','.w-html_box'),(42487,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(42488,'watch-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(42489,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','text-decoration','none','1','','.w-menu-style-1'),(42491,'watch-mobile','.p-blog-index a','text-decoration','none','1','','.p-blog-index'),(42493,'watch-mobile','.p-wedding-registry-manage a.remove-btn','text-decoration','none','1','','.p-wedding-registry-manage'),(42494,'watch-mobile','.b-pagination .pagination span','text-decoration','none','1','','.b-pagination'),(42495,'watch-mobile','.b-pagination .pagination a','text-decoration','none','1','','.b-pagination'),(42497,'watch-mobile','.w-list-type-2_2 .price .old','text-decoration','line-through','','','.w-list-type-2_2'),(42498,'watch-mobile','.w-chat .w-chat-box a','text-decoration','none','1','','.w-chat'),(42499,'watch-mobile','.w-chat .w-chat-box a','text-decoration','none','','','.w-chat'),(42500,'watch-mobile','.w-socials > li a','text-decoration','none','','','.w-socials'),(42501,'watch-mobile','.w-tabs .tab-a','text-decoration','none','','','.w-tabs'),(42504,'watch-mobile','.w-list-type-1_3 .price .old','text-decoration','line-through','','','.w-list-type-1_3'),(42505,'watch-mobile','.w-sale .old','text-decoration','line-through','','','.w-sale'),(42506,'watch-mobile','.b-fancybox .fancybox-nav','text-decoration','none','','','.b-fancybox'),(42507,'watch-mobile','.b-fancybox a.fancybox-close','text-decoration','none','1','','.b-fancybox'),(42508,'watch-mobile','.w-cart a.item','text-decoration','none','1','','.w-cart'),(42509,'watch-mobile','.price .old','text-decoration','line-through','','',''),(42510,'watch-mobile','.w-list-type-2 .price .old','text-decoration','line-through','','','.w-list-type-2'),(42511,'watch-mobile','.heading-3 .right-text, h3 .right-text','text-decoration','none','','',''),(42512,'watch-mobile','.w-list-type-1_2 .price .old','text-decoration','line-through','','','.w-list-type-1_2'),(42513,'watch-mobile','.w-filters .mobileCollapse','text-decoration','none','1','','.w-filters'),(42514,'watch-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(42515,'watch-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(42516,'watch-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(42517,'watch-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(42518,'watch-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(42519,'watch-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(42520,'watch-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(42521,'watch-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(42522,'watch-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(42523,'watch-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(42524,'watch-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(42525,'watch-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(42526,'watch-mobile','.b-select-suggest .select2-container .select2-choice','text-decoration','none','','','.b-select-suggest'),(42527,'watch-mobile','.b-select-suggest .select2-result-selectable .select2-match, .b-select-suggest .select2-result-unselectable .select2-match','text-decoration','underline','','','.b-select-suggest'),(42528,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','text-decoration','none','','','.b-select-suggest'),(42542,'watch-mobile','.w-account-address-book .add_item a.disabled-link','text-decoration','none','1','','.w-account-address-book'),(42543,'watch-mobile','.w-account-personal-catalog .list-switcher a','text-decoration','none','','','.w-account-personal-catalog'),(42544,'watch-mobile','.w-blog-widget-post-share a','text-decoration','none','1','','.w-blog-widget-post-share'),(42545,'watch-mobile','.w-catalog-paging span','text-decoration','none','1','','.w-catalog-paging'),(42546,'watch-mobile','.w-catalog-paging a','text-decoration','none','1','','.w-catalog-paging'),(42547,'watch-mobile','.w-image-maps .categories-items .item a','text-decoration','none','1','','.w-image-maps'),(42548,'watch-mobile','.w-image-maps .float-items .item a','text-decoration','none','1','','.w-image-maps'),(42549,'watch-mobile','.w-social-links a','text-decoration','none','1','','.w-social-links'),(42550,'watch-mobile','.batchPr .btn-batch-remove','text-indent','-33333em','','','.batchPr'),(42551,'watch-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','text-overflow','ellipsis','','','.b-select-suggest'),(42552,'watch-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(42553,'watch-mobile','.p-wedding-registry-index .main-button','text-shadow','0 0','3','','.p-wedding-registry-index'),(42554,'watch-mobile','.b-fancybox .fancybox-skin','text-shadow','none','','','.b-fancybox'),(42555,'watch-mobile','.b-fancybox .fancybox-title','text-shadow','none','','','.b-fancybox'),(42561,'watch-mobile','.w-categories .name','text-transform','uppercase','','','.w-categories'),(42562,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','text-transform','none','','','.b-multi-page-checkout'),(42563,'watch-mobile','.w-product-personal-catalog-button .btn','text-transform','none','','','.w-product-personal-catalog-button'),(42564,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','text-transform','uppercase','','','.b-multi-page-checkout'),(42567,'watch-mobile','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(42568,'watch-mobile','.w-product-wedding-registry-button .btn','text-transform','none','','','.w-product-wedding-registry-button'),(42569,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-transform','uppercase','','','.b-switch'),(42570,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-transform','uppercase','','','.b-switch'),(42571,'watch-mobile','.w-tabs .accordion-heading','text-transform','uppercase','','','.w-tabs'),(42572,'watch-mobile','.heading-4 .edit, h4 .edit','text-transform','none','','',''),(42573,'watch-mobile','.w-tabs .tab-a','text-transform','uppercase','','','.w-tabs'),(42574,'watch-mobile','.heading-4, h4','text-transform','uppercase','','',''),(42575,'watch-mobile','.heading-2, h2','text-transform','uppercase','','',''),(42576,'watch-mobile','.p-account-trade-form .widget h3','text-transform','uppercase','','','.p-account-trade-form'),(42577,'watch-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','text-transform','uppercase','','','.p-account-trade-form'),(42578,'watch-mobile','.w-filters .filter-box-head','text-transform','uppercase','','','.w-filters'),(42579,'watch-mobile','.w-filters .head-filter-widget','text-transform','uppercase','','','.w-filters'),(42580,'watch-mobile','.heading-3 .edit, h3 .edit','text-transform','none','','',''),(42581,'watch-mobile','.p-account-subscription-historyinfo .order_history_table th','text-transform','none','','','.p-account-subscription-historyinfo'),(42582,'watch-mobile','.p-account-subscription-historyinfo .order_history_table h2','text-transform','uppercase','','','.p-account-subscription-historyinfo'),(42584,'watch-mobile','.heading-3, h3','text-transform','uppercase','','',''),(42587,'watch-mobile','.w-top-categories .categories h2','text-transform','inherit','','','.w-top-categories'),(42588,'watch-mobile','.w-categories .categories h2','text-transform','inherit','','','.w-categories'),(42589,'watch-mobile','.w-top-categories .name','text-transform','uppercase','','','.w-top-categories'),(42591,'watch-mobile','h1','text-transform','uppercase','','',''),(42592,'watch-mobile','.btn-2','text-transform','uppercase','','',''),(42593,'watch-mobile','.btn','text-transform','uppercase','','',''),(42594,'watch-mobile','.btn-1','text-transform','uppercase','','',''),(42595,'watch-mobile','.btn-3','text-transform','uppercase','','',''),(42596,'watch-mobile','.heading-4 .right-text, h4 .right-text','text-transform','none','','',''),(42600,'watch-mobile','.b-info .info strong','text-transform','uppercase','','','.b-info'),(42601,'watch-mobile','.b-products-listing .products-listing a.btn.view-button','text-transform','none','','','.b-products-listing'),(42602,'watch-mobile','.b-products-listing .products-listing h2','text-transform','inherit','','','.b-products-listing'),(42603,'watch-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','text-transform','inherit','','','.b-h-inline'),(42604,'watch-mobile','.b-messages .content-messages .heading-2','text-transform','none','','','.b-messages'),(42605,'watch-mobile','.batchPr .batchSelect .checkbox','text-transform','uppercase','','','.batchPr'),(42606,'watch-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(42607,'watch-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(42608,'watch-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(42609,'watch-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(42641,'watch-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(42642,'watch-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(42643,'watch-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(42644,'watch-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(42645,'watch-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(42646,'watch-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(42647,'watch-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(42648,'watch-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(42649,'watch-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(42650,'watch-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(42651,'watch-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(42652,'watch-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(42653,'watch-mobile','.p-sample-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-sample-checkout-success'),(42654,'watch-mobile','.p-sample-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-sample-checkout-success'),(42655,'watch-mobile','.w-account-address-book .btn-edit','text-transform','none','','','.w-account-address-book'),(42656,'watch-mobile','.w-account-personal-catalog .list-switcher a','text-transform','uppercase','','','.w-account-personal-catalog'),(42657,'watch-mobile','.w-blog-widget-post-listing .post_name a','text-transform','uppercase','','','.w-blog-widget-post-listing'),(42658,'watch-mobile','.w-blog-widget-post-title h1','text-transform','none','','','.w-blog-widget-post-title'),(42659,'watch-mobile','.w-blog-widget-related-posts-by-category .post_content a','text-transform','uppercase','','','.w-blog-widget-related-posts-by-category'),(42660,'watch-mobile','.w-blog-widget-tag-cloud a','text-transform','uppercase','','','.w-blog-widget-tag-cloud'),(42661,'watch-mobile','.w-cart-compare .cart-name a','text-transform','uppercase','','','.w-cart-compare'),(42662,'watch-mobile','.w-checkout-shipping-choice span','text-transform','uppercase','','','.w-checkout-shipping-choice'),(42663,'watch-mobile','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','text-transform','uppercase','','','.w-multi-cart-cart-switcher'),(42664,'watch-mobile','.w-personal-gift-status-bar .end-date','text-transform','uppercase','','','.w-personal-gift-status-bar'),(42665,'watch-mobile','.w-personal-gift-status-bar .inform','text-transform','uppercase','','','.w-personal-gift-status-bar'),(42666,'watch-mobile','.w-promotions .heading-3','text-transform','uppercase','','','.w-promotions'),(42667,'watch-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','text-transform','none','','','.w-taxable'),(42668,'watch-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','text-transform','none','','','.w-taxable'),(42669,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_color','#222','','','.b-fancybox'),(42670,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left','0','','','.b-fancybox'),(42671,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left_measure','','','','.b-fancybox'),(42672,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size','2','','','.b-fancybox'),(42673,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size_measure','px','','','.b-fancybox'),(42674,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top','1','','','.b-fancybox'),(42675,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top_measure','px','','','.b-fancybox'),(42676,'watch-mobile','.w-menu-slider > ul > li > ul','top','100','','','.w-menu-slider'),(42677,'watch-mobile','.w-menu-slider .close','top','10','','','.w-menu-slider'),(42678,'watch-mobile','.w-menu-big > ul > li > ul','top','100','','','.w-menu-big'),(42679,'watch-mobile','.w-menu-horizontal > ul > li > ul','top','100','','','.w-menu-horizontal'),(42680,'watch-mobile','.w-bestsellers .heading-3','top','0','3','','.w-bestsellers'),(42681,'watch-mobile','.w-list-type-1 .rating-count','top','-1','','','.w-list-type-1'),(42682,'watch-mobile','.w-menu-style-1 > ul > li > ul','top','100','','','.w-menu-style-1'),(42683,'watch-mobile','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(42684,'watch-mobile','.w-sale .badge','top','10','','','.w-sale'),(42685,'watch-mobile','.w-product-wedding-registry-button .btn','top','1','3','','.w-product-wedding-registry-button'),(42686,'watch-mobile','.w-product-wedding-registry-button .btn','top','1','4','','.w-product-wedding-registry-button'),(42687,'watch-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(42688,'watch-mobile','.b-fancybox #fancybox-loading','top','50','','','.b-fancybox'),(42689,'watch-mobile','.b-fancybox .fancybox-nav','top','0','','','.b-fancybox'),(42693,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','top','-2','4','','.b-multi-page-checkout'),(42694,'watch-mobile','.b-pass-strength .pass-strength span','top','6','','','.b-pass-strength'),(42696,'watch-mobile','.p-blog-index .author .avatar','top','-2','','','.p-blog-index'),(42697,'watch-mobile','.w-menu-mobile .menu-slider .open','top','0','','','.w-menu-mobile'),(42698,'watch-mobile','.b-info-popup .info-popup.top-left div','top','auto','3','','.b-info-popup'),(42699,'watch-mobile','.b-info-popup .info-popup.top-left div','top','auto','','','.b-info-popup'),(42700,'watch-mobile','.w-promo-code .holder','top','2','320,3','','.w-promo-code'),(42701,'watch-mobile','.b-info-popup .info-popup div','top','-12','','','.b-info-popup'),(42702,'watch-mobile','.w-promo-code .holder','top','19','3','','.w-promo-code'),(42703,'watch-mobile','.p-wedding-registry-view h1','top','-4','4','','.p-wedding-registry-view'),(42706,'watch-mobile','.testimonials .heading-3','top','0','3','',''),(42707,'watch-mobile','.testimonials .rating','top','2','','',''),(42708,'watch-mobile','.testimonials .reviews-list span','top','2','','',''),(42709,'watch-mobile','.p-wedding-registry-manage .wr-search button','top','1','','','.p-wedding-registry-manage'),(42711,'watch-mobile','.w-product-personal-catalog-button .btn','top','1','3','','.w-product-personal-catalog-button'),(42712,'watch-mobile','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(42713,'watch-mobile','.b-fancybox .fancybox-close','top','0','','','.b-fancybox'),(42714,'watch-mobile','.w-menu-horizontal ul ul ul','top','0','','','.w-menu-horizontal'),(42715,'watch-mobile','.b-form .radio-button input[type=\"radio\"]','top','2','','','.b-form'),(42716,'watch-mobile','.p-wedding-registry-index .search-list','top','0','3','','.p-wedding-registry-index'),(42717,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','top','1','3','','.b-form'),(42718,'watch-mobile','.b-form .form-buttons','top','10','','','.b-form'),(42719,'watch-mobile','.p-wedding-registry-search h1','top','-4','3','','.p-wedding-registry-search'),(42720,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','top','4','3','','.b-switch'),(42721,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','top','4','3','','.b-switch'),(42722,'watch-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','top','0','','','.b-switch'),(42723,'watch-mobile','.w-currencies .select','top','46','299','','.w-currencies'),(42724,'watch-mobile','.w-languages .select','top','46','299','','.w-languages'),(42725,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container','top','0','','','.b-switch'),(42726,'watch-mobile','.w-currencies .w-currencies .current','top','10','299,3','','.w-currencies'),(42727,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','top','50','','','.b-slick'),(42728,'watch-mobile','.b-bottom .footerTitle','top','8','290,4','','.b-bottom'),(42730,'watch-mobile','.w-socials .post_item > div','top','10','3','','.w-socials'),(42731,'watch-mobile','.w-banner .image-text-banner.top-right .text-banner','top','0','','','.w-banner'),(42732,'watch-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','top','0','','','.w-banner'),(42733,'watch-mobile','.w-banner .image-text-banner.top-left .text-banner','top','0','','','.w-banner'),(42734,'watch-mobile','.w-banner .banner img + img','top','0','','','.w-banner'),(42735,'watch-mobile','.w-banner .image-text-banner.bottom-center .text-banner','top','auto','','','.w-banner'),(42736,'watch-mobile','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','top','0','','','.w-banner'),(42737,'watch-mobile','.w-currencies .current','top','1','3','','.w-currencies'),(42738,'watch-mobile','.w-currencies .select','top','31','','','.w-currencies'),(42739,'watch-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(42740,'watch-mobile','.b-slick .slick-vertical button.slick-prev','top','0','','','.b-slick'),(42741,'watch-mobile','.b-slick .slick-track','top','0','','','.b-slick'),(42742,'watch-mobile','.b-slick .slick-vertical button.slick-next','top','auto','','','.b-slick'),(42745,'watch-mobile','.b-info-popup .info-popup div','top','15','3','','.b-info-popup'),(42746,'watch-mobile','.b-fancybox .fancybox-tmp','top','-99999','','','.b-fancybox'),(42748,'watch-mobile','.b-fancybox .fancybox-wrap','top','0','','','.b-fancybox'),(42749,'watch-mobile','.w-menu-style-1 ul ul ul','top','0','','','.w-menu-style-1'),(42750,'watch-mobile','.b-fancybox .fancybox-overlay','top','0','','','.b-fancybox'),(42752,'watch-mobile','.p-wedding-registry-share .invite-remove','top','27','','','.p-wedding-registry-share'),(42753,'watch-mobile','.w-text .customer-service','top','5','3','','.w-text'),(42754,'watch-mobile','.w-languages .current','top','10','299,3','','.w-languages'),(42755,'watch-mobile','.w-banner .carousel-text','top','0','','','.w-banner'),(42756,'watch-mobile','.b-rating #stars-default .glyphicon','top','1','','','.b-rating'),(42757,'watch-mobile','.b-fancybox .fancybox-nav span','top','50','','','.b-fancybox'),(42758,'watch-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','top','3','3','','.w-cart-discount-coupon'),(42760,'watch-mobile','.b-form .hide-billing-address','top','0','','','.b-form'),(42761,'watch-mobile','.b-form .form-inputs div.required-message','top','-15','','','.b-form'),(42762,'watch-mobile','.p-wedding-registry-manage h1','top','-4','4','','.p-wedding-registry-manage'),(42763,'watch-mobile','.p-wedding-registry-search h1','top','-4','4','','.p-wedding-registry-search'),(42764,'watch-mobile','.view-all','top','50','3','',''),(42765,'watch-mobile','.p-wedding-registry-share h1','top','-4','3','','.p-wedding-registry-share'),(42766,'watch-mobile','.p-wedding-registry-manage h1','top','-4','3','','.p-wedding-registry-manage'),(42767,'watch-mobile','.p-wedding-registry-share h1','top','-4','4','','.p-wedding-registry-share'),(42768,'watch-mobile','.p-wedding-registry-view h1','top','-4','3','','.p-wedding-registry-view'),(42769,'watch-mobile','.b-bottom .pop-up-close','top','7','','','.b-bottom'),(42770,'watch-mobile','.w-filters .mobileCollapse','top','1','','','.w-filters'),(42771,'watch-mobile','.w-filters .ui-slider-handle','top','-5','','','.w-filters'),(42772,'watch-mobile','.w-languages .select','top','31','','','.w-languages'),(42773,'watch-mobile','.w-languages .current','top','1','3','','.w-languages'),(42774,'watch-mobile','.b-form .addresses .address-item input[type=\"radio\"]','top','4','','','.b-form'),(42775,'watch-mobile','.w-product-reviews .reviews-list span','top','2','','','.w-product-reviews'),(42776,'watch-mobile','.w-reviews .heading-3','top','0','3','','.w-reviews'),(42777,'watch-mobile','.w-search .button-search','top','0','','','.w-search'),(42778,'watch-mobile','.w-reviews .rating','top','2','','','.w-reviews'),(42779,'watch-mobile','.w-reviews .reviews-list span','top','2','','','.w-reviews'),(42780,'watch-mobile','.b-form .middle-form .required-message','top','-15','','','.b-form'),(42781,'watch-mobile','.b-form .payment-method .item-radio input','top','5','','','.b-form'),(42782,'watch-mobile','.b-form .shipping-method .input input','top','2','','','.b-form'),(42783,'watch-mobile','.b-info .info','top','3','3','','.b-info'),(42784,'watch-mobile','.b-info-popup .info-popup','top','5','3','','.b-info-popup'),(42785,'watch-mobile','.b-products-listing .hover-box-content','top','-10','3','','.b-products-listing'),(42786,'watch-mobile','.b-products-listing .hover-box-content','top','40','','','.b-products-listing'),(42787,'watch-mobile','.b-products-listing .loader','top','calc(50% - 15px)','4','','.b-products-listing'),(42788,'watch-mobile','.b-products-listing .loader','top','0','3','','.b-products-listing'),(42789,'watch-mobile','.b-products-listing .products-listing .btn-buy','top','3','3','','.b-products-listing'),(42790,'watch-mobile','.b-products-listing .products-listing .promos-info','top','0','','','.b-products-listing'),(42791,'watch-mobile','.b-products-listing .products-listing .qty-input.hidden','top','0','3','','.b-products-listing'),(42792,'watch-mobile','.b-products-listing .products-listing .radio-attributes input','top','2','','','.b-products-listing'),(42793,'watch-mobile','.b-products-listing .promo','top','0','','','.b-products-listing'),(42794,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(42795,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(42796,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(42797,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(42798,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(42799,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(42800,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(42801,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(42802,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(42803,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(42804,'watch-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(42805,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(42806,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top','100','','','.b-menu-lev_display-down'),(42807,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top','100','','','.b-menu-lev_display-down'),(42808,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top','100','','','.b-menu-lev_display-down'),(42809,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top','100','','','.b-menu-lev_display-down'),(42810,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top','100','','','.b-menu-lev_display-down'),(42811,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','top','0','','','.b-menu-lev_display-left'),(42812,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','top','0','','','.b-menu-lev_display-left'),(42813,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','top','0','','','.b-menu-lev_display-left'),(42814,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','top','0','','','.b-menu-lev_display-left'),(42815,'watch-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','top','0','','','.b-menu-lev_display-left'),(42816,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','top','0','','','.b-menu-lev_display-lra'),(42817,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','top','0','','','.b-menu-lev_display-lra'),(42818,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','top','0','','','.b-menu-lev_display-lra'),(42819,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','top','0','','','.b-menu-lev_display-lra'),(42820,'watch-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','top','0','','','.b-menu-lev_display-lra'),(42821,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','top','0','','','.b-menu-lev_display-right'),(42822,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','top','0','','','.b-menu-lev_display-right'),(42823,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','top','0','','','.b-menu-lev_display-right'),(42824,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','top','0','','','.b-menu-lev_display-right'),(42825,'watch-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','top','0','','','.b-menu-lev_display-right'),(42826,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','top','0','','','.b-menu-lev_display-slide'),(42827,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','top','0','','','.b-menu-lev_display-slide'),(42828,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','top','0','','','.b-menu-lev_display-slide'),(42829,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','top','0','','','.b-menu-lev_display-slide'),(42830,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','top','0','','','.b-menu-lev_display-slide'),(42831,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','top','0','','','.b-menu-open_from-left'),(42832,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','top','8','','','.b-menu-style-1'),(42833,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','top','0','','','.b-menu-style-2'),(42834,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','top','50','3','','.b-menu-style-2'),(42835,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','top','0','','','.b-menu-style-2'),(42836,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','top','50','3','','.b-menu-style-2'),(42837,'watch-mobile','.b-messages span.starred::before','top','3','','','.b-messages'),(42838,'watch-mobile','.b-messages .messBtnMenuUnread','top','3','3','','.b-messages'),(42839,'watch-mobile','.b-messages .messBtnMenuStarred','top','3','3','','.b-messages'),(42840,'watch-mobile','.b-messages .messBtnMenuDelete','top','3','3','','.b-messages'),(42841,'watch-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','top','5','','','.b-messages'),(42842,'watch-mobile','.b-preloader .preloader','top','0','','','.b-preloader'),(42843,'watch-mobile','.b-preloader .preloader','top','calc(50% - 20px)','3','','.b-preloader'),(42844,'watch-mobile','.b-select-suggest .select2-search-choice-close','top','4','','','.b-select-suggest'),(42845,'watch-mobile','.b-select-suggest .select2-drop','top','100','','','.b-select-suggest'),(42846,'watch-mobile','.b-select-suggest .select2-drop-mask','top','0','','','.b-select-suggest'),(42847,'watch-mobile','.b-select-suggest .select2-measure-scrollbar','top','-10000','','','.b-select-suggest'),(42848,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','top','8','','','.b-select-suggest'),(42849,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top','0','','','.b-select-suggest'),(42850,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','top','0','','','.b-select-suggest'),(42851,'watch-mobile','.b-upload-file .upload-remove','top','5','','','.b-upload-file'),(42852,'watch-mobile','.b-upload-files .attach-active-holder .attach-file','top','-200','','','.b-upload-files'),(42853,'watch-mobile','.batchPr .batchSelect','top','15','','','.batchPr'),(42854,'watch-mobile','.batchPr .btn-batch-remove','top','10','','','.batchPr'),(42855,'watch-mobile','.bell-ico .heading-2','top','5','3','','.bell-ico'),(42856,'watch-mobile','.heading-ordered-items .heading-4','top','2','3','','.heading-ordered-items'),(42857,'watch-mobile','.heading-saved-lists .heading-4','top','2','3','','.heading-saved-lists'),(42858,'watch-mobile','.heading-settings .heading-4','top','2','3','','.heading-settings'),(42885,'watch-mobile','.p-payer-order-confirmation .discount-ico','top','3','3','','.p-payer-order-confirmation'),(42886,'watch-mobile','.p-payer-order-confirmation .order-ico','top','7','3','','.p-payer-order-confirmation'),(42887,'watch-mobile','.p-payer-order-confirmation .comment-ico','top','7','3','','.p-payer-order-confirmation'),(42888,'watch-mobile','.p-payer-order-pay .order-ico','top','7','3','','.p-payer-order-pay'),(42889,'watch-mobile','.p-payer-order-pay .comment-ico','top','7','3','','.p-payer-order-pay'),(42890,'watch-mobile','.p-payer-order-pay .discount-ico','top','3','3','','.p-payer-order-pay'),(42891,'watch-mobile','.savings-ico .heading-2','top','5','3','','.savings-ico'),(42892,'watch-mobile','.shipping-ico .heading-2','top','5','3','','.shipping-ico'),(42893,'watch-mobile','.shipping-ico .heading-2','top','5','3','','.shipping-ico'),(42894,'watch-mobile','.shipping-ico .heading-2','top','5','3','','.shipping-ico'),(42895,'watch-mobile','.w-account-address-book .btn-del','top','0','','','.w-account-address-book'),(42896,'watch-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','top','4','','','.w-account-addresses-list'),(42897,'watch-mobile','.w-blog-widget-categories-list a','top','5','3','','.w-blog-widget-categories-list'),(42898,'watch-mobile','.w-blog-widget-most-popular-posts a','top','5','3','','.w-blog-widget-most-popular-posts'),(42899,'watch-mobile','.w-blog-widget-post-comments-count span','top','2','3','','.w-blog-widget-post-comments-count'),(42900,'watch-mobile','.w-blog-widget-post-listing .post_comment','top','0','3','','.w-blog-widget-post-listing'),(42901,'watch-mobile','.w-blog-widget-post-share ','top','0','4','','.w-blog-widget-post-share'),(42902,'watch-mobile','.w-blog-widget-post-share','top','15','0,4','','.w-blog-widget-post-share'),(42903,'watch-mobile','.w-cart-bonus-points .title','top','-2','3','','.w-cart-bonus-points'),(42904,'watch-mobile','.w-cart-compare .remove-cart','top','0','','','.w-cart-compare'),(42905,'watch-mobile','.w-cart-compare .atr-col','top','0','3','','.w-cart-compare'),(42906,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top','0','','','.w-catalog-paging'),(42907,'watch-mobile','.w-checkout-billing-address .genders-title input','top','2','','','.w-checkout-billing-address'),(42908,'watch-mobile','.w-checkout-create-account .account-benefits strong','top','3','3','','.w-checkout-create-account'),(42909,'watch-mobile','.w-checkout-gdpr .candlestick-wrapper','top','0','','','.w-checkout-gdpr'),(42910,'watch-mobile','.w-checkout-shipping-address .genders-title input','top','2','','','.w-checkout-shipping-address'),(42911,'watch-mobile','.w-checkout-shipping-choice input','top','-200','','','.w-checkout-shipping-choice'),(42912,'watch-mobile','.w-checkout-terms input[type=\"checkbox\"]','top','2','','','.w-checkout-terms'),(42913,'watch-mobile','.w-checkout-terms .required-message','top','40','','','.w-checkout-terms'),(42914,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','top','0','','','.w-image-maps'),(42915,'watch-mobile','.w-image-maps .svg-wrap svg','top','0','','','.w-image-maps'),(42916,'watch-mobile','.w-multi-cart-actions .cart-actions','top','-3','','','.w-multi-cart-actions'),(42917,'watch-mobile','.w-neighbour-checkout .bootstrap-switch','top','-2','','','.w-neighbour-checkout'),(42918,'watch-mobile','.w-personal-gift-status-bar .inform','top','3','4','','.w-personal-gift-status-bar'),(42919,'watch-mobile','.w-personal-gift-status-bar .end-date','top','4','3','','.w-personal-gift-status-bar'),(42920,'watch-mobile','.w-product-customers-activity .close','top','5','','','.w-product-customers-activity'),(42921,'watch-mobile','.w-promotions .prom-multi-discount .products','top','-13','','','.w-promotions'),(42922,'watch-mobile','.w-promotions .prom-multi-discount > .heading','top','2','3','','.w-promotions'),(42923,'watch-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','top','2','3','','.w-promotions'),(42924,'watch-mobile','.w-promotions .promo-cart-discount .promo-min-qty','top','-19','','','.w-promotions'),(42925,'watch-mobile','.w-promotions .promo-cart-discount .slave .content','top','-17','','','.w-promotions'),(42926,'watch-mobile','.w-promotions .promo-date','top','-10','','','.w-promotions'),(42927,'watch-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','top','2','3','','.w-promotions'),(42928,'watch-mobile','.w-reviews-content .review','top','-16','3','','.w-reviews-content'),(42929,'watch-mobile','.w-taxable input[type=\"checkbox\"]','top','2','','','.w-taxable'),(42930,'watch-mobile','.w-taxable input[type=\"radio\"]','top','2','','','.w-taxable'),(42931,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(42932,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(42933,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(42934,'watch-mobile','.w-wedding-registry-widgets-delete-link a','top','-1','4','','.w-wedding-registry-widgets-delete-link'),(42935,'watch-mobile','.w-wedding-registry-widgets-products .remove','top','0','','','.w-wedding-registry-widgets-products'),(42936,'watch-mobile','.w-wedding-registry-widgets-share-link a','top','-1','4','','.w-wedding-registry-widgets-share-link'),(42937,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top_important','important','','','.b-select-suggest'),(42938,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top_important','important','','','.w-catalog-paging'),(42939,'watch-mobile','.w-menu-horizontal > ul > li > ul','top_measure','%','','','.w-menu-horizontal'),(42940,'watch-mobile','.w-menu-big > ul > li > ul','top_measure','%','','','.w-menu-big'),(42941,'watch-mobile','.w-menu-slider > ul > li > ul','top_measure','%','','','.w-menu-slider'),(42942,'watch-mobile','.w-menu-style-1 > ul > li > ul','top_measure','%','','','.w-menu-style-1'),(42943,'watch-mobile','.b-fancybox .fancybox-nav span','top_measure','%','','','.b-fancybox'),(42944,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','top_measure','%','','','.b-slick'),(42946,'watch-mobile','.b-fancybox #fancybox-loading','top_measure','%','','','.b-fancybox'),(42948,'watch-mobile','.view-all','top_measure','%','3','',''),(42949,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(42950,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(42951,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(42952,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(42953,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(42954,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(42955,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top_measure','%','','','.b-menu-lev_display-down'),(42956,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top_measure','%','','','.b-menu-lev_display-down'),(42957,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top_measure','%','','','.b-menu-lev_display-down'),(42958,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top_measure','%','','','.b-menu-lev_display-down'),(42959,'watch-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top_measure','%','','','.b-menu-lev_display-down'),(42960,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','top_measure','%','3','','.b-menu-style-2'),(42961,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','top_measure','%','3','','.b-menu-style-2'),(42962,'watch-mobile','.b-select-suggest .select2-drop','top_measure','%','','','.b-select-suggest'),(42963,'watch-mobile','.b-slick .slick-slider','touch-action','pan-y','','','.b-slick'),(42964,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container','transform','translate3d(0, 0, 0)','','','.b-switch'),(42965,'watch-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','transform','translate3d(0, 0, 0)','','','.b-slick'),(42966,'watch-mobile','.b-products-listing .hover-box-content','transform','rotate( 45deg )','3','','.b-products-listing'),(42967,'watch-mobile','.b-menu-lev_display-slide .menu-style .slide-parent','transform','translateX(-100vw)','','','.b-menu-lev_display-slide'),(42968,'watch-mobile','.b-switch .bootstrap-switch','transition','border-color ease-in-out .15s, box-shadow ease-in-out .15s','','','.b-switch'),(42969,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-animate .bootstrap-switch-container','transition','margin-left 0.5s','','','.b-switch'),(42970,'watch-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','transition','max-height 1s','','','.b-menu-burger_icon'),(42971,'watch-mobile','.b-menu-lev_display-slide .menu-style ul','transition','visibility 300ms, transform 300ms','','','.b-menu-lev_display-slide'),(42972,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','transition','left 300ms','','','.b-menu-open_from-left'),(42973,'watch-mobile','.b-slick .slick-slider','user-select','none','','','.b-slick'),(42974,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','user-select','none','','','.b-select-suggest'),(42975,'watch-mobile','.b-select-suggest .select2-results .select2-result-label','user-select','none','','','.b-select-suggest'),(42976,'watch-mobile','.b-select-suggest .select2-container .select2-choice','user-select','none','','','.b-select-suggest'),(42977,'watch-mobile','.w-menu-big li li','vertical-align','top','','','.w-menu-big'),(42978,'watch-mobile','.w-menu-big li a, .w-menu-big li .no-link','vertical-align','middle','','','.w-menu-big'),(42979,'watch-mobile','.w-menu-slider > ul > li','vertical-align','top','','','.w-menu-slider'),(42980,'watch-mobile','.w-menu-slider .close','vertical-align','20px','','','.w-menu-slider'),(42981,'watch-mobile','.w-menu-slider > ul > li > ul > li','vertical-align','top','','','.w-menu-slider'),(42982,'watch-mobile','.w-account .my-acc-link','vertical-align','middle','3','','.w-account'),(42983,'watch-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','vertical-align','middle','','','.b-cookie-notice'),(42984,'watch-mobile','.b-form .checkbox-style:checked + .checkbox-span','vertical-align','middle','','','.b-form'),(42985,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','vertical-align','middle','','','.b-form'),(42986,'watch-mobile','.w-cart .cart-box-link','vertical-align','middle','3','','.w-cart'),(42987,'watch-mobile','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','vertical-align','middle','','','.w-menu-horizontal'),(42988,'watch-mobile','.b-product-images .additional-images .item > div, .b-product-images .additional-videos .item > div','vertical-align','middle','','','.b-product-images'),(42989,'watch-mobile','.w-compare-box-item .checkbox','vertical-align','top','','','.w-compare-box-item'),(42990,'watch-mobile','.w-compare-box-item .checkbox + span','vertical-align','middle','','','.w-compare-box-item'),(42991,'watch-mobile','.w-categories .item','vertical-align','top','','','.w-categories'),(42992,'watch-mobile','.w-quote .no-text','vertical-align','top','','','.w-quote'),(42993,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','vertical-align','middle','3','','.b-multi-page-checkout'),(42994,'watch-mobile','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(42995,'watch-mobile','.b-compare .compare_select_items','vertical-align','middle','','','.b-compare'),(42996,'watch-mobile','.w-catalog-listing-look .b2b','vertical-align','top','','','.w-catalog-listing-look'),(42997,'watch-mobile','.w-catalog-listing-look .list','vertical-align','top','','','.w-catalog-listing-look'),(42998,'watch-mobile','.b-pagination .pagination .prev-pages','vertical-align','top','','','.b-pagination'),(42999,'watch-mobile','.b-pagination .pagination .prev','vertical-align','top','','','.b-pagination'),(43000,'watch-mobile','.b-pagination .pagination .page-number','vertical-align','top','','','.b-pagination'),(43001,'watch-mobile','.b-pagination .pagination .next-pages','vertical-align','top','','','.b-pagination'),(43002,'watch-mobile','.b-pagination .pagination .next','vertical-align','top','','','.b-pagination'),(43003,'watch-mobile','.b-pagination .pagination span','vertical-align','top','2','','.b-pagination'),(43005,'watch-mobile','.p-reviews-info .review_by span','vertical-align','middle','','','.p-reviews-info'),(43006,'watch-mobile','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(43007,'watch-mobile','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(43008,'watch-mobile','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(43009,'watch-mobile','.p-wedding-registry-manage .links a','vertical-align','middle','','','.p-wedding-registry-manage'),(43010,'watch-mobile','.b-pagination .pagination a','vertical-align','top','','','.b-pagination'),(43011,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align','top','','','.b-switch'),(43012,'watch-mobile','.b-switch .bootstrap-switch','vertical-align','middle','','','.b-switch'),(43013,'watch-mobile','.w-filters .input-checkbox:checked + .checkbox-span','vertical-align','middle','','','.w-filters'),(43014,'watch-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','vertical-align','middle','','','.w-filters'),(43015,'watch-mobile','.w-quote .cart-box-link','vertical-align','middle','3','','.w-quote'),(43016,'watch-mobile','.w-tabs .tab-li','vertical-align','bottom','','','.w-tabs'),(43017,'watch-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','vertical-align','middle','','','.w-banner'),(43020,'watch-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','vertical-align','top','','','.b-fancybox'),(43021,'watch-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','vertical-align','top','','','.b-fancybox'),(43022,'watch-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(43023,'watch-mobile','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(43024,'watch-mobile','.w-product-configurator .item-content > div','vertical-align','middle','','','.w-product-configurator'),(43025,'watch-mobile','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(43026,'watch-mobile','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(43027,'watch-mobile','.w-catalog-listing-look .grid','vertical-align','top','','','.w-catalog-listing-look'),(43028,'watch-mobile','.w-cart .no-text','vertical-align','top','','','.w-cart'),(43029,'watch-mobile','.w-top-categories .item','vertical-align','top','','','.w-top-categories'),(43030,'watch-mobile','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','vertical-align','middle','','','.b-form'),(43031,'watch-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','vertical-align','middle','','','.w-menu-style-1'),(43032,'watch-mobile','.b-products-listing .products-listing .item','vertical-align','top','','','.b-products-listing'),(43033,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.b-data-table'),(43034,'watch-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.b-data-table'),(43035,'watch-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(43036,'watch-mobile','.b-email .image','vertical-align','top','','','.b-email'),(43037,'watch-mobile','.b-email .model','vertical-align','top','','','.b-email'),(43038,'watch-mobile','.b-email .price','vertical-align','top','','','.b-email'),(43039,'watch-mobile','.b-email .model','vertical-align','top','','','.b-email'),(43040,'watch-mobile','.b-email .model','vertical-align','top','','','.b-email'),(43041,'watch-mobile','.b-email .price','vertical-align','top','','','.b-email'),(43042,'watch-mobile','.b-email .name','vertical-align','top','','','.b-email'),(43043,'watch-mobile','.b-email .model','vertical-align','top','','','.b-email'),(43044,'watch-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(43045,'watch-mobile','.b-email .image','vertical-align','top','','','.b-email'),(43046,'watch-mobile','.b-email .image','vertical-align','top','','','.b-email'),(43047,'watch-mobile','.b-email .model','vertical-align','top','','','.b-email'),(43048,'watch-mobile','.b-email .name','vertical-align','top','','','.b-email'),(43049,'watch-mobile','.b-email .price','vertical-align','top','','','.b-email'),(43050,'watch-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(43051,'watch-mobile','.b-email .image','vertical-align','top','','','.b-email'),(43052,'watch-mobile','.b-email .name','vertical-align','top','','','.b-email'),(43053,'watch-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(43054,'watch-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(43055,'watch-mobile','.b-email .image','vertical-align','top','','','.b-email'),(43056,'watch-mobile','.b-email .image','vertical-align','top','','','.b-email'),(43057,'watch-mobile','.b-email .name','vertical-align','top','','','.b-email'),(43058,'watch-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(43059,'watch-mobile','.b-email .name','vertical-align','top','','','.b-email'),(43060,'watch-mobile','.b-email .name','vertical-align','top','','','.b-email'),(43061,'watch-mobile','.b-email .price','vertical-align','top','','','.b-email'),(43062,'watch-mobile','.b-email .price','vertical-align','top','','','.b-email'),(43063,'watch-mobile','.b-email .model','vertical-align','top','','','.b-email'),(43064,'watch-mobile','.b-email .price','vertical-align','top','','','.b-email'),(43065,'watch-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(43066,'watch-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(43067,'watch-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(43068,'watch-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(43069,'watch-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(43070,'watch-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(43071,'watch-mobile','.b-messages .msv_to_cc div span','vertical-align','middle','','','.b-messages'),(43072,'watch-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(43073,'watch-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(43074,'watch-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(43075,'watch-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(43076,'watch-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(43077,'watch-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(43078,'watch-mobile','.b-upload-file .upload-file-template','vertical-align','top','','','.b-upload-file'),(43079,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','vertical-align','top','','','.b-warehouses-popup'),(43080,'watch-mobile','.batchPr .checkbox input + span','vertical-align','middle','','','.batchPr'),(43087,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.p-quick-order-index'),(43088,'watch-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.p-quick-order-index'),(43089,'watch-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','vertical-align','middle','','','.w-blog-widget-post-share'),(43090,'watch-mobile','.w-cart-compare .product-label','vertical-align','bottom','','','.w-cart-compare'),(43091,'watch-mobile','.w-cart-compare .product-actions .dropdown-toggle','vertical-align','middle','3','','.w-cart-compare'),(43092,'watch-mobile','.w-cart-compare .product-cell','vertical-align','top','','','.w-cart-compare'),(43093,'watch-mobile','.w-cart-credit-amount .amount-title','vertical-align','top','3','','.w-cart-credit-amount'),(43094,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','vertical-align','middle','3','','.w-catalog-compare'),(43095,'watch-mobile','.w-catalog-paging ','vertical-align','top','2','','.w-catalog-paging'),(43096,'watch-mobile','.w-catalog-paging .prev','vertical-align','top','','','.w-catalog-paging'),(43097,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','vertical-align','top','','','.w-catalog-paging'),(43098,'watch-mobile','.w-catalog-paging .page-number','vertical-align','top','','','.w-catalog-paging'),(43099,'watch-mobile','.w-catalog-paging .next-pages','vertical-align','top','','','.w-catalog-paging'),(43100,'watch-mobile','.w-catalog-paging .next','vertical-align','top','','','.w-catalog-paging'),(43101,'watch-mobile','.w-catalog-paging .prev-pages','vertical-align','top','','','.w-catalog-paging'),(43102,'watch-mobile','.w-checkout-billing-address .genders-title > div','vertical-align','top','','','.w-checkout-billing-address'),(43103,'watch-mobile','.w-checkout-shipping-address .genders-title > div','vertical-align','top','','','.w-checkout-shipping-address'),(43104,'watch-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','vertical-align','bottom','','','.w-communication-new-topic'),(43105,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','vertical-align','top','','','.w-communication-new-topic'),(43106,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','3','','.w-communication-new-topic'),(43107,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','','','.w-communication-new-topic'),(43108,'watch-mobile','.w-product-available-in-warehouses .warehouse-item','vertical-align','top','','','.w-product-available-in-warehouses'),(43109,'watch-mobile','.w-promotions .heading-3','vertical-align','top','','','.w-promotions'),(43110,'watch-mobile','.b-quantity .qty-box input[type=\'text\']','vertical-align','top','','','.b-quantity'),(43111,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','vertical-align','middle','','','.w-filters'),(43112,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align_important','important','','','.b-switch'),(43113,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no','visibility','hidden','','','.b-form'),(43114,'watch-mobile','.w-compare-box-item .checkbox:not(checked)','visibility','hidden','','','.w-compare-box-item'),(43115,'watch-mobile','.b-fancybox .fancybox-title','visibility','hidden','','','.b-fancybox'),(43116,'watch-mobile','.b-fancybox .fancybox-tmp','visibility','hidden','','','.b-fancybox'),(43117,'watch-mobile','.b-fancybox .fancybox-nav:hover span','visibility','visible','','','.b-fancybox'),(43118,'watch-mobile','.b-fancybox .fancybox-opened .fancybox-title','visibility','visible','','','.b-fancybox'),(43119,'watch-mobile','.b-slick .slick-loading .slick-track','visibility','hidden','','','.b-slick'),(43120,'watch-mobile','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(43121,'watch-mobile','.b-slick .slick-loading .slick-slide','visibility','hidden','','','.b-slick'),(43122,'watch-mobile','.b-fancybox .fancybox-nav span','visibility','hidden','','','.b-fancybox'),(43123,'watch-mobile','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(43124,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','visibility','hidden','','','.b-menu-lev_display-slide'),(43125,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-1 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(43126,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','visibility','hidden','','','.b-menu-lev_display-slide'),(43127,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','visibility','hidden','','','.b-menu-lev_display-slide'),(43128,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','visibility','hidden','','','.b-menu-lev_display-slide'),(43129,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','visibility','hidden','','','.b-menu-lev_display-slide'),(43130,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-2 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(43131,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-4 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(43132,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-5 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(43133,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-3 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(43134,'watch-mobile','.b-upload-files .attach-active-holder .attach-file','visibility','hidden','','','.b-upload-files'),(43135,'watch-mobile','.batchPr .checkbox input','visibility','hidden','','','.batchPr'),(43136,'watch-mobile','.w-menu-horizontal > ul','white-space','nowrap','','','.w-menu-horizontal'),(43137,'watch-mobile','.w-menu-style-1 > ul','white-space','nowrap','','','.w-menu-style-1'),(43138,'watch-mobile','.w-menu-horizontal > ul','white-space','normal','291','','.w-menu-horizontal'),(43140,'watch-mobile','.b-fancybox .fancybox-error','white-space','nowrap','','','.b-fancybox'),(43141,'watch-mobile','.b-fancybox .fancybox-title-float-wrap .child','white-space','nowrap','','','.b-fancybox'),(43143,'watch-mobile','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(43144,'watch-mobile','.b-select-suggest .select2-search','white-space','nowrap','','','.b-select-suggest'),(43145,'watch-mobile','.b-select-suggest .select2-container .select2-choice','white-space','nowrap','','','.b-select-suggest'),(43146,'watch-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','white-space','nowrap','','','.b-select-suggest'),(43147,'watch-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','white-space','nowrap','','','.b-select-suggest'),(43154,'watch-mobile','.w-checkout-shipping-choice span','white-space','nowrap','','','.w-checkout-shipping-choice'),(43155,'watch-mobile','.w-menu .hided.menu ul li','width','auto','','','.w-menu'),(43156,'watch-mobile','.w-menu .hided.menu ul ul','width','auto','','','.w-menu'),(43157,'watch-mobile','.w-menu-big li','width','auto','','','.w-menu-big'),(43158,'watch-mobile','.w-menu-slider > ul > li > ul','width','100','','','.w-menu-slider'),(43159,'watch-mobile','.w-bestsellers .item','width','31','3','','.w-bestsellers'),(43160,'watch-mobile','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(43161,'watch-mobile','.w-bestsellers .counter','width','31','','','.w-bestsellers'),(43162,'watch-mobile','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(43163,'watch-mobile','.b-form .checkbox-style:checked + .checkbox-span','width','15','','','.b-form'),(43164,'watch-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','width','15','','','.b-form'),(43165,'watch-mobile','.b-form .checkbox-style','width','0','','','.b-form'),(43166,'watch-mobile','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(43167,'watch-mobile','.w-login-block .guest','width','50','','','.w-login-block'),(43168,'watch-mobile','.w-login-block .input','width','100','','','.w-login-block'),(43169,'watch-mobile','.w-login-block .returning','width','50','','','.w-login-block'),(43170,'watch-mobile','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(43171,'watch-mobile','.w-login-block .new','width','50','','','.w-login-block'),(43172,'watch-mobile','.w-sale .left-count','width','23','','','.w-sale'),(43173,'watch-mobile','.w-menu-horizontal .menu-ico','width','54','','','.w-menu-horizontal'),(43174,'watch-mobile','.w-list-type-2_2 .sale','width','100','4','','.w-list-type-2_2'),(43175,'watch-mobile','.w-sale .image','width','50','','','.w-sale'),(43176,'watch-mobile','.w-sale .holder-1','width','25','','','.w-sale'),(43177,'watch-mobile','.w-sale .holder-2','width','25','','','.w-sale'),(43178,'watch-mobile','.w-sale .badge','width','80','','','.w-sale'),(43179,'watch-mobile','.w-menu-style-1 .menu-ico','width','54','','','.w-menu-style-1'),(43180,'watch-mobile','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(43181,'watch-mobile','.w-product-attributes .select','width','100','','','.w-product-attributes'),(43182,'watch-mobile','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(43183,'watch-mobile','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(43184,'watch-mobile','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(43185,'watch-mobile','.w-product-wedding-registry-button .btn','width','18','4','','.w-product-wedding-registry-button'),(43186,'watch-mobile','.w-product-sale-ends .left-count','width','23','','','.w-product-sale-ends'),(43187,'watch-mobile','.w-product-sale-ends .left-text-left','width','24','','','.w-product-sale-ends'),(43188,'watch-mobile','.w-product-sale-ends .left-text-right','width','24','','','.w-product-sale-ends'),(43189,'watch-mobile','.w-product-collection .right-area','width','25','','','.w-product-collection'),(43190,'watch-mobile','.w-product-collection .chosen-products','width','50','','','.w-product-collection'),(43191,'watch-mobile','.w-product-collection .current-product','width','25','','','.w-product-collection'),(43192,'watch-mobile','.b-fancybox .fancybox-nav','width','40','','','.b-fancybox'),(43193,'watch-mobile','.w-top-categories .item','width','50','290','','.w-top-categories'),(43194,'watch-mobile','.w-product-personal-catalog-button .btn','width','160','','','.w-product-personal-catalog-button'),(43195,'watch-mobile','.w-currencies .select','width','100','','','.w-currencies'),(43196,'watch-mobile','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(43197,'watch-mobile','.w-categories .item','width','50','290','','.w-categories'),(43200,'watch-mobile','.w-compare-box-item .checkbox','width','22','','','.w-compare-box-item'),(43201,'watch-mobile','.w-compare-box-item .checkbox + span','width','24','','','.w-compare-box-item'),(43202,'watch-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width','49','','','.p-account-trade-form'),(43203,'watch-mobile','.w-categories .item','width','25','','','.w-categories'),(43204,'watch-mobile','.w-cart-order-total.box','width','100','319','','.w-cart-order-total'),(43205,'watch-mobile','.w-cart-checkout-btn','width','100','290','','.w-cart-checkout-btn'),(43206,'watch-mobile','.b-product-images .additional-horizontal .additional-images, .b-product-images .additional-horizontal .additional-videos','width','100','','','.b-product-images'),(43207,'watch-mobile','.b-price-box .price-box .price','width','200','','','.b-price-box'),(43208,'watch-mobile','.w-cart-give-away .ga_column','width','100','290','','.w-cart-give-away'),(43209,'watch-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','width','auto','','','.b-product-images'),(43210,'watch-mobile','.w-product-properties li','width','50','','','.w-product-properties'),(43211,'watch-mobile','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(43212,'watch-mobile','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(43213,'watch-mobile','.w-product-in-bundles .bundle_item','width','48','','','.w-product-in-bundles'),(43214,'watch-mobile','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(43216,'watch-mobile','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(43217,'watch-mobile','.w-product-bundle .bundle_item','width','48','','','.w-product-bundle'),(43218,'watch-mobile','.w-menu-slider .menu-ico','width','54','','','.w-menu-slider'),(43219,'watch-mobile','.w-catalog-listing-look .b2b','width','31','','','.w-catalog-listing-look'),(43220,'watch-mobile','.w-catalog-listing-look .list','width','31','','','.w-catalog-listing-look'),(43226,'watch-mobile','.p-blog-index .nav-next','width','100','315','','.p-blog-index'),(43228,'watch-mobile','.p-blog-index .nav-previous','width','100','315','','.p-blog-index'),(43229,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','width','35','3','','.b-multi-page-checkout'),(43230,'watch-mobile','.p-blog-index .post-thumbnail','width','200','','','.p-blog-index'),(43231,'watch-mobile','.w-list-type-1_2 .right-area','width','100','291','','.w-list-type-1_2'),(43232,'watch-mobile','.p-blog-index .comment-form p label','width','100','','','.p-blog-index'),(43233,'watch-mobile','.w-list-type-1_2 .right-area .name','width','60','','','.w-list-type-1_2'),(43234,'watch-mobile','.w-list-type-1_2 .image','width','100','291','','.w-list-type-1_2'),(43235,'watch-mobile','.w-list-type-1_2 .right-area .right-area-2','width','100','291','','.w-list-type-1_2'),(43236,'watch-mobile','.w-list-type-1_2 .right-area .right-area-2','width','38','','','.w-list-type-1_2'),(43237,'watch-mobile','.w-list-type-1_2 .right-area .name','width','100','291','','.w-list-type-1_2'),(43238,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','width','33','','','.b-multi-page-checkout'),(43239,'watch-mobile','.b-info-popup .info-popup div','width','250','','','.b-info-popup'),(43240,'watch-mobile','.w-menu-mobile .menu-slider .open','width','100','','','.w-menu-mobile'),(43241,'watch-mobile','.w-promo-code .promo-text','width','100','291','','.w-promo-code'),(43242,'watch-mobile','.w-promo-code .promo-code-form','width','100','291','','.w-promo-code'),(43243,'watch-mobile','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(43244,'watch-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 110px)','291','','.w-promo-code'),(43245,'watch-mobile','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(43246,'watch-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(43247,'watch-mobile','.w-catalog-sorting select','width','100','','','.w-catalog-sorting'),(43248,'watch-mobile','.b-form .col-right','width','100','317','','.b-form'),(43249,'watch-mobile','.b-form .columns .col-2','width','100','320','','.b-form'),(43250,'watch-mobile','.b-form .col-left','width','100','317','','.b-form'),(43254,'watch-mobile','.w-product-configurator .item-content','width','100','299','','.w-product-configurator'),(43255,'watch-mobile','.w-product-configurator .pc_item','width','100','299','','.w-product-configurator'),(43256,'watch-mobile','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(43257,'watch-mobile','.p-wedding-registry-manage .wr-search input','width','100','','','.p-wedding-registry-manage'),(43258,'watch-mobile','.p-wedding-registry-manage .wr-search','width','400','','','.p-wedding-registry-manage'),(43259,'watch-mobile','.p-wedding-registry-manage .wr-search button','width','30','','','.p-wedding-registry-manage'),(43263,'watch-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','50','317','','.p-blog-index'),(43265,'watch-mobile','.p-blog-index .nav-next','width','50','','','.p-blog-index'),(43266,'watch-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','100','320','','.p-blog-index'),(43267,'watch-mobile','.p-blog-index .nav-previous','width','50','','','.p-blog-index'),(43268,'watch-mobile','.pop-up-content .buttons .btn','width','100','291','',''),(43269,'watch-mobile','.w-list-type-1_3 .right-area .right-area-2','width','38','','','.w-list-type-1_3'),(43270,'watch-mobile','.pop-up-content .buttons .btn-2','width','100','291','',''),(43271,'watch-mobile','.w-list-type-2_2 .sale','width','94','','','.w-list-type-2_2'),(43272,'watch-mobile','.pop-up-content .buttons .right-buttons','width','100','291','',''),(43273,'watch-mobile','.pop-up-content .buttons .left-buttons','width','100','291','',''),(43274,'watch-mobile','.w-list-type-2_2 .image','width','170','','','.w-list-type-2_2'),(43275,'watch-mobile','.w-list-type-2_2 .sale','width','100','3','','.w-list-type-2_2'),(43276,'watch-mobile','.w-list-type-2_2 .button-wishlist button','width','100','','','.w-list-type-2_2'),(43277,'watch-mobile','.w-list-type-2 .sale','width','100','3','','.w-list-type-2'),(43278,'watch-mobile','.w-list-type-2 .sale','width','94','','','.w-list-type-2'),(43279,'watch-mobile','.w-list-type-2_2 .button-wishlist','width','50','','','.w-list-type-2_2'),(43280,'watch-mobile','.personal-buttons > div > div','width','50','','','.personal-buttons'),(43281,'watch-mobile','.w-product-bonus-points > div > div','width','50','','','.w-product-bonus-points'),(43282,'watch-mobile','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(43283,'watch-mobile','.w-cart-continue-btn a','width','100','290','','.w-cart-continue-btn'),(43284,'watch-mobile','.b-fancybox #fancybox-loading div','width','44','','','.b-fancybox'),(43285,'watch-mobile','.w-brands .brands-listing > div','width','16','','','.w-brands'),(43286,'watch-mobile','.w-product-wedding-registry-button .btn','width','160','','','.w-product-wedding-registry-button'),(43287,'watch-mobile','.b-fancybox .fancybox-close','width','36','','','.b-fancybox'),(43288,'watch-mobile','.b-fancybox .fancybox-lock','width','auto','','','.b-fancybox'),(43289,'watch-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width','100','','','.b-fancybox'),(43290,'watch-mobile','.w-delivery-location-top-location-list .deliveryList li','width','23','','','.w-delivery-location-top-location-list'),(43291,'watch-mobile','.w-menu-horizontal li','width','auto','','','.w-menu-horizontal'),(43292,'watch-mobile','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(43293,'watch-mobile','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(43294,'watch-mobile','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(43295,'watch-mobile','.b-form .radio-button input[type=\"radio\"].no + span','width','30','3','','.b-form'),(43296,'watch-mobile','.p-wedding-registry-index .search-list input','width','300','','','.p-wedding-registry-index'),(43297,'watch-mobile','.p-wedding-registry-index .search-list','width','150','3','','.p-wedding-registry-index'),(43298,'watch-mobile','.p-wedding-registry-search .search-list input','width','100','','','.p-wedding-registry-search'),(43299,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width','20','3','','.b-switch'),(43300,'watch-mobile','.b-bottom .popup-credit-amount .popup-box','width','100','','','.b-bottom'),(43301,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width','20','3','','.b-switch'),(43302,'watch-mobile','.b-compare .col-two label','width','20','','','.b-compare'),(43303,'watch-mobile','.b-compare .col-two select','width','80','','','.b-compare'),(43304,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-label','width','30','','','.b-switch'),(43305,'watch-mobile','.w-list-type-1 .image img','width','auto','','','.w-list-type-1'),(43307,'watch-mobile','.w-languages .lang-link','width','61','299','','.w-languages'),(43308,'watch-mobile','.w-product-buttons .btn, .w-product-buttons .btn-2, .w-product-buttons .btn-3, .w-product-buttons .btn-4','width','100','','','.w-product-buttons'),(43309,'watch-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','width','39','','','.b-quantity'),(43310,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','width','40','','','.b-slick'),(43311,'watch-mobile','.w-filters .input-checkbox:checked + .checkbox-span','width','24','','','.w-filters'),(43312,'watch-mobile','.b-form .col-left','width','48','','','.b-form'),(43313,'watch-mobile','.w-search .suggest','width','100','','','.w-search'),(43314,'watch-mobile','.w-search .image','width','40','','','.w-search'),(43315,'watch-mobile','.w-search .search-input','width','100','','','.w-search'),(43316,'watch-mobile','.w-socials .post_item_img','width','100','','','.w-socials'),(43317,'watch-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width','100','','','.w-banner'),(43318,'watch-mobile','textarea','width','100','','',''),(43319,'watch-mobile','.w-filters .input-txt','width','60','','','.w-filters'),(43320,'watch-mobile','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width','100','','','.w-banner'),(43321,'watch-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width','48','','','.p-account-trade-form'),(43322,'watch-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width','55','','','.p-account-trade-form'),(43323,'watch-mobile','.p-account-trade-form .wl-td label','width','40','','','.p-account-trade-form'),(43324,'watch-mobile','.p-account-trade-form .wl-td select','width','55','','','.p-account-trade-form'),(43325,'watch-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width','48','','','.p-account-trade-form'),(43326,'watch-mobile','.b-price-box .price-box .price','width','120','319','','.b-price-box'),(43327,'watch-mobile','.w-filters .handle-from','width','50','','','.w-filters'),(43328,'watch-mobile','.b-bottom .popup-box.popupCompare','width','80','','','.b-bottom'),(43329,'watch-mobile','.w-filters .handle-to','width','50','','','.w-filters'),(43330,'watch-mobile','.w-filters .input-checkbox','width','0','','','.w-filters'),(43331,'watch-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','width','24','','','.w-filters'),(43332,'watch-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(43333,'watch-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','width','22','','','.w-compare-box-item'),(43334,'watch-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width','49','','','.p-account-trade-form'),(43335,'watch-mobile','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(43336,'watch-mobile','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(43337,'watch-mobile','.b-info-popup .info-popup div','width','20','3','','.b-info-popup'),(43338,'watch-mobile','.p-reviews-info .review-info-image','width','24','','','.p-reviews-info'),(43339,'watch-mobile','.b-fancybox .fancybox-nav span','width','40','','','.b-fancybox'),(43341,'watch-mobile','.w-menu-mobile .menu-ico','width','54','','','.w-menu-mobile'),(43342,'watch-mobile','.w-product-quantity-discounts .quantity-discounts .count','width','40','','','.w-product-quantity-discounts'),(43343,'watch-mobile','.w-product-wedding-registry-button .btn','width','18','3','','.w-product-wedding-registry-button'),(43344,'watch-mobile','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(43345,'watch-mobile','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(43346,'watch-mobile','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(43347,'watch-mobile','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(43348,'watch-mobile','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(43349,'watch-mobile','.w-menu-style-1 li','width','auto','','','.w-menu-style-1'),(43351,'watch-mobile','.w-sale .left-text-right','width','24','','','.w-sale'),(43352,'watch-mobile','.w-sale .left-text-left','width','24','','','.w-sale'),(43353,'watch-mobile','.w-banner .carousel-text','width','100','','','.w-banner'),(43354,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','width','50','303','','.b-slick'),(43355,'watch-mobile','.b-quantity .qty-box .smaller','width','35','','','.b-quantity'),(43356,'watch-mobile','.b-quantity .qty-input input','width','40','','','.b-quantity'),(43357,'watch-mobile','.b-quantity .qty-box .bigger','width','35','','','.b-quantity'),(43358,'watch-mobile','.w-cart-checkout-btn a','width','100','290','','.w-cart-checkout-btn'),(43359,'watch-mobile','.w-cart .cart-box.hover-box .cart-content','width','410','','','.w-cart'),(43361,'watch-mobile','.w-product-images .item-div','width','80','320','','.w-product-images'),(43362,'watch-mobile','.w-product-images .item','width','80','320','','.w-product-images'),(43363,'watch-mobile','.w-list-type-1_3 .right-area .name','width','60','','','.w-list-type-1_3'),(43364,'watch-mobile','.w-list-type-1_3 .right-area','width','100','291','','.w-list-type-1_3'),(43365,'watch-mobile','.w-list-type-1_3 .right-area .right-area-2','width','100','291','','.w-list-type-1_3'),(43366,'watch-mobile','.w-list-type-1_3 .image','width','100','291','','.w-list-type-1_3'),(43367,'watch-mobile','.w-list-type-1_3 .right-area .name','width','100','291','','.w-list-type-1_3'),(43368,'watch-mobile','.w-cart-order-total.box','width','100','','','.w-cart-order-total'),(43369,'watch-mobile','.w-cart-discount-coupon .gift-code input','width','100','','','.w-cart-discount-coupon'),(43370,'watch-mobile','.w-cart .image','width','70','','','.w-cart'),(43371,'watch-mobile','.b-form .addresses .address-item','width','48','','','.b-form'),(43372,'watch-mobile','.w-catalog-listing-look .grid','width','31','','','.w-catalog-listing-look'),(43373,'watch-mobile','.b-form .discount-box input[type=\"text\"]','width','100','','','.b-form'),(43375,'watch-mobile','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width','100','','','.b-form'),(43376,'watch-mobile','.b-form .hide-billing-address','width','100','','','.b-form'),(43377,'watch-mobile','.b-form .col-right','width','48','','','.b-form'),(43378,'watch-mobile','.b-form .columns .col-2','width','48','','','.b-form'),(43380,'watch-mobile','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(43381,'watch-mobile','.w-cart-give-away .ga_attributes select','width','100','','','.w-cart-give-away'),(43382,'watch-mobile','.w-cart-give-away .ga_column','width','46','','','.w-cart-give-away'),(43383,'watch-mobile','.w-cart-give-away .ga_attributes > div','width','48','','','.w-cart-give-away'),(43384,'watch-mobile','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','width','79','','','.b-datepicker'),(43385,'watch-mobile','.w-cart-give-away .ga_img','width','30','','','.w-cart-give-away'),(43386,'watch-mobile','.w-list-type-1_3 .right-area','width','calc(100% - 190px)','','','.w-list-type-1_3'),(43387,'watch-mobile','.view-all','width','100','3','',''),(43388,'watch-mobile','.w-list-type-2 .button-wishlist button','width','100','','','.w-list-type-2'),(43389,'watch-mobile','.w-list-type-2 .button-wishlist','width','50','','','.w-list-type-2'),(43390,'watch-mobile','.w-list-type-1_3 .sale','width','100','4','','.w-list-type-1_3'),(43391,'watch-mobile','.w-list-type-1_3 .sale','width','100','3','','.w-list-type-1_3'),(43392,'watch-mobile','.w-list-type-2 .sale','width','100','4','','.w-list-type-2'),(43393,'watch-mobile','.w-list-type-1_3 .sale','width','94','','','.w-list-type-1_3'),(43394,'watch-mobile','.w-list-type-1_3 .image','width','170','','','.w-list-type-1_3'),(43395,'watch-mobile','.w-list-type-1_3 .button-wishlist','width','50','','','.w-list-type-1_3'),(43396,'watch-mobile','.w-list-type-1_2 .sale','width','100','4','','.w-list-type-1_2'),(43397,'watch-mobile','.w-list-type-1_3 .button-wishlist button','width','100','','','.w-list-type-1_3'),(43398,'watch-mobile','.w-list-type-1_3 .attributes > .attributes > div','width','48','','','.w-list-type-1_3'),(43399,'watch-mobile','.w-list-type-1_2 .right-area','width','calc(100% - 190px)','','','.w-list-type-1_2'),(43400,'watch-mobile','.w-list-type-1_2 .sale','width','100','3','','.w-list-type-1_2'),(43401,'watch-mobile','.w-list-type-1_2 .sale','width','94','','','.w-list-type-1_2'),(43402,'watch-mobile','.b-bottom .pop-up-close','width','31','','','.b-bottom'),(43403,'watch-mobile','.w-list-type-1 .sale','width','100','4','','.w-list-type-1'),(43404,'watch-mobile','.w-list-type-1_2 .button-view','width','50','','','.w-list-type-1_2'),(43405,'watch-mobile','.w-list-type-1_2 .button-wishlist button','width','100','','','.w-list-type-1_2'),(43406,'watch-mobile','.w-list-type-1_2 .button-wishlist','width','50','','','.w-list-type-1_2'),(43407,'watch-mobile','.w-list-type-1 .sale','width','94','','','.w-list-type-1'),(43408,'watch-mobile','.w-list-type-1 .sale','width','100','3','','.w-list-type-1'),(43409,'watch-mobile','.b-bottom .popup-box','width','530','','','.b-bottom'),(43410,'watch-mobile','.w-list-type-1 .button-wishlist button','width','100','','','.w-list-type-1'),(43411,'watch-mobile','.w-filters .mobileCollapse','width','17','','','.w-filters'),(43412,'watch-mobile','.w-filters .input-txt-keywords','width','100','','','.w-filters'),(43413,'watch-mobile','.w-filters .ui-slider-handle','width','15','','','.w-filters'),(43414,'watch-mobile','.w-filters .ui-slider','width','92','','','.w-filters'),(43415,'watch-mobile','.w-tabs .tab-navigation','width','100','','','.w-tabs'),(43416,'watch-mobile','.w-list-type-1 .button-wishlist','width','50','','','.w-list-type-1'),(43418,'watch-mobile','.w-top-categories .item','width','25','','','.w-top-categories'),(43419,'watch-mobile','.w-search .button-search','width','48','','','.w-search'),(43420,'watch-mobile','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width','100','','','.b-form'),(43422,'watch-mobile','.b-form .middle-form .dob-input input[type=\"text\"]','width','48','','','.b-form'),(43423,'watch-mobile','div.cart-popup','width','850','','',''),(43424,'watch-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width','80','','','.b-products-listing'),(43425,'watch-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width','20','','','.b-products-listing'),(43426,'watch-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width','40','','','.b-products-listing'),(43427,'watch-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width','60','','','.b-products-listing'),(43428,'watch-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width','60','','','.b-products-listing'),(43429,'watch-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width','40','','','.b-products-listing'),(43430,'watch-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width','20','','','.b-products-listing'),(43431,'watch-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width','60','','','.b-products-listing'),(43432,'watch-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width','20','','','.b-products-listing'),(43433,'watch-mobile','.b-products-listing .BlockBox.type-14 > .col','width','25','','','.b-products-listing'),(43434,'watch-mobile','.b-products-listing .BlockBox.type-15 > .col','width','20','','','.b-products-listing'),(43435,'watch-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width','50','','','.b-products-listing'),(43436,'watch-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width','50','','','.b-products-listing'),(43437,'watch-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(43438,'watch-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(43439,'watch-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width','33.33','','','.b-products-listing'),(43440,'watch-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width','66.66','','','.b-products-listing'),(43441,'watch-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(43442,'watch-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(43443,'watch-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width','66.66','','','.b-products-listing'),(43444,'watch-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width','25','','','.b-products-listing'),(43445,'watch-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width','75','','','.b-products-listing'),(43446,'watch-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width','75','','','.b-products-listing'),(43447,'watch-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width','25','','','.b-products-listing'),(43448,'watch-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width','25','','','.b-products-listing'),(43449,'watch-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width','50','','','.b-products-listing'),(43450,'watch-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width','25','','','.b-products-listing'),(43451,'watch-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width','20','','','.b-products-listing'),(43452,'watch-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width','80','','','.b-products-listing'),(43453,'watch-mobile','.b-products-listing .btn-choose-options','width','100','','','.b-products-listing'),(43454,'watch-mobile','.b-products-listing .btn-preloader','width','24','3','','.b-products-listing'),(43455,'watch-mobile','.b-products-listing .hover-box-content','width','20','3','','.b-products-listing'),(43456,'watch-mobile','.b-products-listing .loader','width','30','4','','.b-products-listing'),(43457,'watch-mobile','.b-products-listing .loader','width','100','3','','.b-products-listing'),(43458,'watch-mobile','.b-products-listing .products-listing .attribute-qty-block','width','47','','','.b-products-listing'),(43459,'watch-mobile','.b-products-listing .products-listing .attribute-qty-block > span','width','50','','','.b-products-listing'),(43460,'watch-mobile','.b-products-listing .products-listing .attributes select','width','100','','','.b-products-listing'),(43461,'watch-mobile','.b-products-listing .products-listing .btn-buy','width','100','','','.b-products-listing'),(43462,'watch-mobile','.b-products-listing .products-listing .btn-preloader','width','100','','','.b-products-listing'),(43463,'watch-mobile','.b-products-listing .products-listing .buyButton .btn','width','100','','','.b-products-listing'),(43464,'watch-mobile','.b-products-listing .products-listing .in-cart','width','100','','','.b-products-listing'),(43465,'watch-mobile','.b-products-listing .products-listing .item','width','25','','','.b-products-listing'),(43466,'watch-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','width','35','','','.b-products-listing'),(43467,'watch-mobile','.b-products-listing .products-listing .qty-input.hidden','width','100','3','','.b-products-listing'),(43468,'watch-mobile','.b-products-listing .products-listing .radio-attributes .item-title','width','33','','','.b-products-listing'),(43469,'watch-mobile','.b-products-listing .products-listing a.btn.view-button','width','100','','','.b-products-listing'),(43470,'watch-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','width','auto','','','.b-products-listing'),(43471,'watch-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width','100','','','.b-products-listing'),(43472,'watch-mobile','.b-products-listing .select-attributes .item-title','width','33','','','.b-products-listing'),(43473,'watch-mobile','.b-products-listing .select-attributes select','width','66','','','.b-products-listing'),(43474,'watch-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(43475,'watch-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(43476,'watch-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(43477,'watch-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(43478,'watch-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(43479,'watch-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(43480,'watch-mobile','.b-email .totals-title','width','70','','','.b-email'),(43481,'watch-mobile','.b-email .heading-image','width','100','','','.b-email'),(43482,'watch-mobile','.b-email .image','width','100','','','.b-email'),(43483,'watch-mobile','.b-email .heading-image','width','100','','','.b-email'),(43484,'watch-mobile','.b-email .totals-title','width','70','','','.b-email'),(43485,'watch-mobile','.b-email .totals-table','width','100','','','.b-email'),(43486,'watch-mobile','.b-email .image','width','100','','','.b-email'),(43487,'watch-mobile','.b-email .totals-table','width','100','','','.b-email'),(43488,'watch-mobile','.b-email .totals-table','width','100','','','.b-email'),(43489,'watch-mobile','.b-email .totals-value','width','30','','','.b-email'),(43490,'watch-mobile','.b-email .totals-value','width','30','','','.b-email'),(43491,'watch-mobile','.b-email .products-table','width','100','','','.b-email'),(43492,'watch-mobile','.b-email .products-table','width','100','','','.b-email'),(43493,'watch-mobile','.b-email img','width','60','','','.b-email'),(43494,'watch-mobile','.b-email .heading-image','width','100','','','.b-email'),(43495,'watch-mobile','.b-email .totals-value','width','30','','','.b-email'),(43496,'watch-mobile','.b-email .products-table','width','100','','','.b-email'),(43497,'watch-mobile','.b-email .image','width','100','','','.b-email'),(43498,'watch-mobile','.b-email .totals-value','width','30','','','.b-email'),(43499,'watch-mobile','.b-email .totals-title','width','70','','','.b-email'),(43500,'watch-mobile','.b-email .products-table','width','100','','','.b-email'),(43501,'watch-mobile','.b-email .totals-title','width','70','','','.b-email'),(43502,'watch-mobile','.b-email .image','width','100','','','.b-email'),(43503,'watch-mobile','.b-email .totals-value','width','30','','','.b-email'),(43504,'watch-mobile','.b-email .image','width','100','','','.b-email'),(43505,'watch-mobile','.b-email img','width','60','','','.b-email'),(43506,'watch-mobile','.b-email .totals-title','width','70','','','.b-email'),(43507,'watch-mobile','.b-email .heading-image','width','100','','','.b-email'),(43508,'watch-mobile','.b-email img','width','60','','','.b-email'),(43509,'watch-mobile','.b-email .totals-table','width','100','','','.b-email'),(43510,'watch-mobile','.b-email .products-table','width','100','','','.b-email'),(43511,'watch-mobile','.b-email .totals-title','width','70','','','.b-email'),(43512,'watch-mobile','.b-email img','width','60','','','.b-email'),(43513,'watch-mobile','.b-email .totals-table','width','100','','','.b-email'),(43514,'watch-mobile','.b-email .heading-image','width','100','','','.b-email'),(43515,'watch-mobile','.b-email img','width','60','','','.b-email'),(43516,'watch-mobile','.b-email img','width','60','','','.b-email'),(43517,'watch-mobile','.b-email .products-table','width','100','','','.b-email'),(43518,'watch-mobile','.b-email .totals-table','width','100','','','.b-email'),(43519,'watch-mobile','.b-email .totals-value','width','30','','','.b-email'),(43520,'watch-mobile','.b-email .image','width','100','','','.b-email'),(43521,'watch-mobile','.b-email .heading-image','width','100','','','.b-email'),(43522,'watch-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(43523,'watch-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(43524,'watch-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(43525,'watch-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(43526,'watch-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(43527,'watch-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(43528,'watch-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','width','30','','','.b-menu-burger_icon'),(43529,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width','100','','','.b-menu-lev_display-slide'),(43530,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width','100','','','.b-menu-lev_display-slide'),(43531,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width','100','','','.b-menu-lev_display-slide'),(43532,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width','100','','','.b-menu-lev_display-slide'),(43533,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width','100','','','.b-menu-lev_display-slide'),(43534,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(43535,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(43536,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(43537,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(43538,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(43539,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width','100','','','.b-menu-open_from-left'),(43540,'watch-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(43541,'watch-mobile','.b-menu-style-1 .menu-style[data-lev2_display=\"width\"] .level-2 > li','width','300','','','.b-menu-style-1'),(43542,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','width','100','','','.b-menu-style-1'),(43543,'watch-mobile','.b-menu-style-1 .menu-style[data-lev2_display=\"width_cont\"] .level-2 > li','width','300','','','.b-menu-style-1'),(43544,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','width','100','','','.b-menu-style-1'),(43545,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','width','40','','','.b-menu-style-2'),(43546,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','width','50','','','.b-menu-style-2'),(43547,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','width','36','','','.b-menu-style-2'),(43548,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','width','40','','','.b-menu-style-2'),(43549,'watch-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','width','36','','','.b-menu-style-2'),(43550,'watch-mobile','.b-messages .msv_to_cc div span.msv_to_cc_bold','width','100','','','.b-messages'),(43551,'watch-mobile','.b-messages .box-block.type-6 > .block:nth-child(1)','width','25','','','.b-messages'),(43552,'watch-mobile','.b-messages .messages-sidebar .btn-2','width','100','','','.b-messages'),(43553,'watch-mobile','.b-messages .pre_upload','width','auto','','','.b-messages'),(43554,'watch-mobile','.b-messages .email-line input','width','100','','','.b-messages'),(43555,'watch-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead td:last-child, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td:last-child','width','200','','','.b-messages'),(43556,'watch-mobile','.b-messages .email-line label','width','150','','','.b-messages'),(43557,'watch-mobile','.b-preloader .preloader','width','100','','','.b-preloader'),(43558,'watch-mobile','.b-preloader .preloader','width','40','3','','.b-preloader'),(43559,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width','1','','','.b-select-suggest'),(43560,'watch-mobile','.b-select-suggest .select2-drop','width','100','','','.b-select-suggest'),(43561,'watch-mobile','.b-select-suggest .select2-drop-mask','width','auto','','','.b-select-suggest'),(43562,'watch-mobile','.b-select-suggest .select2-drop-auto-width','width','auto','','','.b-select-suggest'),(43563,'watch-mobile','.b-select-suggest .select2-measure-scrollbar','width','100','','','.b-select-suggest'),(43564,'watch-mobile','.b-select-suggest .select2-container .select2-choice abbr','width','12','','','.b-select-suggest'),(43565,'watch-mobile','.b-select-suggest .select2-container','width','100','','','.b-select-suggest'),(43566,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width','100','','','.b-select-suggest'),(43567,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','width','18','','','.b-select-suggest'),(43568,'watch-mobile','.b-select-suggest .select2-search','width','100','','','.b-select-suggest'),(43569,'watch-mobile','.b-select-suggest .select2-search-choice-close','width','12','','','.b-select-suggest'),(43570,'watch-mobile','.b-select-suggest .select2-search input','width','100','','','.b-select-suggest'),(43571,'watch-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(43572,'watch-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(43573,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(43574,'watch-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(43575,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(43576,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(43577,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(43578,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(43579,'watch-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(43580,'watch-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(43581,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(43582,'watch-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(43583,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(43584,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(43585,'watch-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(43586,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(43587,'watch-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(43588,'watch-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(43589,'watch-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(43590,'watch-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(43591,'watch-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(43592,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(43593,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(43594,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(43595,'watch-mobile','.b-trade-approval .steps-bar','width','100','','','.b-trade-approval'),(43596,'watch-mobile','.b-trade-approval .col-right','width','48','','','.b-trade-approval'),(43597,'watch-mobile','.b-trade-approval .col-left','width','48','','','.b-trade-approval'),(43598,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width','100','','','.b-trade-approval'),(43599,'watch-mobile','.b-trade-approval .col-3','width','31.33','','','.b-trade-approval'),(43600,'watch-mobile','.b-upload-file .upload-file-template','width','150','','','.b-upload-file'),(43601,'watch-mobile','.b-upload-file .snapshot','width','38','','','.b-upload-file'),(43602,'watch-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','width','230','','','.b-warehouses-popup'),(43603,'watch-mobile','.b-warehouses-popup .warehouses-popup','width','570','','','.b-warehouses-popup'),(43604,'watch-mobile','.batchPr .w-batch-products .products-listing .attribute-qty-block','width','100','','','.batchPr'),(43605,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(2)','width','auto','','','.batchPr'),(43606,'watch-mobile','.batchPr .checkbox input + span','width','80','','','.batchPr'),(43607,'watch-mobile','.batchPr .batchSelect .checkbox','width','80','','','.batchPr'),(43608,'watch-mobile','.batchPr .box-block.type-5 > .block:nth-child(1), .batchPr .box-block.type-5 > .block:nth-child(2)','width','50','','','.batchPr'),(43609,'watch-mobile','.batchPr .checkbox input + span','width','32','','','.batchPr'),(43610,'watch-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','width','40','','','.batchPr'),(43611,'watch-mobile','.batchPr .checkbox input:not(checked) + span:before','width','30','','','.batchPr'),(43612,'watch-mobile','.batchPr .btn-batch-remove','width','20','','','.batchPr'),(43653,'watch-mobile','.p-payer-order-confirmation .order-summary2 .btn-2','width','100','','','.p-payer-order-confirmation'),(43654,'watch-mobile','.p-payer-order-confirmation .dob-hide > div','width','48','','','.p-payer-order-confirmation'),(43655,'watch-mobile','.p-payer-order-pay .order-summary2 .btn-2','width','100','','','.p-payer-order-pay'),(43656,'watch-mobile','.p-payer-order-pay .dob-hide > div','width','48','','','.p-payer-order-pay'),(43657,'watch-mobile','.p-quick-order-index .all-scroll-div','width','100','','','.p-quick-order-index'),(43658,'watch-mobile','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width','100','','','.p-quote-checkout-login'),(43659,'watch-mobile','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width','100','','','.p-sample-checkout-login'),(43660,'watch-mobile','.w-account-address-book .item','width','50','','','.w-account-address-book'),(43661,'watch-mobile','.w-account-address-book .add_item a','width','100','','','.w-account-address-book'),(43662,'watch-mobile','.w-account-addresses-list .addsess-suggestion-item','width','50','','','.w-account-addresses-list'),(43663,'watch-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width','60','','','.w-account-customer-additional-field'),(43664,'watch-mobile','.w-account-customer-additional-field .field-type-text label','width','40','','','.w-account-customer-additional-field'),(43665,'watch-mobile','.w-account-customer-additional-field .field-type-checkbox label','width','40','','','.w-account-customer-additional-field'),(43666,'watch-mobile','.w-account-personal-catalog .list-switcher','width','100','','','.w-account-personal-catalog'),(43667,'watch-mobile','.w-blog-widget-post-date ','width','100','','','.w-blog-widget-post-date'),(43668,'watch-mobile','.w-blog-widget-post-image ','width','100','','','.w-blog-widget-post-image'),(43669,'watch-mobile','.w-blog-widget-post-listing .post','width','33.33','','','.w-blog-widget-post-listing'),(43670,'watch-mobile','.w-blog-widget-post-listing .post','width','100','','','.w-blog-widget-post-listing'),(43671,'watch-mobile','.w-blog-widget-post-listing .post','width','50','','','.w-blog-widget-post-listing'),(43672,'watch-mobile','.w-blog-widget-post-share ','width','1','4','','.w-blog-widget-post-share'),(43673,'watch-mobile','.w-blog-widget-post-title ','width','100','','','.w-blog-widget-post-title'),(43674,'watch-mobile','.w-blog-widget-related-posts .post','width','50','','','.w-blog-widget-related-posts'),(43675,'watch-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','width','35','','','.w-blog-widget-related-posts'),(43676,'watch-mobile','.w-blog-widget-related-posts-by-category .post','width','50','','','.w-blog-widget-related-posts-by-category'),(43677,'watch-mobile','.w-cart-bonus-points .bonus_points_amount','width','150','','','.w-cart-bonus-points'),(43678,'watch-mobile','.w-cart-bonus-points .btn-remove','width','25','','','.w-cart-bonus-points'),(43679,'watch-mobile','.w-cart-compare .product .image','width','50','','','.w-cart-compare'),(43680,'watch-mobile','.w-cart-credit-amount .btn-remove','width','25','','','.w-cart-credit-amount'),(43681,'watch-mobile','.w-cart-credit-amount input[type=\"text\"]','width','150','','','.w-cart-credit-amount'),(43682,'watch-mobile','.w-catalog-b2b-add-button ','width','100','','','.w-catalog-b2b-add-button'),(43683,'watch-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','width','auto','','','.w-catalog-compare'),(43684,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','width','50','','','.w-catalog-compare'),(43685,'watch-mobile','.w-catalog-paging .paging-holder','width','150','','','.w-catalog-paging'),(43686,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width','30','','','.w-catalog-paging'),(43687,'watch-mobile','.w-checkout-billing-address .addresses .address-item','width','50','','','.w-checkout-billing-address'),(43688,'watch-mobile','.w-checkout-billing-address .addresses.address-main .address-item','width','100','','','.w-checkout-billing-address'),(43689,'watch-mobile','.w-checkout-bonus-points .btn-remove','width','25','','','.w-checkout-bonus-points'),(43690,'watch-mobile','.w-checkout-bonus-points .bonus_points_amount','width','150','','','.w-checkout-bonus-points'),(43691,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','width','25','3','','.w-checkout-contact-information'),(43692,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','width','25','3','','.w-checkout-contact-information'),(43693,'watch-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','width','25','3','','.w-checkout-contact-information'),(43694,'watch-mobile','.w-checkout-create-account .col-2','width','100','','','.w-checkout-create-account'),(43695,'watch-mobile','.w-checkout-create-btn .btn-2','width','240','','','.w-checkout-create-btn'),(43696,'watch-mobile','.w-checkout-credit-amount .cot_gv_amount','width','150','','','.w-checkout-credit-amount'),(43697,'watch-mobile','.w-checkout-credit-amount .btn-remove','width','25','','','.w-checkout-credit-amount'),(43698,'watch-mobile','.w-checkout-guest-btn .btn-2','width','240','','','.w-checkout-guest-btn'),(43699,'watch-mobile','.w-checkout-shipping-address .addresses.address-main .address-item','width','100','','','.w-checkout-shipping-address'),(43700,'watch-mobile','.w-checkout-shipping-address .addresses .address-item','width','50','','','.w-checkout-shipping-address'),(43701,'watch-mobile','.w-checkout-shipping-choice #shippingchoice-choice','width','430','','','.w-checkout-shipping-choice'),(43702,'watch-mobile','.w-checkout-shipping-choice label','width','50','','','.w-checkout-shipping-choice'),(43703,'watch-mobile','.w-checkout-shipping-choice input:checked + span:before','width','10','','','.w-checkout-shipping-choice'),(43704,'watch-mobile','.w-checkout-shipping-choice label','width','auto','','','.w-checkout-shipping-choice'),(43705,'watch-mobile','.w-checkout-shipping-choice #shippingchoice-choice','width','auto','','','.w-checkout-shipping-choice'),(43706,'watch-mobile','.w-checkout-terms .required-message','width','100','','','.w-checkout-terms'),(43707,'watch-mobile','.w-communication-new-topic .return-reason','width','150','','','.w-communication-new-topic'),(43708,'watch-mobile','.w-communication-new-topic .request-type','width','150','','','.w-communication-new-topic'),(43709,'watch-mobile','.w-communication-new-topic .date-purchased','width','130','','','.w-communication-new-topic'),(43710,'watch-mobile','.w-communication-new-topic .middle-form select','width','100','','','.w-communication-new-topic'),(43711,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','width','36','','','.w-communication-new-topic'),(43712,'watch-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateTo\"]','width','60','','','.w-communication-new-topic'),(43713,'watch-mobile','.w-communication-new-topic .btn-submit','width','200','','','.w-communication-new-topic'),(43714,'watch-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterOrderId\"]','width','60','','','.w-communication-new-topic'),(43715,'watch-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','width','36','','','.w-communication-new-topic'),(43716,'watch-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateFrom\"]','width','60','','','.w-communication-new-topic'),(43717,'watch-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterName\"]','width','100','','','.w-communication-new-topic'),(43718,'watch-mobile','.w-communication-new-topic .model','width','100','','','.w-communication-new-topic'),(43719,'watch-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterSku\"]','width','60','','','.w-communication-new-topic'),(43720,'watch-mobile','.w-coupons-and-vauchers-checkout .btn-remove','width','25','','','.w-coupons-and-vauchers-checkout'),(43721,'watch-mobile','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width','150','','','.w-coupons-and-vauchers-checkout'),(43722,'watch-mobile','.w-delayed-despatch-checkout #delivery_date','width','150','','','.w-delayed-despatch-checkout'),(43723,'watch-mobile','.w-image-maps .svg-wrap svg','width','100','','','.w-image-maps'),(43724,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','width','250','','','.w-image-maps'),(43725,'watch-mobile','.w-list-b2b .select-attributes','width','47','','','.w-list-b2b'),(43726,'watch-mobile','.w-personal-gift-status-bar .progress-bar','width','230','','','.w-personal-gift-status-bar'),(43727,'watch-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(43728,'watch-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(43729,'watch-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(43730,'watch-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(43731,'watch-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(43732,'watch-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(43733,'watch-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(43734,'watch-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(43735,'watch-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(43736,'watch-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(43737,'watch-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(43738,'watch-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(43739,'watch-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(43740,'watch-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(43741,'watch-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(43742,'watch-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(43743,'watch-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(43744,'watch-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(43745,'watch-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(43746,'watch-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(43747,'watch-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(43748,'watch-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(43749,'watch-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(43750,'watch-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(43751,'watch-mobile','.w-product-customers-activity .customers-activity','width','255','','','.w-product-customers-activity'),(43752,'watch-mobile','.w-product-customers-activity .close','width','30','','','.w-product-customers-activity'),(43753,'watch-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(43754,'watch-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(43755,'watch-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(43756,'watch-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(43757,'watch-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(43758,'watch-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(43759,'watch-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(43760,'watch-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(43761,'watch-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(43762,'watch-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(43763,'watch-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(43764,'watch-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(43765,'watch-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(43766,'watch-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(43767,'watch-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(43768,'watch-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(43769,'watch-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(43770,'watch-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(43771,'watch-mobile','.w-promotions .prom-multi-discount .list','width','100','','','.w-promotions'),(43772,'watch-mobile','.w-promotions .nextdiscount .item-holder .image','width','40','','','.w-promotions'),(43773,'watch-mobile','.w-promotions .promo-cart-discount .master .item','width','calc(50% - 24px)','','','.w-promotions'),(43774,'watch-mobile','.w-promotions .promo-cart-discount .image img','width','auto','','','.w-promotions'),(43775,'watch-mobile','.w-promotions .promo-cart-discount > div','width','50','','','.w-promotions'),(43776,'watch-mobile','.w-promotions .promo-cart-discount .slave .item','width','calc(50% - 4px)','','','.w-promotions'),(43777,'watch-mobile','.w-promotions .promo-salemaker .image img','width','auto','','','.w-promotions'),(43778,'watch-mobile','.w-promotions .promo-salemaker .item','width','50','','','.w-promotions'),(43779,'watch-mobile','.w-promotions .promo-salemaker > div','width','50','','','.w-promotions'),(43780,'watch-mobile','.w-promotions .prom-multi-discount .image img','width','auto','','','.w-promotions'),(43781,'watch-mobile','.w-promotions .nextdiscount .item-holder .name','width','60','','','.w-promotions'),(43782,'watch-mobile','.w-promotions .icon','width','45','','','.w-promotions'),(43783,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul > li','width','25','','','.w-sitemap-delivery-location'),(43784,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(43785,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','width','150','','','.w-upload-customer-id-upload-customer-id-form'),(43786,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(43787,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box-full','width','auto','','','.w-wedding-registry-widgets-photos'),(43788,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-box','width','180','','','.w-wedding-registry-widgets-photos'),(43789,'watch-mobile','.w-wedding-registry-widgets-photos .avatar-container','width','144','','','.w-wedding-registry-widgets-photos'),(43790,'watch-mobile','.w-wedding-registry-widgets-products .products-listing .item','width','33','','','.w-wedding-registry-widgets-products'),(43791,'watch-mobile','.w-wedding-registry-widgets-products .products-listing .item','width','50','','','.w-wedding-registry-widgets-products'),(43792,'watch-mobile','.w-wedding-registry-widgets-products .products-listing .item','width','100','','','.w-wedding-registry-widgets-products'),(43793,'watch-mobile','.w-wedding-registry-widgets-share-url input','width','100','','','.w-wedding-registry-widgets-share-url'),(43794,'watch-mobile','.b-quantity .qty-box input[type=\'text\']','width','60','','','.b-quantity'),(43795,'watch-mobile','.p-shopping-cart-index .order-summary .btn-2','width','100','','','.p-shopping-cart-index'),(43796,'watch-mobile','.w-filters .fsl_handle > div','width','50','','','.w-filters'),(43797,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','width','0','','','.w-filters'),(43798,'watch-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','width','24','','','.w-filters'),(43799,'watch-mobile','.w-menu .hided.menu ul ul','width_important','important','','','.w-menu'),(43800,'watch-mobile','.w-menu .hided.menu ul li','width_important','important','','','.w-menu'),(43801,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width_important','important','3','','.b-switch'),(43802,'watch-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width_important','important','3','','.b-switch'),(43803,'watch-mobile','.b-messages .pre_upload','width_important','important','','','.b-messages'),(43804,'watch-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width_important','important','','','.b-select-suggest'),(43805,'watch-mobile','.b-warehouses-popup .warehouses-popup','width_important','important','','','.b-warehouses-popup'),(43806,'watch-mobile','.w-cart-bonus-points .bonus_points_amount','width_important','important','','','.w-cart-bonus-points'),(43807,'watch-mobile','.w-cart-credit-amount input[type=\"text\"]','width_important','important','','','.w-cart-credit-amount'),(43808,'watch-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width_important','important','','','.w-catalog-paging'),(43809,'watch-mobile','.w-checkout-bonus-points .bonus_points_amount','width_important','important','','','.w-checkout-bonus-points'),(43810,'watch-mobile','.w-checkout-credit-amount .cot_gv_amount','width_important','important','','','.w-checkout-credit-amount'),(43811,'watch-mobile','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width_important','important','','','.w-coupons-and-vauchers-checkout'),(43812,'watch-mobile','.w-menu-slider > ul > li > ul','width_measure','%','','','.w-menu-slider'),(43813,'watch-mobile','.b-form .checkbox-style:checked + .checkbox-span','width_measure','x','','','.b-form'),(43814,'watch-mobile','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(43815,'watch-mobile','.w-login-block .returning','width_measure','%','','','.w-login-block'),(43816,'watch-mobile','.w-login-block .new','width_measure','%','','','.w-login-block'),(43817,'watch-mobile','.w-login-block .guest','width_measure','%','','','.w-login-block'),(43818,'watch-mobile','.w-login-block .input','width_measure','%','','','.w-login-block'),(43819,'watch-mobile','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(43820,'watch-mobile','.w-list-type-2_2 .sale','width_measure','%','4','','.w-list-type-2_2'),(43821,'watch-mobile','.w-sale .holder-1','width_measure','%','','','.w-sale'),(43822,'watch-mobile','.w-sale .image','width_measure','%','','','.w-sale'),(43823,'watch-mobile','.w-sale .holder-2','width_measure','%','','','.w-sale'),(43824,'watch-mobile','.w-product-attributes .select','width_measure','%','','','.w-product-attributes'),(43825,'watch-mobile','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(43826,'watch-mobile','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(43827,'watch-mobile','.w-menu-mobile .menu-slider .open','width_measure','vw','','','.w-menu-mobile'),(43828,'watch-mobile','.w-product-sale-ends .left-count','width_measure','%','','','.w-product-sale-ends'),(43829,'watch-mobile','.w-product-sale-ends .left-text-left','width_measure','%','','','.w-product-sale-ends'),(43830,'watch-mobile','.w-product-sale-ends .left-text-right','width_measure','%','','','.w-product-sale-ends'),(43831,'watch-mobile','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(43832,'watch-mobile','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(43833,'watch-mobile','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(43834,'watch-mobile','.b-fancybox .fancybox-nav','width_measure','%','','','.b-fancybox'),(43835,'watch-mobile','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(43836,'watch-mobile','.w-categories .item','width_measure','%','290','','.w-categories'),(43837,'watch-mobile','.w-top-categories .item','width_measure','%','290','','.w-top-categories'),(43838,'watch-mobile','.w-currencies .select','width_measure','%','','','.w-currencies'),(43839,'watch-mobile','.w-categories .item','width_measure','%','','','.w-categories'),(43840,'watch-mobile','.w-cart-give-away .ga_column','width_measure','%','290','','.w-cart-give-away'),(43841,'watch-mobile','.w-cart-order-total.box','width_measure','%','319','','.w-cart-order-total'),(43842,'watch-mobile','.w-cart-checkout-btn','width_measure','%','290','','.w-cart-checkout-btn'),(43843,'watch-mobile','.b-product-images .additional-horizontal .additional-images, .b-product-images .additional-horizontal .additional-videos','width_measure','%','','','.b-product-images'),(43844,'watch-mobile','.w-product-properties li','width_measure','%','','','.w-product-properties'),(43845,'watch-mobile','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(43846,'watch-mobile','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(43847,'watch-mobile','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(43848,'watch-mobile','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(43850,'watch-mobile','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(43851,'watch-mobile','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(43852,'watch-mobile','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(43853,'watch-mobile','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(43860,'watch-mobile','.p-blog-index .nav-next','width_measure','%','315','','.p-blog-index'),(43861,'watch-mobile','.w-list-type-1_2 .right-area','width_measure','%','291','','.w-list-type-1_2'),(43862,'watch-mobile','.w-list-type-1_2 .right-area .right-area-2','width_measure','%','291','','.w-list-type-1_2'),(43863,'watch-mobile','.p-blog-index .nav-previous','width_measure','%','315','','.p-blog-index'),(43864,'watch-mobile','.w-list-type-1_2 .image','width_measure','%','291','','.w-list-type-1_2'),(43865,'watch-mobile','.w-list-type-1_2 .right-area .name','width_measure','%','291','','.w-list-type-1_2'),(43866,'watch-mobile','.w-list-type-1_2 .right-area .name','width_measure','%','','','.w-list-type-1_2'),(43867,'watch-mobile','.w-list-type-1_2 .right-area .right-area-2','width_measure','%','','','.w-list-type-1_2'),(43868,'watch-mobile','.w-promo-code .promo-code-form','width_measure','%','291','','.w-promo-code'),(43869,'watch-mobile','.w-promo-code .promo-text','width_measure','%','291','','.w-promo-code'),(43870,'watch-mobile','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(43871,'watch-mobile','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(43872,'watch-mobile','.b-form .col-right','width_measure','%','317','','.b-form'),(43873,'watch-mobile','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(43874,'watch-mobile','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(43875,'watch-mobile','.b-form .col-left','width_measure','%','317','','.b-form'),(43876,'watch-mobile','.b-form .columns .col-2','width_measure','%','320','','.b-form'),(43879,'watch-mobile','.w-product-configurator .item-content','width_measure','%','299','','.w-product-configurator'),(43880,'watch-mobile','.w-product-configurator .pc_item','width_measure','%','299','','.w-product-configurator'),(43881,'watch-mobile','.p-wedding-registry-manage .wr-search input','width_measure','%','','','.p-wedding-registry-manage'),(43883,'watch-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','317','','.p-blog-index'),(43884,'watch-mobile','.p-blog-index .nav-previous','width_measure','%','','','.p-blog-index'),(43886,'watch-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','320','','.p-blog-index'),(43887,'watch-mobile','.p-blog-index .nav-next','width_measure','%','','','.p-blog-index'),(43888,'watch-mobile','.w-list-type-1_3 .right-area .right-area-2','width_measure','%','','','.w-list-type-1_3'),(43889,'watch-mobile','.pop-up-content .buttons .right-buttons','width_measure','%','291','',''),(43890,'watch-mobile','.w-list-type-2_2 .sale','width_measure','%','3','','.w-list-type-2_2'),(43891,'watch-mobile','.pop-up-content .buttons .btn-2','width_measure','%','291','',''),(43892,'watch-mobile','.pop-up-content .buttons .left-buttons','width_measure','%','291','',''),(43893,'watch-mobile','.pop-up-content .buttons .btn','width_measure','%','291','',''),(43894,'watch-mobile','.b-form .columns .col-2','width_measure','%','','','.b-form'),(43895,'watch-mobile','.w-list-type-2_2 .button-wishlist button','width_measure','%','','','.w-list-type-2_2'),(43896,'watch-mobile','.w-list-type-2 .sale','width_measure','%','3','','.w-list-type-2'),(43897,'watch-mobile','.w-list-type-2_2 .button-wishlist','width_measure','%','','','.w-list-type-2_2'),(43898,'watch-mobile','.personal-buttons > div > div','width_measure','%','','','.personal-buttons'),(43899,'watch-mobile','.w-product-bonus-points > div > div','width_measure','%','','','.w-product-bonus-points'),(43900,'watch-mobile','.w-cart-checkout-btn a','width_measure','%','290','','.w-cart-checkout-btn'),(43901,'watch-mobile','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(43902,'watch-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width_measure','%','','','.b-fancybox'),(43903,'watch-mobile','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(43904,'watch-mobile','.p-wedding-registry-search .search-list input','width_measure','%','','','.p-wedding-registry-search'),(43905,'watch-mobile','.b-bottom .popup-credit-amount .popup-box','width_measure','%','','','.b-bottom'),(43906,'watch-mobile','.b-compare .col-two select','width_measure','%','','','.b-compare'),(43907,'watch-mobile','.b-compare .col-two label','width_measure','%','','','.b-compare'),(43908,'watch-mobile','.w-list-type-1 .button-wishlist','width_measure','%','','','.w-list-type-1'),(43909,'watch-mobile','.w-search .suggest','width_measure','vw','','','.w-search'),(43910,'watch-mobile','.w-search .search-input','width_measure','%','','','.w-search'),(43911,'watch-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width_measure','%','','','.w-banner'),(43912,'watch-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(43913,'watch-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(43914,'watch-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width_measure','%','','','.p-account-trade-form'),(43915,'watch-mobile','.p-account-trade-form .wl-td label','width_measure','%','','','.p-account-trade-form'),(43916,'watch-mobile','.p-account-trade-form .wl-td select','width_measure','%','','','.p-account-trade-form'),(43917,'watch-mobile','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width_measure','%','','','.w-banner'),(43918,'watch-mobile','.w-filters .handle-to','width_measure','%','','','.w-filters'),(43919,'watch-mobile','.b-bottom .popup-box.popupCompare','width_measure','%','','','.b-bottom'),(43920,'watch-mobile','.w-filters .handle-from','width_measure','%','','','.w-filters'),(43921,'watch-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(43922,'watch-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(43923,'watch-mobile','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(43924,'watch-mobile','.w-product-buttons .btn, .w-product-buttons .btn-2, .w-product-buttons .btn-3, .w-product-buttons .btn-4','width_measure','%','','','.w-product-buttons'),(43925,'watch-mobile','.p-reviews-info .review-info-image','width_measure','%','','','.p-reviews-info'),(43929,'watch-mobile','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(43930,'watch-mobile','.w-sale .left-text-right','width_measure','%','','','.w-sale'),(43931,'watch-mobile','.w-sale .left-count','width_measure','%','','','.w-sale'),(43932,'watch-mobile','.w-sale .left-text-left','width_measure','%','','','.w-sale'),(43933,'watch-mobile','.w-banner .carousel-text','width_measure','%','','','.w-banner'),(43934,'watch-mobile','.w-list-type-1_3 .right-area .name','width_measure','%','','','.w-list-type-1_3'),(43935,'watch-mobile','.w-list-type-1_3 .right-area .right-area-2','width_measure','%','291','','.w-list-type-1_3'),(43936,'watch-mobile','.w-list-type-1_3 .right-area .name','width_measure','%','291','','.w-list-type-1_3'),(43937,'watch-mobile','.w-list-type-1_3 .right-area','width_measure','%','291','','.w-list-type-1_3'),(43938,'watch-mobile','.w-list-type-1_3 .image','width_measure','%','291','','.w-list-type-1_3'),(43939,'watch-mobile','.w-cart-continue-btn a','width_measure','%','290','','.w-cart-continue-btn'),(43940,'watch-mobile','.w-top-categories .item','width_measure','%','','','.w-top-categories'),(43941,'watch-mobile','.w-cart-discount-coupon .gift-code input','width_measure','%','','','.w-cart-discount-coupon'),(43942,'watch-mobile','.w-cart-order-total.box','width_measure','%','','','.w-cart-order-total'),(43945,'watch-mobile','.b-form .addresses .address-item','width_measure','%','','','.b-form'),(43946,'watch-mobile','textarea','width_measure','%','','',''),(43947,'watch-mobile','.b-form .discount-box input[type=\"text\"]','width_measure','%','','','.b-form'),(43948,'watch-mobile','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width_measure','%','','','.b-form'),(43951,'watch-mobile','.b-form .col-right','width_measure','%','','','.b-form'),(43952,'watch-mobile','.w-cart-give-away .ga_attributes > div','width_measure','%','','','.w-cart-give-away'),(43953,'watch-mobile','.w-cart-give-away .ga_attributes select','width_measure','%','','','.w-cart-give-away'),(43954,'watch-mobile','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(43955,'watch-mobile','.w-cart-give-away .ga_column','width_measure','%','','','.w-cart-give-away'),(43956,'watch-mobile','.w-cart-give-away .ga_img','width_measure','%','','','.w-cart-give-away'),(43957,'watch-mobile','.view-all','width_measure','%','3','',''),(43958,'watch-mobile','.w-list-type-1_3 .sale','width_measure','%','4','','.w-list-type-1_3'),(43959,'watch-mobile','.w-list-type-2 .button-wishlist','width_measure','%','','','.w-list-type-2'),(43960,'watch-mobile','.w-list-type-1_3 .sale','width_measure','%','3','','.w-list-type-1_3'),(43961,'watch-mobile','.w-list-type-2 .sale','width_measure','%','4','','.w-list-type-2'),(43962,'watch-mobile','.w-list-type-2 .button-wishlist button','width_measure','%','','','.w-list-type-2'),(43963,'watch-mobile','.w-list-type-1_3 .button-wishlist','width_measure','%','','','.w-list-type-1_3'),(43964,'watch-mobile','.w-list-type-1_3 .button-wishlist button','width_measure','%','','','.w-list-type-1_3'),(43965,'watch-mobile','.w-list-type-1_2 .sale','width_measure','%','3','','.w-list-type-1_2'),(43966,'watch-mobile','.w-list-type-1_2 .sale','width_measure','%','4','','.w-list-type-1_2'),(43967,'watch-mobile','.w-list-type-1_3 .attributes > .attributes > div','width_measure','%','','','.w-list-type-1_3'),(43968,'watch-mobile','.w-list-type-1_2 .button-wishlist button','width_measure','%','','','.w-list-type-1_2'),(43969,'watch-mobile','.w-list-type-1_2 .button-wishlist','width_measure','%','','','.w-list-type-1_2'),(43970,'watch-mobile','.w-list-type-1_2 .button-view','width_measure','%','','','.w-list-type-1_2'),(43971,'watch-mobile','.w-list-type-1 .sale','width_measure','%','4','','.w-list-type-1'),(43972,'watch-mobile','.w-list-type-1 .sale','width_measure','%','3','','.w-list-type-1'),(43973,'watch-mobile','.w-list-type-1 .button-wishlist button','width_measure','%','','','.w-list-type-1'),(43974,'watch-mobile','.w-filters .input-txt','width_measure','%','','','.w-filters'),(43975,'watch-mobile','.w-filters .input-txt-keywords','width_measure','%','','','.w-filters'),(43976,'watch-mobile','.w-filters .ui-slider','width_measure','%','','','.w-filters'),(43977,'watch-mobile','.w-tabs .tab-navigation','width_measure','%','','','.w-tabs'),(43978,'watch-mobile','.b-form .hide-billing-address','width_measure','%','','','.b-form'),(43979,'watch-mobile','.b-form .col-left','width_measure','%','','','.b-form'),(43980,'watch-mobile','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width_measure','%','','','.b-form'),(43981,'watch-mobile','.b-form .middle-form .dob-input input[type=\"text\"]','width_measure','%','','','.b-form'),(43982,'watch-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(43983,'watch-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(43984,'watch-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(43985,'watch-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(43986,'watch-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(43987,'watch-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(43988,'watch-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(43989,'watch-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(43990,'watch-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(43991,'watch-mobile','.b-products-listing .BlockBox.type-14 > .col','width_measure','%','','','.b-products-listing'),(43992,'watch-mobile','.b-products-listing .BlockBox.type-15 > .col','width_measure','%','','','.b-products-listing'),(43993,'watch-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(43994,'watch-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(43995,'watch-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(43996,'watch-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(43997,'watch-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(43998,'watch-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(43999,'watch-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(44000,'watch-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(44001,'watch-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(44002,'watch-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(44003,'watch-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(44004,'watch-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(44005,'watch-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(44006,'watch-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(44007,'watch-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(44008,'watch-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(44009,'watch-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(44010,'watch-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(44011,'watch-mobile','.b-products-listing .btn-choose-options','width_measure','%','','','.b-products-listing'),(44012,'watch-mobile','.b-products-listing .loader','width_measure','%','3','','.b-products-listing'),(44013,'watch-mobile','.b-products-listing .products-listing .attribute-qty-block','width_measure','%','','','.b-products-listing'),(44014,'watch-mobile','.b-products-listing .products-listing .attribute-qty-block > span','width_measure','%','','','.b-products-listing'),(44015,'watch-mobile','.b-products-listing .products-listing .attributes select','width_measure','%','','','.b-products-listing'),(44016,'watch-mobile','.b-products-listing .products-listing .btn-buy','width_measure','%','','','.b-products-listing'),(44017,'watch-mobile','.b-products-listing .products-listing .btn-preloader','width_measure','%','','','.b-products-listing'),(44018,'watch-mobile','.b-products-listing .products-listing .buyButton .btn','width_measure','%','','','.b-products-listing'),(44019,'watch-mobile','.b-products-listing .products-listing .in-cart','width_measure','%','','','.b-products-listing'),(44020,'watch-mobile','.b-products-listing .products-listing .item','width_measure','%','','','.b-products-listing'),(44021,'watch-mobile','.b-products-listing .products-listing .qty-input.hidden','width_measure','%','3','','.b-products-listing'),(44022,'watch-mobile','.b-products-listing .products-listing .radio-attributes .item-title','width_measure','%','','','.b-products-listing'),(44023,'watch-mobile','.b-products-listing .products-listing a.btn.view-button','width_measure','%','','','.b-products-listing'),(44024,'watch-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width_measure','%','','','.b-products-listing'),(44025,'watch-mobile','.b-products-listing .select-attributes .item-title','width_measure','%','','','.b-products-listing'),(44026,'watch-mobile','.b-products-listing .select-attributes select','width_measure','%','','','.b-products-listing'),(44027,'watch-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(44028,'watch-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(44029,'watch-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(44030,'watch-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(44031,'watch-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(44032,'watch-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(44033,'watch-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(44034,'watch-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(44035,'watch-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(44036,'watch-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(44037,'watch-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(44038,'watch-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(44039,'watch-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(44040,'watch-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(44041,'watch-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(44042,'watch-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(44043,'watch-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(44044,'watch-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(44045,'watch-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(44046,'watch-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(44047,'watch-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(44048,'watch-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(44049,'watch-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(44050,'watch-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(44051,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width_measure','vw','','','.b-menu-lev_display-slide'),(44052,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width_measure','vw','','','.b-menu-lev_display-slide'),(44053,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width_measure','vw','','','.b-menu-lev_display-slide'),(44054,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width_measure','vw','','','.b-menu-lev_display-slide'),(44055,'watch-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width_measure','vw','','','.b-menu-lev_display-slide'),(44056,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_measure','vw','','','.b-menu-open_from-left'),(44057,'watch-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(44058,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','width_measure','%','','','.b-menu-style-1'),(44059,'watch-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','width_measure','%','','','.b-menu-style-1'),(44060,'watch-mobile','.b-messages .box-block.type-6 > .block:nth-child(1)','width_measure','%','','','.b-messages'),(44061,'watch-mobile','.b-messages .messages-sidebar .btn-2','width_measure','%','','','.b-messages'),(44062,'watch-mobile','.b-messages .email-line input','width_measure','%','','','.b-messages'),(44063,'watch-mobile','.b-preloader .preloader','width_measure','%','','','.b-preloader'),(44064,'watch-mobile','.b-select-suggest .select2-search input','width_measure','%','','','.b-select-suggest'),(44065,'watch-mobile','.b-select-suggest .select2-container','width_measure','%','','','.b-select-suggest'),(44066,'watch-mobile','.b-select-suggest .select2-drop','width_measure','%','','','.b-select-suggest'),(44067,'watch-mobile','.b-select-suggest .select2-search','width_measure','%','','','.b-select-suggest'),(44068,'watch-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width_measure','%','','','.b-select-suggest'),(44069,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(44070,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(44071,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(44072,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(44073,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(44074,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(44075,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(44076,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(44077,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(44078,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(44079,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(44080,'watch-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(44081,'watch-mobile','.b-trade-approval .steps-bar','width_measure','%','','','.b-trade-approval'),(44082,'watch-mobile','.b-trade-approval .col-right','width_measure','%','','','.b-trade-approval'),(44083,'watch-mobile','.b-trade-approval .col-left','width_measure','%','','','.b-trade-approval'),(44084,'watch-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width_measure','%','','','.b-trade-approval'),(44085,'watch-mobile','.b-trade-approval .col-3','width_measure','%','','','.b-trade-approval'),(44086,'watch-mobile','.batchPr .w-batch-products .products-listing .attribute-qty-block','width_measure','%','','','.batchPr'),(44087,'watch-mobile','.batchPr .box-block.type-5 > .block:nth-child(1), .batchPr .box-block.type-5 > .block:nth-child(2)','width_measure','%','','','.batchPr'),(44108,'watch-mobile','.p-payer-order-confirmation .dob-hide > div','width_measure','%','','','.p-payer-order-confirmation'),(44109,'watch-mobile','.p-payer-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-confirmation'),(44110,'watch-mobile','.p-payer-order-pay .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-pay'),(44111,'watch-mobile','.p-payer-order-pay .dob-hide > div','width_measure','%','','','.p-payer-order-pay'),(44112,'watch-mobile','.p-quick-order-index .all-scroll-div','width_measure','%','','','.p-quick-order-index'),(44113,'watch-mobile','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width_measure','%','','','.p-quote-checkout-login'),(44114,'watch-mobile','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width_measure','%','','','.p-sample-checkout-login'),(44115,'watch-mobile','.w-account-address-book .item','width_measure','%','','','.w-account-address-book'),(44116,'watch-mobile','.w-account-address-book .add_item a','width_measure','%','','','.w-account-address-book'),(44117,'watch-mobile','.w-account-addresses-list .addsess-suggestion-item','width_measure','%','','','.w-account-addresses-list'),(44118,'watch-mobile','.w-account-customer-additional-field .field-type-checkbox label','width_measure','%','','','.w-account-customer-additional-field'),(44119,'watch-mobile','.w-account-customer-additional-field .field-type-text label','width_measure','%','','','.w-account-customer-additional-field'),(44120,'watch-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width_measure','%','','','.w-account-customer-additional-field'),(44121,'watch-mobile','.w-account-personal-catalog .list-switcher','width_measure','%','','','.w-account-personal-catalog'),(44122,'watch-mobile','.w-blog-widget-post-date ','width_measure','%','','','.w-blog-widget-post-date'),(44123,'watch-mobile','.w-blog-widget-post-image ','width_measure','%','','','.w-blog-widget-post-image'),(44124,'watch-mobile','.w-blog-widget-post-listing .post','width_measure','%','','','.w-blog-widget-post-listing'),(44125,'watch-mobile','.w-blog-widget-post-listing .post','width_measure','%','','','.w-blog-widget-post-listing'),(44126,'watch-mobile','.w-blog-widget-post-listing .post','width_measure','%','','','.w-blog-widget-post-listing'),(44127,'watch-mobile','.w-blog-widget-post-title ','width_measure','%','','','.w-blog-widget-post-title'),(44128,'watch-mobile','.w-blog-widget-related-posts .post','width_measure','%','','','.w-blog-widget-related-posts'),(44129,'watch-mobile','.w-blog-widget-related-posts-by-category .post','width_measure','%','','','.w-blog-widget-related-posts-by-category'),(44130,'watch-mobile','.w-catalog-b2b-add-button ','width_measure','%','','','.w-catalog-b2b-add-button'),(44131,'watch-mobile','.w-catalog-compare .cross-box .different-all > div','width_measure','%','','','.w-catalog-compare'),(44132,'watch-mobile','.w-checkout-billing-address .addresses .address-item','width_measure','%','','','.w-checkout-billing-address'),(44133,'watch-mobile','.w-checkout-billing-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-billing-address'),(44134,'watch-mobile','.w-checkout-create-account .col-2','width_measure','%','','','.w-checkout-create-account'),(44135,'watch-mobile','.w-checkout-shipping-address .addresses .address-item','width_measure','%','','','.w-checkout-shipping-address'),(44136,'watch-mobile','.w-checkout-shipping-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-shipping-address'),(44137,'watch-mobile','.w-checkout-shipping-choice label','width_measure','%','','','.w-checkout-shipping-choice'),(44138,'watch-mobile','.w-checkout-terms .required-message','width_measure','%','','','.w-checkout-terms'),(44139,'watch-mobile','.w-communication-new-topic .middle-form select','width_measure','%','','','.w-communication-new-topic'),(44140,'watch-mobile','.w-image-maps .svg-wrap svg','width_measure','%','','','.w-image-maps'),(44141,'watch-mobile','.w-list-b2b .select-attributes','width_measure','%','','','.w-list-b2b'),(44142,'watch-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(44143,'watch-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(44144,'watch-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(44145,'watch-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(44146,'watch-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(44147,'watch-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(44148,'watch-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(44149,'watch-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(44150,'watch-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(44151,'watch-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(44152,'watch-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(44153,'watch-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(44154,'watch-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(44155,'watch-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(44156,'watch-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(44157,'watch-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(44158,'watch-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(44159,'watch-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(44160,'watch-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(44161,'watch-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(44162,'watch-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(44163,'watch-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(44164,'watch-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(44165,'watch-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(44166,'watch-mobile','.w-promotions .prom-multi-discount .list','width_measure','%','','','.w-promotions'),(44167,'watch-mobile','.w-promotions .promo-cart-discount > div','width_measure','%','','','.w-promotions'),(44168,'watch-mobile','.w-promotions .promo-salemaker .item','width_measure','%','','','.w-promotions'),(44169,'watch-mobile','.w-promotions .promo-salemaker > div','width_measure','%','','','.w-promotions'),(44170,'watch-mobile','.w-promotions .nextdiscount .item-holder .name','width_measure','%','','','.w-promotions'),(44171,'watch-mobile','.w-promotions .nextdiscount .item-holder .image','width_measure','%','','','.w-promotions'),(44172,'watch-mobile','.w-sitemap-delivery-location > ul > li > ul > li','width_measure','%','','','.w-sitemap-delivery-location'),(44173,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(44174,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(44175,'watch-mobile','.w-wedding-registry-widgets-products .products-listing .item','width_measure','%','','','.w-wedding-registry-widgets-products'),(44176,'watch-mobile','.w-wedding-registry-widgets-products .products-listing .item','width_measure','%','','','.w-wedding-registry-widgets-products'),(44177,'watch-mobile','.w-wedding-registry-widgets-products .products-listing .item','width_measure','%','','','.w-wedding-registry-widgets-products'),(44178,'watch-mobile','.w-wedding-registry-widgets-share-url input','width_measure','%','','','.w-wedding-registry-widgets-share-url'),(44179,'watch-mobile','.p-shopping-cart-index .order-summary .btn-2','width_measure','%','','','.p-shopping-cart-index'),(44180,'watch-mobile','.w-filters .fsl_handle > div','width_measure','%','','','.w-filters'),(44181,'watch-mobile','.w-menu .hided.menu > ul','z-index','100','','','.w-menu'),(44182,'watch-mobile','.w-menu-horizontal > ul','z-index','21','','','.w-menu-horizontal'),(44183,'watch-mobile','.w-menu-slider > ul > li > ul','z-index','100','','','.w-menu-slider'),(44184,'watch-mobile','.w-menu-horizontal > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-horizontal'),(44185,'watch-mobile','.w-menu-horizontal > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-horizontal'),(44186,'watch-mobile','.w-menu-horizontal > ul > li > ul','z-index','22','','','.w-menu-horizontal'),(44187,'watch-mobile','.w-menu-horizontal > ul > li > ul > li > ul','z-index','23','','','.w-menu-horizontal'),(44188,'watch-mobile','.w-menu-big li','z-index','20','','','.w-menu-big'),(44189,'watch-mobile','.w-menu-big > ul > li > ul','z-index','100','','','.w-menu-big'),(44190,'watch-mobile','.w-menu-style-1 > ul > li > ul','z-index','22','','','.w-menu-style-1'),(44191,'watch-mobile','.w-menu-style-1 > ul','z-index','21','','','.w-menu-style-1'),(44192,'watch-mobile','.w-cart .cart-box-link','z-index','1','','','.w-cart'),(44193,'watch-mobile','.w-cart .cart-box','z-index','100','','','.w-cart'),(44194,'watch-mobile','.b-fancybox .fancybox-opened','z-index','8030','','','.b-fancybox'),(44195,'watch-mobile','.w-quote .cart-box','z-index','100','','','.w-quote'),(44196,'watch-mobile','.w-quote .cart-box-link','z-index','1','','','.w-quote'),(44197,'watch-mobile','.b-info-popup .info-popup div','z-index','1000','','','.b-info-popup'),(44198,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > ul','z-index','23','','','.w-menu-style-1'),(44199,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-style-1'),(44200,'watch-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-style-1'),(44201,'watch-mobile','.w-account a.my-acc-link','z-index','1','','','.w-account'),(44202,'watch-mobile','.b-fancybox .fancybox-close','z-index','8040','','','.b-fancybox'),(44203,'watch-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','z-index','-1','','','.b-switch'),(44204,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','z-index','1','','','.b-switch'),(44205,'watch-mobile','.b-switch .bootstrap-switch .bootstrap-switch-label','z-index','100','','','.b-switch'),(44206,'watch-mobile','.b-switch .bootstrap-switch','z-index','0','','','.b-switch'),(44207,'watch-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','z-index','1','','','.b-slick'),(44208,'watch-mobile','.w-languages .select','z-index','100','','','.w-languages'),(44209,'watch-mobile','.w-search .suggest','z-index','500','','','.w-search'),(44210,'watch-mobile','.w-banner .banner img + img','z-index','-1','','','.w-banner'),(44211,'watch-mobile','.w-currencies .select','z-index','10','','','.w-currencies'),(44212,'watch-mobile','.b-fancybox .fancybox-title','z-index','8050','','','.b-fancybox'),(44214,'watch-mobile','.b-fancybox .fancybox-title-float-wrap','z-index','8050','','','.b-fancybox'),(44215,'watch-mobile','.b-fancybox .fancybox-wrap','z-index','8020','','','.b-fancybox'),(44217,'watch-mobile','.b-fancybox .fancybox-overlay','z-index','8010','','','.b-fancybox'),(44218,'watch-mobile','.b-fancybox #fancybox-loading','z-index','8060','','','.b-fancybox'),(44219,'watch-mobile','.b-fancybox .fancybox-nav span','z-index','8040','','','.b-fancybox'),(44220,'watch-mobile','.b-fancybox .fancybox-nav','z-index','8040','','','.b-fancybox'),(44221,'watch-mobile','.b-form .form-inputs div.required-message','z-index','1','','','.b-form'),(44222,'watch-mobile','.b-form .hide-billing-address','z-index','70','','','.b-form'),(44223,'watch-mobile','.b-fancybox .filter-listing-preloader','z-index','100001','','','.b-fancybox'),(44224,'watch-mobile','.b-fancybox .filter-listing-loader','z-index','100000','','','.b-fancybox'),(44225,'watch-mobile','.b-bottom .pop-up-close','z-index','1','','','.b-bottom'),(44226,'watch-mobile','.b-form .same-address','z-index','80','','','.b-form'),(44227,'watch-mobile','.b-products-listing .promos-info','z-index','1','','','.b-products-listing'),(44228,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(44229,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(44230,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(44231,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(44232,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(44233,'watch-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(44234,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(44235,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(44236,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(44237,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(44238,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(44239,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(44240,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(44241,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(44242,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(44243,'watch-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(44244,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(44245,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(44246,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(44247,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(44248,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(44249,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(44250,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(44251,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(44252,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(44253,'watch-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(44254,'watch-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','z-index','1000','','','.b-menu-open_from-left'),(44255,'watch-mobile','.b-messages .messMenuButton span','z-index','1','','','.b-messages'),(44256,'watch-mobile','.b-preloader .preloader','z-index','10','','','.b-preloader'),(44257,'watch-mobile','.b-select-suggest .select2-search','z-index','10000','','','.b-select-suggest'),(44258,'watch-mobile','.b-select-suggest .select2-drop-mask','z-index','9998','','','.b-select-suggest'),(44259,'watch-mobile','.b-select-suggest .select2-drop','z-index','9999','','','.b-select-suggest'),(44260,'watch-mobile','.batchPr .batchSelect','z-index','1','','','.batchPr'),(44261,'watch-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(44262,'watch-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(44263,'watch-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(44264,'watch-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(44265,'watch-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(44266,'watch-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(44267,'watch-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(44268,'watch-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(44269,'watch-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(44270,'watch-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(44271,'watch-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(44272,'watch-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(44273,'watch-mobile','.p-sample-checkout-success .page-success > div','z-index','1','','','.p-sample-checkout-success'),(44274,'watch-mobile','.p-sample-checkout-success .page-success','z-index','-1','','','.p-sample-checkout-success'),(44275,'watch-mobile','.w-catalog-b2b-add-button ','z-index','1','','','.w-catalog-b2b-add-button'),(44276,'watch-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','z-index','1000','','','.w-image-maps'),(44277,'watch-mobile','.w-promotions .promo-cart-discount .slave .condition','z-index','1','','','.w-promotions'),(44278,'watch-mobile','.w-promotions .prom-multi-discount .promo-range','z-index','1','','','.w-promotions'),(44279,'watch-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','z-index','10','','','.w-upload-customer-id-upload-customer-id-form'),(122257,'printshop-mobile','.b-slick .slick-slider','-khtml-user-select','none','','','.b-slick'),(122258,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','-moz-border-radius','15px','','','.b-fancybox'),(122259,'printshop-mobile','.b-fancybox .fancybox-skin','-moz-border-radius','4px','','','.b-fancybox'),(122260,'printshop-mobile','.b-fancybox .fancybox-opened .fancybox-skin','-moz-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(122261,'printshop-mobile','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-moz-box-sizing','border-box','','','.b-select-suggest'),(122262,'printshop-mobile','.b-rating #stars-default .glyphicon','-moz-osx-font-smoothing','grayscale','','','.b-rating'),(122263,'printshop-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-moz-transform','translate3d(0, 0, 0)','','','.b-slick'),(122264,'printshop-mobile','.b-products-listing .hover-box-content','-moz-transform','rotate( 45deg )','3','','.b-products-listing'),(122265,'printshop-mobile','.b-slick .slick-slider','-moz-user-select','none','','','.b-slick'),(122266,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','-moz-user-select','none','','','.b-select-suggest'),(122267,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','-moz-user-select','none','','','.b-select-suggest'),(122268,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-moz-user-select','none','','','.b-select-suggest'),(122269,'printshop-mobile','.b-slick .slick-slider','-ms-touch-action','pan-y','','','.b-slick'),(122270,'printshop-mobile','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(122271,'printshop-mobile','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(122272,'printshop-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-ms-transform','translate3d(0, 0, 0)','','','.b-slick'),(122273,'printshop-mobile','.b-products-listing .hover-box-content','-ms-transform','rotate( 45deg )','3','','.b-products-listing'),(122274,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(122275,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(122276,'printshop-mobile','.b-slick .slick-slider','-ms-user-select','none','','','.b-slick'),(122277,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','-ms-user-select','none','','','.b-select-suggest'),(122278,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','-ms-user-select','none','','','.b-select-suggest'),(122279,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-ms-user-select','none','','','.b-select-suggest'),(122280,'printshop-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-o-transform','translate3d(0, 0, 0)','','','.b-slick'),(122281,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','-webkit-border-radius','15px','','','.b-fancybox'),(122282,'printshop-mobile','.b-fancybox .fancybox-skin','-webkit-border-radius','4px','','','.b-fancybox'),(122283,'printshop-mobile','.b-fancybox .fancybox-opened .fancybox-skin','-webkit-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(122284,'printshop-mobile','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-webkit-box-sizing','border-box','','','.b-select-suggest'),(122285,'printshop-mobile','.b-rating #stars-default .glyphicon','-webkit-font-smoothing','antialiased','','','.b-rating'),(122286,'printshop-mobile','.b-fancybox .fancybox-type-iframe .fancybox-inner','-webkit-overflow-scrolling','touch','','','.b-fancybox'),(122287,'printshop-mobile','.b-fancybox .fancybox-nav','-webkit-tap-highlight-color','rgba(0,0,0,0)','','','.b-fancybox'),(122288,'printshop-mobile','.b-slick .slick-slider','-webkit-tap-highlight-color','transparent','','','.b-slick'),(122289,'printshop-mobile','.b-select-suggest .select2-results','-webkit-tap-highlight-color','rgba(0, 0, 0, 0)','','','.b-select-suggest'),(122290,'printshop-mobile','.b-slick .slick-slider','-webkit-touch-callout','none','','','.b-slick'),(122291,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(122292,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(122293,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','-webkit-touch-callout','none','','','.b-select-suggest'),(122294,'printshop-mobile','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(122295,'printshop-mobile','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(122296,'printshop-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-webkit-transform','translate3d(0, 0, 0)','','','.b-slick'),(122297,'printshop-mobile','.b-products-listing .hover-box-content','-webkit-transform','rotate( 45deg )','3','','.b-products-listing'),(122298,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(122299,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(122300,'printshop-mobile','.b-slick .slick-slider','-webkit-user-select','none','','','.b-slick'),(122301,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','-webkit-user-select','none','','','.b-select-suggest'),(122302,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','-webkit-user-select','none','','','.b-select-suggest'),(122303,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-user-select','none','','','.b-select-suggest'),(122304,'printshop-mobile','.p-wedding-registry-search .search-form','align-items','center','','','.p-wedding-registry-search'),(122305,'printshop-mobile','.w-banner .carousel .middle-center','align-items','center','','','.w-banner'),(122306,'printshop-mobile','.w-banner .carousel .bottom-right','align-items','flex-end','','','.w-banner'),(122307,'printshop-mobile','.w-banner .carousel .middle-right','align-items','center','','','.w-banner'),(122308,'printshop-mobile','.w-banner .carousel .top-right','align-items','flex-start','','','.w-banner'),(122309,'printshop-mobile','.w-banner .carousel .top-center','align-items','flex-start','','','.w-banner'),(122310,'printshop-mobile','.w-banner .carousel .middle-left','align-items','center','','','.w-banner'),(122311,'printshop-mobile','.w-banner .carousel .bottom-center','align-items','flex-end','','','.w-banner'),(122312,'printshop-mobile','.w-banner .carousel .bottom-left','align-items','flex-end','','','.w-banner'),(122313,'printshop-mobile','.w-banner .carousel .top-left','align-items','flex-start','','','.w-banner'),(122314,'printshop-mobile','.b-products-listing .products-listing .attribute-qty-block','align-items','center','','','.b-products-listing'),(122315,'printshop-mobile','.b-products-listing .promos-info .promo-item','align-items','center','','','.b-products-listing'),(122316,'printshop-mobile','.b-products-listing .select-attributes','align-items','center','','','.b-products-listing'),(122317,'printshop-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(122318,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','align-items','center','','','.b-menu-style-1'),(122319,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .languages','align-items','center','','','.b-menu-style-2'),(122320,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','align-items','center','','','.b-menu-style-2'),(122321,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies','align-items','center','','','.b-menu-style-2'),(122322,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','align-items','center','','','.b-menu-style-2'),(122323,'printshop-mobile','.b-messages .email-line','align-items','center','','','.b-messages'),(122324,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(122325,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(122326,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(122327,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(122328,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(122329,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(122330,'printshop-mobile','.p-quick-order-index .quick-order-total','align-items','center','','','.p-quick-order-index'),(122331,'printshop-mobile','.w-account-customer-additional-field .field-type-text','align-items','center','','','.w-account-customer-additional-field'),(122332,'printshop-mobile','.w-account-subscription .subscription-variant','align-items','center','','','.w-account-subscription'),(122333,'printshop-mobile','.w-catalog-compare .cross-box .different-all','align-items','flex-end','','','.w-catalog-compare'),(122334,'printshop-mobile','.w-communication-new-topic #communication_group_holder + .columns','align-items','flex-end','','','.w-communication-new-topic'),(122335,'printshop-mobile','.w-personal-gift-status-bar .timeline','align-items','center','','','.w-personal-gift-status-bar'),(122336,'printshop-mobile','.w-promotions .promo-cart-discount','align-items','flex-start','','','.w-promotions'),(122337,'printshop-mobile','.w-taxable form','align-items','center','','','.w-taxable'),(122338,'printshop-mobile','.b-products-listing .btn-preloader','animation','load8 1.5s infinite linear','3','','.b-products-listing'),(122339,'printshop-mobile','.b-products-listing .loader','animation','load8 1.5s infinite linear','4','','.b-products-listing'),(122340,'printshop-mobile','.b-preloader .preloader','animation','load8 1.5s infinite linear','3','','.b-preloader'),(122341,'printshop-mobile','.w-product-customers-activity .customers-activity','animation','customers-activity-show 4s ease-in-out','','','.w-product-customers-activity'),(122342,'printshop-mobile','.w-product-customers-activity .customers-activity.closed','animation','customers-activity-hide 2s ease-in-out','','','.w-product-customers-activity'),(122343,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(122344,'printshop-mobile','.w-filters .ui-slider-range','background','none','','','.w-filters'),(122345,'printshop-mobile','.w-filters .ui-slider','background','none','','','.w-filters'),(122346,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','background','transparent','','','.b-fancybox'),(122347,'printshop-mobile','.w-top-categories .categories h2','background','none','','','.w-top-categories'),(122348,'printshop-mobile','.w-categories .categories h2','background','none','','','.w-categories'),(122349,'printshop-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','background','none','','','.b-products-listing'),(122350,'printshop-mobile','.b-products-listing .products-listing h2','background','none','','','.b-products-listing'),(122351,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.b-data-table'),(122352,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.b-data-table'),(122353,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','background','none','','','.b-menu-style-2'),(122354,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','background','none','','','.b-menu-style-2'),(122355,'printshop-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','background','transparent','','','.b-select-suggest'),(122356,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','background','none','','','.b-select-suggest'),(122357,'printshop-mobile','.b-select-suggest .select2-results .select2-highlighted em','background','transparent','','','.b-select-suggest'),(122358,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background','transparent','','','.b-select-suggest'),(122359,'printshop-mobile','.batchPr .checkbox input + span','background','none','','','.batchPr'),(122360,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.p-quick-order-index'),(122361,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.p-quick-order-index'),(122362,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','background','none','','','.w-catalog-compare'),(122363,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','background-clip','padding-box','','','.b-select-suggest'),(122364,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','background-clip','padding-box','','','.b-select-suggest'),(122365,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','background-clip','padding-box','','','.b-select-suggest'),(122366,'printshop-mobile','.w-menu .hided.menu','background-color','inherit','','','.w-menu'),(122367,'printshop-mobile','.w-menu .menu .menu-ico','background-color','inherit','','','.w-menu'),(122368,'printshop-mobile','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','background-color','#ee4225','','','.b-cookie-notice'),(122369,'printshop-mobile','.w-sale .left-count-days','background-color','#fff','','','.w-sale'),(122370,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li > ul','background-color','#ffffff','','','.w-menu-horizontal'),(122371,'printshop-mobile','.w-menu-slider .menu-ico','background-color','#183d78','','','.w-menu-slider'),(122372,'printshop-mobile','.w-menu-horizontal > ul > li > ul','background-color','#ffffff','','','.w-menu-horizontal'),(122373,'printshop-mobile','.w-menu-slider > ul > li.active > ul','background-color','#183d78','','','.w-menu-slider'),(122374,'printshop-mobile','.w-menu-style-1 .menu-ico','background-color','#183d78','','','.w-menu-style-1'),(122375,'printshop-mobile','.w-sale .badge','background-color','#183d78','','','.w-sale'),(122376,'printshop-mobile','.w-menu-style-1 > ul > li > ul','background-color','#183d78','','','.w-menu-style-1'),(122377,'printshop-mobile','.w-menu-style-1 > ul','background-color','#183d78','','','.w-menu-style-1'),(122378,'printshop-mobile','.w-menu-style-1 > ul > li','background-color','#0a204a','1','','.w-menu-style-1'),(122379,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li','background-color','#0a204a','1','','.w-menu-style-1'),(122380,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li ul','background-color','#183d78','','','.w-menu-style-1'),(122381,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > ul li','background-color','#0a204a','1','','.w-menu-style-1'),(122382,'printshop-mobile','.w-product-sale-ends .left-count','background-color','#183d78','','','.w-product-sale-ends'),(122383,'printshop-mobile','.w-product-sale-ends .left-count-hours','background-color','#fff','','','.w-product-sale-ends'),(122384,'printshop-mobile','.p-account-history .order_history_table th','background-color','#eee','','','.p-account-history'),(122385,'printshop-mobile','.w-product-sale-ends .left-count-days','background-color','#fff','','','.w-product-sale-ends'),(122386,'printshop-mobile','.p-account-trade-form .trade-form-area','background-color','#eee','','','.p-account-trade-form'),(122387,'printshop-mobile','.w-quote .cart-box','background-color','#ffffff','','','.w-quote'),(122388,'printshop-mobile','.w-product-reviews .reviews-list .review','background-color','#ffffff','','','.w-product-reviews'),(122389,'printshop-mobile','.w-quote .cart-box-link','background-color','#183d78','','','.w-quote'),(122390,'printshop-mobile','.b-compare .popupCompare .pop-up-content','background-color','#e0e0e0','','','.b-compare'),(122391,'printshop-mobile','.w-menu-slider > ul','background-color','#183d78','','','.w-menu-slider'),(122392,'printshop-mobile','.w-menu-slider > ul > li > ul','background-color','#183d78','','','.w-menu-slider'),(122393,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','background-color','#00c853','3','','.b-multi-page-checkout'),(122394,'printshop-mobile','.b-info-popup .info-popup div','background-color','#fff','','','.b-info-popup'),(122395,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','background-color','#092964','','','.b-multi-page-checkout'),(122396,'printshop-mobile','.testimonials .review','background-color','#eeeeee','','',''),(122397,'printshop-mobile','.p-wedding-registry-manage .wr-search button','background-color','transparent','','','.p-wedding-registry-manage'),(122398,'printshop-mobile','.b-pagination .pagination span','background-color','#183d78','2','','.b-pagination'),(122399,'printshop-mobile','.p-account-history .orders-table th','background-color','#eeeeee','','','.p-account-history'),(122400,'printshop-mobile','.w-filters .head-filter-widget','background-color','#183d78','720','','.w-filters'),(122401,'printshop-mobile','.w-list-type-2_2 .compare-box-item','background-color','#eeeeee','','','.w-list-type-2_2'),(122402,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','background-color','#ffffff','','','.w-list-type-2_2'),(122403,'printshop-mobile','.w-chat .w-chat-box','background-color','#183d78','','','.w-chat'),(122404,'printshop-mobile','.p-wedding-registry-index .middle-box','background-color','#fff','','','.p-wedding-registry-index'),(122405,'printshop-mobile','.b-table .table .headings td','background-color','#eeeeee','','','.b-table'),(122406,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','background-color','#183d78','','','.b-switch'),(122407,'printshop-mobile','.b-bottom .popup-heading','background-color','#f9f9f9','','','.b-bottom'),(122408,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label','background-color','#fff','3','','.b-switch'),(122409,'printshop-mobile','.b-compare .compare-box-item','background-color','#e0e0e0','','','.b-compare'),(122410,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label','background-color','#fff','3','','.b-switch'),(122411,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','background-color','#9aa4b3','','','.b-switch'),(122412,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','background-color','rgba(0, 0, 0, 0.8)','','','.b-fancybox'),(122413,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','background-color','#fff','','','.b-slick'),(122414,'printshop-mobile','.w-reviews .review','background-color','#ffffff','','','.w-reviews'),(122415,'printshop-mobile','.w-search .suggest','background-color','#eee','','','.w-search'),(122416,'printshop-mobile','.btn-1','background-color','#ee4225','','',''),(122417,'printshop-mobile','body','background-color','#ffffff','','',''),(122418,'printshop-mobile','.w-currencies .select','background-color','#ffffff','','','.w-currencies'),(122419,'printshop-mobile','.b-bottom .popup-box.popupCompare','background-color','#e0e0e0','','','.b-bottom'),(122420,'printshop-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','background-color','#fff','','','.w-compare-box-item'),(122421,'printshop-mobile','.w-compare-box-item .checkbox:checked + span:before','background-color','#04a440','','','.w-compare-box-item'),(122422,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table th','background-color','#eee','','','.p-account-subscription-historyinfo'),(122423,'printshop-mobile','.b-info-popup .info-popup div','background-color','#fff','3','','.b-info-popup'),(122424,'printshop-mobile','.w-menu-mobile .menu-ico','background-color','#183d78','','','.w-menu-mobile'),(122425,'printshop-mobile','.p-account-index th','background-color','#eeeeee','','','.p-account-index'),(122426,'printshop-mobile','.w-search .search form','background-color','#ccc','','','.w-search'),(122427,'printshop-mobile','.b-compare .popupCompare table','background-color','#fff','','','.b-compare'),(122428,'printshop-mobile','.b-fancybox .fancybox-skin','background-color','#f9f9f9','','','.b-fancybox'),(122429,'printshop-mobile','.b-fancybox .fancybox-overlay','background-color','rgba(0, 0, 0, 0.7)','','','.b-fancybox'),(122430,'printshop-mobile','.p-reviews-info .review-info-content','background-color','#eeeeee','','','.p-reviews-info'),(122431,'printshop-mobile','.p-reviews-info .review-info-image','background-color','#fff','','','.p-reviews-info'),(122432,'printshop-mobile','.w-sale .left-count','background-color','#183d78','','','.w-sale'),(122433,'printshop-mobile','.w-sale .left-count-hours','background-color','#fff','','','.w-sale'),(122434,'printshop-mobile','.w-cart .cart-content','background-color','#ffffff','','','.w-cart'),(122435,'printshop-mobile','.b-fancybox .fancybox-nav span','background-color','rgba(0, 0, 0, 0.7)','','','.b-fancybox'),(122436,'printshop-mobile','.b-form .hide-billing-address','background-color','#fff','','','.b-form'),(122437,'printshop-mobile','.p-account-index .topAccount','background-color','#eee','','','.p-account-index'),(122438,'printshop-mobile','.p-account-index .orders-table th','background-color','#eeeeee','','','.p-account-index'),(122439,'printshop-mobile','.b-fancybox .filter-listing-loader','background-color','rgba(255, 255, 255, 0.7)','','','.b-fancybox'),(122440,'printshop-mobile','.b-compare .vary td','background-color','#f3f5a1','','','.b-compare'),(122441,'printshop-mobile','.b-datepicker .datepicker-dropdown','background-color','#fff','','','.b-datepicker'),(122442,'printshop-mobile','.w-list-type-2 .button-wishlist button','background-color','#ffffff','','','.w-list-type-2'),(122443,'printshop-mobile','.w-list-type-2 .compare-box-item','background-color','#eeeeee','','','.w-list-type-2'),(122444,'printshop-mobile','.btn-2','background-color','#ee4225','','',''),(122445,'printshop-mobile','.btn','background-color','#ffffff','','',''),(122446,'printshop-mobile','.w-list-type-1_3 .compare-box-item','background-color','#eeeeee','','','.w-list-type-1_3'),(122447,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','background-color','#ffffff','','','.w-list-type-1_3'),(122448,'printshop-mobile','.b-bottom .around-pop-up','background-color','#212121','','','.b-bottom'),(122449,'printshop-mobile','.w-list-type-1_2 .compare-box-item','background-color','#eeeeee','','','.w-list-type-1_2'),(122450,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','background-color','#ffffff','','','.w-list-type-1_2'),(122451,'printshop-mobile','.b-bottom .pop-up-content','background-color','#fff','','','.b-bottom'),(122452,'printshop-mobile','.p-reviews-info .review-info-text','background-color','#fff','','','.p-reviews-info'),(122453,'printshop-mobile','.b-bottom .popup-box','background-color','#fff','','','.b-bottom'),(122454,'printshop-mobile','.w-list-type-1 .compare-box-item','background-color','#eeeeee','','','.w-list-type-1'),(122455,'printshop-mobile','.w-filters .ui-slider','background-color','#757575','','','.w-filters'),(122456,'printshop-mobile','.w-filters .ui-slider-range','background-color','#15286f','','','.w-filters'),(122457,'printshop-mobile','.w-list-type-1 .button-wishlist button','background-color','#ffffff','','','.w-list-type-1'),(122458,'printshop-mobile','.w-languages .select','background-color','#ffffff','','','.w-languages'),(122459,'printshop-mobile','.w-reviews .reviews','background-color','#eeeeee','','','.w-reviews'),(122460,'printshop-mobile','.w-search .button-search','background-color','transparent','','','.w-search'),(122461,'printshop-mobile','.b-form .required-message','background-color','#eee','','','.b-form'),(122462,'printshop-mobile','.b-products-listing .loader','background-color','rgba(255, 255, 255, 0.7)','3','','.b-products-listing'),(122463,'printshop-mobile','.b-products-listing .products-listing .qty-input.hidden','background-color','#ffffff','3','','.b-products-listing'),(122464,'printshop-mobile','.b-products-listing .promos-info .promo-name','background-color','rgba(200, 200, 200, 0.7)','','','.b-products-listing'),(122465,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','#eeeeee','','','.b-data-table'),(122466,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.b-data-table'),(122467,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','#ffffff','','','.b-dropdown'),(122468,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','#ffffff','','','.b-dropdown'),(122469,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','#ffffff','','','.b-dropdown'),(122470,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','#ffffff','','','.b-dropdown'),(122471,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','#ffffff','','','.b-dropdown'),(122472,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','#ffffff','','','.b-dropdown'),(122473,'printshop-mobile','.b-email .heading-products','background-color','#eeeeee','','','.b-email'),(122474,'printshop-mobile','.b-email .heading-products','background-color','#eeeeee','','','.b-email'),(122475,'printshop-mobile','.b-email .heading-products','background-color','#eeeeee','','','.b-email'),(122476,'printshop-mobile','.b-email .heading-products','background-color','#eeeeee','','','.b-email'),(122477,'printshop-mobile','.b-email .heading-products','background-color','#eeeeee','','','.b-email'),(122478,'printshop-mobile','.b-email .heading-products','background-color','#eeeeee','','','.b-email'),(122479,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','background-color','#ddd','','','.b-menu-style-1'),(122480,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li:hover > a','background-color','#ddd','','','.b-menu-style-1'),(122481,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2','background-color','#eeeeee','','','.b-menu-style-1'),(122482,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .menu-content','background-color','#183d78','','','.b-menu-style-2'),(122483,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] ul','background-color','#183d78','','','.b-menu-style-3'),(122484,'printshop-mobile','.b-messages .msv_to_cc','background-color','#eeeeee','','','.b-messages'),(122485,'printshop-mobile','.b-messages .msv_history','background-color','#eeeeee','','','.b-messages'),(122486,'printshop-mobile','.b-messages .email-heading','background-color','#eeeeee','','','.b-messages'),(122487,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','background-color','#eeeeee','','','.b-messages'),(122488,'printshop-mobile','.b-preloader .preloader','background-color','rgba(255, 255, 255, 0.7)','','','.b-preloader'),(122489,'printshop-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','background-color','#eeeeee','','','.b-select-suggest'),(122490,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-color','#eeeeee','','','.b-select-suggest'),(122491,'printshop-mobile','.b-select-suggest .select2-search input','background-color','#ffffff','','','.b-select-suggest'),(122492,'printshop-mobile','.b-select-suggest .select2-search input.select2-active','background-color','#ffffff','','','.b-select-suggest'),(122493,'printshop-mobile','.b-select-suggest .select2-drop','background-color','#ffffff','','','.b-select-suggest'),(122494,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-color','#eeeeee','','','.b-select-suggest'),(122495,'printshop-mobile','.b-select-suggest .select2-drop-mask','background-color','#ffffff','','','.b-select-suggest'),(122496,'printshop-mobile','.b-select-suggest .select2-results .select2-disabled','background-color','#eeeeee','','','.b-select-suggest'),(122497,'printshop-mobile','.b-select-suggest .select2-results .select2-highlighted','background-color','#eeeeee','','','.b-select-suggest'),(122498,'printshop-mobile','.b-select-suggest .select2-results li em','background-color','#feffde','','','.b-select-suggest'),(122499,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-color','#eeeeee','','','.b-select-suggest'),(122500,'printshop-mobile','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','background-color','#eeeeee','','','.b-select-suggest'),(122501,'printshop-mobile','.b-select-suggest .select2-more-results.select2-active','background-color','#eeeeee','','','.b-select-suggest'),(122502,'printshop-mobile','.b-select-suggest .select2-more-results','background-color','#eeeeee','','','.b-select-suggest'),(122503,'printshop-mobile','.b-select-suggest .select2-results .select2-highlighted ul','background-color','#ffffff','','','.b-select-suggest'),(122504,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','background-color','#ffffff','','','.b-select-suggest'),(122505,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-color','#eeeeee','','','.b-select-suggest'),(122506,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color','#ffffff','','','.b-select-suggest'),(122507,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus','background-color','#eeeeee','','','.b-select-suggest'),(122508,'printshop-mobile','.b-trade-approval .steps-bar','background-color','#eeeeee','','','.b-trade-approval'),(122509,'printshop-mobile','.b-trade-approval .steps-bar li.current a','background-color','#183d78','','','.b-trade-approval'),(122510,'printshop-mobile','.batchPr .checkbox input:checked + span','background-color','#1428a0','','','.batchPr'),(122511,'printshop-mobile','.batchPr .checkbox input + span','background-color','#ffffff','','','.batchPr'),(122512,'printshop-mobile','.batchPr .btn-batch-remove','background-color','red','','','.batchPr'),(122513,'printshop-mobile','.p-account-samples-history .order_history_table th','background-color','#eeeeee','','','.p-account-samples-history'),(122514,'printshop-mobile','.p-account-samples-history .order_history_table th','background-color','#eeeeee','','','.p-account-samples-history'),(122515,'printshop-mobile','.p-account-samples-history .order_history_table th','background-color','#eeeeee','','','.p-account-samples-history'),(122516,'printshop-mobile','.p-account-samples-history .order_history_table th','background-color','#eeeeee','','','.p-account-samples-history'),(122517,'printshop-mobile','.p-account-samples-history .orders-table th','background-color','#eeeeee','','','.p-account-samples-history'),(122518,'printshop-mobile','.p-account-samples-history .orders-table th','background-color','#eeeeee','','','.p-account-samples-history'),(122519,'printshop-mobile','.p-account-samples-history .orders-table th','background-color','#eeeeee','','','.p-account-samples-history'),(122520,'printshop-mobile','.p-account-samples-history .orders-table th','background-color','#eeeeee','','','.p-account-samples-history'),(122521,'printshop-mobile','.p-account-samples-history .orders-table th','background-color','#eeeeee','','','.p-account-samples-history'),(122522,'printshop-mobile','.p-account-samples-history .order_history_table th','background-color','#eeeeee','','','.p-account-samples-history'),(122523,'printshop-mobile','.p-account-samples-history .orders-table th','background-color','#eeeeee','','','.p-account-samples-history'),(122524,'printshop-mobile','.p-account-samples-history .order_history_table th','background-color','#eeeeee','','','.p-account-samples-history'),(122525,'printshop-mobile','.p-catalog-product .prev-next-product','background-color','rgba(255, 255, 255, 0.7)','','','.p-catalog-product'),(122526,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.p-quick-order-index'),(122527,'printshop-mobile','.p-quick-order-index .all-scroll-div','background-color','#183d78','','','.p-quick-order-index'),(122528,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','#eeeeee','','','.p-quick-order-index'),(122529,'printshop-mobile','.w-account-personal-catalog .list-switcher a','background-color','#ffffff','2','','.w-account-personal-catalog'),(122530,'printshop-mobile','.w-blog-widget-post-listing .post_content','background-color','#ffffff','','','.w-blog-widget-post-listing'),(122531,'printshop-mobile','.w-blog-widget-post-listing .post_image','background-color','#ffffff','','','.w-blog-widget-post-listing'),(122532,'printshop-mobile','.w-blog-widget-post-share ','background-color','#EDE5D5','4','','.w-blog-widget-post-share'),(122533,'printshop-mobile','.w-blog-widget-related-posts .post_content a','background-color','#ffffff','','','.w-blog-widget-related-posts'),(122534,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','background-color','#E3D6BB','','','.w-blog-widget-related-posts'),(122535,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_img','background-color','#ffffff','','','.w-blog-widget-related-posts-by-category'),(122536,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_content','background-color','#ffffff','','','.w-blog-widget-related-posts-by-category'),(122537,'printshop-mobile','.w-blog-widget-tag-cloud a','background-color','#eeeeee','','','.w-blog-widget-tag-cloud'),(122538,'printshop-mobile','.w-cart-compare .price-cell','background-color','#fefdd6','','','.w-cart-compare'),(122539,'printshop-mobile','.w-cart-compare .attributes-cell','background-color','#fefdd6','','','.w-cart-compare'),(122540,'printshop-mobile','.w-cart-compare .price-block + .attributes-block .attributes-cell','background-color','#ffffff','','','.w-cart-compare'),(122541,'printshop-mobile','.w-catalog-b2b-add-button ','background-color','#183d78','','','.w-catalog-b2b-add-button'),(122542,'printshop-mobile','.w-catalog-compare tr','background-color','#eeeeee','1','','.w-catalog-compare'),(122543,'printshop-mobile','.w-catalog-compare .compare .checkbox input:checked + span','background-color','#ffffff','','','.w-catalog-compare'),(122544,'printshop-mobile','.w-catalog-compare .compare-fix-bar','background-color','#ffffff','','','.w-catalog-compare'),(122545,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','background-color','#ffffff','2','','.w-catalog-compare'),(122546,'printshop-mobile','.w-catalog-paging ','background-color','#183d78','2','','.w-catalog-paging'),(122547,'printshop-mobile','.w-checkout-billing-address .same-address','background-color','#eeeeee','','','.w-checkout-billing-address'),(122548,'printshop-mobile','.w-checkout-shipping-choice input:checked + span','background-color','#183d78','','','.w-checkout-shipping-choice'),(122549,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','background-color','#183d78','','','.w-checkout-shipping-choice'),(122550,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','background-color','#F0F0F0','','','.w-communication-new-topic'),(122551,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','background-color','#F0F0F0','','','.w-communication-new-topic'),(122552,'printshop-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','background-color','#ffffff','','','.w-delivery-day'),(122553,'printshop-mobile','.w-delivery-day .left-count','background-color','#183d78','','','.w-delivery-day'),(122554,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','background-color','#ffffff','','','.w-image-maps'),(122555,'printshop-mobile','.w-personal-gift-status-bar .progress-bar','background-color','#ffffff','','','.w-personal-gift-status-bar'),(122556,'printshop-mobile','.w-personal-gift-status-bar .timeline','background-color','#c9d5f6','','','.w-personal-gift-status-bar'),(122557,'printshop-mobile','.w-personal-gift-status-bar .progress-bar-content','background-color','#183d78','','','.w-personal-gift-status-bar'),(122558,'printshop-mobile','.w-product-customers-activity .customers-activity','background-color','#eeeeee','','','.w-product-customers-activity'),(122559,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','background-color','#ffffff','','','.w-promotions'),(122560,'printshop-mobile','.w-promotions .promo-cart-discount .master .item','background-color','#ffffff','','','.w-promotions'),(122561,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','background-color','#ffffff','','','.w-promotions'),(122562,'printshop-mobile','.w-promotions .promo-cart-discount .slave .item','background-color','#ffffff','','','.w-promotions'),(122563,'printshop-mobile','.w-promotions .promo-salemaker .item','background-color','#ffffff','','','.w-promotions'),(122564,'printshop-mobile','.w-promotions .promo-item','background-color','#eeeeee','','','.w-promotions'),(122565,'printshop-mobile','.w-promotions .promo-salemaker .discount','background-color','#ffffff','','','.w-promotions'),(122566,'printshop-mobile','.w-promotions .nextdiscount .content > div','background-color','#ffffff','','','.w-promotions'),(122567,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','background-color','#ffffff','','','.w-promotions'),(122568,'printshop-mobile','.w-promotions .nextdiscount .promo-for-each','background-color','#eeeeee','','','.w-promotions'),(122569,'printshop-mobile','.w-promotions .prom-multi-discount .promo-product','background-color','#ffffff','','','.w-promotions'),(122570,'printshop-mobile','.w-reviews-content .author','background-color','#eeeeee','','','.w-reviews-content'),(122571,'printshop-mobile','.w-reviews-content .review','background-color','#eeeeee','','','.w-reviews-content'),(122572,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','background-color','#eee','','','.w-upload-customer-id-upload-customer-id-form'),(122573,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','background-color','#fff','','','.w-upload-customer-id-upload-customer-id-form'),(122574,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-color','#ffffff','','','.w-wedding-registry-widgets-photos'),(122575,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.b-data-table'),(122576,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color_important','important','','','.b-select-suggest'),(122577,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.p-quick-order-index'),(122578,'printshop-mobile','.p-account-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-history-info'),(122579,'printshop-mobile','.p-account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-order-pay'),(122580,'printshop-mobile','.p-wedding-registry-share .wedding-image','background-image','url(themes/theme-1/img/wedding-registry-page.jpg)','','','.p-wedding-registry-share'),(122581,'printshop-mobile','.p-account-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-history'),(122582,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-image','none','','','.b-select-suggest'),(122583,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(122584,'printshop-mobile','.b-select-suggest .select2-more-results.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(122585,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-image','none','','','.b-select-suggest'),(122586,'printshop-mobile','.b-select-suggest .select2-search input','background-image','url(\'\')','','','.b-select-suggest'),(122587,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-image','url(\'\')','','','.b-select-suggest'),(122588,'printshop-mobile','.b-select-suggest .select2-results li','background-image','none','','','.b-select-suggest'),(122589,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-image','none','','','.b-select-suggest'),(122590,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-image','none','','','.b-select-suggest'),(122591,'printshop-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-image','url(\'\')','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(122592,'printshop-mobile','.b-select-suggest .select2-search-choice-close','background-image','url(\'\')','','','.b-select-suggest'),(122593,'printshop-mobile','.b-select-suggest .select2-search input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(122594,'printshop-mobile','.p-account-samples-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-samples-history'),(122595,'printshop-mobile','.p-account-samples-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-samples-history'),(122596,'printshop-mobile','.p-account-samples-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-samples-history'),(122597,'printshop-mobile','.p-account-samples-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-samples-history'),(122598,'printshop-mobile','.p-account-samples-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-samples-history'),(122599,'printshop-mobile','.p-account-samples-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-samples-history'),(122600,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-samples-history-info'),(122601,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-samples-history-info'),(122602,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-samples-history-info'),(122603,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-samples-history-info'),(122604,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-samples-history-info'),(122605,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-samples-history-info'),(122606,'printshop-mobile','.w-categories .image','background-position','50% 50%','','','.w-categories'),(122607,'printshop-mobile','.p-wedding-registry-manage .wedding-image','background-position','50%','','','.p-wedding-registry-manage'),(122608,'printshop-mobile','.p-wedding-registry-index .main-content','background-position','50%','','','.p-wedding-registry-index'),(122609,'printshop-mobile','.p-wedding-registry-share .wedding-image','background-position','50%','','','.p-wedding-registry-share'),(122610,'printshop-mobile','.w-top-categories .image','background-position','50% 50%','','','.w-top-categories'),(122611,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close','background-position','right -11px','1','','.b-select-suggest'),(122612,'printshop-mobile','.b-select-suggest .select2-search-choice-close','background-position','top right','','','.b-select-suggest'),(122613,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close','background-position','right -11px','','','.b-select-suggest'),(122614,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-position','right -11px','1','','.b-select-suggest'),(122615,'printshop-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow b','background-position','-18px 1px','','','.b-select-suggest'),(122616,'printshop-mobile','.b-select-suggest .select2-search input','background-position','100% -22px','','','.b-select-suggest'),(122617,'printshop-mobile','.b-select-suggest .select2-search input','background-position','100% -21px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(122618,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-position','top right','','','.b-select-suggest'),(122619,'printshop-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','background-position','50%','','','.w-wedding-registry-widgets-manage-banner'),(122620,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-position','center','','','.w-wedding-registry-widgets-photos'),(122621,'printshop-mobile','.b-select-suggest .select2-search input','background-position_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(122622,'printshop-mobile','.b-select-suggest .select2-search-choice-close','background-repeat','no-repeat','','','.b-select-suggest'),(122623,'printshop-mobile','.b-select-suggest .select2-search input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(122624,'printshop-mobile','.b-select-suggest .select2-search input','background-repeat','no-repeat','','','.b-select-suggest'),(122625,'printshop-mobile','.b-select-suggest .select2-more-results.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(122626,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-repeat','no-repeat','','','.b-select-suggest'),(122627,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','','.b-select-suggest'),(122628,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(122629,'printshop-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(122630,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-repeat','no-repeat','','','.w-wedding-registry-widgets-photos'),(122631,'printshop-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(122632,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat_important','important','','','.b-select-suggest'),(122633,'printshop-mobile','.w-categories .image','background-size','cover','','','.w-categories'),(122634,'printshop-mobile','.p-wedding-registry-index .main-content','background-size','cover','','','.p-wedding-registry-index'),(122635,'printshop-mobile','.p-wedding-registry-manage .wedding-image','background-size','cover','','','.p-wedding-registry-manage'),(122636,'printshop-mobile','.p-wedding-registry-share .wedding-image','background-size','cover','','','.p-wedding-registry-share'),(122637,'printshop-mobile','.w-top-categories .image','background-size','cover','','','.w-top-categories'),(122638,'printshop-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size','60px 40px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(122639,'printshop-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','background-size','cover','','','.w-wedding-registry-widgets-manage-banner'),(122640,'printshop-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(122641,'printshop-mobile','.p-account-index .moduleRowDue td','background_image','themes/printshop-mobile/img/pattern-1.png','','','.p-account-index'),(122642,'printshop-mobile','.p-wedding-registry-manage .wedding-image','background_image','themes/printshop-mobile/img/wedding-registry-page-1-1-1.jpg','','','.p-wedding-registry-manage'),(122643,'printshop-mobile','.p-wedding-registry-index .main-content','background_image','themes/printshop-mobile/img/wedding-registry-page-1-1-1.jpg','','','.p-wedding-registry-index'),(122644,'printshop-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','background_image','themes/printshop-mobile/img/wedding-registry-page-2.jpg','','','.w-wedding-registry-widgets-manage-banner'),(122645,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','background_image','themes/printshop-mobile/img/avatar-bg-1.png','','','.w-wedding-registry-widgets-photos'),(122646,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.b-data-table'),(122647,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background_important','important','','','.b-select-suggest'),(122648,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.p-quick-order-index'),(122649,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(122650,'printshop-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','border','none','','','.b-cookie-notice'),(122651,'printshop-mobile','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(122652,'printshop-mobile','.p-account-order-pay .historyTotal table','border','none','','','.p-account-order-pay'),(122653,'printshop-mobile','.p-account-order-pay .historyTotal td','border','none','','','.p-account-order-pay'),(122654,'printshop-mobile','.p-account-history .orders-table tr:first-child','border','none','','','.p-account-history'),(122655,'printshop-mobile','.w-product-wedding-registry-button .btn','border','none','','','.w-product-wedding-registry-button'),(122656,'printshop-mobile','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(122657,'printshop-mobile','.p-wedding-registry-share .middle-form > input','border','none','','','.p-wedding-registry-share'),(122658,'printshop-mobile','.b-compare .compare-head','border','none','','','.b-compare'),(122659,'printshop-mobile','.w-product-personal-catalog-button .btn','border','none','','','.w-product-personal-catalog-button'),(122660,'printshop-mobile','.w-filters .input-checkbox','border','none','','','.w-filters'),(122661,'printshop-mobile','.b-bottom .popup-box.popupCompare','border','none','','','.b-bottom'),(122662,'printshop-mobile','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(122663,'printshop-mobile','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(122664,'printshop-mobile','.w-compare-box-item .checkbox','border','none','','','.w-compare-box-item'),(122665,'printshop-mobile','.p-account-history-info .historyTotal table','border','none','','','.p-account-history-info'),(122666,'printshop-mobile','.w-categories .categories h2','border','none','','','.w-categories'),(122667,'printshop-mobile','.w-top-categories .categories h2','border','none','','','.w-top-categories'),(122668,'printshop-mobile','.b-form .checkbox-style','border','none','','','.b-form'),(122669,'printshop-mobile','.p-account-index .orders-table tr:first-child','border','none','','','.p-account-index'),(122670,'printshop-mobile','.p-account-history-info .historyTotal td','border','none','','','.p-account-history-info'),(122671,'printshop-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input + span','border','none','','','.b-products-listing'),(122672,'printshop-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','border','none','','','.b-products-listing'),(122673,'printshop-mobile','.b-products-listing .products-listing a.btn.view-button','border','none','','','.b-products-listing'),(122674,'printshop-mobile','.b-products-listing .products-listing h2','border','none','','','.b-products-listing'),(122675,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.b-data-table'),(122676,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.b-data-table'),(122677,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.b-data-table'),(122678,'printshop-mobile','.b-data-table table.dataTable thead td','border','none','','','.b-data-table'),(122679,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','border','none','','','.b-menu-style-2'),(122680,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','border','none','','','.b-menu-style-2'),(122681,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','border','none','','','.b-menu-style-2'),(122682,'printshop-mobile','.b-messages .select2-container-multi input.select2-input','border','none','','','.b-messages'),(122683,'printshop-mobile','.b-messages .emailLineTextArea textarea','border','none','','','.b-messages'),(122684,'printshop-mobile','.b-sub-totals .historyTotal td','border','none','','','.b-sub-totals'),(122685,'printshop-mobile','.b-sub-totals .historyTotal table','border','none','','','.b-sub-totals'),(122686,'printshop-mobile','.b-trade-approval .w-login-block .heading-3','border','none','','','.b-trade-approval'),(122687,'printshop-mobile','.p-account-samples-history .orders-table tr:first-child','border','none','','','.p-account-samples-history'),(122688,'printshop-mobile','.p-account-samples-history .orders-table tr:first-child','border','none','','','.p-account-samples-history'),(122689,'printshop-mobile','.p-account-samples-history .orders-table tr:first-child','border','none','','','.p-account-samples-history'),(122690,'printshop-mobile','.p-account-samples-history .orders-table tr:first-child','border','none','','','.p-account-samples-history'),(122691,'printshop-mobile','.p-account-samples-history .orders-table tr:first-child','border','none','','','.p-account-samples-history'),(122692,'printshop-mobile','.p-account-samples-history .orders-table tr:first-child','border','none','','','.p-account-samples-history'),(122693,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.p-quick-order-index'),(122694,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','1','','.p-quick-order-index'),(122695,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.p-quick-order-index'),(122696,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.p-quick-order-index'),(122697,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border','none','','','.w-blog-widget-related-posts'),(122698,'printshop-mobile','.w-cart-cart-tabs .w-tabs > .block','border','none','','','.w-cart-cart-tabs'),(122699,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','border','none','','','.w-catalog-compare'),(122700,'printshop-mobile','.w-checkout-gdpr .privacy-row','border','none','','','.w-checkout-gdpr'),(122701,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','border','none','','','.w-communication-new-topic'),(122702,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','border','none','','','.w-communication-new-topic'),(122703,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','border','none','','','.w-communication-new-topic'),(122704,'printshop-mobile','.w-cart-shipping-estimator .addresses','border-bottom','none','','','.w-cart-shipping-estimator'),(122705,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable.no-footer','border-bottom','none','','','.b-messages'),(122706,'printshop-mobile','.w-account-personal-catalog .list-switcher a','border-bottom','none','2','','.w-account-personal-catalog'),(122707,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','border-bottom','none','2','','.w-catalog-compare'),(122708,'printshop-mobile','.w-promotions .heading-3','border-bottom','none','','','.w-promotions'),(122709,'printshop-mobile','.w-sale .sale-holder','border-bottom-color','#ccc','','','.w-sale'),(122710,'printshop-mobile','.w-product-wedding-registry-button .btn','border-bottom-color','#183d78','3','','.w-product-wedding-registry-button'),(122711,'printshop-mobile','.w-product-sale-ends .left-text-left','border-bottom-color','#ccc','','','.w-product-sale-ends'),(122712,'printshop-mobile','.w-product-sale-ends .left-text-right','border-bottom-color','#ccc','','','.w-product-sale-ends'),(122713,'printshop-mobile','.w-currencies .select','border-bottom-color','#e0e0e0','','','.w-currencies'),(122714,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-history-info'),(122715,'printshop-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-color','#04a440','','','.w-compare-box-item'),(122716,'printshop-mobile','.w-catalog-listing-look .list','border-bottom-color','#e0e0e0','','','.w-catalog-listing-look'),(122717,'printshop-mobile','.w-catalog-listing-look .grid','border-bottom-color','#e0e0e0','','','.w-catalog-listing-look'),(122718,'printshop-mobile','.b-pagination .pagination span','border-bottom-color','#e0e0e0','2','','.b-pagination'),(122719,'printshop-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-bottom-color','#bdbdbd','2','','.b-product-images'),(122720,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-color','#e0e0e0','','','.b-multi-page-checkout'),(122721,'printshop-mobile','textarea','border-bottom-color','#e0e0e0','','',''),(122722,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-color','#e0e0e0','','','.p-blog-index'),(122723,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-color','#bdbdbd','','','.b-multi-page-checkout'),(122724,'printshop-mobile','.b-info-popup .info-popup div','border-bottom-color','#e0e0e0','','','.b-info-popup'),(122725,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-color','#092964','','','.b-multi-page-checkout'),(122726,'printshop-mobile','.w-promo-code .holder','border-bottom-color','#e0e0e0','','','.w-promo-code'),(122727,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-order-pay'),(122728,'printshop-mobile','.testimonials .review','border-bottom-color','transparent','3','',''),(122729,'printshop-mobile','.b-pagination .pagination .prev-pages','border-bottom-color','#e0e0e0','','','.b-pagination'),(122730,'printshop-mobile','.b-pagination .pagination .page-number','border-bottom-color','#e0e0e0','','','.b-pagination'),(122731,'printshop-mobile','.b-pagination .pagination .prev','border-bottom-color','#e0e0e0','','','.b-pagination'),(122732,'printshop-mobile','.b-pagination .pagination .next-pages','border-bottom-color','#e0e0e0','','','.b-pagination'),(122733,'printshop-mobile','.b-pagination .pagination .next','border-bottom-color','#e0e0e0','','','.b-pagination'),(122734,'printshop-mobile','.p-account-history .orders-table .item','border-bottom-color','#ccc','720','','.p-account-history'),(122735,'printshop-mobile','.p-account-index .orders-table .item','border-bottom-color','#ccc','720','','.p-account-index'),(122736,'printshop-mobile','.w-cart .cart-content','border-bottom-color','#cccccc','','','.w-cart'),(122737,'printshop-mobile','.p-blog-index .comments-area article','border-bottom-color','#e0e0e0','','','.p-blog-index'),(122738,'printshop-mobile','.w-product-wedding-registry-button .btn','border-bottom-color','#183d78','4','','.w-product-wedding-registry-button'),(122739,'printshop-mobile','.p-reviews-info .review-info-text','border-bottom-color','#fff','4','','.p-reviews-info'),(122740,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-color','#e0e0e0','3','','.b-form'),(122741,'printshop-mobile','.p-wedding-registry-manage .links','border-bottom-color','#e0e0e0','','','.p-wedding-registry-manage'),(122742,'printshop-mobile','.b-pagination .pagination a','border-bottom-color','#e0e0e0','','','.b-pagination'),(122743,'printshop-mobile','.b-bottom .popup-heading','border-bottom-color','#d9d9d9','','','.b-bottom'),(122744,'printshop-mobile','.b-compare .compare_pagination','border-bottom-color','#e0e0e0','','','.b-compare'),(122745,'printshop-mobile','.w-tabs .accordion-heading','border-bottom-color','#183d78','2','','.w-tabs'),(122746,'printshop-mobile','.w-tabs .accordion-heading','border-bottom-color','#e0e0e0','','','.w-tabs'),(122747,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-color','#ccc','','','.b-slick'),(122748,'printshop-mobile','.b-bottom .footerTitle','border-bottom-color','#e0e0e0','693','','.b-bottom'),(122749,'printshop-mobile','.btn','border-bottom-color','#183d78','','',''),(122750,'printshop-mobile','.w-languages .select','border-bottom-color','#e0e0e0','','','.w-languages'),(122751,'printshop-mobile','.w-tabs .tab-a','border-bottom-color','#e0e0e0','','','.w-tabs'),(122752,'printshop-mobile','.w-tabs .tab-a','border-bottom-color','#183d78','2','','.w-tabs'),(122753,'printshop-mobile','.w-socials > li','border-bottom-color','#dedede','','','.w-socials'),(122754,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-bottom-color','#e0e0e0','','',''),(122755,'printshop-mobile','.heading-4, h4','border-bottom-color','#e2e2e2','','',''),(122756,'printshop-mobile','.heading-2, h2','border-bottom-color','#e0e0e0','','',''),(122757,'printshop-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-color','#eee','','','.p-account-trade-form'),(122758,'printshop-mobile','.p-account-trade-form .widget .widget','border-bottom-color','#eee','','','.p-account-trade-form'),(122759,'printshop-mobile','.w-filters .filter-box-head','border-bottom-color','#e0e0e0','','','.w-filters'),(122760,'printshop-mobile','.w-currencies .currencies-title','border-bottom-color','#092964','','','.w-currencies'),(122761,'printshop-mobile','.w-compare-box-item .checkbox + span','border-bottom-color','#bdbdbd','','','.w-compare-box-item'),(122762,'printshop-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-color','#898989','','','.b-compare'),(122763,'printshop-mobile','.w-cart-products .checkout-attention-message','border-bottom-color','#ee4225','','','.w-cart-products'),(122764,'printshop-mobile','.w-product-quantity .qty_packs .qty-input','border-bottom-color','#ccc','','','.w-product-quantity'),(122765,'printshop-mobile','.w-sale .left-text-left','border-bottom-color','#ccc','','','.w-sale'),(122766,'printshop-mobile','.w-sale .left-text-right','border-bottom-color','#ccc','','','.w-sale'),(122767,'printshop-mobile','.b-form .col-full-padding','border-bottom-color','#cccccc','','','.b-form'),(122768,'printshop-mobile','.b-quantity .qty-box .smaller','border-bottom-color','#e0e0e0','','','.b-quantity'),(122769,'printshop-mobile','.b-quantity .qty-box .bigger','border-bottom-color','#e0e0e0','','','.b-quantity'),(122770,'printshop-mobile','.w-cart .cart-total','border-bottom-color','#eeeeee','','','.w-cart'),(122771,'printshop-mobile','.w-cart-give-away .ga_column','border-bottom-color','#e0e0e0','','','.w-cart-give-away'),(122772,'printshop-mobile','.w-catalog-listing-look .b2b','border-bottom-color','#e0e0e0','','','.w-catalog-listing-look'),(122773,'printshop-mobile','.btn-3','border-bottom-color','#183d78','','',''),(122774,'printshop-mobile','.b-bottom .popup-box','border-bottom-color','#d9d9d9','','','.b-bottom'),(122775,'printshop-mobile','.w-reviews .review','border-bottom-color','transparent','3','','.w-reviews'),(122776,'printshop-mobile','.b-form .required-error','border-bottom-color','#ed4224','','','.b-form'),(122777,'printshop-mobile','.p-account-address-book .address_book h2','border-bottom-color','#e0e0e0','','','.p-account-address-book'),(122778,'printshop-mobile','.p-account-address-book .address_book h1','border-bottom-color','#e0e0e0','','','.p-account-address-book'),(122779,'printshop-mobile','.b-products-listing .products-listing .compare','border-bottom-color','#e0e0e0','','','.b-products-listing'),(122780,'printshop-mobile','.b-data-table table.dataTable.no-footer','border-bottom-color','#e0e0e0','','','.b-data-table'),(122781,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','#e0e0e0','','','.b-dropdown'),(122782,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','#e0e0e0','','','.b-dropdown'),(122783,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','#e0e0e0','','','.b-dropdown'),(122784,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','#e0e0e0','','','.b-dropdown'),(122785,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','#e0e0e0','','','.b-dropdown'),(122786,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','#e0e0e0','','','.b-dropdown'),(122787,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-bottom-color','#ffffff','','','.b-menu-style-2'),(122788,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','border-bottom-color','#1a61ad','','','.b-menu-style-2'),(122789,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-bottom-color','#ffffff','','','.b-menu-style-2'),(122790,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-bottom-color','#ffffff','','','.b-menu-style-2'),(122791,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-bottom-color','#ffffff','','','.b-menu-style-2'),(122792,'printshop-mobile','.b-messages .msv_btn','border-bottom-color','#e0e0e0','','','.b-messages'),(122793,'printshop-mobile','.b-messages .content_management_attach button','border-bottom-color','#183d78','','','.b-messages'),(122794,'printshop-mobile','.b-messages .content_management_attach','border-bottom-color','#e0e0e0','','','.b-messages'),(122795,'printshop-mobile','.b-messages .email-heading','border-bottom-color','#e0e0e0','','','.b-messages'),(122796,'printshop-mobile','.b-messages .dataTables_wrapper > .bottom','border-bottom-color','#e0e0e0','','','.b-messages'),(122797,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-color','#e0e0e0','','','.b-messages'),(122798,'printshop-mobile','.b-messages .msv_to_cc','border-bottom-color','#e0e0e0','','','.b-messages'),(122799,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-color','#e0e0e0','','','.b-messages'),(122800,'printshop-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-color','#e0e0e0','','','.b-messages'),(122801,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(122802,'printshop-mobile','.b-select-suggest .select2-dropdown-open .select2-choice','border-bottom-color','transparent','','','.b-select-suggest'),(122803,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(122804,'printshop-mobile','.b-select-suggest .select2-drop','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(122805,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(122806,'printshop-mobile','.b-select-suggest .select2-container.select2-drop-above .select2-choice','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(122807,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(122808,'printshop-mobile','.b-select-suggest .select2-search input','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(122809,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(122810,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(122811,'printshop-mobile','.b-select-suggest .select2-drop-active','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(122812,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(122813,'printshop-mobile','.b-trade-approval .orders-table th','border-bottom-color','#e0e0e0','','','.b-trade-approval'),(122814,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-color','#e0e0e0','','','.b-trade-approval'),(122815,'printshop-mobile','.b-upload-file .snapshot','border-bottom-color','#757575','','','.b-upload-file'),(122816,'printshop-mobile','.b-upload-file .upload-file-template div','border-bottom-color','#e0e0e0','','','.b-upload-file'),(122817,'printshop-mobile','.b-upload-file .upload-file-template','border-bottom-color','#e0e0e0','','','.b-upload-file'),(122818,'printshop-mobile','.b-upload-files .upload-files','border-bottom-color','#e0e0e0','','','.b-upload-files'),(122819,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-color','#e0e0e0','','','.batchPr'),(122820,'printshop-mobile','.batchPr .checkbox input + span','border-bottom-color','#e0e0e0','','','.batchPr'),(122821,'printshop-mobile','.batchPr .checkbox input + span','border-bottom-color','#e0e0e0','','','.batchPr'),(122822,'printshop-mobile','.batchPr .w-batch-selected-products','border-bottom-color','#e0e0e0','','','.batchPr'),(122823,'printshop-mobile','.batchPr .checkbox input:checked + span','border-bottom-color','#1428a0','','','.batchPr'),(122824,'printshop-mobile','.blogsidebar .heading-title','border-bottom-color','#e0e0e0','','','.blogsidebar'),(122825,'printshop-mobile','.blogsidebar .heading-title','border-bottom-color','#e0e0e0','','','.blogsidebar'),(122826,'printshop-mobile','.blogsidebar .heading-title','border-bottom-color','#e0e0e0','','','.blogsidebar'),(122827,'printshop-mobile','.blogsidebar .heading-title','border-bottom-color','#e0e0e0','','','.blogsidebar'),(122828,'printshop-mobile','.p-account-samples-history .orders-table .item','border-bottom-color','#e0e0e0','','','.p-account-samples-history'),(122829,'printshop-mobile','.p-account-samples-history .orders-table .item','border-bottom-color','#e0e0e0','','','.p-account-samples-history'),(122830,'printshop-mobile','.p-account-samples-history .orders-table .item','border-bottom-color','#e0e0e0','','','.p-account-samples-history'),(122831,'printshop-mobile','.p-account-samples-history .orders-table .item','border-bottom-color','#e0e0e0','','','.p-account-samples-history'),(122832,'printshop-mobile','.p-account-samples-history .orders-table .item','border-bottom-color','#e0e0e0','','','.p-account-samples-history'),(122833,'printshop-mobile','.p-account-samples-history .orders-table .item','border-bottom-color','#e0e0e0','','','.p-account-samples-history'),(122834,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-samples-history-info'),(122835,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-samples-history-info'),(122836,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-samples-history-info'),(122837,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-samples-history-info'),(122838,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-samples-history-info'),(122839,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-samples-history-info'),(122840,'printshop-mobile','.p-catalog-product .prev-next-product','border-bottom-color','#e0e0e0','','','.p-catalog-product'),(122841,'printshop-mobile','.p-catalog-product .pn-image','border-bottom-color','#e0e0e0','3','','.p-catalog-product'),(122842,'printshop-mobile','.p-payer-order-confirmation .input-wrapper','border-bottom-color','#e0e0e0','','','.p-payer-order-confirmation'),(122843,'printshop-mobile','.p-payer-order-pay .input-wrapper','border-bottom-color','#e0e0e0','','','.p-payer-order-pay'),(122844,'printshop-mobile','.w-account-address-book .wrap','border-bottom-color','#c4c4c4','','','.w-account-address-book'),(122845,'printshop-mobile','.w-account-personal-catalog .list-switcher a','border-bottom-color','#e0e0e0','','','.w-account-personal-catalog'),(122846,'printshop-mobile','.w-blog-widget-post-listing .post_content','border-bottom-color','#e0e0e0','','','.w-blog-widget-post-listing'),(122847,'printshop-mobile','.w-blog-widget-post-listing .post_name','border-bottom-color','#e0e0e0','','','.w-blog-widget-post-listing'),(122848,'printshop-mobile','.w-blog-widget-post-title ','border-bottom-color','#e0e0e0','','','.w-blog-widget-post-title'),(122849,'printshop-mobile','.w-cart-compare .compare-table','border-bottom-color','#e0e0e0','','','.w-cart-compare'),(122850,'printshop-mobile','.w-cart-compare .cart-cell > div','border-bottom-color','#e0e0e0','','','.w-cart-compare'),(122851,'printshop-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-color','#ffffff','','','.w-catalog-compare'),(122852,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','border-bottom-color','#e0e0e0','','','.w-catalog-compare'),(122853,'printshop-mobile','.w-catalog-paging .next','border-bottom-color','#e0e0e0','','','.w-catalog-paging'),(122854,'printshop-mobile','.w-catalog-paging .prev','border-bottom-color','#e0e0e0','','','.w-catalog-paging'),(122855,'printshop-mobile','.w-catalog-paging ','border-bottom-color','#e0e0e0','2','','.w-catalog-paging'),(122856,'printshop-mobile','.w-catalog-paging .next-pages','border-bottom-color','#e0e0e0','','','.w-catalog-paging'),(122857,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-color','#e0e0e0','','','.w-catalog-paging'),(122858,'printshop-mobile','.w-catalog-paging .prev-pages','border-bottom-color','#e0e0e0','','','.w-catalog-paging'),(122859,'printshop-mobile','.w-catalog-paging .page-number','border-bottom-color','#e0e0e0','','','.w-catalog-paging'),(122860,'printshop-mobile','.w-checkout-shipping-choice span','border-bottom-color','#183d78','','','.w-checkout-shipping-choice'),(122861,'printshop-mobile','.w-communication-post .communication-post','border-bottom-color','#e0e0e0','','','.w-communication-post'),(122862,'printshop-mobile','.w-delivery-day .left-text-left','border-bottom-color','#e0e0e0','','','.w-delivery-day'),(122863,'printshop-mobile','.w-delivery-day .left-text-right','border-bottom-color','#e0e0e0','','','.w-delivery-day'),(122864,'printshop-mobile','.w-product-customers-activity .customers-activity','border-bottom-color','#e0e0e0','','','.w-product-customers-activity'),(122865,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-color','#ee4225','','','.w-promotions'),(122866,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-color','#ee4225','','','.w-promotions'),(122867,'printshop-mobile','.w-promotions .promo-salemaker .discount','border-bottom-color','#ff6716','','','.w-promotions'),(122868,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-color','#ee4225','','','.w-promotions'),(122869,'printshop-mobile','.w-reviews-content .item','border-bottom-color','#e0e0e0','','','.w-reviews-content'),(122870,'printshop-mobile','.w-reviews-content .review','border-bottom-color','#e0e0e0','3','','.w-reviews-content'),(122871,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-color','#ccc','','','.w-upload-customer-id-upload-customer-id-form'),(122872,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-bottom-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(122873,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-bottom-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(122874,'printshop-mobile','.b-data-table table.dataTable.no-footer','border-bottom-color_important','important','','','.b-data-table'),(122875,'printshop-mobile','.w-product-sale-ends .left-count-days','border-bottom-left-radius','3','','','.w-product-sale-ends'),(122876,'printshop-mobile','.w-sale .left-count-days','border-bottom-left-radius','3','','','.w-sale'),(122877,'printshop-mobile','.w-sale .badge','border-bottom-left-radius','50','','','.w-sale'),(122878,'printshop-mobile','.w-product-wedding-registry-button .btn','border-bottom-left-radius','50','3','','.w-product-wedding-registry-button'),(122879,'printshop-mobile','.w-product-sale-ends .left-count','border-bottom-left-radius','3','','','.w-product-sale-ends'),(122880,'printshop-mobile','.w-product-sale-ends .left-count-hours','border-bottom-left-radius','3','','','.w-product-sale-ends'),(122881,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-left-radius','50','3','','.b-multi-page-checkout'),(122882,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-left-radius','50','','','.b-multi-page-checkout'),(122883,'printshop-mobile','.p-blog-index .avatar','border-bottom-left-radius','50','','','.p-blog-index'),(122884,'printshop-mobile','.w-product-wedding-registry-button .btn','border-bottom-left-radius','50','4','','.w-product-wedding-registry-button'),(122885,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-left-radius','50','3','','.b-form'),(122886,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(122887,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(122888,'printshop-mobile','.b-switch .bootstrap-switch','border-bottom-left-radius','14','','','.b-switch'),(122889,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border-bottom-left-radius','30','706','','.w-list-type-1'),(122890,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-left-radius','50','','','.b-slick'),(122891,'printshop-mobile','.b-fancybox .fancybox-skin','border-bottom-left-radius','4','','','.b-fancybox'),(122892,'printshop-mobile','.w-sale .left-count-hours','border-bottom-left-radius','3','','','.w-sale'),(122893,'printshop-mobile','.w-sale .left-count','border-bottom-left-radius','3','','','.w-sale'),(122894,'printshop-mobile','.b-fancybox .fancybox-nav span','border-bottom-left-radius','50','','','.b-fancybox'),(122895,'printshop-mobile','.btn-3','border-bottom-left-radius','24','','',''),(122896,'printshop-mobile','.btn-1','border-bottom-left-radius','20','','',''),(122897,'printshop-mobile','.btn','border-bottom-left-radius','24','','',''),(122898,'printshop-mobile','.btn-2','border-bottom-left-radius','24','','',''),(122899,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-left-radius','15','','','.b-fancybox'),(122900,'printshop-mobile','.b-products-listing .promos-info .promo-name','border-bottom-left-radius','0','','','.b-products-listing'),(122901,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.b-data-table'),(122902,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.b-data-table'),(122903,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-left-radius','5','','','.b-messages'),(122904,'printshop-mobile','.b-trade-approval .steps-bar','border-bottom-left-radius','18','','','.b-trade-approval'),(122905,'printshop-mobile','.b-upload-file .snapshot','border-bottom-left-radius','50','','','.b-upload-file'),(122906,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-left-radius','10','','','.batchPr'),(122907,'printshop-mobile','.batchPr .checkbox input + span','border-bottom-left-radius','18','','','.batchPr'),(122908,'printshop-mobile','.batchPr .btn-batch-remove','border-bottom-left-radius','100','','','.batchPr'),(122909,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-bottom-left-radius','0','','','.batchPr'),(122910,'printshop-mobile','.p-catalog-product .pn-image','border-bottom-left-radius','50','3','','.p-catalog-product'),(122911,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.p-quick-order-index'),(122912,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.p-quick-order-index'),(122913,'printshop-mobile','.w-account-address-book .wrap','border-bottom-left-radius','5','','','.w-account-address-book'),(122914,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-bottom-left-radius','0','','','.w-blog-widget-related-posts'),(122915,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-left-radius','0','','','.w-catalog-paging'),(122916,'printshop-mobile','.w-checkout-shipping-choice label:last-child span','border-bottom-left-radius','0','','','.w-checkout-shipping-choice'),(122917,'printshop-mobile','.w-checkout-shipping-choice label:first-child span','border-bottom-left-radius','16','','','.w-checkout-shipping-choice'),(122918,'printshop-mobile','.w-delivery-day .left-count','border-bottom-left-radius','3','','','.w-delivery-day'),(122919,'printshop-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-left-radius','3','','','.w-delivery-day'),(122920,'printshop-mobile','.w-personal-gift-status-bar .progress-bar-content','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(122921,'printshop-mobile','.w-personal-gift-status-bar .progress-bar','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(122922,'printshop-mobile','.w-product-customers-activity .customers-activity','border-bottom-left-radius','0','','','.w-product-customers-activity'),(122923,'printshop-mobile','.w-product-customers-activity .close','border-bottom-left-radius','50','','','.w-product-customers-activity'),(122924,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-left-radius','12','','','.w-promotions'),(122925,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-left-radius','12','','','.w-promotions'),(122926,'printshop-mobile','.w-promotions .promo-salemaker .discount','border-bottom-left-radius','12','','','.w-promotions'),(122927,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-left-radius','12','','','.w-promotions'),(122928,'printshop-mobile','.w-product-sale-ends .left-count-days','border-bottom-right-radius','3','','','.w-product-sale-ends'),(122929,'printshop-mobile','.w-sale .left-count-days','border-bottom-right-radius','3','','','.w-sale'),(122930,'printshop-mobile','.w-sale .badge','border-bottom-right-radius','50','','','.w-sale'),(122931,'printshop-mobile','.w-product-wedding-registry-button .btn','border-bottom-right-radius','50','3','','.w-product-wedding-registry-button'),(122932,'printshop-mobile','.w-product-sale-ends .left-count','border-bottom-right-radius','3','','','.w-product-sale-ends'),(122933,'printshop-mobile','.w-product-sale-ends .left-count-hours','border-bottom-right-radius','3','','','.w-product-sale-ends'),(122934,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-right-radius','50','3','','.b-multi-page-checkout'),(122935,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-right-radius','50','','','.b-multi-page-checkout'),(122936,'printshop-mobile','.p-blog-index .avatar','border-bottom-right-radius','50','','','.p-blog-index'),(122937,'printshop-mobile','.w-product-wedding-registry-button .btn','border-bottom-right-radius','50','4','','.w-product-wedding-registry-button'),(122938,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-right-radius','50','3','','.b-form'),(122939,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(122940,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(122941,'printshop-mobile','.b-switch .bootstrap-switch','border-bottom-right-radius','14','','','.b-switch'),(122942,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border-bottom-right-radius','30','706','','.w-list-type-1'),(122943,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-right-radius','50','','','.b-slick'),(122944,'printshop-mobile','.b-fancybox .fancybox-skin','border-bottom-right-radius','4','','','.b-fancybox'),(122945,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-right-radius','15','','','.b-fancybox'),(122946,'printshop-mobile','.b-fancybox .fancybox-nav span','border-bottom-right-radius','50','','','.b-fancybox'),(122947,'printshop-mobile','.w-sale .left-count-hours','border-bottom-right-radius','3','','','.w-sale'),(122948,'printshop-mobile','.w-sale .left-count','border-bottom-right-radius','3','','','.w-sale'),(122949,'printshop-mobile','.btn-3','border-bottom-right-radius','24','','',''),(122950,'printshop-mobile','.btn-2','border-bottom-right-radius','24','','',''),(122951,'printshop-mobile','.btn','border-bottom-right-radius','24','','',''),(122952,'printshop-mobile','.btn-1','border-bottom-right-radius','20','','',''),(122953,'printshop-mobile','.b-products-listing .promos-info .promo-name','border-bottom-right-radius','8','','','.b-products-listing'),(122954,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.b-data-table'),(122955,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.b-data-table'),(122956,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-right-radius','5','','','.b-messages'),(122957,'printshop-mobile','.b-trade-approval .steps-bar','border-bottom-right-radius','18','','','.b-trade-approval'),(122958,'printshop-mobile','.b-upload-file .snapshot','border-bottom-right-radius','50','','','.b-upload-file'),(122959,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-right-radius','10','','','.batchPr'),(122960,'printshop-mobile','.batchPr .checkbox input + span','border-bottom-right-radius','18','','','.batchPr'),(122961,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-bottom-right-radius','0','','','.batchPr'),(122962,'printshop-mobile','.batchPr .btn-batch-remove','border-bottom-right-radius','100','','','.batchPr'),(122963,'printshop-mobile','.p-catalog-product .pn-image','border-bottom-right-radius','50','3','','.p-catalog-product'),(122964,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.p-quick-order-index'),(122965,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.p-quick-order-index'),(122966,'printshop-mobile','.w-account-address-book .wrap','border-bottom-right-radius','5','','','.w-account-address-book'),(122967,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-bottom-right-radius','0','','','.w-blog-widget-related-posts'),(122968,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-right-radius','0','','','.w-catalog-paging'),(122969,'printshop-mobile','.w-checkout-shipping-choice label:last-child span','border-bottom-right-radius','16','','','.w-checkout-shipping-choice'),(122970,'printshop-mobile','.w-checkout-shipping-choice label:first-child span','border-bottom-right-radius','0','','','.w-checkout-shipping-choice'),(122971,'printshop-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-right-radius','3','','','.w-delivery-day'),(122972,'printshop-mobile','.w-delivery-day .left-count','border-bottom-right-radius','3','','','.w-delivery-day'),(122973,'printshop-mobile','.w-personal-gift-status-bar .progress-bar','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(122974,'printshop-mobile','.w-personal-gift-status-bar .progress-bar-content','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(122975,'printshop-mobile','.w-product-customers-activity .customers-activity','border-bottom-right-radius','0','','','.w-product-customers-activity'),(122976,'printshop-mobile','.w-product-customers-activity .close','border-bottom-right-radius','50','','','.w-product-customers-activity'),(122977,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-right-radius','12','','','.w-promotions'),(122978,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-right-radius','12','','','.w-promotions'),(122979,'printshop-mobile','.w-promotions .promo-salemaker .discount','border-bottom-right-radius','12','','','.w-promotions'),(122980,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-right-radius','12','','','.w-promotions'),(122981,'printshop-mobile','.b-upload-file .upload-file-template div','border-bottom-style','dotted','','','.b-upload-file'),(122982,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(122983,'printshop-mobile','.w-sale .sale-holder','border-bottom-width','2','','','.w-sale'),(122984,'printshop-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','border-bottom-width','2','','','.b-product-images'),(122985,'printshop-mobile','.w-product-wedding-registry-button .btn','border-bottom-width','2','3','','.w-product-wedding-registry-button'),(122986,'printshop-mobile','.w-product-sale-ends .left-text-right','border-bottom-width','2','','','.w-product-sale-ends'),(122987,'printshop-mobile','.w-product-sale-ends .left-text-left','border-bottom-width','2','','','.w-product-sale-ends'),(122988,'printshop-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-bottom-width','2','2','','.b-product-images'),(122989,'printshop-mobile','.w-currencies .select','border-bottom-width','1','','','.w-currencies'),(122990,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-history-info'),(122991,'printshop-mobile','.b-pagination .pagination span','border-bottom-width','1','2','','.b-pagination'),(122992,'printshop-mobile','.w-product-reviews .reviews-list .review','border-bottom-width','13','3','','.w-product-reviews'),(122993,'printshop-mobile','.w-catalog-listing-look .list','border-bottom-width','1','','','.w-catalog-listing-look'),(122994,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-width','1','','','.b-multi-page-checkout'),(122995,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-width','2','','','.p-blog-index'),(122996,'printshop-mobile','textarea','border-bottom-width','2','','',''),(122997,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(122998,'printshop-mobile','.b-info-popup .info-popup div','border-bottom-width','1','','','.b-info-popup'),(122999,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(123000,'printshop-mobile','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(123001,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','border-bottom-width','1','','','.p-account-order-pay'),(123002,'printshop-mobile','.testimonials .review','border-bottom-width','7','3','',''),(123003,'printshop-mobile','.b-pagination .pagination .prev','border-bottom-width','1','','','.b-pagination'),(123004,'printshop-mobile','.b-pagination .pagination .prev-pages','border-bottom-width','1','','','.b-pagination'),(123005,'printshop-mobile','.p-wedding-registry-manage .wr-search button','border-bottom-width','0','','','.p-wedding-registry-manage'),(123006,'printshop-mobile','.b-pagination .pagination .page-number','border-bottom-width','1','','','.b-pagination'),(123007,'printshop-mobile','.b-pagination .pagination .next-pages','border-bottom-width','1','','','.b-pagination'),(123008,'printshop-mobile','.b-pagination .pagination .next','border-bottom-width','1','','','.b-pagination'),(123009,'printshop-mobile','.p-account-history .orders-table .item','border-bottom-width','1','720','','.p-account-history'),(123010,'printshop-mobile','.p-account-index .orders-table .item','border-bottom-width','1','720','','.p-account-index'),(123011,'printshop-mobile','.p-blog-index .comments-area article','border-bottom-width','1','','','.p-blog-index'),(123012,'printshop-mobile','.w-cart .cart-content','border-bottom-width','1','','','.w-cart'),(123013,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','border-bottom-width','0','','','.w-list-type-2_2'),(123014,'printshop-mobile','.w-product-wedding-registry-button .btn','border-bottom-width','2','4','','.w-product-wedding-registry-button'),(123015,'printshop-mobile','.p-reviews-info .review-info-text','border-bottom-width','5','4','','.p-reviews-info'),(123016,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-width','2','3','','.b-form'),(123017,'printshop-mobile','.p-wedding-registry-manage .links','border-bottom-width','1','','','.p-wedding-registry-manage'),(123018,'printshop-mobile','.b-pagination .pagination a','border-bottom-width','1','','','.b-pagination'),(123019,'printshop-mobile','.b-bottom .popup-heading','border-bottom-width','1','','','.b-bottom'),(123020,'printshop-mobile','.b-compare .compare_pagination','border-bottom-width','1','','','.b-compare'),(123021,'printshop-mobile','.w-tabs .accordion-heading','border-bottom-width','1','','','.w-tabs'),(123022,'printshop-mobile','.w-tabs .accordion-heading','border-bottom-width','3','2','','.w-tabs'),(123023,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-width','2','','','.b-slick'),(123024,'printshop-mobile','.b-bottom .footerTitle','border-bottom-width','1','693','','.b-bottom'),(123025,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-bottom-width','2','','',''),(123026,'printshop-mobile','.btn','border-bottom-width','2','','',''),(123027,'printshop-mobile','.w-tabs .tab-a','border-bottom-width','3','2','','.w-tabs'),(123028,'printshop-mobile','.w-tabs .tab-a','border-bottom-width','1','','','.w-tabs'),(123029,'printshop-mobile','.w-search .search-input','border-bottom-width','0','','','.w-search'),(123030,'printshop-mobile','.p-account-trade-form .widget .widget','border-bottom-width','1','','','.p-account-trade-form'),(123031,'printshop-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-width','1','','','.p-account-trade-form'),(123032,'printshop-mobile','.w-filters .filter-box-head','border-bottom-width','1','','','.w-filters'),(123033,'printshop-mobile','.w-currencies .currencies-title','border-bottom-width','2','','','.w-currencies'),(123034,'printshop-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-width','1','','','.w-compare-box-item'),(123035,'printshop-mobile','.w-compare-box-item .checkbox + span','border-bottom-width','1','','','.w-compare-box-item'),(123036,'printshop-mobile','.b-slick .slick-vertical .slick-slide','border-bottom-width','1','','','.b-slick'),(123037,'printshop-mobile','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(123038,'printshop-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-width','1','','','.b-compare'),(123039,'printshop-mobile','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(123040,'printshop-mobile','.heading-4, h4','border-bottom-width','1','','',''),(123041,'printshop-mobile','.heading-2, h2','border-bottom-width','1','','',''),(123042,'printshop-mobile','.w-sale .left-text-right','border-bottom-width','2','','','.w-sale'),(123043,'printshop-mobile','.w-sale .left-text-left','border-bottom-width','2','','','.w-sale'),(123044,'printshop-mobile','.b-form .col-full-padding','border-bottom-width','1','','','.b-form'),(123045,'printshop-mobile','.b-quantity .qty-box .smaller','border-bottom-width','2','','','.b-quantity'),(123046,'printshop-mobile','.b-quantity .qty-box .bigger','border-bottom-width','2','','','.b-quantity'),(123047,'printshop-mobile','.w-cart .cart-total','border-bottom-width','1','','','.w-cart'),(123048,'printshop-mobile','.w-catalog-listing-look .grid','border-bottom-width','1','','','.w-catalog-listing-look'),(123049,'printshop-mobile','.w-cart-give-away .ga_column','border-bottom-width','1','','','.w-cart-give-away'),(123050,'printshop-mobile','.w-catalog-listing-look .b2b','border-bottom-width','1','','','.w-catalog-listing-look'),(123051,'printshop-mobile','.w-list-type-2 .button-wishlist button','border-bottom-width','0','','','.w-list-type-2'),(123052,'printshop-mobile','.b-autocomplete .ui-autocomplete li','border-bottom-width','1','','','.b-autocomplete'),(123053,'printshop-mobile','.btn-3','border-bottom-width','2','','',''),(123054,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','border-bottom-width','0','','','.w-list-type-1_3'),(123055,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','border-bottom-width','0','','','.w-list-type-1_2'),(123056,'printshop-mobile','.b-bottom .popup-box','border-bottom-width','1','','','.b-bottom'),(123057,'printshop-mobile','.w-list-type-1 .button-wishlist button','border-bottom-width','0','','','.w-list-type-1'),(123058,'printshop-mobile','.w-filters .ui-slider','border-bottom-width','0','','','.w-filters'),(123059,'printshop-mobile','.w-filters .ui-slider-range','border-bottom-width','0','','','.w-filters'),(123060,'printshop-mobile','.w-filters .ui-slider-handle','border-bottom-width','0','','','.w-filters'),(123061,'printshop-mobile','.w-languages .select','border-bottom-width','1','','','.w-languages'),(123062,'printshop-mobile','.w-reviews .review','border-bottom-width','7','3','','.w-reviews'),(123063,'printshop-mobile','.w-search .button-search','border-bottom-width','0','','','.w-search'),(123064,'printshop-mobile','.w-socials > li','border-bottom-width','1','','','.w-socials'),(123065,'printshop-mobile','.b-form .required-error','border-bottom-width','1','','','.b-form'),(123066,'printshop-mobile','.p-account-address-book .address_book h1','border-bottom-width','1','','','.p-account-address-book'),(123067,'printshop-mobile','.p-account-address-book .address_book h2','border-bottom-width','1','','','.p-account-address-book'),(123068,'printshop-mobile','.b-products-listing .products-listing .compare','border-bottom-width','1','','','.b-products-listing'),(123069,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(123070,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(123071,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(123072,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(123073,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(123074,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(123075,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','border-bottom-width','1','','','.b-menu-style-2'),(123076,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-bottom-width','1','','','.b-menu-style-2'),(123077,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-bottom-width','3','','','.b-menu-style-2'),(123078,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-bottom-width','1','','','.b-menu-style-2'),(123079,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-bottom-width','3','','','.b-menu-style-2'),(123080,'printshop-mobile','.b-messages .msv_to_cc','border-bottom-width','1','','','.b-messages'),(123081,'printshop-mobile','.b-messages .msv_btn','border-bottom-width','1','','','.b-messages'),(123082,'printshop-mobile','.b-messages .email-heading','border-bottom-width','1','','','.b-messages'),(123083,'printshop-mobile','.b-messages .content_management_attach button','border-bottom-width','1','','','.b-messages'),(123084,'printshop-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-width','2','','','.b-messages'),(123085,'printshop-mobile','.b-messages .content_management_attach','border-bottom-width','1','','','.b-messages'),(123086,'printshop-mobile','.b-messages .dataTables_wrapper > .bottom','border-bottom-width','1','','','.b-messages'),(123087,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-width','1','','','.b-messages'),(123088,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-width','1','','','.b-messages'),(123089,'printshop-mobile','.b-select-suggest .select2-search input','border-bottom-width','1','','','.b-select-suggest'),(123090,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','border-bottom-width','2','','','.b-select-suggest'),(123091,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(123092,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(123093,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(123094,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-width','1','','','.b-select-suggest'),(123095,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(123096,'printshop-mobile','.b-select-suggest .select2-drop-active','border-bottom-width','1','','','.b-select-suggest'),(123097,'printshop-mobile','.b-select-suggest .select2-drop','border-bottom-width','1','','','.b-select-suggest'),(123098,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(123099,'printshop-mobile','.b-trade-approval .orders-table th','border-bottom-width','1','','','.b-trade-approval'),(123100,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-width','2','','','.b-trade-approval'),(123101,'printshop-mobile','.b-upload-file .snapshot','border-bottom-width','1','','','.b-upload-file'),(123102,'printshop-mobile','.b-upload-file .upload-file-template div','border-bottom-width','1','','','.b-upload-file'),(123103,'printshop-mobile','.b-upload-file .upload-file-template','border-bottom-width','1','','','.b-upload-file'),(123104,'printshop-mobile','.b-upload-files .upload-files','border-bottom-width','1','','','.b-upload-files'),(123105,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-width','1','','','.batchPr'),(123106,'printshop-mobile','.batchPr .checkbox input + span','border-bottom-width','1','','','.batchPr'),(123107,'printshop-mobile','.batchPr .checkbox input + span','border-bottom-width','1','','','.batchPr'),(123108,'printshop-mobile','.batchPr .checkbox input:checked + span','border-bottom-width','1','','','.batchPr'),(123109,'printshop-mobile','.batchPr .w-batch-selected-products','border-bottom-width','1','','','.batchPr'),(123110,'printshop-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(123111,'printshop-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(123112,'printshop-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(123113,'printshop-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(123114,'printshop-mobile','.p-account-samples-history .orders-table .item','border-bottom-width','1','','','.p-account-samples-history'),(123115,'printshop-mobile','.p-account-samples-history .orders-table .item','border-bottom-width','1','','','.p-account-samples-history'),(123116,'printshop-mobile','.p-account-samples-history .orders-table .item','border-bottom-width','1','','','.p-account-samples-history'),(123117,'printshop-mobile','.p-account-samples-history .orders-table .item','border-bottom-width','1','','','.p-account-samples-history'),(123118,'printshop-mobile','.p-account-samples-history .orders-table .item','border-bottom-width','1','','','.p-account-samples-history'),(123119,'printshop-mobile','.p-account-samples-history .orders-table .item','border-bottom-width','1','','','.p-account-samples-history'),(123120,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-samples-history-info'),(123121,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-samples-history-info'),(123122,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-samples-history-info'),(123123,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-samples-history-info'),(123124,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-samples-history-info'),(123125,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-samples-history-info'),(123126,'printshop-mobile','.p-catalog-product .prev-next-product','border-bottom-width','1','','','.p-catalog-product'),(123127,'printshop-mobile','.p-catalog-product .pn-image','border-bottom-width','2','3','','.p-catalog-product'),(123128,'printshop-mobile','.p-payer-order-confirmation .input-wrapper','border-bottom-width','2','','','.p-payer-order-confirmation'),(123129,'printshop-mobile','.p-payer-order-pay .input-wrapper','border-bottom-width','2','','','.p-payer-order-pay'),(123130,'printshop-mobile','.w-account-address-book .wrap','border-bottom-width','1','','','.w-account-address-book'),(123131,'printshop-mobile','.w-account-personal-catalog .list-switcher a','border-bottom-width','1','','','.w-account-personal-catalog'),(123132,'printshop-mobile','.w-blog-widget-post-listing .post_content','border-bottom-width','1','','','.w-blog-widget-post-listing'),(123133,'printshop-mobile','.w-blog-widget-post-listing .post_name','border-bottom-width','1','','','.w-blog-widget-post-listing'),(123134,'printshop-mobile','.w-blog-widget-post-title ','border-bottom-width','1','','','.w-blog-widget-post-title'),(123135,'printshop-mobile','.w-cart-compare .cart-cell > div','border-bottom-width','1','','','.w-cart-compare'),(123136,'printshop-mobile','.w-cart-compare .compare-table','border-bottom-width','1','','','.w-cart-compare'),(123137,'printshop-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-width','1','','','.w-catalog-compare'),(123138,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','border-bottom-width','1','','','.w-catalog-compare'),(123139,'printshop-mobile','.w-catalog-paging .prev','border-bottom-width','1','','','.w-catalog-paging'),(123140,'printshop-mobile','.w-catalog-paging .page-number','border-bottom-width','1','','','.w-catalog-paging'),(123141,'printshop-mobile','.w-catalog-paging .next','border-bottom-width','1','','','.w-catalog-paging'),(123142,'printshop-mobile','.w-catalog-paging ','border-bottom-width','1','2','','.w-catalog-paging'),(123143,'printshop-mobile','.w-catalog-paging .next-pages','border-bottom-width','1','','','.w-catalog-paging'),(123144,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-width','1','','','.w-catalog-paging'),(123145,'printshop-mobile','.w-catalog-paging .prev-pages','border-bottom-width','1','','','.w-catalog-paging'),(123146,'printshop-mobile','.w-checkout-shipping-choice span','border-bottom-width','2','','','.w-checkout-shipping-choice'),(123147,'printshop-mobile','.w-communication-post .communication-post','border-bottom-width','1','','','.w-communication-post'),(123148,'printshop-mobile','.w-delivery-day .left-text-right','border-bottom-width','2','','','.w-delivery-day'),(123149,'printshop-mobile','.w-delivery-day .left-text-left','border-bottom-width','2','','','.w-delivery-day'),(123150,'printshop-mobile','.w-product-customers-activity .customers-activity','border-bottom-width','1','','','.w-product-customers-activity'),(123151,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-width','1','','','.w-promotions'),(123152,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-width','1','','','.w-promotions'),(123153,'printshop-mobile','.w-promotions .promo-salemaker .discount','border-bottom-width','1','','','.w-promotions'),(123154,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-width','1','','','.w-promotions'),(123155,'printshop-mobile','.w-reviews-content .review','border-bottom-width','8','3','','.w-reviews-content'),(123156,'printshop-mobile','.w-reviews-content .item','border-bottom-width','1','','','.w-reviews-content'),(123157,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(123158,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-bottom-width','1','','','.w-wedding-registry-widgets-photos'),(123159,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-bottom-width','1','','','.w-wedding-registry-widgets-photos'),(123160,'printshop-mobile','.b-compare .popupCompare table','border-collapse','collapse','','','.b-compare'),(123161,'printshop-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','border-left','none','','','.b-select-suggest'),(123162,'printshop-mobile','.w-catalog-listing-look .list','border-left-color','#e0e0e0','','','.w-catalog-listing-look'),(123163,'printshop-mobile','.w-sale .sale-holder','border-left-color','#ccc','','','.w-sale'),(123164,'printshop-mobile','.w-product-wedding-registry-button .btn','border-left-color','#183d78','3','','.w-product-wedding-registry-button'),(123165,'printshop-mobile','.w-cart-products .checkout-attention-message','border-left-color','#ee4225','','','.w-cart-products'),(123166,'printshop-mobile','.w-currencies .select','border-left-color','#e0e0e0','','','.w-currencies'),(123167,'printshop-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-left-color','#bdbdbd','2','','.b-product-images'),(123168,'printshop-mobile','.b-pagination .pagination span','border-left-color','#e0e0e0','2','','.b-pagination'),(123169,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-color','#e0e0e0','','','.b-multi-page-checkout'),(123170,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-color','#e0e0e0','','','.p-blog-index'),(123171,'printshop-mobile','textarea','border-left-color','#e0e0e0','','',''),(123172,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-color','#bdbdbd','','','.b-multi-page-checkout'),(123173,'printshop-mobile','.b-info-popup .info-popup div','border-left-color','#e0e0e0','3','','.b-info-popup'),(123174,'printshop-mobile','.b-info-popup .info-popup div','border-left-color','#e0e0e0','','','.b-info-popup'),(123175,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-color','#092964','','','.b-multi-page-checkout'),(123176,'printshop-mobile','.w-promo-code .holder','border-left-color','#e0e0e0','','','.w-promo-code'),(123177,'printshop-mobile','.testimonials .review','border-left-color','#eeeeee','3','',''),(123178,'printshop-mobile','.b-pagination .pagination .prev-pages','border-left-color','#e0e0e0','','','.b-pagination'),(123179,'printshop-mobile','.b-pagination .pagination .prev','border-left-color','#e0e0e0','','','.b-pagination'),(123180,'printshop-mobile','.b-pagination .pagination .page-number','border-left-color','#e0e0e0','','','.b-pagination'),(123181,'printshop-mobile','.b-pagination .pagination .next-pages','border-left-color','#e0e0e0','','','.b-pagination'),(123182,'printshop-mobile','.b-pagination .pagination .next','border-left-color','#e0e0e0','','','.b-pagination'),(123183,'printshop-mobile','.p-account-history .orders-table .item','border-left-color','#ccc','720','','.p-account-history'),(123184,'printshop-mobile','.p-account-index .orders-table .item','border-left-color','#ccc','720','','.p-account-index'),(123185,'printshop-mobile','.w-cart .cart-content','border-left-color','#cccccc','','','.w-cart'),(123186,'printshop-mobile','.w-product-wedding-registry-button .btn','border-left-color','#183d78','4','','.w-product-wedding-registry-button'),(123187,'printshop-mobile','.p-reviews-info .review-info-text','border-left-color','#fff','4','','.p-reviews-info'),(123188,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-left-color','#e0e0e0','3','','.b-form'),(123189,'printshop-mobile','.p-wedding-registry-manage .links a + a','border-left-color','#e0e0e0','','','.p-wedding-registry-manage'),(123190,'printshop-mobile','.b-pagination .pagination a','border-left-color','#e0e0e0','','','.b-pagination'),(123191,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-left-color','#ccc','','','.b-slick'),(123192,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-left-color','#e0e0e0','','',''),(123193,'printshop-mobile','.w-socials > li','border-left-color','#dedede','','','.w-socials'),(123194,'printshop-mobile','.w-currencies .currencies-title','border-left-color','#092964','','','.w-currencies'),(123195,'printshop-mobile','.w-compare-box-item .checkbox:checked + span','border-left-color','#04a440','','','.w-compare-box-item'),(123196,'printshop-mobile','.w-compare-box-item .checkbox + span','border-left-color','#bdbdbd','','','.w-compare-box-item'),(123197,'printshop-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-color','#898989','','','.b-compare'),(123198,'printshop-mobile','.b-quantity .qty-box .smaller','border-left-color','#e0e0e0','','','.b-quantity'),(123199,'printshop-mobile','.b-quantity .qty-box .bigger','border-left-color','#e0e0e0','','','.b-quantity'),(123200,'printshop-mobile','.w-catalog-listing-look .grid','border-left-color','#e0e0e0','','','.w-catalog-listing-look'),(123201,'printshop-mobile','.w-catalog-listing-look .b2b','border-left-color','#e0e0e0','','','.w-catalog-listing-look'),(123202,'printshop-mobile','.btn-3','border-left-color','#183d78','','',''),(123203,'printshop-mobile','.btn','border-left-color','#183d78','','',''),(123204,'printshop-mobile','.b-bottom .popup-box','border-left-color','#d9d9d9','','','.b-bottom'),(123205,'printshop-mobile','.w-languages .select','border-left-color','#e0e0e0','','','.w-languages'),(123206,'printshop-mobile','.w-reviews .review','border-left-color','#fff','3','','.w-reviews'),(123207,'printshop-mobile','.b-form .required-error','border-left-color','#ed4224','','','.b-form'),(123208,'printshop-mobile','.b-data-table table.dataTable.no-footer','border-left-color','#e0e0e0','','','.b-data-table'),(123209,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','#e0e0e0','','','.b-dropdown'),(123210,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','#e0e0e0','','','.b-dropdown'),(123211,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','#e0e0e0','','','.b-dropdown'),(123212,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','#e0e0e0','','','.b-dropdown'),(123213,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','#e0e0e0','','','.b-dropdown'),(123214,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','#e0e0e0','','','.b-dropdown'),(123215,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-left-color','#ffffff','','','.b-menu-style-2'),(123216,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-left-color','#ffffff','','','.b-menu-style-2'),(123217,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-left-color','#ffffff','','','.b-menu-style-2'),(123218,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-left-color','#ffffff','','','.b-menu-style-2'),(123219,'printshop-mobile','.b-messages .content_management_attach button','border-left-color','#183d78','','','.b-messages'),(123220,'printshop-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-color','#e0e0e0','','','.b-messages'),(123221,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-color','#e0e0e0','','','.b-select-suggest'),(123222,'printshop-mobile','.b-select-suggest .select2-search input','border-left-color','#e0e0e0','','','.b-select-suggest'),(123223,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','border-left-color','#e0e0e0','','','.b-select-suggest'),(123224,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-color','#e0e0e0','','','.b-select-suggest'),(123225,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-color','#e0e0e0','','','.b-select-suggest'),(123226,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-color','#e0e0e0','','','.b-select-suggest'),(123227,'printshop-mobile','.b-select-suggest .select2-drop-active','border-left-color','#e0e0e0','','','.b-select-suggest'),(123228,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-left-color','#e0e0e0','','','.b-select-suggest'),(123229,'printshop-mobile','.b-select-suggest .select2-drop','border-left-color','#e0e0e0','','','.b-select-suggest'),(123230,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-color','#e0e0e0','','','.b-select-suggest'),(123231,'printshop-mobile','.b-trade-approval .steps-bar li ~ li a','border-left-color','#fff','','','.b-trade-approval'),(123232,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-color','#e0e0e0','','','.b-trade-approval'),(123233,'printshop-mobile','.b-upload-file .snapshot','border-left-color','#757575','','','.b-upload-file'),(123234,'printshop-mobile','.b-upload-file .upload-file-template','border-left-color','#e0e0e0','','','.b-upload-file'),(123235,'printshop-mobile','.b-upload-files .upload-files','border-left-color','#e0e0e0','','','.b-upload-files'),(123236,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-left-color','#e0e0e0','','','.batchPr'),(123237,'printshop-mobile','.batchPr .checkbox input + span','border-left-color','#e0e0e0','','','.batchPr'),(123238,'printshop-mobile','.batchPr .checkbox input + span','border-left-color','#e0e0e0','','','.batchPr'),(123239,'printshop-mobile','.batchPr .checkbox input:checked + span','border-left-color','#1428a0','','','.batchPr'),(123240,'printshop-mobile','.batchPr .w-batch-selected-products','border-left-color','#e0e0e0','','','.batchPr'),(123241,'printshop-mobile','.p-account-samples-history .orders-table .item','border-left-color','#e0e0e0','','','.p-account-samples-history'),(123242,'printshop-mobile','.p-account-samples-history .orders-table .item','border-left-color','#e0e0e0','','','.p-account-samples-history'),(123243,'printshop-mobile','.p-account-samples-history .orders-table .item','border-left-color','#e0e0e0','','','.p-account-samples-history'),(123244,'printshop-mobile','.p-account-samples-history .orders-table .item','border-left-color','#e0e0e0','','','.p-account-samples-history'),(123245,'printshop-mobile','.p-account-samples-history .orders-table .item','border-left-color','#e0e0e0','','','.p-account-samples-history'),(123246,'printshop-mobile','.p-account-samples-history .orders-table .item','border-left-color','#e0e0e0','','','.p-account-samples-history'),(123247,'printshop-mobile','.p-catalog-product .next-product','border-left-color','#e0e0e0','','','.p-catalog-product'),(123248,'printshop-mobile','.p-catalog-product .pn-image','border-left-color','#e0e0e0','3','','.p-catalog-product'),(123249,'printshop-mobile','.p-payer-order-confirmation .input-wrapper','border-left-color','#e0e0e0','','','.p-payer-order-confirmation'),(123250,'printshop-mobile','.p-payer-order-pay .input-wrapper','border-left-color','#e0e0e0','','','.p-payer-order-pay'),(123251,'printshop-mobile','.w-account-address-book .wrap','border-left-color','#c4c4c4','','','.w-account-address-book'),(123252,'printshop-mobile','.w-account-personal-catalog .list-switcher a','border-left-color','#e0e0e0','2','','.w-account-personal-catalog'),(123253,'printshop-mobile','.w-cart-compare .attributes-block td:nth-child(1)','border-left-color','#e0e0e0','','','.w-cart-compare'),(123254,'printshop-mobile','.w-cart-compare .price-block td:nth-child(1)','border-left-color','#e0e0e0','','','.w-cart-compare'),(123255,'printshop-mobile','.w-cart-compare .product-block td:nth-child(1)','border-left-color','#e0e0e0','','','.w-cart-compare'),(123256,'printshop-mobile','.w-cart-compare .cart-cell > div','border-left-color','#e0e0e0','','','.w-cart-compare'),(123257,'printshop-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-left-color','#ffffff','','','.w-catalog-compare'),(123258,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','border-left-color','#e0e0e0','2','','.w-catalog-compare'),(123259,'printshop-mobile','.w-catalog-paging ','border-left-color','#e0e0e0','2','','.w-catalog-paging'),(123260,'printshop-mobile','.w-catalog-paging .prev','border-left-color','#e0e0e0','','','.w-catalog-paging'),(123261,'printshop-mobile','.w-catalog-paging .next','border-left-color','#e0e0e0','','','.w-catalog-paging'),(123262,'printshop-mobile','.w-catalog-paging .page-number','border-left-color','#e0e0e0','','','.w-catalog-paging'),(123263,'printshop-mobile','.w-catalog-paging .next-pages','border-left-color','#e0e0e0','','','.w-catalog-paging'),(123264,'printshop-mobile','.w-catalog-paging .prev-pages','border-left-color','#e0e0e0','','','.w-catalog-paging'),(123265,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-color','#e0e0e0','','','.w-catalog-paging'),(123266,'printshop-mobile','.w-checkout-shipping-choice label:first-child span','border-left-color','#183d78','','','.w-checkout-shipping-choice'),(123267,'printshop-mobile','.w-product-customers-activity .customers-activity','border-left-color','#e0e0e0','','','.w-product-customers-activity'),(123268,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-left-color','#ee4225','','','.w-promotions'),(123269,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-color','#ee4225','','','.w-promotions'),(123270,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border-left-color','#ee4225','','','.w-promotions'),(123271,'printshop-mobile','.w-promotions .promo-salemaker .discount','border-left-color','#ff6716','','','.w-promotions'),(123272,'printshop-mobile','.w-reviews-content .review','border-left-color','#e0e0e0','3','','.w-reviews-content'),(123273,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-color','#ccc','','','.w-upload-customer-id-upload-customer-id-form'),(123274,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-left-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(123275,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-left-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(123276,'printshop-mobile','.b-data-table table.dataTable.no-footer','border-left-color_important','important','','','.b-data-table'),(123277,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(123278,'printshop-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','border-left-width','2','','','.b-product-images'),(123279,'printshop-mobile','.w-sale .sale-holder','border-left-width','2','','','.w-sale'),(123280,'printshop-mobile','.w-product-wedding-registry-button .btn','border-left-width','2','3','','.w-product-wedding-registry-button'),(123281,'printshop-mobile','.w-currencies .select','border-left-width','1','','','.w-currencies'),(123282,'printshop-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-left-width','2','2','','.b-product-images'),(123283,'printshop-mobile','.w-compare-box-item .checkbox + span','border-left-width','1','','','.w-compare-box-item'),(123284,'printshop-mobile','.w-catalog-listing-look .b2b','border-left-width','1','','','.w-catalog-listing-look'),(123285,'printshop-mobile','.w-catalog-listing-look .list','border-left-width','1','','','.w-catalog-listing-look'),(123286,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-width','1','','','.b-multi-page-checkout'),(123287,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-width','2','','','.p-blog-index'),(123288,'printshop-mobile','textarea','border-left-width','2','','',''),(123289,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(123290,'printshop-mobile','.btn','border-left-width','2','','',''),(123291,'printshop-mobile','.btn-3','border-left-width','2','','',''),(123292,'printshop-mobile','.b-info-popup .info-popup div','border-left-width','1','','','.b-info-popup'),(123293,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(123294,'printshop-mobile','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(123295,'printshop-mobile','.testimonials .review','border-left-width','10','3','',''),(123296,'printshop-mobile','.b-pagination .pagination .prev-pages','border-left-width','1','','','.b-pagination'),(123297,'printshop-mobile','.b-pagination .pagination .prev','border-left-width','1','','','.b-pagination'),(123298,'printshop-mobile','.p-wedding-registry-manage .wr-search button','border-left-width','0','','','.p-wedding-registry-manage'),(123299,'printshop-mobile','.b-pagination .pagination .page-number','border-left-width','1','','','.b-pagination'),(123300,'printshop-mobile','.b-pagination .pagination .next-pages','border-left-width','1','','','.b-pagination'),(123301,'printshop-mobile','.b-pagination .pagination .next','border-left-width','1','','','.b-pagination'),(123302,'printshop-mobile','.b-pagination .pagination span','border-left-width','1','2','','.b-pagination'),(123303,'printshop-mobile','.p-account-history .orders-table .item','border-left-width','1','720','','.p-account-history'),(123304,'printshop-mobile','.p-account-index .orders-table .item','border-left-width','1','720','','.p-account-index'),(123305,'printshop-mobile','.w-cart .cart-content','border-left-width','1','','','.w-cart'),(123306,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','border-left-width','0','','','.w-list-type-2_2'),(123307,'printshop-mobile','.w-list-type-2_2 .button-wishlist','border-left-width','1','','','.w-list-type-2_2'),(123308,'printshop-mobile','.w-product-wedding-registry-button .btn','border-left-width','2','4','','.w-product-wedding-registry-button'),(123309,'printshop-mobile','.p-reviews-info .review-info-text','border-left-width','5','4','','.p-reviews-info'),(123310,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-left-width','2','3','','.b-form'),(123311,'printshop-mobile','.p-wedding-registry-manage .links a + a','border-left-width','1','','','.p-wedding-registry-manage'),(123312,'printshop-mobile','.b-pagination .pagination a','border-left-width','1','','','.b-pagination'),(123313,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-left-width','2','','','.b-slick'),(123314,'printshop-mobile','.w-languages .select','border-left-width','1','','','.w-languages'),(123315,'printshop-mobile','.w-search .search-input','border-left-width','0','','','.w-search'),(123316,'printshop-mobile','.w-socials > li','border-left-width','1','','','.w-socials'),(123317,'printshop-mobile','.w-currencies .currencies-title','border-left-width','2','','','.w-currencies'),(123318,'printshop-mobile','.w-compare-box-item .checkbox:checked + span','border-left-width','1','','','.w-compare-box-item'),(123319,'printshop-mobile','.b-slick .slick-vertical .slick-slide','border-left-width','1','','','.b-slick'),(123320,'printshop-mobile','.b-info-popup .info-popup div','border-left-width','1','3','','.b-info-popup'),(123321,'printshop-mobile','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(123322,'printshop-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-width','1','','','.b-compare'),(123323,'printshop-mobile','.w-catalog-listing-look .grid','border-left-width','1','','','.w-catalog-listing-look'),(123324,'printshop-mobile','.b-quantity .qty-box .smaller','border-left-width','2','','','.b-quantity'),(123325,'printshop-mobile','.b-quantity .qty-box .bigger','border-left-width','2','','','.b-quantity'),(123326,'printshop-mobile','.b-autocomplete .ui-autocomplete li','border-left-width','1','','','.b-autocomplete'),(123327,'printshop-mobile','.w-list-type-2 .button-wishlist button','border-left-width','0','','','.w-list-type-2'),(123328,'printshop-mobile','.w-list-type-2 .button-wishlist','border-left-width','1','','','.w-list-type-2'),(123329,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','border-left-width','0','','','.w-list-type-1_3'),(123330,'printshop-mobile','.w-list-type-1_3 .button-wishlist','border-left-width','1','','','.w-list-type-1_3'),(123331,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','border-left-width','0','','','.w-list-type-1_2'),(123332,'printshop-mobile','.w-list-type-1_2 .button-wishlist','border-left-width','1','','','.w-list-type-1_2'),(123333,'printshop-mobile','.b-bottom .popup-box','border-left-width','1','','','.b-bottom'),(123334,'printshop-mobile','.w-list-type-1 .button-wishlist button','border-left-width','0','','','.w-list-type-1'),(123335,'printshop-mobile','.w-filters .ui-slider','border-left-width','0','','','.w-filters'),(123336,'printshop-mobile','.w-list-type-1 .button-wishlist','border-left-width','1','','','.w-list-type-1'),(123337,'printshop-mobile','.w-filters .ui-slider-range','border-left-width','0','','','.w-filters'),(123338,'printshop-mobile','.w-filters .ui-slider-handle','border-left-width','0','','','.w-filters'),(123339,'printshop-mobile','.w-product-reviews .reviews-list .review','border-left-width','20','3','','.w-product-reviews'),(123340,'printshop-mobile','.w-search .button-search','border-left-width','0','','','.w-search'),(123341,'printshop-mobile','.w-reviews .review','border-left-width','10','3','','.w-reviews'),(123342,'printshop-mobile','.b-form .required-error','border-left-width','1','','','.b-form'),(123343,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-left-width','2','','',''),(123344,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(123345,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(123346,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(123347,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(123348,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(123349,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(123350,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-left-width','1','','','.b-menu-style-2'),(123351,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-left-width','3','','','.b-menu-style-2'),(123352,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-left-width','1','','','.b-menu-style-2'),(123353,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-left-width','3','','','.b-menu-style-2'),(123354,'printshop-mobile','.b-messages .content_management_attach button','border-left-width','1','','','.b-messages'),(123355,'printshop-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-width','2','','','.b-messages'),(123356,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','border-left-width','2','','','.b-select-suggest'),(123357,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-width','1','','','.b-select-suggest'),(123358,'printshop-mobile','.b-select-suggest .select2-search input','border-left-width','1','','','.b-select-suggest'),(123359,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(123360,'printshop-mobile','.b-select-suggest .select2-drop','border-left-width','1','','','.b-select-suggest'),(123361,'printshop-mobile','.b-select-suggest .select2-drop-active','border-left-width','1','','','.b-select-suggest'),(123362,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-width','1','','','.b-select-suggest'),(123363,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','border-left-width','0','','','.b-select-suggest'),(123364,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-left-width','1','','','.b-select-suggest'),(123365,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-width','1','','','.b-select-suggest'),(123366,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(123367,'printshop-mobile','.b-trade-approval .steps-bar li ~ li a','border-left-width','1','','','.b-trade-approval'),(123368,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-width','2','','','.b-trade-approval'),(123369,'printshop-mobile','.b-upload-file .upload-file-template','border-left-width','1','','','.b-upload-file'),(123370,'printshop-mobile','.b-upload-file .snapshot','border-left-width','1','','','.b-upload-file'),(123371,'printshop-mobile','.b-upload-files .upload-files','border-left-width','1','','','.b-upload-files'),(123372,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-left-width','1','','','.batchPr'),(123373,'printshop-mobile','.batchPr .checkbox input + span','border-left-width','1','','','.batchPr'),(123374,'printshop-mobile','.batchPr .checkbox input + span','border-left-width','1','','','.batchPr'),(123375,'printshop-mobile','.batchPr .checkbox input:checked + span','border-left-width','1','','','.batchPr'),(123376,'printshop-mobile','.batchPr .w-batch-selected-products','border-left-width','1','','','.batchPr'),(123377,'printshop-mobile','.p-account-samples-history .orders-table .item','border-left-width','1','','','.p-account-samples-history'),(123378,'printshop-mobile','.p-account-samples-history .orders-table .item','border-left-width','1','','','.p-account-samples-history'),(123379,'printshop-mobile','.p-account-samples-history .orders-table .item','border-left-width','1','','','.p-account-samples-history'),(123380,'printshop-mobile','.p-account-samples-history .orders-table .item','border-left-width','1','','','.p-account-samples-history'),(123381,'printshop-mobile','.p-account-samples-history .orders-table .item','border-left-width','1','','','.p-account-samples-history'),(123382,'printshop-mobile','.p-account-samples-history .orders-table .item','border-left-width','1','','','.p-account-samples-history'),(123383,'printshop-mobile','.p-catalog-product .next-product','border-left-width','1','','','.p-catalog-product'),(123384,'printshop-mobile','.p-catalog-product .pn-image','border-left-width','2','3','','.p-catalog-product'),(123385,'printshop-mobile','.p-payer-order-confirmation .input-wrapper','border-left-width','2','','','.p-payer-order-confirmation'),(123386,'printshop-mobile','.p-payer-order-pay .input-wrapper','border-left-width','2','','','.p-payer-order-pay'),(123387,'printshop-mobile','.w-account-address-book .wrap','border-left-width','1','','','.w-account-address-book'),(123388,'printshop-mobile','.w-account-personal-catalog .list-switcher a','border-left-width','1','2','','.w-account-personal-catalog'),(123389,'printshop-mobile','.w-cart-compare .attributes-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(123390,'printshop-mobile','.w-cart-compare .price-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(123391,'printshop-mobile','.w-cart-compare .product-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(123392,'printshop-mobile','.w-cart-compare .cart-cell > div','border-left-width','1','','','.w-cart-compare'),(123393,'printshop-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-left-width','1','','','.w-catalog-compare'),(123394,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','border-left-width','1','2','','.w-catalog-compare'),(123395,'printshop-mobile','.w-catalog-paging ','border-left-width','1','2','','.w-catalog-paging'),(123396,'printshop-mobile','.w-catalog-paging .prev','border-left-width','1','','','.w-catalog-paging'),(123397,'printshop-mobile','.w-catalog-paging .page-number','border-left-width','1','','','.w-catalog-paging'),(123398,'printshop-mobile','.w-catalog-paging .next','border-left-width','1','','','.w-catalog-paging'),(123399,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-width','1','','','.w-catalog-paging'),(123400,'printshop-mobile','.w-catalog-paging .next-pages','border-left-width','1','','','.w-catalog-paging'),(123401,'printshop-mobile','.w-catalog-paging .prev-pages','border-left-width','1','','','.w-catalog-paging'),(123402,'printshop-mobile','.w-checkout-shipping-choice label:first-child span','border-left-width','2','','','.w-checkout-shipping-choice'),(123403,'printshop-mobile','.w-product-customers-activity .customers-activity','border-left-width','1','','','.w-product-customers-activity'),(123404,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-left-width','1','','','.w-promotions'),(123405,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-width','1','','','.w-promotions'),(123406,'printshop-mobile','.w-promotions .promo-salemaker .discount','border-left-width','1','','','.w-promotions'),(123407,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border-left-width','1','','','.w-promotions'),(123408,'printshop-mobile','.w-reviews-content .review','border-left-width','12','3','','.w-reviews-content'),(123409,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(123410,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-left-width','1','','','.w-wedding-registry-widgets-photos'),(123411,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-left-width','1','','','.w-wedding-registry-widgets-photos'),(123412,'printshop-mobile','.w-sale .sale-holder','border-right-color','#ccc','','','.w-sale'),(123413,'printshop-mobile','.w-product-wedding-registry-button .btn','border-right-color','#183d78','3','','.w-product-wedding-registry-button'),(123414,'printshop-mobile','.w-currencies .select','border-right-color','#e0e0e0','','','.w-currencies'),(123415,'printshop-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-right-color','#bdbdbd','2','','.b-product-images'),(123416,'printshop-mobile','.b-pagination .pagination span','border-right-color','#e0e0e0','2','','.b-pagination'),(123417,'printshop-mobile','.w-catalog-listing-look .grid','border-right-color','#e0e0e0','','','.w-catalog-listing-look'),(123418,'printshop-mobile','.w-catalog-listing-look .list','border-right-color','#e0e0e0','','','.w-catalog-listing-look'),(123419,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-color','#e0e0e0','','','.b-multi-page-checkout'),(123420,'printshop-mobile','textarea','border-right-color','#e0e0e0','','',''),(123421,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-color','#e0e0e0','','','.p-blog-index'),(123422,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-color','#bdbdbd','','','.b-multi-page-checkout'),(123423,'printshop-mobile','.b-info-popup .info-popup div','border-right-color','#e0e0e0','','','.b-info-popup'),(123424,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-color','#092964','','','.b-multi-page-checkout'),(123425,'printshop-mobile','.w-promo-code .holder','border-right-color','#e0e0e0','','','.w-promo-code'),(123426,'printshop-mobile','.testimonials .review','border-right-color','transparent','3','',''),(123427,'printshop-mobile','.b-pagination .pagination .prev-pages','border-right-color','#e0e0e0','','','.b-pagination'),(123428,'printshop-mobile','.b-pagination .pagination .prev','border-right-color','#e0e0e0','','','.b-pagination'),(123429,'printshop-mobile','.b-pagination .pagination .page-number','border-right-color','#e0e0e0','','','.b-pagination'),(123430,'printshop-mobile','.b-pagination .pagination .next-pages','border-right-color','#e0e0e0','','','.b-pagination'),(123431,'printshop-mobile','.b-pagination .pagination .next','border-right-color','#e0e0e0','','','.b-pagination'),(123432,'printshop-mobile','.p-account-history .orders-table .item','border-right-color','#ccc','720','','.p-account-history'),(123433,'printshop-mobile','.p-account-index .orders-table .item','border-right-color','#ccc','720','','.p-account-index'),(123434,'printshop-mobile','.w-cart .cart-content','border-right-color','#cccccc','','','.w-cart'),(123435,'printshop-mobile','.w-product-wedding-registry-button .btn','border-right-color','#183d78','4','','.w-product-wedding-registry-button'),(123436,'printshop-mobile','.p-reviews-info .review-info-text','border-right-color','#fff','4','','.p-reviews-info'),(123437,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-right-color','#e0e0e0','3','','.b-form'),(123438,'printshop-mobile','.b-pagination .pagination a','border-right-color','#e0e0e0','','','.b-pagination'),(123439,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-right-color','#ccc','','','.b-slick'),(123440,'printshop-mobile','.w-socials > li','border-right-color','#dedede','','','.w-socials'),(123441,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-right-color','#e0e0e0','','',''),(123442,'printshop-mobile','.w-currencies .currencies-title','border-right-color','#092964','','','.w-currencies'),(123443,'printshop-mobile','.w-compare-box-item .checkbox:checked + span','border-right-color','#04a440','','','.w-compare-box-item'),(123444,'printshop-mobile','.w-compare-box-item .checkbox + span','border-right-color','#bdbdbd','','','.w-compare-box-item'),(123445,'printshop-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-color','#898989','','','.b-compare'),(123446,'printshop-mobile','.w-cart-products .checkout-attention-message','border-right-color','#ee4225','','','.w-cart-products'),(123447,'printshop-mobile','.b-quantity .qty-box .smaller','border-right-color','#e0e0e0','','','.b-quantity'),(123448,'printshop-mobile','.b-quantity .qty-box .bigger','border-right-color','#e0e0e0','','','.b-quantity'),(123449,'printshop-mobile','.w-catalog-listing-look .b2b','border-right-color','#e0e0e0','','','.w-catalog-listing-look'),(123450,'printshop-mobile','.btn-3','border-right-color','#183d78','','',''),(123451,'printshop-mobile','.btn','border-right-color','#183d78','','',''),(123452,'printshop-mobile','.b-bottom .popup-box','border-right-color','#d9d9d9','','','.b-bottom'),(123453,'printshop-mobile','.w-languages .select','border-right-color','#e0e0e0','','','.w-languages'),(123454,'printshop-mobile','.w-reviews .review','border-right-color','transparent','3','','.w-reviews'),(123455,'printshop-mobile','.b-form .required-error','border-right-color','#ed4224','','','.b-form'),(123456,'printshop-mobile','.b-data-table table.dataTable.no-footer','border-right-color','#e0e0e0','','','.b-data-table'),(123457,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','#e0e0e0','','','.b-dropdown'),(123458,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','#e0e0e0','','','.b-dropdown'),(123459,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','#e0e0e0','','','.b-dropdown'),(123460,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','#e0e0e0','','','.b-dropdown'),(123461,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','#e0e0e0','','','.b-dropdown'),(123462,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','#e0e0e0','','','.b-dropdown'),(123463,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-right-color','#ffffff','','','.b-menu-style-2'),(123464,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-right-color','#ffffff','','','.b-menu-style-2'),(123465,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-right-color','#ffffff','','','.b-menu-style-2'),(123466,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-right-color','#ffffff','','','.b-menu-style-2'),(123467,'printshop-mobile','.b-messages .content_management_attach button','border-right-color','#183d78','','','.b-messages'),(123468,'printshop-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-color','#e0e0e0','','','.b-messages'),(123469,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-color','#e0e0e0','','','.b-select-suggest'),(123470,'printshop-mobile','.b-select-suggest .select2-search input','border-right-color','#e0e0e0','','','.b-select-suggest'),(123471,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','border-right-color','#e0e0e0','','','.b-select-suggest'),(123472,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-color','#e0e0e0','','','.b-select-suggest'),(123473,'printshop-mobile','.b-select-suggest .select2-drop','border-right-color','#e0e0e0','','','.b-select-suggest'),(123474,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-color','#e0e0e0','','','.b-select-suggest'),(123475,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-color','#e0e0e0','','','.b-select-suggest'),(123476,'printshop-mobile','.b-select-suggest .select2-drop-active','border-right-color','#e0e0e0','','','.b-select-suggest'),(123477,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-right-color','#e0e0e0','','','.b-select-suggest'),(123478,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-color','#e0e0e0','','','.b-select-suggest'),(123479,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-color','#e0e0e0','','','.b-trade-approval'),(123480,'printshop-mobile','.b-upload-file .snapshot','border-right-color','#757575','','','.b-upload-file'),(123481,'printshop-mobile','.b-upload-file .upload-file-template','border-right-color','#e0e0e0','','','.b-upload-file'),(123482,'printshop-mobile','.b-upload-files .upload-files','border-right-color','#e0e0e0','','','.b-upload-files'),(123483,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-right-color','#e0e0e0','','','.batchPr'),(123484,'printshop-mobile','.batchPr .checkbox input + span','border-right-color','#e0e0e0','','','.batchPr'),(123485,'printshop-mobile','.batchPr .checkbox input + span','border-right-color','#e0e0e0','','','.batchPr'),(123486,'printshop-mobile','.batchPr .w-batch-selected-products','border-right-color','#e0e0e0','','','.batchPr'),(123487,'printshop-mobile','.batchPr .checkbox input:checked + span','border-right-color','#1428a0','','','.batchPr'),(123488,'printshop-mobile','.p-account-samples-history .orders-table .item','border-right-color','#e0e0e0','','','.p-account-samples-history'),(123489,'printshop-mobile','.p-account-samples-history .orders-table .item','border-right-color','#e0e0e0','','','.p-account-samples-history'),(123490,'printshop-mobile','.p-account-samples-history .orders-table .item','border-right-color','#e0e0e0','','','.p-account-samples-history'),(123491,'printshop-mobile','.p-account-samples-history .orders-table .item','border-right-color','#e0e0e0','','','.p-account-samples-history'),(123492,'printshop-mobile','.p-account-samples-history .orders-table .item','border-right-color','#e0e0e0','','','.p-account-samples-history'),(123493,'printshop-mobile','.p-account-samples-history .orders-table .item','border-right-color','#e0e0e0','','','.p-account-samples-history'),(123494,'printshop-mobile','.p-catalog-product .prev-product','border-right-color','#e0e0e0','','','.p-catalog-product'),(123495,'printshop-mobile','.p-catalog-product .pn-image','border-right-color','#e0e0e0','3','','.p-catalog-product'),(123496,'printshop-mobile','.p-payer-order-confirmation .input-wrapper','border-right-color','#e0e0e0','','','.p-payer-order-confirmation'),(123497,'printshop-mobile','.p-payer-order-pay .input-wrapper','border-right-color','#e0e0e0','','','.p-payer-order-pay'),(123498,'printshop-mobile','.w-account-address-book .btn-del','border-right-color','#c4c4c4','','','.w-account-address-book'),(123499,'printshop-mobile','.w-account-address-book .wrap','border-right-color','#c4c4c4','','','.w-account-address-book'),(123500,'printshop-mobile','.w-account-address-book .btn-edit','border-right-color','#c4c4c4','','','.w-account-address-book'),(123501,'printshop-mobile','.w-account-personal-catalog .list-switcher a','border-right-color','#e0e0e0','2','','.w-account-personal-catalog'),(123502,'printshop-mobile','.w-cart-compare .product-block td','border-right-color','#e0e0e0','','','.w-cart-compare'),(123503,'printshop-mobile','.w-cart-compare .attributes-block td','border-right-color','#e0e0e0','','','.w-cart-compare'),(123504,'printshop-mobile','.w-cart-compare .price-block td','border-right-color','#e0e0e0','','','.w-cart-compare'),(123505,'printshop-mobile','.w-cart-compare .cart-cell > div','border-right-color','#e0e0e0','','','.w-cart-compare'),(123506,'printshop-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-right-color','#ffffff','','','.w-catalog-compare'),(123507,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','border-right-color','#e0e0e0','2','','.w-catalog-compare'),(123508,'printshop-mobile','.w-catalog-compare td:first-child','border-right-color','#e0e0e0','','','.w-catalog-compare'),(123509,'printshop-mobile','.w-catalog-paging ','border-right-color','#e0e0e0','2','','.w-catalog-paging'),(123510,'printshop-mobile','.w-catalog-paging .prev','border-right-color','#e0e0e0','','','.w-catalog-paging'),(123511,'printshop-mobile','.w-catalog-paging .next','border-right-color','#e0e0e0','','','.w-catalog-paging'),(123512,'printshop-mobile','.w-catalog-paging .next-pages','border-right-color','#e0e0e0','','','.w-catalog-paging'),(123513,'printshop-mobile','.w-catalog-paging .prev-pages','border-right-color','#e0e0e0','','','.w-catalog-paging'),(123514,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-color','#e0e0e0','','','.w-catalog-paging'),(123515,'printshop-mobile','.w-catalog-paging .page-number','border-right-color','#e0e0e0','','','.w-catalog-paging'),(123516,'printshop-mobile','.w-checkout-shipping-choice label:last-child span','border-right-color','#183d78','','','.w-checkout-shipping-choice'),(123517,'printshop-mobile','.w-product-customers-activity .customers-activity','border-right-color','#e0e0e0','','','.w-product-customers-activity'),(123518,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-right-color','#ee4225','','','.w-promotions'),(123519,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-color','#ee4225','','','.w-promotions'),(123520,'printshop-mobile','.w-promotions .promo-salemaker .discount','border-right-color','#ff6716','','','.w-promotions'),(123521,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border-right-color','#ee4225','','','.w-promotions'),(123522,'printshop-mobile','.w-reviews-content .review','border-right-color','transparent','3','','.w-reviews-content'),(123523,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-color','#ccc','','','.w-upload-customer-id-upload-customer-id-form'),(123524,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-right-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(123525,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-right-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(123526,'printshop-mobile','.b-data-table table.dataTable.no-footer','border-right-color_important','important','','','.b-data-table'),(123527,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(123528,'printshop-mobile','.w-sale .sale-holder','border-right-width','2','','','.w-sale'),(123529,'printshop-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','border-right-width','2','','','.b-product-images'),(123530,'printshop-mobile','.w-product-wedding-registry-button .btn','border-right-width','2','3','','.w-product-wedding-registry-button'),(123531,'printshop-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-right-width','2','2','','.b-product-images'),(123532,'printshop-mobile','.w-currencies .select','border-right-width','1','','','.w-currencies'),(123533,'printshop-mobile','.w-catalog-listing-look .b2b','border-right-width','1','','','.w-catalog-listing-look'),(123534,'printshop-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-width','1','','','.b-compare'),(123535,'printshop-mobile','.w-catalog-listing-look .list','border-right-width','1','','','.w-catalog-listing-look'),(123536,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-width','1','','','.b-multi-page-checkout'),(123537,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-width','2','','','.p-blog-index'),(123538,'printshop-mobile','textarea','border-right-width','2','','',''),(123539,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(123540,'printshop-mobile','.b-info-popup .info-popup div','border-right-width','1','','','.b-info-popup'),(123541,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(123542,'printshop-mobile','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(123543,'printshop-mobile','.testimonials .review','border-right-width','10','3','',''),(123544,'printshop-mobile','.b-pagination .pagination .prev-pages','border-right-width','1','','','.b-pagination'),(123545,'printshop-mobile','.b-pagination .pagination .prev','border-right-width','1','','','.b-pagination'),(123546,'printshop-mobile','.p-wedding-registry-manage .wr-search button','border-right-width','0','','','.p-wedding-registry-manage'),(123547,'printshop-mobile','.b-pagination .pagination .page-number','border-right-width','1','','','.b-pagination'),(123548,'printshop-mobile','.b-pagination .pagination .next-pages','border-right-width','1','','','.b-pagination'),(123549,'printshop-mobile','.b-pagination .pagination .next','border-right-width','1','','','.b-pagination'),(123550,'printshop-mobile','.b-pagination .pagination span','border-right-width','1','2','','.b-pagination'),(123551,'printshop-mobile','.p-account-history .orders-table .item','border-right-width','1','720','','.p-account-history'),(123552,'printshop-mobile','.p-account-index .orders-table .item','border-right-width','1','720','','.p-account-index'),(123553,'printshop-mobile','.w-cart .cart-content','border-right-width','1','','','.w-cart'),(123554,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','border-right-width','0','','','.w-list-type-2_2'),(123555,'printshop-mobile','.w-product-wedding-registry-button .btn','border-right-width','2','4','','.w-product-wedding-registry-button'),(123556,'printshop-mobile','.p-reviews-info .review-info-text','border-right-width','5','4','','.p-reviews-info'),(123557,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-right-width','2','3','','.b-form'),(123558,'printshop-mobile','.b-pagination .pagination a','border-right-width','1','','','.b-pagination'),(123559,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-right-width','2','','','.b-slick'),(123560,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-right-width','2','','',''),(123561,'printshop-mobile','.w-search .search-input','border-right-width','0','','','.w-search'),(123562,'printshop-mobile','.w-currencies .currencies-title','border-right-width','2','','','.w-currencies'),(123563,'printshop-mobile','.w-compare-box-item .checkbox:checked + span','border-right-width','1','','','.w-compare-box-item'),(123564,'printshop-mobile','.w-compare-box-item .checkbox + span','border-right-width','1','','','.w-compare-box-item'),(123565,'printshop-mobile','.b-slick .slick-vertical .slick-slide','border-right-width','1','','','.b-slick'),(123566,'printshop-mobile','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(123567,'printshop-mobile','.b-quantity .qty-box .bigger','border-right-width','2','','','.b-quantity'),(123568,'printshop-mobile','.b-quantity .qty-box .smaller','border-right-width','2','','','.b-quantity'),(123569,'printshop-mobile','.w-catalog-listing-look .grid','border-right-width','1','','','.w-catalog-listing-look'),(123570,'printshop-mobile','.w-list-type-2 .button-wishlist button','border-right-width','0','','','.w-list-type-2'),(123571,'printshop-mobile','.btn-3','border-right-width','2','','',''),(123572,'printshop-mobile','.b-autocomplete .ui-autocomplete li','border-right-width','1','','','.b-autocomplete'),(123573,'printshop-mobile','.btn','border-right-width','2','','',''),(123574,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','border-right-width','0','','','.w-list-type-1_3'),(123575,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','border-right-width','0','','','.w-list-type-1_2'),(123576,'printshop-mobile','.b-bottom .popup-box','border-right-width','1','','','.b-bottom'),(123577,'printshop-mobile','.w-list-type-1 .button-wishlist button','border-right-width','0','','','.w-list-type-1'),(123578,'printshop-mobile','.w-filters .ui-slider','border-right-width','0','','','.w-filters'),(123579,'printshop-mobile','.w-filters .ui-slider-handle','border-right-width','0','','','.w-filters'),(123580,'printshop-mobile','.w-filters .ui-slider-range','border-right-width','0','','','.w-filters'),(123581,'printshop-mobile','.w-languages .select','border-right-width','1','','','.w-languages'),(123582,'printshop-mobile','.w-reviews .review','border-right-width','10','3','','.w-reviews'),(123583,'printshop-mobile','.w-search .button-search','border-right-width','0','','','.w-search'),(123584,'printshop-mobile','.w-socials > li','border-right-width','1','','','.w-socials'),(123585,'printshop-mobile','.b-form .required-error','border-right-width','1','','','.b-form'),(123586,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(123587,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(123588,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(123589,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(123590,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(123591,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(123592,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-right-width','1','','','.b-menu-style-2'),(123593,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-right-width','3','','','.b-menu-style-2'),(123594,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-right-width','1','','','.b-menu-style-2'),(123595,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-right-width','3','','','.b-menu-style-2'),(123596,'printshop-mobile','.b-messages .content_management_attach button','border-right-width','1','','','.b-messages'),(123597,'printshop-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-width','2','','','.b-messages'),(123598,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','border-right-width','2','','','.b-select-suggest'),(123599,'printshop-mobile','.b-select-suggest .select2-search input','border-right-width','1','','','.b-select-suggest'),(123600,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-width','1','','','.b-select-suggest'),(123601,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(123602,'printshop-mobile','.b-select-suggest .select2-drop-active','border-right-width','1','','','.b-select-suggest'),(123603,'printshop-mobile','.b-select-suggest .select2-drop','border-right-width','1','','','.b-select-suggest'),(123604,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-right-width','1','','','.b-select-suggest'),(123605,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-width','1','','','.b-select-suggest'),(123606,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-width','1','','','.b-select-suggest'),(123607,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(123608,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-width','2','','','.b-trade-approval'),(123609,'printshop-mobile','.b-upload-file .snapshot','border-right-width','1','','','.b-upload-file'),(123610,'printshop-mobile','.b-upload-file .upload-file-template','border-right-width','1','','','.b-upload-file'),(123611,'printshop-mobile','.b-upload-files .upload-files','border-right-width','1','','','.b-upload-files'),(123612,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-right-width','1','','','.batchPr'),(123613,'printshop-mobile','.batchPr .checkbox input + span','border-right-width','1','','','.batchPr'),(123614,'printshop-mobile','.batchPr .checkbox input + span','border-right-width','1','','','.batchPr'),(123615,'printshop-mobile','.batchPr .checkbox input:checked + span','border-right-width','1','','','.batchPr'),(123616,'printshop-mobile','.batchPr .w-batch-selected-products','border-right-width','1','','','.batchPr'),(123617,'printshop-mobile','.p-account-samples-history .orders-table .item','border-right-width','1','','','.p-account-samples-history'),(123618,'printshop-mobile','.p-account-samples-history .orders-table .item','border-right-width','1','','','.p-account-samples-history'),(123619,'printshop-mobile','.p-account-samples-history .orders-table .item','border-right-width','1','','','.p-account-samples-history'),(123620,'printshop-mobile','.p-account-samples-history .orders-table .item','border-right-width','1','','','.p-account-samples-history'),(123621,'printshop-mobile','.p-account-samples-history .orders-table .item','border-right-width','1','','','.p-account-samples-history'),(123622,'printshop-mobile','.p-account-samples-history .orders-table .item','border-right-width','1','','','.p-account-samples-history'),(123623,'printshop-mobile','.p-catalog-product .prev-product','border-right-width','1','','','.p-catalog-product'),(123624,'printshop-mobile','.p-catalog-product .pn-image','border-right-width','2','3','','.p-catalog-product'),(123625,'printshop-mobile','.p-payer-order-confirmation .input-wrapper','border-right-width','2','','','.p-payer-order-confirmation'),(123626,'printshop-mobile','.p-payer-order-pay .input-wrapper','border-right-width','2','','','.p-payer-order-pay'),(123627,'printshop-mobile','.w-account-address-book .wrap','border-right-width','1','','','.w-account-address-book'),(123628,'printshop-mobile','.w-account-address-book .btn-edit','border-right-width','1','','','.w-account-address-book'),(123629,'printshop-mobile','.w-account-address-book .btn-del','border-right-width','1','','','.w-account-address-book'),(123630,'printshop-mobile','.w-account-personal-catalog .list-switcher a','border-right-width','1','2','','.w-account-personal-catalog'),(123631,'printshop-mobile','.w-cart-compare .attributes-block td','border-right-width','1','','','.w-cart-compare'),(123632,'printshop-mobile','.w-cart-compare .cart-cell > div','border-right-width','1','','','.w-cart-compare'),(123633,'printshop-mobile','.w-cart-compare .product-block td','border-right-width','1','','','.w-cart-compare'),(123634,'printshop-mobile','.w-cart-compare .price-block td','border-right-width','1','','','.w-cart-compare'),(123635,'printshop-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-right-width','1','','','.w-catalog-compare'),(123636,'printshop-mobile','.w-catalog-compare td:first-child','border-right-width','1','','','.w-catalog-compare'),(123637,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','border-right-width','1','2','','.w-catalog-compare'),(123638,'printshop-mobile','.w-catalog-paging ','border-right-width','1','2','','.w-catalog-paging'),(123639,'printshop-mobile','.w-catalog-paging .prev','border-right-width','1','','','.w-catalog-paging'),(123640,'printshop-mobile','.w-catalog-paging .page-number','border-right-width','1','','','.w-catalog-paging'),(123641,'printshop-mobile','.w-catalog-paging .next','border-right-width','1','','','.w-catalog-paging'),(123642,'printshop-mobile','.w-catalog-paging .next-pages','border-right-width','1','','','.w-catalog-paging'),(123643,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-width','1','','','.w-catalog-paging'),(123644,'printshop-mobile','.w-catalog-paging .prev-pages','border-right-width','1','','','.w-catalog-paging'),(123645,'printshop-mobile','.w-checkout-shipping-choice label:last-child span','border-right-width','2','','','.w-checkout-shipping-choice'),(123646,'printshop-mobile','.w-product-customers-activity .customers-activity','border-right-width','1','','','.w-product-customers-activity'),(123647,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-right-width','1','','','.w-promotions'),(123648,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-width','1','','','.w-promotions'),(123649,'printshop-mobile','.w-promotions .promo-salemaker .discount','border-right-width','1','','','.w-promotions'),(123650,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border-right-width','1','','','.w-promotions'),(123651,'printshop-mobile','.w-reviews-content .review','border-right-width','12','3','','.w-reviews-content'),(123652,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(123653,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-right-width','1','','','.w-wedding-registry-widgets-photos'),(123654,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-right-width','1','','','.w-wedding-registry-widgets-photos'),(123655,'printshop-mobile','.p-account-history .orders-table','border-top','none','','','.p-account-history'),(123656,'printshop-mobile','.p-checkout-index .shipping-estimator .info','border-top','none','','','.p-checkout-index'),(123657,'printshop-mobile','.p-account-index .orders-table','border-top','none','','','.p-account-index'),(123658,'printshop-mobile','.b-select-suggest .select2-drop-active','border-top','none','','','.b-select-suggest'),(123659,'printshop-mobile','.p-account-samples-history .orders-table','border-top','none','','','.p-account-samples-history'),(123660,'printshop-mobile','.p-account-samples-history .orders-table','border-top','none','','','.p-account-samples-history'),(123661,'printshop-mobile','.p-account-samples-history .orders-table','border-top','none','','','.p-account-samples-history'),(123662,'printshop-mobile','.p-account-samples-history .orders-table','border-top','none','','','.p-account-samples-history'),(123663,'printshop-mobile','.p-account-samples-history .orders-table','border-top','none','','','.p-account-samples-history'),(123664,'printshop-mobile','.p-account-samples-history .orders-table','border-top','none','','','.p-account-samples-history'),(123665,'printshop-mobile','.w-catalog-listing-look .list','border-top-color','#e0e0e0','','','.w-catalog-listing-look'),(123666,'printshop-mobile','.b-social-login .social-login-text-2','border-top-color','#ddd','4','','.b-social-login'),(123667,'printshop-mobile','.b-social-login .social-login-text-2','border-top-color','#ddd','3','','.b-social-login'),(123668,'printshop-mobile','.w-sale .sale-holder','border-top-color','#ccc','','','.w-sale'),(123669,'printshop-mobile','.w-menu-slider > ul > li > ul','border-top-color','#ffffff','','','.w-menu-slider'),(123670,'printshop-mobile','.w-product-wedding-registry-button .btn','border-top-color','#183d78','3','','.w-product-wedding-registry-button'),(123671,'printshop-mobile','.w-product-sale-ends .left-text-left','border-top-color','#ccc','','','.w-product-sale-ends'),(123672,'printshop-mobile','.w-product-sale-ends .left-text-right','border-top-color','#ccc','','','.w-product-sale-ends'),(123673,'printshop-mobile','.w-cart-products .checkout-attention-message','border-top-color','#ee4225','','','.w-cart-products'),(123674,'printshop-mobile','.w-cart .cart-content','border-top-color','#cccccc','','','.w-cart'),(123675,'printshop-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-top-color','#bdbdbd','2','','.b-product-images'),(123676,'printshop-mobile','.b-pagination .pagination span','border-top-color','#e0e0e0','2','','.b-pagination'),(123677,'printshop-mobile','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-color','#e0e0e0','','','.w-product-in-bundles'),(123678,'printshop-mobile','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-color','#e0e0e0','','','.w-product-bundle'),(123679,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-color','#e0e0e0','','','.b-multi-page-checkout'),(123680,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-color','#e0e0e0','','','.p-blog-index'),(123681,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-color','#bdbdbd','','','.b-multi-page-checkout'),(123682,'printshop-mobile','.btn-3','border-top-color','#183d78','','',''),(123683,'printshop-mobile','.btn','border-top-color','#183d78','','',''),(123684,'printshop-mobile','.b-info-popup .info-popup div','border-top-color','#e0e0e0','','','.b-info-popup'),(123685,'printshop-mobile','.w-menu .hided.menu ul li','border-top-color','#0a204a','720','','.w-menu'),(123686,'printshop-mobile','.b-info-popup .info-popup div','border-top-color','#e0e0e0','3','','.b-info-popup'),(123687,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-color','#092964','','','.b-multi-page-checkout'),(123688,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','border-top-color','#e0e0e0','','','.b-multi-page-checkout'),(123689,'printshop-mobile','.view-all','border-top-color','#e0e0e0','3','',''),(123690,'printshop-mobile','.p-wedding-registry-manage .remove','border-top-color','#e0e0e0','','','.p-wedding-registry-manage'),(123691,'printshop-mobile','.w-promo-code .holder','border-top-color','#e0e0e0','','','.w-promo-code'),(123692,'printshop-mobile','.testimonials .review','border-top-color','#eeeeee','3','',''),(123693,'printshop-mobile','.b-pagination .pagination .page-number','border-top-color','#e0e0e0','','','.b-pagination'),(123694,'printshop-mobile','.b-pagination .pagination .prev-pages','border-top-color','#e0e0e0','','','.b-pagination'),(123695,'printshop-mobile','.b-pagination .pagination .prev','border-top-color','#e0e0e0','','','.b-pagination'),(123696,'printshop-mobile','.b-pagination .pagination .next-pages','border-top-color','#e0e0e0','','','.b-pagination'),(123697,'printshop-mobile','.b-pagination .pagination .next','border-top-color','#e0e0e0','','','.b-pagination'),(123698,'printshop-mobile','.p-account-history .orders-table .item','border-top-color','#ccc','720','','.p-account-history'),(123699,'printshop-mobile','.p-account-history .orders-table .td-alignright','border-top-color','#ccc','720','','.p-account-history'),(123700,'printshop-mobile','.p-account-index .orders-table .item','border-top-color','#ccc','720','','.p-account-index'),(123701,'printshop-mobile','.p-account-index .orders-table .td-alignright','border-top-color','#ccc','720','','.p-account-index'),(123702,'printshop-mobile','.w-list-type-2_2 .compare-box-item','border-top-color','#e0e0e0','','','.w-list-type-2_2'),(123703,'printshop-mobile','.w-list-type-2_2 .buttons','border-top-color','#e0e0e0','','','.w-list-type-2_2'),(123704,'printshop-mobile','.w-product-wedding-registry-button .btn','border-top-color','#183d78','4','','.w-product-wedding-registry-button'),(123705,'printshop-mobile','.p-reviews-info .review-info-text','border-top-color','#fff','4','','.p-reviews-info'),(123706,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-color','#e0e0e0','3','','.b-form'),(123707,'printshop-mobile','.b-form .form-buttons','border-top-color','#e0e0e0','','','.b-form'),(123708,'printshop-mobile','.p-wedding-registry-index .search-list','border-top-color','#e0e0e0','3','','.p-wedding-registry-index'),(123709,'printshop-mobile','.b-table .table .headings + tr ~ tr td','border-top-color','#e0e0e0','','','.b-table'),(123710,'printshop-mobile','.b-pagination .pagination a','border-top-color','#e0e0e0','','','.b-pagination'),(123711,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-color','#ccc','','','.b-slick'),(123712,'printshop-mobile','.w-languages .select','border-top-color','#e0e0e0','','','.w-languages'),(123713,'printshop-mobile','.w-socials > li','border-top-color','#dedede','','','.w-socials'),(123714,'printshop-mobile','.p-checkout-index .shipping-method .item + .item','border-top-color','#e0e0e0','','','.p-checkout-index'),(123715,'printshop-mobile','.w-currencies .select','border-top-color','#e0e0e0','','','.w-currencies'),(123716,'printshop-mobile','.b-bottom .popup-buttons','border-top-color','#d9d9d9','','','.b-bottom'),(123717,'printshop-mobile','.w-currencies .currencies-title','border-top-color','#092964','','','.w-currencies'),(123718,'printshop-mobile','.w-compare-box-item .checkbox:checked + span','border-top-color','#04a440','','','.w-compare-box-item'),(123719,'printshop-mobile','.w-compare-box-item .checkbox + span','border-top-color','#bdbdbd','','','.w-compare-box-item'),(123720,'printshop-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-color','#898989','','','.b-compare'),(123721,'printshop-mobile','.w-sale .left-text-left','border-top-color','#ccc','','','.w-sale'),(123722,'printshop-mobile','.w-sale .left-text-right','border-top-color','#ccc','','','.w-sale'),(123723,'printshop-mobile','.b-quantity .qty-box .smaller','border-top-color','#e0e0e0','','','.b-quantity'),(123724,'printshop-mobile','.b-quantity .qty-box .bigger','border-top-color','#e0e0e0','','','.b-quantity'),(123725,'printshop-mobile','.w-catalog-listing-look .b2b','border-top-color','#e0e0e0','','','.w-catalog-listing-look'),(123726,'printshop-mobile','.w-catalog-listing-look .grid','border-top-color','#e0e0e0','','','.w-catalog-listing-look'),(123727,'printshop-mobile','.w-list-type-2 .buttons','border-top-color','#e0e0e0','','','.w-list-type-2'),(123728,'printshop-mobile','.w-list-type-2 .compare-box-item','border-top-color','#e0e0e0','','','.w-list-type-2'),(123729,'printshop-mobile','.w-list-type-2 .item','border-top-color','#e0e0e0','1','','.w-list-type-2'),(123730,'printshop-mobile','.w-list-type-1_3 .compare-box-item','border-top-color','#e0e0e0','','','.w-list-type-1_3'),(123731,'printshop-mobile','.w-list-type-1_3 .buttons','border-top-color','#e0e0e0','','','.w-list-type-1_3'),(123732,'printshop-mobile','.w-list-type-1_2 .buttons','border-top-color','#e0e0e0','','','.w-list-type-1_2'),(123733,'printshop-mobile','.w-list-type-1_2 .compare-box-item','border-top-color','#e0e0e0','','','.w-list-type-1_2'),(123734,'printshop-mobile','.w-list-type-1 .compare-box-item','border-top-color','#e0e0e0','','','.w-list-type-1'),(123735,'printshop-mobile','.b-bottom .popup-box','border-top-color','#d9d9d9','','','.b-bottom'),(123736,'printshop-mobile','.w-list-type-1 .buttons','border-top-color','#e0e0e0','','','.w-list-type-1'),(123737,'printshop-mobile','.w-reviews .review','border-top-color','#fff','3','','.w-reviews'),(123738,'printshop-mobile','.w-search .item + .item','border-top-color','#cccccc','','','.w-search'),(123739,'printshop-mobile','.b-form .required-error','border-top-color','#ed4224','','','.b-form'),(123740,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-top-color','#e0e0e0','','',''),(123741,'printshop-mobile','textarea','border-top-color','#e0e0e0','','',''),(123742,'printshop-mobile','.b-info div + .info','border-top-color','#e0e0e0','','','.b-info'),(123743,'printshop-mobile','.b-products-listing .products-listing .compare','border-top-color','#e0e0e0','','','.b-products-listing'),(123744,'printshop-mobile','.b-data-table table.dataTable tbody td','border-top-color','#e0e0e0','','','.b-data-table'),(123745,'printshop-mobile','.b-data-table table.dataTable.no-footer','border-top-color','#e0e0e0','','','.b-data-table'),(123746,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','#e0e0e0','','','.b-dropdown'),(123747,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','#e0e0e0','','','.b-dropdown'),(123748,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','#e0e0e0','','','.b-dropdown'),(123749,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','#e0e0e0','','','.b-dropdown'),(123750,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','#e0e0e0','','','.b-dropdown'),(123751,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','#e0e0e0','','','.b-dropdown'),(123752,'printshop-mobile','.b-email .qty','border-top-color','#e0e0e0','','','.b-email'),(123753,'printshop-mobile','.b-email .name','border-top-color','#e0e0e0','','','.b-email'),(123754,'printshop-mobile','.b-email .totals-table','border-top-color','#e0e0e0','','','.b-email'),(123755,'printshop-mobile','.b-email .price','border-top-color','#e0e0e0','','','.b-email'),(123756,'printshop-mobile','.b-email .image','border-top-color','#e0e0e0','','','.b-email'),(123757,'printshop-mobile','.b-email .totals-table','border-top-color','#e0e0e0','','','.b-email'),(123758,'printshop-mobile','.b-email .image','border-top-color','#e0e0e0','','','.b-email'),(123759,'printshop-mobile','.b-email .price','border-top-color','#e0e0e0','','','.b-email'),(123760,'printshop-mobile','.b-email .model','border-top-color','#e0e0e0','','','.b-email'),(123761,'printshop-mobile','.b-email .name','border-top-color','#e0e0e0','','','.b-email'),(123762,'printshop-mobile','.b-email .image','border-top-color','#e0e0e0','','','.b-email'),(123763,'printshop-mobile','.b-email .model','border-top-color','#e0e0e0','','','.b-email'),(123764,'printshop-mobile','.b-email .image','border-top-color','#e0e0e0','','','.b-email'),(123765,'printshop-mobile','.b-email .price','border-top-color','#e0e0e0','','','.b-email'),(123766,'printshop-mobile','.b-email .price','border-top-color','#e0e0e0','','','.b-email'),(123767,'printshop-mobile','.b-email .qty','border-top-color','#e0e0e0','','','.b-email'),(123768,'printshop-mobile','.b-email .model','border-top-color','#e0e0e0','','','.b-email'),(123769,'printshop-mobile','.b-email .name','border-top-color','#e0e0e0','','','.b-email'),(123770,'printshop-mobile','.b-email .totals-table','border-top-color','#e0e0e0','','','.b-email'),(123771,'printshop-mobile','.b-email .price','border-top-color','#e0e0e0','','','.b-email'),(123772,'printshop-mobile','.b-email .name','border-top-color','#e0e0e0','','','.b-email'),(123773,'printshop-mobile','.b-email .qty','border-top-color','#e0e0e0','','','.b-email'),(123774,'printshop-mobile','.b-email .totals-table','border-top-color','#e0e0e0','','','.b-email'),(123775,'printshop-mobile','.b-email .image','border-top-color','#e0e0e0','','','.b-email'),(123776,'printshop-mobile','.b-email .name','border-top-color','#e0e0e0','','','.b-email'),(123777,'printshop-mobile','.b-email .totals-table','border-top-color','#e0e0e0','','','.b-email'),(123778,'printshop-mobile','.b-email .qty','border-top-color','#e0e0e0','','','.b-email'),(123779,'printshop-mobile','.b-email .qty','border-top-color','#e0e0e0','','','.b-email'),(123780,'printshop-mobile','.b-email .model','border-top-color','#e0e0e0','','','.b-email'),(123781,'printshop-mobile','.b-email .name','border-top-color','#e0e0e0','','','.b-email'),(123782,'printshop-mobile','.b-email .qty','border-top-color','#e0e0e0','','','.b-email'),(123783,'printshop-mobile','.b-email .model','border-top-color','#e0e0e0','','','.b-email'),(123784,'printshop-mobile','.b-email .price','border-top-color','#e0e0e0','','','.b-email'),(123785,'printshop-mobile','.b-email .totals-table','border-top-color','#e0e0e0','','','.b-email'),(123786,'printshop-mobile','.b-email .image','border-top-color','#e0e0e0','','','.b-email'),(123787,'printshop-mobile','.b-email .model','border-top-color','#e0e0e0','','','.b-email'),(123788,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-top-color','#ffffff','','','.b-menu-style-2'),(123789,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-top-color','#ffffff','','','.b-menu-style-2'),(123790,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','border-top-color','#1a61ad','','','.b-menu-style-2'),(123791,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-top-color','#ffffff','','','.b-menu-style-2'),(123792,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-top-color','#ffffff','','','.b-menu-style-2'),(123793,'printshop-mobile','.b-messages .messMenuButtonTop','border-top-color','#e0e0e0','','','.b-messages'),(123794,'printshop-mobile','.b-messages .msv_btn','border-top-color','#e0e0e0','','','.b-messages'),(123795,'printshop-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-color','#e0e0e0','','','.b-messages'),(123796,'printshop-mobile','.b-messages .email-heading','border-top-color','#e0e0e0','','','.b-messages'),(123797,'printshop-mobile','.b-messages .dataTable','border-top-color','#e0e0e0','','','.b-messages'),(123798,'printshop-mobile','.b-messages .messages-menu li + li','border-top-color','#e0e0e0','','','.b-messages'),(123799,'printshop-mobile','.b-messages .content_management_attach button','border-top-color','#183d78','','','.b-messages'),(123800,'printshop-mobile','.b-messages .content_management_attach','border-top-color','#e0e0e0','','','.b-messages'),(123801,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','border-top-color','#e0e0e0','','','.b-select-suggest'),(123802,'printshop-mobile','.b-select-suggest .select2-search input','border-top-color','#e0e0e0','','','.b-select-suggest'),(123803,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-color','#e0e0e0','','','.b-select-suggest'),(123804,'printshop-mobile','.b-select-suggest .select2-drop-auto-width','border-top-color','#e0e0e0','','','.b-select-suggest'),(123805,'printshop-mobile','.b-select-suggest .select2-drop','border-top-color','#e0e0e0','','','.b-select-suggest'),(123806,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-top-color','#e0e0e0','','','.b-select-suggest'),(123807,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-color','#e0e0e0','','','.b-select-suggest'),(123808,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-color','#e0e0e0','','','.b-select-suggest'),(123809,'printshop-mobile','.b-select-suggest .select2-drop-active','border-top-color','#e0e0e0','','','.b-select-suggest'),(123810,'printshop-mobile','.b-select-suggest .select2-drop.select2-drop-above','border-top-color','#e0e0e0','','','.b-select-suggest'),(123811,'printshop-mobile','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-color','#e0e0e0','','','.b-select-suggest'),(123812,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-color','#e0e0e0','','','.b-select-suggest'),(123813,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-color','#e0e0e0','','','.b-select-suggest'),(123814,'printshop-mobile','.b-table-list .table-list td','border-top-color','#e0e0e0','','','.b-table-list'),(123815,'printshop-mobile','.b-table-list .table-list td','border-top-color','#e0e0e0','','','.b-table-list'),(123816,'printshop-mobile','.b-table-list .table-list td','border-top-color','#e0e0e0','','','.b-table-list'),(123817,'printshop-mobile','.b-table-list .table-list td','border-top-color','#e0e0e0','','','.b-table-list'),(123818,'printshop-mobile','.b-table-list .table-list td','border-top-color','#e0e0e0','','','.b-table-list'),(123819,'printshop-mobile','.b-table-list .table-list td','border-top-color','#e0e0e0','','','.b-table-list'),(123820,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','#e0e0e0','','','.b-tracking-numbers'),(123821,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','#e0e0e0','','','.b-tracking-numbers'),(123822,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','#e0e0e0','','','.b-tracking-numbers'),(123823,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','#e0e0e0','','','.b-tracking-numbers'),(123824,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','#e0e0e0','','','.b-tracking-numbers'),(123825,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','#e0e0e0','','','.b-tracking-numbers'),(123826,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-color','#e0e0e0','','','.b-trade-approval'),(123827,'printshop-mobile','.b-upload-file .upload-file-template','border-top-color','#e0e0e0','','','.b-upload-file'),(123828,'printshop-mobile','.b-upload-file .snapshot','border-top-color','#757575','','','.b-upload-file'),(123829,'printshop-mobile','.b-upload-files .upload-files','border-top-color','#e0e0e0','','','.b-upload-files'),(123830,'printshop-mobile','.b-upload-files .added-file','border-top-color','#e0e0e0','','','.b-upload-files'),(123831,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-color','#e0e0e0','','','.batchPr'),(123832,'printshop-mobile','.batchPr .checkbox input + span','border-top-color','#e0e0e0','','','.batchPr'),(123833,'printshop-mobile','.batchPr .checkbox input + span','border-top-color','#e0e0e0','','','.batchPr'),(123834,'printshop-mobile','.batchPr .checkbox input:checked + span','border-top-color','#1428a0','','','.batchPr'),(123835,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .item + .item','border-top-color','#e0e0e0','','','.batchPr'),(123836,'printshop-mobile','.batchPr .w-batch-selected-products','border-top-color','#e0e0e0','','','.batchPr'),(123837,'printshop-mobile','.p-account-samples-history .orders-table .item','border-top-color','#e0e0e0','','','.p-account-samples-history'),(123838,'printshop-mobile','.p-account-samples-history .orders-table .item','border-top-color','#e0e0e0','','','.p-account-samples-history'),(123839,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-color','#e0e0e0','','','.p-account-samples-history'),(123840,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-color','#e0e0e0','','','.p-account-samples-history'),(123841,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-color','#e0e0e0','','','.p-account-samples-history'),(123842,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-color','#e0e0e0','','','.p-account-samples-history'),(123843,'printshop-mobile','.p-account-samples-history .orders-table .item','border-top-color','#e0e0e0','','','.p-account-samples-history'),(123844,'printshop-mobile','.p-account-samples-history .orders-table .item','border-top-color','#e0e0e0','','','.p-account-samples-history'),(123845,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-color','#e0e0e0','','','.p-account-samples-history'),(123846,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-color','#e0e0e0','','','.p-account-samples-history'),(123847,'printshop-mobile','.p-account-samples-history .orders-table .item','border-top-color','#e0e0e0','','','.p-account-samples-history'),(123848,'printshop-mobile','.p-account-samples-history .orders-table .item','border-top-color','#e0e0e0','','','.p-account-samples-history'),(123849,'printshop-mobile','.p-catalog-product .prev-next-product','border-top-color','#e0e0e0','','','.p-catalog-product'),(123850,'printshop-mobile','.p-catalog-product .pn-image','border-top-color','#e0e0e0','','','.p-catalog-product'),(123851,'printshop-mobile','.p-catalog-product .pn-name','border-top-color','#e0e0e0','','','.p-catalog-product'),(123852,'printshop-mobile','.p-catalog-product .pn-image','border-top-color','#e0e0e0','3','','.p-catalog-product'),(123853,'printshop-mobile','.p-payer-order-confirmation .input-wrapper','border-top-color','#e0e0e0','','','.p-payer-order-confirmation'),(123854,'printshop-mobile','.p-payer-order-pay .input-wrapper','border-top-color','#e0e0e0','','','.p-payer-order-pay'),(123855,'printshop-mobile','.w-account-address-book .wrap','border-top-color','#c4c4c4','','','.w-account-address-book'),(123856,'printshop-mobile','.w-account-personal-catalog .list-switcher a','border-top-color','#183d78','2','','.w-account-personal-catalog'),(123857,'printshop-mobile','.w-account-subscription .subscription-variant + .subscription-variant','border-top-color','#ccc','','','.w-account-subscription'),(123858,'printshop-mobile','.w-cart-compare .attributes-block td','border-top-color','#e0e0e0','','','.w-cart-compare'),(123859,'printshop-mobile','.w-cart-compare .price-block td','border-top-color','#e0e0e0','','','.w-cart-compare'),(123860,'printshop-mobile','.w-cart-compare .product-block td','border-top-color','#e0e0e0','','','.w-cart-compare'),(123861,'printshop-mobile','.w-cart-compare .cart-cell > div','border-top-color','#e0e0e0','','','.w-cart-compare'),(123862,'printshop-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-top-color','#ffffff','','','.w-catalog-compare'),(123863,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','border-top-color','#183d78','2','','.w-catalog-compare'),(123864,'printshop-mobile','.w-catalog-paging ','border-top-color','#e0e0e0','2','','.w-catalog-paging'),(123865,'printshop-mobile','.w-catalog-paging .prev','border-top-color','#e0e0e0','','','.w-catalog-paging'),(123866,'printshop-mobile','.w-catalog-paging .next','border-top-color','#e0e0e0','','','.w-catalog-paging'),(123867,'printshop-mobile','.w-catalog-paging .page-number','border-top-color','#e0e0e0','','','.w-catalog-paging'),(123868,'printshop-mobile','.w-catalog-paging .next-pages','border-top-color','#e0e0e0','','','.w-catalog-paging'),(123869,'printshop-mobile','.w-catalog-paging .prev-pages','border-top-color','#e0e0e0','','','.w-catalog-paging'),(123870,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-color','#e0e0e0','','','.w-catalog-paging'),(123871,'printshop-mobile','.w-checkout-shipping .sub-item + .sub-item','border-top-color','#e0e0e0','','','.w-checkout-shipping'),(123872,'printshop-mobile','.w-checkout-shipping-choice span','border-top-color','#183d78','','','.w-checkout-shipping-choice'),(123873,'printshop-mobile','.w-communication-new-topic td','border-top-color','#e0e0e0','','','.w-communication-new-topic'),(123874,'printshop-mobile','.w-communication-post .communication-post','border-top-color','#e0e0e0','','','.w-communication-post'),(123875,'printshop-mobile','.w-delivery-day .left-text-left','border-top-color','#e0e0e0','','','.w-delivery-day'),(123876,'printshop-mobile','.w-delivery-day .left-text-right','border-top-color','#e0e0e0','','','.w-delivery-day'),(123877,'printshop-mobile','.w-product-customers-activity .customers-activity','border-top-color','#e0e0e0','','','.w-product-customers-activity'),(123878,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-color','#ee4225','','','.w-promotions'),(123879,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-color','#ee4225','','','.w-promotions'),(123880,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-color','#ee4225','','','.w-promotions'),(123881,'printshop-mobile','.w-promotions .promo-salemaker .discount','border-top-color','#ff6716','','','.w-promotions'),(123882,'printshop-mobile','.w-reviews-content .review','border-top-color','transparent','3','','.w-reviews-content'),(123883,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-color','#ccc','','','.w-upload-customer-id-upload-customer-id-form'),(123884,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-top-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(123885,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-top-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(123886,'printshop-mobile','.w-wedding-registry-widgets-products .rating','border-top-color','#e0e0e0','','','.w-wedding-registry-widgets-products'),(123887,'printshop-mobile','.b-data-table table.dataTable.no-footer','border-top-color_important','important','','','.b-data-table'),(123888,'printshop-mobile','.w-sale .left-count-days','border-top-left-radius','3','','','.w-sale'),(123889,'printshop-mobile','.w-sale .badge','border-top-left-radius','50','','','.w-sale'),(123890,'printshop-mobile','.w-product-wedding-registry-button .btn','border-top-left-radius','50','3','','.w-product-wedding-registry-button'),(123891,'printshop-mobile','.w-product-sale-ends .left-count-days','border-top-left-radius','3','','','.w-product-sale-ends'),(123892,'printshop-mobile','.w-product-sale-ends .left-count','border-top-left-radius','3','','','.w-product-sale-ends'),(123893,'printshop-mobile','.w-product-sale-ends .left-count-hours','border-top-left-radius','3','','','.w-product-sale-ends'),(123894,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-left-radius','50','3','','.b-multi-page-checkout'),(123895,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-left-radius','50','','','.b-multi-page-checkout'),(123896,'printshop-mobile','.p-blog-index .avatar','border-top-left-radius','50','','','.p-blog-index'),(123897,'printshop-mobile','.w-product-wedding-registry-button .btn','border-top-left-radius','50','4','','.w-product-wedding-registry-button'),(123898,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-left-radius','50','3','','.b-form'),(123899,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(123900,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(123901,'printshop-mobile','.b-switch .bootstrap-switch','border-top-left-radius','14','','','.b-switch'),(123902,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-top-left-radius','15','','','.b-fancybox'),(123903,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border-top-left-radius','30','706','','.w-list-type-1'),(123904,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-left-radius','50','','','.b-slick'),(123905,'printshop-mobile','.b-fancybox .fancybox-skin','border-top-left-radius','4','','','.b-fancybox'),(123906,'printshop-mobile','.b-fancybox .fancybox-nav span','border-top-left-radius','50','','','.b-fancybox'),(123907,'printshop-mobile','.w-sale .left-count','border-top-left-radius','3','','','.w-sale'),(123908,'printshop-mobile','.w-sale .left-count-hours','border-top-left-radius','3','','','.w-sale'),(123909,'printshop-mobile','.btn-3','border-top-left-radius','24','','',''),(123910,'printshop-mobile','.btn','border-top-left-radius','24','','',''),(123911,'printshop-mobile','.btn-1','border-top-left-radius','20','','',''),(123912,'printshop-mobile','.btn-2','border-top-left-radius','24','','',''),(123913,'printshop-mobile','.b-products-listing .promos-info .promo-name','border-top-left-radius','0','','','.b-products-listing'),(123914,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.b-data-table'),(123915,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.b-data-table'),(123916,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-left-radius','5','','','.b-messages'),(123917,'printshop-mobile','.b-trade-approval .steps-bar','border-top-left-radius','18','','','.b-trade-approval'),(123918,'printshop-mobile','.b-upload-file .snapshot','border-top-left-radius','50','','','.b-upload-file'),(123919,'printshop-mobile','.batchPr .checkbox input + span','border-top-left-radius','18','','','.batchPr'),(123920,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-top-left-radius','0','','','.batchPr'),(123921,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-left-radius','10','','','.batchPr'),(123922,'printshop-mobile','.batchPr .btn-batch-remove','border-top-left-radius','100','','','.batchPr'),(123923,'printshop-mobile','.p-catalog-product .pn-image','border-top-left-radius','50','3','','.p-catalog-product'),(123924,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.p-quick-order-index'),(123925,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.p-quick-order-index'),(123926,'printshop-mobile','.w-account-address-book .wrap','border-top-left-radius','5','','','.w-account-address-book'),(123927,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-top-left-radius','0','','','.w-blog-widget-related-posts'),(123928,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-left-radius','0','','','.w-catalog-paging'),(123929,'printshop-mobile','.w-checkout-shipping-choice label:last-child span','border-top-left-radius','0','','','.w-checkout-shipping-choice'),(123930,'printshop-mobile','.w-checkout-shipping-choice label:first-child span','border-top-left-radius','16','','','.w-checkout-shipping-choice'),(123931,'printshop-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-left-radius','3','','','.w-delivery-day'),(123932,'printshop-mobile','.w-delivery-day .left-count','border-top-left-radius','3','','','.w-delivery-day'),(123933,'printshop-mobile','.w-personal-gift-status-bar .progress-bar-content','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(123934,'printshop-mobile','.w-personal-gift-status-bar .progress-bar','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(123935,'printshop-mobile','.w-product-customers-activity .customers-activity','border-top-left-radius','10','','','.w-product-customers-activity'),(123936,'printshop-mobile','.w-product-customers-activity .close','border-top-left-radius','50','','','.w-product-customers-activity'),(123937,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-left-radius','12','','','.w-promotions'),(123938,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-left-radius','12','','','.w-promotions'),(123939,'printshop-mobile','.w-promotions .promo-salemaker .discount','border-top-left-radius','12','','','.w-promotions'),(123940,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-left-radius','12','','','.w-promotions'),(123941,'printshop-mobile','.w-product-sale-ends .left-count-days','border-top-right-radius','3','','','.w-product-sale-ends'),(123942,'printshop-mobile','.w-sale .left-count-hours','border-top-right-radius','3','','','.w-sale'),(123943,'printshop-mobile','.w-sale .left-count','border-top-right-radius','3','','','.w-sale'),(123944,'printshop-mobile','.w-sale .left-count-days','border-top-right-radius','3','','','.w-sale'),(123945,'printshop-mobile','.w-sale .badge','border-top-right-radius','50','','','.w-sale'),(123946,'printshop-mobile','.w-product-wedding-registry-button .btn','border-top-right-radius','50','3','','.w-product-wedding-registry-button'),(123947,'printshop-mobile','.w-product-sale-ends .left-count','border-top-right-radius','3','','','.w-product-sale-ends'),(123948,'printshop-mobile','.w-product-sale-ends .left-count-hours','border-top-right-radius','3','','','.w-product-sale-ends'),(123949,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-right-radius','50','3','','.b-multi-page-checkout'),(123950,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-right-radius','50','','','.b-multi-page-checkout'),(123951,'printshop-mobile','.p-blog-index .avatar','border-top-right-radius','50','','','.p-blog-index'),(123952,'printshop-mobile','.w-product-wedding-registry-button .btn','border-top-right-radius','50','4','','.w-product-wedding-registry-button'),(123953,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-right-radius','50','3','','.b-form'),(123954,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(123955,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(123956,'printshop-mobile','.b-switch .bootstrap-switch','border-top-right-radius','14','','','.b-switch'),(123957,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-right-radius','50','','','.b-slick'),(123958,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border-top-right-radius','30','706','','.w-list-type-1'),(123959,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-top-right-radius','15','','','.b-fancybox'),(123960,'printshop-mobile','.b-fancybox .fancybox-skin','border-top-right-radius','4','','','.b-fancybox'),(123961,'printshop-mobile','.b-fancybox .fancybox-nav span','border-top-right-radius','50','','','.b-fancybox'),(123962,'printshop-mobile','.btn-3','border-top-right-radius','24','','',''),(123963,'printshop-mobile','.btn-2','border-top-right-radius','24','','',''),(123964,'printshop-mobile','.btn-1','border-top-right-radius','20','','',''),(123965,'printshop-mobile','.btn','border-top-right-radius','24','','',''),(123966,'printshop-mobile','.b-products-listing .promos-info .promo-name','border-top-right-radius','8','','','.b-products-listing'),(123967,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.b-data-table'),(123968,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.b-data-table'),(123969,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-right-radius','5','','','.b-messages'),(123970,'printshop-mobile','.b-trade-approval .steps-bar','border-top-right-radius','18','','','.b-trade-approval'),(123971,'printshop-mobile','.b-upload-file .snapshot','border-top-right-radius','50','','','.b-upload-file'),(123972,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-right-radius','10','','','.batchPr'),(123973,'printshop-mobile','.batchPr .checkbox input + span','border-top-right-radius','18','','','.batchPr'),(123974,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-top-right-radius','0','','','.batchPr'),(123975,'printshop-mobile','.batchPr .btn-batch-remove','border-top-right-radius','100','','','.batchPr'),(123976,'printshop-mobile','.p-catalog-product .pn-image','border-top-right-radius','50','3','','.p-catalog-product'),(123977,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.p-quick-order-index'),(123978,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.p-quick-order-index'),(123979,'printshop-mobile','.w-account-address-book .wrap','border-top-right-radius','5','','','.w-account-address-book'),(123980,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-top-right-radius','0','','','.w-blog-widget-related-posts'),(123981,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-right-radius','0','','','.w-catalog-paging'),(123982,'printshop-mobile','.w-checkout-shipping-choice label:first-child span','border-top-right-radius','0','','','.w-checkout-shipping-choice'),(123983,'printshop-mobile','.w-checkout-shipping-choice label:last-child span','border-top-right-radius','16','','','.w-checkout-shipping-choice'),(123984,'printshop-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-right-radius','3','','','.w-delivery-day'),(123985,'printshop-mobile','.w-delivery-day .left-count','border-top-right-radius','3','','','.w-delivery-day'),(123986,'printshop-mobile','.w-personal-gift-status-bar .progress-bar-content','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(123987,'printshop-mobile','.w-personal-gift-status-bar .progress-bar','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(123988,'printshop-mobile','.w-product-customers-activity .customers-activity','border-top-right-radius','10','','','.w-product-customers-activity'),(123989,'printshop-mobile','.w-product-customers-activity .close','border-top-right-radius','50','','','.w-product-customers-activity'),(123990,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-right-radius','12','','','.w-promotions'),(123991,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-right-radius','12','','','.w-promotions'),(123992,'printshop-mobile','.w-promotions .promo-salemaker .discount','border-top-right-radius','12','','','.w-promotions'),(123993,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-right-radius','12','','','.w-promotions'),(123994,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(123995,'printshop-mobile','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(123996,'printshop-mobile','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(123997,'printshop-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','border-top-width','2','','','.b-product-images'),(123998,'printshop-mobile','.w-sale .sale-holder','border-top-width','2','','','.w-sale'),(123999,'printshop-mobile','.w-menu-slider > ul > li > ul','border-top-width','1','','','.w-menu-slider'),(124000,'printshop-mobile','.w-product-wedding-registry-button .btn','border-top-width','2','3','','.w-product-wedding-registry-button'),(124001,'printshop-mobile','.w-product-sale-ends .left-text-left','border-top-width','2','','','.w-product-sale-ends'),(124002,'printshop-mobile','.w-product-sale-ends .left-text-right','border-top-width','2','','','.w-product-sale-ends'),(124003,'printshop-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-top-width','2','2','','.b-product-images'),(124004,'printshop-mobile','.w-compare-box-item .checkbox + span','border-top-width','1','','','.w-compare-box-item'),(124005,'printshop-mobile','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(124006,'printshop-mobile','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-bundle'),(124007,'printshop-mobile','.w-catalog-listing-look .b2b','border-top-width','1','','','.w-catalog-listing-look'),(124008,'printshop-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-width','1','','','.b-compare'),(124009,'printshop-mobile','.w-catalog-listing-look .list','border-top-width','1','','','.w-catalog-listing-look'),(124010,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-width','1','','','.b-multi-page-checkout'),(124011,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-width','2','','','.p-blog-index'),(124012,'printshop-mobile','.btn','border-top-width','2','','',''),(124013,'printshop-mobile','.btn-3','border-top-width','2','','',''),(124014,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(124015,'printshop-mobile','.view-all','border-top-width','1','3','',''),(124016,'printshop-mobile','.b-info-popup .info-popup div','border-top-width','1','','','.b-info-popup'),(124017,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(124018,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','border-top-width','1','','','.b-multi-page-checkout'),(124019,'printshop-mobile','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(124020,'printshop-mobile','.testimonials .review','border-top-width','7','3','',''),(124021,'printshop-mobile','.b-pagination .pagination .prev-pages','border-top-width','1','','','.b-pagination'),(124022,'printshop-mobile','.b-pagination .pagination .prev','border-top-width','1','','','.b-pagination'),(124023,'printshop-mobile','.b-pagination .pagination .page-number','border-top-width','1','','','.b-pagination'),(124024,'printshop-mobile','.p-wedding-registry-manage .wr-search button','border-top-width','0','','','.p-wedding-registry-manage'),(124025,'printshop-mobile','.b-pagination .pagination .next-pages','border-top-width','1','','','.b-pagination'),(124026,'printshop-mobile','.b-pagination .pagination .next','border-top-width','1','','','.b-pagination'),(124027,'printshop-mobile','.b-pagination .pagination span','border-top-width','1','2','','.b-pagination'),(124028,'printshop-mobile','.p-account-history .orders-table .item','border-top-width','1','720','','.p-account-history'),(124029,'printshop-mobile','.p-account-history .orders-table .td-alignright','border-top-width','1','720','','.p-account-history'),(124030,'printshop-mobile','.p-account-index .orders-table .td-alignright','border-top-width','1','720','','.p-account-index'),(124031,'printshop-mobile','.p-account-index .orders-table .item','border-top-width','1','720','','.p-account-index'),(124032,'printshop-mobile','.w-list-type-2_2 .compare-box-item','border-top-width','1','','','.w-list-type-2_2'),(124033,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','border-top-width','0','','','.w-list-type-2_2'),(124034,'printshop-mobile','.w-list-type-2_2 .buttons','border-top-width','1','','','.w-list-type-2_2'),(124035,'printshop-mobile','.w-product-wedding-registry-button .btn','border-top-width','2','4','','.w-product-wedding-registry-button'),(124036,'printshop-mobile','.p-wedding-registry-index .search-list','border-top-width','1','3','','.p-wedding-registry-index'),(124037,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-width','2','3','','.b-form'),(124038,'printshop-mobile','.b-form .form-buttons','border-top-width','1','','','.b-form'),(124039,'printshop-mobile','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(124040,'printshop-mobile','.b-pagination .pagination a','border-top-width','1','','','.b-pagination'),(124041,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-width','2','','','.b-slick'),(124042,'printshop-mobile','.w-languages .select','border-top-width','1','','','.w-languages'),(124043,'printshop-mobile','.w-search .item + .item','border-top-width','1','','','.w-search'),(124044,'printshop-mobile','.w-search .search-input','border-top-width','0','','','.w-search'),(124045,'printshop-mobile','.w-socials > li','border-top-width','1','','','.w-socials'),(124046,'printshop-mobile','.p-checkout-index .shipping-method .item + .item','border-top-width','1','','','.p-checkout-index'),(124047,'printshop-mobile','.w-currencies .currencies-title','border-top-width','2','','','.w-currencies'),(124048,'printshop-mobile','.w-currencies .select','border-top-width','1','','','.w-currencies'),(124049,'printshop-mobile','.b-bottom .popup-buttons','border-top-width','1','','','.b-bottom'),(124050,'printshop-mobile','.w-compare-box-item .checkbox:checked + span','border-top-width','1','','','.w-compare-box-item'),(124051,'printshop-mobile','.b-slick .slick-vertical .slick-slide','border-top-width','1','','','.b-slick'),(124052,'printshop-mobile','.w-menu .hided.menu ul li','border-top-width','1','720','','.w-menu'),(124053,'printshop-mobile','.b-info-popup .info-popup div','border-top-width','1','3','','.b-info-popup'),(124054,'printshop-mobile','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(124055,'printshop-mobile','.w-catalog-listing-look .grid','border-top-width','1','','','.w-catalog-listing-look'),(124056,'printshop-mobile','.w-sale .left-text-left','border-top-width','2','','','.w-sale'),(124057,'printshop-mobile','.w-sale .left-text-right','border-top-width','2','','','.w-sale'),(124058,'printshop-mobile','.b-quantity .qty-box .bigger','border-top-width','2','','','.b-quantity'),(124059,'printshop-mobile','.b-quantity .qty-box .smaller','border-top-width','2','','','.b-quantity'),(124060,'printshop-mobile','.w-cart .cart-content','border-top-width','1','','','.w-cart'),(124061,'printshop-mobile','.p-reviews-info .review-info-text','border-top-width','5','4','','.p-reviews-info'),(124062,'printshop-mobile','.w-list-type-2 .button-wishlist button','border-top-width','0','','','.w-list-type-2'),(124063,'printshop-mobile','.w-list-type-2 .buttons','border-top-width','1','','','.w-list-type-2'),(124064,'printshop-mobile','.w-list-type-2 .item','border-top-width','1','1','','.w-list-type-2'),(124065,'printshop-mobile','.w-list-type-2 .compare-box-item','border-top-width','1','','','.w-list-type-2'),(124066,'printshop-mobile','.b-autocomplete .ui-autocomplete li','border-top-width','1','','','.b-autocomplete'),(124067,'printshop-mobile','.p-wedding-registry-manage .remove','border-top-width','1','','','.p-wedding-registry-manage'),(124068,'printshop-mobile','.w-list-type-1_3 .compare-box-item','border-top-width','1','','','.w-list-type-1_3'),(124069,'printshop-mobile','.w-list-type-1_3 .buttons','border-top-width','1','','','.w-list-type-1_3'),(124070,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','border-top-width','0','','','.w-list-type-1_3'),(124071,'printshop-mobile','.w-list-type-1_2 .compare-box-item','border-top-width','1','','','.w-list-type-1_2'),(124072,'printshop-mobile','.w-list-type-1_2 .buttons','border-top-width','1','','','.w-list-type-1_2'),(124073,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','border-top-width','0','','','.w-list-type-1_2'),(124074,'printshop-mobile','.b-bottom .popup-box','border-top-width','1','','','.b-bottom'),(124075,'printshop-mobile','.w-list-type-1 .compare-box-item','border-top-width','1','','','.w-list-type-1'),(124076,'printshop-mobile','.w-list-type-1 .button-wishlist button','border-top-width','0','','','.w-list-type-1'),(124077,'printshop-mobile','.w-filters .ui-slider-range','border-top-width','0','','','.w-filters'),(124078,'printshop-mobile','.w-list-type-1 .buttons','border-top-width','1','','','.w-list-type-1'),(124079,'printshop-mobile','.w-filters .ui-slider','border-top-width','0','','','.w-filters'),(124080,'printshop-mobile','.w-filters .ui-slider-handle','border-top-width','0','','','.w-filters'),(124081,'printshop-mobile','.w-reviews .review','border-top-width','7','3','','.w-reviews'),(124082,'printshop-mobile','.w-search .button-search','border-top-width','0','','','.w-search'),(124083,'printshop-mobile','.b-form .required-error','border-top-width','1','','','.b-form'),(124084,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-top-width','2','','',''),(124085,'printshop-mobile','textarea','border-top-width','2','','',''),(124086,'printshop-mobile','.b-info div + .info','border-top-width','1','','','.b-info'),(124087,'printshop-mobile','.b-products-listing .products-listing .compare','border-top-width','1','','','.b-products-listing'),(124088,'printshop-mobile','.b-data-table table.dataTable tbody td','border-top-width','1','','','.b-data-table'),(124089,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(124090,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(124091,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(124092,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(124093,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(124094,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(124095,'printshop-mobile','.b-email .model','border-top-width','1','','','.b-email'),(124096,'printshop-mobile','.b-email .model','border-top-width','1','','','.b-email'),(124097,'printshop-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(124098,'printshop-mobile','.b-email .name','border-top-width','1','','','.b-email'),(124099,'printshop-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(124100,'printshop-mobile','.b-email .name','border-top-width','1','','','.b-email'),(124101,'printshop-mobile','.b-email .model','border-top-width','1','','','.b-email'),(124102,'printshop-mobile','.b-email .price','border-top-width','1','','','.b-email'),(124103,'printshop-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(124104,'printshop-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(124105,'printshop-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(124106,'printshop-mobile','.b-email .price','border-top-width','1','','','.b-email'),(124107,'printshop-mobile','.b-email .image','border-top-width','1','','','.b-email'),(124108,'printshop-mobile','.b-email .image','border-top-width','1','','','.b-email'),(124109,'printshop-mobile','.b-email .name','border-top-width','1','','','.b-email'),(124110,'printshop-mobile','.b-email .name','border-top-width','1','','','.b-email'),(124111,'printshop-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(124112,'printshop-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(124113,'printshop-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(124114,'printshop-mobile','.b-email .name','border-top-width','1','','','.b-email'),(124115,'printshop-mobile','.b-email .image','border-top-width','1','','','.b-email'),(124116,'printshop-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(124117,'printshop-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(124118,'printshop-mobile','.b-email .model','border-top-width','1','','','.b-email'),(124119,'printshop-mobile','.b-email .image','border-top-width','1','','','.b-email'),(124120,'printshop-mobile','.b-email .name','border-top-width','1','','','.b-email'),(124121,'printshop-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(124122,'printshop-mobile','.b-email .price','border-top-width','1','','','.b-email'),(124123,'printshop-mobile','.b-email .image','border-top-width','1','','','.b-email'),(124124,'printshop-mobile','.b-email .price','border-top-width','1','','','.b-email'),(124125,'printshop-mobile','.b-email .model','border-top-width','1','','','.b-email'),(124126,'printshop-mobile','.b-email .image','border-top-width','1','','','.b-email'),(124127,'printshop-mobile','.b-email .price','border-top-width','1','','','.b-email'),(124128,'printshop-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(124129,'printshop-mobile','.b-email .model','border-top-width','1','','','.b-email'),(124130,'printshop-mobile','.b-email .price','border-top-width','1','','','.b-email'),(124131,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-top-width','1','','','.b-menu-style-2'),(124132,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-top-width','3','','','.b-menu-style-2'),(124133,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','border-top-width','1','','','.b-menu-style-2'),(124134,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-top-width','1','','','.b-menu-style-2'),(124135,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-top-width','3','','','.b-menu-style-2'),(124136,'printshop-mobile','.b-messages .msv_btn','border-top-width','1','','','.b-messages'),(124137,'printshop-mobile','.b-messages .email-heading','border-top-width','1','','','.b-messages'),(124138,'printshop-mobile','.b-messages .dataTable','border-top-width','1','','','.b-messages'),(124139,'printshop-mobile','.b-messages .messMenuButtonTop','border-top-width','1','','','.b-messages'),(124140,'printshop-mobile','.b-messages .content_management_attach button','border-top-width','1','','','.b-messages'),(124141,'printshop-mobile','.b-messages .messages-menu li + li','border-top-width','1','','','.b-messages'),(124142,'printshop-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-width','2','','','.b-messages'),(124143,'printshop-mobile','.b-messages .content_management_attach','border-top-width','1','','','.b-messages'),(124144,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','border-top-width','2','','','.b-select-suggest'),(124145,'printshop-mobile','.b-select-suggest .select2-search input','border-top-width','1','','','.b-select-suggest'),(124146,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-width','1','','','.b-select-suggest'),(124147,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(124148,'printshop-mobile','.b-select-suggest .select2-drop-auto-width','border-top-width','1','','','.b-select-suggest'),(124149,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-width','1','','','.b-select-suggest'),(124150,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-top-width','1','','','.b-select-suggest'),(124151,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-width','1','','','.b-select-suggest'),(124152,'printshop-mobile','.b-select-suggest .select2-drop.select2-drop-above','border-top-width','1','','','.b-select-suggest'),(124153,'printshop-mobile','.b-select-suggest .select2-drop-active','border-top-width','1','','','.b-select-suggest'),(124154,'printshop-mobile','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-width','1','','','.b-select-suggest'),(124155,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(124156,'printshop-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(124157,'printshop-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(124158,'printshop-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(124159,'printshop-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(124160,'printshop-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(124161,'printshop-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(124162,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(124163,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(124164,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(124165,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(124166,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(124167,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(124168,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-width','2','','','.b-trade-approval'),(124169,'printshop-mobile','.b-upload-file .snapshot','border-top-width','1','','','.b-upload-file'),(124170,'printshop-mobile','.b-upload-file .upload-file-template','border-top-width','1','','','.b-upload-file'),(124171,'printshop-mobile','.b-upload-files .upload-files','border-top-width','1','','','.b-upload-files'),(124172,'printshop-mobile','.b-upload-files .added-file','border-top-width','1','','','.b-upload-files'),(124173,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-width','1','','','.batchPr'),(124174,'printshop-mobile','.batchPr .checkbox input + span','border-top-width','1','','','.batchPr'),(124175,'printshop-mobile','.batchPr .checkbox input + span','border-top-width','1','','','.batchPr'),(124176,'printshop-mobile','.batchPr .checkbox input:checked + span','border-top-width','1','','','.batchPr'),(124177,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .item + .item','border-top-width','1','','','.batchPr'),(124178,'printshop-mobile','.batchPr .w-batch-selected-products','border-top-width','1','','','.batchPr'),(124179,'printshop-mobile','.p-account-samples-history .orders-table .item','border-top-width','1','','','.p-account-samples-history'),(124180,'printshop-mobile','.p-account-samples-history .orders-table .item','border-top-width','1','','','.p-account-samples-history'),(124181,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-width','1','','','.p-account-samples-history'),(124182,'printshop-mobile','.p-account-samples-history .orders-table .item','border-top-width','1','','','.p-account-samples-history'),(124183,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-width','1','','','.p-account-samples-history'),(124184,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-width','1','','','.p-account-samples-history'),(124185,'printshop-mobile','.p-account-samples-history .orders-table .item','border-top-width','1','','','.p-account-samples-history'),(124186,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-width','1','','','.p-account-samples-history'),(124187,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-width','1','','','.p-account-samples-history'),(124188,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-width','1','','','.p-account-samples-history'),(124189,'printshop-mobile','.p-account-samples-history .orders-table .item','border-top-width','1','','','.p-account-samples-history'),(124190,'printshop-mobile','.p-account-samples-history .orders-table .item','border-top-width','1','','','.p-account-samples-history'),(124191,'printshop-mobile','.p-catalog-product .prev-next-product','border-top-width','1','','','.p-catalog-product'),(124192,'printshop-mobile','.p-catalog-product .pn-image','border-top-width','1','','','.p-catalog-product'),(124193,'printshop-mobile','.p-catalog-product .pn-name','border-top-width','1','','','.p-catalog-product'),(124194,'printshop-mobile','.p-catalog-product .pn-image','border-top-width','2','3','','.p-catalog-product'),(124195,'printshop-mobile','.p-payer-order-confirmation .input-wrapper','border-top-width','2','','','.p-payer-order-confirmation'),(124196,'printshop-mobile','.p-payer-order-pay .input-wrapper','border-top-width','2','','','.p-payer-order-pay'),(124197,'printshop-mobile','.w-account-address-book .wrap','border-top-width','1','','','.w-account-address-book'),(124198,'printshop-mobile','.w-account-personal-catalog .list-switcher a','border-top-width','3','2','','.w-account-personal-catalog'),(124199,'printshop-mobile','.w-account-subscription .subscription-variant + .subscription-variant','border-top-width','1','','','.w-account-subscription'),(124200,'printshop-mobile','.w-cart-compare .attributes-block td','border-top-width','1','','','.w-cart-compare'),(124201,'printshop-mobile','.w-cart-compare .price-block td','border-top-width','1','','','.w-cart-compare'),(124202,'printshop-mobile','.w-cart-compare .product-block td','border-top-width','1','','','.w-cart-compare'),(124203,'printshop-mobile','.w-cart-compare .cart-cell > div','border-top-width','1','','','.w-cart-compare'),(124204,'printshop-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-top-width','1','','','.w-catalog-compare'),(124205,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','border-top-width','3','2','','.w-catalog-compare'),(124206,'printshop-mobile','.w-catalog-paging .prev','border-top-width','1','','','.w-catalog-paging'),(124207,'printshop-mobile','.w-catalog-paging .page-number','border-top-width','1','','','.w-catalog-paging'),(124208,'printshop-mobile','.w-catalog-paging .next','border-top-width','1','','','.w-catalog-paging'),(124209,'printshop-mobile','.w-catalog-paging ','border-top-width','1','2','','.w-catalog-paging'),(124210,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-width','1','','','.w-catalog-paging'),(124211,'printshop-mobile','.w-catalog-paging .next-pages','border-top-width','1','','','.w-catalog-paging'),(124212,'printshop-mobile','.w-catalog-paging .prev-pages','border-top-width','1','','','.w-catalog-paging'),(124213,'printshop-mobile','.w-checkout-shipping .sub-item + .sub-item','border-top-width','1','','','.w-checkout-shipping'),(124214,'printshop-mobile','.w-checkout-shipping-choice span','border-top-width','2','','','.w-checkout-shipping-choice'),(124215,'printshop-mobile','.w-communication-new-topic td','border-top-width','1','','','.w-communication-new-topic'),(124216,'printshop-mobile','.w-communication-post .communication-post','border-top-width','1','','','.w-communication-post'),(124217,'printshop-mobile','.w-delivery-day .left-text-left','border-top-width','2','','','.w-delivery-day'),(124218,'printshop-mobile','.w-delivery-day .left-text-right','border-top-width','2','','','.w-delivery-day'),(124219,'printshop-mobile','.w-product-customers-activity .customers-activity','border-top-width','1','','','.w-product-customers-activity'),(124220,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-width','1','','','.w-promotions'),(124221,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-width','1','','','.w-promotions'),(124222,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-width','1','','','.w-promotions'),(124223,'printshop-mobile','.w-promotions .promo-salemaker .discount','border-top-width','1','','','.w-promotions'),(124224,'printshop-mobile','.w-reviews-content .review','border-top-width','8','3','','.w-reviews-content'),(124225,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(124226,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-top-width','1','','','.w-wedding-registry-widgets-photos'),(124227,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-top-width','1','','','.w-wedding-registry-widgets-photos'),(124228,'printshop-mobile','.w-wedding-registry-widgets-products .rating','border-top-width','1','','','.w-wedding-registry-widgets-products'),(124229,'printshop-mobile','.b-data-table table.dataTable thead td','border_important','important','','','.b-data-table'),(124230,'printshop-mobile','.w-sale .left-count-days','border_radius_1_measure','px','','','.w-sale'),(124231,'printshop-mobile','.w-sale .left-count-hours','border_radius_1_measure','px','','','.w-sale'),(124232,'printshop-mobile','.w-sale .left-count','border_radius_1_measure','px','','','.w-sale'),(124233,'printshop-mobile','.w-sale .badge','border_radius_1_measure','%','','','.w-sale'),(124234,'printshop-mobile','.w-product-sale-ends .left-count','border_radius_1_measure','px','','','.w-product-sale-ends'),(124235,'printshop-mobile','.w-product-sale-ends .left-count-hours','border_radius_1_measure','px','','','.w-product-sale-ends'),(124236,'printshop-mobile','.w-product-sale-ends .left-count-days','border_radius_1_measure','px','','','.w-product-sale-ends'),(124237,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_1_measure','%','3','','.b-multi-page-checkout'),(124238,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_1_measure','%','','','.b-multi-page-checkout'),(124239,'printshop-mobile','.p-blog-index .avatar','border_radius_1_measure','%','','','.p-blog-index'),(124240,'printshop-mobile','.w-product-wedding-registry-button .btn','border_radius_1_measure','%','4','','.w-product-wedding-registry-button'),(124241,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_1_measure','%','3','','.b-form'),(124242,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(124243,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(124244,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_1_measure','px','','','.b-fancybox'),(124245,'printshop-mobile','.b-switch .bootstrap-switch','border_radius_1_measure','px','','','.b-switch'),(124246,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_1_measure','%','','','.b-slick'),(124247,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border_radius_1_measure','px','706','','.w-list-type-1'),(124248,'printshop-mobile','.btn-3','border_radius_1_measure','px','','',''),(124249,'printshop-mobile','.btn-2','border_radius_1_measure','px','','',''),(124250,'printshop-mobile','.btn-1','border_radius_1_measure','px','','',''),(124251,'printshop-mobile','.btn','border_radius_1_measure','px','','',''),(124252,'printshop-mobile','.b-fancybox .fancybox-skin','border_radius_1_measure','px','','','.b-fancybox'),(124253,'printshop-mobile','.w-product-wedding-registry-button .btn','border_radius_1_measure','%','3','','.w-product-wedding-registry-button'),(124254,'printshop-mobile','.b-fancybox .fancybox-nav span','border_radius_1_measure','%','','','.b-fancybox'),(124255,'printshop-mobile','.b-products-listing .promos-info .promo-name','border_radius_1_measure','px','','','.b-products-listing'),(124256,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.b-data-table'),(124257,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.b-data-table'),(124258,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_1_measure','px','','','.b-messages'),(124259,'printshop-mobile','.b-trade-approval .steps-bar','border_radius_1_measure','px','','','.b-trade-approval'),(124260,'printshop-mobile','.b-upload-file .snapshot','border_radius_1_measure','%','','','.b-upload-file'),(124261,'printshop-mobile','.batchPr .checkbox input + span','border_radius_1_measure','px','','','.batchPr'),(124262,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_1_measure','px','','','.batchPr'),(124263,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_1_measure','px','','','.batchPr'),(124264,'printshop-mobile','.batchPr .btn-batch-remove','border_radius_1_measure','%','','','.batchPr'),(124265,'printshop-mobile','.p-catalog-product .pn-image','border_radius_1_measure','%','3','','.p-catalog-product'),(124266,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.p-quick-order-index'),(124267,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.p-quick-order-index'),(124268,'printshop-mobile','.w-account-address-book .wrap','border_radius_1_measure','px','','','.w-account-address-book'),(124269,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_1_measure','px','','','.w-blog-widget-related-posts'),(124270,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_1_measure','px','','','.w-catalog-paging'),(124271,'printshop-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(124272,'printshop-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(124273,'printshop-mobile','.w-delivery-day .left-count','border_radius_1_measure','px','','','.w-delivery-day'),(124274,'printshop-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_1_measure','px','','','.w-delivery-day'),(124275,'printshop-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(124276,'printshop-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(124277,'printshop-mobile','.w-product-customers-activity .customers-activity','border_radius_1_measure','px','','','.w-product-customers-activity'),(124278,'printshop-mobile','.w-product-customers-activity .close','border_radius_1_measure','%','','','.w-product-customers-activity'),(124279,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_1_measure','px','','','.w-promotions'),(124280,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_1_measure','px','','','.w-promotions'),(124281,'printshop-mobile','.w-promotions .promo-salemaker .discount','border_radius_1_measure','px','','','.w-promotions'),(124282,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_1_measure','px','','','.w-promotions'),(124283,'printshop-mobile','.w-sale .left-count-days','border_radius_2_measure','px','','','.w-sale'),(124284,'printshop-mobile','.w-sale .left-count','border_radius_2_measure','px','','','.w-sale'),(124285,'printshop-mobile','.w-sale .left-count-hours','border_radius_2_measure','px','','','.w-sale'),(124286,'printshop-mobile','.w-sale .badge','border_radius_2_measure','%','','','.w-sale'),(124287,'printshop-mobile','.w-product-wedding-registry-button .btn','border_radius_2_measure','%','3','','.w-product-wedding-registry-button'),(124288,'printshop-mobile','.w-product-sale-ends .left-count','border_radius_2_measure','px','','','.w-product-sale-ends'),(124289,'printshop-mobile','.w-product-sale-ends .left-count-days','border_radius_2_measure','px','','','.w-product-sale-ends'),(124290,'printshop-mobile','.w-product-sale-ends .left-count-hours','border_radius_2_measure','px','','','.w-product-sale-ends'),(124291,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_2_measure','%','3','','.b-multi-page-checkout'),(124292,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_2_measure','%','','','.b-multi-page-checkout'),(124293,'printshop-mobile','.p-blog-index .avatar','border_radius_2_measure','%','','','.p-blog-index'),(124294,'printshop-mobile','.w-product-wedding-registry-button .btn','border_radius_2_measure','%','4','','.w-product-wedding-registry-button'),(124295,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_2_measure','%','3','','.b-form'),(124296,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(124297,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(124298,'printshop-mobile','.b-switch .bootstrap-switch','border_radius_2_measure','px','','','.b-switch'),(124299,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_2_measure','%','','','.b-slick'),(124300,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border_radius_2_measure','px','706','','.w-list-type-1'),(124301,'printshop-mobile','.btn-3','border_radius_2_measure','px','','',''),(124302,'printshop-mobile','.btn-2','border_radius_2_measure','px','','',''),(124303,'printshop-mobile','.btn-1','border_radius_2_measure','px','','',''),(124304,'printshop-mobile','.btn','border_radius_2_measure','px','','',''),(124305,'printshop-mobile','.b-fancybox .fancybox-skin','border_radius_2_measure','px','','','.b-fancybox'),(124306,'printshop-mobile','.b-fancybox .fancybox-nav span','border_radius_2_measure','%','','','.b-fancybox'),(124307,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_2_measure','px','','','.b-fancybox'),(124308,'printshop-mobile','.b-products-listing .promos-info .promo-name','border_radius_2_measure','px','','','.b-products-listing'),(124309,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.b-data-table'),(124310,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.b-data-table'),(124311,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_2_measure','px','','','.b-messages'),(124312,'printshop-mobile','.b-trade-approval .steps-bar','border_radius_2_measure','px','','','.b-trade-approval'),(124313,'printshop-mobile','.b-upload-file .snapshot','border_radius_2_measure','%','','','.b-upload-file'),(124314,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_2_measure','px','','','.batchPr'),(124315,'printshop-mobile','.batchPr .checkbox input + span','border_radius_2_measure','px','','','.batchPr'),(124316,'printshop-mobile','.batchPr .btn-batch-remove','border_radius_2_measure','%','','','.batchPr'),(124317,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_2_measure','px','','','.batchPr'),(124318,'printshop-mobile','.p-catalog-product .pn-image','border_radius_2_measure','%','3','','.p-catalog-product'),(124319,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.p-quick-order-index'),(124320,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.p-quick-order-index'),(124321,'printshop-mobile','.w-account-address-book .wrap','border_radius_2_measure','px','','','.w-account-address-book'),(124322,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_2_measure','px','','','.w-blog-widget-related-posts'),(124323,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_2_measure','px','','','.w-catalog-paging'),(124324,'printshop-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(124325,'printshop-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(124326,'printshop-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_2_measure','px','','','.w-delivery-day'),(124327,'printshop-mobile','.w-delivery-day .left-count','border_radius_2_measure','px','','','.w-delivery-day'),(124328,'printshop-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(124329,'printshop-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(124330,'printshop-mobile','.w-product-customers-activity .customers-activity','border_radius_2_measure','px','','','.w-product-customers-activity'),(124331,'printshop-mobile','.w-product-customers-activity .close','border_radius_2_measure','%','','','.w-product-customers-activity'),(124332,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_2_measure','px','','','.w-promotions'),(124333,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_2_measure','px','','','.w-promotions'),(124334,'printshop-mobile','.w-promotions .promo-salemaker .discount','border_radius_2_measure','px','','','.w-promotions'),(124335,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_2_measure','px','','','.w-promotions'),(124336,'printshop-mobile','.w-sale .left-count','border_radius_3_measure','px','','','.w-sale'),(124337,'printshop-mobile','.w-sale .left-count-days','border_radius_3_measure','px','','','.w-sale'),(124338,'printshop-mobile','.w-sale .badge','border_radius_3_measure','%','','','.w-sale'),(124339,'printshop-mobile','.w-product-wedding-registry-button .btn','border_radius_3_measure','%','3','','.w-product-wedding-registry-button'),(124340,'printshop-mobile','.w-product-sale-ends .left-count-days','border_radius_3_measure','px','','','.w-product-sale-ends'),(124341,'printshop-mobile','.w-product-sale-ends .left-count','border_radius_3_measure','px','','','.w-product-sale-ends'),(124342,'printshop-mobile','.w-product-sale-ends .left-count-hours','border_radius_3_measure','px','','','.w-product-sale-ends'),(124343,'printshop-mobile','.b-fancybox .fancybox-nav span','border_radius_3_measure','%','','','.b-fancybox'),(124344,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_3_measure','%','3','','.b-multi-page-checkout'),(124345,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_3_measure','%','','','.b-multi-page-checkout'),(124346,'printshop-mobile','.p-blog-index .avatar','border_radius_3_measure','%','','','.p-blog-index'),(124347,'printshop-mobile','.w-product-wedding-registry-button .btn','border_radius_3_measure','%','4','','.w-product-wedding-registry-button'),(124348,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_3_measure','%','3','','.b-form'),(124349,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(124350,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(124351,'printshop-mobile','.b-switch .bootstrap-switch','border_radius_3_measure','px','','','.b-switch'),(124352,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_3_measure','%','','','.b-slick'),(124353,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border_radius_3_measure','px','706','','.w-list-type-1'),(124354,'printshop-mobile','.btn-3','border_radius_3_measure','px','','',''),(124355,'printshop-mobile','.btn-2','border_radius_3_measure','px','','',''),(124356,'printshop-mobile','.btn-1','border_radius_3_measure','px','','',''),(124357,'printshop-mobile','.btn','border_radius_3_measure','px','','',''),(124358,'printshop-mobile','.b-fancybox .fancybox-skin','border_radius_3_measure','px','','','.b-fancybox'),(124359,'printshop-mobile','.w-sale .left-count-hours','border_radius_3_measure','px','','','.w-sale'),(124360,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_3_measure','px','','','.b-fancybox'),(124361,'printshop-mobile','.b-products-listing .promos-info .promo-name','border_radius_3_measure','px','','','.b-products-listing'),(124362,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.b-data-table'),(124363,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.b-data-table'),(124364,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_3_measure','px','','','.b-messages'),(124365,'printshop-mobile','.b-trade-approval .steps-bar','border_radius_3_measure','px','','','.b-trade-approval'),(124366,'printshop-mobile','.b-upload-file .snapshot','border_radius_3_measure','%','','','.b-upload-file'),(124367,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_3_measure','px','','','.batchPr'),(124368,'printshop-mobile','.batchPr .checkbox input + span','border_radius_3_measure','px','','','.batchPr'),(124369,'printshop-mobile','.batchPr .btn-batch-remove','border_radius_3_measure','%','','','.batchPr'),(124370,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_3_measure','px','','','.batchPr'),(124371,'printshop-mobile','.p-catalog-product .pn-image','border_radius_3_measure','%','3','','.p-catalog-product'),(124372,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.p-quick-order-index'),(124373,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.p-quick-order-index'),(124374,'printshop-mobile','.w-account-address-book .wrap','border_radius_3_measure','px','','','.w-account-address-book'),(124375,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_3_measure','px','','','.w-blog-widget-related-posts'),(124376,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_3_measure','px','','','.w-catalog-paging'),(124377,'printshop-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(124378,'printshop-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(124379,'printshop-mobile','.w-delivery-day .left-count','border_radius_3_measure','px','','','.w-delivery-day'),(124380,'printshop-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_3_measure','px','','','.w-delivery-day'),(124381,'printshop-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(124382,'printshop-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(124383,'printshop-mobile','.w-product-customers-activity .customers-activity','border_radius_3_measure','px','','','.w-product-customers-activity'),(124384,'printshop-mobile','.w-product-customers-activity .close','border_radius_3_measure','%','','','.w-product-customers-activity'),(124385,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_3_measure','px','','','.w-promotions'),(124386,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_3_measure','px','','','.w-promotions'),(124387,'printshop-mobile','.w-promotions .promo-salemaker .discount','border_radius_3_measure','px','','','.w-promotions'),(124388,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_3_measure','px','','','.w-promotions'),(124389,'printshop-mobile','.w-sale .left-count-days','border_radius_4_measure','px','','','.w-sale'),(124390,'printshop-mobile','.w-sale .left-count-hours','border_radius_4_measure','px','','','.w-sale'),(124391,'printshop-mobile','.w-sale .left-count','border_radius_4_measure','px','','','.w-sale'),(124392,'printshop-mobile','.w-sale .badge','border_radius_4_measure','%','','','.w-sale'),(124393,'printshop-mobile','.w-product-wedding-registry-button .btn','border_radius_4_measure','%','3','','.w-product-wedding-registry-button'),(124394,'printshop-mobile','.w-product-wedding-registry-button .btn','border_radius_4_measure','%','4','','.w-product-wedding-registry-button'),(124395,'printshop-mobile','.w-product-sale-ends .left-count','border_radius_4_measure','px','','','.w-product-sale-ends'),(124396,'printshop-mobile','.w-product-sale-ends .left-count-days','border_radius_4_measure','px','','','.w-product-sale-ends'),(124397,'printshop-mobile','.w-product-sale-ends .left-count-hours','border_radius_4_measure','px','','','.w-product-sale-ends'),(124398,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_4_measure','%','3','','.b-multi-page-checkout'),(124399,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_4_measure','%','','','.b-multi-page-checkout'),(124400,'printshop-mobile','.p-blog-index .avatar','border_radius_4_measure','%','','','.p-blog-index'),(124401,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_4_measure','%','3','','.b-form'),(124402,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(124403,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(124404,'printshop-mobile','.b-switch .bootstrap-switch','border_radius_4_measure','px','','','.b-switch'),(124405,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border_radius_4_measure','px','706','','.w-list-type-1'),(124406,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_4_measure','%','','','.b-slick'),(124407,'printshop-mobile','.btn-3','border_radius_4_measure','px','','',''),(124408,'printshop-mobile','.btn-2','border_radius_4_measure','px','','',''),(124409,'printshop-mobile','.btn-1','border_radius_4_measure','px','','',''),(124410,'printshop-mobile','.btn','border_radius_4_measure','px','','',''),(124411,'printshop-mobile','.b-fancybox .fancybox-skin','border_radius_4_measure','px','','','.b-fancybox'),(124412,'printshop-mobile','.b-fancybox .fancybox-nav span','border_radius_4_measure','%','','','.b-fancybox'),(124413,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_4_measure','px','','','.b-fancybox'),(124414,'printshop-mobile','.b-products-listing .promos-info .promo-name','border_radius_4_measure','px','','','.b-products-listing'),(124415,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.b-data-table'),(124416,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.b-data-table'),(124417,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_4_measure','px','','','.b-messages'),(124418,'printshop-mobile','.b-trade-approval .steps-bar','border_radius_4_measure','px','','','.b-trade-approval'),(124419,'printshop-mobile','.b-upload-file .snapshot','border_radius_4_measure','%','','','.b-upload-file'),(124420,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_4_measure','px','','','.batchPr'),(124421,'printshop-mobile','.batchPr .checkbox input + span','border_radius_4_measure','px','','','.batchPr'),(124422,'printshop-mobile','.batchPr .btn-batch-remove','border_radius_4_measure','%','','','.batchPr'),(124423,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_4_measure','px','','','.batchPr'),(124424,'printshop-mobile','.p-catalog-product .pn-image','border_radius_4_measure','%','3','','.p-catalog-product'),(124425,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.p-quick-order-index'),(124426,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.p-quick-order-index'),(124427,'printshop-mobile','.w-account-address-book .wrap','border_radius_4_measure','px','','','.w-account-address-book'),(124428,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_4_measure','px','','','.w-blog-widget-related-posts'),(124429,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_4_measure','px','','','.w-catalog-paging'),(124430,'printshop-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(124431,'printshop-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(124432,'printshop-mobile','.w-delivery-day .left-count','border_radius_4_measure','px','','','.w-delivery-day'),(124433,'printshop-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_4_measure','px','','','.w-delivery-day'),(124434,'printshop-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(124435,'printshop-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(124436,'printshop-mobile','.w-product-customers-activity .customers-activity','border_radius_4_measure','px','','','.w-product-customers-activity'),(124437,'printshop-mobile','.w-product-customers-activity .close','border_radius_4_measure','%','','','.w-product-customers-activity'),(124438,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_4_measure','px','','','.w-promotions'),(124439,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_4_measure','px','','','.w-promotions'),(124440,'printshop-mobile','.w-promotions .promo-salemaker .discount','border_radius_4_measure','px','','','.w-promotions'),(124441,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_4_measure','px','','','.w-promotions'),(124442,'printshop-mobile','.p-reviews-info .review-info-text','bottom','-10','4','','.p-reviews-info'),(124443,'printshop-mobile','.b-info-popup .info-popup.top-left div','bottom','-11','3','','.b-info-popup'),(124444,'printshop-mobile','.b-info-popup .info-popup.top-left div','bottom','30','','','.b-info-popup'),(124445,'printshop-mobile','.testimonials .review','bottom','-13','3','',''),(124446,'printshop-mobile','.p-account-history .orders-table .status-name','bottom','7','720','','.p-account-history'),(124447,'printshop-mobile','.p-account-history .orders-table .td-alignright','bottom','0','720','','.p-account-history'),(124448,'printshop-mobile','.p-account-history .orders-table .order-total','bottom','45','720','','.p-account-history'),(124449,'printshop-mobile','.p-account-index .orders-table .status-name','bottom','7','720','','.p-account-index'),(124450,'printshop-mobile','.p-account-index .orders-table .order-total','bottom','45','720','','.p-account-index'),(124451,'printshop-mobile','.p-account-index .orders-table .td-alignright','bottom','0','720','','.p-account-index'),(124452,'printshop-mobile','.w-list-type-2_2 .sale','bottom','0','','','.w-list-type-2_2'),(124453,'printshop-mobile','.w-list-type-2_2 .sale','bottom','0','3','','.w-list-type-2_2'),(124454,'printshop-mobile','.w-list-type-2 .sale','bottom','0','','','.w-list-type-2'),(124455,'printshop-mobile','.w-list-type-2 .sale','bottom','0','4','','.w-list-type-2'),(124456,'printshop-mobile','.w-list-type-2 .sale','bottom','0','3','','.w-list-type-2'),(124457,'printshop-mobile','.w-banner .image-text-banner.bottom-center .text-banner','bottom','0','','','.w-banner'),(124458,'printshop-mobile','.w-banner .image-text-banner.bottom-left .text-banner','bottom','0','','','.w-banner'),(124459,'printshop-mobile','.w-banner .image-text-banner.bottom-right .text-banner','bottom','0','','','.w-banner'),(124460,'printshop-mobile','.b-slick .slick-vertical button.slick-next','bottom','0','','','.b-slick'),(124461,'printshop-mobile','.b-slick .slick-vertical button.slick-prev','bottom','auto','','','.b-slick'),(124462,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap','bottom','0','','','.b-fancybox'),(124463,'printshop-mobile','.w-list-type-1_3 #add_all','bottom','20','','','.w-list-type-1_3'),(124464,'printshop-mobile','.b-fancybox .fancybox-title-over-wrap','bottom','0','','','.b-fancybox'),(124465,'printshop-mobile','.b-fancybox .fancybox-overlay-fixed','bottom','0','','','.b-fancybox'),(124466,'printshop-mobile','.w-list-type-2_2 .sale','bottom','0','4','','.w-list-type-2_2'),(124467,'printshop-mobile','.w-list-type-1_3 .sale','bottom','0','3','','.w-list-type-1_3'),(124468,'printshop-mobile','.w-list-type-1_3 .sale','bottom','0','4','','.w-list-type-1_3'),(124469,'printshop-mobile','.w-list-type-1_3 .sale','bottom','0','','','.w-list-type-1_3'),(124470,'printshop-mobile','.w-list-type-1_2 .sale','bottom','0','','','.w-list-type-1_2'),(124471,'printshop-mobile','.w-list-type-1_2 .sale','bottom','0','3','','.w-list-type-1_2'),(124472,'printshop-mobile','.w-list-type-1_2 .sale','bottom','0','4','','.w-list-type-1_2'),(124473,'printshop-mobile','.w-list-type-1 .sale','bottom','0','4','','.w-list-type-1'),(124474,'printshop-mobile','.w-list-type-1 .sale','bottom','0','3','','.w-list-type-1'),(124475,'printshop-mobile','.w-list-type-1 .sale','bottom','0','','','.w-list-type-1'),(124476,'printshop-mobile','.w-product-reviews .reviews-list .review','bottom','-13','3','','.w-product-reviews'),(124477,'printshop-mobile','.w-reviews .review','bottom','-13','3','','.w-reviews'),(124478,'printshop-mobile','.b-upload-file .snapshot','bottom','5','','','.b-upload-file'),(124479,'printshop-mobile','.p-account-samples-history .orders-table .status-name','bottom','7','','','.p-account-samples-history'),(124480,'printshop-mobile','.p-account-samples-history .orders-table .status-name','bottom','7','','','.p-account-samples-history'),(124481,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','bottom','0','','','.p-account-samples-history'),(124482,'printshop-mobile','.p-account-samples-history .orders-table .order-total','bottom','45','','','.p-account-samples-history'),(124483,'printshop-mobile','.p-account-samples-history .orders-table .status-name','bottom','7','','','.p-account-samples-history'),(124484,'printshop-mobile','.p-account-samples-history .orders-table .order-total','bottom','45','','','.p-account-samples-history'),(124485,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','bottom','0','','','.p-account-samples-history'),(124486,'printshop-mobile','.p-account-samples-history .orders-table .status-name','bottom','7','','','.p-account-samples-history'),(124487,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','bottom','0','','','.p-account-samples-history'),(124488,'printshop-mobile','.p-account-samples-history .orders-table .status-name','bottom','7','','','.p-account-samples-history'),(124489,'printshop-mobile','.p-account-samples-history .orders-table .order-total','bottom','45','','','.p-account-samples-history'),(124490,'printshop-mobile','.p-account-samples-history .orders-table .order-total','bottom','45','','','.p-account-samples-history'),(124491,'printshop-mobile','.p-account-samples-history .orders-table .order-total','bottom','45','','','.p-account-samples-history'),(124492,'printshop-mobile','.p-account-samples-history .orders-table .status-name','bottom','7','','','.p-account-samples-history'),(124493,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','bottom','0','','','.p-account-samples-history'),(124494,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','bottom','0','','','.p-account-samples-history'),(124495,'printshop-mobile','.p-account-samples-history .orders-table .order-total','bottom','45','','','.p-account-samples-history'),(124496,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','bottom','0','','','.p-account-samples-history'),(124497,'printshop-mobile','.p-quick-order-index .all-scroll-div','bottom','0','','','.p-quick-order-index'),(124498,'printshop-mobile','.w-catalog-b2b-add-button ','bottom','0','','','.w-catalog-b2b-add-button'),(124499,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','bottom','-7','','','.w-checkout-shipping-choice'),(124500,'printshop-mobile','.w-product-customers-activity .customers-activity','bottom','0','','','.w-product-customers-activity'),(124501,'printshop-mobile','.w-product-customers-activity .customers-activity.closed','bottom','-1000','','','.w-product-customers-activity'),(124502,'printshop-mobile','.w-menu .hided.menu ul ul','box-shadow','none','','','.w-menu'),(124503,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(124504,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','box-shadow','0 2px 9px 0 rgba(0, 0, 0, 0.2)','2','','.b-multi-page-checkout'),(124505,'printshop-mobile','.b-fancybox .fancybox-opened .fancybox-skin','box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(124506,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','box-shadow','none','','','.batchPr'),(124507,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','box-shadow','none','','','.batchPr'),(124508,'printshop-mobile','.w-catalog-compare .compare-fix-bar.fix-bar-fix','box-shadow','0 10px 10px -10px #cccccc','','','.w-catalog-compare'),(124509,'printshop-mobile','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(124510,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','box-sizing','border-box','','','.b-switch'),(124511,'printshop-mobile','.b-slick .slick-slider','box-sizing','border-box','','','.b-slick'),(124512,'printshop-mobile','.b-fancybox .filter-listing-loader','box-sizing','content-box','','','.b-fancybox'),(124513,'printshop-mobile','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','box-sizing','border-box','','','.b-select-suggest'),(124514,'printshop-mobile','.b-info-popup .info-popup div','box_shadow_blur','10','','','.b-info-popup'),(124515,'printshop-mobile','.b-datepicker .datepicker-dropdown','box_shadow_blur','10','','','.b-datepicker'),(124516,'printshop-mobile','.w-account-address-book .wrap','box_shadow_blur','4','','','.w-account-address-book'),(124517,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur','5','','','.w-image-maps'),(124518,'printshop-mobile','.w-product-customers-activity .customers-activity','box_shadow_blur','20','','','.w-product-customers-activity'),(124519,'printshop-mobile','.b-info-popup .info-popup div','box_shadow_blur_measure','px','','','.b-info-popup'),(124520,'printshop-mobile','.b-datepicker .datepicker-dropdown','box_shadow_blur_measure','px','','','.b-datepicker'),(124521,'printshop-mobile','.w-account-address-book .wrap','box_shadow_blur_measure','px','','','.w-account-address-book'),(124522,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur_measure','px','','','.w-image-maps'),(124523,'printshop-mobile','.w-product-customers-activity .customers-activity','box_shadow_blur_measure','px','','','.w-product-customers-activity'),(124524,'printshop-mobile','.b-info-popup .info-popup div','box_shadow_color','#ccc','','','.b-info-popup'),(124525,'printshop-mobile','.b-datepicker .datepicker-dropdown','box_shadow_color','#ccc','','','.b-datepicker'),(124526,'printshop-mobile','.w-account-address-book .wrap','box_shadow_color','#c4c4c4','','','.w-account-address-book'),(124527,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_color','#ccc','','','.w-image-maps'),(124528,'printshop-mobile','.w-product-customers-activity .customers-activity','box_shadow_color','#eee','','','.w-product-customers-activity'),(124529,'printshop-mobile','.b-info-popup .info-popup div','box_shadow_left','0','','','.b-info-popup'),(124530,'printshop-mobile','.b-datepicker .datepicker-dropdown','box_shadow_left','0','','','.b-datepicker'),(124531,'printshop-mobile','.w-account-address-book .wrap','box_shadow_left','1','','','.w-account-address-book'),(124532,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left','0','','','.w-image-maps'),(124533,'printshop-mobile','.w-product-customers-activity .customers-activity','box_shadow_left','0','','','.w-product-customers-activity'),(124534,'printshop-mobile','.b-info-popup .info-popup div','box_shadow_left_measure','','','','.b-info-popup'),(124535,'printshop-mobile','.b-datepicker .datepicker-dropdown','box_shadow_left_measure','','','','.b-datepicker'),(124536,'printshop-mobile','.w-account-address-book .wrap','box_shadow_left_measure','px','','','.w-account-address-book'),(124537,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left_measure','','','','.w-image-maps'),(124538,'printshop-mobile','.w-product-customers-activity .customers-activity','box_shadow_left_measure','','','','.w-product-customers-activity'),(124539,'printshop-mobile','.b-info-popup .info-popup div','box_shadow_top','0','','','.b-info-popup'),(124540,'printshop-mobile','.b-datepicker .datepicker-dropdown','box_shadow_top','0','','','.b-datepicker'),(124541,'printshop-mobile','.w-account-address-book .wrap','box_shadow_top','1','','','.w-account-address-book'),(124542,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top','0','','','.w-image-maps'),(124543,'printshop-mobile','.w-product-customers-activity .customers-activity','box_shadow_top','0','','','.w-product-customers-activity'),(124544,'printshop-mobile','.b-info-popup .info-popup div','box_shadow_top_measure','','','','.b-info-popup'),(124545,'printshop-mobile','.b-datepicker .datepicker-dropdown','box_shadow_top_measure','','','','.b-datepicker'),(124546,'printshop-mobile','.w-account-address-book .wrap','box_shadow_top_measure','px','','','.w-account-address-book'),(124547,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top_measure','','','','.w-image-maps'),(124548,'printshop-mobile','.w-product-customers-activity .customers-activity','box_shadow_top_measure','','','','.w-product-customers-activity'),(124549,'printshop-mobile','.w-menu-big li','clear','none','','','.w-menu-big'),(124550,'printshop-mobile','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(124551,'printshop-mobile','.w-login-block .cols','clear','both','4','','.w-login-block'),(124552,'printshop-mobile','.w-login-block .guest','clear','right','','','.w-login-block'),(124553,'printshop-mobile','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(124554,'printshop-mobile','.w-login-block .buttons','clear','none','','','.w-login-block'),(124555,'printshop-mobile','.w-product-attributes .attributes','clear','both','4','','.w-product-attributes'),(124556,'printshop-mobile','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(124557,'printshop-mobile','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(124558,'printshop-mobile','.w-cart a.item','clear','both','4','','.w-cart'),(124559,'printshop-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','clear','both','','','.p-account-trade-form'),(124560,'printshop-mobile','.w-categories .item:nth-child(4n + 1)','clear','both','','','.w-categories'),(124561,'printshop-mobile','.w-categories .categories','clear','both','4','','.w-categories'),(124562,'printshop-mobile','.b-pagination .pagination','clear','both','4','','.b-pagination'),(124563,'printshop-mobile','.w-cart-shipping-estimator .shipping-estimator','clear','both','4','','.w-cart-shipping-estimator'),(124564,'printshop-mobile','.w-list-type-1_2 .right-area','clear','both','4','','.w-list-type-1_2'),(124565,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','clear','both','4','','.b-multi-page-checkout'),(124566,'printshop-mobile','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(124567,'printshop-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','clear','none','','','.p-wedding-registry-manage'),(124568,'printshop-mobile','.w-product-bonus-points > div','clear','both','4','','.w-product-bonus-points'),(124569,'printshop-mobile','.w-product-configurator .pc_attr','clear','both','693','','.w-product-configurator'),(124570,'printshop-mobile','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(124571,'printshop-mobile','.w-product-configurator .pc_qty','clear','both','693','','.w-product-configurator'),(124572,'printshop-mobile','.p-account-address-book .address_book_row','clear','both','','','.p-account-address-book'),(124573,'printshop-mobile','.p-blog-index .w-blog-sidebar .wp-widget:nth-child(2n + 1)','clear','both','720','','.p-blog-index'),(124574,'printshop-mobile','.p-blog-index .entry-content','clear','both','4','','.p-blog-index'),(124575,'printshop-mobile','.p-blog-index .comment-meta','clear','both','4','','.p-blog-index'),(124576,'printshop-mobile','.buttons','clear','both','','',''),(124577,'printshop-mobile','.w-list-type-2_2 .qty-input','clear','left','','','.w-list-type-2_2'),(124578,'printshop-mobile','.w-list-type-2_2 .compare-box-item','clear','both','','','.w-list-type-2_2'),(124579,'printshop-mobile','.w-list-type-2_2 .item','clear','both','','','.w-list-type-2_2'),(124580,'printshop-mobile','.buttons','clear','both','4','',''),(124581,'printshop-mobile','.w-list-type-2_2 .item','clear','both','4','','.w-list-type-2_2'),(124582,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','clear','right','','','.w-list-type-2_2'),(124583,'printshop-mobile','.w-list-type-2_2 .add-height','clear','both','4','','.w-list-type-2_2'),(124584,'printshop-mobile','.w-list-type-2 .qty-input','clear','left','','','.w-list-type-2'),(124585,'printshop-mobile','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(124586,'printshop-mobile','.b-form .center-buttons','clear','both','','','.b-form'),(124587,'printshop-mobile','.b-product-images .main-image-box','clear','both','4','','.b-product-images'),(124588,'printshop-mobile','.w-top-categories .categories','clear','both','4','','.w-top-categories'),(124589,'printshop-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(124590,'printshop-mobile','.p-account-trade-form .widget','clear','both','','','.p-account-trade-form'),(124591,'printshop-mobile','.b-slick .slick-track','clear','both','4','','.b-slick'),(124592,'printshop-mobile','.p-account-trade-form .wd-line-row-2','clear','both','4','','.p-account-trade-form'),(124593,'printshop-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','clear','left','','','.p-account-trade-form'),(124594,'printshop-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(124595,'printshop-mobile','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(124596,'printshop-mobile','.w-list-type-1_3 .qty-input','clear','left','','','.w-list-type-1_3'),(124597,'printshop-mobile','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(124598,'printshop-mobile','.p-wedding-registry-share .add-row','clear','both','','','.p-wedding-registry-share'),(124599,'printshop-mobile','.p-wedding-registry-share .address-row','clear','both','','','.p-wedding-registry-share'),(124600,'printshop-mobile','.b-slick .slick-slide','clear','none','','','.b-slick'),(124601,'printshop-mobile','.w-menu-horizontal li','clear','none','','','.w-menu-horizontal'),(124602,'printshop-mobile','.b-form .addresses .address-item:nth-child(2n + 1)','clear','left','','','.b-form'),(124603,'printshop-mobile','.b-form .columns','clear','both','4','','.b-form'),(124604,'printshop-mobile','.b-form .columns .col-2:nth-child(2n + 1)','clear','left','','','.b-form'),(124605,'printshop-mobile','.b-form .addresses','clear','both','4','','.b-form'),(124606,'printshop-mobile','.w-cart-give-away .ga_name','clear','both','4','','.w-cart-give-away'),(124607,'printshop-mobile','.w-cart-give-away .ga_column:nth-child(2n + 1)','clear','both','','','.w-cart-give-away'),(124608,'printshop-mobile','.b-form .col-right + .col-left','clear','both','','','.b-form'),(124609,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','clear','right','','','.w-list-type-2'),(124610,'printshop-mobile','.w-list-type-2 .compare-box-item','clear','both','','','.w-list-type-2'),(124611,'printshop-mobile','.w-list-type-2 .add-height','clear','both','4','','.w-list-type-2'),(124612,'printshop-mobile','.w-list-type-1_3 .item','clear','both','','','.w-list-type-1_3'),(124613,'printshop-mobile','.w-list-type-1_3 .item','clear','both','4','','.w-list-type-1_3'),(124614,'printshop-mobile','.w-list-type-1_3 .compare-box-item','clear','both','','','.w-list-type-1_3'),(124615,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','clear','right','','','.w-list-type-1_3'),(124616,'printshop-mobile','.w-list-type-1_3 .attributes > .attributes','clear','both','4','','.w-list-type-1_3'),(124617,'printshop-mobile','.w-list-type-1_3 .add-height','clear','both','4','','.w-list-type-1_3'),(124618,'printshop-mobile','.w-list-type-1_2 .qty-input','clear','left','','','.w-list-type-1_2'),(124619,'printshop-mobile','.w-list-type-1_2 .item','clear','both','','','.w-list-type-1_2'),(124620,'printshop-mobile','.w-list-type-1_2 .item','clear','both','4','','.w-list-type-1_2'),(124621,'printshop-mobile','.w-list-type-1_2 .compare-box-item','clear','both','','','.w-list-type-1_2'),(124622,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','clear','right','','','.w-list-type-1_2'),(124623,'printshop-mobile','.w-list-type-1_2 .add-height','clear','both','4','','.w-list-type-1_2'),(124624,'printshop-mobile','.w-list-type-1 .qty-input','clear','left','','','.w-list-type-1'),(124625,'printshop-mobile','.w-list-type-1 .compare-box-item','clear','both','','','.w-list-type-1'),(124626,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','clear','right','','','.w-list-type-1'),(124627,'printshop-mobile','.w-list-type-1 .add-height','clear','both','4','','.w-list-type-1'),(124628,'printshop-mobile','.w-top-categories .item:nth-child(4n + 1)','clear','both','','','.w-top-categories'),(124629,'printshop-mobile','.b-form .col-right','clear','right','','','.b-form'),(124630,'printshop-mobile','.b-form .col-full','clear','both','','','.b-form'),(124631,'printshop-mobile','.b-form .col-left','clear','left','','','.b-form'),(124632,'printshop-mobile','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(124633,'printshop-mobile','.b-form .requiredM','clear','both','','','.b-form'),(124634,'printshop-mobile','.w-menu-style-1 li','clear','none','','','.w-menu-style-1'),(124635,'printshop-mobile','.b-products-listing .BlockBox','clear','both','4','','.b-products-listing'),(124636,'printshop-mobile','.b-products-listing .products-listing','clear','both','4','','.b-products-listing'),(124637,'printshop-mobile','.b-products-listing .products-listing .mix-attributes','clear','bpth','4','','.b-products-listing'),(124638,'printshop-mobile','.b-messages .dataTables_wrapper > .top','clear','both','4','','.b-messages'),(124639,'printshop-mobile','.b-messages .dataTables_wrapper > .bottom','clear','both','4','','.b-messages'),(124640,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(124641,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(124642,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(124643,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(124644,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(124645,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(124646,'printshop-mobile','.b-trade-approval .col-right','clear','right','','','.b-trade-approval'),(124647,'printshop-mobile','.b-trade-approval .col-left','clear','left','','','.b-trade-approval'),(124648,'printshop-mobile','.b-trade-approval .center-buttons','clear','both','','','.b-trade-approval'),(124649,'printshop-mobile','.b-trade-approval .columns','clear','both','4','','.b-trade-approval'),(124650,'printshop-mobile','.w-account-address-book .button-add','clear','both','','','.w-account-address-book'),(124651,'printshop-mobile','.w-account-address-book .item:nth-child(2n + 1)','clear','both','','','.w-account-address-book'),(124652,'printshop-mobile','.w-blog-widget-post-listing .post:nth-child(2n+1)','clear','both','','','.w-blog-widget-post-listing'),(124653,'printshop-mobile','.w-blog-widget-post-listing .post:nth-child(3n+1)','clear','none','','','.w-blog-widget-post-listing'),(124654,'printshop-mobile','.w-blog-widget-post-listing .products','clear','both','4','','.w-blog-widget-post-listing'),(124655,'printshop-mobile','.w-blog-widget-post-share ','clear','both','','','.w-blog-widget-post-share'),(124656,'printshop-mobile','.w-cart-compare .product .image','clear','both','','','.w-cart-compare'),(124657,'printshop-mobile','.w-cart-compare .product','clear','both','4','','.w-cart-compare'),(124658,'printshop-mobile','.w-cart-compare .buttons','clear','none','','','.w-cart-compare'),(124659,'printshop-mobile','.w-cart-compare .product .name','clear','right','','','.w-cart-compare'),(124660,'printshop-mobile','.w-catalog-compare .BlockBox','clear','both','','','.w-catalog-compare'),(124661,'printshop-mobile','.w-checkout-billing-address .addresses','clear','both','4','','.w-checkout-billing-address'),(124662,'printshop-mobile','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-billing-address'),(124663,'printshop-mobile','.w-checkout-billing-address .btn-cancel','clear','both','','','.w-checkout-billing-address'),(124664,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-shipping-address'),(124665,'printshop-mobile','.w-checkout-shipping-address .addresses','clear','both','4','','.w-checkout-shipping-address'),(124666,'printshop-mobile','.w-checkout-shipping-address .btn-cancel','clear','both','','','.w-checkout-shipping-address'),(124667,'printshop-mobile','.w-list-b2b .attributes','clear','both','4','','.w-list-b2b'),(124668,'printshop-mobile','.w-list-b2b .mix-attributes','clear','both','','','.w-list-b2b'),(124669,'printshop-mobile','.w-product-available-in-warehouses .content','clear','both','4','','.w-product-available-in-warehouses'),(124670,'printshop-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(124671,'printshop-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(124672,'printshop-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(124673,'printshop-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(124674,'printshop-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(124675,'printshop-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(124676,'printshop-mobile','.w-promotions .prom-multi-discount','clear','both','4','','.w-promotions'),(124677,'printshop-mobile','.w-wedding-registry-widgets-products .qty-input','clear','none','','','.w-wedding-registry-widgets-products'),(124678,'printshop-mobile','.w-wedding-registry-widgets-search-form .button','clear','both','','','.w-wedding-registry-widgets-search-form'),(124679,'printshop-mobile','.w-menu-big li','clear_important','important','','','.w-menu-big'),(124680,'printshop-mobile','.w-menu-style-1 li','clear_important','important','','','.w-menu-style-1'),(124681,'printshop-mobile','.b-slick .slick-slide','clear_important','important','','','.b-slick'),(124682,'printshop-mobile','.w-menu-horizontal li','clear_important','important','','','.w-menu-horizontal'),(124683,'printshop-mobile','.w-blog-widget-post-share ','clear_important','important','','','.w-blog-widget-post-share'),(124684,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip','rect(0 0 0 0)','','','.b-select-suggest'),(124685,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip_important','important','','','.b-select-suggest'),(124686,'printshop-mobile','.w-menu .menu .menu-ico','color','inherit','','','.w-menu'),(124687,'printshop-mobile','.w-menu-big a','color','inherit','','','.w-menu-big'),(124688,'printshop-mobile','.w-bestsellers .item','color','#183d78','3','','.w-bestsellers'),(124689,'printshop-mobile','.w-bestsellers .item:first-child .counter','color','#ffffff','','','.w-bestsellers'),(124690,'printshop-mobile','.w-bestsellers .counter','color','#183d78','','','.w-bestsellers'),(124691,'printshop-mobile','.w-bestsellers .heading-3','color','#183d78','3','','.w-bestsellers'),(124692,'printshop-mobile','.w-account .my-acc-link','color','#ffffff','3','','.w-account'),(124693,'printshop-mobile','a','color','inherit','','',''),(124694,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(124695,'printshop-mobile','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','color','#ffffff','','','.b-cookie-notice'),(124696,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','color','#e0e0e0','','','.b-form'),(124697,'printshop-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','color','#1b4388','','','.b-form'),(124698,'printshop-mobile','.w-sale .left-count-days-text','color','#fff','','','.w-sale'),(124699,'printshop-mobile','.w-product-sale-ends .ends','color','#ee4225','','','.w-product-sale-ends'),(124700,'printshop-mobile','.w-sale .left-count-hours-text','color','#fff','','','.w-sale'),(124701,'printshop-mobile','.w-html_box .linkedin','color','#0073b0','3','','.w-html_box'),(124702,'printshop-mobile','.w-html_box .instagram','color','#d02f7a','3','','.w-html_box'),(124703,'printshop-mobile','.w-html_box .stumbleupon','color','#eb4924','3','','.w-html_box'),(124704,'printshop-mobile','.w-html_box .pinterest','color','#bd081c','3','','.w-html_box'),(124705,'printshop-mobile','.w-html_box .twitter','color','#1b95e0','3','','.w-html_box'),(124706,'printshop-mobile','.w-html_box .facebook','color','#4267b2','3','','.w-html_box'),(124707,'printshop-mobile','.w-sale .badge','color','#fff','','','.w-sale'),(124708,'printshop-mobile','.w-html_box .google-plus','color','#dc4a38','3','','.w-html_box'),(124709,'printshop-mobile','.w-menu-style-1 > ul','color','#ffffff','','','.w-menu-style-1'),(124710,'printshop-mobile','.w-menu-style-1 .menu-ico','color','#ffffff','','','.w-menu-style-1'),(124711,'printshop-mobile','.w-product-sale-ends .left-count-days-text','color','#fff','','','.w-product-sale-ends'),(124712,'printshop-mobile','.w-product-sale-ends .left-count-hours-text','color','#fff','','','.w-product-sale-ends'),(124713,'printshop-mobile','.w-cart .cart-box-link','color','#ffffff','','','.w-cart'),(124714,'printshop-mobile','.w-menu-horizontal a','color','inherit','','','.w-menu-horizontal'),(124715,'printshop-mobile','.w-product-collection .save','color','#00a858','','','.w-product-collection'),(124716,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','color','#1d3d76','3','','.p-account-history-info'),(124717,'printshop-mobile','.p-account-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-history-info'),(124718,'printshop-mobile','.p-account-index .not_fully_paid_td','color','#ee4225','','','.p-account-index'),(124719,'printshop-mobile','.p-account-index .moduleRowDue td','color','#ccc','','','.p-account-index'),(124720,'printshop-mobile','.w-categories .name','color','#424242','','','.w-categories'),(124721,'printshop-mobile','.heading-3 .edit, h3 .edit','color','#092964','','',''),(124722,'printshop-mobile','.w-catalog-listing-look .list','color','#424242','2','','.w-catalog-listing-look'),(124723,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','#000','','','.b-multi-page-checkout'),(124724,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','#616161','','','.b-multi-page-checkout'),(124725,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','#092964','4','','.b-multi-page-checkout'),(124726,'printshop-mobile','.b-pass-strength span.strong-pass, .b-pass-strength span.pass-match','color','#00C853','','','.b-pass-strength'),(124727,'printshop-mobile','.b-pass-strength span.bad-pass','color','#FF6D00','','','.b-pass-strength'),(124728,'printshop-mobile','.b-pass-strength .short-pass, .b-pass-strength .pass-strength, .b-pass-strength .pass-no-match','color','#D32F2F','','','.b-pass-strength'),(124729,'printshop-mobile','.b-pass-strength span.good-pass','color','#7CB342','','','.b-pass-strength'),(124730,'printshop-mobile','.w-reviews .date','color','#999999','','','.w-reviews'),(124731,'printshop-mobile','.w-quote .cart-box-link','color','#ffffff','','','.w-quote'),(124732,'printshop-mobile','.w-product-reviews .reviews-list .date','color','#999999','','','.w-product-reviews'),(124733,'printshop-mobile','.w-product-in-bundles .product-link','color','#424242','','','.w-product-in-bundles'),(124734,'printshop-mobile','.w-catalog-listing-look .list','color','#cccccc','','','.w-catalog-listing-look'),(124735,'printshop-mobile','.w-menu-slider > ul','color','#ffffff','','','.w-menu-slider'),(124736,'printshop-mobile','.w-catalog-listing-look .b2b','color','#cccccc','','','.w-catalog-listing-look'),(124737,'printshop-mobile','.p-blog-index .posted-on','color','#666','','','.p-blog-index'),(124738,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','#fff','3','','.b-multi-page-checkout'),(124739,'printshop-mobile','.p-blog-index .reply a','color','#183d78','','','.p-blog-index'),(124740,'printshop-mobile','.p-blog-index .wp-widget li','color','#183d78','3','','.p-blog-index'),(124741,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','color','#bdbdbd','','','.b-multi-page-checkout'),(124742,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading','color','#092964','','','.b-multi-page-checkout'),(124743,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','color','#fff','','','.b-multi-page-checkout'),(124744,'printshop-mobile','.w-promo-code .holder','color','#e4452f','3','','.w-promo-code'),(124745,'printshop-mobile','.p-wedding-registry-manage a.remove-btn','color','#000','1','','.p-wedding-registry-manage'),(124746,'printshop-mobile','.p-wedding-registry-manage a.remove-btn','color','#757575','','','.p-wedding-registry-manage'),(124747,'printshop-mobile','.p-wedding-registry-share h1','color','#ee4225','4','','.p-wedding-registry-share'),(124748,'printshop-mobile','.w-product-bonus-points > div > div','color','#183d78','','','.w-product-bonus-points'),(124749,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','color','#1d3d76','3','','.p-account-order-pay'),(124750,'printshop-mobile','.p-account-order-pay .not_fully_paid_td','color','#ee4225','','','.p-account-order-pay'),(124751,'printshop-mobile','.testimonials .date','color','#999999','','',''),(124752,'printshop-mobile','.testimonials .heading-3','color','#183d78','3','',''),(124753,'printshop-mobile','.js-stock','color','#00a858','','',''),(124754,'printshop-mobile','.testimonials .reviews-list .date','color','#999999','','',''),(124755,'printshop-mobile','.p-wedding-registry-manage .wr-search button','color','#092964','3','','.p-wedding-registry-manage'),(124756,'printshop-mobile','.b-pagination .pagination span','color','#ffffff','2','','.b-pagination'),(124757,'printshop-mobile','.p-account-history .view_link','color','#092964','','','.p-account-history'),(124758,'printshop-mobile','.p-blog-index .nav-next a','color','#999','3','','.p-blog-index'),(124759,'printshop-mobile','.p-blog-index .nav-previous a','color','#999','3','','.p-blog-index'),(124760,'printshop-mobile','.w-list-type-2_2 .sale','color','#ee4225','3','','.w-list-type-2_2'),(124761,'printshop-mobile','.w-list-type-2_2 .price .specials','color','#ee4225','','','.w-list-type-2_2'),(124762,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','color','#183d78','','','.w-list-type-2_2'),(124763,'printshop-mobile','.w-list-type-2_2 .button-view a','color','#183d78','','','.w-list-type-2_2'),(124764,'printshop-mobile','.w-list-type-2 .sale','color','#ee4225','3','','.w-list-type-2'),(124765,'printshop-mobile','.w-list-type-2 .price .specials','color','#ee4225','','','.w-list-type-2'),(124766,'printshop-mobile','.p-reviews-info .review-info-text, .p-reviews-info .review-info-reviewed_by, .p-reviews-info .review-info-date','color','#424242','','','.p-reviews-info'),(124767,'printshop-mobile','.rating-1, .rating-2, .rating-3, .rating-4, .rating-5','color','#183d78','','',''),(124768,'printshop-mobile','.w-chat .w-chat-box a','color','#fff','3','','.w-chat'),(124769,'printshop-mobile','.w-delivery-location-top-location-list .deliveryName a','color','#424242','','','.w-delivery-location-top-location-list'),(124770,'printshop-mobile','.w-product-promotions .promotion-data-2 .save','color','#00a858','','','.w-product-promotions'),(124771,'printshop-mobile','.w-product-promotions .promotion-full-price-discount','color','#ee4225','','','.w-product-promotions'),(124772,'printshop-mobile','.p-wedding-registry-index .main-button','color','#183d78','4','','.p-wedding-registry-index'),(124773,'printshop-mobile','.b-form .radio-button input[type=\"radio\"]:checked + span:before','color','#444','','','.b-form'),(124774,'printshop-mobile','.p-wedding-registry-index .main-button','color','#183d78','3','','.p-wedding-registry-index'),(124775,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','color','#fff','3','','.b-form'),(124776,'printshop-mobile','.p-wedding-registry-manage .links a.share-registry','color','#183d78','4','','.p-wedding-registry-manage'),(124777,'printshop-mobile','.p-wedding-registry-search h1','color','#ee4225','4','','.p-wedding-registry-search'),(124778,'printshop-mobile','.p-wedding-registry-search h1','color','#ee4225','3','','.p-wedding-registry-search'),(124779,'printshop-mobile','.p-wedding-registry-manage h1','color','#ee4225','4','','.p-wedding-registry-manage'),(124780,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','color','#fff','','','.b-switch'),(124781,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','color','#fff','','','.b-switch'),(124782,'printshop-mobile','.b-fancybox .fancybox-title-outside-wrap','color','#fff','','','.b-fancybox'),(124783,'printshop-mobile','.w-tabs .accordion-heading','color','#183d78','2','','.w-tabs'),(124784,'printshop-mobile','.w-list-type-1 .rating','color','#183d78','','','.w-list-type-1'),(124785,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','color','#ccc','','','.b-slick'),(124786,'printshop-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','color','#1b4388','','','.w-filters'),(124787,'printshop-mobile','.w-filters .mobileCollapse','color','#fff','4','','.w-filters'),(124788,'printshop-mobile','.p-account-index .date_value','color','#ee4225','','','.p-account-index'),(124789,'printshop-mobile','.w-tabs .tab-a','color','#183d78','2','','.w-tabs'),(124790,'printshop-mobile','.btn-1','color','#ffffff','','',''),(124791,'printshop-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','color','#e0e0e0','','','.w-filters'),(124792,'printshop-mobile','.w-currencies .select-link','color','#092964','','','.w-currencies'),(124793,'printshop-mobile','.w-filters .filter-box-head','color','#000000','','','.w-filters'),(124794,'printshop-mobile','.w-filters .head-filter-widget','color','#fff','720','','.w-filters'),(124795,'printshop-mobile','.w-currencies .current','color','#b0b0b0','3','','.w-currencies'),(124796,'printshop-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','#bbb','3','','.w-contact-contacts'),(124797,'printshop-mobile','.w-currencies .currencies-title','color','#092964','','','.w-currencies'),(124798,'printshop-mobile','.w-compare-box-item .checkbox:checked + span:before','color','#fff','','','.w-compare-box-item'),(124799,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','color','#FFF','','','.b-fancybox'),(124800,'printshop-mobile','.p-checkout-success .page-success','color','#eeeeee','3','','.p-checkout-success'),(124801,'printshop-mobile','.b-info .info a','color','#183d78','','','.b-info'),(124802,'printshop-mobile','.p-account-index .view_link','color','#092964','','','.p-account-index'),(124803,'printshop-mobile','.p-account-index .view_history','color','#092964','','','.p-account-index'),(124804,'printshop-mobile','.w-menu-style-1 a','color','inherit','','','.w-menu-style-1'),(124805,'printshop-mobile','.w-menu-mobile .menu-ico','color','#ffffff','','','.w-menu-mobile'),(124806,'printshop-mobile','.w-list-type-2_2 .sale','color','#ffffff','4','','.w-list-type-2_2'),(124807,'printshop-mobile','.b-fancybox .fancybox-title-over-wrap','color','#fff','','','.b-fancybox'),(124808,'printshop-mobile','.p-account-index .topAccount > li > div.points_earnt .date_value, .p-account-index .topAccount > li > div.points_earnt, .p-account-index .topAccount > li > div.points_earnt .date_title','color','#989898','3','','.p-account-index'),(124809,'printshop-mobile','.p-account-index .topAccount > li > div','color','#ee4225','3','','.p-account-index'),(124810,'printshop-mobile','.w-product-quantity .qty_packs .price_1','color','#bcbcbc','4','','.w-product-quantity'),(124811,'printshop-mobile','.p-checkout-success .page-success .text-1','color','#092964','3','','.p-checkout-success'),(124812,'printshop-mobile','.b-fancybox .fancybox-skin','color','#444','','','.b-fancybox'),(124813,'printshop-mobile','.b-form .inputRequirement','color','#ee4225','','','.b-form'),(124814,'printshop-mobile','.p-checkout-success .page-success .text-3','color','#ee4225','','','.p-checkout-success'),(124815,'printshop-mobile','.w-sale .ends','color','#ee4225','','','.w-sale'),(124816,'printshop-mobile','.w-sale .special-price','color','#ee4225','','','.w-sale'),(124817,'printshop-mobile','.p-wedding-registry-share .invite-remove','color','#ee4225','','','.p-wedding-registry-share'),(124818,'printshop-mobile','.w-menu-slider .menu-ico','color','#ffffff','','','.w-menu-slider'),(124819,'printshop-mobile','.p-account-history .not_fully_paid_td','color','#ee4225','','','.p-account-history'),(124820,'printshop-mobile','.p-account-history .moduleRowDue td','color','#ccc','','','.p-account-history'),(124821,'printshop-mobile','.w-text .customer-service','color','#183d78','3','','.w-text'),(124822,'printshop-mobile','.w-text .customer-service b','color','#183d78','','','.w-text'),(124823,'printshop-mobile','.w-top-categories .categories h2','color','inherit','','','.w-top-categories'),(124824,'printshop-mobile','.w-categories .categories h2','color','inherit','','','.w-categories'),(124825,'printshop-mobile','.b-rating #stars-default .glyphicon.coloron','color','#092964','','','.b-rating'),(124826,'printshop-mobile','.b-rating #stars-default .glyphicon','color','#ccc','','','.b-rating'),(124827,'printshop-mobile','.b-quantity .qty-box .smaller','color','#183d78','','','.b-quantity'),(124828,'printshop-mobile','.b-quantity .qty-box .bigger','color','#183d78','','','.b-quantity'),(124829,'printshop-mobile','.b-fancybox .fancybox-nav span','color','#fff','','','.b-fancybox'),(124830,'printshop-mobile','.w-top-categories .name','color','#424242','','','.w-top-categories'),(124831,'printshop-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','color','#183d78','3','','.w-cart-discount-coupon'),(124832,'printshop-mobile','.p-account-index .date_title','color','#000','','','.p-account-index'),(124833,'printshop-mobile','.w-catalog-listing-look .grid','color','#424242','2','','.w-catalog-listing-look'),(124834,'printshop-mobile','.w-list-type-1_3 .price .specials','color','#ee4225','','','.w-list-type-1_3'),(124835,'printshop-mobile','.p-account-index .account_info .info .info_span','color','#000','','','.p-account-index'),(124836,'printshop-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','color','#183d78','3','','.w-cart-gift-certificate'),(124837,'printshop-mobile','.w-catalog-listing-look .grid','color','#cccccc','','','.w-catalog-listing-look'),(124838,'printshop-mobile','.w-search .search','color','#fff','3','','.w-search'),(124839,'printshop-mobile','.w-catalog-listing-look .b2b','color','#424242','2','','.w-catalog-listing-look'),(124840,'printshop-mobile','.price .specials','color','#ee4225','','',''),(124841,'printshop-mobile','.w-list-type-2 .button-view a','color','#183d78','','','.w-list-type-2'),(124842,'printshop-mobile','.w-list-type-1_3 .sale','color','#ffffff','4','','.w-list-type-1_3'),(124843,'printshop-mobile','.w-list-type-1_3 .sale','color','#ee4225','3','','.w-list-type-1_3'),(124844,'printshop-mobile','.p-wedding-registry-view h1','color','#ee4225','4','','.p-wedding-registry-view'),(124845,'printshop-mobile','.w-list-type-2 .button-wishlist button','color','#183d78','','','.w-list-type-2'),(124846,'printshop-mobile','.price .special','color','#ee4225','','',''),(124847,'printshop-mobile','.p-wedding-registry-manage h1','color','#ee4225','3','','.p-wedding-registry-manage'),(124848,'printshop-mobile','.p-wedding-registry-share h1','color','#ee4225','3','','.p-wedding-registry-share'),(124849,'printshop-mobile','.p-wedding-registry-view h1','color','#ee4225','3','','.p-wedding-registry-view'),(124850,'printshop-mobile','.w-list-type-2 .sale','color','#ffffff','4','','.w-list-type-2'),(124851,'printshop-mobile','.btn-3','color','#183d78','','',''),(124852,'printshop-mobile','.btn-2','color','#ffffff','','',''),(124853,'printshop-mobile','.btn','color','#183d78','','',''),(124854,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','color','#183d78','','','.w-list-type-1_3'),(124855,'printshop-mobile','.w-list-type-1_3 .button-view a','color','#183d78','','','.w-list-type-1_3'),(124856,'printshop-mobile','.w-list-type-1_2 .sale','color','#ffffff','4','','.w-list-type-1_2'),(124857,'printshop-mobile','.w-list-type-1_2 .price .specials','color','#ee4225','','','.w-list-type-1_2'),(124858,'printshop-mobile','.w-list-type-1_2 .sale','color','#ee4225','3','','.w-list-type-1_2'),(124859,'printshop-mobile','.b-bottom .pop-up-close','color','#999','','','.b-bottom'),(124860,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','color','#183d78','','','.w-list-type-1_2'),(124861,'printshop-mobile','.b-bottom .pop-up-close','color','#777','1','','.b-bottom'),(124862,'printshop-mobile','.w-list-type-1 .sale','color','#ffffff','4','','.w-list-type-1'),(124863,'printshop-mobile','.w-list-type-1 .sale','color','#ee4225','3','','.w-list-type-1'),(124864,'printshop-mobile','.w-list-type-1_2 .button-view a','color','#183d78','','','.w-list-type-1_2'),(124865,'printshop-mobile','.heading-4 .edit, h4 .edit','color','#092964','','',''),(124866,'printshop-mobile','.w-list-type-1 .button-wishlist button','color','#183d78','','','.w-list-type-1'),(124867,'printshop-mobile','.w-filters .open','color','#15286f','3','','.w-filters'),(124868,'printshop-mobile','.in-stock','color','#00a858','','',''),(124869,'printshop-mobile','.out-stock','color','#ee4225','','',''),(124870,'printshop-mobile','.transit','color','#a47615','','',''),(124871,'printshop-mobile','.w-filters .view_more','color','#15286f','','','.w-filters'),(124872,'printshop-mobile','.w-list-type-1 .button-view a','color','#183d78','','','.w-list-type-1'),(124873,'printshop-mobile','.w-languages .current','color','#b0b0b0','3','','.w-languages'),(124874,'printshop-mobile','.p-account-index .date_value strong','color','#000','','','.p-account-index'),(124875,'printshop-mobile','.w-reviews .reviews-list .date','color','#999999','','','.w-reviews'),(124876,'printshop-mobile','.w-reviews .heading-3','color','#183d78','3','','.w-reviews'),(124877,'printshop-mobile','.w-search .button-search','color','#092964','3','','.w-search'),(124878,'printshop-mobile','.w-socials .post_item > div.fb_post_item','color','#4267b2','3','','.w-socials'),(124879,'printshop-mobile','.w-socials .post_item > div.tw_post_item','color','#1da1f2','3','','.w-socials'),(124880,'printshop-mobile','.w-socials .post_item_name a','color','#424242','','','.w-socials'),(124881,'printshop-mobile','.w-socials .post_item > div.insta_post_item','color','#f53d42','3','','.w-socials'),(124882,'printshop-mobile','.btn-del','color','#de0404','4','',''),(124883,'printshop-mobile','.b-form .required','color','#ed4224','','','.b-form'),(124884,'printshop-mobile','.b-form .required-message','color','#ed4224','','','.b-form'),(124885,'printshop-mobile','.b-form .middle-form label','color','#000','','','.b-form'),(124886,'printshop-mobile','.p-account-address-book .rightMes ul','color','#ee4225','','','.p-account-address-book'),(124887,'printshop-mobile','.p-account-address-book .leftMes ul','color','#ee4225','','','.p-account-address-book'),(124888,'printshop-mobile','.p-account-address-book .leftMes div','color','#ee4225','','','.p-account-address-book'),(124889,'printshop-mobile','.b-info .info','color','#ee4225','','','.b-info'),(124890,'printshop-mobile','.b-info-popup .info-popup','color','#ee4225','3','','.b-info-popup'),(124891,'printshop-mobile','.b-products-listing .products-listing .bonus-points span:first-child','color','#183d78','','','.b-products-listing'),(124892,'printshop-mobile','.b-products-listing .products-listing .bonus-points-cost','color','#183d78','3','','.b-products-listing'),(124893,'printshop-mobile','.b-products-listing .products-listing .bonus-points-price','color','#183d78','3','','.b-products-listing'),(124894,'printshop-mobile','.b-products-listing .products-listing .name a','color','#424242','','','.b-products-listing'),(124895,'printshop-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','color','#00a858','','','.b-products-listing'),(124896,'printshop-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','color','#00a858','','','.b-products-listing'),(124897,'printshop-mobile','.b-products-listing .products-listing h2','color','inherit','','','.b-products-listing'),(124898,'printshop-mobile','.b-products-listing .promos-info .promo-name','color','#ee4225','','','.b-products-listing'),(124899,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','#424242','','','.b-data-table'),(124900,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','#183d78','','','.b-data-table'),(124901,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','#183d78','1','','.b-data-table'),(124902,'printshop-mobile','.b-delete-account .delete-box .delete-message','color','#ee4225','','','.b-delete-account'),(124903,'printshop-mobile','.b-email-editor .special-price','color','#ee4225','','','.b-email-editor'),(124904,'printshop-mobile','.b-email-editor .name a','color','#424242','','','.b-email-editor'),(124905,'printshop-mobile','.b-email-editor a','color','#424242','','','.b-email-editor'),(124906,'printshop-mobile','.b-email-editor .name a','color','#424242','','','.b-email-editor'),(124907,'printshop-mobile','.b-email-editor .special-price','color','#ee4225','','','.b-email-editor'),(124908,'printshop-mobile','.b-email-editor .price','color','#183d78','','','.b-email-editor'),(124909,'printshop-mobile','.b-email-editor .price','color','#183d78','','','.b-email-editor'),(124910,'printshop-mobile','.b-email-editor .price','color','#183d78','','','.b-email-editor'),(124911,'printshop-mobile','.b-email-editor a','color','#424242','','','.b-email-editor'),(124912,'printshop-mobile','.b-email-editor .special-price','color','#ee4225','','','.b-email-editor'),(124913,'printshop-mobile','.b-email-editor .name a','color','#424242','','','.b-email-editor'),(124914,'printshop-mobile','.b-email-editor .price','color','#183d78','','','.b-email-editor'),(124915,'printshop-mobile','.b-email-editor .special-price','color','#ee4225','','','.b-email-editor'),(124916,'printshop-mobile','.b-email-editor .name a','color','#424242','','','.b-email-editor'),(124917,'printshop-mobile','.b-email-editor .name a','color','#424242','','','.b-email-editor'),(124918,'printshop-mobile','.b-email-editor a','color','#424242','','','.b-email-editor'),(124919,'printshop-mobile','.b-email-editor a','color','#424242','','','.b-email-editor'),(124920,'printshop-mobile','.b-email-editor .name a','color','#424242','','','.b-email-editor'),(124921,'printshop-mobile','.b-email-editor a','color','#424242','','','.b-email-editor'),(124922,'printshop-mobile','.b-email-editor a','color','#424242','','','.b-email-editor'),(124923,'printshop-mobile','.b-email-editor .special-price','color','#ee4225','','','.b-email-editor'),(124924,'printshop-mobile','.b-email-editor .special-price','color','#ee4225','','','.b-email-editor'),(124925,'printshop-mobile','.b-email-editor .price','color','#183d78','','','.b-email-editor'),(124926,'printshop-mobile','.b-email-editor .price','color','#183d78','','','.b-email-editor'),(124927,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2','color','#141412','','','.b-menu-style-1'),(124928,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','color','#183d78','','','.b-menu-style-1'),(124929,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','color','#fff','','','.b-menu-style-2'),(124930,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','color','#fff','','','.b-menu-style-2'),(124931,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','color','#183d78','','','.b-menu-style-2'),(124932,'printshop-mobile','.b-messages .messMenuButton span','color','#183d78','','','.b-messages'),(124933,'printshop-mobile','.b-messages .messages-menu li a','color','#424242','','','.b-messages'),(124934,'printshop-mobile','.b-messages .content_management_attach','color','#183d78','','','.b-messages'),(124935,'printshop-mobile','.b-messages .content_management_attach button','color','#183d78','','','.b-messages'),(124936,'printshop-mobile','.b-messages .select2-search-choice-close','color','#757575','3','','.b-messages'),(124937,'printshop-mobile','.b-personal-catalog-popup #personal_catalog_popup .show-all-lists','color','#183d78','','','.b-personal-catalog-popup'),(124938,'printshop-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','color','#424242','','','.b-select-suggest'),(124939,'printshop-mobile','.b-select-suggest .select2-drop','color','#424242','','','.b-select-suggest'),(124940,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','color','#424242','','','.b-select-suggest'),(124941,'printshop-mobile','.b-select-suggest .select2-results .select2-highlighted','color','#424242','','','.b-select-suggest'),(124942,'printshop-mobile','.b-select-suggest .select2-results .select2-highlighted ul','color','#424242','','','.b-select-suggest'),(124943,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','color','#424242','','','.b-select-suggest'),(124944,'printshop-mobile','.b-select-suggest .select2-default','color','#757575','','','.b-select-suggest'),(124945,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','color','#424242','','','.b-select-suggest'),(124946,'printshop-mobile','.b-trade-approval .steps-bar li.current a','color','#fff','','','.b-trade-approval'),(124947,'printshop-mobile','.b-trade-approval .middle-form label','color','#424242','','','.b-trade-approval'),(124948,'printshop-mobile','.b-upload-file .snapshot','color','#757575','','','.b-upload-file'),(124949,'printshop-mobile','.b-upload-files .remove-file','color','#ee4225','3','','.b-upload-files'),(124950,'printshop-mobile','.b-warehouses-popup a.warehouses-popup-link','color','#424242','','','.b-warehouses-popup'),(124951,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','color','#ee4225','','','.b-warehouses-popup'),(124952,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','color','#00a858','','','.b-warehouses-popup'),(124953,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','color','#183d78','','','.b-warehouses-popup'),(124954,'printshop-mobile','.batchPr .checkbox input:checked + span:before','color','#ffffff','','','.batchPr'),(124955,'printshop-mobile','.batchPr .btn-batch-remove','color','#fff','','','.batchPr'),(124956,'printshop-mobile','.bell-ico .heading-2','color','#183d78','3','','.bell-ico'),(124957,'printshop-mobile','.heading-ordered-items .heading-4','color','#183d78','3','','.heading-ordered-items'),(124958,'printshop-mobile','.heading-saved-lists .heading-4','color','#183d78','3','','.heading-saved-lists'),(124959,'printshop-mobile','.heading-settings .heading-4','color','#183d78','3','','.heading-settings'),(124960,'printshop-mobile','.p-account-samples-history .moduleRowDue td','color','#cccccc','','','.p-account-samples-history'),(124961,'printshop-mobile','.p-account-samples-history .moduleRowDue td','color','#cccccc','','','.p-account-samples-history'),(124962,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history'),(124963,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history'),(124964,'printshop-mobile','.p-account-samples-history .view_link','color','#183d78','','','.p-account-samples-history'),(124965,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history'),(124966,'printshop-mobile','.p-account-samples-history .view_link','color','#183d78','','','.p-account-samples-history'),(124967,'printshop-mobile','.p-account-samples-history .moduleRowDue td','color','#cccccc','','','.p-account-samples-history'),(124968,'printshop-mobile','.p-account-samples-history .moduleRowDue td','color','#cccccc','','','.p-account-samples-history'),(124969,'printshop-mobile','.p-account-samples-history .moduleRowDue td','color','#cccccc','','','.p-account-samples-history'),(124970,'printshop-mobile','.p-account-samples-history .view_link','color','#183d78','','','.p-account-samples-history'),(124971,'printshop-mobile','.p-account-samples-history .moduleRowDue td','color','#cccccc','','','.p-account-samples-history'),(124972,'printshop-mobile','.p-account-samples-history .view_link','color','#183d78','','','.p-account-samples-history'),(124973,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history'),(124974,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history'),(124975,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history'),(124976,'printshop-mobile','.p-account-samples-history .view_link','color','#183d78','','','.p-account-samples-history'),(124977,'printshop-mobile','.p-account-samples-history .view_link','color','#183d78','','','.p-account-samples-history'),(124978,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history-info'),(124979,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history-info'),(124980,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','color','#183d78','3','','.p-account-samples-history-info'),(124981,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','color','#183d78','3','','.p-account-samples-history-info'),(124982,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','color','#183d78','3','','.p-account-samples-history-info'),(124983,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','color','#183d78','3','','.p-account-samples-history-info'),(124984,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history-info'),(124985,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history-info'),(124986,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','color','#183d78','3','','.p-account-samples-history-info'),(124987,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','color','#183d78','3','','.p-account-samples-history-info'),(124988,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history-info'),(124989,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history-info'),(124990,'printshop-mobile','.p-account-update .main-text a','color','#183d78','','','.p-account-update'),(124991,'printshop-mobile','.p-account-update .main-text a','color','#183d78','','','.p-account-update'),(124992,'printshop-mobile','.p-account-update .main-text a','color','#183d78','','','.p-account-update'),(124993,'printshop-mobile','.p-account-update .main-text a','color','#183d78','','','.p-account-update'),(124994,'printshop-mobile','.p-account-update .main-text a','color','#183d78','','','.p-account-update'),(124995,'printshop-mobile','.p-account-update .main-text a','color','#183d78','','','.p-account-update'),(124996,'printshop-mobile','.p-catalog-product .pn-direction','color','#183d78','','','.p-catalog-product'),(124997,'printshop-mobile','.p-catalog-product .pn-image','color','#cccccc','3','','.p-catalog-product'),(124998,'printshop-mobile','.p-payer-order-confirmation .discount-ico','color','#183d78','3','','.p-payer-order-confirmation'),(124999,'printshop-mobile','.p-payer-order-confirmation .ship-ico','color','#183d78','3','','.p-payer-order-confirmation'),(125000,'printshop-mobile','.p-payer-order-confirmation .comment-ico','color','#183d78','3','','.p-payer-order-confirmation'),(125001,'printshop-mobile','.p-payer-order-confirmation .order-ico','color','#183d78','3','','.p-payer-order-confirmation'),(125002,'printshop-mobile','.p-payer-order-confirmation .pay-ico','color','#183d78','3','','.p-payer-order-confirmation'),(125003,'printshop-mobile','.p-payer-order-pay .ship-ico','color','#183d78','3','','.p-payer-order-pay'),(125004,'printshop-mobile','.p-payer-order-pay .pay-ico','color','#183d78','3','','.p-payer-order-pay'),(125005,'printshop-mobile','.p-payer-order-pay .comment-ico','color','#183d78','3','','.p-payer-order-pay'),(125006,'printshop-mobile','.p-payer-order-pay .order-ico','color','#183d78','3','','.p-payer-order-pay'),(125007,'printshop-mobile','.p-payer-order-pay .discount-ico','color','#183d78','3','','.p-payer-order-pay'),(125008,'printshop-mobile','.p-quick-order-index .all-scroll-div','color','#ffffff','','','.p-quick-order-index'),(125009,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','#183d78','1','','.p-quick-order-index'),(125010,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','#183d78','','','.p-quick-order-index'),(125011,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','#424242','','','.p-quick-order-index'),(125012,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','color','#183d78','3','','.p-quote-checkout-success'),(125013,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','color','#183d78','3','','.p-quote-checkout-success'),(125014,'printshop-mobile','.p-quote-checkout-success .page-success .text-3','color','#ee4225','','','.p-quote-checkout-success'),(125015,'printshop-mobile','.p-quote-checkout-success .page-success .text-3','color','#ee4225','','','.p-quote-checkout-success'),(125016,'printshop-mobile','.p-quote-checkout-success .page-success .text-3','color','#ee4225','','','.p-quote-checkout-success'),(125017,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','color','#183d78','3','','.p-quote-checkout-success'),(125018,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','color','#183d78','3','','.p-quote-checkout-success'),(125019,'printshop-mobile','.p-quote-checkout-success .page-success .text-3','color','#ee4225','','','.p-quote-checkout-success'),(125020,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','color','#183d78','3','','.p-quote-checkout-success'),(125021,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','color','#183d78','3','','.p-quote-checkout-success'),(125022,'printshop-mobile','.p-quote-checkout-success .page-success .text-3','color','#ee4225','','','.p-quote-checkout-success'),(125023,'printshop-mobile','.p-quote-checkout-success .page-success .text-3','color','#ee4225','','','.p-quote-checkout-success'),(125024,'printshop-mobile','.p-sample-checkout-success .page-success .text-3','color','#ee4225','','','.p-sample-checkout-success'),(125025,'printshop-mobile','.p-sample-checkout-success .page-success .text-1','color','#183d78','3','','.p-sample-checkout-success'),(125026,'printshop-mobile','.savings-ico .heading-2','color','#00a858','3','','.savings-ico'),(125027,'printshop-mobile','.shipping-ico .heading-2','color','#183d78','3','','.shipping-ico'),(125028,'printshop-mobile','.shipping-ico .heading-2','color','#00a858','3','','.shipping-ico'),(125029,'printshop-mobile','.shipping-ico .heading-2','color','#00a858','3','','.shipping-ico'),(125030,'printshop-mobile','.w-account-address-book .add_item a.disabled-link','color','#eaeaea','','','.w-account-address-book'),(125031,'printshop-mobile','.w-account-address-book .add_item a','color','#c4c4c4','','','.w-account-address-book'),(125032,'printshop-mobile','.w-account-personal-catalog .list-switcher a','color','#183d78','2','','.w-account-personal-catalog'),(125033,'printshop-mobile','.w-blog-widget-categories-list a','color','#424242','','','.w-blog-widget-categories-list'),(125034,'printshop-mobile','.w-blog-widget-most-popular-posts a','color','#424242','','','.w-blog-widget-most-popular-posts'),(125035,'printshop-mobile','.w-blog-widget-post-comments-count span','color','#CEC0A6','3','','.w-blog-widget-post-comments-count'),(125036,'printshop-mobile','.w-blog-widget-post-date ','color','#424242','','','.w-blog-widget-post-date'),(125037,'printshop-mobile','.w-blog-widget-post-listing .post_comment','color','#CEC0A6','3','','.w-blog-widget-post-listing'),(125038,'printshop-mobile','.w-blog-widget-post-listing .post_tagged a','color','#424242','','','.w-blog-widget-post-listing'),(125039,'printshop-mobile','.w-blog-widget-post-listing .post_name a','color','#424242','','','.w-blog-widget-post-listing'),(125040,'printshop-mobile','.w-blog-widget-post-share .facebook-btn','color','#424242','3','','.w-blog-widget-post-share'),(125041,'printshop-mobile','.w-blog-widget-post-share .pinterest-btn','color','#424242','3','','.w-blog-widget-post-share'),(125042,'printshop-mobile','.w-blog-widget-post-share .twitter-btn','color','#424242','3','','.w-blog-widget-post-share'),(125043,'printshop-mobile','.w-blog-widget-post-share .printto','color','#CEC0A6','3','','.w-blog-widget-post-share'),(125044,'printshop-mobile','.w-blog-widget-post-share .mailto','color','#CEC0A6','3','','.w-blog-widget-post-share'),(125045,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','color','#424242','3','','.w-blog-widget-related-posts'),(125046,'printshop-mobile','.w-blog-widget-related-posts .post_content a','color','#AC4A4B','','','.w-blog-widget-related-posts'),(125047,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_content a','color','#424242','','','.w-blog-widget-related-posts-by-category'),(125048,'printshop-mobile','.w-blog-widget-tag-cloud a','color','#424242','','','.w-blog-widget-tag-cloud'),(125049,'printshop-mobile','.w-cart-bonus-points .title','color','#00a858','3','','.w-cart-bonus-points'),(125050,'printshop-mobile','.w-cart-compare .product .name a','color','#424242','','','.w-cart-compare'),(125051,'printshop-mobile','.w-cart-compare .cart-name a','color','#424242','','','.w-cart-compare'),(125052,'printshop-mobile','.w-cart-compare .delete-cart','color','#424242','3','','.w-cart-compare'),(125053,'printshop-mobile','.w-cart-compare .product-actions .dropdown-toggle','color','#757575','','','.w-cart-compare'),(125054,'printshop-mobile','.w-cart-credit-amount .amount-title','color','#00a858','3','','.w-cart-credit-amount'),(125055,'printshop-mobile','.w-cart-credit-amount #credit_modules_message.error','color','#ee4225','','','.w-cart-credit-amount'),(125056,'printshop-mobile','.w-cart-credit-amount #credit_modules_message','color','#00a858','','','.w-cart-credit-amount'),(125057,'printshop-mobile','.w-catalog-b2b-add-button ','color','#ffffff','','','.w-catalog-b2b-add-button'),(125058,'printshop-mobile','.w-catalog-compare .checkbox input:checked + span:before','color','#999999','','','.w-catalog-compare'),(125059,'printshop-mobile','.w-catalog-compare span.btn-preloader','color','#183d78','3','','.w-catalog-compare'),(125060,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','color','#183d78','2','','.w-catalog-compare'),(125061,'printshop-mobile','.w-catalog-compare .cross-box .return','color','#183d78','','','.w-catalog-compare'),(125062,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','color','#183d78','3','','.w-catalog-compare'),(125063,'printshop-mobile','.w-catalog-paging ','color','#ffffff','2','','.w-catalog-paging'),(125064,'printshop-mobile','.w-checkout-shipping-choice span','color','#183d78','','','.w-checkout-shipping-choice'),(125065,'printshop-mobile','.w-checkout-shipping-choice input:checked + span','color','#ffffff','','','.w-checkout-shipping-choice'),(125066,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','color','#4a4a4a','','','.w-communication-new-topic'),(125067,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','color','#4a4a4a','','','.w-communication-new-topic'),(125068,'printshop-mobile','.w-coupons-and-vauchers-checkout #credit_modules_message.error','color','#ee4225','','','.w-coupons-and-vauchers-checkout'),(125069,'printshop-mobile','.w-coupons-and-vauchers-checkout #credit_modules_message','color','#00a858','','','.w-coupons-and-vauchers-checkout'),(125070,'printshop-mobile','.w-delivery-day .ends','color','#ee4225','','','.w-delivery-day'),(125071,'printshop-mobile','.w-delivery-day .left-count-days-text, .w-delivery-day .left-count-hours-text, .w-delivery-day .left-count-minutes-text, .w-delivery-day .left-count-seconds-text','color','#ffffff','','','.w-delivery-day'),(125072,'printshop-mobile','.w-image-maps .float-items .item .description','color','#424242','','','.w-image-maps'),(125073,'printshop-mobile','.w-image-maps .categories-items .item .description','color','#424242','','','.w-image-maps'),(125074,'printshop-mobile','.w-image-maps .default-links .item .description','color','#424242','','','.w-image-maps'),(125075,'printshop-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','color','#757575','3','','.w-multi-cart-actions'),(125076,'printshop-mobile','.w-personal-gift-status-bar .end-date','color','#183d78','3','','.w-personal-gift-status-bar'),(125077,'printshop-mobile','.w-personal-gift-status-bar .end-label','color','#183d78','','','.w-personal-gift-status-bar'),(125078,'printshop-mobile','.w-personal-gift-status-bar .inform','color','#183d78','4','','.w-personal-gift-status-bar'),(125079,'printshop-mobile','.w-personal-gift-status-bar .start-label','color','#183d78','','','.w-personal-gift-status-bar'),(125080,'printshop-mobile','.w-product-custom-bundle .save','color','#00a858','','','.w-product-custom-bundle'),(125081,'printshop-mobile','.w-product-custom-bundle .save','color','#00a858','','','.w-product-custom-bundle'),(125082,'printshop-mobile','.w-product-custom-bundle .save','color','#00a858','','','.w-product-custom-bundle'),(125083,'printshop-mobile','.w-product-custom-bundle .save','color','#00a858','','','.w-product-custom-bundle'),(125084,'printshop-mobile','.w-product-custom-bundle .save','color','#00a858','','','.w-product-custom-bundle'),(125085,'printshop-mobile','.w-product-custom-bundle .save','color','#00a858','','','.w-product-custom-bundle'),(125086,'printshop-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','color','#f8a100','3','','.w-promotions'),(125087,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','color','#ee4225','','','.w-promotions'),(125088,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','color','#ee4225','','','.w-promotions'),(125089,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','color','#ee4225','','','.w-promotions'),(125090,'printshop-mobile','.w-promotions .promo-salemaker .discount','color','#ff6d00','','','.w-promotions'),(125091,'printshop-mobile','.w-promotions .promo-cart-discount .item a','color','#424242','','','.w-promotions'),(125092,'printshop-mobile','.w-promotions .promo-salemaker .content a','color','#424242','','','.w-promotions'),(125093,'printshop-mobile','.w-promotions .specials_category .heading-3','color','#ff6d00','','','.w-promotions'),(125094,'printshop-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .specials_category .promo-conditions','color','#ff6d00','3','','.w-promotions'),(125095,'printshop-mobile','.w-promotions .specials_category .promo-salemaker .content a, .w-promotions .specials_category .promo-date','color','#ff6d00','3','','.w-promotions'),(125096,'printshop-mobile','.w-promotions .cart_discount .heading-3','color','#f8a100','','','.w-promotions'),(125097,'printshop-mobile','.w-promotions .cart_discount .promo-date','color','#f8a100','3','','.w-promotions'),(125098,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range, .w-promotions .prom-multi-discount > .heading','color','#ee4225','3','','.w-promotions'),(125099,'printshop-mobile','.w-promotions .multidiscount .promo-date, .w-promotions .multidiscount .heading-3','color','#ee4225','','','.w-promotions'),(125100,'printshop-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','color','#424242','','','.w-promotions'),(125101,'printshop-mobile','.w-reviews-content .date','color','#cccccc','','','.w-reviews-content'),(125102,'printshop-mobile','.w-reviews-content .product-name a','color','#183d78','','','.w-reviews-content'),(125103,'printshop-mobile','.w-social-links .google-plus','color','#ee4225','3','','.w-social-links'),(125104,'printshop-mobile','.w-social-links .twitter','color','#1da1f2','3','','.w-social-links'),(125105,'printshop-mobile','.w-social-links .stumbleupon','color','#ee4225','3','','.w-social-links'),(125106,'printshop-mobile','.w-social-links .facebook','color','#183d78','3','','.w-social-links'),(125107,'printshop-mobile','.w-social-links .linkedin','color','#183d78','3','','.w-social-links'),(125108,'printshop-mobile','.w-social-links .instagram','color','#ee4225','3','','.w-social-links'),(125109,'printshop-mobile','.w-social-links .pinterest','color','#ee4225','3','','.w-social-links'),(125110,'printshop-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','color','#fff','','','.w-taxable'),(125111,'printshop-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','color','#fff','','','.w-taxable'),(125112,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','color','#f52f1b','','','.w-upload-customer-id-upload-customer-id-form'),(125113,'printshop-mobile','.w-wedding-registry-widgets-delete-link a','color','#cccccc','4','','.w-wedding-registry-widgets-delete-link'),(125114,'printshop-mobile','.w-wedding-registry-widgets-manage-names .names-separator','color','#ee4225','','','.w-wedding-registry-widgets-manage-names'),(125115,'printshop-mobile','.w-wedding-registry-widgets-products .remove-btn','color','#757575','3','','.w-wedding-registry-widgets-products'),(125116,'printshop-mobile','.w-wedding-registry-widgets-share-link a','color','#cccccc','4','','.w-wedding-registry-widgets-share-link'),(125117,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.b-data-table'),(125118,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.b-data-table'),(125119,'printshop-mobile','.b-select-suggest .select2-default','color_important','important','','','.b-select-suggest'),(125120,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.p-quick-order-index'),(125121,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.p-quick-order-index'),(125122,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','column-count','4','','','.b-menu-style-1'),(125123,'printshop-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','content','\\f067','3','','.w-menu'),(125124,'printshop-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','content','\\f068','3','','.w-menu'),(125125,'printshop-mobile','.w-menu .menu .menu-ico','content','\\e91b','3','','.w-menu'),(125126,'printshop-mobile','.w-menu-slider .close','content','\\f00d','3','','.w-menu-slider'),(125127,'printshop-mobile','.w-bestsellers .item:first-child:before','content','\\e90c','','','.w-bestsellers'),(125128,'printshop-mobile','.w-bestsellers .heading-3','content','\\e903','3','','.w-bestsellers'),(125129,'printshop-mobile','.w-bestsellers .item','content','\\e90b','3','','.w-bestsellers'),(125130,'printshop-mobile','.w-account .my-acc-link','content','\\f007','3','','.w-account'),(125131,'printshop-mobile','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(125132,'printshop-mobile','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(125133,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','content','\\f1db','','','.b-form'),(125134,'printshop-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','content','\\f058','','','.b-form'),(125135,'printshop-mobile','.w-login-block .cols','content','\\_','4','','.w-login-block'),(125136,'printshop-mobile','.w-list-type-2_2 .sale','content','SALE','4','','.w-list-type-2_2'),(125137,'printshop-mobile','.w-html_box .stumbleupon','content','\\f1a4','3','','.w-html_box'),(125138,'printshop-mobile','.w-html_box .twitter','content','\\f099','3','','.w-html_box'),(125139,'printshop-mobile','.w-html_box .linkedin','content','\\f0e1','3','','.w-html_box'),(125140,'printshop-mobile','.w-html_box .instagram','content','\\f16d','3','','.w-html_box'),(125141,'printshop-mobile','.w-html_box .pinterest','content','\\f0d2','3','','.w-html_box'),(125142,'printshop-mobile','.w-html_box .facebook','content','\\f230','3','','.w-html_box'),(125143,'printshop-mobile','.w-html_box .google-plus','content','\\f2b3','3','','.w-html_box'),(125144,'printshop-mobile','.w-product-attributes .attributes','content','\\_','4','','.w-product-attributes'),(125145,'printshop-mobile','.w-product-wedding-registry-button .btn','content','\\_','3','','.w-product-wedding-registry-button'),(125146,'printshop-mobile','.w-cart a.item','content','\\_','4','','.w-cart'),(125147,'printshop-mobile','.w-cart .cart-box-link','content','\\e90d','3','','.w-cart'),(125148,'printshop-mobile','.w-cart .qty','content','\\274c','4','','.w-cart'),(125149,'printshop-mobile','.w-categories .categories','content','\\_','4','','.w-categories'),(125150,'printshop-mobile','.w-catalog-listing-look .list','content','\\f00b','3','','.w-catalog-listing-look'),(125151,'printshop-mobile','.b-pagination .pagination .prev','content','\\f104','3','','.b-pagination'),(125152,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','content','\\e917','4','','.b-multi-page-checkout'),(125153,'printshop-mobile','.b-pagination .pagination','content','\\_','4','','.b-pagination'),(125154,'printshop-mobile','.b-pagination .pagination .next','content','\\f105','3','','.b-pagination'),(125155,'printshop-mobile','.w-quote .cart-box-link','content','\\e90d','3','','.w-quote'),(125156,'printshop-mobile','.b-product-images .main-image-box','content','\\_','4','','.b-product-images'),(125157,'printshop-mobile','.p-checkout-success .page-success','content','\\_','693,3','','.p-checkout-success'),(125158,'printshop-mobile','.w-cart-shipping-estimator .shipping-estimator','content','\\_','4','','.w-cart-shipping-estimator'),(125159,'printshop-mobile','.w-list-type-2_2 .sale','content','\\e909','3','','.w-list-type-2_2'),(125160,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','content','\\f00c','3','','.b-multi-page-checkout'),(125161,'printshop-mobile','.p-blog-index .nav-previous a','content','\\f137','3','','.p-blog-index'),(125162,'printshop-mobile','.p-blog-index .wp-widget li','content','\\f111','3','','.p-blog-index'),(125163,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','content','\\_','4','','.b-multi-page-checkout'),(125164,'printshop-mobile','.p-checkout-success .page-success','content','\\e90c','3','','.p-checkout-success'),(125165,'printshop-mobile','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(125166,'printshop-mobile','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(125167,'printshop-mobile','.p-wedding-registry-manage .remove-btn','content','\\e913','3','','.p-wedding-registry-manage'),(125168,'printshop-mobile','.p-wedding-registry-view h1','content','\\f004','4','','.p-wedding-registry-view'),(125169,'printshop-mobile','.w-product-bonus-points > div','content','\\_','4','','.w-product-bonus-points'),(125170,'printshop-mobile','.p-wedding-registry-view h1','content','\\f004','3','','.p-wedding-registry-view'),(125171,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2.title-delivery-address, .p-account-order-pay .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-order-pay'),(125172,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-order-pay'),(125173,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-order-pay'),(125174,'printshop-mobile','.js-stock-icon','content','\\f058','3','',''),(125175,'printshop-mobile','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(125176,'printshop-mobile','.testimonials .heading-3','content','\\e908','3','',''),(125177,'printshop-mobile','.testimonials .review','content','\\_','3','',''),(125178,'printshop-mobile','.p-wedding-registry-manage .wr-search button','content','\\e90a','3','','.p-wedding-registry-manage'),(125179,'printshop-mobile','.p-account-history .view_link','content','\\e901','4','','.p-account-history'),(125180,'printshop-mobile','.p-blog-index .nav-next a','content','\\f138','3','','.p-blog-index'),(125181,'printshop-mobile','.p-blog-index .entry-content','content','\\_','4','','.p-blog-index'),(125182,'printshop-mobile','.p-blog-index .comment-meta','content','\\_','4','','.p-blog-index'),(125183,'printshop-mobile','.w-list-type-2_2 .item','content','\\_','4','','.w-list-type-2_2'),(125184,'printshop-mobile','.out-stock-icon','content','\\f10c','3','',''),(125185,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','content','\\e98e','4','','.w-list-type-2_2'),(125186,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-2_2'),(125187,'printshop-mobile','.buttons','content','\\_','4','',''),(125188,'printshop-mobile','.w-list-type-2_2 .button-view a','content','\\e98f','4','','.w-list-type-2_2'),(125189,'printshop-mobile','.w-list-type-2_2 .add-height','content','\\_','4','','.w-list-type-2_2'),(125190,'printshop-mobile','.w-product-personal-catalog-button .btn','content','\\f097','3','','.w-product-personal-catalog-button'),(125191,'printshop-mobile','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(125192,'printshop-mobile','.w-product-wedding-registry-button .btn','content','\\_','4','','.w-product-wedding-registry-button'),(125193,'printshop-mobile','.w-product-bonus-points > div > div','content','\\f219','3','','.w-product-bonus-points'),(125194,'printshop-mobile','.w-chat .w-chat-box a','content','\\f075','3','','.w-chat'),(125195,'printshop-mobile','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(125196,'printshop-mobile','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(125197,'printshop-mobile','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(125198,'printshop-mobile','.p-wedding-registry-index .search-list','content','\\_','3','','.p-wedding-registry-index'),(125199,'printshop-mobile','.p-wedding-registry-index .main-button','content','\\f004','4','','.p-wedding-registry-index'),(125200,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','content','\\f00c','3','','.b-form'),(125201,'printshop-mobile','.p-wedding-registry-index .main-button','content','\\f004','3','','.p-wedding-registry-index'),(125202,'printshop-mobile','.p-wedding-registry-search h1','content','\\f004','4','','.p-wedding-registry-search'),(125203,'printshop-mobile','.p-wedding-registry-manage .links a.share-registry','content','\\f14d','4','','.p-wedding-registry-manage'),(125204,'printshop-mobile','.p-wedding-registry-search h1','content','\\f004','3','','.p-wedding-registry-search'),(125205,'printshop-mobile','.p-wedding-registry-manage h1','content','\\f004','3','','.p-wedding-registry-manage'),(125206,'printshop-mobile','.p-wedding-registry-manage h1','content','\\f004','4','','.p-wedding-registry-manage'),(125207,'printshop-mobile','.p-account-address-book .btn-edit','content','\\e917','4','','.p-account-address-book'),(125208,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','content',' ','3','','.b-switch'),(125209,'printshop-mobile','.b-compare .clear_all','content','\\f00d','4','','.b-compare'),(125210,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','content',' ','3','','.b-switch'),(125211,'printshop-mobile','.b-slick button.slick-prev','content','\\f053','3','','.b-slick'),(125212,'printshop-mobile','.b-bottom .footerTitle','content','\\f067','693,4','','.b-bottom'),(125213,'printshop-mobile','.b-slick button.slick-next','content','\\f054','3','','.b-slick'),(125214,'printshop-mobile','.heading-3 .edit, h3 .edit','content','\\e917','4','',''),(125215,'printshop-mobile','.w-list-type-1 .button-view a','content','\\e98f','4','','.w-list-type-1'),(125216,'printshop-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','content','\\f1db','','','.w-filters'),(125217,'printshop-mobile','.w-top-categories .categories','content','\\_','4','','.w-top-categories'),(125218,'printshop-mobile','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(125219,'printshop-mobile','.w-search .search','content','\\e90a','3','','.w-search'),(125220,'printshop-mobile','.b-bottom .footerTitle','content','\\f068','693,2,4','','.b-bottom'),(125221,'printshop-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','content','\\f058','','','.w-filters'),(125222,'printshop-mobile','.w-currencies .current','content','\\e902','3','','.w-currencies'),(125223,'printshop-mobile','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(125224,'printshop-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(125225,'printshop-mobile','.w-compare-box-item .checkbox:checked + span:before','content','\\f00c','','','.w-compare-box-item'),(125226,'printshop-mobile','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(125227,'printshop-mobile','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(125228,'printshop-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','content','\\_','','','.w-compare-box-item'),(125229,'printshop-mobile','.b-slick .slick-vertical button.slick-prev','content','\\f077','3','','.b-slick'),(125230,'printshop-mobile','.b-slick .slick-track, .b-slick .slick-track:after','content','\\_','3','','.b-slick'),(125231,'printshop-mobile','.b-slick .slick-vertical button.slick-next','content','\\f078','3','','.b-slick'),(125232,'printshop-mobile','.p-account-trade-form .wd-line-row-2','content','\\_','4','','.p-account-trade-form'),(125233,'printshop-mobile','.p-account-index .view_link','content','\\e901','4','','.p-account-index'),(125234,'printshop-mobile','.b-info-popup .info-popup','content','\\e918','3','','.b-info-popup'),(125235,'printshop-mobile','.p-account-index .view_history','content','\\e991','3','','.p-account-index'),(125236,'printshop-mobile','.b-info-popup .info-popup div','content','\\_','3','','.b-info-popup'),(125237,'printshop-mobile','.p-account-index .topAccount > li > div.order_count','content','\\e928','3','','.p-account-index'),(125238,'printshop-mobile','.p-account-index .topAccount > li > div.total_count','content','\\e922','3','','.p-account-index'),(125239,'printshop-mobile','.p-account-index .topAccount > li > div.dateLast','content','\\e920','3','','.p-account-index'),(125240,'printshop-mobile','.p-account-index .topAccount > li > div.points_earnt','content','\\e990','3','','.p-account-index'),(125241,'printshop-mobile','.w-menu-mobile .menu-ico','content','\\e91b','3','','.w-menu-mobile'),(125242,'printshop-mobile','.p-checkout-success .page-success .text-1','content','\\e916','3','','.p-checkout-success'),(125243,'printshop-mobile','.b-fancybox .fancybox-next span','content','\\e901','3','','.b-fancybox'),(125244,'printshop-mobile','.p-account-index .topAccount > li > div.credit_amount_ac','content','\\e994','3','','.p-account-index'),(125245,'printshop-mobile','.w-product-quantity-discounts .quantity-discounts .count','content','+','4','','.w-product-quantity-discounts'),(125246,'printshop-mobile','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(125247,'printshop-mobile','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(125248,'printshop-mobile','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(125249,'printshop-mobile','.b-fancybox .fancybox-prev span','content','\\e900','3','','.b-fancybox'),(125250,'printshop-mobile','.p-wedding-registry-share .invite-remove','content','\\e913','3','','.p-wedding-registry-share'),(125251,'printshop-mobile','.w-text .customer-service','content','\\e907','3','','.w-text'),(125252,'printshop-mobile','.b-rating .glyphicon-chevron-right','content','\\f105','3','','.b-rating'),(125253,'printshop-mobile','.b-rating .glyphicon-calendar','content','\\f073','3','','.b-rating'),(125254,'printshop-mobile','.b-rating .glyphicon-chevron-up','content','\\f106','3','','.b-rating'),(125255,'printshop-mobile','.b-rating .glyphicon-time','content','\\f017','3','','.b-rating'),(125256,'printshop-mobile','.b-rating .glyphicon-chevron-left','content','\\f104','3','','.b-rating'),(125257,'printshop-mobile','.b-rating .glyphicon-chevron-down','content','\\f107','3','','.b-rating'),(125258,'printshop-mobile','.b-rating #stars-default .glyphicon-star','content','\\e90f','3','','.b-rating'),(125259,'printshop-mobile','.b-quantity .qty-box .smaller','content','-','3','','.b-quantity'),(125260,'printshop-mobile','.b-quantity .qty-box .bigger','content','+','3','','.b-quantity'),(125261,'printshop-mobile','.w-breadcrumb .breadcrumb-li + .breadcrumb-li','content','/','3','','.w-breadcrumb'),(125262,'printshop-mobile','.b-fancybox .fancybox-close','content','\\f00d','3','','.b-fancybox'),(125263,'printshop-mobile','.p-reviews-info .review-info-text','content','\\_','4','','.p-reviews-info'),(125264,'printshop-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','content','\\e912','3','','.w-cart-discount-coupon'),(125265,'printshop-mobile','.p-account-index .account_page .icon-address','content','\\e905','3','','.p-account-index'),(125266,'printshop-mobile','.p-account-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-history-info'),(125267,'printshop-mobile','.p-account-index .account_page h4.icon-user','content','\\e921','3','','.p-account-index'),(125268,'printshop-mobile','.p-account-index .account_page h4.icon-password','content','\\e906','3','','.p-account-index'),(125269,'printshop-mobile','.b-form .columns','content','\\_','4','','.b-form'),(125270,'printshop-mobile','.b-form .addresses','content','\\_','4','','.b-form'),(125271,'printshop-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(125272,'printshop-mobile','.w-cart-give-away .ga_name','content','\\_','4','','.w-cart-give-away'),(125273,'printshop-mobile','.p-account-index .account_page h4.icon-mail','content','\\e927','3','','.p-account-index'),(125274,'printshop-mobile','.w-catalog-listing-look .b2b','content','\\f0c9','3','','.w-catalog-listing-look'),(125275,'printshop-mobile','.w-list-type-2 .button-wishlist button','content','\\e98e','4','','.w-list-type-2'),(125276,'printshop-mobile','.w-list-type-1_3 .sale','content','SALE','4','','.w-list-type-1_3'),(125277,'printshop-mobile','.w-list-type-1_3 .sale','content','\\e909','3','','.w-list-type-1_3'),(125278,'printshop-mobile','.w-list-type-2 .add-height','content','\\_','4','','.w-list-type-2'),(125279,'printshop-mobile','.w-list-type-2 .button-view a','content','\\e98f','4','','.w-list-type-2'),(125280,'printshop-mobile','.transit-icon','content','\\f133','3','',''),(125281,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-2'),(125282,'printshop-mobile','.in-stock-icon','content','\\f058','3','',''),(125283,'printshop-mobile','.w-list-type-2 .sale','content','SALE','4','','.w-list-type-2'),(125284,'printshop-mobile','.p-wedding-registry-share h1','content','\\f004','3','','.p-wedding-registry-share'),(125285,'printshop-mobile','.w-catalog-listing-look .grid','content','\\f009','3','','.w-catalog-listing-look'),(125286,'printshop-mobile','.view-all .btn','content','\\f054','4','',''),(125287,'printshop-mobile','.view-all','content','\\_','3','',''),(125288,'printshop-mobile','.p-wedding-registry-share h1','content','\\f004','4','','.p-wedding-registry-share'),(125289,'printshop-mobile','.w-list-type-2 .sale','content','\\e909','3','','.w-list-type-2'),(125290,'printshop-mobile','.w-list-type-1_3 .item','content','\\_','4','','.w-list-type-1_3'),(125291,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-1_3'),(125292,'printshop-mobile','.w-list-type-1_3 .button-view a','content','\\e98f','4','','.w-list-type-1_3'),(125293,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','content','\\e98e','4','','.w-list-type-1_3'),(125294,'printshop-mobile','.w-list-type-1_3 .attributes > .attributes','content','\\_','4','','.w-list-type-1_3'),(125295,'printshop-mobile','.w-list-type-1_2 .sale','content','\\e909','3','','.w-list-type-1_2'),(125296,'printshop-mobile','.w-list-type-1_3 .add-height','content','\\_','4','','.w-list-type-1_3'),(125297,'printshop-mobile','.w-list-type-1_2 .sale','content','SALE','4','','.w-list-type-1_2'),(125298,'printshop-mobile','.w-list-type-1_2 .right-area','content','\\_','4','','.w-list-type-1_2'),(125299,'printshop-mobile','.w-list-type-1_2 .item','content','\\_','4','','.w-list-type-1_2'),(125300,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-1_2'),(125301,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','content','\\e98e','4','','.w-list-type-1_2'),(125302,'printshop-mobile','.w-list-type-1_2 .button-view a','content','\\e98f','4','','.w-list-type-1_2'),(125303,'printshop-mobile','.b-bottom .pop-up-close','content','\\f00d','3','','.b-bottom'),(125304,'printshop-mobile','.w-list-type-1_2 .add-height','content','\\_','4','','.w-list-type-1_2'),(125305,'printshop-mobile','.w-list-type-1 .sale','content','SALE','4','','.w-list-type-1'),(125306,'printshop-mobile','.w-list-type-1 .sale','content','\\e909','3','','.w-list-type-1'),(125307,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-1'),(125308,'printshop-mobile','.w-list-type-1 .button-wishlist button','content','\\e98e','4','','.w-list-type-1'),(125309,'printshop-mobile','.heading-4 .edit, h4 .edit','content','\\e917','4','',''),(125310,'printshop-mobile','.w-filters .open','content','\\f056','3','','.w-filters'),(125311,'printshop-mobile','.w-filters .mobileCollapse','content','\\f056','2,4','','.w-filters'),(125312,'printshop-mobile','.w-filters .mobileCollapse','content','\\f055','4','','.w-filters'),(125313,'printshop-mobile','.w-filters .view_more','content','\\f061','4','','.w-filters'),(125314,'printshop-mobile','.w-filters span.close','content','\\f055','3','','.w-filters'),(125315,'printshop-mobile','.w-languages .current','content','\\e902','3','','.w-languages'),(125316,'printshop-mobile','.w-list-type-1 .add-height','content','\\_','4','','.w-list-type-1'),(125317,'printshop-mobile','.w-product-reviews .reviews-list .review','content','\\_','3','','.w-product-reviews'),(125318,'printshop-mobile','.w-reviews .heading-3','content','\\e908','3','','.w-reviews'),(125319,'printshop-mobile','.w-reviews .review','content','\\_','3','','.w-reviews'),(125320,'printshop-mobile','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(125321,'printshop-mobile','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(125322,'printshop-mobile','.w-search .button-search','content','\\e90a','3','','.w-search'),(125323,'printshop-mobile','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(125324,'printshop-mobile','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(125325,'printshop-mobile','.btn-del','content','\\f1f8','4','',''),(125326,'printshop-mobile','.p-account-history-info .historyInfoColumn h2.title-delivery-address, .p-account-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-history-info'),(125327,'printshop-mobile','.p-account-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-history-info'),(125328,'printshop-mobile','.b-info .info','content','\\e918','3','','.b-info'),(125329,'printshop-mobile','.b-products-listing .BlockBox','content','\\_','4','','.b-products-listing'),(125330,'printshop-mobile','.b-products-listing .btn-preloader','content','\\f110','3','','.b-products-listing'),(125331,'printshop-mobile','.b-products-listing .hover-box-content','content','\\_','3','','.b-products-listing'),(125332,'printshop-mobile','.b-products-listing .loader','content','\\f110','4','','.b-products-listing'),(125333,'printshop-mobile','.b-products-listing .loader','content','\\_','3','','.b-products-listing'),(125334,'printshop-mobile','.b-products-listing .products-listing','content','\\_','4','','.b-products-listing'),(125335,'printshop-mobile','.b-products-listing .products-listing .bonus-points-cost','content','\\f219','3','','.b-products-listing'),(125336,'printshop-mobile','.b-products-listing .products-listing .bonus-points-price','content','\\f219','3','','.b-products-listing'),(125337,'printshop-mobile','.b-products-listing .products-listing .btn-buy','content','\\e977','3','','.b-products-listing'),(125338,'printshop-mobile','.b-products-listing .products-listing .mix-attributes','content','\\_','4','','.b-products-listing'),(125339,'printshop-mobile','.b-products-listing .products-listing .qty-input.hidden','content','\\_','3','','.b-products-listing'),(125340,'printshop-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','content','\\f004','','','.b-products-listing'),(125341,'printshop-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','content','\\f08a','','','.b-products-listing'),(125342,'printshop-mobile','.b-products-listing .products-listing a.btn.view-button','content','\\e991','3','','.b-products-listing'),(125343,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(125344,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(125345,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(125346,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(125347,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(125348,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(125349,'printshop-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','content','\\f0c9','3','','.b-menu-burger_icon'),(125350,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(125351,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(125352,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(125353,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(125354,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(125355,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(125356,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(125357,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(125358,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(125359,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(125360,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','content','\\f107','4','','.b-menu-style-1'),(125361,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > .no-link','content','\\f105','4','','.b-menu-style-1'),(125362,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','content','\\f105 \\f105','4','','.b-menu-style-1'),(125363,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','content','\\f00d','3','','.b-menu-style-2'),(125364,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','content','\\_','3','','.b-menu-style-2'),(125365,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','content','\\f105','3','','.b-menu-style-2'),(125366,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','content','\\_','3','','.b-menu-style-2'),(125367,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','content','\\f104','3','','.b-menu-style-2'),(125368,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > .no-link','content','\\f107','4','','.b-menu-style-3'),(125369,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > .no-link','content','\\f105','3','','.b-menu-style-3'),(125370,'printshop-mobile','.b-messages .select2-search-choice-close','content','\\e913','3','','.b-messages'),(125371,'printshop-mobile','.b-messages .messBtnMenuDelete','content','\\e913','3','','.b-messages'),(125372,'printshop-mobile','.b-messages span.starred::before','content','\\e90e','','','.b-messages'),(125373,'printshop-mobile','.b-messages .dataTables_wrapper > .top','content','\\_','4','','.b-messages'),(125374,'printshop-mobile','.b-messages .messBtnMenuUnread','content','\\f097','3','','.b-messages'),(125375,'printshop-mobile','.b-messages .messBtnMenuStarred','content','\\e90e','3','','.b-messages'),(125376,'printshop-mobile','.b-messages .icon-circle-with-cross::before','content','×','','','.b-messages'),(125377,'printshop-mobile','.b-messages .dataTables_wrapper > .bottom','content','\\_','4','','.b-messages'),(125378,'printshop-mobile','.b-preloader .preloader','content','\\f110','3','','.b-preloader'),(125379,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','content','\\25be','3','','.b-select-suggest'),(125380,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(125381,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(125382,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(125383,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(125384,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(125385,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(125386,'printshop-mobile','.b-trade-approval .columns','content','\\_','4','','.b-trade-approval'),(125387,'printshop-mobile','.b-upload-file .snapshot','content','\\f030','3','','.b-upload-file'),(125388,'printshop-mobile','.b-upload-file .upload-file-wrap .upload-remove','content','\\e913','3','','.b-upload-file'),(125389,'printshop-mobile','.b-upload-files .remove-file','content','\\f014','3','','.b-upload-files'),(125390,'printshop-mobile','.b-warehouses-popup .warehouses-popup-link','content','\\f041','3','','.b-warehouses-popup'),(125391,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','content','\\f041','3','','.b-warehouses-popup'),(125392,'printshop-mobile','.batchPr .btn-batch-remove','content','x','3','','.batchPr'),(125393,'printshop-mobile','.batchPr .checkbox input:not(checked) + span:before','content','\\002B','','','.batchPr'),(125394,'printshop-mobile','.batchPr .checkbox input:checked + span:before','content','\\f00c','','','.batchPr'),(125395,'printshop-mobile','.bell-ico .heading-2','content','\\e9a7','3','','.bell-ico'),(125396,'printshop-mobile','.heading-ordered-items .heading-4','content','\\e99b','3','','.heading-ordered-items'),(125397,'printshop-mobile','.heading-saved-lists .heading-4','content','\\e99c','3','','.heading-saved-lists'),(125398,'printshop-mobile','.heading-settings .heading-4','content','\\e99a','3','','.heading-settings'),(125399,'printshop-mobile','.p-account-samples-history .view_link','content','\\e901','4','','.p-account-samples-history'),(125400,'printshop-mobile','.p-account-samples-history .view_link','content','\\e901','4','','.p-account-samples-history'),(125401,'printshop-mobile','.p-account-samples-history .view_link','content','\\e901','4','','.p-account-samples-history'),(125402,'printshop-mobile','.p-account-samples-history .view_link','content','\\e901','4','','.p-account-samples-history'),(125403,'printshop-mobile','.p-account-samples-history .view_link','content','\\e901','4','','.p-account-samples-history'),(125404,'printshop-mobile','.p-account-samples-history .view_link','content','\\e901','4','','.p-account-samples-history'),(125405,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-samples-history-info'),(125406,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-samples-history-info'),(125407,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-samples-history-info'),(125408,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-samples-history-info'),(125409,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-samples-history-info'),(125410,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-samples-history-info'),(125411,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-samples-history-info'),(125412,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-samples-history-info'),(125413,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-samples-history-info'),(125414,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-samples-history-info'),(125415,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-samples-history-info'),(125416,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-samples-history-info'),(125417,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-samples-history-info'),(125418,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-samples-history-info'),(125419,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-samples-history-info'),(125420,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-samples-history-info'),(125421,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-samples-history-info'),(125422,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-samples-history-info'),(125423,'printshop-mobile','.p-catalog-product .prev-product .pn-image','content','\\f053','3','','.p-catalog-product'),(125424,'printshop-mobile','.p-catalog-product .next-product .pn-image','content','\\f054','3','','.p-catalog-product'),(125425,'printshop-mobile','.p-payer-order-confirmation .ship-ico','content','\\e94e','3','','.p-payer-order-confirmation'),(125426,'printshop-mobile','.p-payer-order-confirmation .pay-ico','content','\\e99e','3','','.p-payer-order-confirmation'),(125427,'printshop-mobile','.p-payer-order-confirmation .order-ico','content','\\e922','3','','.p-payer-order-confirmation'),(125428,'printshop-mobile','.p-payer-order-confirmation .comment-ico','content','\\e99d','3','','.p-payer-order-confirmation'),(125429,'printshop-mobile','.p-payer-order-confirmation .discount-ico','content','\\e95e','3','','.p-payer-order-confirmation'),(125430,'printshop-mobile','.p-payer-order-pay .ship-ico','content','\\e94e','3','','.p-payer-order-pay'),(125431,'printshop-mobile','.p-payer-order-pay .pay-ico','content','\\e99e','3','','.p-payer-order-pay'),(125432,'printshop-mobile','.p-payer-order-pay .order-ico','content','\\e922','3','','.p-payer-order-pay'),(125433,'printshop-mobile','.p-payer-order-pay .comment-ico','content','\\e99d','3','','.p-payer-order-pay'),(125434,'printshop-mobile','.p-payer-order-pay .discount-ico','content','\\e95e','3','','.p-payer-order-pay'),(125435,'printshop-mobile','.p-quick-order-index .paginate_button.next','content','\\f105','3','','.p-quick-order-index'),(125436,'printshop-mobile','.p-quick-order-index .paginate_button.previous','content','\\f104','3','','.p-quick-order-index'),(125437,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(125438,'printshop-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(125439,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(125440,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(125441,'printshop-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(125442,'printshop-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(125443,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(125444,'printshop-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(125445,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(125446,'printshop-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(125447,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(125448,'printshop-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(125449,'printshop-mobile','.p-sample-checkout-success .page-success .text-1','content','\\e916','3','','.p-sample-checkout-success'),(125450,'printshop-mobile','.p-sample-checkout-success .page-success','content','\\_','0,3','','.p-sample-checkout-success'),(125451,'printshop-mobile','.savings-ico .heading-2','content','\\e95e','3','','.savings-ico'),(125452,'printshop-mobile','.shipping-ico .heading-2','content','\\e95e','3','','.shipping-ico'),(125453,'printshop-mobile','.shipping-ico .heading-2','content','\\e94e','3','','.shipping-ico'),(125454,'printshop-mobile','.shipping-ico .heading-2','content','\\e95e','3','','.shipping-ico'),(125455,'printshop-mobile','.w-account-address-book .add_item a','content','\\f067','3','','.w-account-address-book'),(125456,'printshop-mobile','.w-blog-widget-categories-list a','content','\\2022','3','','.w-blog-widget-categories-list'),(125457,'printshop-mobile','.w-blog-widget-most-popular-posts a','content','\\2022','3','','.w-blog-widget-most-popular-posts'),(125458,'printshop-mobile','.w-blog-widget-post-comments-count span','content','\\e645','3','','.w-blog-widget-post-comments-count'),(125459,'printshop-mobile','.w-blog-widget-post-listing .post_comment','content','\\e645','3','','.w-blog-widget-post-listing'),(125460,'printshop-mobile','.w-blog-widget-post-listing .post_date span + span','content','\\2022','3','','.w-blog-widget-post-listing'),(125461,'printshop-mobile','.w-blog-widget-post-listing .products','content','\\_','4','','.w-blog-widget-post-listing'),(125462,'printshop-mobile','.w-blog-widget-post-share ','content','\\_','4','','.w-blog-widget-post-share'),(125463,'printshop-mobile','.w-blog-widget-post-share .facebook-btn','content','\\f09a','3','','.w-blog-widget-post-share'),(125464,'printshop-mobile','.w-blog-widget-post-share .twitter-btn','content','\\f099','3','','.w-blog-widget-post-share'),(125465,'printshop-mobile','.w-blog-widget-post-share .pinterest-btn','content','\\f231','3','','.w-blog-widget-post-share'),(125466,'printshop-mobile','.w-blog-widget-post-share .mailto','content','\\e75a','3','','.w-blog-widget-post-share'),(125467,'printshop-mobile','.w-blog-widget-post-share .printto','content','\\e681','3','','.w-blog-widget-post-share'),(125468,'printshop-mobile','.w-cart-bonus-points .btn-remove','content','\\e913','3','','.w-cart-bonus-points'),(125469,'printshop-mobile','.w-cart-bonus-points .title','content','\\f219','3','','.w-cart-bonus-points'),(125470,'printshop-mobile','.w-cart-compare .product-actions .dropdown-toggle','content','\\f013','3','','.w-cart-compare'),(125471,'printshop-mobile','.w-cart-compare .product','content','\\_','4','','.w-cart-compare'),(125472,'printshop-mobile','.w-cart-compare .delete-cart','content','\\2573','3','','.w-cart-compare'),(125473,'printshop-mobile','.w-cart-compare .atr-col','content','\\f070','3','','.w-cart-compare'),(125474,'printshop-mobile','.w-cart-credit-amount .amount-title','content','\\e99f','3','','.w-cart-credit-amount'),(125475,'printshop-mobile','.w-cart-credit-amount .btn-remove','content','\\e913','3','','.w-cart-credit-amount'),(125476,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','content','\\e90d','3','','.w-catalog-compare'),(125477,'printshop-mobile','.w-catalog-compare td span + span','content','| ','3','','.w-catalog-compare'),(125478,'printshop-mobile','.w-catalog-compare .checkbox input:checked + span:before','content','\\f014','','','.w-catalog-compare'),(125479,'printshop-mobile','.w-catalog-paging .next','content','\\f105','3','','.w-catalog-paging'),(125480,'printshop-mobile','.w-catalog-paging .prev','content','\\f104','3','','.w-catalog-paging'),(125481,'printshop-mobile','.w-checkout-billing-address .addresses','content','\\_','4','','.w-checkout-billing-address'),(125482,'printshop-mobile','.w-checkout-bonus-points .btn-remove','content','\\e913','3','','.w-checkout-bonus-points'),(125483,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','content','\\f10b','3','','.w-checkout-contact-information'),(125484,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','content','\\f095','3','','.w-checkout-contact-information'),(125485,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','content','\\f003','3','','.w-checkout-contact-information'),(125486,'printshop-mobile','.w-checkout-create-account .account-benefits strong','content','\\e918','3','','.w-checkout-create-account'),(125487,'printshop-mobile','.w-checkout-credit-amount .btn-remove','content','\\e913','3','','.w-checkout-credit-amount'),(125488,'printshop-mobile','.w-checkout-shipping-address .addresses','content','\\_','4','','.w-checkout-shipping-address'),(125489,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','content','\\_','','','.w-checkout-shipping-choice'),(125490,'printshop-mobile','.w-coupons-and-vauchers-checkout .btn-remove','content','\\e913','3','','.w-coupons-and-vauchers-checkout'),(125491,'printshop-mobile','.w-list-b2b .attributes','content','\\_','4','','.w-list-b2b'),(125492,'printshop-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','content','\\f013','3','','.w-multi-cart-actions'),(125493,'printshop-mobile','.w-personal-gift-status-bar .inform','content','\\e6a0','4','','.w-personal-gift-status-bar'),(125494,'printshop-mobile','.w-personal-gift-status-bar .end-date','content','\\e72b','3','','.w-personal-gift-status-bar'),(125495,'printshop-mobile','.w-product-available-in-warehouses .content','content','\\_','4','','.w-product-available-in-warehouses'),(125496,'printshop-mobile','.w-product-cross-sell .buy-all-checker','content','\\f14a','3','','.w-product-cross-sell'),(125497,'printshop-mobile','.w-product-customers-activity .close','content','\\2715','3','','.w-product-customers-activity'),(125498,'printshop-mobile','.w-promotions .prom-multi-discount','content','\\_','4','','.w-promotions'),(125499,'printshop-mobile','.w-promotions .nextdiscount .heading','content','\\f07a','3','','.w-promotions'),(125500,'printshop-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','content','\\_','3','','.w-promotions'),(125501,'printshop-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','content','\\_','3','','.w-promotions'),(125502,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range .promo-prod-qty','content',',','4','','.w-promotions'),(125503,'printshop-mobile','.w-promotions .prom-multi-discount > .heading','content','\\_','3','','.w-promotions'),(125504,'printshop-mobile','.w-reviews-content .review','content','\\_','3','','.w-reviews-content'),(125505,'printshop-mobile','.w-social-links .facebook','content','\\f09a','3','','.w-social-links'),(125506,'printshop-mobile','.w-social-links .pinterest','content','\\f0d2','3','','.w-social-links'),(125507,'printshop-mobile','.w-social-links .stumbleupon','content','\\f1a4','3','','.w-social-links'),(125508,'printshop-mobile','.w-social-links .google-plus','content','\\f2b3','3','','.w-social-links'),(125509,'printshop-mobile','.w-social-links .linkedin','content','\\f0e1','3','','.w-social-links'),(125510,'printshop-mobile','.w-social-links .instagram','content','\\f16d','3','','.w-social-links'),(125511,'printshop-mobile','.w-social-links .twitter','content','\\f099','3','','.w-social-links'),(125512,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','content','\\f1f8','3','','.w-upload-customer-id-upload-customer-id-form'),(125513,'printshop-mobile','.w-wedding-registry-widgets-delete-link a','content','|','4','','.w-wedding-registry-widgets-delete-link'),(125514,'printshop-mobile','.w-wedding-registry-widgets-manage-names .names-separator','content','\\f004','3','','.w-wedding-registry-widgets-manage-names'),(125515,'printshop-mobile','.w-wedding-registry-widgets-products .remove-btn','content','\\e913','3','','.w-wedding-registry-widgets-products'),(125516,'printshop-mobile','.w-wedding-registry-widgets-search-registry-button a','content','\\f002','3','','.w-wedding-registry-widgets-search-registry-button'),(125517,'printshop-mobile','.w-wedding-registry-widgets-share-link a','content','|','4','','.w-wedding-registry-widgets-share-link'),(125518,'printshop-mobile','.w-wedding-registry-widgets-share-link a','content','\\f045','3','','.w-wedding-registry-widgets-share-link'),(125519,'printshop-mobile','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(125520,'printshop-mobile','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(125521,'printshop-mobile','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(125522,'printshop-mobile','.b-rating .glyphicon-chevron-right','content_important','important','3','','.b-rating'),(125523,'printshop-mobile','.b-rating .glyphicon-time','content_important','important','3','','.b-rating'),(125524,'printshop-mobile','.b-rating .glyphicon-chevron-down','content_important','important','3','','.b-rating'),(125525,'printshop-mobile','.b-rating .glyphicon-chevron-left','content_important','important','3','','.b-rating'),(125526,'printshop-mobile','.b-rating .glyphicon-calendar','content_important','important','3','','.b-rating'),(125527,'printshop-mobile','.b-rating .glyphicon-chevron-up','content_important','important','3','','.b-rating'),(125528,'printshop-mobile','.w-menu-big .show-all','cursor','pointer','','','.w-menu-big'),(125529,'printshop-mobile','.w-menu .menu .menu-ico','cursor','pointer','','','.w-menu'),(125530,'printshop-mobile','.w-menu-slider .close','cursor','pointer','','','.w-menu-slider'),(125531,'printshop-mobile','.b-switch .bootstrap-switch','cursor','pointer','','','.b-switch'),(125532,'printshop-mobile','.w-product-images img','cursor','pointer','','','.w-product-images'),(125533,'printshop-mobile','.w-filters .filter-box-content ul li.view_items','cursor','pointer','','','.w-filters'),(125534,'printshop-mobile','.p-account-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-history-info'),(125535,'printshop-mobile','.p-account-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-history-info'),(125536,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','cursor','pointer','','','.b-multi-page-checkout'),(125537,'printshop-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','cursor','pointer','','','.b-product-images'),(125538,'printshop-mobile','.p-account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-order-pay'),(125539,'printshop-mobile','.p-account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-order-pay'),(125540,'printshop-mobile','.b-fancybox .fancybox-close','cursor','pointer','','','.b-fancybox'),(125541,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','cursor','pointer','3','','.b-form'),(125542,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor','default','','','.b-switch'),(125543,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor','default','','','.b-switch'),(125544,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor','default','','','.b-switch'),(125545,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','cursor','pointer','','','.b-switch'),(125546,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor','default','','','.b-switch'),(125547,'printshop-mobile','.w-tabs .accordion-heading','cursor','pointer','','','.w-tabs'),(125548,'printshop-mobile','.w-tabs .accordion-heading','cursor','default','2','','.w-tabs'),(125549,'printshop-mobile','.b-slick button.slick-disabled','cursor','default','','','.b-slick'),(125550,'printshop-mobile','.b-bottom .footerTitle','cursor','pointer','693','','.b-bottom'),(125551,'printshop-mobile','.w-tabs .tab-a','cursor','default','2','','.w-tabs'),(125552,'printshop-mobile','.w-tabs .tab-a','cursor','pointer','','','.w-tabs'),(125553,'printshop-mobile','.w-filters .mobileCollapse','cursor','pointer','4','','.w-filters'),(125554,'printshop-mobile','.p-checkout-index .shipping-method .row','cursor','pointer','','','.p-checkout-index'),(125555,'printshop-mobile','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(125556,'printshop-mobile','.b-form .item-radio label','cursor','pointer','','','.b-form'),(125557,'printshop-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','cursor','pointer','','','.b-product-images'),(125558,'printshop-mobile','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(125559,'printshop-mobile','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(125560,'printshop-mobile','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(125561,'printshop-mobile','.b-fancybox .fancybox-nav span','cursor','pointer','','','.b-fancybox'),(125562,'printshop-mobile','.b-fancybox .fancybox-nav','cursor','pointer','','','.b-fancybox'),(125563,'printshop-mobile','.b-form .item-radio.active label','cursor','default','','','.b-form'),(125564,'printshop-mobile','.b-fancybox #fancybox-loading','cursor','pointer','','','.b-fancybox'),(125565,'printshop-mobile','.b-autocomplete .ui-autocomplete li','cursor','pointer','','','.b-autocomplete'),(125566,'printshop-mobile','.b-bottom .pop-up-close','cursor','pointer','','','.b-bottom'),(125567,'printshop-mobile','.w-filters .open, .w-filters .close','cursor','pointer','','','.w-filters'),(125568,'printshop-mobile','.w-filters .ui-slider-handle','cursor','pointer','','','.w-filters'),(125569,'printshop-mobile','.b-form .addresses .address-item label','cursor','pointer','','','.b-form'),(125570,'printshop-mobile','.b-products-listing .products-listing .wishlistButton .checkbox','cursor','pointer','','','.b-products-listing'),(125571,'printshop-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','cursor','pointer','','','.b-menu-burger_icon'),(125572,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(125573,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(125574,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(125575,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(125576,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(125577,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','cursor','pointer','','','.b-menu-style-2'),(125578,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','cursor','pointer','','','.b-menu-style-2'),(125579,'printshop-mobile','.b-messages .messMenuButton span','cursor','pointer','','','.b-messages'),(125580,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-chosen','cursor','default','','','.b-select-suggest'),(125581,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','1','','.b-select-suggest'),(125582,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','','','.b-select-suggest'),(125583,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','cursor','default','','','.b-select-suggest'),(125584,'printshop-mobile','.b-select-suggest .select2-results .select2-disabled','cursor','default','','','.b-select-suggest'),(125585,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','cursor','pointer','','','.b-select-suggest'),(125586,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','cursor','default','','','.b-select-suggest'),(125587,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','cursor','text','','','.b-select-suggest'),(125588,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','cursor','default','','','.b-select-suggest'),(125589,'printshop-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','cursor','default','','','.b-select-suggest'),(125590,'printshop-mobile','.b-upload-file .snapshot','cursor','pointer','','','.b-upload-file'),(125591,'printshop-mobile','.b-upload-files .remove-file','cursor','pointer','','','.b-upload-files'),(125592,'printshop-mobile','.batchPr .batchSelect .checkbox','cursor','pointer','','','.batchPr'),(125593,'printshop-mobile','.batchPr .btn-batch-remove','cursor','pointer','','','.batchPr'),(125594,'printshop-mobile','.batchPr .batchSelect .checkbox','cursor','pointer','','','.batchPr'),(125595,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-samples-history-info'),(125596,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-samples-history-info'),(125597,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-samples-history-info'),(125598,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-samples-history-info'),(125599,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-samples-history-info'),(125600,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-samples-history-info'),(125601,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-samples-history-info'),(125602,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-samples-history-info'),(125603,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-samples-history-info'),(125604,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-samples-history-info'),(125605,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-samples-history-info'),(125606,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-samples-history-info'),(125607,'printshop-mobile','.p-quick-order-index .filters .clear','cursor','pointer','','','.p-quick-order-index'),(125608,'printshop-mobile','.w-account-personal-catalog .list-switcher a','cursor','pointer','','','.w-account-personal-catalog'),(125609,'printshop-mobile','.w-account-personal-catalog .list-switcher a','cursor','default','2','','.w-account-personal-catalog'),(125610,'printshop-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','cursor','pointer','','','.w-blog-widget-post-share'),(125611,'printshop-mobile','.w-cart-bonus-points .btn-remove','cursor','pointer','','','.w-cart-bonus-points'),(125612,'printshop-mobile','.w-cart-compare .atr-col','cursor','pointer','','','.w-cart-compare'),(125613,'printshop-mobile','.w-cart-credit-amount .btn-remove','cursor','pointer','','','.w-cart-credit-amount'),(125614,'printshop-mobile','.w-catalog-compare .compare label','cursor','pointer','','','.w-catalog-compare'),(125615,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','cursor','pointer','','','.w-catalog-compare'),(125616,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','cursor','default','2','','.w-catalog-compare'),(125617,'printshop-mobile','.w-catalog-compare .cross-box .return','cursor','pointer','','','.w-catalog-compare'),(125618,'printshop-mobile','.w-checkout-bonus-points .btn-remove','cursor','pointer','','','.w-checkout-bonus-points'),(125619,'printshop-mobile','.w-checkout-credit-amount .btn-remove','cursor','pointer','','','.w-checkout-credit-amount'),(125620,'printshop-mobile','.w-checkout-shipping-choice span','cursor','pointer','','','.w-checkout-shipping-choice'),(125621,'printshop-mobile','.w-checkout-shipping-choice input:checked + span','cursor','default','','','.w-checkout-shipping-choice'),(125622,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','cursor','pointer','','','.w-communication-new-topic'),(125623,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','cursor','pointer','','','.w-communication-new-topic'),(125624,'printshop-mobile','.w-coupons-and-vauchers-checkout .btn-remove','cursor','pointer','','','.w-coupons-and-vauchers-checkout'),(125625,'printshop-mobile','.w-product-customers-activity .close','cursor','pointer','','','.w-product-customers-activity'),(125626,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','cursor','pointer','','','.w-upload-customer-id-upload-customer-id-form'),(125627,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor_important','important','','','.b-switch'),(125628,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor_important','important','','','.b-switch'),(125629,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor_important','important','','','.b-switch'),(125630,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor_important','important','','','.b-switch'),(125631,'printshop-mobile','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(125632,'printshop-mobile','.b-switch .bootstrap-switch','direction','ltr','','','.b-switch'),(125633,'printshop-mobile','.w-menu-big li a, .w-menu-big li .no-link','display','inline-block','','','.w-menu-big'),(125634,'printshop-mobile','.w-menu .hided.menu .menu-ico','display','block','','','.w-menu'),(125635,'printshop-mobile','.w-menu-big li li li','display','block','','','.w-menu-big'),(125636,'printshop-mobile','.w-menu .hided.menu a, .w-menu .hided.menu .no-link','display','block','','','.w-menu'),(125637,'printshop-mobile','.w-menu-big li li a, .w-menu-big li li .no-link','display','block','','','.w-menu-big'),(125638,'printshop-mobile','.w-menu .hided.menu ul li','display','block','','','.w-menu'),(125639,'printshop-mobile','.w-menu .menu .menu-ico','display','none','','','.w-menu'),(125640,'printshop-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','display','none','','','.w-menu'),(125641,'printshop-mobile','.w-menu div.hided.menu .active + ul, .w-menu div.hided.menu .opened + ul','display','block','','','.w-menu'),(125642,'printshop-mobile','.w-menu-big .hide-more.hide-more-disable, .w-menu-big .hide-more.hide-more-disable ~ li:not(.show-all)','display','block','','','.w-menu-big'),(125643,'printshop-mobile','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','display','inline-block','','','.w-menu-horizontal'),(125644,'printshop-mobile','.w-menu-slider > ul > li > ul > li','display','inline-block','','','.w-menu-slider'),(125645,'printshop-mobile','.w-menu-big > ul > li > ul','display','none','','','.w-menu-big'),(125646,'printshop-mobile','.w-menu-big > ul > li:hover > ul','display','block','','','.w-menu-big'),(125647,'printshop-mobile','.w-menu-big .hide-more, .w-menu-big .hide-more ~ li:not(.show-all)','display','none','','','.w-menu-big'),(125648,'printshop-mobile','.w-menu-big li','display','inline-block','','','.w-menu-big'),(125649,'printshop-mobile','.w-bestsellers .counter','display','inline-block','','','.w-bestsellers'),(125650,'printshop-mobile','.w-menu-slider > ul > li','display','inline-block','','','.w-menu-slider'),(125651,'printshop-mobile','.w-menu-slider a, .w-menu-slider .no-link','display','inline-block','','','.w-menu-slider'),(125652,'printshop-mobile','.w-account .my-acc-link','display','inline-block','3','','.w-account'),(125653,'printshop-mobile','.w-menu-slider > ul > li > ul','display','none','','','.w-menu-slider'),(125654,'printshop-mobile','.w-account .no-text','display','none','','','.w-account'),(125655,'printshop-mobile','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(125656,'printshop-mobile','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(125657,'printshop-mobile','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(125658,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(125659,'printshop-mobile','.b-form .checkbox-style:checked + .checkbox-span','display','inline-block','','','.b-form'),(125660,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','display','inline-block','','','.b-form'),(125661,'printshop-mobile','.w-sale .btn','display','block','','','.w-sale'),(125662,'printshop-mobile','.w-login-block .label','display','block','','','.w-login-block'),(125663,'printshop-mobile','.w-login-block .cols','display','block','4','','.w-login-block'),(125664,'printshop-mobile','.b-product-images .additional-images .item > div, .b-product-images .additional-videos .item > div','display','table-cell','','','.b-product-images'),(125665,'printshop-mobile','.w-sale .left-count-days','display','block','','','.w-sale'),(125666,'printshop-mobile','.w-sale .left-count','display','block','','','.w-sale'),(125667,'printshop-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','display','block','','','.b-product-images'),(125668,'printshop-mobile','.w-product-attributes .attributes','display','block','4','','.w-product-attributes'),(125669,'printshop-mobile','.w-product-sale-ends .left-count-days','display','block','','','.w-product-sale-ends'),(125670,'printshop-mobile','.w-product-sale-ends .left-count','display','block','','','.w-product-sale-ends'),(125671,'printshop-mobile','.w-product-sale-ends .left-count-hours','display','block','','','.w-product-sale-ends'),(125672,'printshop-mobile','.w-product-sale-ends .left-text-right','display','block','','','.w-product-sale-ends'),(125673,'printshop-mobile','.w-product-sale-ends .left-text-left','display','block','','','.w-product-sale-ends'),(125674,'printshop-mobile','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(125675,'printshop-mobile','.p-account-history .short-date','display','none','','','.p-account-history'),(125676,'printshop-mobile','.w-filters .filter-widget-horizontal .filter-box','display','table-cell','','','.w-filters'),(125677,'printshop-mobile','.w-filters .filter-widget-horizontal .content-filter-widget','display','table','','','.w-filters'),(125678,'printshop-mobile','.w-cart .price','display','block','','','.w-cart'),(125679,'printshop-mobile','.w-filters .filter-box-content ul li.view_items','display','block','','','.w-filters'),(125680,'printshop-mobile','.w-cart .name','display','block','','','.w-cart'),(125681,'printshop-mobile','.w-cart .no-text','display','none','','','.w-cart'),(125682,'printshop-mobile','.p-reviews-info .review-info-text','display','block','4','','.p-reviews-info'),(125683,'printshop-mobile','.w-product-collection .together','display','block','','','.w-product-collection'),(125684,'printshop-mobile','.w-menu-mobile .menu-slider .open','display','block','','','.w-menu-mobile'),(125685,'printshop-mobile','.w-menu-mobile .menu-ico','display','block','','','.w-menu-mobile'),(125686,'printshop-mobile','.w-menu-mobile .menu-slider','display','none','','','.w-menu-mobile'),(125687,'printshop-mobile','.w-categories .categories','display','flex','','','.w-categories'),(125688,'printshop-mobile','.b-price-box .price-box .title','display','inline-block','','','.b-price-box'),(125689,'printshop-mobile','.w-quote .no-text','display','none','702','','.w-quote'),(125690,'printshop-mobile','.p-account-history-info .history_attr div strong, .p-account-history-info .history_attr div span','display','table-cell','','','.p-account-history-info'),(125691,'printshop-mobile','.w-categories .item','display','inline-block','','','.w-categories'),(125692,'printshop-mobile','.w-categories .categories','display','block','4','','.w-categories'),(125693,'printshop-mobile','.w-compare-box-item .checkbox + span','display','inline-block','','','.w-compare-box-item'),(125694,'printshop-mobile','.w-categories .name','display','block','','','.w-categories'),(125695,'printshop-mobile','.w-categories .image','display','block','','','.w-categories'),(125696,'printshop-mobile','.w-catalog-listing-look .listing-look-title','display','inline-block','','','.w-catalog-listing-look'),(125697,'printshop-mobile','.b-pagination .pagination','display','block','4','','.b-pagination'),(125698,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','block','','','.b-multi-page-checkout'),(125699,'printshop-mobile','.b-pass-strength .pass-strength','display','block','','','.b-pass-strength'),(125700,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','inline-block','4','','.b-multi-page-checkout'),(125701,'printshop-mobile','.b-price-box .price-box .price','display','inline-block','','','.b-price-box'),(125702,'printshop-mobile','.w-quote .cart-box-link','display','inline-block','3','','.w-quote'),(125703,'printshop-mobile','.w-quote .strong','display','block','','','.w-quote'),(125704,'printshop-mobile','.w-quote .no-text','display','inline-block','','','.w-quote'),(125705,'printshop-mobile','.w-quote .cart-box-link','display','block','','','.w-quote'),(125706,'printshop-mobile','.w-product-properties li','display','table-cell','','','.w-product-properties'),(125707,'printshop-mobile','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(125708,'printshop-mobile','.b-product-images .main-image-box','display','block','4','','.b-product-images'),(125709,'printshop-mobile','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(125710,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','display','inline-block','3','','.b-multi-page-checkout'),(125711,'printshop-mobile','.b-compare .compare_select_items','display','inline-block','','','.b-compare'),(125712,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .count','display','none','','','.b-multi-page-checkout'),(125713,'printshop-mobile','.w-catalog-listing-look .list','display','inline-block','','','.w-catalog-listing-look'),(125714,'printshop-mobile','.w-catalog-listing-look .b2b','display','inline-block','','','.w-catalog-listing-look'),(125715,'printshop-mobile','.price .old','display','block','','',''),(125716,'printshop-mobile','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(125717,'printshop-mobile','.w-cart-shipping-estimator .shipping-estimator','display','block','4','','.w-cart-shipping-estimator'),(125718,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .edit','display','none','','','.b-multi-page-checkout'),(125719,'printshop-mobile','.p-blog-index .post-title','display','block','','','.p-blog-index'),(125720,'printshop-mobile','.p-blog-index .comment-form p label','display','inline-block','','','.p-blog-index'),(125721,'printshop-mobile','.p-account-history .orders-table .hidden','display','none','','','.p-account-history'),(125722,'printshop-mobile','.p-blog-index .post-list .comments-link','display','none','','','.p-blog-index'),(125723,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','display','inline-block','','','.b-multi-page-checkout'),(125724,'printshop-mobile','.b-info-popup .info-popup div','display','none','','','.b-info-popup'),(125725,'printshop-mobile','.b-info-popup .info-popup:hover div','display','block','','','.b-info-popup'),(125726,'printshop-mobile','.w-filters .content-filter-widget','display','none','720','','.w-filters'),(125727,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','display','block','4','','.b-multi-page-checkout'),(125728,'printshop-mobile','.w-promo-code .promo-text-2','display','none','694','','.w-promo-code'),(125729,'printshop-mobile','.w-promo-code .holder','display','block','4','','.w-promo-code'),(125730,'printshop-mobile','.w-product-bonus-points > div','display','block','4','','.w-product-bonus-points'),(125731,'printshop-mobile','.p-wedding-registry-manage a.remove-btn','display','inline-block','','','.p-wedding-registry-manage'),(125732,'printshop-mobile','.p-account-history-info .popup-tracking-number-link','display','block','','','.p-account-history-info'),(125733,'printshop-mobile','.p-account-history-info .popup-tracking-number a','display','block','','','.p-account-history-info'),(125734,'printshop-mobile','.p-account-order-pay .history_attr','display','table','','','.p-account-order-pay'),(125735,'printshop-mobile','.p-account-order-pay .history_attr div','display','table-row','','','.p-account-order-pay'),(125736,'printshop-mobile','.p-account-order-pay .history_attr div strong, .p-account-order-pay .history_attr div span','display','table-cell','','','.p-account-order-pay'),(125737,'printshop-mobile','.w-product-configurator .item-content > div','display','block','693','','.w-product-configurator'),(125738,'printshop-mobile','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(125739,'printshop-mobile','.w-product-configurator .item-content','display','block','693','','.w-product-configurator'),(125740,'printshop-mobile','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(125741,'printshop-mobile','.testimonials .review','display','block','3','',''),(125742,'printshop-mobile','.b-pagination .pagination .paging','display','inline-block','','','.b-pagination'),(125743,'printshop-mobile','.b-pagination .pagination .prev','display','inline-block','','','.b-pagination'),(125744,'printshop-mobile','.b-pagination .pagination .prev-pages','display','inline-block','','','.b-pagination'),(125745,'printshop-mobile','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(125746,'printshop-mobile','.b-pagination .pagination .page-number','display','inline-block','','','.b-pagination'),(125747,'printshop-mobile','.b-pagination .pagination .next-pages','display','inline-block','','','.b-pagination'),(125748,'printshop-mobile','.b-pagination .pagination .next','display','inline-block','','','.b-pagination'),(125749,'printshop-mobile','.b-pagination .pagination span','display','inline-block','2','','.b-pagination'),(125750,'printshop-mobile','.p-account-history .orders-table .headings','display','none','720','','.p-account-history'),(125751,'printshop-mobile','.p-account-history .view_link','display','inline-block','4','','.p-account-history'),(125752,'printshop-mobile','.p-account-history .orders-table .hidden','display','inline-block','720','','.p-account-history'),(125753,'printshop-mobile','.p-account-history .orders-table .item','display','block','720','','.p-account-history'),(125754,'printshop-mobile','.p-account-index .orders-table .hidden','display','none','','','.p-account-index'),(125755,'printshop-mobile','.p-account-history .orders-table .item td','display','block','720','','.p-account-history'),(125756,'printshop-mobile','.p-account-index .orders-table .hidden','display','inline-block','720','','.p-account-index'),(125757,'printshop-mobile','.p-account-index .orders-table .item','display','block','720','','.p-account-index'),(125758,'printshop-mobile','.p-account-index .orders-table .headings','display','none','720','','.p-account-index'),(125759,'printshop-mobile','.p-account-history .orders-table td.name','display','none','720','','.p-account-history'),(125760,'printshop-mobile','.p-account-history .orders-table, .p-account-history .orders-table tbody','display','block','720','','.p-account-history'),(125761,'printshop-mobile','.p-account-index .orders-table .item td','display','block','720','','.p-account-index'),(125762,'printshop-mobile','.p-account-index .orders-table, .p-account-index .orders-table tbody','display','block','720','','.p-account-index'),(125763,'printshop-mobile','.p-blog-index .entry-content','display','block','4','','.p-blog-index'),(125764,'printshop-mobile','.p-account-index .orders-table td.name','display','none','720','','.p-account-index'),(125765,'printshop-mobile','.p-blog-index .nav-links .screen-reader-text','display','block','','','.p-blog-index'),(125766,'printshop-mobile','.p-blog-index .comment-author .says','display','none','','','.p-blog-index'),(125767,'printshop-mobile','.p-blog-index .comment-meta','display','block','4','','.p-blog-index'),(125768,'printshop-mobile','.w-list-type-2_2 .qty-input label','display','none','','','.w-list-type-2_2'),(125769,'printshop-mobile','.w-list-type-2_2 .price .old','display','block','','','.w-list-type-2_2'),(125770,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','display','block','3','','.w-list-type-2_2'),(125771,'printshop-mobile','.w-list-type-2_2 .item','display','block','4','','.w-list-type-2_2'),(125772,'printshop-mobile','.w-list-type-2_2 .button-view a','display','block','','','.w-list-type-2_2'),(125773,'printshop-mobile','.buttons','display','block','4','',''),(125774,'printshop-mobile','.w-list-type-2_2 .add-height','display','block','4','','.w-list-type-2_2'),(125775,'printshop-mobile','.w-list-type-2 .qty-input label','display','none','','','.w-list-type-2'),(125776,'printshop-mobile','.w-list-type-2 .price .old','display','block','','','.w-list-type-2'),(125777,'printshop-mobile','.personal-buttons > div','display','flex','','','.personal-buttons'),(125778,'printshop-mobile','.w-account a.my-acc-link','display','inline-block','','','.w-account'),(125779,'printshop-mobile','.p-reviews-info .review_by span','display','inline-block','','','.p-reviews-info'),(125780,'printshop-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','display','block','','','.b-fancybox'),(125781,'printshop-mobile','.w-menu-horizontal ul ul li','display','block','','','.w-menu-horizontal'),(125782,'printshop-mobile','.w-menu-horizontal ul li:hover > ul','display','block','','','.w-menu-horizontal'),(125783,'printshop-mobile','.w-menu-horizontal ul ul','display','none','','','.w-menu-horizontal'),(125784,'printshop-mobile','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(125785,'printshop-mobile','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(125786,'printshop-mobile','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(125787,'printshop-mobile','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(125788,'printshop-mobile','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(125789,'printshop-mobile','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(125790,'printshop-mobile','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(125791,'printshop-mobile','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(125792,'printshop-mobile','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(125793,'printshop-mobile','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(125794,'printshop-mobile','.p-wedding-registry-index .search-list label','display','block','','','.p-wedding-registry-index'),(125795,'printshop-mobile','.b-form .form-inputs label > span','display','inline-block','','','.b-form'),(125796,'printshop-mobile','.p-wedding-registry-manage .links a','display','inline-block','','','.p-wedding-registry-manage'),(125797,'printshop-mobile','.p-wedding-registry-search #searchform-status','display','flex','','','.p-wedding-registry-search'),(125798,'printshop-mobile','.p-wedding-registry-search .search-form','display','flex','','','.p-wedding-registry-search'),(125799,'printshop-mobile','.b-pagination .pagination a','display','inline-block','','','.b-pagination'),(125800,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(125801,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(125802,'printshop-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','display','inline-block','','','.b-compare'),(125803,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display','inline-block','','','.b-switch'),(125804,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container','display','inline-block','','','.b-switch'),(125805,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display','inline-block','','','.b-switch'),(125806,'printshop-mobile','.b-switch .bootstrap-switch','display','inline-block','','','.b-switch'),(125807,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','display','inline-block','','','.b-fancybox'),(125808,'printshop-mobile','.b-form .middle-form .col-gender label','display','inline-block','','','.b-form'),(125809,'printshop-mobile','.w-tabs .accordion-heading','display','block','','','.w-tabs'),(125810,'printshop-mobile','.w-currencies .select-link','display','block','702','','.w-currencies'),(125811,'printshop-mobile','.w-languages .lang-link','display','block','702','','.w-languages'),(125812,'printshop-mobile','.b-bottom .footerTitle ~ div','display','none','693','','.b-bottom'),(125813,'printshop-mobile','.w-filters .input-checkbox:checked + .checkbox-span','display','inline-block','','','.w-filters'),(125814,'printshop-mobile','.w-catalog-listing-look .grid','display','inline-block','','','.w-catalog-listing-look'),(125815,'printshop-mobile','.w-list-type-1 .button-view a','display','block','','','.w-list-type-1'),(125816,'printshop-mobile','.w-top-categories .categories','display','block','4','','.w-top-categories'),(125817,'printshop-mobile','.w-tabs .tab-li','display','table-cell','','','.w-tabs'),(125818,'printshop-mobile','.w-top-categories .item','display','inline-block','','','.w-top-categories'),(125819,'printshop-mobile','.w-tabs .tab-a','display','block','','','.w-tabs'),(125820,'printshop-mobile','.w-search .search','display','block','3','','.w-search'),(125821,'printshop-mobile','.w-search .item','display','block','','','.w-search'),(125822,'printshop-mobile','.w-search .name','display','block','','','.w-search'),(125823,'printshop-mobile','.b-product-images .additional-images .item, .b-product-images .additional-videos .item','display','table','','','.b-product-images'),(125824,'printshop-mobile','.w-banner .sliderItems a + a, .w-banner .sliderItems a + img, .w-banner .sliderItems img + a, .w-banner .sliderItems img + img','display','none','','','.w-banner'),(125825,'printshop-mobile','.w-list-type-1_3 .price .old','display','block','','','.w-list-type-1_3'),(125826,'printshop-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','display','inline-block','','','.w-filters'),(125827,'printshop-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','display','table-cell','','','.w-banner'),(125828,'printshop-mobile','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','display','table','','','.w-banner'),(125829,'printshop-mobile','.p-account-trade-form .wl-td label','display','inline-block','','','.p-account-trade-form'),(125830,'printshop-mobile','.p-checkout-index .shipping-method .row','display','block','','','.p-checkout-index'),(125831,'printshop-mobile','.p-quote-cart-index .cart-popup .gift-wrap','display','none','','','.p-quote-cart-index'),(125832,'printshop-mobile','.p-shopping-cart-index .cart-popup .gift-wrap','display','none','','','.p-shopping-cart-index'),(125833,'printshop-mobile','.w-currencies .select','display','none','','','.w-currencies'),(125834,'printshop-mobile','.w-currencies .currencies-title','display','block','','','.w-currencies'),(125835,'printshop-mobile','.w-currencies .currencies:hover .select','display','block','','','.w-currencies'),(125836,'printshop-mobile','.w-currencies .currencies','display','inline-block','','','.w-currencies'),(125837,'printshop-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(125838,'printshop-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(125839,'printshop-mobile','.b-slick .slick-slider','display','block','','','.b-slick'),(125840,'printshop-mobile','.b-slick .slick-track','display','block','','','.b-slick'),(125841,'printshop-mobile','.b-slick .slick-vertical .slick-slide','display','block','','','.b-slick'),(125842,'printshop-mobile','.b-slick .slick-track, .b-slick .slick-track:after','display','table','3','','.b-slick'),(125843,'printshop-mobile','.p-account-trade-form .wd-line-row-2','display','block','4','','.p-account-trade-form'),(125844,'printshop-mobile','.b-info-popup .info-popup','display','inline-block','3','','.b-info-popup'),(125845,'printshop-mobile','.b-info-popup .info-popup','display','inline-block','','','.b-info-popup'),(125846,'printshop-mobile','.p-account-index .view_link','display','inline-block','4','','.p-account-index'),(125847,'printshop-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','display','inline-block','','','.w-menu-style-1'),(125848,'printshop-mobile','.p-account-index .view_history','display','inline-block','3','','.p-account-index'),(125849,'printshop-mobile','.w-menu-style-1 li','display','inline-block','','','.w-menu-style-1'),(125850,'printshop-mobile','.w-account .account-dropdown','display','none','','','.w-account'),(125851,'printshop-mobile','.p-checkout-success .page-success .text-1','display','block','3','','.p-checkout-success'),(125852,'printshop-mobile','.p-account-index .topAccount > li > div','display','block','3','','.p-account-index'),(125853,'printshop-mobile','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(125854,'printshop-mobile','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(125855,'printshop-mobile','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(125856,'printshop-mobile','.w-product-quantity-discounts .quantity-discounts .count','display','inline-block','','','.w-product-quantity-discounts'),(125857,'printshop-mobile','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(125858,'printshop-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(125859,'printshop-mobile','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(125860,'printshop-mobile','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(125861,'printshop-mobile','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(125862,'printshop-mobile','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(125863,'printshop-mobile','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(125864,'printshop-mobile','.w-menu-style-1 ul ul li','display','block','','','.w-menu-style-1'),(125865,'printshop-mobile','.w-menu-style-1 ul li:hover > ul','display','block','','','.w-menu-style-1'),(125866,'printshop-mobile','.w-menu-style-1 ul ul','display','none','','','.w-menu-style-1'),(125867,'printshop-mobile','.w-menu-style-1 li li a, .w-menu-style-1 li li .no-link','display','block','','','.w-menu-style-1'),(125868,'printshop-mobile','.b-fancybox .fancybox-overlay','display','none','','','.b-fancybox'),(125869,'printshop-mobile','.w-sale .left-text-right','display','block','','','.w-sale'),(125870,'printshop-mobile','.w-sale .left-count-hours','display','block','','','.w-sale'),(125871,'printshop-mobile','.w-sale .left-text-left','display','block','','','.w-sale'),(125872,'printshop-mobile','.w-sale .special-price','display','block','','','.w-sale'),(125873,'printshop-mobile','.w-sale .text','display','block','','','.w-sale'),(125874,'printshop-mobile','.w-sale .special-price-text','display','none','','','.w-sale'),(125875,'printshop-mobile','.w-text .customer-service b','display','block','','','.w-text'),(125876,'printshop-mobile','.w-top-categories .categories','display','flex','','','.w-top-categories'),(125877,'printshop-mobile','.w-banner .carousel-text','display','flex','','','.w-banner'),(125878,'printshop-mobile','.b-slick .slick-slide.slick-loading img','display','none','','','.b-slick'),(125879,'printshop-mobile','.b-slick .slick-slide','display','none','','','.b-slick'),(125880,'printshop-mobile','.b-slick .slick-arrow.slick-hidden','display','none','','','.b-slick'),(125881,'printshop-mobile','.b-slick .slick-initialized .slick-slide','display','block','','','.b-slick'),(125882,'printshop-mobile','.b-slick .slick-list','display','block','','','.b-slick'),(125883,'printshop-mobile','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(125884,'printshop-mobile','.b-rating #stars-default .glyphicon','display','inline-block','','','.b-rating'),(125885,'printshop-mobile','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(125886,'printshop-mobile','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(125887,'printshop-mobile','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(125888,'printshop-mobile','.w-cart .cart-box.hover-box .cart-content','display','none','','','.w-cart'),(125889,'printshop-mobile','.w-cart .cart-box.hover-box:hover .cart-content','display','block','','','.w-cart'),(125890,'printshop-mobile','.w-cart .cart-box-link','display','block','','','.w-cart'),(125891,'printshop-mobile','.w-cart .strong','display','block','','','.w-cart'),(125892,'printshop-mobile','.w-filters .mobileCollapse','display','inline-block','720','','.w-filters'),(125893,'printshop-mobile','.w-menu-horizontal li','display','inline-block','','','.w-menu-horizontal'),(125894,'printshop-mobile','.w-menu-horizontal li li a, .w-menu-horizontal li li .no-link','display','block','','','.w-menu-horizontal'),(125895,'printshop-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','display','inline-block','3','','.w-cart-discount-coupon'),(125896,'printshop-mobile','.w-cart .cart-box-link','display','inline-block','3','','.w-cart'),(125897,'printshop-mobile','.w-search .search form','display','none','','','.w-search'),(125898,'printshop-mobile','.w-list-type-1_3 .qty-input label','display','none','','','.w-list-type-1_3'),(125899,'printshop-mobile','.p-account-index .account_info .info','display','none','3','','.p-account-index'),(125900,'printshop-mobile','.p-account-history-info .history_attr','display','table','','','.p-account-history-info'),(125901,'printshop-mobile','.p-account-history-info .history_attr div','display','table-row','','','.p-account-history-info'),(125902,'printshop-mobile','.b-form .columns','display','block','4','','.b-form'),(125903,'printshop-mobile','.b-form .addresses','display','block','4','','.b-form'),(125904,'printshop-mobile','.p-account-index .date_value, .p-account-index .date_title','display','block','','','.p-account-index'),(125905,'printshop-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(125906,'printshop-mobile','.w-cart a.item','display','block','','','.w-cart'),(125907,'printshop-mobile','.b-datepicker .picker-switch','display','none','','','.b-datepicker'),(125908,'printshop-mobile','.w-cart a.item','display','block','4','','.w-cart'),(125909,'printshop-mobile','.w-cart-give-away .ga_name','display','block','4','','.w-cart-give-away'),(125910,'printshop-mobile','.w-search .search.opened form','display','block','','','.w-search'),(125911,'printshop-mobile','.w-list-type-2 .button-view a','display','block','','','.w-list-type-2'),(125912,'printshop-mobile','.w-list-type-2 .add-height','display','block','4','','.w-list-type-2'),(125913,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','display','block','3','','.w-list-type-2'),(125914,'printshop-mobile','.w-list-type-1_3 .item','display','block','4','','.w-list-type-1_3'),(125915,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','display','block','3','','.w-list-type-1_3'),(125916,'printshop-mobile','.w-list-type-1_3 .button-view a','display','block','','','.w-list-type-1_3'),(125917,'printshop-mobile','.w-list-type-1_3 .attributes > .attributes','display','block','4','','.w-list-type-1_3'),(125918,'printshop-mobile','.w-list-type-1_3 .add-height','display','block','4','','.w-list-type-1_3'),(125919,'printshop-mobile','.w-list-type-1_2 .right-area','display','block','4','','.w-list-type-1_2'),(125920,'printshop-mobile','.w-list-type-1_2 .qty-input label','display','none','','','.w-list-type-1_2'),(125921,'printshop-mobile','.w-list-type-1_2 .item','display','block','4','','.w-list-type-1_2'),(125922,'printshop-mobile','.w-list-type-1_2 .price .old','display','block','','','.w-list-type-1_2'),(125923,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','display','block','3','','.w-list-type-1_2'),(125924,'printshop-mobile','.w-list-type-1_2 .button-view a','display','block','','','.w-list-type-1_2'),(125925,'printshop-mobile','.w-list-type-1_2 .add-height','display','block','4','','.w-list-type-1_2'),(125926,'printshop-mobile','.w-list-type-1 .qty-input label','display','none','','','.w-list-type-1'),(125927,'printshop-mobile','.w-list-type-1 .price .old','display','block','','','.w-list-type-1'),(125928,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','display','block','3','','.w-list-type-1'),(125929,'printshop-mobile','.w-filters .mobileCollapse','display','none','','','.w-filters'),(125930,'printshop-mobile','.w-languages .select','display','none','','','.w-languages'),(125931,'printshop-mobile','.w-languages .languages:hover .select','display','block','','','.w-languages'),(125932,'printshop-mobile','.w-languages .languages','display','inline-block','','','.w-languages'),(125933,'printshop-mobile','.w-list-type-1 .add-height','display','block','4','','.w-list-type-1'),(125934,'printshop-mobile','.b-form .addresses .address-item span','display','block','','','.b-form'),(125935,'printshop-mobile','.w-tabs > .block > .box .heading-2, .w-tabs > .block > .box .heading-3, .w-tabs > .block > .box .heading-4','display','none','','','.w-tabs'),(125936,'printshop-mobile','.w-top-categories .name','display','block','','','.w-top-categories'),(125937,'printshop-mobile','.w-tabs .tab-navigation','display','table','','','.w-tabs'),(125938,'printshop-mobile','.w-product-reviews .reviews-list .review','display','block','3','','.w-product-reviews'),(125939,'printshop-mobile','.w-top-categories .image','display','block','','','.w-top-categories'),(125940,'printshop-mobile','.w-reviews .review','display','block','3','','.w-reviews'),(125941,'printshop-mobile','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(125942,'printshop-mobile','.w-search .items-title','display','block','','','.w-search'),(125943,'printshop-mobile','.b-form .middle-form label','display','block','','','.b-form'),(125944,'printshop-mobile','.b-form .payment-method .item-radio label','display','block','','','.b-form'),(125945,'printshop-mobile','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','display','inline-block','','','.b-form'),(125946,'printshop-mobile','.b-form .payment-method .item-radio label span','display','block','','','.b-form'),(125947,'printshop-mobile','.b-form .payment-method .sub-item span','display','block','','','.b-form'),(125948,'printshop-mobile','.b-info .info','display','inline-block','3','','.b-info'),(125949,'printshop-mobile','.w-cart .cart-content','display','none','','','.w-cart'),(125950,'printshop-mobile','.b-products-listing .BlockBox','display','block','4','','.b-products-listing'),(125951,'printshop-mobile','.b-products-listing .btn-preloader','display','inline-block','3','','.b-products-listing'),(125952,'printshop-mobile','.b-products-listing .hide','display','none','','','.b-products-listing'),(125953,'printshop-mobile','.b-products-listing .hover-box-content','display','none','','','.b-products-listing'),(125954,'printshop-mobile','.b-products-listing .hover-box:hover .hover-box-content','display','block','','','.b-products-listing'),(125955,'printshop-mobile','.b-products-listing .loader','display','inline-block','4','','.b-products-listing'),(125956,'printshop-mobile','.b-products-listing .products-listing','display','block','4','','.b-products-listing'),(125957,'printshop-mobile','.b-products-listing .products-listing .attribute-qty-block','display','flex','','','.b-products-listing'),(125958,'printshop-mobile','.b-products-listing .products-listing .attribute-qty-blocks','display','flex','','','.b-products-listing'),(125959,'printshop-mobile','.b-products-listing .products-listing .bonus-points','display','flex','','','.b-products-listing'),(125960,'printshop-mobile','.b-products-listing .products-listing .btn-buy','display','inline-block','3','','.b-products-listing'),(125961,'printshop-mobile','.b-products-listing .products-listing .compare','display','block','','','.b-products-listing'),(125962,'printshop-mobile','.b-products-listing .products-listing .compare label','display','inline','','','.b-products-listing'),(125963,'printshop-mobile','.b-products-listing .products-listing .item','display','inline-block','','','.b-products-listing'),(125964,'printshop-mobile','.b-products-listing .products-listing .mix-attributes','display','block','4','','.b-products-listing'),(125965,'printshop-mobile','.b-products-listing .products-listing.align-left .item','display','block','','','.b-products-listing'),(125966,'printshop-mobile','.b-products-listing .products-listing.align-right .item','display','block','','','.b-products-listing'),(125967,'printshop-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','display','block','','','.b-products-listing'),(125968,'printshop-mobile','.b-products-listing .promos-info .promo-item','display','flex','','','.b-products-listing'),(125969,'printshop-mobile','.b-products-listing .select-attributes','display','flex','','','.b-products-listing'),(125970,'printshop-mobile','.b-products-listing .show-ofstock-products .headerStock','display','inline-block','','','.b-products-listing'),(125971,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.b-data-table'),(125972,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.b-data-table'),(125973,'printshop-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(125974,'printshop-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(125975,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(125976,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(125977,'printshop-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(125978,'printshop-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(125979,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(125980,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(125981,'printshop-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(125982,'printshop-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(125983,'printshop-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(125984,'printshop-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(125985,'printshop-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(125986,'printshop-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(125987,'printshop-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(125988,'printshop-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(125989,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(125990,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(125991,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','display','inline','','','.b-h-inline'),(125992,'printshop-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .menu-content','display','none','','','.b-menu-burger_icon'),(125993,'printshop-mobile','.b-menu-burger_icon .bi-opened .menu-style[data-burger_icon] .menu-content','display','block','','','.b-menu-burger_icon'),(125994,'printshop-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','display','block','','','.b-menu-burger_icon'),(125995,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','display','block','','','.b-menu-lev_display-slide'),(125996,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','display','block','','','.b-menu-lev_display-slide'),(125997,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','display','block','','','.b-menu-lev_display-slide'),(125998,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','display','block','','','.b-menu-lev_display-slide'),(125999,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','display','block','','','.b-menu-lev_display-slide'),(126000,'printshop-mobile','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(126001,'printshop-mobile','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(126002,'printshop-mobile','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(126003,'printshop-mobile','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(126004,'printshop-mobile','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(126005,'printshop-mobile','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(126006,'printshop-mobile','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(126007,'printshop-mobile','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(126008,'printshop-mobile','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(126009,'printshop-mobile','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(126010,'printshop-mobile','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(126011,'printshop-mobile','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(126012,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-2','display','none','','','.b-menu-lev_vis'),(126013,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(126014,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-3','display','none','','','.b-menu-lev_vis'),(126015,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(126016,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-4','display','none','','','.b-menu-lev_vis'),(126017,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(126018,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-5','display','none','','','.b-menu-lev_vis'),(126019,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(126020,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-6','display','none','','','.b-menu-lev_vis'),(126021,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(126022,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(126023,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-2','display','none','','','.b-menu-lev_vis'),(126024,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(126025,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-3','display','none','','','.b-menu-lev_vis'),(126026,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(126027,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-4','display','none','','','.b-menu-lev_vis'),(126028,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(126029,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-5','display','none','','','.b-menu-lev_vis'),(126030,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(126031,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-6','display','none','','','.b-menu-lev_vis'),(126032,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(126033,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1','display','none','','','.b-menu-lev_vis-click_icon'),(126034,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(126035,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-3','display','none','','','.b-menu-lev_vis-click_icon'),(126036,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(126037,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-4','display','none','','','.b-menu-lev_vis-click_icon'),(126038,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(126039,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-5','display','none','','','.b-menu-lev_vis-click_icon'),(126040,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(126041,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-6','display','none','','','.b-menu-lev_vis-click_icon'),(126042,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display','block','','','.b-menu-open_from-left'),(126043,'printshop-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul','display','flex','','','.b-menu-position'),(126044,'printshop-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(126045,'printshop-mobile','.b-menu-style picture','display','none','','','.b-menu-style'),(126046,'printshop-mobile','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display','none','','','.b-menu-style'),(126047,'printshop-mobile','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display','none','','','.b-menu-style'),(126048,'printshop-mobile','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display','none','','','.b-menu-style'),(126049,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','display','flex','','','.b-menu-style-1'),(126050,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .component-item','display','none','','','.b-menu-style-1'),(126051,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','display','inline-block','','','.b-menu-style-1'),(126052,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','display','block','','','.b-menu-style-1'),(126053,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','display','block','','','.b-menu-style-2'),(126054,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','display','block','','','.b-menu-style-2'),(126055,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','display','flex','','','.b-menu-style-2'),(126056,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .languages','display','flex','','','.b-menu-style-2'),(126057,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','display','block','','','.b-menu-style-2'),(126058,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies','display','flex','','','.b-menu-style-2'),(126059,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','display','flex','','','.b-menu-style-2'),(126060,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','display','block','','','.b-menu-style-3'),(126061,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .component-item','display','none','','','.b-menu-style-3'),(126062,'printshop-mobile','.b-messages .messMenuButton span','display','inline-block','','','.b-messages'),(126063,'printshop-mobile','.b-messages .msv_to_cc div span','display','inline-block','','','.b-messages'),(126064,'printshop-mobile','.b-messages span.starred::before','display','inline-block','','','.b-messages'),(126065,'printshop-mobile','.b-messages .messBtnMenuStarred','display','inline-block','3','','.b-messages'),(126066,'printshop-mobile','.b-messages .dataTables_wrapper > .top','display','block','4','','.b-messages'),(126067,'printshop-mobile','.b-messages .messBtnMenuDelete','display','inline-block','3','','.b-messages'),(126068,'printshop-mobile','.b-messages .messBtnMenuUnread','display','inline-block','3','','.b-messages'),(126069,'printshop-mobile','.b-messages .messages-menu li a','display','block','','','.b-messages'),(126070,'printshop-mobile','.b-messages .content_management_attach button','display','inline-block','','','.b-messages'),(126071,'printshop-mobile','.b-messages .email-line','display','flex','','','.b-messages'),(126072,'printshop-mobile','.b-messages .dataTables_wrapper > .bottom','display','block','4','','.b-messages'),(126073,'printshop-mobile','.b-preloader .preloader','display','inline-block','3','','.b-preloader'),(126074,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','display','block','','','.b-select-suggest'),(126075,'printshop-mobile','.b-select-suggest .select2-container.select2-allowclear .select2-choice abbr','display','inline-block','','','.b-select-suggest'),(126076,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','display','none','','','.b-select-suggest'),(126077,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','3','','.b-select-suggest'),(126078,'printshop-mobile','.b-select-suggest .select2-results .select2-disabled','display','list-item','','','.b-select-suggest'),(126079,'printshop-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','display','block','','','.b-select-suggest'),(126080,'printshop-mobile','.b-select-suggest .select2-display-none','display','none','','','.b-select-suggest'),(126081,'printshop-mobile','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','display','list-item','','','.b-select-suggest'),(126082,'printshop-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice abbr','display','none','','','.b-select-suggest'),(126083,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','display','none','','','.b-select-suggest'),(126084,'printshop-mobile','.b-select-suggest .select2-more-results','display','list-item','','','.b-select-suggest'),(126085,'printshop-mobile','.b-select-suggest .select2-results li','display','list-item','','','.b-select-suggest'),(126086,'printshop-mobile','.b-select-suggest .select2-results .select2-selected','display','none','','','.b-select-suggest'),(126087,'printshop-mobile','.b-select-suggest .select2-search','display','inline-block','','','.b-select-suggest'),(126088,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','','','.b-select-suggest'),(126089,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','display','inline-block','','','.b-select-suggest'),(126090,'printshop-mobile','.b-select-suggest .select2-container','display','inline-block','','','.b-select-suggest'),(126091,'printshop-mobile','.b-select-suggest .select2-search-choice-close','display','block','','','.b-select-suggest'),(126092,'printshop-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','display','list-item','','','.b-select-suggest'),(126093,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(126094,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(126095,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(126096,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(126097,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(126098,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(126099,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(126100,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(126101,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(126102,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(126103,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(126104,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(126105,'printshop-mobile','.b-trade-approval .steps-bar','display','table','','','.b-trade-approval'),(126106,'printshop-mobile','.b-trade-approval .steps-bar li','display','table-cell','','','.b-trade-approval'),(126107,'printshop-mobile','.b-trade-approval .steps-bar li a','display','block','','','.b-trade-approval'),(126108,'printshop-mobile','.b-trade-approval .middle-form label','display','block','','','.b-trade-approval'),(126109,'printshop-mobile','.b-trade-approval .columns','display','block','4','','.b-trade-approval'),(126110,'printshop-mobile','.b-upload-file .upload-file-template','display','inline-block','','','.b-upload-file'),(126111,'printshop-mobile','.b-upload-files .attach-active-holder','display','block','','','.b-upload-files'),(126112,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','display','inline-block','','','.b-warehouses-popup'),(126113,'printshop-mobile','.batchPr .checkbox input:not(checked) + span:before','display','none','','','.batchPr'),(126114,'printshop-mobile','.batchPr .checkbox input:checked + span:before','display','inline-block','','','.batchPr'),(126115,'printshop-mobile','.batchPr .batchSelect .checkbox','display','inline-block','','','.batchPr'),(126116,'printshop-mobile','.batchPr .btn-batch-remove','display','block','3','','.batchPr'),(126117,'printshop-mobile','.batchPr .checkbox input + span','display','block','','','.batchPr'),(126118,'printshop-mobile','.batchPr .batch-selected-products-list','display','none','','','.batchPr'),(126119,'printshop-mobile','.batchPr .checkbox input','display','none','','','.batchPr'),(126120,'printshop-mobile','.batchPr .w-batch-selected-products .item:hover .btn-batch-remove','display','block','','','.batchPr'),(126121,'printshop-mobile','.batchPr .btn-batch-remove','display','none','','','.batchPr'),(126122,'printshop-mobile','.batchPr .w-batch-products .radio-attributes .option-color, .batchPr .w-batch-products .radio-attributes span[itemprop=\"price\"]','display','none','','','.batchPr'),(126123,'printshop-mobile','.batchPr .products-listing .radio-attributes label','display','inline-block','','','.batchPr'),(126124,'printshop-mobile','.p-account-samples-history .orders-table .hidden','display','inline-block','','','.p-account-samples-history'),(126125,'printshop-mobile','.p-account-samples-history .orders-table .item','display','block','','','.p-account-samples-history'),(126126,'printshop-mobile','.p-account-samples-history .orders-table td.name','display','none','','','.p-account-samples-history'),(126127,'printshop-mobile','.p-account-samples-history .orders-table .headings','display','none','','','.p-account-samples-history'),(126128,'printshop-mobile','.p-account-samples-history .orders-table .item td','display','block','','','.p-account-samples-history'),(126129,'printshop-mobile','.p-account-samples-history .orders-table, .p-account-samples-history .orders-table tbody','display','block','','','.p-account-samples-history'),(126130,'printshop-mobile','.p-account-samples-history .view_link','display','inline-block','4','','.p-account-samples-history'),(126131,'printshop-mobile','.p-account-samples-history .orders-table .headings','display','none','','','.p-account-samples-history'),(126132,'printshop-mobile','.p-account-samples-history .orders-table .item','display','block','','','.p-account-samples-history'),(126133,'printshop-mobile','.p-account-samples-history .orders-table .headings','display','none','','','.p-account-samples-history'),(126134,'printshop-mobile','.p-account-samples-history .orders-table .item td','display','block','','','.p-account-samples-history'),(126135,'printshop-mobile','.p-account-samples-history .orders-table .item td','display','block','','','.p-account-samples-history'),(126136,'printshop-mobile','.p-account-samples-history .orders-table td.name','display','none','','','.p-account-samples-history'),(126137,'printshop-mobile','.p-account-samples-history .view_link','display','inline-block','4','','.p-account-samples-history'),(126138,'printshop-mobile','.p-account-samples-history .short-date','display','none','','','.p-account-samples-history'),(126139,'printshop-mobile','.p-account-samples-history .orders-table, .p-account-samples-history .orders-table tbody','display','block','','','.p-account-samples-history'),(126140,'printshop-mobile','.p-account-samples-history .orders-table .hidden','display','inline-block','','','.p-account-samples-history'),(126141,'printshop-mobile','.p-account-samples-history .orders-table .hidden','display','none','','','.p-account-samples-history'),(126142,'printshop-mobile','.p-account-samples-history .orders-table td.name','display','none','','','.p-account-samples-history'),(126143,'printshop-mobile','.p-account-samples-history .orders-table, .p-account-samples-history .orders-table tbody','display','block','','','.p-account-samples-history'),(126144,'printshop-mobile','.p-account-samples-history .orders-table .hidden','display','none','','','.p-account-samples-history'),(126145,'printshop-mobile','.p-account-samples-history .orders-table .item td','display','block','','','.p-account-samples-history'),(126146,'printshop-mobile','.p-account-samples-history .orders-table td.name','display','none','','','.p-account-samples-history'),(126147,'printshop-mobile','.p-account-samples-history .view_link','display','inline-block','4','','.p-account-samples-history'),(126148,'printshop-mobile','.p-account-samples-history .orders-table .hidden','display','inline-block','','','.p-account-samples-history'),(126149,'printshop-mobile','.p-account-samples-history .orders-table .headings','display','none','','','.p-account-samples-history'),(126150,'printshop-mobile','.p-account-samples-history .orders-table .headings','display','none','','','.p-account-samples-history'),(126151,'printshop-mobile','.p-account-samples-history .orders-table, .p-account-samples-history .orders-table tbody','display','block','','','.p-account-samples-history'),(126152,'printshop-mobile','.p-account-samples-history .orders-table .item','display','block','','','.p-account-samples-history'),(126153,'printshop-mobile','.p-account-samples-history .short-date','display','none','','','.p-account-samples-history'),(126154,'printshop-mobile','.p-account-samples-history .orders-table .headings','display','none','','','.p-account-samples-history'),(126155,'printshop-mobile','.p-account-samples-history .short-date','display','none','','','.p-account-samples-history'),(126156,'printshop-mobile','.p-account-samples-history .orders-table .hidden','display','inline-block','','','.p-account-samples-history'),(126157,'printshop-mobile','.p-account-samples-history .orders-table .hidden','display','none','','','.p-account-samples-history'),(126158,'printshop-mobile','.p-account-samples-history .orders-table td.name','display','none','','','.p-account-samples-history'),(126159,'printshop-mobile','.p-account-samples-history .view_link','display','inline-block','4','','.p-account-samples-history'),(126160,'printshop-mobile','.p-account-samples-history .orders-table td.name','display','none','','','.p-account-samples-history'),(126161,'printshop-mobile','.p-account-samples-history .orders-table, .p-account-samples-history .orders-table tbody','display','block','','','.p-account-samples-history'),(126162,'printshop-mobile','.p-account-samples-history .orders-table .hidden','display','none','','','.p-account-samples-history'),(126163,'printshop-mobile','.p-account-samples-history .orders-table .item td','display','block','','','.p-account-samples-history'),(126164,'printshop-mobile','.p-account-samples-history .orders-table .hidden','display','none','','','.p-account-samples-history'),(126165,'printshop-mobile','.p-account-samples-history .orders-table .hidden','display','none','','','.p-account-samples-history'),(126166,'printshop-mobile','.p-account-samples-history .orders-table .hidden','display','inline-block','','','.p-account-samples-history'),(126167,'printshop-mobile','.p-account-samples-history .view_link','display','inline-block','4','','.p-account-samples-history'),(126168,'printshop-mobile','.p-account-samples-history .view_link','display','inline-block','4','','.p-account-samples-history'),(126169,'printshop-mobile','.p-account-samples-history .orders-table .item','display','block','','','.p-account-samples-history'),(126170,'printshop-mobile','.p-account-samples-history .short-date','display','none','','','.p-account-samples-history'),(126171,'printshop-mobile','.p-account-samples-history .short-date','display','none','','','.p-account-samples-history'),(126172,'printshop-mobile','.p-account-samples-history .short-date','display','none','','','.p-account-samples-history'),(126173,'printshop-mobile','.p-account-samples-history .orders-table, .p-account-samples-history .orders-table tbody','display','block','','','.p-account-samples-history'),(126174,'printshop-mobile','.p-account-samples-history .orders-table .item','display','block','','','.p-account-samples-history'),(126175,'printshop-mobile','.p-account-samples-history .orders-table .hidden','display','inline-block','','','.p-account-samples-history'),(126176,'printshop-mobile','.p-account-samples-history .orders-table .item','display','block','','','.p-account-samples-history'),(126177,'printshop-mobile','.p-account-samples-history .orders-table .item td','display','block','','','.p-account-samples-history'),(126178,'printshop-mobile','.p-account-samples-history-info .history_attr div','display','table-row','','','.p-account-samples-history-info'),(126179,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number a','display','block','','','.p-account-samples-history-info'),(126180,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','display','block','','','.p-account-samples-history-info'),(126181,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number a','display','block','','','.p-account-samples-history-info'),(126182,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','display','block','','','.p-account-samples-history-info'),(126183,'printshop-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','display','table-cell','','','.p-account-samples-history-info'),(126184,'printshop-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','display','table-cell','','','.p-account-samples-history-info'),(126185,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','display','block','','','.p-account-samples-history-info'),(126186,'printshop-mobile','.p-account-samples-history-info .history_attr','display','table','','','.p-account-samples-history-info'),(126187,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number a','display','block','','','.p-account-samples-history-info'),(126188,'printshop-mobile','.p-account-samples-history-info .history_attr div','display','table-row','','','.p-account-samples-history-info'),(126189,'printshop-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','display','table-cell','','','.p-account-samples-history-info'),(126190,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number a','display','block','','','.p-account-samples-history-info'),(126191,'printshop-mobile','.p-account-samples-history-info .history_attr div','display','table-row','','','.p-account-samples-history-info'),(126192,'printshop-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','display','table-cell','','','.p-account-samples-history-info'),(126193,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','display','block','','','.p-account-samples-history-info'),(126194,'printshop-mobile','.p-account-samples-history-info .history_attr','display','table','','','.p-account-samples-history-info'),(126195,'printshop-mobile','.p-account-samples-history-info .history_attr div','display','table-row','','','.p-account-samples-history-info'),(126196,'printshop-mobile','.p-account-samples-history-info .history_attr div','display','table-row','','','.p-account-samples-history-info'),(126197,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','display','block','','','.p-account-samples-history-info'),(126198,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number a','display','block','','','.p-account-samples-history-info'),(126199,'printshop-mobile','.p-account-samples-history-info .history_attr','display','table','','','.p-account-samples-history-info'),(126200,'printshop-mobile','.p-account-samples-history-info .history_attr div','display','table-row','','','.p-account-samples-history-info'),(126201,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number a','display','block','','','.p-account-samples-history-info'),(126202,'printshop-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','display','table-cell','','','.p-account-samples-history-info'),(126203,'printshop-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','display','table-cell','','','.p-account-samples-history-info'),(126204,'printshop-mobile','.p-account-samples-history-info .history_attr','display','table','','','.p-account-samples-history-info'),(126205,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','display','block','','','.p-account-samples-history-info'),(126206,'printshop-mobile','.p-account-samples-history-info .history_attr','display','table','','','.p-account-samples-history-info'),(126207,'printshop-mobile','.p-account-samples-history-info .history_attr','display','table','','','.p-account-samples-history-info'),(126208,'printshop-mobile','.p-catalog-product .prev-next-product > span','display','block','','','.p-catalog-product'),(126209,'printshop-mobile','.p-catalog-product .pn-price','display','none','','','.p-catalog-product'),(126210,'printshop-mobile','.p-quick-order-index .quick-order-total','display','flex','','','.p-quick-order-index'),(126211,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.p-quick-order-index'),(126212,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.p-quick-order-index'),(126213,'printshop-mobile','.p-quick-order-index ul.token-input-list','display','inline-block','','','.p-quick-order-index'),(126214,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(126215,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(126216,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(126217,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(126218,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(126219,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(126220,'printshop-mobile','.p-sample-checkout-success .page-success .text-1','display','block','3','','.p-sample-checkout-success'),(126221,'printshop-mobile','.w-account-address-book .wrap','display','flex','','','.w-account-address-book'),(126222,'printshop-mobile','.w-account-address-book .default-address','display','inline-block','','','.w-account-address-book'),(126223,'printshop-mobile','.w-account-address-book .address-book','display','flex','','','.w-account-address-book'),(126224,'printshop-mobile','.w-account-address-book .add_item a','display','flex','','','.w-account-address-book'),(126225,'printshop-mobile','.w-account-address-book .btn-edit','display','none','3','','.w-account-address-book'),(126226,'printshop-mobile','.w-account-address-book .add_item a','display','block','3','','.w-account-address-book'),(126227,'printshop-mobile','.w-account-customer-additional-field .field-type-checkbox label','display','inline-block','','','.w-account-customer-additional-field'),(126228,'printshop-mobile','.w-account-customer-additional-field .field-type-text','display','flex','','','.w-account-customer-additional-field'),(126229,'printshop-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(126230,'printshop-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(126231,'printshop-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(126232,'printshop-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(126233,'printshop-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(126234,'printshop-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(126235,'printshop-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(126236,'printshop-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(126237,'printshop-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(126238,'printshop-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(126239,'printshop-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(126240,'printshop-mobile','.w-account-personal-catalog .list-switcher','display','flex','','','.w-account-personal-catalog'),(126241,'printshop-mobile','.w-account-subscription .send-email','display','block','','','.w-account-subscription'),(126242,'printshop-mobile','.w-account-subscription .subscription-variant','display','flex','','','.w-account-subscription'),(126243,'printshop-mobile','.w-blog-widget-categories-list a','display','inline-block','3','','.w-blog-widget-categories-list'),(126244,'printshop-mobile','.w-blog-widget-categories-list a','display','block','','','.w-blog-widget-categories-list'),(126245,'printshop-mobile','.w-blog-widget-most-popular-posts a','display','block','','','.w-blog-widget-most-popular-posts'),(126246,'printshop-mobile','.w-blog-widget-most-popular-posts a','display','inline-block','3','','.w-blog-widget-most-popular-posts'),(126247,'printshop-mobile','.w-blog-widget-post-comments-count span','display','inline-block','','','.w-blog-widget-post-comments-count'),(126248,'printshop-mobile','.w-blog-widget-post-listing .post_comment','display','none','','','.w-blog-widget-post-listing'),(126249,'printshop-mobile','.w-blog-widget-post-listing .post_date span + span','display','inline-block','3','','.w-blog-widget-post-listing'),(126250,'printshop-mobile','.w-blog-widget-post-listing .products','display','block','4','','.w-blog-widget-post-listing'),(126251,'printshop-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','display','inline-block','','','.w-blog-widget-post-share'),(126252,'printshop-mobile','.w-blog-widget-post-title h1','display','none','4','','.w-blog-widget-post-title'),(126253,'printshop-mobile','.w-blog-widget-post-title h1','display','none','3','','.w-blog-widget-post-title'),(126254,'printshop-mobile','.w-blog-widget-related-posts .post_content a','display','block','','','.w-blog-widget-related-posts'),(126255,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_content a','display','block','','','.w-blog-widget-related-posts-by-category'),(126256,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_img img','display','inline-block','','','.w-blog-widget-related-posts-by-category'),(126257,'printshop-mobile','.w-blog-widget-tag-cloud a','display','inline-block','','','.w-blog-widget-tag-cloud'),(126258,'printshop-mobile','.w-cart-bonus-points .btn-remove','display','inline-block','','','.w-cart-bonus-points'),(126259,'printshop-mobile','.w-cart-compare .product-actions .dropdown-toggle','display','none','4','','.w-cart-compare'),(126260,'printshop-mobile','.w-cart-compare .js-cart_totals_container b','display','block','','','.w-cart-compare'),(126261,'printshop-mobile','.w-cart-compare .product','display','block','4','','.w-cart-compare'),(126262,'printshop-mobile','.w-cart-compare .delete-cart','display','inline-block','','','.w-cart-compare'),(126263,'printshop-mobile','.w-cart-credit-amount .btn-remove','display','inline-block','','','.w-cart-credit-amount'),(126264,'printshop-mobile','.w-cart-up-sell h3','display','none','','','.w-cart-up-sell'),(126265,'printshop-mobile','.w-catalog-additional-images li','display','inline-block','','','.w-catalog-additional-images'),(126266,'printshop-mobile','.w-catalog-b2b-add-button ','display','none','','','.w-catalog-b2b-add-button'),(126267,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','display','inline-block','3','','.w-catalog-compare'),(126268,'printshop-mobile','.w-catalog-compare td span','display','inline','','','.w-catalog-compare'),(126269,'printshop-mobile','.w-catalog-compare .product-listing','display','flex','','','.w-catalog-compare'),(126270,'printshop-mobile','.w-catalog-compare .promos-info','display','none','','','.w-catalog-compare'),(126271,'printshop-mobile','.w-catalog-compare .item .compare a','display','none','','','.w-catalog-compare'),(126272,'printshop-mobile','.w-catalog-compare .cross-box .different-all','display','flex','','','.w-catalog-compare'),(126273,'printshop-mobile','.w-catalog-compare .cross-box','display','flex','','','.w-catalog-compare'),(126274,'printshop-mobile','.w-catalog-items-on-page .items-on-page','display','flex','','','.w-catalog-items-on-page'),(126275,'printshop-mobile','.w-catalog-paging .page-number','display','inline-block','','','.w-catalog-paging'),(126276,'printshop-mobile','.w-catalog-paging .next','display','inline-block','','','.w-catalog-paging'),(126277,'printshop-mobile','.w-catalog-paging .paging-item','display','inline-block','','','.w-catalog-paging'),(126278,'printshop-mobile','.w-catalog-paging ','display','inline-block','2','','.w-catalog-paging'),(126279,'printshop-mobile','.w-catalog-paging .paging-holder','display','inline-block','','','.w-catalog-paging'),(126280,'printshop-mobile','.w-catalog-paging .prev','display','inline-block','','','.w-catalog-paging'),(126281,'printshop-mobile','.w-catalog-paging .next-pages','display','inline-block','','','.w-catalog-paging'),(126282,'printshop-mobile','.w-catalog-paging .prev-pages','display','inline-block','','','.w-catalog-paging'),(126283,'printshop-mobile','.w-catalog-paging .paging','display','inline-block','','','.w-catalog-paging'),(126284,'printshop-mobile','.w-checkout-billing-address .genders-title label','display','inline-block','','','.w-checkout-billing-address'),(126285,'printshop-mobile','.w-checkout-billing-address .genders-title > div','display','inline-block','','','.w-checkout-billing-address'),(126286,'printshop-mobile','.w-checkout-billing-address .addresses','display','block','4','','.w-checkout-billing-address'),(126287,'printshop-mobile','.w-checkout-billing-address .edit-ab','display','inline-block','','','.w-checkout-billing-address'),(126288,'printshop-mobile','.w-checkout-billing-address .addresses .address-item label','display','block','','','.w-checkout-billing-address'),(126289,'printshop-mobile','.w-checkout-bonus-points .btn-remove','display','inline-block','','','.w-checkout-bonus-points'),(126290,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','display','inline-block','3','','.w-checkout-contact-information'),(126291,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','display','inline-block','3','','.w-checkout-contact-information'),(126292,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','display','inline-block','3','','.w-checkout-contact-information'),(126293,'printshop-mobile','.w-checkout-create-account .columns .col-2:nth-child(2n)','display','none','','','.w-checkout-create-account'),(126294,'printshop-mobile','.w-checkout-credit-amount .btn-remove','display','inline-block','','','.w-checkout-credit-amount'),(126295,'printshop-mobile','.w-checkout-shipping .sub-item','display','block','','','.w-checkout-shipping'),(126296,'printshop-mobile','.w-checkout-shipping-address .edit-ab','display','inline-block','','','.w-checkout-shipping-address'),(126297,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item label','display','block','','','.w-checkout-shipping-address'),(126298,'printshop-mobile','.w-checkout-shipping-address .change-ab','display','inline-block','','','.w-checkout-shipping-address'),(126299,'printshop-mobile','.w-checkout-shipping-address .genders-title > div','display','inline-block','','','.w-checkout-shipping-address'),(126300,'printshop-mobile','.w-checkout-shipping-address .addresses','display','block','4','','.w-checkout-shipping-address'),(126301,'printshop-mobile','.w-checkout-shipping-address .genders-title label','display','inline-block','','','.w-checkout-shipping-address'),(126302,'printshop-mobile','.w-checkout-shipping-choice #shippingchoice-choice','display','flex','','','.w-checkout-shipping-choice'),(126303,'printshop-mobile','.w-checkout-shipping-choice span','display','flex','','','.w-checkout-shipping-choice'),(126304,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','display','block','','','.w-checkout-shipping-choice'),(126305,'printshop-mobile','.w-checkout-shipping-choice input','display','none','','','.w-checkout-shipping-choice'),(126306,'printshop-mobile','.w-checkout-terms .required-message-wrap','display','inline-block','','','.w-checkout-terms'),(126307,'printshop-mobile','.w-communication-new-topic #communication_group_holder + .columns','display','flex','','','.w-communication-new-topic'),(126308,'printshop-mobile','.w-communication-new-topic .middle-form .col-2 label > span','display','block','','','.w-communication-new-topic'),(126309,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','display','inline-block','','','.w-communication-new-topic'),(126310,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','','','.w-communication-new-topic'),(126311,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','3','','.w-communication-new-topic'),(126312,'printshop-mobile','.w-communication-post .communication-post-author','display','flex','','','.w-communication-post'),(126313,'printshop-mobile','.w-coupons-and-vauchers-checkout .btn-remove','display','inline-block','','','.w-coupons-and-vauchers-checkout'),(126314,'printshop-mobile','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(126315,'printshop-mobile','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(126316,'printshop-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','display','block','','','.w-delivery-day'),(126317,'printshop-mobile','.w-delivery-day .time-left','display','flex','','','.w-delivery-day'),(126318,'printshop-mobile','.w-delivery-day .left-count','display','block','','','.w-delivery-day'),(126319,'printshop-mobile','.w-delivery-day .left-text-left','display','block','','','.w-delivery-day'),(126320,'printshop-mobile','.w-delivery-day .left-text-right','display','block','','','.w-delivery-day'),(126321,'printshop-mobile','.w-image-maps .categories-items .item .description','display','block','','','.w-image-maps'),(126322,'printshop-mobile','.w-image-maps .categories-items .item .title','display','block','','','.w-image-maps'),(126323,'printshop-mobile','.w-image-maps .default-links .item','display','block','1','','.w-image-maps'),(126324,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','display','none','','','.w-image-maps'),(126325,'printshop-mobile','.w-image-maps .float-items .item .description','display','block','','','.w-image-maps'),(126326,'printshop-mobile','.w-image-maps .float-items .item .title','display','block','','','.w-image-maps'),(126327,'printshop-mobile','.w-image-maps .products-items .item-holder','display','block','1','','.w-image-maps'),(126328,'printshop-mobile','.w-image-maps .svg-wrap','display','inline-block','','','.w-image-maps'),(126329,'printshop-mobile','.w-image-maps .categories-items .item','display','block','1','','.w-image-maps'),(126330,'printshop-mobile','.w-image-maps .float-items .item','display','block','1','','.w-image-maps'),(126331,'printshop-mobile','.w-image-maps .default-links .item .title','display','block','','','.w-image-maps'),(126332,'printshop-mobile','.w-image-maps .default-links .item .description','display','block','','','.w-image-maps'),(126333,'printshop-mobile','.w-list-b2b .attributes','display','block','4','','.w-list-b2b'),(126334,'printshop-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','display','inline-block','','','.w-multi-cart-actions'),(126335,'printshop-mobile','.w-multi-cart-actions .cart-actions','display','inline-block','','','.w-multi-cart-actions'),(126336,'printshop-mobile','.w-neighbour-checkout .text','display','inline-block','','','.w-neighbour-checkout'),(126337,'printshop-mobile','.w-personal-gift-status-bar .timeline','display','flex','','','.w-personal-gift-status-bar'),(126338,'printshop-mobile','.w-personal-gift-status-bar .inform','display','inline-block','4','','.w-personal-gift-status-bar'),(126339,'printshop-mobile','.w-personal-gift-status-bar .end-date','display','inline-block','3','','.w-personal-gift-status-bar'),(126340,'printshop-mobile','.w-product-available-in-warehouses .content','display','block','4','','.w-product-available-in-warehouses'),(126341,'printshop-mobile','.w-product-available-in-warehouses .warehouse-item','display','inline-block','','','.w-product-available-in-warehouses'),(126342,'printshop-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(126343,'printshop-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(126344,'printshop-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(126345,'printshop-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(126346,'printshop-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(126347,'printshop-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(126348,'printshop-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(126349,'printshop-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(126350,'printshop-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(126351,'printshop-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(126352,'printshop-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(126353,'printshop-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(126354,'printshop-mobile','.w-promotions .prom-multi-discount .products','display','grid','','','.w-promotions'),(126355,'printshop-mobile','.w-promotions .prom-multi-discount .list','display','grid','','','.w-promotions'),(126356,'printshop-mobile','.w-promotions .nextdiscount .item-holder','display','flex','','','.w-promotions'),(126357,'printshop-mobile','.w-promotions .nextdiscount .promo-for-each','display','inline-block','','','.w-promotions'),(126358,'printshop-mobile','.w-promotions .promo-cart-discount .item a','display','block','','','.w-promotions'),(126359,'printshop-mobile','.w-promotions .promo-cart-discount .content','display','flex','','','.w-promotions'),(126360,'printshop-mobile','.w-promotions .promo-cart-discount .slave','display','flex','','','.w-promotions'),(126361,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','display','inline-block','','','.w-promotions'),(126362,'printshop-mobile','.w-promotions .promo-cart-discount','display','flex','','','.w-promotions'),(126363,'printshop-mobile','.w-promotions .promo-content > .personalgift','display','none','','','.w-promotions'),(126364,'printshop-mobile','.w-promotions .promo-date > div','display','inline-block','','','.w-promotions'),(126365,'printshop-mobile','.w-promotions .promo-salemaker .discount','display','inline-block','','','.w-promotions'),(126366,'printshop-mobile','.w-promotions .promo-salemaker .content','display','flex','','','.w-promotions'),(126367,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','display','inline-block','','','.w-promotions'),(126368,'printshop-mobile','.w-promotions .promo-salemaker','display','flex','','','.w-promotions'),(126369,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range > div','display','inline-block','','','.w-promotions'),(126370,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','display','inline-block','','','.w-promotions'),(126371,'printshop-mobile','.w-promotions .icon','display','inline-block','','','.w-promotions'),(126372,'printshop-mobile','.w-promotions .promo-salemaker .content a.name','display','block','','','.w-promotions'),(126373,'printshop-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','display','block','','','.w-promotions'),(126374,'printshop-mobile','.w-promotions .heading-3','display','inline-block','','','.w-promotions'),(126375,'printshop-mobile','.w-promotions .prom-multi-discount','display','block','4','','.w-promotions'),(126376,'printshop-mobile','.w-promotions .nextdiscount .content','display','grid','','','.w-promotions'),(126377,'printshop-mobile','.w-reviews-content .item','display','grid','','','.w-reviews-content'),(126378,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul','display','flex','','','.w-sitemap-delivery-location'),(126379,'printshop-mobile','.w-social-links .name, .w-social-links .image','display','none','','','.w-social-links'),(126380,'printshop-mobile','.w-taxable select','display','inline-block','','','.w-taxable'),(126381,'printshop-mobile','.w-taxable form','display','flex','','','.w-taxable'),(126382,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','display','flex','','','.w-upload-customer-id-upload-customer-id-form'),(126383,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details ~ div','display','none','','','.w-upload-customer-id-upload-customer-id-form'),(126384,'printshop-mobile','.w-wedding-registry-widgets-photos .upload-file-wrap','display','flex','','','.w-wedding-registry-widgets-photos'),(126385,'printshop-mobile','.w-wedding-registry-widgets-search-registry-button a','display','inline-block','3','','.w-wedding-registry-widgets-search-registry-button'),(126386,'printshop-mobile','.w-wedding-registry-widgets-share-link a','display','inline-block','3','','.w-wedding-registry-widgets-share-link'),(126387,'printshop-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(126388,'printshop-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(126389,'printshop-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(126390,'printshop-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(126391,'printshop-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(126392,'printshop-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(126393,'printshop-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(126394,'printshop-mobile','.p-catalog-product .pn-image','display','inline-block','3','','.p-catalog-product'),(126395,'printshop-mobile','.w-filters .filter-box-content ul li.view_items','display_important','important','','','.w-filters'),(126396,'printshop-mobile','.w-menu-mobile .menu-ico','display_important','important','','','.w-menu-mobile'),(126397,'printshop-mobile','.w-cart .cart-box.hover-box:hover .cart-content','display_important','important','','','.w-cart'),(126398,'printshop-mobile','.w-menu-horizontal ul ul li','display_important','important','','','.w-menu-horizontal'),(126399,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display_important','important','','','.b-switch'),(126400,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display_important','important','','','.b-switch'),(126401,'printshop-mobile','.w-menu-style-1 ul ul li','display_important','important','','','.w-menu-style-1'),(126402,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display_important','important','','','.b-menu-open_from-left'),(126403,'printshop-mobile','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display_important','important','','','.b-menu-style'),(126404,'printshop-mobile','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display_important','important','','','.b-menu-style'),(126405,'printshop-mobile','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display_important','important','','','.b-menu-style'),(126406,'printshop-mobile','.p-catalog-product .pn-price','display_important','important','','','.p-catalog-product'),(126407,'printshop-mobile','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','fill','rgba(255, 255, 255, 0)','','','.w-image-maps'),(126408,'printshop-mobile','.w-image-maps rect.no-items, .w-image-maps circle.no-items, .w-image-maps polygon.no-items','fill','rgba(150, 150, 150, 0.7)','','','.w-image-maps'),(126409,'printshop-mobile','.w-image-maps polygon:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(126410,'printshop-mobile','.w-image-maps rect:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(126411,'printshop-mobile','.w-image-maps circle:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(126412,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','filter','alpha(opacity=50)','','','.b-switch'),(126413,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','filter','alpha(opacity=50)','','','.b-switch'),(126414,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','filter','alpha(opacity=50)','','','.b-switch'),(126415,'printshop-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','filter','alpha(opacity=0)','','','.b-switch'),(126416,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','filter','progid','','','.b-select-suggest'),(126417,'printshop-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','filter','none','','','.b-select-suggest'),(126418,'printshop-mobile','.b-select-suggest .select2-dropdown-open .select2-choice','filter','progid','','','.b-select-suggest'),(126419,'printshop-mobile','.b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choice, .b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choices','filter','progid','','','.b-select-suggest'),(126420,'printshop-mobile','.b-select-suggest .select2-drop-mask','filter','alpha(opacity=0)','','','.b-select-suggest'),(126421,'printshop-mobile','.b-select-suggest .select2-container.select2-drop-above .select2-choice','filter','progid','','','.b-select-suggest'),(126422,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','filter','progid','','','.b-select-suggest'),(126423,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','filter','progid','','','.b-select-suggest'),(126424,'printshop-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-basis','0','','','.b-menu-position'),(126425,'printshop-mobile','.w-account-address-book .wrap','flex-direction','column','','','.w-account-address-book'),(126426,'printshop-mobile','.w-account-address-book .add_item a','flex-direction','column','','','.w-account-address-book'),(126427,'printshop-mobile','.w-catalog-compare .cross-box','flex-direction','column','','','.w-catalog-compare'),(126428,'printshop-mobile','.w-promotions .promo-cart-discount .slave','flex-direction','column','','','.w-promotions'),(126429,'printshop-mobile','.p-wedding-registry-search .search-form > div','flex-grow','2','','','.p-wedding-registry-search'),(126430,'printshop-mobile','.p-wedding-registry-search #searchform-status label','flex-grow','1','','','.p-wedding-registry-search'),(126431,'printshop-mobile','.p-wedding-registry-search .button','flex-grow','1','','','.p-wedding-registry-search'),(126432,'printshop-mobile','.b-products-listing .products-listing .attribute-qty-block > span','flex-grow','1','','','.b-products-listing'),(126433,'printshop-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-grow','1','','','.b-menu-position'),(126434,'printshop-mobile','.b-messages .email-line > div','flex-grow','1','','','.b-messages'),(126435,'printshop-mobile','.w-account-customer-additional-field .field-type-text label','flex-grow','1','','','.w-account-customer-additional-field'),(126436,'printshop-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-grow','1','','','.w-account-customer-additional-field'),(126437,'printshop-mobile','.w-account-personal-catalog .list-switcher a','flex-grow','1','','','.w-account-personal-catalog'),(126438,'printshop-mobile','.w-account-subscription .title','flex-grow','1','','','.w-account-subscription'),(126439,'printshop-mobile','.w-catalog-compare .product-listing > div','flex-grow','1','','','.w-catalog-compare'),(126440,'printshop-mobile','.w-delivery-day .time-left > span','flex-grow','1','','','.w-delivery-day'),(126441,'printshop-mobile','.w-promotions .prom-multi-discount .promo-product, .w-promotions .prom-multi-discount .promo-category-item','flex-grow','1','','','.w-promotions'),(126442,'printshop-mobile','.b-products-listing .select-attributes .item-title','flex-shrink','0','','','.b-products-listing'),(126443,'printshop-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-shrink','1','','','.b-menu-position'),(126444,'printshop-mobile','.w-account-customer-additional-field .field-type-text label','flex-shrink','0','','','.w-account-customer-additional-field'),(126445,'printshop-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-shrink','0','','','.w-account-customer-additional-field'),(126446,'printshop-mobile','.w-catalog-compare .cross-box','flex-shrink','0','','','.w-catalog-compare'),(126447,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','flex-shrink','0','','','.w-upload-customer-id-upload-customer-id-form'),(126448,'printshop-mobile','.w-categories .categories','flex-wrap','wrap','','','.w-categories'),(126449,'printshop-mobile','.personal-buttons > div','flex-wrap','wrap','','','.personal-buttons'),(126450,'printshop-mobile','.w-top-categories .categories','flex-wrap','wrap','','','.w-top-categories'),(126451,'printshop-mobile','.b-products-listing .products-listing .attribute-qty-blocks','flex-wrap','wrap','','','.b-products-listing'),(126452,'printshop-mobile','.w-account-address-book .address-book','flex-wrap','wrap','','','.w-account-address-book'),(126453,'printshop-mobile','.w-communication-new-topic #communication_group_holder + .columns','flex-wrap','wrap','','','.w-communication-new-topic'),(126454,'printshop-mobile','.w-promotions .promo-cart-discount .content','flex-wrap','wrap','','','.w-promotions'),(126455,'printshop-mobile','.w-promotions .promo-salemaker .content','flex-wrap','wrap','','','.w-promotions'),(126456,'printshop-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','float','right','3','','.w-menu'),(126457,'printshop-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','float','none','','','.w-menu'),(126458,'printshop-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','float','right','3','','.w-menu'),(126459,'printshop-mobile','.w-menu .hided.menu ul li','float','none','','','.w-menu'),(126460,'printshop-mobile','.w-menu-horizontal .box','float','none','','','.w-menu-horizontal'),(126461,'printshop-mobile','.w-menu-big li','float','none','','','.w-menu-big'),(126462,'printshop-mobile','.w-menu-style-1 .box','float','none','','','.w-menu-style-1'),(126463,'printshop-mobile','.b-slick [dir=\'rtl\'] .slick-slide','float','right','','','.b-slick'),(126464,'printshop-mobile','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(126465,'printshop-mobile','.w-login-block .returning','float','left','','','.w-login-block'),(126466,'printshop-mobile','.w-login-block .new','float','right','','','.w-login-block'),(126467,'printshop-mobile','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(126468,'printshop-mobile','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(126469,'printshop-mobile','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(126470,'printshop-mobile','.w-login-block .guest','float','right','','','.w-login-block'),(126471,'printshop-mobile','.w-sale .holder-1','float','right','','','.w-sale'),(126472,'printshop-mobile','.w-sale .image','float','left','','','.w-sale'),(126473,'printshop-mobile','.w-sale .holder-2','float','left','','','.w-sale'),(126474,'printshop-mobile','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(126475,'printshop-mobile','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(126476,'printshop-mobile','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(126477,'printshop-mobile','.w-product-sale-ends .left-count','float','left','','','.w-product-sale-ends'),(126478,'printshop-mobile','.w-product-sale-ends .left-text-right','float','left','','','.w-product-sale-ends'),(126479,'printshop-mobile','.w-product-collection .current-product','float','left','','','.w-product-collection'),(126480,'printshop-mobile','.w-product-collection .right-area','float','left','','','.w-product-collection'),(126481,'printshop-mobile','.w-product-sale-ends .left-text-left','float','left','','','.w-product-sale-ends'),(126482,'printshop-mobile','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(126483,'printshop-mobile','.w-cart .image','float','left','','','.w-cart'),(126484,'printshop-mobile','.w-cart .cart-box','float','right','','','.w-cart'),(126485,'printshop-mobile','.w-compare-box-item .cb_title','float','left','','','.w-compare-box-item'),(126486,'printshop-mobile','.w-compare-box-item .cb_check','float','right','','','.w-compare-box-item'),(126487,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','float','right','','','.b-multi-page-checkout'),(126488,'printshop-mobile','.b-pagination .pagination .left-area','float','left','','','.b-pagination'),(126489,'printshop-mobile','.b-pagination .pagination .right-area','float','right','','','.b-pagination'),(126490,'printshop-mobile','.w-product-quantity .product-quantity-label','float','left','','','.w-product-quantity'),(126491,'printshop-mobile','.w-product-in-bundles .bundle_item','float','left','','','.w-product-in-bundles'),(126492,'printshop-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','float','left','','','.p-account-address-book'),(126493,'printshop-mobile','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(126494,'printshop-mobile','.w-product-bundle .bundle_item','float','left','','','.w-product-bundle'),(126495,'printshop-mobile','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(126496,'printshop-mobile','.p-account-address-book .topInfo > div','float','none','693','','.p-account-address-book'),(126497,'printshop-mobile','.p-account-address-book .address_book_row .column + .column','float','none','693','','.p-account-address-book'),(126498,'printshop-mobile','.p-blog-index .wp-widget li','float','left','3','','.p-blog-index'),(126499,'printshop-mobile','.p-account-address-book .address_book_row .column','float','none','693','','.p-account-address-book'),(126500,'printshop-mobile','.p-account-address-book .topInfo > div + div','float','none','693','','.p-account-address-book'),(126501,'printshop-mobile','.p-blog-index .post-thumbnail','float','left','','','.p-blog-index'),(126502,'printshop-mobile','.w-list-type-1_2 .right-area .right-area-2','float','left','','','.w-list-type-1_2'),(126503,'printshop-mobile','.w-list-type-1_2 .right-area .name','float','left','','','.w-list-type-1_2'),(126504,'printshop-mobile','.w-list-type-1_2 .right-area','float','right','694','','.w-list-type-1_2'),(126505,'printshop-mobile','.w-list-type-1_2 .right-area .name','float','none','694','','.w-list-type-1_2'),(126506,'printshop-mobile','.w-list-type-1_2 .right-area .right-area-2','float','none','694','','.w-list-type-1_2'),(126507,'printshop-mobile','.w-list-type-1_2 .image','float','none','694','','.w-list-type-1_2'),(126508,'printshop-mobile','.w-list-type-2 .button-wishlist','float','right','','','.w-list-type-2'),(126509,'printshop-mobile','.b-info-popup .password-info .info-popup','float','right','','','.b-info-popup'),(126510,'printshop-mobile','.w-promo-code .btn','float','right','','','.w-promo-code'),(126511,'printshop-mobile','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(126512,'printshop-mobile','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(126513,'printshop-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','float','right','','','.p-wedding-registry-manage'),(126514,'printshop-mobile','.w-product-bonus-points > div > div','float','left','','','.w-product-bonus-points'),(126515,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(126516,'printshop-mobile','.p-account-order-pay .history_info > div','float','left','','','.p-account-order-pay'),(126517,'printshop-mobile','.p-account-order-pay .historyTotal table','float','right','','','.p-account-order-pay'),(126518,'printshop-mobile','.w-product-configurator .item-content > div','float','left','693','','.w-product-configurator'),(126519,'printshop-mobile','.p-wedding-registry-manage .qty-input','float','left','','','.p-wedding-registry-manage'),(126520,'printshop-mobile','.p-wedding-registry-manage a.remove-btn','float','right','','','.p-wedding-registry-manage'),(126521,'printshop-mobile','.p-blog-index .nav-previous','float','left','','','.p-blog-index'),(126522,'printshop-mobile','.p-blog-index .w-blog-sidebar .wp-widget','float','left','720','','.p-blog-index'),(126523,'printshop-mobile','.p-blog-index .nav-previous a','float','left','3','','.p-blog-index'),(126524,'printshop-mobile','.p-blog-index .nav-next a','float','right','3','','.p-blog-index'),(126525,'printshop-mobile','.p-blog-index .nav-next','float','right','','','.p-blog-index'),(126526,'printshop-mobile','.p-blog-index .comment-metadata','float','right','','','.p-blog-index'),(126527,'printshop-mobile','.p-blog-index .comment-author','float','left','','','.p-blog-index'),(126528,'printshop-mobile','.w-list-type-1_3 .right-area .right-area-2','float','left','','','.w-list-type-1_3'),(126529,'printshop-mobile','.w-list-type-2_2 .rating-count','float','right','','','.w-list-type-2_2'),(126530,'printshop-mobile','.w-list-type-2_2 .price','float','left','','','.w-list-type-2_2'),(126531,'printshop-mobile','.w-list-type-2_2 .rating','float','right','','','.w-list-type-2_2'),(126532,'printshop-mobile','.w-list-type-2_2 .qty-input','float','left','','','.w-list-type-2_2'),(126533,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','float','right','','','.w-list-type-2_2'),(126534,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','float','right','4','','.w-list-type-2_2'),(126535,'printshop-mobile','.w-list-type-2_2 .image','float','left','','','.w-list-type-2_2'),(126536,'printshop-mobile','.buttons .left-buttons','float','left','','',''),(126537,'printshop-mobile','.w-list-type-2_2 .button-view a','float','right','4','','.w-list-type-2_2'),(126538,'printshop-mobile','.w-list-type-2_2 .button-wishlist','float','right','','','.w-list-type-2_2'),(126539,'printshop-mobile','.buttons .right-buttons','float','right','','',''),(126540,'printshop-mobile','.w-list-type-2 .price','float','left','','','.w-list-type-2'),(126541,'printshop-mobile','.w-list-type-2 .rating-count','float','right','','','.w-list-type-2'),(126542,'printshop-mobile','.w-brands .brands-listing > div','float','left','','','.w-brands'),(126543,'printshop-mobile','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(126544,'printshop-mobile','.b-compare .compare-box-btn','float','right','','','.b-compare'),(126545,'printshop-mobile','.b-compare .col-two label, .b-compare .col-two select','float','left','','','.b-compare'),(126546,'printshop-mobile','.heading-4 .right-text, h4 .right-text','float','right','','',''),(126547,'printshop-mobile','.w-socials > li','float','left','','','.w-socials'),(126548,'printshop-mobile','.b-product-images .additional-images, .b-product-images .additional-videos','float','right','','','.b-product-images'),(126549,'printshop-mobile','.w-socials .post_item_img','float','left','','','.w-socials'),(126550,'printshop-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(126551,'printshop-mobile','.w-list-type-1 .button-view a','float','right','4','','.w-list-type-1'),(126552,'printshop-mobile','.w-list-type-1 .button-wishlist','float','right','','','.w-list-type-1'),(126553,'printshop-mobile','.w-filters .handle-to','float','right','','','.w-filters'),(126554,'printshop-mobile','.w-filters .handle-from','float','left','','','.w-filters'),(126555,'printshop-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(126556,'printshop-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(126557,'printshop-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(126558,'printshop-mobile','.w-menu-style-1 li','float','none','','','.w-menu-style-1'),(126559,'printshop-mobile','.p-reviews-info .review-info-image','float','left','','','.p-reviews-info'),(126560,'printshop-mobile','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(126561,'printshop-mobile','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(126562,'printshop-mobile','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(126563,'printshop-mobile','.w-list-type-1_3 .rating','float','right','','','.w-list-type-1_3'),(126564,'printshop-mobile','.w-list-type-1_3 .rating-count','float','right','','','.w-list-type-1_3'),(126565,'printshop-mobile','.w-list-type-1_3 .qty-input','float','left','','','.w-list-type-1_3'),(126566,'printshop-mobile','.w-sale .left-text-left','float','left','','','.w-sale'),(126567,'printshop-mobile','.w-sale .left-text-right','float','left','','','.w-sale'),(126568,'printshop-mobile','.w-sale .left-count','float','left','','','.w-sale'),(126569,'printshop-mobile','.b-form .terms-login .bootstrap-switch','float','right','','','.b-form'),(126570,'printshop-mobile','.b-slick .slick-slide','float','left','','','.b-slick'),(126571,'printshop-mobile','.b-quantity .qty-input label','float','left','','','.b-quantity'),(126572,'printshop-mobile','.p-account-index .account_info li','float','none','693','','.p-account-index'),(126573,'printshop-mobile','.w-list-type-1_3 .right-area .right-area-2','float','none','694','','.w-list-type-1_3'),(126574,'printshop-mobile','.w-list-type-1_3 .right-area .name','float','none','694','','.w-list-type-1_3'),(126575,'printshop-mobile','.w-list-type-1_3 .right-area','float','right','694','','.w-list-type-1_3'),(126576,'printshop-mobile','.w-menu-horizontal li','float','none','','','.w-menu-horizontal'),(126577,'printshop-mobile','.w-cart-order-total.box','float','right','','','.w-cart-order-total'),(126578,'printshop-mobile','.w-cart-discount-coupon .gift-code button','float','right','','','.w-cart-discount-coupon'),(126579,'printshop-mobile','.p-account-index .topAccount > li','float','none','693','','.p-account-index'),(126580,'printshop-mobile','.p-account-index .ai_title, .p-account-index .ai_value','float','left','','','.p-account-index'),(126581,'printshop-mobile','.b-form .discount-box button','float','right','','','.b-form'),(126582,'printshop-mobile','.p-account-index .account_info li','float','left','','','.p-account-index'),(126583,'printshop-mobile','.b-form .col-right','float','right','','','.b-form'),(126584,'printshop-mobile','.p-account-history-info .history_info > div','float','left','','','.p-account-history-info'),(126585,'printshop-mobile','.b-form .columns .col-2','float','left','','','.b-form'),(126586,'printshop-mobile','.p-account-index .topAccount > li','float','left','','','.p-account-index'),(126587,'printshop-mobile','.w-cart-gift-certificate .gift-code button','float','right','','','.w-cart-gift-certificate'),(126588,'printshop-mobile','.w-cart-give-away .ga_attributes > div','float','left','','','.w-cart-give-away'),(126589,'printshop-mobile','.w-cart-give-away .ga_column','float','left','','','.w-cart-give-away'),(126590,'printshop-mobile','.w-cart-give-away .ga_price .checkBoxWrap','float','right','','','.w-cart-give-away'),(126591,'printshop-mobile','.w-cart-give-away .ga_img','float','left','','','.w-cart-give-away'),(126592,'printshop-mobile','.w-list-type-1_3 .right-area','float','right','','','.w-list-type-1_3'),(126593,'printshop-mobile','.b-form .addresses .address-item input[type=\"radio\"]','float','left','','','.b-form'),(126594,'printshop-mobile','.w-list-type-1_3 .right-area .name','float','left','','','.w-list-type-1_3'),(126595,'printshop-mobile','.w-list-type-1_3 .image','float','none','694','','.w-list-type-1_3'),(126596,'printshop-mobile','.w-list-type-2 .button-wishlist button','float','right','4','','.w-list-type-2'),(126597,'printshop-mobile','.w-list-type-2 .button-view a','float','right','4','','.w-list-type-2'),(126598,'printshop-mobile','.w-list-type-2 .rating','float','right','','','.w-list-type-2'),(126599,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','float','right','','','.w-list-type-2'),(126600,'printshop-mobile','.w-list-type-2 .qty-input','float','left','','','.w-list-type-2'),(126601,'printshop-mobile','.w-list-type-1_3 .price','float','left','','','.w-list-type-1_3'),(126602,'printshop-mobile','.w-list-type-1_3 .image','float','left','','','.w-list-type-1_3'),(126603,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','float','right','','','.w-list-type-1_3'),(126604,'printshop-mobile','.heading-3 .right-text, h3 .right-text','float','right','','',''),(126605,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','float','right','4','','.w-list-type-1_3'),(126606,'printshop-mobile','.w-list-type-1_3 .button-view a','float','right','4','','.w-list-type-1_3'),(126607,'printshop-mobile','.w-list-type-1_3 .button-wishlist','float','right','','','.w-list-type-1_3'),(126608,'printshop-mobile','.w-list-type-1_3 .attributes > .attributes > div','float','left','','','.w-list-type-1_3'),(126609,'printshop-mobile','.w-list-type-1_2 .right-area','float','right','','','.w-list-type-1_2'),(126610,'printshop-mobile','.w-list-type-1_2 .rating','float','right','','','.w-list-type-1_2'),(126611,'printshop-mobile','.w-list-type-1_2 .rating-count','float','right','','','.w-list-type-1_2'),(126612,'printshop-mobile','.w-list-type-1_2 .qty-input','float','left','','','.w-list-type-1_2'),(126613,'printshop-mobile','.w-list-type-1_2 .price','float','left','','','.w-list-type-1_2'),(126614,'printshop-mobile','.w-list-type-1_2 .image','float','left','','','.w-list-type-1_2'),(126615,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','float','right','4','','.w-list-type-1_2'),(126616,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','float','right','','','.w-list-type-1_2'),(126617,'printshop-mobile','.w-list-type-1_2 .button-view a','float','right','4','','.w-list-type-1_2'),(126618,'printshop-mobile','.w-list-type-1_2 .button-view','float','left','','','.w-list-type-1_2'),(126619,'printshop-mobile','.w-list-type-1_2 .button-wishlist','float','right','','','.w-list-type-1_2'),(126620,'printshop-mobile','.w-list-type-1 .rating-count','float','right','','','.w-list-type-1'),(126621,'printshop-mobile','.w-list-type-1 .rating','float','right','','','.w-list-type-1'),(126622,'printshop-mobile','.w-list-type-1 .qty-input','float','left','','','.w-list-type-1'),(126623,'printshop-mobile','.w-list-type-1 .price','float','left','','','.w-list-type-1'),(126624,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','float','right','','','.w-list-type-1'),(126625,'printshop-mobile','.heading-3 .edit, h3 .edit','float','right','','',''),(126626,'printshop-mobile','.w-list-type-1 .button-wishlist button','float','right','4','','.w-list-type-1'),(126627,'printshop-mobile','.heading-4 .edit, h4 .edit','float','right','','',''),(126628,'printshop-mobile','.b-form .col-left','float','left','','','.b-form'),(126629,'printshop-mobile','.b-form .addresses .address-item','float','left','','','.b-form'),(126630,'printshop-mobile','.w-search .image','float','left','','','.w-search'),(126631,'printshop-mobile','.p-account-history-info .historyTotal table','float','right','','','.p-account-history-info'),(126632,'printshop-mobile','.b-form .payment-method .item-radio input','float','left','','','.b-form'),(126633,'printshop-mobile','.b-form .shipping-method .input','float','right','','','.b-form'),(126634,'printshop-mobile','.b-form .shipping-method .cost','float','right','','','.b-form'),(126635,'printshop-mobile','.p-account-address-book .address_book h2 strong','float','left','','','.p-account-address-book'),(126636,'printshop-mobile','.p-account-address-book .button2','float','left','','','.p-account-address-book'),(126637,'printshop-mobile','.p-account-address-book .button1','float','right','','','.p-account-address-book'),(126638,'printshop-mobile','.b-info .info','float','left','3','','.b-info'),(126639,'printshop-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','float','right','','','.b-products-listing'),(126640,'printshop-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','float','right','','','.b-products-listing'),(126641,'printshop-mobile','.b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockBox.type-14 > .col, .b-products-listing .BlockBox.type-15 > .col, .b-products-listing .BlockBox.type-16 > .col','float','left','','','.b-products-listing'),(126642,'printshop-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','float','right','','','.b-products-listing'),(126643,'printshop-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','float','right','','','.b-products-listing'),(126644,'printshop-mobile','.b-products-listing .BlockBox.type-2 > .col, .b-products-listing .BlockBox.type-3 > .col, .b-products-listing .BlockBox.type-4 > .col, .b-products-listing .BlockBox.type-5 > .col, .b-products-listing .BlockBox.type-6 > .col','float','left','','','.b-products-listing'),(126645,'printshop-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','float','right','','','.b-products-listing'),(126646,'printshop-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','float','right','','','.b-products-listing'),(126647,'printshop-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','float','right','','','.b-products-listing'),(126648,'printshop-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','float','right','','','.b-products-listing'),(126649,'printshop-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','float','right','','','.b-products-listing'),(126650,'printshop-mobile','.b-products-listing .BlockBox.type-7 > .col, .b-products-listing .BlockBox.type-8 > .col, .b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col','float','left','','','.b-products-listing'),(126651,'printshop-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','float','right','','','.b-products-listing'),(126652,'printshop-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','float','right','','','.b-products-listing'),(126653,'printshop-mobile','.b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col, .b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockB','float','left','','','.b-products-listing'),(126654,'printshop-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','float','right','','','.b-products-listing'),(126655,'printshop-mobile','.b-products-listing .products-listing .attribute-qty-block > span','float','left','','','.b-products-listing'),(126656,'printshop-mobile','.b-products-listing .products-listing .bonus-points-cost','float','left','3','','.b-products-listing'),(126657,'printshop-mobile','.b-products-listing .products-listing .bonus-points-price','float','left','3','','.b-products-listing'),(126658,'printshop-mobile','.b-products-listing .products-listing .compare input + span','float','right','','','.b-products-listing'),(126659,'printshop-mobile','.b-products-listing .products-listing .item','float','none','','','.b-products-listing'),(126660,'printshop-mobile','.b-products-listing .products-listing .mult-qty-input','float','right','','','.b-products-listing'),(126661,'printshop-mobile','.b-products-listing .products-listing .radio-attributes .item-title','float','left','','','.b-products-listing'),(126662,'printshop-mobile','.b-products-listing .products-listing a.btn.view-button','float','right','3','','.b-products-listing'),(126663,'printshop-mobile','.b-products-listing .products-listing.align-left .item','float','left','','','.b-products-listing'),(126664,'printshop-mobile','.b-products-listing .products-listing.align-right .item','float','right','','','.b-products-listing'),(126665,'printshop-mobile','.b-products-listing .wedding-registry-count','float','right','','','.b-products-listing'),(126666,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(126667,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(126668,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(126669,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(126670,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(126671,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > .no-link','float','right','3','','.b-menu-style-3'),(126672,'printshop-mobile','.b-messages .msv_btn .btn','float','right','','','.b-messages'),(126673,'printshop-mobile','.b-messages .messages-menu li span','float','right','','','.b-messages'),(126674,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices li','float','left','','','.b-select-suggest'),(126675,'printshop-mobile','.b-sub-totals .historyTotal table','float','right','','','.b-sub-totals'),(126676,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(126677,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(126678,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(126679,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(126680,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(126681,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(126682,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(126683,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(126684,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(126685,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(126686,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(126687,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(126688,'printshop-mobile','.b-trade-approval .col-right','float','right','','','.b-trade-approval'),(126689,'printshop-mobile','.b-trade-approval .col-left','float','left','','','.b-trade-approval'),(126690,'printshop-mobile','.b-trade-approval .col-3','float','left','','','.b-trade-approval'),(126691,'printshop-mobile','.b-upload-files .remove-file','float','right','','','.b-upload-files'),(126692,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','float','left','3','','.b-warehouses-popup'),(126693,'printshop-mobile','.batchPr .w-batch-products .products-listing .image','float','left','','','.batchPr'),(126694,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(2)','float','none','','','.batchPr'),(126695,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','float','left','','','.batchPr'),(126696,'printshop-mobile','.p-account-samples-history-info .history_info > div','float','left','','','.p-account-samples-history-info'),(126697,'printshop-mobile','.p-account-samples-history-info .history_info > div','float','left','','','.p-account-samples-history-info'),(126698,'printshop-mobile','.p-account-samples-history-info .history_info > div','float','left','','','.p-account-samples-history-info'),(126699,'printshop-mobile','.p-account-samples-history-info .history_info > div','float','left','','','.p-account-samples-history-info'),(126700,'printshop-mobile','.p-account-samples-history-info .history_info > div','float','left','','','.p-account-samples-history-info'),(126701,'printshop-mobile','.p-account-samples-history-info .history_info > div','float','left','','','.p-account-samples-history-info'),(126702,'printshop-mobile','.p-payer-order-confirmation .dob-hide label','float','left','','','.p-payer-order-confirmation'),(126703,'printshop-mobile','.p-payer-order-confirmation .dob-hide > div','float','right','','','.p-payer-order-confirmation'),(126704,'printshop-mobile','.p-payer-order-pay .dob-hide > div','float','right','','','.p-payer-order-pay'),(126705,'printshop-mobile','.p-payer-order-pay .dob-hide label','float','left','','','.p-payer-order-pay'),(126706,'printshop-mobile','.w-account-addresses-list .addsess-suggestion-item','float','left','','','.w-account-addresses-list'),(126707,'printshop-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','float','left','','','.w-account-addresses-list'),(126708,'printshop-mobile','.w-blog-widget-post-date ','float','none','','','.w-blog-widget-post-date'),(126709,'printshop-mobile','.w-blog-widget-post-image ','float','none','','','.w-blog-widget-post-image'),(126710,'printshop-mobile','.w-blog-widget-post-listing .post','float','left','','','.w-blog-widget-post-listing'),(126711,'printshop-mobile','.w-blog-widget-post-share ','float','none','','','.w-blog-widget-post-share'),(126712,'printshop-mobile','.w-blog-widget-post-title ','float','none','','','.w-blog-widget-post-title'),(126713,'printshop-mobile','.w-blog-widget-related-posts .post','float','left','','','.w-blog-widget-related-posts'),(126714,'printshop-mobile','.w-blog-widget-related-posts-by-category .post','float','left','','','.w-blog-widget-related-posts-by-category'),(126715,'printshop-mobile','.w-cart-compare .product .image','float','left','','','.w-cart-compare'),(126716,'printshop-mobile','.w-cart-compare .product-actions','float','right','','','.w-cart-compare'),(126717,'printshop-mobile','.w-cart-compare .buttons','float','right','','','.w-cart-compare'),(126718,'printshop-mobile','.w-cart-compare .js-cart_totals_container','float','left','','','.w-cart-compare'),(126719,'printshop-mobile','.w-catalog-compare .compare label','float','right','','','.w-catalog-compare'),(126720,'printshop-mobile','.w-catalog-compare .buyButton','float','right','','','.w-catalog-compare'),(126721,'printshop-mobile','.w-checkout-billing-address .btn-cancel','float','left','','','.w-checkout-billing-address'),(126722,'printshop-mobile','.w-checkout-billing-address .addresses .address-item','float','left','','','.w-checkout-billing-address'),(126723,'printshop-mobile','.w-checkout-billing-address .add-ab','float','left','','','.w-checkout-billing-address'),(126724,'printshop-mobile','.w-checkout-billing-address .bootstrap-switch','float','right','','','.w-checkout-billing-address'),(126725,'printshop-mobile','.w-checkout-contact-information .btn-save','float','right','','','.w-checkout-contact-information'),(126726,'printshop-mobile','.w-checkout-create-account .newsletter-switcher .bootstrap-switch','float','right','','','.w-checkout-create-account'),(126727,'printshop-mobile','.w-checkout-create-account .create-account-switcher','float','right','','','.w-checkout-create-account'),(126728,'printshop-mobile','.w-checkout-gdpr .candlestick-wrapper','float','right','','','.w-checkout-gdpr'),(126729,'printshop-mobile','.w-checkout-shipping-address .add-ab','float','left','','','.w-checkout-shipping-address'),(126730,'printshop-mobile','.w-checkout-shipping-address .btn-cancel','float','left','','','.w-checkout-shipping-address'),(126731,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item','float','left','','','.w-checkout-shipping-address'),(126732,'printshop-mobile','.w-delivery-day .left-count','float','left','','','.w-delivery-day'),(126733,'printshop-mobile','.w-delivery-day .left-text-left','float','left','','','.w-delivery-day'),(126734,'printshop-mobile','.w-delivery-day .left-text-right','float','left','','','.w-delivery-day'),(126735,'printshop-mobile','.w-list-b2b .select-attributes:nth-child(2n)','float','right','','','.w-list-b2b'),(126736,'printshop-mobile','.w-list-b2b .select-attributes','float','left','','','.w-list-b2b'),(126737,'printshop-mobile','.w-neighbour-checkout .bootstrap-switch','float','right','','','.w-neighbour-checkout'),(126738,'printshop-mobile','.w-product-cross-sell .buy-all-checker','float','left','','','.w-product-cross-sell'),(126739,'printshop-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(126740,'printshop-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(126741,'printshop-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(126742,'printshop-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(126743,'printshop-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(126744,'printshop-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(126745,'printshop-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(126746,'printshop-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(126747,'printshop-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(126748,'printshop-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(126749,'printshop-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(126750,'printshop-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(126751,'printshop-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(126752,'printshop-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(126753,'printshop-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(126754,'printshop-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(126755,'printshop-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(126756,'printshop-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(126757,'printshop-mobile','.w-wedding-registry-widgets-products .rating','float','none','','','.w-wedding-registry-widgets-products'),(126758,'printshop-mobile','.w-wedding-registry-widgets-products .price','float','left','','','.w-wedding-registry-widgets-products'),(126759,'printshop-mobile','.w-wedding-registry-widgets-products .qty-input','float','right','','','.w-wedding-registry-widgets-products'),(126760,'printshop-mobile','.w-wedding-registry-widgets-search-form .button','float','right','','','.w-wedding-registry-widgets-search-form'),(126761,'printshop-mobile','.p-wedding-registry-manage .qty-input','float_important','important','','','.p-wedding-registry-manage'),(126762,'printshop-mobile','.b-slick .slick-slide','float_important','important','','','.b-slick'),(126763,'printshop-mobile','.w-blog-widget-post-share ','float_important','important','','','.w-blog-widget-post-share'),(126764,'printshop-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','font-family','FontAwesome','3','','.w-menu'),(126765,'printshop-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','font-family','FontAwesome','3','','.w-menu'),(126766,'printshop-mobile','.w-menu .menu .menu-ico','font-family','\'trueloaded\'','3','','.w-menu'),(126767,'printshop-mobile','.w-menu-slider .close','font-family','FontAwesome','3','','.w-menu-slider'),(126768,'printshop-mobile','.w-bestsellers .item','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-bestsellers'),(126769,'printshop-mobile','.b-social-login .social-login-text-1','font-family','\'Varela Round\'','','','.b-social-login'),(126770,'printshop-mobile','.w-bestsellers .heading-3','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-bestsellers'),(126771,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','font-family','FontAwesome','3','','.b-slick'),(126772,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(126773,'printshop-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','','','.b-form'),(126774,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','','','.b-form'),(126775,'printshop-mobile','.w-html_box .socials','font-family','FontAwesome','','','.w-html_box'),(126776,'printshop-mobile','.w-product-wedding-registry-button .btn','font-family','Hind','','','.w-product-wedding-registry-button'),(126777,'printshop-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-cart-gift-certificate'),(126778,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','font-family','\'trueloaded\'','3','','.p-account-history-info'),(126779,'printshop-mobile','.w-categories .name','font-family','\'Varela Round\', sans-serif','','','.w-categories'),(126780,'printshop-mobile','.heading-3 .edit, h3 .edit','font-family','\'Hind\', Verdana, Arial, sans-serif','','',''),(126781,'printshop-mobile','.w-catalog-listing-look .list','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-catalog-listing-look'),(126782,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-family','\'trueloaded\'','4','','.b-multi-page-checkout'),(126783,'printshop-mobile','.b-pagination .pagination .next','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.b-pagination'),(126784,'printshop-mobile','.b-pagination .pagination .prev','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.b-pagination'),(126785,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-family','FontAwesome','3','','.b-multi-page-checkout'),(126786,'printshop-mobile','.p-blog-index .nav-previous a','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.p-blog-index'),(126787,'printshop-mobile','.p-blog-index .wp-widget li','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.p-blog-index'),(126788,'printshop-mobile','.p-blog-index .post-title','font-family','\'Varela Round\'','','','.p-blog-index'),(126789,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-family','\'Varela Round\'','','','.b-multi-page-checkout'),(126790,'printshop-mobile','.w-list-type-2 .button-view a','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-2'),(126791,'printshop-mobile','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(126792,'printshop-mobile','.p-wedding-registry-manage .remove-btn','font-family','trueloaded','3','','.p-wedding-registry-manage'),(126793,'printshop-mobile','.p-wedding-registry-view h1','font-family','FontAwesome','4','','.p-wedding-registry-view'),(126794,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','font-family','\'trueloaded\'','3','','.p-account-order-pay'),(126795,'printshop-mobile','.js-stock-icon','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','',''),(126796,'printshop-mobile','.testimonials .heading-3','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','',''),(126797,'printshop-mobile','.p-wedding-registry-manage .wr-search button','font-family','trueloaded','3','','.p-wedding-registry-manage'),(126798,'printshop-mobile','.p-account-history .orders-table th','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.p-account-history'),(126799,'printshop-mobile','.p-account-history .view_link','font-family','\'trueloaded\',sans-serif','4','','.p-account-history'),(126800,'printshop-mobile','.p-account-index .orders-table th','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.p-account-index'),(126801,'printshop-mobile','.p-blog-index .nav-next a','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.p-blog-index'),(126802,'printshop-mobile','.p-blog-index .author','font-family','\'Varela Round\'','','','.p-blog-index'),(126803,'printshop-mobile','.no-found','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','',''),(126804,'printshop-mobile','.w-list-type-2_2 .price','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-list-type-2_2'),(126805,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-2_2'),(126806,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','font-family','\'Hind\', Verdana, Arial, sans-serif','','','.w-list-type-2_2'),(126807,'printshop-mobile','.w-list-type-2_2 .button-view a','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-2_2'),(126808,'printshop-mobile','.w-list-type-2 .sale','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-2'),(126809,'printshop-mobile','.w-list-type-2 .price','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-list-type-2'),(126810,'printshop-mobile','.price','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','',''),(126811,'printshop-mobile','.w-product-personal-catalog-button .btn','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-product-personal-catalog-button'),(126812,'printshop-mobile','.w-product-wishlist-button .btn','font-family','Hind','','','.w-product-wishlist-button'),(126813,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-2_2'),(126814,'printshop-mobile','.w-product-bonus-points > div > div','font-family','FontAwesome','3','','.w-product-bonus-points'),(126815,'printshop-mobile','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(126816,'printshop-mobile','.w-product-personal-catalog-button .btn','font-family','\'Hind\', Verdana, Arial, sans-serif','','','.w-product-personal-catalog-button'),(126817,'printshop-mobile','.w-chat .w-chat-box a','font-family','FontAwesome','3','','.w-chat'),(126818,'printshop-mobile','.w-delivery-location-location-list .deliveryListParrent','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-delivery-location-location-list'),(126819,'printshop-mobile','.w-product-promotions .promotion-full-price-discount','font-family','Varela Round','','','.w-product-promotions'),(126820,'printshop-mobile','.p-wedding-registry-index .main-button','font-family','FontAwesome','3','','.p-wedding-registry-index'),(126821,'printshop-mobile','.p-wedding-registry-index .main-button','font-family','FontAwesome','4','','.p-wedding-registry-index'),(126822,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','font-family','FontAwesome','3','','.b-form'),(126823,'printshop-mobile','.p-wedding-registry-index .search-list label','font-family','Varela Round','','','.p-wedding-registry-index'),(126824,'printshop-mobile','.p-wedding-registry-manage .links a.share-registry','font-family','FontAwesome','4','','.p-wedding-registry-manage'),(126825,'printshop-mobile','.p-wedding-registry-search h1','font-family','FontAwesome','3','','.p-wedding-registry-search'),(126826,'printshop-mobile','.p-wedding-registry-search h1','font-family','FontAwesome','4','','.p-wedding-registry-search'),(126827,'printshop-mobile','.p-wedding-registry-share h1','font-family','FontAwesome','3','','.p-wedding-registry-share'),(126828,'printshop-mobile','.p-wedding-registry-manage h1','font-family','FontAwesome','3','','.p-wedding-registry-manage'),(126829,'printshop-mobile','.p-account-address-book .btn-edit','font-family','\'trueloaded\'','4','','.p-account-address-book'),(126830,'printshop-mobile','.b-compare .clear_all','font-family','\'FontAwesome\'','4','','.b-compare'),(126831,'printshop-mobile','.w-account .my-acc-link','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-account'),(126832,'printshop-mobile','.w-tabs .accordion-heading','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-tabs'),(126833,'printshop-mobile','.b-bottom .footerTitle','font-family','FontAwesome','693,4','','.b-bottom'),(126834,'printshop-mobile','.w-filters .head-filter-widget','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-filters'),(126835,'printshop-mobile','.heading-4 .right-text, h4 .right-text','font-family','\'Hind\', Verdana, Arial, sans-serif','','',''),(126836,'printshop-mobile','.w-list-type-1 .button-view a','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-1'),(126837,'printshop-mobile','.w-search .button-search','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-search'),(126838,'printshop-mobile','.w-tabs .tab-a','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-tabs'),(126839,'printshop-mobile','.w-socials .post_item > div','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-socials'),(126840,'printshop-mobile','.w-search .search','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-search'),(126841,'printshop-mobile','.w-list-type-1_3 .price','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-list-type-1_3'),(126842,'printshop-mobile','body','font-family','\'Hind\', Verdana, Arial, sans-serif','','',''),(126843,'printshop-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','','','.w-filters'),(126844,'printshop-mobile','.w-filters .filter-box-head','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-filters'),(126845,'printshop-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','\'trueloaded\'','3','','.w-contact-contacts'),(126846,'printshop-mobile','.w-currencies .current','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-currencies'),(126847,'printshop-mobile','.w-compare-box-item .checkbox:checked + span:before','font-family','\'FontAwesome\'','','','.w-compare-box-item'),(126848,'printshop-mobile','.b-info-popup .info-popup','font-family','\'trueloaded\'','3','','.b-info-popup'),(126849,'printshop-mobile','.p-account-index .view_link','font-family','\'trueloaded\',sans-serif','4','','.p-account-index'),(126850,'printshop-mobile','.p-account-index .view_history','font-family','\'trueloaded\'','3','','.p-account-index'),(126851,'printshop-mobile','.p-checkout-success .page-success','font-family','\'trueloaded\'','3','','.p-checkout-success'),(126852,'printshop-mobile','.w-menu-mobile .menu-ico','font-family','\'trueloaded\'','3','','.w-menu-mobile'),(126853,'printshop-mobile','.p-checkout-success .page-success .text-1','font-family','\'trueloaded\'','3','','.p-checkout-success'),(126854,'printshop-mobile','.b-fancybox .fancybox-nav span','font-family','trueloaded','','','.b-fancybox'),(126855,'printshop-mobile','.heading-2, h2','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','',''),(126856,'printshop-mobile','.p-checkout-success .page-success .text-1, .p-checkout-success .page-success .text-2, .p-checkout-success .page-success .text-3','font-family','\'Varela Round\', sans-serif','','','.p-checkout-success'),(126857,'printshop-mobile','.p-wedding-registry-share .invite-remove','font-family','trueloaded','3','','.p-wedding-registry-share'),(126858,'printshop-mobile','.w-text .customer-service b','font-family','\'Varela Round\'','','','.w-text'),(126859,'printshop-mobile','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(126860,'printshop-mobile','.w-categories .categories h2','font-family','inherit','','','.w-categories'),(126861,'printshop-mobile','.w-top-categories .categories h2','font-family','inherit','','','.w-top-categories'),(126862,'printshop-mobile','.b-rating .glyphicon','font-family','FontAwesome','','','.b-rating'),(126863,'printshop-mobile','.b-rating #stars-default .glyphicon','font-family','\'trueloaded\'','','','.b-rating'),(126864,'printshop-mobile','.w-cart .cart-box-link','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-cart'),(126865,'printshop-mobile','.b-fancybox .fancybox-close','font-family','FontAwesome','3','','.b-fancybox'),(126866,'printshop-mobile','.btn-3','font-family','Varela Round','','',''),(126867,'printshop-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-cart-discount-coupon'),(126868,'printshop-mobile','.btn','font-family','Varela Round','','',''),(126869,'printshop-mobile','.w-top-categories .name','font-family','\'Varela Round\', sans-serif','','','.w-top-categories'),(126870,'printshop-mobile','.p-account-index .date_value strong','font-family','\'Hind\', sans-serif','','','.p-account-index'),(126871,'printshop-mobile','.heading-4, h4','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','',''),(126872,'printshop-mobile','h1','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','',''),(126873,'printshop-mobile','.w-catalog-listing-look .b2b','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-catalog-listing-look'),(126874,'printshop-mobile','.heading-3, h3','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','',''),(126875,'printshop-mobile','.p-account-index .account_page h4','font-family','\'trueloaded\'','3','','.p-account-index'),(126876,'printshop-mobile','.p-account-index .date_value, .p-account-index .date_title','font-family','\'Varela Round\', sans-serif','','','.p-account-index'),(126877,'printshop-mobile','.w-list-type-2_2 .sale','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-2_2'),(126878,'printshop-mobile','.p-account-index .topAccount > li > div','font-family','\'trueloaded\'','3','','.p-account-index'),(126879,'printshop-mobile','.w-cart-give-away .ga_qty','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-cart-give-away'),(126880,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-2'),(126881,'printshop-mobile','.w-list-type-2 .button-wishlist button','font-family','\'Hind\', Verdana, Arial, sans-serif','','','.w-list-type-2'),(126882,'printshop-mobile','.w-list-type-1_3 .sale','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-1_3'),(126883,'printshop-mobile','.w-list-type-2 .button-wishlist button','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-2'),(126884,'printshop-mobile','.w-catalog-listing-look .grid','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-catalog-listing-look'),(126885,'printshop-mobile','.view-all .btn','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','4','',''),(126886,'printshop-mobile','.p-wedding-registry-share h1','font-family','FontAwesome','4','','.p-wedding-registry-share'),(126887,'printshop-mobile','.p-wedding-registry-manage h1','font-family','FontAwesome','4','','.p-wedding-registry-manage'),(126888,'printshop-mobile','.btn-2','font-family','Varela Round','','',''),(126889,'printshop-mobile','.p-wedding-registry-view h1','font-family','FontAwesome','3','','.p-wedding-registry-view'),(126890,'printshop-mobile','.btn-1','font-family','Varela Round','','',''),(126891,'printshop-mobile','.heading-3 .edit, h3 .edit','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','',''),(126892,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-1_3'),(126893,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','font-family','\'Hind\', Verdana, Arial, sans-serif','','','.w-list-type-1_3'),(126894,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-1_3'),(126895,'printshop-mobile','.w-list-type-1_3 .button-view a','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-1_3'),(126896,'printshop-mobile','.w-list-type-1_2 .sale','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-1_2'),(126897,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-1_2'),(126898,'printshop-mobile','.w-list-type-1_2 .price','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-list-type-1_2'),(126899,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','font-family','\'Hind\', Verdana, Arial, sans-serif','','','.w-list-type-1_2'),(126900,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-1_2'),(126901,'printshop-mobile','.b-bottom .pop-up-close','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.b-bottom'),(126902,'printshop-mobile','.w-list-type-1 .sale','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-1'),(126903,'printshop-mobile','.w-list-type-1_2 .button-view a','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-1_2'),(126904,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-1'),(126905,'printshop-mobile','.w-filters .mobileCollapse','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','4','','.w-filters'),(126906,'printshop-mobile','.w-list-type-1 .button-wishlist button','font-family','\'Hind\', Verdana, Arial, sans-serif','','','.w-list-type-1'),(126907,'printshop-mobile','.transit-icon','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','',''),(126908,'printshop-mobile','.w-list-type-1 .button-wishlist button','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-1'),(126909,'printshop-mobile','.in-stock-icon','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','',''),(126910,'printshop-mobile','.w-filters .open','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-filters'),(126911,'printshop-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','','','.w-filters'),(126912,'printshop-mobile','.heading-4 .edit, h4 .edit','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','',''),(126913,'printshop-mobile','.heading-4 .edit, h4 .edit','font-family','\'Hind\', Verdana, Arial, sans-serif','','',''),(126914,'printshop-mobile','.w-filters span.close','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-filters'),(126915,'printshop-mobile','.w-filters .view_more','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','4','','.w-filters'),(126916,'printshop-mobile','.out-stock-icon','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','',''),(126917,'printshop-mobile','.w-languages .current','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-languages'),(126918,'printshop-mobile','.w-reviews .heading-3','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-reviews'),(126919,'printshop-mobile','.w-quote .cart-box-link','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-quote'),(126920,'printshop-mobile','.btn-del','font-family','\'FontAwesome\'','4','',''),(126921,'printshop-mobile','.p-account-address-book .leftMes div','font-family','\'Varela Round\', sans-serif','','','.p-account-address-book'),(126922,'printshop-mobile','.b-info .info','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.b-info'),(126923,'printshop-mobile','.b-info .info strong','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.b-info'),(126924,'printshop-mobile','.b-products-listing .btn-preloader','font-family','FontAwesome','3','','.b-products-listing'),(126925,'printshop-mobile','.b-products-listing .loader','font-family','FontAwesome','4','','.b-products-listing'),(126926,'printshop-mobile','.b-products-listing .products-listing .bonus-points-cost','font-family','FontAwesome','3','','.b-products-listing'),(126927,'printshop-mobile','.b-products-listing .products-listing .bonus-points-price','font-family','FontAwesome','3','','.b-products-listing'),(126928,'printshop-mobile','.b-products-listing .products-listing .btn-buy','font-family','trueloaded','3','','.b-products-listing'),(126929,'printshop-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-family','FontAwesome','','','.b-products-listing'),(126930,'printshop-mobile','.b-products-listing .products-listing a.btn.view-button','font-family','trueloaded','3','','.b-products-listing'),(126931,'printshop-mobile','.b-products-listing .products-listing h2','font-family','inherit','','','.b-products-listing'),(126932,'printshop-mobile','.b-data-table table.dataTable thead td','font-family','Varela Round','','','.b-data-table'),(126933,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(126934,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(126935,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(126936,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(126937,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(126938,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(126939,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-family','inherit','','','.b-h-inline'),(126940,'printshop-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','font-family','FontAwesome','3','','.b-menu-burger_icon'),(126941,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','font-family','FontAwesome','4','','.b-menu-style-1'),(126942,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > .no-link','font-family','FontAwesome','4','','.b-menu-style-1'),(126943,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','font-family','FontAwesome','4','','.b-menu-style-1'),(126944,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','font-family','FontAwesome','3','','.b-menu-style-2'),(126945,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','font-family','FontAwesome','3','','.b-menu-style-2'),(126946,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-family','FontAwesome','3','','.b-menu-style-2'),(126947,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > .no-link','font-family','FontAwesome','4','','.b-menu-style-3'),(126948,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > .no-link','font-family','FontAwesome','3','','.b-menu-style-3'),(126949,'printshop-mobile','.b-messages .select2-search-choice-close','font-family','trueloaded','3','','.b-messages'),(126950,'printshop-mobile','.b-messages .messBtnMenuUnread','font-family','FontAwesome','3','','.b-messages'),(126951,'printshop-mobile','.b-messages .messBtnMenuDelete','font-family','trueloaded','3','','.b-messages'),(126952,'printshop-mobile','.b-messages span.starred::before','font-family','trueloaded','','','.b-messages'),(126953,'printshop-mobile','.b-messages .messBtnMenuStarred','font-family','trueloaded','3','','.b-messages'),(126954,'printshop-mobile','.b-messages .content_management_attach span','font-family','Hind','','','.b-messages'),(126955,'printshop-mobile','.b-preloader .preloader','font-family','FontAwesome','3','','.b-preloader'),(126956,'printshop-mobile','.b-select-suggest .select2-search input','font-family','Hind','','','.b-select-suggest'),(126957,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-family','Hind','','','.b-select-suggest'),(126958,'printshop-mobile','.b-table-list .table-list th','font-family','Varela Round','','','.b-table-list'),(126959,'printshop-mobile','.b-table-list .table-list th','font-family','Varela Round','','','.b-table-list'),(126960,'printshop-mobile','.b-table-list .table-list th','font-family','Varela Round','','','.b-table-list'),(126961,'printshop-mobile','.b-table-list .table-list th','font-family','Varela Round','','','.b-table-list'),(126962,'printshop-mobile','.b-table-list .table-list th','font-family','Varela Round','','','.b-table-list'),(126963,'printshop-mobile','.b-table-list .table-list th','font-family','Varela Round','','','.b-table-list'),(126964,'printshop-mobile','.b-upload-file .snapshot','font-family','FontAwesome','3','','.b-upload-file'),(126965,'printshop-mobile','.b-upload-file .upload-file-wrap .upload-remove','font-family','trueloaded','3','','.b-upload-file'),(126966,'printshop-mobile','.b-upload-files .remove-file','font-family','FontAwesome','3','','.b-upload-files'),(126967,'printshop-mobile','.b-warehouses-popup .warehouses-popup-link','font-family','FontAwesome','3','','.b-warehouses-popup'),(126968,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','font-family','FontAwesome','3','','.b-warehouses-popup'),(126969,'printshop-mobile','.batchPr .checkbox input:checked + span:before','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','','','.batchPr'),(126970,'printshop-mobile','.bell-ico .heading-2','font-family','trueloaded','3','','.bell-ico'),(126971,'printshop-mobile','.heading-ordered-items .heading-4','font-family','trueloaded','3','','.heading-ordered-items'),(126972,'printshop-mobile','.heading-saved-lists .heading-4','font-family','trueloaded','3','','.heading-saved-lists'),(126973,'printshop-mobile','.heading-settings .heading-4','font-family','trueloaded','3','','.heading-settings'),(126974,'printshop-mobile','.p-account-samples-history .orders-table th','font-family','Varela Round','','','.p-account-samples-history'),(126975,'printshop-mobile','.p-account-samples-history .view_link','font-family','trueloaded','4','','.p-account-samples-history'),(126976,'printshop-mobile','.p-account-samples-history .view_link','font-family','trueloaded','4','','.p-account-samples-history'),(126977,'printshop-mobile','.p-account-samples-history .orders-table th','font-family','Varela Round','','','.p-account-samples-history'),(126978,'printshop-mobile','.p-account-samples-history .orders-table th','font-family','Varela Round','','','.p-account-samples-history'),(126979,'printshop-mobile','.p-account-samples-history .orders-table th','font-family','Varela Round','','','.p-account-samples-history'),(126980,'printshop-mobile','.p-account-samples-history .orders-table th','font-family','Varela Round','','','.p-account-samples-history'),(126981,'printshop-mobile','.p-account-samples-history .view_link','font-family','trueloaded','4','','.p-account-samples-history'),(126982,'printshop-mobile','.p-account-samples-history .view_link','font-family','trueloaded','4','','.p-account-samples-history'),(126983,'printshop-mobile','.p-account-samples-history .view_link','font-family','trueloaded','4','','.p-account-samples-history'),(126984,'printshop-mobile','.p-account-samples-history .view_link','font-family','trueloaded','4','','.p-account-samples-history'),(126985,'printshop-mobile','.p-account-samples-history .orders-table th','font-family','Varela Round','','','.p-account-samples-history'),(126986,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-family','trueloaded','3','','.p-account-samples-history-info'),(126987,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-family','trueloaded','3','','.p-account-samples-history-info'),(126988,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-family','trueloaded','3','','.p-account-samples-history-info'),(126989,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-family','trueloaded','3','','.p-account-samples-history-info'),(126990,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-family','trueloaded','3','','.p-account-samples-history-info'),(126991,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-family','trueloaded','3','','.p-account-samples-history-info'),(126992,'printshop-mobile','.p-catalog-product .pn-direction','font-family','Varela Round','','','.p-catalog-product'),(126993,'printshop-mobile','.p-catalog-product .pn-image','font-family','FontAwesome','3','','.p-catalog-product'),(126994,'printshop-mobile','.p-payer-order-confirmation .discount-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(126995,'printshop-mobile','.p-payer-order-confirmation .ship-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(126996,'printshop-mobile','.p-payer-order-confirmation .comment-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(126997,'printshop-mobile','.p-payer-order-confirmation .order-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(126998,'printshop-mobile','.p-payer-order-confirmation .pay-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(126999,'printshop-mobile','.p-payer-order-pay .order-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(127000,'printshop-mobile','.p-payer-order-pay .pay-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(127001,'printshop-mobile','.p-payer-order-pay .comment-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(127002,'printshop-mobile','.p-payer-order-pay .discount-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(127003,'printshop-mobile','.p-payer-order-pay .ship-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(127004,'printshop-mobile','.p-quick-order-index .paginate_button.next','font-family','FontAwesome','3','','.p-quick-order-index'),(127005,'printshop-mobile','.p-quick-order-index .paginate_button.previous','font-family','FontAwesome','3','','.p-quick-order-index'),(127006,'printshop-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-quote-checkout-success'),(127007,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(127008,'printshop-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-quote-checkout-success'),(127009,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(127010,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(127011,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(127012,'printshop-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-quote-checkout-success'),(127013,'printshop-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-quote-checkout-success'),(127014,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(127015,'printshop-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-quote-checkout-success'),(127016,'printshop-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-quote-checkout-success'),(127017,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(127018,'printshop-mobile','.p-sample-checkout-success .page-success .text-1, .p-sample-checkout-success .page-success .text-2, .p-sample-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-sample-checkout-success'),(127019,'printshop-mobile','.p-sample-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-sample-checkout-success'),(127020,'printshop-mobile','.savings-ico .heading-2','font-family','trueloaded','3','','.savings-ico'),(127021,'printshop-mobile','.shipping-ico .heading-2','font-family','trueloaded','3','','.shipping-ico'),(127022,'printshop-mobile','.shipping-ico .heading-2','font-family','trueloaded','3','','.shipping-ico'),(127023,'printshop-mobile','.shipping-ico .heading-2','font-family','trueloaded','3','','.shipping-ico'),(127024,'printshop-mobile','.w-account-address-book .add_item a','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-account-address-book'),(127025,'printshop-mobile','.w-account-personal-catalog .list-switcher a','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-account-personal-catalog'),(127026,'printshop-mobile','.w-blog-widget-post-listing .post_name','font-family','Varela Round','','','.w-blog-widget-post-listing'),(127027,'printshop-mobile','.w-blog-widget-post-share .pinterest-btn','font-family','FontAwesome','3','','.w-blog-widget-post-share'),(127028,'printshop-mobile','.w-blog-widget-post-share .facebook-btn','font-family','FontAwesome','3','','.w-blog-widget-post-share'),(127029,'printshop-mobile','.w-blog-widget-post-share .twitter-btn','font-family','FontAwesome','3','','.w-blog-widget-post-share'),(127030,'printshop-mobile','.w-cart-bonus-points .title','font-family','FontAwesome','3','','.w-cart-bonus-points'),(127031,'printshop-mobile','.w-cart-bonus-points .btn-remove','font-family','trueloaded','3','','.w-cart-bonus-points'),(127032,'printshop-mobile','.w-cart-compare .price-cell','font-family','Varela Round','','','.w-cart-compare'),(127033,'printshop-mobile','.w-cart-compare .cart-name a','font-family','Varela Round','','','.w-cart-compare'),(127034,'printshop-mobile','.w-cart-compare .atr-col','font-family','FontAwesome','3','','.w-cart-compare'),(127035,'printshop-mobile','.w-cart-compare .product-actions .dropdown-toggle','font-family','FontAwesome','3','','.w-cart-compare'),(127036,'printshop-mobile','.w-cart-credit-amount .amount-title','font-family','trueloaded','3','','.w-cart-credit-amount'),(127037,'printshop-mobile','.w-cart-credit-amount .btn-remove','font-family','trueloaded','3','','.w-cart-credit-amount'),(127038,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-catalog-compare'),(127039,'printshop-mobile','.w-catalog-paging .next','font-family','FontAwesome','3','','.w-catalog-paging'),(127040,'printshop-mobile','.w-catalog-paging .prev','font-family','FontAwesome','3','','.w-catalog-paging'),(127041,'printshop-mobile','.w-checkout-bonus-points .btn-remove','font-family','trueloaded','3','','.w-checkout-bonus-points'),(127042,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','font-family','FontAwesome','3','','.w-checkout-contact-information'),(127043,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','font-family','FontAwesome','3','','.w-checkout-contact-information'),(127044,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','font-family','FontAwesome','3','','.w-checkout-contact-information'),(127045,'printshop-mobile','.w-checkout-create-account .account-benefits strong','font-family','trueloaded','3','','.w-checkout-create-account'),(127046,'printshop-mobile','.w-checkout-credit-amount .btn-remove','font-family','trueloaded','3','','.w-checkout-credit-amount'),(127047,'printshop-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-communication-new-topic'),(127048,'printshop-mobile','.w-coupons-and-vauchers-checkout .btn-remove','font-family','trueloaded','3','','.w-coupons-and-vauchers-checkout'),(127049,'printshop-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','font-family','FontAwesome','3','','.w-multi-cart-actions'),(127050,'printshop-mobile','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-family','Varela Round','','','.w-multi-cart-cart-switcher'),(127051,'printshop-mobile','.w-product-cross-sell .buy-all-checker','font-family','FontAwesome','3','','.w-product-cross-sell'),(127052,'printshop-mobile','.w-promotions .nextdiscount .heading','font-family','FontAwesome','3','','.w-promotions'),(127053,'printshop-mobile','.w-social-links a','font-family','FontAwesome','','','.w-social-links'),(127054,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-family','FontAwesome','3','','.w-upload-customer-id-upload-customer-id-form'),(127055,'printshop-mobile','.w-wedding-registry-widgets-manage-names .names-separator','font-family','FontAwesome','3','','.w-wedding-registry-widgets-manage-names'),(127056,'printshop-mobile','.w-wedding-registry-widgets-products .remove-btn','font-family','trueloaded','3','','.w-wedding-registry-widgets-products'),(127057,'printshop-mobile','.w-wedding-registry-widgets-search-registry-button a','font-family','FontAwesome','3','','.w-wedding-registry-widgets-search-registry-button'),(127058,'printshop-mobile','.w-wedding-registry-widgets-share-link a','font-family','FontAwesome','3','','.w-wedding-registry-widgets-share-link'),(127059,'printshop-mobile','.b-rating .glyphicon','font-family_important','important','','','.b-rating'),(127060,'printshop-mobile','.b-rating #stars-default .glyphicon','font-family_important','important','','','.b-rating'),(127061,'printshop-mobile','.w-bestsellers .item','font-size','32','3','','.w-bestsellers'),(127062,'printshop-mobile','.w-bestsellers .heading-3','font-size','50','3','','.w-bestsellers'),(127063,'printshop-mobile','.w-account .my-acc-link','font-size','30','3','','.w-account'),(127064,'printshop-mobile','.b-switch .bootstrap-switch','font-size','16','','','.b-switch'),(127065,'printshop-mobile','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(127066,'printshop-mobile','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(127067,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','20','3','','.b-slick'),(127068,'printshop-mobile','.w-list-type-1 .rating-count','font-size','14','','','.w-list-type-1'),(127069,'printshop-mobile','.w-tabs .accordion-heading','font-size','20','','','.w-tabs'),(127070,'printshop-mobile','.w-list-type-1 .price','font-size','20','','','.w-list-type-1'),(127071,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(127072,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-size','18','','','.b-form'),(127073,'printshop-mobile','.w-product-sale-ends .ends','font-size','26','','','.w-product-sale-ends'),(127074,'printshop-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','font-size','18','','','.b-form'),(127075,'printshop-mobile','.w-sale .left-count-days','font-size','40','','','.w-sale'),(127076,'printshop-mobile','.w-sale .left-count-hours','font-size','40','','','.w-sale'),(127077,'printshop-mobile','.w-menu-slider .menu-ico','font-size','23','','','.w-menu-slider'),(127078,'printshop-mobile','.w-menu-horizontal .menu-ico','font-size','23','','','.w-menu-horizontal'),(127079,'printshop-mobile','.w-sale .name','font-size','20','','','.w-sale'),(127080,'printshop-mobile','.w-list-type-2_2 .title','font-size','16','','','.w-list-type-2_2'),(127081,'printshop-mobile','.w-sale .percents','font-size','30','','','.w-sale'),(127082,'printshop-mobile','.w-sale .badge','font-size','20','','','.w-sale'),(127083,'printshop-mobile','.w-html_box .socials a','font-size','26','','','.w-html_box'),(127084,'printshop-mobile','.w-menu-style-1 .menu-ico','font-size','23','','','.w-menu-style-1'),(127085,'printshop-mobile','.w-menu-style-1 > ul','font-size','16','','','.w-menu-style-1'),(127086,'printshop-mobile','.w-product-sale-ends .left-count-hours','font-size','40','','','.w-product-sale-ends'),(127087,'printshop-mobile','.w-product-sale-ends .left-count-days','font-size','40','','','.w-product-sale-ends'),(127088,'printshop-mobile','.w-product-sale-ends .left-text-right','font-size','24','','','.w-product-sale-ends'),(127089,'printshop-mobile','.w-product-sale-ends .left-text-left','font-size','24','','','.w-product-sale-ends'),(127090,'printshop-mobile','.w-cart .cart-box-link','font-size','30','3','','.w-cart'),(127091,'printshop-mobile','.p-account-index .date_title','font-size','14','','','.p-account-index'),(127092,'printshop-mobile','.w-product-collection .right-area .special','font-size','30','','','.w-product-collection'),(127093,'printshop-mobile','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(127094,'printshop-mobile','.w-product-personal-catalog-button .btn','font-size','14','','','.w-product-personal-catalog-button'),(127095,'printshop-mobile','.w-html_box .socials a','font-size','30','693','','.w-html_box'),(127096,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','font-size','18','','','.p-account-history-info'),(127097,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','font-size','22','3','','.p-account-history-info'),(127098,'printshop-mobile','.p-account-history-info .not_fully_paid_td','font-size','30','','','.p-account-history-info'),(127099,'printshop-mobile','.p-account-index .not_fully_paid_td','font-size','30','','','.p-account-index'),(127100,'printshop-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','font-size','16','','','.p-account-index'),(127101,'printshop-mobile','.p-account-trade-form .address-wrapp','font-size','14','','','.p-account-trade-form'),(127102,'printshop-mobile','.w-compare-box-item .cb_title','font-size','16','','','.w-compare-box-item'),(127103,'printshop-mobile','.w-categories .name','font-size','18','','','.w-categories'),(127104,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-size','0.7','4','','.b-multi-page-checkout'),(127105,'printshop-mobile','.w-cart-give-away .ga_qty','font-size','17','693','','.w-cart-give-away'),(127106,'printshop-mobile','.b-price-box .price-box .price-row.total','font-size','24','','','.b-price-box'),(127107,'printshop-mobile','.b-price-box .price-box','font-size','18','','','.b-price-box'),(127108,'printshop-mobile','.w-cart-checkout-btn a','font-size','17','693','','.w-cart-checkout-btn'),(127109,'printshop-mobile','.w-product-reviews .reviews-list .date','font-size','14','','','.w-product-reviews'),(127110,'printshop-mobile','.w-product-reviews .reviews-list span','font-size','22','','','.w-product-reviews'),(127111,'printshop-mobile','.w-reviews .date','font-size','14','','','.w-reviews'),(127112,'printshop-mobile','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(127113,'printshop-mobile','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(127114,'printshop-mobile','.w-product-properties li','font-size','14','','','.w-product-properties'),(127115,'printshop-mobile','.w-product-in-bundles .product-link','font-size','16','','','.w-product-in-bundles'),(127116,'printshop-mobile','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(127117,'printshop-mobile','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(127118,'printshop-mobile','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(127119,'printshop-mobile','.price .old','font-size','0.8','','',''),(127120,'printshop-mobile','.p-checkout-success .page-success .text-1','font-size','40','693','','.p-checkout-success'),(127121,'printshop-mobile','.p-checkout-success .page-success .text-2','font-size','30','693','','.p-checkout-success'),(127122,'printshop-mobile','.p-blog-index .post-title','font-size','20','','','.p-blog-index'),(127123,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','font-size','14','','','.p-blog-index'),(127124,'printshop-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','font-size','16','','','.p-account-history'),(127125,'printshop-mobile','.p-blog-index .wp-widget li','font-size','8','3','','.p-blog-index'),(127126,'printshop-mobile','.w-filters .head-filter-widget','font-size','21','701','','.w-filters'),(127127,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-size','24','','','.b-multi-page-checkout'),(127128,'printshop-mobile','.b-info-popup .info-popup div','font-size','14','','','.b-info-popup'),(127129,'printshop-mobile','.w-promo-code .holder','font-size','30','723,3','','.w-promo-code'),(127130,'printshop-mobile','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(127131,'printshop-mobile','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(127132,'printshop-mobile','.p-wedding-registry-manage a.remove-btn','font-size','22','','','.p-wedding-registry-manage'),(127133,'printshop-mobile','.p-account-history-info .popup-tracking-number-link','font-size','18','','','.p-account-history-info'),(127134,'printshop-mobile','.w-product-bonus-points > div','font-size','14','','','.w-product-bonus-points'),(127135,'printshop-mobile','.p-account-history-info .trackings-nambers-label','font-size','20','','','.p-account-history-info'),(127136,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','font-size','18','','','.p-account-order-pay'),(127137,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','font-size','22','3','','.p-account-order-pay'),(127138,'printshop-mobile','.p-account-order-pay .history_attr','font-size','14','','','.p-account-order-pay'),(127139,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-order-pay'),(127140,'printshop-mobile','.p-account-order-pay .historyTotal table tr:last-child td','font-size','24','','','.p-account-order-pay'),(127141,'printshop-mobile','.p-account-order-pay .historyTotal table td','font-size','18','','','.p-account-order-pay'),(127142,'printshop-mobile','.testimonials .date','font-size','14','','',''),(127143,'printshop-mobile','.p-account-order-pay .not_fully_paid_td','font-size','30','','','.p-account-order-pay'),(127144,'printshop-mobile','.testimonials .heading-3','font-size','37','3','',''),(127145,'printshop-mobile','.js-stock','font-size','14','','',''),(127146,'printshop-mobile','.testimonials .rating','font-size','22','','',''),(127147,'printshop-mobile','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(127148,'printshop-mobile','.testimonials .reviews-list span','font-size','22','','',''),(127149,'printshop-mobile','.testimonials .reviews-list .date','font-size','14','','',''),(127150,'printshop-mobile','.b-bottom .confirm-popup .confirm-text','font-size','20','','','.b-bottom'),(127151,'printshop-mobile','.b-pagination .pagination .prev','font-size','20','3','','.b-pagination'),(127152,'printshop-mobile','.p-wedding-registry-manage .wr-search button','font-size','23','3','','.p-wedding-registry-manage'),(127153,'printshop-mobile','.b-pagination .pagination .next','font-size','20','3','','.b-pagination'),(127154,'printshop-mobile','.p-account-history .view_link','font-size','18','4','','.p-account-history'),(127155,'printshop-mobile','.p-blog-index .nav-previous a','font-size','40','3','','.p-blog-index'),(127156,'printshop-mobile','.p-blog-index .nav-next a','font-size','40','3','','.p-blog-index'),(127157,'printshop-mobile','.p-blog-index .comment-metadata','font-size','14','','','.p-blog-index'),(127158,'printshop-mobile','.p-blog-index .author','font-size','20','','','.p-blog-index'),(127159,'printshop-mobile','.no-found','font-size','1.4','','',''),(127160,'printshop-mobile','.w-list-type-2_2 .sale','font-size','19','3','','.w-list-type-2_2'),(127161,'printshop-mobile','.w-list-type-2_2 .price .old','font-size','18','','','.w-list-type-2_2'),(127162,'printshop-mobile','.w-list-type-2_2 .properties','font-size','13','','','.w-list-type-2_2'),(127163,'printshop-mobile','.w-list-type-2_2 .price','font-size','24','','','.w-list-type-2_2'),(127164,'printshop-mobile','.w-list-type-2_2 .products-model','font-size','13','','','.w-list-type-2_2'),(127165,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','font-size','28','3','','.w-list-type-2_2'),(127166,'printshop-mobile','.w-list-type-2 .title','font-size','16','','','.w-list-type-2'),(127167,'printshop-mobile','.w-list-type-2_2 .button-view a','font-size','16','','','.w-list-type-2_2'),(127168,'printshop-mobile','.w-list-type-2 .price .old','font-size','18','','','.w-list-type-2'),(127169,'printshop-mobile','.w-list-type-2 .products-model','font-size','13','','','.w-list-type-2'),(127170,'printshop-mobile','.w-list-type-2 .price','font-size','24','','','.w-list-type-2'),(127171,'printshop-mobile','.w-product-wedding-registry-button .btn','font-size','14','','','.w-product-wedding-registry-button'),(127172,'printshop-mobile','.w-product-personal-catalog-button .btn','font-size','21','3','','.w-product-personal-catalog-button'),(127173,'printshop-mobile','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(127174,'printshop-mobile','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(127175,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','font-size','16','','','.w-list-type-2_2'),(127176,'printshop-mobile','.b-fancybox .fancybox-close','font-size','26','','','.b-fancybox'),(127177,'printshop-mobile','.p-reviews-info .review_by .rating-1, .p-reviews-info .review_by .rating-2, .p-reviews-info .review_by .rating-3, .p-reviews-info .review_by .rating-4, .p-reviews-info .review_by .rating-5','font-size','20','','','.p-reviews-info'),(127178,'printshop-mobile','.p-reviews-info .reviews-info h1','font-size','30','','','.p-reviews-info'),(127179,'printshop-mobile','.w-list-type-2_2 .sale','font-size','17','4','','.w-list-type-2_2'),(127180,'printshop-mobile','.w-delivery-location-top-location-list .deliveryName a','font-size','21','','','.w-delivery-location-top-location-list'),(127181,'printshop-mobile','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(127182,'printshop-mobile','.w-chat .w-chat-box a','font-size','20','3','','.w-chat'),(127183,'printshop-mobile','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(127184,'printshop-mobile','.b-bottom .alert-message','font-size','18','','','.b-bottom'),(127185,'printshop-mobile','.p-wedding-registry-index .search-list label','font-size','24','','','.p-wedding-registry-index'),(127186,'printshop-mobile','.p-wedding-registry-index .main-button','font-size','20','4','','.p-wedding-registry-index'),(127187,'printshop-mobile','.p-wedding-registry-index .main-button','font-size','20','3','','.p-wedding-registry-index'),(127188,'printshop-mobile','.p-wedding-registry-manage .links a','font-size','16','','','.p-wedding-registry-manage'),(127189,'printshop-mobile','.p-wedding-registry-manage .links','font-size','0','','','.p-wedding-registry-manage'),(127190,'printshop-mobile','.p-wedding-registry-manage .links a.share-registry','font-size','20','','','.p-wedding-registry-manage'),(127191,'printshop-mobile','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(127192,'printshop-mobile','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(127193,'printshop-mobile','.p-wedding-registry-manage .wedding-date','font-size','20','','','.p-wedding-registry-manage'),(127194,'printshop-mobile','.p-wedding-registry-search h1','font-size','22','4','','.p-wedding-registry-search'),(127195,'printshop-mobile','.p-wedding-registry-search h1','font-size','22','3','','.p-wedding-registry-search'),(127196,'printshop-mobile','.p-account-history .order_history_table h2','font-size','24','','','.p-account-history'),(127197,'printshop-mobile','.p-account-history .order_history_table th','font-size','16','','','.p-account-history'),(127198,'printshop-mobile','.p-wedding-registry-manage h1','font-size','22','3','','.p-wedding-registry-manage'),(127199,'printshop-mobile','.p-wedding-registry-share h1','font-size','22','3','','.p-wedding-registry-share'),(127200,'printshop-mobile','.p-account-address-book .btn-edit','font-size','16','4','','.p-account-address-book'),(127201,'printshop-mobile','.b-compare .clear_all','font-size','16','4','','.b-compare'),(127202,'printshop-mobile','.b-bottom .popup-heading','font-size','16','','','.b-bottom'),(127203,'printshop-mobile','.b-compare .compare-head','font-size','22','','','.b-compare'),(127204,'printshop-mobile','.w-chat .w-chat-box a','font-size','30','706,3','','.w-chat'),(127205,'printshop-mobile','.w-quote .cart-box-link','font-size','30','702,3','','.w-quote'),(127206,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','0','','','.b-slick'),(127207,'printshop-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(127208,'printshop-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','font-size','28','','','.w-filters'),(127209,'printshop-mobile','.w-list-type-1_3 .price .old','font-size','18','','','.w-list-type-1_3'),(127210,'printshop-mobile','.w-list-type-1_3 .properties','font-size','13','','','.w-list-type-1_3'),(127211,'printshop-mobile','.w-list-type-1_3 .products-model','font-size','13','','','.w-list-type-1_3'),(127212,'printshop-mobile','.p-account-index .date_value strong','font-size','16','','','.p-account-index'),(127213,'printshop-mobile','.p-account-index .date_value, .p-account-index .date_title','font-size','18','','','.p-account-index'),(127214,'printshop-mobile','.w-tabs .tab-a','font-size','20','','','.w-tabs'),(127215,'printshop-mobile','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(127216,'printshop-mobile','.w-search .search','font-size','23','3','','.w-search'),(127217,'printshop-mobile','.heading-4, h4','font-size','18','','',''),(127218,'printshop-mobile','.p-account-trade-form .widget h3','font-size','24','','','.p-account-trade-form'),(127219,'printshop-mobile','.p-quote-cart-index .cart-page .empty','font-size','24','','','.p-quote-cart-index'),(127220,'printshop-mobile','.p-checkout-index .same-address','font-size','16','','','.p-checkout-index'),(127221,'printshop-mobile','.p-shopping-cart-index .cart-page .empty','font-size','24','','','.p-shopping-cart-index'),(127222,'printshop-mobile','.b-price-box .price-box .price-row.total','font-size','20','722','','.b-price-box'),(127223,'printshop-mobile','.w-filters .head-filter-widget','font-size','24','','','.w-filters'),(127224,'printshop-mobile','.p-account-index h1, .p-account-index .reviews-info h1','font-size','21','693','','.p-account-index'),(127225,'printshop-mobile','.w-currencies .current','font-size','26','3','','.w-currencies'),(127226,'printshop-mobile','.w-filters .filter-box-head','font-size','20','','','.w-filters'),(127227,'printshop-mobile','.heading-4 .right-text, h4 .right-text','font-size','16','','',''),(127228,'printshop-mobile','.w-compare-box-item .checkbox:checked + span:before','font-size','18','','','.w-compare-box-item'),(127229,'printshop-mobile','.heading-3 .edit, h3 .edit','font-size','16','','',''),(127230,'printshop-mobile','.p-reviews-info .review-info-reviewed_by, .review-info-date','font-size','14','','','.p-reviews-info'),(127231,'printshop-mobile','.p-checkout-success .page-success','font-size','600','3','','.p-checkout-success'),(127232,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table th','font-size','16','','','.p-account-subscription-historyinfo'),(127233,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-size','24','','','.p-account-subscription-historyinfo'),(127234,'printshop-mobile','.p-account-index .view_history','font-size','14','3','','.p-account-index'),(127235,'printshop-mobile','.p-account-index .view_history','font-size','16','','','.p-account-index'),(127236,'printshop-mobile','.p-account-index .view_link','font-size','18','4','','.p-account-index'),(127237,'printshop-mobile','.p-checkout-success .page-success .text-1','font-size','80','3','','.p-checkout-success'),(127238,'printshop-mobile','.p-checkout-success .page-success .text-1','font-size','60','','','.p-checkout-success'),(127239,'printshop-mobile','.p-account-index .topAccount > li > div','font-size','42','3','','.p-account-index'),(127240,'printshop-mobile','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(127241,'printshop-mobile','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(127242,'printshop-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(127243,'printshop-mobile','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(127244,'printshop-mobile','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(127245,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','font-size','14','','',''),(127246,'printshop-mobile','.heading-3, h3','font-size','20','','',''),(127247,'printshop-mobile','.p-checkout-success .page-success .text-2','font-size','34','','','.p-checkout-success'),(127248,'printshop-mobile','.p-checkout-success .page-success .text-3','font-size','27','','','.p-checkout-success'),(127249,'printshop-mobile','.p-account-history-info .historyTotal table tr:last-child td','font-size','24','','','.p-account-history-info'),(127250,'printshop-mobile','.p-account-history-info .historyTotal table td','font-size','18','','','.p-account-history-info'),(127251,'printshop-mobile','.p-account-history .not_fully_paid_td','font-size','30','','','.p-account-history'),(127252,'printshop-mobile','.p-wedding-registry-share .invite-remove','font-size','20','','','.p-wedding-registry-share'),(127253,'printshop-mobile','.w-sale .left-text-right','font-size','24','','','.w-sale'),(127254,'printshop-mobile','.w-sale .ends','font-size','26','','','.w-sale'),(127255,'printshop-mobile','.w-sale .left-text-left','font-size','24','','','.w-sale'),(127256,'printshop-mobile','.w-sale .old','font-size','45','','','.w-sale'),(127257,'printshop-mobile','.w-sale .special-price','font-size','70','','','.w-sale'),(127258,'printshop-mobile','.w-text .customer-service','font-size','21','3','','.w-text'),(127259,'printshop-mobile','.w-text .customer-service','font-size','13','','','.w-text');
INSERT INTO `themes_styles` VALUES (127260,'printshop-mobile','.b-page-name .page-name','font-size','20','','','.b-page-name'),(127261,'printshop-mobile','.w-text .customer-service b','font-size','18','','','.w-text'),(127262,'printshop-mobile','.w-top-categories .categories h2','font-size','inherit','','','.w-top-categories'),(127263,'printshop-mobile','.w-categories .categories h2','font-size','inherit','','','.w-categories'),(127264,'printshop-mobile','.b-form .cart-popup .price','font-size','18','','','.b-form'),(127265,'printshop-mobile','.b-quantity .qty-box .smaller','font-size','31','','','.b-quantity'),(127266,'printshop-mobile','.b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(127267,'printshop-mobile','.w-tabs .tab-a','font-size','16','694','','.w-tabs'),(127268,'printshop-mobile','h1','font-size','26','694','',''),(127269,'printshop-mobile','.b-fancybox .fancybox-nav span','font-size','34','','','.b-fancybox'),(127270,'printshop-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','font-size','22','3','','.w-cart-discount-coupon'),(127271,'printshop-mobile','.w-cart-discount-coupon .gift-code p','font-size','13','','','.w-cart-discount-coupon'),(127272,'printshop-mobile','.w-filters .head-filter-widget > span','font-size','18','706','','.w-filters'),(127273,'printshop-mobile','.w-cart .cart-total','font-size','1.2','','','.w-cart'),(127274,'printshop-mobile','.p-account-index .date_value','font-size','18','','','.p-account-index'),(127275,'printshop-mobile','.heading-2, h2','font-size','24','','',''),(127276,'printshop-mobile','h1','font-size','32','','',''),(127277,'printshop-mobile','.p-account-index .account_page h4','font-size','22','3','','.p-account-index'),(127278,'printshop-mobile','.p-account-history-info .history_attr','font-size','14','','','.p-account-history-info'),(127279,'printshop-mobile','.p-account-index .account_page h1','font-size','30','','','.p-account-index'),(127280,'printshop-mobile','.p-account-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-history-info'),(127281,'printshop-mobile','.b-form #payment_method .title','font-size','16','','','.b-form'),(127282,'printshop-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(127283,'printshop-mobile','.w-menu-mobile .menu-ico','font-size','23','','','.w-menu-mobile'),(127284,'printshop-mobile','.w-cart .qty','font-size','0.6','4','','.w-cart'),(127285,'printshop-mobile','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(127286,'printshop-mobile','.w-cart-give-away .ga_qty','font-size','20','','','.w-cart-give-away'),(127287,'printshop-mobile','.w-cart-give-away .ga_name','font-size','16','','','.w-cart-give-away'),(127288,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','font-size','28','3','','.w-list-type-2'),(127289,'printshop-mobile','.w-list-type-2 .button-view a','font-size','16','','','.w-list-type-2'),(127290,'printshop-mobile','.w-list-type-1_3 .title','font-size','16','','','.w-list-type-1_3'),(127291,'printshop-mobile','.w-list-type-2 .properties','font-size','13','','','.w-list-type-2'),(127292,'printshop-mobile','.w-list-type-2 .button-wishlist button','font-size','16','','','.w-list-type-2'),(127293,'printshop-mobile','.p-wedding-registry-manage h1','font-size','22','4','','.p-wedding-registry-manage'),(127294,'printshop-mobile','.price','font-size','24','','',''),(127295,'printshop-mobile','.w-list-type-1_3 .sale','font-size','17','4','','.w-list-type-1_3'),(127296,'printshop-mobile','.view-all .btn','font-size','0.8','4','',''),(127297,'printshop-mobile','.w-list-type-1_3 .sale','font-size','19','3','','.w-list-type-1_3'),(127298,'printshop-mobile','.w-list-type-2 .sale','font-size','17','4','','.w-list-type-2'),(127299,'printshop-mobile','.p-wedding-registry-view h1','font-size','22','3','','.p-wedding-registry-view'),(127300,'printshop-mobile','.p-wedding-registry-view h1','font-size','22','4','','.p-wedding-registry-view'),(127301,'printshop-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','font-size','14','','','.p-wedding-registry-manage'),(127302,'printshop-mobile','.w-list-type-2 .sale','font-size','19','3','','.w-list-type-2'),(127303,'printshop-mobile','.p-wedding-registry-share h1','font-size','22','4','','.p-wedding-registry-share'),(127304,'printshop-mobile','.btn','font-size','16','','',''),(127305,'printshop-mobile','.heading-3 .right-text, h3 .right-text','font-size','16','','',''),(127306,'printshop-mobile','.btn-2','font-size','20','','',''),(127307,'printshop-mobile','.btn-3','font-size','20','','',''),(127308,'printshop-mobile','.btn-1','font-size','16','','',''),(127309,'printshop-mobile','.w-list-type-1_3 .price','font-size','24','','','.w-list-type-1_3'),(127310,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','font-size','28','3','','.w-list-type-1_3'),(127311,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','font-size','16','','','.w-list-type-1_3'),(127312,'printshop-mobile','.w-list-type-1_3 .button-view a','font-size','16','','','.w-list-type-1_3'),(127313,'printshop-mobile','.w-list-type-1_2 .sale','font-size','19','3','','.w-list-type-1_2'),(127314,'printshop-mobile','.w-list-type-1_2 .sale','font-size','17','4','','.w-list-type-1_2'),(127315,'printshop-mobile','.w-list-type-1_2 .title','font-size','16','','','.w-list-type-1_2'),(127316,'printshop-mobile','.w-list-type-1_2 .products-model','font-size','13','','','.w-list-type-1_2'),(127317,'printshop-mobile','.w-list-type-1_2 .price .old','font-size','18','','','.w-list-type-1_2'),(127318,'printshop-mobile','.w-list-type-1_2 .price','font-size','24','','','.w-list-type-1_2'),(127319,'printshop-mobile','.w-list-type-1_2 .properties','font-size','13','','','.w-list-type-1_2'),(127320,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','font-size','28','3','','.w-list-type-1_2'),(127321,'printshop-mobile','.w-list-type-1 .sale','font-size','17','4','','.w-list-type-1'),(127322,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','font-size','16','','','.w-list-type-1_2'),(127323,'printshop-mobile','.b-bottom .pop-up-close','font-size','25','','','.b-bottom'),(127324,'printshop-mobile','.b-bottom .footerTitle','font-size','24','','','.b-bottom'),(127325,'printshop-mobile','.w-list-type-1 .rating','font-size','12','','','.w-list-type-1'),(127326,'printshop-mobile','.w-list-type-1 .title','font-size','16','','','.w-list-type-1'),(127327,'printshop-mobile','.w-list-type-1 .products-model','font-size','13','','','.w-list-type-1'),(127328,'printshop-mobile','.w-list-type-1_2 .button-view a','font-size','16','','','.w-list-type-1_2'),(127329,'printshop-mobile','.w-list-type-1 .sale','font-size','19','3','','.w-list-type-1'),(127330,'printshop-mobile','.w-list-type-1 .properties','font-size','13','','','.w-list-type-1'),(127331,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','font-size','28','3','','.w-list-type-1'),(127332,'printshop-mobile','.heading-3 .edit, h3 .edit','font-size','14','4','',''),(127333,'printshop-mobile','.heading-4 .edit, h4 .edit','font-size','16','','',''),(127334,'printshop-mobile','.transit','font-size','14','','',''),(127335,'printshop-mobile','.out-stock','font-size','14','','',''),(127336,'printshop-mobile','.w-list-type-1 .button-wishlist button','font-size','16','','','.w-list-type-1'),(127337,'printshop-mobile','.in-stock','font-size','14','','',''),(127338,'printshop-mobile','.w-filters .mobileCollapse','font-size','20','4','','.w-filters'),(127339,'printshop-mobile','.w-filters .view_more','font-size','16','4','','.w-filters'),(127340,'printshop-mobile','.w-list-type-1 .button-view a','font-size','16','','','.w-list-type-1'),(127341,'printshop-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-size','28','','','.w-filters'),(127342,'printshop-mobile','.w-languages .current','font-size','26','3','','.w-languages'),(127343,'printshop-mobile','.w-top-categories .name','font-size','18','','','.w-top-categories'),(127344,'printshop-mobile','.w-reviews .heading-3','font-size','37','3','','.w-reviews'),(127345,'printshop-mobile','.w-quote .cart-box-link','font-size','1.5','3','','.w-quote'),(127346,'printshop-mobile','.w-reviews .rating','font-size','22','','','.w-reviews'),(127347,'printshop-mobile','.w-search .button-search','font-size','23','3','','.w-search'),(127348,'printshop-mobile','.w-reviews .reviews-list span','font-size','22','','','.w-reviews'),(127349,'printshop-mobile','.w-reviews .reviews-list .date','font-size','14','','','.w-reviews'),(127350,'printshop-mobile','.w-search .search-input','font-size','14','','','.w-search'),(127351,'printshop-mobile','.b-form .middle-form .middle-rating span','font-size','26','','','.b-form'),(127352,'printshop-mobile','.b-form .required-message','font-size','14','','','.b-form'),(127353,'printshop-mobile','.b-info .info','font-size','30','3','','.b-info'),(127354,'printshop-mobile','.p-account-address-book .address_book h2','font-size','18','','','.p-account-address-book'),(127355,'printshop-mobile','.p-account-address-book .leftMes div','font-size','18','','','.p-account-address-book'),(127356,'printshop-mobile','.p-account-address-book .address_book .btn-edit, .p-account-address-book .address_book .btn-delete','font-size','16','4','','.p-account-address-book'),(127357,'printshop-mobile','.b-info .info strong','font-size','18','','','.b-info'),(127358,'printshop-mobile','.b-info-popup .info-popup','font-size','30','3','','.b-info-popup'),(127359,'printshop-mobile','.b-products-listing .btn-preloader','font-size','24','3','','.b-products-listing'),(127360,'printshop-mobile','.b-products-listing .loader','font-size','30','4','','.b-products-listing'),(127361,'printshop-mobile','.b-products-listing .products-listing .attribute-qty-block','font-size','14','','','.b-products-listing'),(127362,'printshop-mobile','.b-products-listing .products-listing .bonusPoints','font-size','13','','','.b-products-listing'),(127363,'printshop-mobile','.b-products-listing .products-listing .btn-buy','font-size','20','3','','.b-products-listing'),(127364,'printshop-mobile','.b-products-listing .products-listing .model','font-size','14','','','.b-products-listing'),(127365,'printshop-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','font-size','20','','','.b-products-listing'),(127366,'printshop-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-size','20','','','.b-products-listing'),(127367,'printshop-mobile','.b-products-listing .products-listing h2','font-size','inherit','','','.b-products-listing'),(127368,'printshop-mobile','.b-products-listing .promos-info .promo-name','font-size','14','','','.b-products-listing'),(127369,'printshop-mobile','.b-products-listing .wedding-registry-count','font-size','14','','','.b-products-listing'),(127370,'printshop-mobile','.b-products-listing .products-listing .out-stock','font-size','11','','','.b-products-listing'),(127371,'printshop-mobile','.b-products-listing .products-listing .name','font-size','14','','','.b-products-listing'),(127372,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.b-data-table'),(127373,'printshop-mobile','.b-data-table table.dataTable thead td','font-size','16','','','.b-data-table'),(127374,'printshop-mobile','.b-email .qty','font-size','14','','','.b-email'),(127375,'printshop-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(127376,'printshop-mobile','.b-email .model','font-size','14','','','.b-email'),(127377,'printshop-mobile','.b-email .qty','font-size','14','','','.b-email'),(127378,'printshop-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(127379,'printshop-mobile','.b-email .model','font-size','14','','','.b-email'),(127380,'printshop-mobile','.b-email .name','font-size','14','','','.b-email'),(127381,'printshop-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(127382,'printshop-mobile','.b-email .name','font-size','14','','','.b-email'),(127383,'printshop-mobile','.b-email .model','font-size','14','','','.b-email'),(127384,'printshop-mobile','.b-email .model','font-size','14','','','.b-email'),(127385,'printshop-mobile','.b-email .name','font-size','14','','','.b-email'),(127386,'printshop-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(127387,'printshop-mobile','.b-email .qty','font-size','14','','','.b-email'),(127388,'printshop-mobile','.b-email .qty','font-size','14','','','.b-email'),(127389,'printshop-mobile','.b-email .qty','font-size','14','','','.b-email'),(127390,'printshop-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(127391,'printshop-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(127392,'printshop-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(127393,'printshop-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(127394,'printshop-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(127395,'printshop-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(127396,'printshop-mobile','.b-email .price','font-size','14','','','.b-email'),(127397,'printshop-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(127398,'printshop-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(127399,'printshop-mobile','.b-email .name','font-size','14','','','.b-email'),(127400,'printshop-mobile','.b-email .price','font-size','14','','','.b-email'),(127401,'printshop-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(127402,'printshop-mobile','.b-email .qty','font-size','14','','','.b-email'),(127403,'printshop-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(127404,'printshop-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(127405,'printshop-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(127406,'printshop-mobile','.b-email .price','font-size','14','','','.b-email'),(127407,'printshop-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(127408,'printshop-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(127409,'printshop-mobile','.b-email .price','font-size','14','','','.b-email'),(127410,'printshop-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(127411,'printshop-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(127412,'printshop-mobile','.b-email .price','font-size','14','','','.b-email'),(127413,'printshop-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(127414,'printshop-mobile','.b-email .price','font-size','14','','','.b-email'),(127415,'printshop-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(127416,'printshop-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(127417,'printshop-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(127418,'printshop-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(127419,'printshop-mobile','.b-email .model','font-size','14','','','.b-email'),(127420,'printshop-mobile','.b-email .name','font-size','14','','','.b-email'),(127421,'printshop-mobile','.b-email .name','font-size','14','','','.b-email'),(127422,'printshop-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(127423,'printshop-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(127424,'printshop-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(127425,'printshop-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(127426,'printshop-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(127427,'printshop-mobile','.b-email .model','font-size','14','','','.b-email'),(127428,'printshop-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(127429,'printshop-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(127430,'printshop-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(127431,'printshop-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(127432,'printshop-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(127433,'printshop-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(127434,'printshop-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(127435,'printshop-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(127436,'printshop-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(127437,'printshop-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(127438,'printshop-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(127439,'printshop-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(127440,'printshop-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(127441,'printshop-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(127442,'printshop-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(127443,'printshop-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(127444,'printshop-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(127445,'printshop-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(127446,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-size','inherit','','','.b-h-inline'),(127447,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(127448,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(127449,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(127450,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(127451,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(127452,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(127453,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(127454,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(127455,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(127456,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev63_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(127457,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','font-size','16','','','.b-menu-style-1'),(127458,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','font-size','18','','','.b-menu-style-1'),(127459,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','font-size','14','','','.b-menu-style-2'),(127460,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','font-size','14','','','.b-menu-style-2'),(127461,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','font-size','26','','','.b-menu-style-2'),(127462,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','font-size','20','3','','.b-menu-style-2'),(127463,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-size','20','3','','.b-menu-style-2'),(127464,'printshop-mobile','.b-messages .content-messages .heading-2','font-size','26','','','.b-messages'),(127465,'printshop-mobile','.b-messages span.starred::before','font-size','16','','','.b-messages'),(127466,'printshop-mobile','.b-messages .messBtnMenuStarred','font-size','22','3','','.b-messages'),(127467,'printshop-mobile','.b-messages .messBtnMenuDelete','font-size','22','3','','.b-messages'),(127468,'printshop-mobile','.b-messages .messBtnMenuUnread','font-size','22','3','','.b-messages'),(127469,'printshop-mobile','.b-messages .messMenuButton span','font-size','14','','','.b-messages'),(127470,'printshop-mobile','.b-messages .content_management_attach button','font-size','14','','','.b-messages'),(127471,'printshop-mobile','.b-messages .content_management_attach','font-size','14','','','.b-messages'),(127472,'printshop-mobile','.b-messages .content_management_attach span','font-size','16','','','.b-messages'),(127473,'printshop-mobile','.b-messages .select2-search-choice-close','font-size','11','3','','.b-messages'),(127474,'printshop-mobile','.b-preloader .preloader','font-size','40','3','','.b-preloader'),(127475,'printshop-mobile','.b-select-suggest .select2-search-choice-close','font-size','1','','','.b-select-suggest'),(127476,'printshop-mobile','.b-select-suggest .select2-search input','font-size','1','','','.b-select-suggest'),(127477,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','font-size','1','','','.b-select-suggest'),(127478,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-size','100','','','.b-select-suggest'),(127479,'printshop-mobile','.b-sub-totals .historyTotal table td','font-size','18','','','.b-sub-totals'),(127480,'printshop-mobile','.b-sub-totals .historyTotal table tr:last-child td','font-size','24','','','.b-sub-totals'),(127481,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(127482,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(127483,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(127484,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(127485,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(127486,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(127487,'printshop-mobile','.b-trade-approval .middle-form label','font-size','16','','','.b-trade-approval'),(127488,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','font-size','14','','','.b-trade-approval'),(127489,'printshop-mobile','.b-upload-file .snapshot','font-size','18','','','.b-upload-file'),(127490,'printshop-mobile','.b-warehouses-popup .warehouses-popup .heading','font-size','18','','','.b-warehouses-popup'),(127491,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','font-size','14','','','.b-warehouses-popup'),(127492,'printshop-mobile','.b-warehouses-popup a.warehouses-popup-link','font-size','14','','','.b-warehouses-popup'),(127493,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-name','font-size','16','','','.b-warehouses-popup'),(127494,'printshop-mobile','.batchPr .w-batch-products .products-listing .name a','font-size','16','','','.batchPr'),(127495,'printshop-mobile','.batchPr .w-batch-products .products-listing .price','font-size','16','','','.batchPr'),(127496,'printshop-mobile','.batchPr .btn-batch-remove','font-size','17','3','','.batchPr'),(127497,'printshop-mobile','.batchPr .batchSelect .checkbox','font-size','18','','','.batchPr'),(127498,'printshop-mobile','.batchPr .batchSelect','font-size','12','','','.batchPr'),(127499,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .name a, .batchPr .w-batch-selected-products .products-listing .price','font-size','14','','','.batchPr'),(127500,'printshop-mobile','.batchPr .checkbox input:checked + span:before','font-size','18','','','.batchPr'),(127501,'printshop-mobile','.batchPr .batch-selected-products-empty','font-size','20','','','.batchPr'),(127502,'printshop-mobile','.batchPr .checkbox input:not(checked) + span:before','font-size','32','','','.batchPr'),(127503,'printshop-mobile','.batchPr .batch-selected-products-total','font-size','20','','','.batchPr'),(127504,'printshop-mobile','.batchPr .btn-batch-remove','font-size','0','','','.batchPr'),(127505,'printshop-mobile','.bell-ico .heading-2','font-size','32','3','','.bell-ico'),(127506,'printshop-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(127507,'printshop-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(127508,'printshop-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(127509,'printshop-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(127510,'printshop-mobile','.heading-ordered-items .heading-4','font-size','28','3','','.heading-ordered-items'),(127511,'printshop-mobile','.heading-saved-lists .heading-4','font-size','28','3','','.heading-saved-lists'),(127512,'printshop-mobile','.heading-settings .heading-4','font-size','28','3','','.heading-settings'),(127513,'printshop-mobile','.p-account-samples-history .order_history_table th','font-size','16','','','.p-account-samples-history'),(127514,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','font-size','16','','','.p-account-samples-history'),(127515,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','font-size','30','','','.p-account-samples-history'),(127516,'printshop-mobile','.p-account-samples-history .order_history_table th','font-size','16','','','.p-account-samples-history'),(127517,'printshop-mobile','.p-account-samples-history .order_history_table h2','font-size','24','','','.p-account-samples-history'),(127518,'printshop-mobile','.p-account-samples-history .view_link','font-size','18','4','','.p-account-samples-history'),(127519,'printshop-mobile','.p-account-samples-history .view_link','font-size','18','4','','.p-account-samples-history'),(127520,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','font-size','30','','','.p-account-samples-history'),(127521,'printshop-mobile','.p-account-samples-history .view_link','font-size','18','4','','.p-account-samples-history'),(127522,'printshop-mobile','.p-account-samples-history .view_link','font-size','18','4','','.p-account-samples-history'),(127523,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','font-size','30','','','.p-account-samples-history'),(127524,'printshop-mobile','.p-account-samples-history .order_history_table th','font-size','16','','','.p-account-samples-history'),(127525,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','font-size','16','','','.p-account-samples-history'),(127526,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','font-size','30','','','.p-account-samples-history'),(127527,'printshop-mobile','.p-account-samples-history .order_history_table h2','font-size','24','','','.p-account-samples-history'),(127528,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','font-size','16','','','.p-account-samples-history'),(127529,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','font-size','30','','','.p-account-samples-history'),(127530,'printshop-mobile','.p-account-samples-history .order_history_table h2','font-size','24','','','.p-account-samples-history'),(127531,'printshop-mobile','.p-account-samples-history .order_history_table h2','font-size','24','','','.p-account-samples-history'),(127532,'printshop-mobile','.p-account-samples-history .view_link','font-size','18','4','','.p-account-samples-history'),(127533,'printshop-mobile','.p-account-samples-history .order_history_table th','font-size','16','','','.p-account-samples-history'),(127534,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','font-size','16','','','.p-account-samples-history'),(127535,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','font-size','30','','','.p-account-samples-history'),(127536,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','font-size','16','','','.p-account-samples-history'),(127537,'printshop-mobile','.p-account-samples-history .order_history_table h2','font-size','24','','','.p-account-samples-history'),(127538,'printshop-mobile','.p-account-samples-history .view_link','font-size','18','4','','.p-account-samples-history'),(127539,'printshop-mobile','.p-account-samples-history .order_history_table th','font-size','16','','','.p-account-samples-history'),(127540,'printshop-mobile','.p-account-samples-history .order_history_table h2','font-size','24','','','.p-account-samples-history'),(127541,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','font-size','16','','','.p-account-samples-history'),(127542,'printshop-mobile','.p-account-samples-history .order_history_table th','font-size','16','','','.p-account-samples-history'),(127543,'printshop-mobile','.p-account-samples-history-info .history_attr','font-size','14','','','.p-account-samples-history-info'),(127544,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-size','18','','','.p-account-samples-history-info'),(127545,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','22','3','','.p-account-samples-history-info'),(127546,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','font-size','30','','','.p-account-samples-history-info'),(127547,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-samples-history-info'),(127548,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','font-size','30','','','.p-account-samples-history-info'),(127549,'printshop-mobile','.p-account-samples-history-info .trackings-nambers-label','font-size','20','','','.p-account-samples-history-info'),(127550,'printshop-mobile','.p-account-samples-history-info .history_attr','font-size','14','','','.p-account-samples-history-info'),(127551,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','22','3','','.p-account-samples-history-info'),(127552,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-size','18','','','.p-account-samples-history-info'),(127553,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-samples-history-info'),(127554,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','18','','','.p-account-samples-history-info'),(127555,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','18','','','.p-account-samples-history-info'),(127556,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-size','18','','','.p-account-samples-history-info'),(127557,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','22','3','','.p-account-samples-history-info'),(127558,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','18','','','.p-account-samples-history-info'),(127559,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-samples-history-info'),(127560,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-samples-history-info'),(127561,'printshop-mobile','.p-account-samples-history-info .history_attr','font-size','14','','','.p-account-samples-history-info'),(127562,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','18','','','.p-account-samples-history-info'),(127563,'printshop-mobile','.p-account-samples-history-info .history_attr','font-size','14','','','.p-account-samples-history-info'),(127564,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','font-size','30','','','.p-account-samples-history-info'),(127565,'printshop-mobile','.p-account-samples-history-info .trackings-nambers-label','font-size','20','','','.p-account-samples-history-info'),(127566,'printshop-mobile','.p-account-samples-history-info .trackings-nambers-label','font-size','20','','','.p-account-samples-history-info'),(127567,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','font-size','30','','','.p-account-samples-history-info'),(127568,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','22','3','','.p-account-samples-history-info'),(127569,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-samples-history-info'),(127570,'printshop-mobile','.p-account-samples-history-info .trackings-nambers-label','font-size','20','','','.p-account-samples-history-info'),(127571,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','font-size','30','','','.p-account-samples-history-info'),(127572,'printshop-mobile','.p-account-samples-history-info .history_attr','font-size','14','','','.p-account-samples-history-info'),(127573,'printshop-mobile','.p-account-samples-history-info .trackings-nambers-label','font-size','20','','','.p-account-samples-history-info'),(127574,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','font-size','30','','','.p-account-samples-history-info'),(127575,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','18','','','.p-account-samples-history-info'),(127576,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-samples-history-info'),(127577,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','22','3','','.p-account-samples-history-info'),(127578,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','18','','','.p-account-samples-history-info'),(127579,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-size','18','','','.p-account-samples-history-info'),(127580,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','22','3','','.p-account-samples-history-info'),(127581,'printshop-mobile','.p-account-samples-history-info .history_attr','font-size','14','','','.p-account-samples-history-info'),(127582,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-size','18','','','.p-account-samples-history-info'),(127583,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-size','18','','','.p-account-samples-history-info'),(127584,'printshop-mobile','.p-account-samples-history-info .trackings-nambers-label','font-size','20','','','.p-account-samples-history-info'),(127585,'printshop-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(127586,'printshop-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(127587,'printshop-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(127588,'printshop-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(127589,'printshop-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(127590,'printshop-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(127591,'printshop-mobile','.p-catalog-product .pn-direction','font-size','14','','','.p-catalog-product'),(127592,'printshop-mobile','.p-catalog-product .pn-image','font-size','14','3','','.p-catalog-product'),(127593,'printshop-mobile','.p-catalog-product .pn-name','font-size','14','','','.p-catalog-product'),(127594,'printshop-mobile','.p-checkout-login .password-forgotten-link','font-size','14','','','.p-checkout-login'),(127595,'printshop-mobile','.p-payer-order-confirmation .ship-ico','font-size','30','3','','.p-payer-order-confirmation'),(127596,'printshop-mobile','.p-payer-order-confirmation .comment-ico','font-size','30','3','','.p-payer-order-confirmation'),(127597,'printshop-mobile','.p-payer-order-confirmation .order-ico','font-size','36','3','','.p-payer-order-confirmation'),(127598,'printshop-mobile','.p-payer-order-confirmation .pay-ico','font-size','30','3','','.p-payer-order-confirmation'),(127599,'printshop-mobile','.p-payer-order-confirmation .discount-ico','font-size','30','3','','.p-payer-order-confirmation'),(127600,'printshop-mobile','.p-payer-order-pay .ship-ico','font-size','30','3','','.p-payer-order-pay'),(127601,'printshop-mobile','.p-payer-order-pay .pay-ico','font-size','30','3','','.p-payer-order-pay'),(127602,'printshop-mobile','.p-payer-order-pay .discount-ico','font-size','30','3','','.p-payer-order-pay'),(127603,'printshop-mobile','.p-payer-order-pay .comment-ico','font-size','30','3','','.p-payer-order-pay'),(127604,'printshop-mobile','.p-payer-order-pay .order-ico','font-size','36','3','','.p-payer-order-pay'),(127605,'printshop-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-size','14','','','.p-quick-order-index'),(127606,'printshop-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','font-size','13','','','.p-quick-order-index'),(127607,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.next','font-size','0','','','.p-quick-order-index'),(127608,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.previous','font-size','0','','','.p-quick-order-index'),(127609,'printshop-mobile','.p-quick-order-index .dataTables_info','font-size','14','','','.p-quick-order-index'),(127610,'printshop-mobile','.p-quick-order-index .value','font-size','20','','','.p-quick-order-index'),(127611,'printshop-mobile','.p-quick-order-index .in-stock, .p-quick-order-index .out-stock','font-size','12','','','.p-quick-order-index'),(127612,'printshop-mobile','.p-quick-order-index .stock','font-size','12','','','.p-quick-order-index'),(127613,'printshop-mobile','.p-quick-order-index .paginate_button.previous','font-size','20','3','','.p-quick-order-index'),(127614,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.p-quick-order-index'),(127615,'printshop-mobile','.p-quick-order-index .paginate_button.next','font-size','20','3','','.p-quick-order-index'),(127616,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(127617,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(127618,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(127619,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(127620,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(127621,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(127622,'printshop-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(127623,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(127624,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(127625,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(127626,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(127627,'printshop-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(127628,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(127629,'printshop-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(127630,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(127631,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(127632,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(127633,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(127634,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(127635,'printshop-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(127636,'printshop-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(127637,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(127638,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(127639,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(127640,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(127641,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(127642,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(127643,'printshop-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(127644,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(127645,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(127646,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(127647,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(127648,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(127649,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(127650,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(127651,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(127652,'printshop-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(127653,'printshop-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(127654,'printshop-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(127655,'printshop-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(127656,'printshop-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(127657,'printshop-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(127658,'printshop-mobile','.p-sample-checkout-success .page-success .text-1','font-size','80','3','','.p-sample-checkout-success'),(127659,'printshop-mobile','.p-sample-checkout-success .page-success .text-3','font-size','27','','','.p-sample-checkout-success'),(127660,'printshop-mobile','.p-sample-checkout-success .page-success .text-2','font-size','34','','','.p-sample-checkout-success'),(127661,'printshop-mobile','.p-sample-checkout-success .page-success .text-2','font-size','30','','','.p-sample-checkout-success'),(127662,'printshop-mobile','.p-sample-checkout-success .page-success .text-1','font-size','60','','','.p-sample-checkout-success'),(127663,'printshop-mobile','.p-sample-checkout-success .page-success .text-1','font-size','40','','','.p-sample-checkout-success'),(127664,'printshop-mobile','.savings-ico .heading-2','font-size','32','3','','.savings-ico'),(127665,'printshop-mobile','.shipping-ico .heading-2','font-size','32','3','','.shipping-ico'),(127666,'printshop-mobile','.shipping-ico .heading-2','font-size','32','3','','.shipping-ico'),(127667,'printshop-mobile','.shipping-ico .heading-2','font-size','32','3','','.shipping-ico'),(127668,'printshop-mobile','.w-account-address-book .address-buttons','font-size','14','','','.w-account-address-book'),(127669,'printshop-mobile','.w-account-address-book .add_item a','font-size','25','','','.w-account-address-book'),(127670,'printshop-mobile','.w-account-addresses-list .addsess-suggestion-item','font-size','14','','','.w-account-addresses-list'),(127671,'printshop-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(127672,'printshop-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(127673,'printshop-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(127674,'printshop-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(127675,'printshop-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(127676,'printshop-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(127677,'printshop-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(127678,'printshop-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(127679,'printshop-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(127680,'printshop-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(127681,'printshop-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(127682,'printshop-mobile','.w-account-personal-catalog .list-switcher a','font-size','20','','','.w-account-personal-catalog'),(127683,'printshop-mobile','.w-blog-widget-categories-list a','font-size','14','','','.w-blog-widget-categories-list'),(127684,'printshop-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','font-size','15','','','.w-blog-widget-most-popular-posts'),(127685,'printshop-mobile','.w-blog-widget-most-popular-posts a','font-size','14','','','.w-blog-widget-most-popular-posts'),(127686,'printshop-mobile','.w-blog-widget-post-comments-count span','font-size','14','3','','.w-blog-widget-post-comments-count'),(127687,'printshop-mobile','.w-blog-widget-post-date ','font-size','14','','','.w-blog-widget-post-date'),(127688,'printshop-mobile','.w-blog-widget-post-linked-products .heading-2','font-size','22','','','.w-blog-widget-post-linked-products'),(127689,'printshop-mobile','.w-blog-widget-post-listing .post_date','font-size','14','','','.w-blog-widget-post-listing'),(127690,'printshop-mobile','.w-blog-widget-post-listing .post_name a','font-size','22','','','.w-blog-widget-post-listing'),(127691,'printshop-mobile','.w-blog-widget-post-share .facebook-btn','font-size','22','3','','.w-blog-widget-post-share'),(127692,'printshop-mobile','.w-blog-widget-post-share .mailto','font-size','26','3','','.w-blog-widget-post-share'),(127693,'printshop-mobile','.w-blog-widget-post-share .printto','font-size','26','3','','.w-blog-widget-post-share'),(127694,'printshop-mobile','.w-blog-widget-post-share .twitter-btn','font-size','22','3','','.w-blog-widget-post-share'),(127695,'printshop-mobile','.w-blog-widget-post-share .pinterest-btn','font-size','22','3','','.w-blog-widget-post-share'),(127696,'printshop-mobile','.w-blog-widget-post-title h1','font-size','32','','','.w-blog-widget-post-title'),(127697,'printshop-mobile','.w-blog-widget-post-title h1','font-size','24','','','.w-blog-widget-post-title'),(127698,'printshop-mobile','.w-blog-widget-post-title ','font-size','24','','','.w-blog-widget-post-title'),(127699,'printshop-mobile','.w-blog-widget-related-posts .post_content a','font-size','20','','','.w-blog-widget-related-posts'),(127700,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','font-size','18','3','','.w-blog-widget-related-posts'),(127701,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_content a','font-size','18','','','.w-blog-widget-related-posts-by-category'),(127702,'printshop-mobile','.w-blog-widget-tag-cloud a','font-size','12','','','.w-blog-widget-tag-cloud'),(127703,'printshop-mobile','.w-cart-bonus-points .text','font-size','14','','','.w-cart-bonus-points'),(127704,'printshop-mobile','.w-cart-bonus-points .title','font-size','14','3','','.w-cart-bonus-points'),(127705,'printshop-mobile','.w-cart-bonus-points .btn-remove','font-size','12','','','.w-cart-bonus-points'),(127706,'printshop-mobile','.w-cart-cart-tabs .w-tabs .tab-a','font-size','12','','','.w-cart-cart-tabs'),(127707,'printshop-mobile','.w-cart-compare .attributes-label','font-size','14','','','.w-cart-compare'),(127708,'printshop-mobile','.w-cart-compare .product-actions .dropdown-toggle','font-size','18','3','','.w-cart-compare'),(127709,'printshop-mobile','.w-cart-compare .js-cart_totals_container','font-size','14','','','.w-cart-compare'),(127710,'printshop-mobile','.w-cart-compare .cart-name a','font-size','17','','','.w-cart-compare'),(127711,'printshop-mobile','.w-cart-compare .product-actions','font-size','12','','','.w-cart-compare'),(127712,'printshop-mobile','.w-cart-compare .delete-cart','font-size','12','','','.w-cart-compare'),(127713,'printshop-mobile','.w-cart-compare .js-cart_totals_container b','font-size','16','','','.w-cart-compare'),(127714,'printshop-mobile','.w-cart-compare .atr-col','font-size','20','3','','.w-cart-compare'),(127715,'printshop-mobile','.w-cart-compare .attributes-cell','font-size','14','','','.w-cart-compare'),(127716,'printshop-mobile','.w-cart-compare .dropdown li','font-size','14','','','.w-cart-compare'),(127717,'printshop-mobile','.w-cart-compare .product .name a','font-size','14','','','.w-cart-compare'),(127718,'printshop-mobile','.w-cart-compare .price-label','font-size','14','','','.w-cart-compare'),(127719,'printshop-mobile','.w-cart-compare .price-cell','font-size','18','','','.w-cart-compare'),(127720,'printshop-mobile','.w-cart-credit-amount .text','font-size','14','','','.w-cart-credit-amount'),(127721,'printshop-mobile','.w-cart-credit-amount .btn-remove','font-size','12','','','.w-cart-credit-amount'),(127722,'printshop-mobile','.w-catalog-compare .checkbox input:checked + span:before','font-size','24','','','.w-catalog-compare'),(127723,'printshop-mobile','.w-catalog-compare .model','font-size','14','','','.w-catalog-compare'),(127724,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-size','26','3','','.w-catalog-compare'),(127725,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','font-size','0','','','.w-catalog-compare'),(127726,'printshop-mobile','.w-catalog-compare .item .compare','font-size','0','','','.w-catalog-compare'),(127727,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','font-size','15','','','.w-catalog-compare'),(127728,'printshop-mobile','.w-catalog-compare .name','font-size','12','','','.w-catalog-compare'),(127729,'printshop-mobile','.w-catalog-paging .next','font-size','20','3','','.w-catalog-paging'),(127730,'printshop-mobile','.w-catalog-paging .prev','font-size','20','3','','.w-catalog-paging'),(127731,'printshop-mobile','.w-checkout-bonus-points .btn-remove','font-size','12','','','.w-checkout-bonus-points'),(127732,'printshop-mobile','.w-checkout-create-account .account-benefits','font-size','0.8','','','.w-checkout-create-account'),(127733,'printshop-mobile','.w-checkout-create-account .account-benefits strong','font-size','18','3','','.w-checkout-create-account'),(127734,'printshop-mobile','.w-checkout-credit-amount .btn-remove','font-size','12','','','.w-checkout-credit-amount'),(127735,'printshop-mobile','.w-checkout-shipping-choice span','font-size','14','','','.w-checkout-shipping-choice'),(127736,'printshop-mobile','.w-checkout-terms .terms-box','font-size','13','','','.w-checkout-terms'),(127737,'printshop-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-size','14','','','.w-communication-new-topic'),(127738,'printshop-mobile','.w-communication-new-topic td.date-purchased','font-size','14','','','.w-communication-new-topic'),(127739,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','font-size','31','','','.w-communication-new-topic'),(127740,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','font-size','31','','','.w-communication-new-topic'),(127741,'printshop-mobile','.w-communication-post .communication-post-attach','font-size','14','','','.w-communication-post'),(127742,'printshop-mobile','.w-communication-post .communication-post-date','font-size','14','','','.w-communication-post'),(127743,'printshop-mobile','.w-coupons-and-vauchers-checkout .btn-remove','font-size','12','','','.w-coupons-and-vauchers-checkout'),(127744,'printshop-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-size','40','','','.w-delivery-day'),(127745,'printshop-mobile','.w-delivery-day .ends','font-size','26','','','.w-delivery-day'),(127746,'printshop-mobile','.w-delivery-day .left-text-left','font-size','24','','','.w-delivery-day'),(127747,'printshop-mobile','.w-delivery-day .left-text-right','font-size','24','','','.w-delivery-day'),(127748,'printshop-mobile','.w-delivery-day .title','font-size','18','','','.w-delivery-day'),(127749,'printshop-mobile','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-size','24','','','.w-multi-cart-cart-switcher'),(127750,'printshop-mobile','.w-personal-gift-status-bar .end-label','font-size','14','','','.w-personal-gift-status-bar'),(127751,'printshop-mobile','.w-personal-gift-status-bar .start-label','font-size','14','','','.w-personal-gift-status-bar'),(127752,'printshop-mobile','.w-personal-gift-status-bar .inform','font-size','24','4','','.w-personal-gift-status-bar'),(127753,'printshop-mobile','.w-personal-gift-status-bar .end-date','font-size','22','3','','.w-personal-gift-status-bar'),(127754,'printshop-mobile','.w-personal-gift-status-bar .inform','font-size','14','','','.w-personal-gift-status-bar'),(127755,'printshop-mobile','.w-personal-gift-status-bar .end-date','font-size','14','','','.w-personal-gift-status-bar'),(127756,'printshop-mobile','.w-product-available-in-warehouses .heading','font-size','18','','','.w-product-available-in-warehouses'),(127757,'printshop-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(127758,'printshop-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(127759,'printshop-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(127760,'printshop-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(127761,'printshop-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(127762,'printshop-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(127763,'printshop-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(127764,'printshop-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(127765,'printshop-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(127766,'printshop-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(127767,'printshop-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(127768,'printshop-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(127769,'printshop-mobile','.w-product-customers-activity .customers-activity','font-size','16','','','.w-product-customers-activity'),(127770,'printshop-mobile','.w-promotions .prom-multi-discount .promo-group','font-size','16','','','.w-promotions'),(127771,'printshop-mobile','.w-promotions .nextdiscount .item-holder .name','font-size','14','','','.w-promotions'),(127772,'printshop-mobile','.w-promotions .prom-multi-discount .heading','font-size','26','','','.w-promotions'),(127773,'printshop-mobile','.w-promotions .nextdiscount .heading','font-size','18','3','','.w-promotions'),(127774,'printshop-mobile','.w-promotions .nextdiscount .heading','font-size','26','','','.w-promotions'),(127775,'printshop-mobile','.w-promotions .promo-cart-discount .item a','font-size','14','','','.w-promotions'),(127776,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','font-size','13','','','.w-promotions'),(127777,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','font-size','16','','','.w-promotions'),(127778,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','font-size','13','','','.w-promotions'),(127779,'printshop-mobile','.w-promotions .promo-salemaker .content a','font-size','14','','','.w-promotions'),(127780,'printshop-mobile','.w-promotions .promo-item','font-size','24','','','.w-promotions'),(127781,'printshop-mobile','.w-promotions .promo-salemaker .discount','font-size','13','','','.w-promotions'),(127782,'printshop-mobile','.w-promotions .heading-3','font-size','48','','','.w-promotions'),(127783,'printshop-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','font-size','14','','','.w-promotions'),(127784,'printshop-mobile','.w-promotions .nextdiscount .promo-for-each','font-size','14','','','.w-promotions'),(127785,'printshop-mobile','.w-quote-products .empty','font-size','24','','','.w-quote-products'),(127786,'printshop-mobile','.w-reviews-content .rating','font-size','18','','','.w-reviews-content'),(127787,'printshop-mobile','.w-reviews-content .date','font-size','13','','','.w-reviews-content'),(127788,'printshop-mobile','.w-social-links a','font-size','26','','','.w-social-links'),(127789,'printshop-mobile','.w-social-links a','font-size','30','','','.w-social-links'),(127790,'printshop-mobile','.w-taxable .bootstrap-switch .bootstrap-switch-label','font-size','0','','','.w-taxable'),(127791,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-size','20','','','.w-upload-customer-id-upload-customer-id-form'),(127792,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-template','font-size','18','','','.w-upload-customer-id-upload-customer-id-form'),(127793,'printshop-mobile','.w-wedding-registry-widgets-products .remove','font-size','24','','','.w-wedding-registry-widgets-products'),(127794,'printshop-mobile','.b-rating #stars-default .glyphicon','font-style','normal','','','.b-rating'),(127795,'printshop-mobile','.b-select-suggest .select2-results li em','font-style','normal','','','.b-select-suggest'),(127796,'printshop-mobile','.w-bestsellers .counter','font-weight','600','','','.w-bestsellers'),(127797,'printshop-mobile','.w-bestsellers .heading-3','font-weight','400','3','','.w-bestsellers'),(127798,'printshop-mobile','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(127799,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(127800,'printshop-mobile','.w-sale .left-count-hours','font-weight','600','','','.w-sale'),(127801,'printshop-mobile','.w-sale .left-count-days','font-weight','600','','','.w-sale'),(127802,'printshop-mobile','.w-sale .left-text-right','font-weight','600','','','.w-sale'),(127803,'printshop-mobile','.w-sale .special-price','font-weight','600','','','.w-sale'),(127804,'printshop-mobile','.w-list-type-2_2 .sale','font-weight','600','4','','.w-list-type-2_2'),(127805,'printshop-mobile','.w-list-type-2_2 .title','font-weight','700','','','.w-list-type-2_2'),(127806,'printshop-mobile','.w-sale .name','font-weight','bold','','','.w-sale'),(127807,'printshop-mobile','.w-menu-slider > ul > li > ul > li > a','font-weight','700','','','.w-menu-slider'),(127808,'printshop-mobile','.w-product-sale-ends .left-count-days','font-weight','600','','','.w-product-sale-ends'),(127809,'printshop-mobile','.w-product-sale-ends .ends-date','font-weight','600','','','.w-product-sale-ends'),(127810,'printshop-mobile','.w-product-sale-ends .left-count-hours','font-weight','600','','','.w-product-sale-ends'),(127811,'printshop-mobile','.w-product-sale-ends .left-text-left','font-weight','600','','','.w-product-sale-ends'),(127812,'printshop-mobile','.w-product-sale-ends .left-text-right','font-weight','600','','','.w-product-sale-ends'),(127813,'printshop-mobile','.w-product-collection .title','font-weight','bold','','','.w-product-collection'),(127814,'printshop-mobile','.w-product-collection .together','font-weight','700','','','.w-product-collection'),(127815,'printshop-mobile','.w-cart .cart-total','font-weight','600','','','.w-cart'),(127816,'printshop-mobile','.w-cart .price','font-weight','600','','','.w-cart'),(127817,'printshop-mobile','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(127818,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','font-weight','normal','3','','.p-account-history-info'),(127819,'printshop-mobile','.p-account-history-info .not_fully_paid_td','font-weight','700','','','.p-account-history-info'),(127820,'printshop-mobile','.p-account-index .not_fully_paid_td','font-weight','700','','','.p-account-index'),(127821,'printshop-mobile','.b-pass-strength .pass-strength span','font-weight','bold','','','.b-pass-strength'),(127822,'printshop-mobile','.b-price-box .price-box .price-row.total','font-weight','700','','','.b-price-box'),(127823,'printshop-mobile','.w-reviews .name','font-weight','700','','','.w-reviews'),(127824,'printshop-mobile','.w-product-reviews .reviews-list span','font-weight','400','','','.w-product-reviews'),(127825,'printshop-mobile','.w-quote .strong','font-weight','400','','','.w-quote'),(127826,'printshop-mobile','.w-product-reviews .reviews-list .name','font-weight','700','','','.w-product-reviews'),(127827,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-weight','normal','3','','.b-multi-page-checkout'),(127828,'printshop-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','font-weight','bold','','','.p-wedding-registry-manage'),(127829,'printshop-mobile','.p-account-history-info .trackings-nambers-label','font-weight','600','','','.p-account-history-info'),(127830,'printshop-mobile','.w-product-bonus-points > div','font-weight','bold','','','.w-product-bonus-points'),(127831,'printshop-mobile','.p-account-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-history-info'),(127832,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','font-weight','normal','3','','.p-account-order-pay'),(127833,'printshop-mobile','.p-account-order-pay .not_fully_paid_td','font-weight','700','','','.p-account-order-pay'),(127834,'printshop-mobile','.p-account-order-pay .historyTotal table tr:last-child td','font-weight','bold','','','.p-account-order-pay'),(127835,'printshop-mobile','.js-stock','font-weight','700','','',''),(127836,'printshop-mobile','.testimonials .heading-3','font-weight','400','3','',''),(127837,'printshop-mobile','.testimonials .name','font-weight','700','','',''),(127838,'printshop-mobile','.testimonials .rating','font-weight','400','','',''),(127839,'printshop-mobile','.testimonials .reviews-list .name','font-weight','700','','',''),(127840,'printshop-mobile','.testimonials .reviews-list span','font-weight','400','','',''),(127841,'printshop-mobile','.b-pagination .pagination span','font-weight','700','2','','.b-pagination'),(127842,'printshop-mobile','.p-blog-index .nav-links .screen-reader-text','font-weight','700','','','.p-blog-index'),(127843,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-2_2'),(127844,'printshop-mobile','.w-list-type-2 .title','font-weight','700','','','.w-list-type-2'),(127845,'printshop-mobile','.w-product-wedding-registry-button .btn','font-weight','700','','','.w-product-wedding-registry-button'),(127846,'printshop-mobile','.w-product-personal-catalog-button .btn','font-weight','normal','3','','.w-product-personal-catalog-button'),(127847,'printshop-mobile','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(127848,'printshop-mobile','.w-product-personal-catalog-button .btn','font-weight','700','','','.w-product-personal-catalog-button'),(127849,'printshop-mobile','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(127850,'printshop-mobile','.w-list-type-2_2 .button-view a','font-weight','700','','','.w-list-type-2_2'),(127851,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','font-weight','700','','','.w-list-type-2_2'),(127852,'printshop-mobile','.w-delivery-location-top-location-list .deliveryName a','font-weight','bold','','','.w-delivery-location-top-location-list'),(127853,'printshop-mobile','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(127854,'printshop-mobile','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(127855,'printshop-mobile','.b-bottom .alert-message','font-weight','bold','','','.b-bottom'),(127856,'printshop-mobile','.p-wedding-registry-manage .links a.share-registry','font-weight','600','','','.p-wedding-registry-manage'),(127857,'printshop-mobile','.p-wedding-registry-manage .wedding-date','font-weight','600','','','.p-wedding-registry-manage'),(127858,'printshop-mobile','.b-table .table .headings td','font-weight','600','','','.b-table'),(127859,'printshop-mobile','.b-pagination .pagination a','font-weight','700','','','.b-pagination'),(127860,'printshop-mobile','.p-account-history .order_history_table h2','font-weight','normal','','','.p-account-history'),(127861,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','font-weight','600','','','.b-switch'),(127862,'printshop-mobile','.b-bottom .popup-heading','font-weight','bold','','','.b-bottom'),(127863,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','font-weight','600','','','.b-switch'),(127864,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','font-weight','bold','','','.b-fancybox'),(127865,'printshop-mobile','.heading-2, h2','font-weight','400','','',''),(127866,'printshop-mobile','.p-account-index .ai_title','font-weight','bold','','','.p-account-index'),(127867,'printshop-mobile','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(127868,'printshop-mobile','.btn-2','font-weight','600','','',''),(127869,'printshop-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','font-weight','normal','','','.p-account-trade-form'),(127870,'printshop-mobile','.p-account-trade-form .widget h3','font-weight','normal','','','.p-account-trade-form'),(127871,'printshop-mobile','.p-checkout-index .same-address','font-weight','bold','','','.p-checkout-index'),(127872,'printshop-mobile','.p-quote-cart-index .cart-page .empty','font-weight','700','','','.p-quote-cart-index'),(127873,'printshop-mobile','.p-checkout-index .shipping-method .title','font-weight','bold','','','.p-checkout-index'),(127874,'printshop-mobile','.p-shopping-cart-index .cart-page .empty','font-weight','700','','','.p-shopping-cart-index'),(127875,'printshop-mobile','.w-currencies .currencies-title','font-weight','700','','','.w-currencies'),(127876,'printshop-mobile','.p-account-trade-form .address-wrapp b','font-weight','600','','','.p-account-trade-form'),(127877,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-weight','normal','','','.p-account-subscription-historyinfo'),(127878,'printshop-mobile','.p-reviews-info .review-info-reviewed_by','font-weight','bold','','','.p-reviews-info'),(127879,'printshop-mobile','.w-sale .left-text-left','font-weight','600','','','.w-sale'),(127880,'printshop-mobile','.w-sale .ends-date','font-weight','600','','','.w-sale'),(127881,'printshop-mobile','.p-account-history .not_fully_paid_td','font-weight','700','','','.p-account-history'),(127882,'printshop-mobile','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(127883,'printshop-mobile','.w-top-categories .categories h2','font-weight','inherit','','','.w-top-categories'),(127884,'printshop-mobile','.w-categories .categories h2','font-weight','inherit','','','.w-categories'),(127885,'printshop-mobile','.b-rating #stars-default .glyphicon','font-weight','400','','','.b-rating'),(127886,'printshop-mobile','.p-account-index .date_value strong','font-weight','normal','','','.p-account-index'),(127887,'printshop-mobile','.p-account-index .account_page h4','font-weight','normal','3','','.p-account-index'),(127888,'printshop-mobile','.p-account-index .account_info .info .info_span','font-weight','bold','','','.p-account-index'),(127889,'printshop-mobile','.b-form #payment_method .title','font-weight','bold','','','.b-form'),(127890,'printshop-mobile','.w-cart .strong','font-weight','400','','','.w-cart'),(127891,'printshop-mobile','.w-cart-give-away .ga_price','font-weight','700','','','.w-cart-give-away'),(127892,'printshop-mobile','.w-list-type-1_3 .sale','font-weight','600','4','','.w-list-type-1_3'),(127893,'printshop-mobile','.w-list-type-1_3 .title','font-weight','700','','','.w-list-type-1_3'),(127894,'printshop-mobile','.w-list-type-2 .button-view a','font-weight','700','','','.w-list-type-2'),(127895,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-2'),(127896,'printshop-mobile','.w-list-type-2 .sale','font-weight','600','4','','.w-list-type-2'),(127897,'printshop-mobile','.w-list-type-2 .button-wishlist button','font-weight','700','','','.w-list-type-2'),(127898,'printshop-mobile','h1','font-weight','400','','',''),(127899,'printshop-mobile','.w-currencies .select-link','font-weight','700','','','.w-currencies'),(127900,'printshop-mobile','.btn-1','font-weight','600','','',''),(127901,'printshop-mobile','.btn-3','font-weight','600','','',''),(127902,'printshop-mobile','.btn','font-weight','600','','',''),(127903,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-1_3'),(127904,'printshop-mobile','.w-list-type-1_3 .button-view a','font-weight','700','','','.w-list-type-1_3'),(127905,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','font-weight','700','','','.w-list-type-1_3'),(127906,'printshop-mobile','.w-list-type-1_2 .title','font-weight','700','','','.w-list-type-1_2'),(127907,'printshop-mobile','.w-list-type-1_2 .sale','font-weight','600','4','','.w-list-type-1_2'),(127908,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-1_2'),(127909,'printshop-mobile','.b-bottom .footerTitle','font-weight','700','','','.b-bottom'),(127910,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','font-weight','700','','','.w-list-type-1_2'),(127911,'printshop-mobile','.w-list-type-1_2 .button-view a','font-weight','700','','','.w-list-type-1_2'),(127912,'printshop-mobile','.w-list-type-1 .sale','font-weight','600','4','','.w-list-type-1'),(127913,'printshop-mobile','.heading-4 .right-text, h4 .right-text','font-weight','400','','',''),(127914,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-1'),(127915,'printshop-mobile','.heading-4 .edit, h4 .edit','font-weight','400','','',''),(127916,'printshop-mobile','.w-list-type-1 .button-wishlist button','font-weight','700','','','.w-list-type-1'),(127917,'printshop-mobile','.out-stock','font-weight','700','','',''),(127918,'printshop-mobile','.in-stock','font-weight','700','','',''),(127919,'printshop-mobile','.transit','font-weight','700','','',''),(127920,'printshop-mobile','.w-filters .view_more','font-weight','400','4','','.w-filters'),(127921,'printshop-mobile','.w-list-type-1 .button-view a','font-weight','700','','','.w-list-type-1'),(127922,'printshop-mobile','.w-reviews .reviews-list .name','font-weight','700','','','.w-reviews'),(127923,'printshop-mobile','.w-reviews .heading-3','font-weight','400','3','','.w-reviews'),(127924,'printshop-mobile','.w-reviews .rating','font-weight','400','','','.w-reviews'),(127925,'printshop-mobile','.w-reviews .reviews-list span','font-weight','400','','','.w-reviews'),(127926,'printshop-mobile','.p-account-history-info .historyTotal table tr:last-child td','font-weight','bold','','','.p-account-history-info'),(127927,'printshop-mobile','.p-account-address-book .address_book h2','font-weight','normal','','','.p-account-address-book'),(127928,'printshop-mobile','.b-info .info strong','font-weight','400','','','.b-info'),(127929,'printshop-mobile','.b-products-listing .products-listing .bonus-points span:first-child','font-weight','bold','','','.b-products-listing'),(127930,'printshop-mobile','.b-products-listing .products-listing .btn-buy','font-weight','400','3','','.b-products-listing'),(127931,'printshop-mobile','.b-products-listing .products-listing .name a','font-weight','bold','','','.b-products-listing'),(127932,'printshop-mobile','.b-products-listing .products-listing a.btn.view-button','font-weight','bold','','','.b-products-listing'),(127933,'printshop-mobile','.b-products-listing .products-listing h2','font-weight','inherit','','','.b-products-listing'),(127934,'printshop-mobile','.b-products-listing .promos-info .promo-name','font-weight','500','','','.b-products-listing'),(127935,'printshop-mobile','.b-products-listing .wedding-registry-count','font-weight','bold','','','.b-products-listing'),(127936,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.b-data-table'),(127937,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.b-data-table'),(127938,'printshop-mobile','.b-data-table table.dataTable thead td','font-weight','700','','','.b-data-table'),(127939,'printshop-mobile','.b-delete-account .delete-box .delete-message','font-weight','normal','','','.b-delete-account'),(127940,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-weight','inherit','','','.b-h-inline'),(127941,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','font-weight','600','','','.b-menu-style-1'),(127942,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','font-weight','600','','','.b-menu-style-1'),(127943,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','font-weight','600','','','.b-menu-style-2'),(127944,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','font-weight','600','','','.b-menu-style-2'),(127945,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-weight','600','','','.b-menu-style-2'),(127946,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-weight','300','3','','.b-menu-style-2'),(127947,'printshop-mobile','.b-messages span.starred::before','font-weight','normal','','','.b-messages'),(127948,'printshop-mobile','.b-messages .messMenuButton span','font-weight','600','','','.b-messages'),(127949,'printshop-mobile','.b-messages .messBtnMenuDelete','font-weight','normal','3','','.b-messages'),(127950,'printshop-mobile','.b-messages .messBtnMenuStarred','font-weight','normal','3','','.b-messages'),(127951,'printshop-mobile','.b-messages .messBtnMenuUnread','font-weight','normal','3','','.b-messages'),(127952,'printshop-mobile','.b-messages .messages-menu li a','font-weight','bold','2','','.b-messages'),(127953,'printshop-mobile','.b-messages .content_management_attach','font-weight','600','','','.b-messages'),(127954,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','font-weight','600','','','.b-messages'),(127955,'printshop-mobile','.b-personal-catalog-popup #personal_catalog_popup','font-weight','normal','','','.b-personal-catalog-popup'),(127956,'printshop-mobile','.b-select-suggest .select2-results li.select2-result-with-children > .select2-result-label','font-weight','bold','','','.b-select-suggest'),(127957,'printshop-mobile','.b-sub-totals .historyTotal table tr:last-child td','font-weight','bold','','','.b-sub-totals'),(127958,'printshop-mobile','.b-trade-approval .middle-form label','font-weight','600','','','.b-trade-approval'),(127959,'printshop-mobile','.b-warehouses-popup .warehouses-popup .heading','font-weight','bold','','','.b-warehouses-popup'),(127960,'printshop-mobile','.b-warehouses-popup a.warehouses-popup-link','font-weight','bold','','','.b-warehouses-popup'),(127961,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','font-weight','bold','','','.b-warehouses-popup'),(127962,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','font-weight','bold','','','.b-warehouses-popup'),(127963,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-name','font-weight','bold','','','.b-warehouses-popup'),(127964,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','font-weight','bold','','','.b-warehouses-popup'),(127965,'printshop-mobile','.batchPr .batch-selected-products-empty','font-weight','600','','','.batchPr'),(127966,'printshop-mobile','.batchPr .batch-selected-products-total','font-weight','600','','','.batchPr'),(127967,'printshop-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(127968,'printshop-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(127969,'printshop-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(127970,'printshop-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(127971,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','font-weight','700','','','.p-account-samples-history'),(127972,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','font-weight','700','','','.p-account-samples-history'),(127973,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','font-weight','700','','','.p-account-samples-history'),(127974,'printshop-mobile','.p-account-samples-history .order_history_table h2','font-weight','normal','','','.p-account-samples-history'),(127975,'printshop-mobile','.p-account-samples-history .order_history_table h2','font-weight','normal','','','.p-account-samples-history'),(127976,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','font-weight','700','','','.p-account-samples-history'),(127977,'printshop-mobile','.p-account-samples-history .order_history_table h2','font-weight','normal','','','.p-account-samples-history'),(127978,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','font-weight','700','','','.p-account-samples-history'),(127979,'printshop-mobile','.p-account-samples-history .order_history_table h2','font-weight','normal','','','.p-account-samples-history'),(127980,'printshop-mobile','.p-account-samples-history .order_history_table h2','font-weight','normal','','','.p-account-samples-history'),(127981,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','font-weight','700','','','.p-account-samples-history'),(127982,'printshop-mobile','.p-account-samples-history .order_history_table h2','font-weight','normal','','','.p-account-samples-history'),(127983,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','font-weight','700','','','.p-account-samples-history-info'),(127984,'printshop-mobile','.p-account-samples-history-info .trackings-nambers-label','font-weight','600','','','.p-account-samples-history-info'),(127985,'printshop-mobile','.p-account-samples-history-info .trackings-nambers-label','font-weight','600','','','.p-account-samples-history-info'),(127986,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','font-weight','700','','','.p-account-samples-history-info'),(127987,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-samples-history-info'),(127988,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-weight','normal','3','','.p-account-samples-history-info'),(127989,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-samples-history-info'),(127990,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-weight','normal','3','','.p-account-samples-history-info'),(127991,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-weight','normal','3','','.p-account-samples-history-info'),(127992,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-weight','normal','3','','.p-account-samples-history-info'),(127993,'printshop-mobile','.p-account-samples-history-info .trackings-nambers-label','font-weight','600','','','.p-account-samples-history-info'),(127994,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-samples-history-info'),(127995,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-weight','normal','3','','.p-account-samples-history-info'),(127996,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-weight','normal','3','','.p-account-samples-history-info'),(127997,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','font-weight','700','','','.p-account-samples-history-info'),(127998,'printshop-mobile','.p-account-samples-history-info .trackings-nambers-label','font-weight','600','','','.p-account-samples-history-info'),(127999,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','font-weight','700','','','.p-account-samples-history-info'),(128000,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','font-weight','700','','','.p-account-samples-history-info'),(128001,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','font-weight','700','','','.p-account-samples-history-info'),(128002,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-samples-history-info'),(128003,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-samples-history-info'),(128004,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-samples-history-info'),(128005,'printshop-mobile','.p-account-samples-history-info .trackings-nambers-label','font-weight','600','','','.p-account-samples-history-info'),(128006,'printshop-mobile','.p-account-samples-history-info .trackings-nambers-label','font-weight','600','','','.p-account-samples-history-info'),(128007,'printshop-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(128008,'printshop-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(128009,'printshop-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(128010,'printshop-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(128011,'printshop-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(128012,'printshop-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(128013,'printshop-mobile','.p-catalog-product .pn-direction','font-weight','600','','','.p-catalog-product'),(128014,'printshop-mobile','.p-payer-order-confirmation .cardinfo-label','font-weight','bold','','','.p-payer-order-confirmation'),(128015,'printshop-mobile','.p-payer-order-pay .cardinfo-label','font-weight','bold','','','.p-payer-order-pay'),(128016,'printshop-mobile','.p-quick-order-index .dataTables_info','font-weight','500','','','.p-quick-order-index'),(128017,'printshop-mobile','.p-quick-order-index .value','font-weight','bold','','','.p-quick-order-index'),(128018,'printshop-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-weight','600','','','.p-quick-order-index'),(128019,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.p-quick-order-index'),(128020,'printshop-mobile','.p-quick-order-index .filters label','font-weight','700','','','.p-quick-order-index'),(128021,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.p-quick-order-index'),(128022,'printshop-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(128023,'printshop-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(128024,'printshop-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(128025,'printshop-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(128026,'printshop-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(128027,'printshop-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(128028,'printshop-mobile','.w-account-address-book .name','font-weight','bold','','','.w-account-address-book'),(128029,'printshop-mobile','.w-account-address-book .address-buttons','font-weight','600','','','.w-account-address-book'),(128030,'printshop-mobile','.w-account-address-book .add_item a','font-weight','bold','','','.w-account-address-book'),(128031,'printshop-mobile','.w-blog-widget-post-listing .post_name','font-weight','400','','','.w-blog-widget-post-listing'),(128032,'printshop-mobile','.w-blog-widget-tag-cloud a','font-weight','700','','','.w-blog-widget-tag-cloud'),(128033,'printshop-mobile','.w-cart-bonus-points .title','font-weight','bold','','','.w-cart-bonus-points'),(128034,'printshop-mobile','.w-cart-compare .cart-name a','font-weight','600','','','.w-cart-compare'),(128035,'printshop-mobile','.w-cart-compare .atr-col','font-weight','normal','3','','.w-cart-compare'),(128036,'printshop-mobile','.w-cart-compare .js-cart_totals_container b','font-weight','600','','','.w-cart-compare'),(128037,'printshop-mobile','.w-cart-compare .atr-col','font-weight','600','','','.w-cart-compare'),(128038,'printshop-mobile','.w-cart-credit-amount .amount-title','font-weight','bold','','','.w-cart-credit-amount'),(128039,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-weight','normal','3','','.w-catalog-compare'),(128040,'printshop-mobile','.w-catalog-paging ','font-weight','700','2','','.w-catalog-paging'),(128041,'printshop-mobile','.w-checkout-billing-address .genders-title > div','font-weight','bold','','','.w-checkout-billing-address'),(128042,'printshop-mobile','.w-checkout-billing-address .btn-cancel','font-weight','500','','','.w-checkout-billing-address'),(128043,'printshop-mobile','.w-checkout-billing-address .add-ab','font-weight','500','','','.w-checkout-billing-address'),(128044,'printshop-mobile','.w-checkout-billing-address .edit-ab','font-weight','500','','','.w-checkout-billing-address'),(128045,'printshop-mobile','.w-checkout-bonus-points .title','font-weight','bold','','','.w-checkout-bonus-points'),(128046,'printshop-mobile','.w-checkout-contact-information .contact-info-buttons a','font-weight','500','','','.w-checkout-contact-information'),(128047,'printshop-mobile','.w-checkout-create-account .account-benefits strong','font-weight','normal','','','.w-checkout-create-account'),(128048,'printshop-mobile','.w-checkout-credit-amount .amount-title','font-weight','bold','','','.w-checkout-credit-amount'),(128049,'printshop-mobile','.w-checkout-shipping-address .change-ab','font-weight','500','','','.w-checkout-shipping-address'),(128050,'printshop-mobile','.w-checkout-shipping-address .genders-title > div','font-weight','bold','','','.w-checkout-shipping-address'),(128051,'printshop-mobile','.w-checkout-shipping-choice span','font-weight','600','','','.w-checkout-shipping-choice'),(128052,'printshop-mobile','.w-checkout-totals .ot_code_ot_subtotal','font-weight','bold','','','.w-checkout-totals'),(128053,'printshop-mobile','.w-communication-post .communication-post-author-name','font-weight','bold','','','.w-communication-post'),(128054,'printshop-mobile','.w-coupons-and-vauchers-checkout .title','font-weight','bold','','','.w-coupons-and-vauchers-checkout'),(128055,'printshop-mobile','.w-delayed-despatch-checkout .heading','font-weight','bold','','','.w-delayed-despatch-checkout'),(128056,'printshop-mobile','.w-delayed-despatch-checkout-confirm .heading','font-weight','bold','','','.w-delayed-despatch-checkout-confirm'),(128057,'printshop-mobile','.w-delayed-despatch-checkout-confirm .heading','font-weight','600','','','.w-delayed-despatch-checkout-confirm'),(128058,'printshop-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-weight','600','','','.w-delivery-day'),(128059,'printshop-mobile','.w-delivery-day .ends-date','font-weight','600','','','.w-delivery-day'),(128060,'printshop-mobile','.w-delivery-day .title','font-weight','bold','','','.w-delivery-day'),(128061,'printshop-mobile','.w-delivery-day .left-text-left','font-weight','600','','','.w-delivery-day'),(128062,'printshop-mobile','.w-delivery-day .left-text-right','font-weight','600','','','.w-delivery-day'),(128063,'printshop-mobile','.w-image-maps .categories-items .item .title','font-weight','700','','','.w-image-maps'),(128064,'printshop-mobile','.w-image-maps .float-items .item .title','font-weight','700','','','.w-image-maps'),(128065,'printshop-mobile','.w-image-maps .default-links .item .title','font-weight','700','','','.w-image-maps'),(128066,'printshop-mobile','.w-multi-cart-actions .cart-actions','font-weight','600','','','.w-multi-cart-actions'),(128067,'printshop-mobile','.w-multi-cart-cart-switcher .cart-label','font-weight','600','','','.w-multi-cart-cart-switcher'),(128068,'printshop-mobile','.w-multi-cart-cart-switcher .dropdown-menu a','font-weight','bold','','','.w-multi-cart-cart-switcher'),(128069,'printshop-mobile','.w-neighbour-checkout .text','font-weight','bold','','','.w-neighbour-checkout'),(128070,'printshop-mobile','.w-personal-gift-status-bar .end-date b','font-weight','bold','','','.w-personal-gift-status-bar'),(128071,'printshop-mobile','.w-personal-gift-status-bar .start-label','font-weight','bold','','','.w-personal-gift-status-bar'),(128072,'printshop-mobile','.w-personal-gift-status-bar .inform b','font-weight','bold','','','.w-personal-gift-status-bar'),(128073,'printshop-mobile','.w-personal-gift-status-bar .end-label','font-weight','bold','','','.w-personal-gift-status-bar'),(128074,'printshop-mobile','.w-product-available-in-warehouses .warehouse-name','font-weight','bold','','','.w-product-available-in-warehouses'),(128075,'printshop-mobile','.w-product-available-in-warehouses .heading','font-weight','bold','','','.w-product-available-in-warehouses'),(128076,'printshop-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(128077,'printshop-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(128078,'printshop-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(128079,'printshop-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(128080,'printshop-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(128081,'printshop-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(128082,'printshop-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(128083,'printshop-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(128084,'printshop-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(128085,'printshop-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(128086,'printshop-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(128087,'printshop-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(128088,'printshop-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(128089,'printshop-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(128090,'printshop-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(128091,'printshop-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(128092,'printshop-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(128093,'printshop-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(128094,'printshop-mobile','.w-promotions .prom-multi-discount .heading','font-weight','300','','','.w-promotions'),(128095,'printshop-mobile','.w-promotions .promo-cart-discount .master .heading','font-weight','300','','','.w-promotions'),(128096,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder .value','font-weight','bold','','','.w-promotions'),(128097,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty .value','font-weight','bold','','','.w-promotions'),(128098,'printshop-mobile','.w-promotions .promo-date','font-weight','500','','','.w-promotions'),(128099,'printshop-mobile','.w-promotions .promo-salemaker .promo-conditions','font-weight','300','','','.w-promotions'),(128100,'printshop-mobile','.w-promotions .promo-cart-discount .slave .heading','font-weight','300','','','.w-promotions'),(128101,'printshop-mobile','.w-promotions .promo-salemaker .discount .value','font-weight','700','','','.w-promotions'),(128102,'printshop-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading','font-weight','300','','','.w-promotions'),(128103,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range .value','font-weight','bold','','','.w-promotions'),(128104,'printshop-mobile','.w-promotions .heading-3','font-weight','bold','','','.w-promotions'),(128105,'printshop-mobile','.w-quote-products .empty','font-weight','700','','','.w-quote-products'),(128106,'printshop-mobile','.w-reviews-content .author','font-weight','bold','','','.w-reviews-content'),(128107,'printshop-mobile','.w-reviews-content .product-name a','font-weight','bold','','','.w-reviews-content'),(128108,'printshop-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','font-weight','normal','','','.w-taxable'),(128109,'printshop-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','font-weight','normal','','','.w-taxable'),(128110,'printshop-mobile','.w-wedding-registry-widgets-delete-link a','font-weight','normal','4','','.w-wedding-registry-widgets-delete-link'),(128111,'printshop-mobile','.w-wedding-registry-widgets-products .rating','font-weight','bold','','','.w-wedding-registry-widgets-products'),(128112,'printshop-mobile','.w-wedding-registry-widgets-share-link a','font-weight','normal','4','','.w-wedding-registry-widgets-share-link'),(128113,'printshop-mobile','.w-cart .qty','font_size_measure','em','4','','.w-cart'),(128114,'printshop-mobile','.w-cart .cart-total','font_size_measure','em','','','.w-cart'),(128115,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font_size_measure','em','4','','.b-multi-page-checkout'),(128116,'printshop-mobile','.w-quote .cart-box-link','font_size_measure','em','3','','.w-quote'),(128117,'printshop-mobile','.no-found','font_size_measure','em','','',''),(128118,'printshop-mobile','.view-all .btn','font_size_measure','em','4','',''),(128119,'printshop-mobile','.price .old','font_size_measure','em','','',''),(128120,'printshop-mobile','.b-select-suggest .select2-search input','font_size_measure','em','','','.b-select-suggest'),(128121,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font_size_measure','%','','','.b-select-suggest'),(128122,'printshop-mobile','.w-checkout-create-account .account-benefits','font_size_measure','em','','','.w-checkout-create-account'),(128123,'printshop-mobile','.w-promotions .prom-multi-discount .list','grid-auto-flow','dense','','','.w-promotions'),(128124,'printshop-mobile','.w-account-personal-catalog div .price','grid-column','4 / 5','','','.w-account-personal-catalog'),(128125,'printshop-mobile','.w-promotions .prom-multi-discount .promo-group-2','grid-column','span 2','','','.w-promotions'),(128126,'printshop-mobile','.w-promotions .prom-multi-discount .promo-group-3','grid-column','span 3','','','.w-promotions'),(128127,'printshop-mobile','.w-promotions .prom-multi-discount .promo-group-4','grid-column','span 4','','','.w-promotions'),(128128,'printshop-mobile','.w-reviews-content .product-name','grid-column','2/4','','','.w-reviews-content'),(128129,'printshop-mobile','.w-reviews-content .product-image','grid-column','1','','','.w-reviews-content'),(128130,'printshop-mobile','.w-reviews-content .review','grid-column','2/4','','','.w-reviews-content'),(128131,'printshop-mobile','.w-reviews-content .rating','grid-column','2','','','.w-reviews-content'),(128132,'printshop-mobile','.w-reviews-content .author','grid-column','2/4','','','.w-reviews-content'),(128133,'printshop-mobile','.w-reviews-content .date','grid-column','3','','','.w-reviews-content'),(128134,'printshop-mobile','.w-promotions .content','grid-column-end','3','','','.w-promotions'),(128135,'printshop-mobile','.w-promotions .content','grid-column-start','1','','','.w-promotions'),(128136,'printshop-mobile','.w-promotions .condition','grid-column-start','2','','','.w-promotions'),(128137,'printshop-mobile','.w-promotions .heading','grid-column-start','1','','','.w-promotions'),(128138,'printshop-mobile','.w-promotions .prom-multi-discount .products','grid-gap','4px','','','.w-promotions'),(128139,'printshop-mobile','.w-promotions .prom-multi-discount .list','grid-gap','20px','','','.w-promotions'),(128140,'printshop-mobile','.w-promotions .nextdiscount .content','grid-gap','3px','','','.w-promotions'),(128141,'printshop-mobile','.w-account-personal-catalog div .price','grid-row','1 / 2','','','.w-account-personal-catalog'),(128142,'printshop-mobile','.w-reviews-content .product-image','grid-row','1/6','','','.w-reviews-content'),(128143,'printshop-mobile','.w-reviews-content .product-name','grid-row','2','','','.w-reviews-content'),(128144,'printshop-mobile','.w-reviews-content .review','grid-row','3','','','.w-reviews-content'),(128145,'printshop-mobile','.w-reviews-content .date','grid-row','1','','','.w-reviews-content'),(128146,'printshop-mobile','.w-reviews-content .author','grid-row','4','','','.w-reviews-content'),(128147,'printshop-mobile','.w-reviews-content .rating','grid-row','1','','','.w-reviews-content'),(128148,'printshop-mobile','.w-promotions .heading','grid-row-start','1','','','.w-promotions'),(128149,'printshop-mobile','.w-promotions .condition','grid-row-start','1','','','.w-promotions'),(128150,'printshop-mobile','.w-promotions .content','grid-row-start','2','','','.w-promotions'),(128151,'printshop-mobile','.w-promotions .nextdiscount .content','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(128152,'printshop-mobile','.w-promotions .prom-multi-discount .promo-group-4 .products','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(128153,'printshop-mobile','.w-promotions .prom-multi-discount .products','grid-template-columns','1fr','','','.w-promotions'),(128154,'printshop-mobile','.w-promotions .prom-multi-discount .promo-group-3 .products','grid-template-columns','1fr 1fr 1fr','','','.w-promotions'),(128155,'printshop-mobile','.w-promotions .prom-multi-discount .promo-group-2 .products','grid-template-columns','1fr 1fr','','','.w-promotions'),(128156,'printshop-mobile','.w-promotions .prom-multi-discount .list','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(128157,'printshop-mobile','.w-reviews-content .item','grid-template-columns','170px 1fr 1fr','','','.w-reviews-content'),(128158,'printshop-mobile','.w-bestsellers .item','height','32','3','','.w-bestsellers'),(128159,'printshop-mobile','.b-fancybox .fancybox-close','height','36','','','.b-fancybox'),(128160,'printshop-mobile','.w-bestsellers .counter','height','32','','','.w-bestsellers'),(128161,'printshop-mobile','.b-switch .bootstrap-switch','height','28','','','.b-switch'),(128162,'printshop-mobile','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(128163,'printshop-mobile','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(128164,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','height','18','','','.b-form'),(128165,'printshop-mobile','.b-form .checkbox-style:checked + .checkbox-span','height','18','','','.b-form'),(128166,'printshop-mobile','.w-menu-slider .menu-ico','height','54','','','.w-menu-slider'),(128167,'printshop-mobile','.w-menu-horizontal .menu-ico','height','54','','','.w-menu-horizontal'),(128168,'printshop-mobile','.w-list-type-2_2 .sale','height','19','4','','.w-list-type-2_2'),(128169,'printshop-mobile','.w-sale .badge','height','80','','','.w-sale'),(128170,'printshop-mobile','.w-menu-style-1 .menu-ico','height','48','','','.w-menu-style-1'),(128171,'printshop-mobile','.w-menu-mobile .menu-slider .open','height','100','','','.w-menu-mobile'),(128172,'printshop-mobile','.w-product-wedding-registry-button .btn','height','18','3','','.w-product-wedding-registry-button'),(128173,'printshop-mobile','.w-product-wedding-registry-button .btn','height','18','4','','.w-product-wedding-registry-button'),(128174,'printshop-mobile','.w-compare-box-item .checkbox','height','22','','','.w-compare-box-item'),(128175,'printshop-mobile','.w-compare-box-item .checkbox + span','height','24','','','.w-compare-box-item'),(128176,'printshop-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','height','auto','','','.b-product-images'),(128177,'printshop-mobile','.w-catalog-listing-look .list','height','31','','','.w-catalog-listing-look'),(128178,'printshop-mobile','.w-catalog-listing-look .b2b','height','31','','','.w-catalog-listing-look'),(128179,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','height','35','3','','.b-multi-page-checkout'),(128180,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','height','35','','','.p-blog-index'),(128181,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','height','33','','','.b-multi-page-checkout'),(128182,'printshop-mobile','.b-pagination .pagination .prev','height','30','','','.b-pagination'),(128183,'printshop-mobile','.b-pagination .pagination .prev-pages','height','30','','','.b-pagination'),(128184,'printshop-mobile','.p-wedding-registry-manage .wr-search button','height','30','','','.p-wedding-registry-manage'),(128185,'printshop-mobile','.b-pagination .pagination .page-number','height','30','','','.b-pagination'),(128186,'printshop-mobile','.b-pagination .pagination .next-pages','height','30','','','.b-pagination'),(128187,'printshop-mobile','.b-pagination .pagination .next','height','30','','','.b-pagination'),(128188,'printshop-mobile','.b-pagination .pagination span','height','30','2','','.b-pagination'),(128189,'printshop-mobile','.p-account-history .orders-table .td-alignright','height','45','720','','.p-account-history'),(128190,'printshop-mobile','.p-account-index .orders-table .td-alignright','height','45','720','','.p-account-index'),(128191,'printshop-mobile','.w-list-type-2_2 .sale','height','19','3','','.w-list-type-2_2'),(128192,'printshop-mobile','.w-list-type-2_2 .sale','height','19','','','.w-list-type-2_2'),(128193,'printshop-mobile','.w-list-type-2 .sale','height','19','3','','.w-list-type-2'),(128194,'printshop-mobile','.w-list-type-2 .sale','height','19','','','.w-list-type-2'),(128195,'printshop-mobile','.w-list-type-2 .sale','height','19','4','','.w-list-type-2'),(128196,'printshop-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height','100','','','.b-fancybox'),(128197,'printshop-mobile','.b-fancybox .fancybox-nav','height','100','','','.b-fancybox'),(128198,'printshop-mobile','.w-product-promotions select','height','29','','','.w-product-promotions'),(128199,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','height','30','3','','.b-form'),(128200,'printshop-mobile','.b-pagination .pagination a','height','30','','','.b-pagination'),(128201,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','height','20','3','','.b-switch'),(128202,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','height','20','3','','.b-switch'),(128203,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','height','28','','','.b-switch'),(128204,'printshop-mobile','.w-list-type-1 .image img','height','auto','','','.w-list-type-1'),(128205,'printshop-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','height','40','','','.b-quantity'),(128206,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','height','40','','','.b-slick'),(128207,'printshop-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height','100','','','.w-banner'),(128208,'printshop-mobile','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height','100','','','.w-banner'),(128209,'printshop-mobile','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height','100','','','.w-banner'),(128210,'printshop-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','height','24','','','.w-filters'),(128211,'printshop-mobile','.w-filters .input-checkbox:checked + .checkbox-span','height','24','','','.w-filters'),(128212,'printshop-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','height','22','','','.w-compare-box-item'),(128213,'printshop-mobile','.b-slick .slick-vertical .slick-slide','height','auto','','','.b-slick'),(128214,'printshop-mobile','.b-info-popup .info-popup','height','2','','','.b-info-popup'),(128215,'printshop-mobile','.b-info-popup .info-popup div','height','20','3','','.b-info-popup'),(128216,'printshop-mobile','.w-menu-mobile .menu-ico','height','48','','','.w-menu-mobile'),(128217,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','height','50','706','','.b-slick'),(128218,'printshop-mobile','.w-banner .carousel-text','height','100','','','.w-banner'),(128219,'printshop-mobile','.b-slick .slick-slide','height','100','','','.b-slick'),(128220,'printshop-mobile','.b-quantity .qty-box .smaller','height','35','','','.b-quantity'),(128221,'printshop-mobile','.b-quantity .qty-box .bigger','height','35','','','.b-quantity'),(128222,'printshop-mobile','.b-fancybox #fancybox-loading div','height','44','','','.b-fancybox'),(128223,'printshop-mobile','.w-product-images .item-div','height','80','723','','.w-product-images'),(128224,'printshop-mobile','.b-fancybox .fancybox-nav span','height','40','','','.b-fancybox'),(128225,'printshop-mobile','.w-product-images .item','height','80','723','','.w-product-images'),(128226,'printshop-mobile','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','height','25','','','.b-datepicker'),(128227,'printshop-mobile','.w-catalog-listing-look .grid','height','31','','','.w-catalog-listing-look'),(128228,'printshop-mobile','.w-list-type-1_3 .sale','height','19','4','','.w-list-type-1_3'),(128229,'printshop-mobile','.w-list-type-1_3 .sale','height','19','','','.w-list-type-1_3'),(128230,'printshop-mobile','.w-list-type-1_3 .sale','height','19','3','','.w-list-type-1_3'),(128231,'printshop-mobile','.b-autocomplete .ui-autocomplete','height','300','','','.b-autocomplete'),(128232,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','height','40','','',''),(128233,'printshop-mobile','.w-list-type-1_2 .sale','height','19','3','','.w-list-type-1_2'),(128234,'printshop-mobile','.w-list-type-1_2 .sale','height','19','4','','.w-list-type-1_2'),(128235,'printshop-mobile','.w-list-type-1_2 .sale','height','19','','','.w-list-type-1_2'),(128236,'printshop-mobile','.b-bottom .pop-up-close','height','31','','','.b-bottom'),(128237,'printshop-mobile','.w-list-type-1 .sale','height','19','4','','.w-list-type-1'),(128238,'printshop-mobile','.w-list-type-1 .sale','height','19','','','.w-list-type-1'),(128239,'printshop-mobile','.w-list-type-1 .sale','height','19','3','','.w-list-type-1'),(128240,'printshop-mobile','.w-filters .ui-slider','height','7','','','.w-filters'),(128241,'printshop-mobile','.w-filters .ui-slider-range','height','6','','','.w-filters'),(128242,'printshop-mobile','.w-filters .ui-slider-handle','height','18','','','.w-filters'),(128243,'printshop-mobile','.w-search .button-search','height','48','','','.w-search'),(128244,'printshop-mobile','.w-search .image','height','40','','','.w-search'),(128245,'printshop-mobile','.b-form .hide-billing-address','height','100','','','.b-form'),(128246,'printshop-mobile','.b-products-listing .btn-preloader','height','24','3','','.b-products-listing'),(128247,'printshop-mobile','.b-products-listing .hover-box-content','height','20','3','','.b-products-listing'),(128248,'printshop-mobile','.b-products-listing .loader','height','30','4','','.b-products-listing'),(128249,'printshop-mobile','.b-products-listing .loader','height','100','3','','.b-products-listing'),(128250,'printshop-mobile','.b-products-listing .products-listing .qty-input.hidden','height','100','3','','.b-products-listing'),(128251,'printshop-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','height','auto','','','.b-products-listing'),(128252,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.b-data-table'),(128253,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.b-data-table'),(128254,'printshop-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(128255,'printshop-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(128256,'printshop-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(128257,'printshop-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(128258,'printshop-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(128259,'printshop-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(128260,'printshop-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','height','30','','','.b-menu-burger_icon'),(128261,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(128262,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(128263,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(128264,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(128265,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(128266,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height','100','','','.b-menu-open_from-left'),(128267,'printshop-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(128268,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','height','28','','','.b-menu-style-2'),(128269,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','height','50','','','.b-menu-style-2'),(128270,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','height','24','','','.b-menu-style-2'),(128271,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','height','16','3','','.b-menu-style-2'),(128272,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','height','28','','','.b-menu-style-2'),(128273,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','height','16','3','','.b-menu-style-2'),(128274,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','height','24','','','.b-menu-style-2'),(128275,'printshop-mobile','.b-messages .select2-container-multi input.select2-input','height','31','','','.b-messages'),(128276,'printshop-mobile','.b-preloader .preloader','height','100','','','.b-preloader'),(128277,'printshop-mobile','.b-preloader .preloader','height','40','3','','.b-preloader'),(128278,'printshop-mobile','.b-select-suggest .select2-search input','height','auto','','','.b-select-suggest'),(128279,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height','100','','','.b-select-suggest'),(128280,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height','1','','','.b-select-suggest'),(128281,'printshop-mobile','.b-select-suggest .select2-drop-mask','height','auto','','','.b-select-suggest'),(128282,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','height','12','','','.b-select-suggest'),(128283,'printshop-mobile','.b-select-suggest .select2-measure-scrollbar','height','100','','','.b-select-suggest'),(128284,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','height','100','','','.b-select-suggest'),(128285,'printshop-mobile','.b-select-suggest .select2-search-choice-close','height','13','','','.b-select-suggest'),(128286,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','height','35','','','.b-select-suggest'),(128287,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','height','35','','','.b-trade-approval'),(128288,'printshop-mobile','.b-upload-file .snapshot','height','38','','','.b-upload-file'),(128289,'printshop-mobile','.b-upload-file .upload-file-template','height','150','','','.b-upload-file'),(128290,'printshop-mobile','.batchPr .checkbox input + span','height','36','','','.batchPr'),(128291,'printshop-mobile','.batchPr .batchSelect .checkbox','height','36','','','.batchPr'),(128292,'printshop-mobile','.batchPr .checkbox input + span','height','32','','','.batchPr'),(128293,'printshop-mobile','.batchPr .batch-selected-products-list','height','304','','','.batchPr'),(128294,'printshop-mobile','.batchPr .checkbox input:not(checked) + span:before','height','30','','','.batchPr'),(128295,'printshop-mobile','.batchPr .btn-batch-remove','height','20','','','.batchPr'),(128296,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','height','45','','','.p-account-samples-history'),(128297,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','height','45','','','.p-account-samples-history'),(128298,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','height','45','','','.p-account-samples-history'),(128299,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','height','45','','','.p-account-samples-history'),(128300,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','height','45','','','.p-account-samples-history'),(128301,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','height','45','','','.p-account-samples-history'),(128302,'printshop-mobile','.p-catalog-product .pn-image','height','24','3','','.p-catalog-product'),(128303,'printshop-mobile','.p-payer-order-confirmation .input-wrapper','height','35','','','.p-payer-order-confirmation'),(128304,'printshop-mobile','.p-payer-order-pay .input-wrapper','height','35','','','.p-payer-order-pay'),(128305,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.p-quick-order-index'),(128306,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.p-quick-order-index'),(128307,'printshop-mobile','.w-account-address-book .wrap','height','100','','','.w-account-address-book'),(128308,'printshop-mobile','.w-account-address-book .add_item a','height','100','','','.w-account-address-book'),(128309,'printshop-mobile','.w-account-subscription .info-popup','height','15','','','.w-account-subscription'),(128310,'printshop-mobile','.w-blog-widget-post-share ','height','26','4','','.w-blog-widget-post-share'),(128311,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','height','35','','','.w-blog-widget-related-posts'),(128312,'printshop-mobile','.w-catalog-compare span.btn-preloader','height','24','','','.w-catalog-compare'),(128313,'printshop-mobile','.w-catalog-paging .prev','height','30','','','.w-catalog-paging'),(128314,'printshop-mobile','.w-catalog-paging .paging-holder','height','30','','','.w-catalog-paging'),(128315,'printshop-mobile','.w-catalog-paging ','height','30','2','','.w-catalog-paging'),(128316,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height','30','','','.w-catalog-paging'),(128317,'printshop-mobile','.w-catalog-paging .next','height','30','','','.w-catalog-paging'),(128318,'printshop-mobile','.w-catalog-paging .page-number','height','30','','','.w-catalog-paging'),(128319,'printshop-mobile','.w-catalog-paging .next-pages','height','30','','','.w-catalog-paging'),(128320,'printshop-mobile','.w-catalog-paging .prev-pages','height','30','','','.w-catalog-paging'),(128321,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','height','10','','','.w-checkout-shipping-choice'),(128322,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','height','30','','','.w-communication-new-topic'),(128323,'printshop-mobile','.w-communication-new-topic #communication_group_holder select','height','35','','','.w-communication-new-topic'),(128324,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','height','36','','','.w-communication-new-topic'),(128325,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','height','36','','','.w-communication-new-topic'),(128326,'printshop-mobile','.w-image-maps .svg-wrap svg','height','100','','','.w-image-maps'),(128327,'printshop-mobile','.w-personal-gift-status-bar .progress-bar','height','8','','','.w-personal-gift-status-bar'),(128328,'printshop-mobile','.w-personal-gift-status-bar .progress-bar-content','height','8','','','.w-personal-gift-status-bar'),(128329,'printshop-mobile','.w-product-customers-activity .close','height','30','','','.w-product-customers-activity'),(128330,'printshop-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(128331,'printshop-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(128332,'printshop-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(128333,'printshop-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(128334,'printshop-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(128335,'printshop-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(128336,'printshop-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(128337,'printshop-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(128338,'printshop-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(128339,'printshop-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(128340,'printshop-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(128341,'printshop-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(128342,'printshop-mobile','.w-promotions .prom-multi-discount .products','height','calc(100% - 25px)','','','.w-promotions'),(128343,'printshop-mobile','.w-promotions .prom-multi-discount .image img','height','auto','','','.w-promotions'),(128344,'printshop-mobile','.w-promotions .promo-cart-discount .image img','height','auto','','','.w-promotions'),(128345,'printshop-mobile','.w-promotions .promo-salemaker .image img','height','auto','','','.w-promotions'),(128346,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','height','150','','','.w-upload-customer-id-upload-customer-id-form'),(128347,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','height','100','','','.w-upload-customer-id-upload-customer-id-form'),(128348,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','height','144','','','.w-wedding-registry-widgets-photos'),(128349,'printshop-mobile','.w-wedding-registry-widgets-photos .upload-file-template','height','144','','','.w-wedding-registry-widgets-photos'),(128350,'printshop-mobile','.b-quantity .qty-box input[type=\'text\']','height','40','','','.b-quantity'),(128351,'printshop-mobile','.b-select-suggest .select2-search input','height_important','important','','','.b-select-suggest'),(128352,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height_important','important','','','.b-select-suggest'),(128353,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height_important','important','','','.w-catalog-paging'),(128354,'printshop-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height_measure','%','','','.b-fancybox'),(128355,'printshop-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height_measure','%','','','.w-banner'),(128356,'printshop-mobile','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height_measure','%','','','.w-banner'),(128357,'printshop-mobile','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height_measure','%','','','.w-banner'),(128358,'printshop-mobile','.w-menu-mobile .menu-slider .open','height_measure','vh','','','.w-menu-mobile'),(128359,'printshop-mobile','.w-banner .carousel-text','height_measure','%','','','.w-banner'),(128360,'printshop-mobile','.b-slick .slick-slide','height_measure','%','','','.b-slick'),(128361,'printshop-mobile','.b-fancybox .fancybox-nav','height_measure','%','','','.b-fancybox'),(128362,'printshop-mobile','.b-form .hide-billing-address','height_measure','%','','','.b-form'),(128363,'printshop-mobile','.b-products-listing .loader','height_measure','%','3','','.b-products-listing'),(128364,'printshop-mobile','.b-products-listing .products-listing .qty-input.hidden','height_measure','%','3','','.b-products-listing'),(128365,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height_measure','vh','','','.b-menu-open_from-left'),(128366,'printshop-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(128367,'printshop-mobile','.b-preloader .preloader','height_measure','%','','','.b-preloader'),(128368,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height_measure','%','','','.b-select-suggest'),(128369,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','height_measure','%','','','.b-select-suggest'),(128370,'printshop-mobile','.w-account-address-book .wrap','height_measure','%','','','.w-account-address-book'),(128371,'printshop-mobile','.w-account-address-book .add_item a','height_measure','%','','','.w-account-address-book'),(128372,'printshop-mobile','.w-image-maps .svg-wrap svg','height_measure','%','','','.w-image-maps'),(128373,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(128374,'printshop-mobile','.personal-buttons > div','justify-content','space-around','','','.personal-buttons'),(128375,'printshop-mobile','.w-banner .carousel .top-right','justify-content','flex-end','','','.w-banner'),(128376,'printshop-mobile','.w-banner .carousel .top-center','justify-content','center','','','.w-banner'),(128377,'printshop-mobile','.w-banner .carousel .middle-center','justify-content','center','','','.w-banner'),(128378,'printshop-mobile','.w-banner .carousel .bottom-left','justify-content','flex-start','','','.w-banner'),(128379,'printshop-mobile','.w-banner .carousel .bottom-center','justify-content','center','','','.w-banner'),(128380,'printshop-mobile','.w-banner .carousel .top-left','justify-content','flex-start','','','.w-banner'),(128381,'printshop-mobile','.w-banner .carousel .middle-right','justify-content','flex-end','','','.w-banner'),(128382,'printshop-mobile','.w-banner .carousel .bottom-right','justify-content','flex-end','','','.w-banner'),(128383,'printshop-mobile','.w-banner .carousel .middle-left','justify-content','flex-start','','','.w-banner'),(128384,'printshop-mobile','.b-products-listing .products-listing .attribute-qty-blocks','justify-content','space-between','','','.b-products-listing'),(128385,'printshop-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(128386,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','justify-content','space-between','','','.b-menu-style-1'),(128387,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(128388,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(128389,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(128390,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(128391,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(128392,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(128393,'printshop-mobile','.p-quick-order-index .quick-order-total','justify-content','space-between','','','.p-quick-order-index'),(128394,'printshop-mobile','.w-account-address-book .wrap','justify-content','space-between','','','.w-account-address-book'),(128395,'printshop-mobile','.w-account-address-book .add_item a','justify-content','center','','','.w-account-address-book'),(128396,'printshop-mobile','.w-catalog-compare .cross-box','justify-content','flex-end','','','.w-catalog-compare'),(128397,'printshop-mobile','.w-checkout-shipping-choice span','justify-content','center','','','.w-checkout-shipping-choice'),(128398,'printshop-mobile','.w-communication-post .communication-post-author','justify-content','space-between','','','.w-communication-post'),(128399,'printshop-mobile','.w-personal-gift-status-bar .timeline','justify-content','center','','','.w-personal-gift-status-bar'),(128400,'printshop-mobile','.w-promotions .prom-multi-discount .products','justify-content','space-between','','','.w-promotions'),(128401,'printshop-mobile','.w-promotions .promo-salemaker .content','justify-content','center','','','.w-promotions'),(128402,'printshop-mobile','.w-promotions .promo-cart-discount .content','justify-content','center','','','.w-promotions'),(128403,'printshop-mobile','.w-menu-horizontal > ul > li > ul','left','0','','','.w-menu-horizontal'),(128404,'printshop-mobile','.w-menu-slider > ul > li > ul','left','0','','','.w-menu-slider'),(128405,'printshop-mobile','.w-menu-big > ul > li > ul','left','0','','','.w-menu-big'),(128406,'printshop-mobile','.w-bestsellers .heading-3','left','0','3','','.w-bestsellers'),(128407,'printshop-mobile','.w-menu-style-1 > ul > li > ul','left','0','','','.w-menu-style-1'),(128408,'printshop-mobile','.w-sale .badge','left','10','','','.w-sale'),(128409,'printshop-mobile','.w-product-wedding-registry-button .btn','left','0','3','','.w-product-wedding-registry-button'),(128410,'printshop-mobile','.w-product-wedding-registry-button .btn','left','13','4','','.w-product-wedding-registry-button'),(128411,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','left','1','3','','.p-account-history-info'),(128412,'printshop-mobile','.p-account-index .not_fully_paid_td','left','15','','','.p-account-index'),(128413,'printshop-mobile','.p-account-history-info .not_fully_paid_td','left','15','','','.p-account-history-info'),(128414,'printshop-mobile','.w-product-reviews .reviews-list .review','left','10','3','','.w-product-reviews'),(128415,'printshop-mobile','.p-account-index .topAccount > li > div','left','0','693,3','','.p-account-index'),(128416,'printshop-mobile','.b-info-popup .info-popup div','left','40','','','.b-info-popup'),(128417,'printshop-mobile','.w-promo-code .holder','left','12','723,3','','.w-promo-code'),(128418,'printshop-mobile','.w-menu-mobile .menu-slider .open','left','0','','','.w-menu-mobile'),(128419,'printshop-mobile','.b-info-popup .info-popup.top-left div','left','auto','','','.b-info-popup'),(128420,'printshop-mobile','.b-info-popup .info-popup.top-left div','left','auto','3','','.b-info-popup'),(128421,'printshop-mobile','.w-promo-code .holder','left','20','3','','.w-promo-code'),(128422,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2.title-delivery-address, .p-account-order-pay .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-order-pay'),(128423,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','left','1','3','','.p-account-order-pay'),(128424,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2.title-payment','left','10','3','','.p-account-order-pay'),(128425,'printshop-mobile','.p-account-order-pay .not_fully_paid_td','left','15','','','.p-account-order-pay'),(128426,'printshop-mobile','.testimonials .review','left','10','3','',''),(128427,'printshop-mobile','.testimonials .heading-3','left','0','3','',''),(128428,'printshop-mobile','.p-account-history .orders-table .status-name','left','0','720','','.p-account-history'),(128429,'printshop-mobile','.p-account-history .orders-table .td-alignright','left','0','720','','.p-account-history'),(128430,'printshop-mobile','.p-account-index .orders-table .status-name','left','0','720','','.p-account-index'),(128431,'printshop-mobile','.p-account-index .orders-table .td-alignright','left','0','720','','.p-account-index'),(128432,'printshop-mobile','.w-product-personal-catalog-button .btn','left','0','3','','.w-product-personal-catalog-button'),(128433,'printshop-mobile','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(128434,'printshop-mobile','.p-wedding-registry-index .search-list','left','50','3','','.p-wedding-registry-index'),(128435,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no','left','-100','','','.b-form'),(128436,'printshop-mobile','.p-wedding-registry-search h1','left','-10','3','','.p-wedding-registry-search'),(128437,'printshop-mobile','.p-wedding-registry-manage h1','left','-10','3','','.p-wedding-registry-manage'),(128438,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','left','2','3','','.b-switch'),(128439,'printshop-mobile','.w-filters .ui-slider','left','14','','','.w-filters'),(128440,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','left','2','3','','.b-switch'),(128441,'printshop-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','left','0','','','.b-switch'),(128442,'printshop-mobile','.b-slick button.slick-next','left','auto','','','.b-slick'),(128443,'printshop-mobile','.b-slick button.slick-prev','left','0','','','.b-slick'),(128444,'printshop-mobile','.w-search .search form','left','-25','','','.w-search'),(128445,'printshop-mobile','.w-search .suggest','left','-25','','','.w-search'),(128446,'printshop-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','left','0','','','.w-banner'),(128447,'printshop-mobile','.w-banner .image-text-banner.top-left .text-banner','left','0','','','.w-banner'),(128448,'printshop-mobile','.w-banner .image-text-banner.bottom-left .text-banner','left','0','','','.w-banner'),(128449,'printshop-mobile','.w-banner .banner img + img','left','0','','','.w-banner'),(128450,'printshop-mobile','.w-currencies .select','left','0','','','.w-currencies'),(128451,'printshop-mobile','.b-slick .slick-track','left','0','','','.b-slick'),(128452,'printshop-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left','50','','','.b-slick'),(128453,'printshop-mobile','.p-checkout-success .page-success','left','0','3','','.p-checkout-success'),(128454,'printshop-mobile','.b-info-popup .info-popup div','left','-11','3','','.b-info-popup'),(128455,'printshop-mobile','.b-fancybox .fancybox-title-over-wrap','left','0','','','.b-fancybox'),(128456,'printshop-mobile','.b-fancybox .fancybox-tmp','left','-99999','','','.b-fancybox'),(128457,'printshop-mobile','.b-fancybox .fancybox-wrap','left','0','','','.b-fancybox'),(128458,'printshop-mobile','.b-fancybox .fancybox-prev span','left','10','','','.b-fancybox'),(128459,'printshop-mobile','.b-fancybox .fancybox-overlay','left','0','','','.b-fancybox'),(128460,'printshop-mobile','.b-fancybox .fancybox-prev','left','0','','','.b-fancybox'),(128461,'printshop-mobile','.p-account-history .not_fully_paid_td','left','15','','','.p-account-history'),(128462,'printshop-mobile','.w-text .customer-service','left','0','3','','.w-text'),(128463,'printshop-mobile','.w-banner .carousel-text','left','0','','','.w-banner'),(128464,'printshop-mobile','.p-reviews-info .review-info-text','left','11','4','','.p-reviews-info'),(128465,'printshop-mobile','.p-account-index .account_page h4','left','9','3','','.p-account-index'),(128466,'printshop-mobile','.b-form .hide-billing-address','left','0','','','.b-form'),(128467,'printshop-mobile','.b-fancybox #fancybox-loading','left','50','','','.b-fancybox'),(128468,'printshop-mobile','.view-all','left','0','3','',''),(128469,'printshop-mobile','.p-wedding-registry-share h1','left','-10','3','','.p-wedding-registry-share'),(128470,'printshop-mobile','.p-wedding-registry-view h1','left','-10','3','','.p-wedding-registry-view'),(128471,'printshop-mobile','.w-languages .select','left','-1','','','.w-languages'),(128472,'printshop-mobile','.w-reviews .review','left','10','3','','.w-reviews'),(128473,'printshop-mobile','.w-reviews .heading-3','left','0','3','','.w-reviews'),(128474,'printshop-mobile','.p-account-history-info .historyInfoColumn h2.title-delivery-address, .p-account-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-history-info'),(128475,'printshop-mobile','.p-account-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-history-info'),(128476,'printshop-mobile','.p-account-address-book .buttonBox .info','left','-6','3','','.p-account-address-book'),(128477,'printshop-mobile','.b-products-listing .hover-box-content','left','20','3','','.b-products-listing'),(128478,'printshop-mobile','.b-products-listing .hover-box-content','left','0','','','.b-products-listing'),(128479,'printshop-mobile','.b-products-listing .loader','left','calc(50% - 15px)','4','','.b-products-listing'),(128480,'printshop-mobile','.b-products-listing .loader','left','0','3','','.b-products-listing'),(128481,'printshop-mobile','.b-products-listing .products-listing .promos-info','left','0','','','.b-products-listing'),(128482,'printshop-mobile','.b-products-listing .products-listing .qty-input.hidden','left','0','3','','.b-products-listing'),(128483,'printshop-mobile','.b-products-listing .promo','left','0','','','.b-products-listing'),(128484,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(128485,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(128486,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(128487,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(128488,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(128489,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(128490,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','left','0','','','.b-menu-lev_display-down'),(128491,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','left','0','','','.b-menu-lev_display-down'),(128492,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','left','0','','','.b-menu-lev_display-down'),(128493,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','left','0','','','.b-menu-lev_display-down'),(128494,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','left','0','','','.b-menu-lev_display-down'),(128495,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left','100','','','.b-menu-lev_display-lra'),(128496,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left','100','','','.b-menu-lev_display-lra'),(128497,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left','100','','','.b-menu-lev_display-lra'),(128498,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left','100','','','.b-menu-lev_display-lra'),(128499,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left','100','','','.b-menu-lev_display-lra'),(128500,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','left','auto','','','.b-menu-lev_display-lra'),(128501,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','left','auto','','','.b-menu-lev_display-lra'),(128502,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','left','auto','','','.b-menu-lev_display-lra'),(128503,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','left','auto','','','.b-menu-lev_display-lra'),(128504,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','left','auto','','','.b-menu-lev_display-lra'),(128505,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left','100','','','.b-menu-lev_display-right'),(128506,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left','100','','','.b-menu-lev_display-right'),(128507,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left','100','','','.b-menu-lev_display-right'),(128508,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left','100','','','.b-menu-lev_display-right'),(128509,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left','100','','','.b-menu-lev_display-right'),(128510,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left','100','','','.b-menu-lev_display-slide'),(128511,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left','100','','','.b-menu-lev_display-slide'),(128512,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left','100','','','.b-menu-lev_display-slide'),(128513,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left','100','','','.b-menu-lev_display-slide'),(128514,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left','100','','','.b-menu-lev_display-slide'),(128515,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left','-110','','','.b-menu-open_from-left'),(128516,'printshop-mobile','.b-menu-open_from-left .bi-opened .menu-style[data-open_from=\"left\"] .menu-content','left','0','','','.b-menu-open_from-left'),(128517,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','left','0','','','.b-menu-style-1'),(128518,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','left','0','','','.b-menu-style-2'),(128519,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','left','0','','','.b-menu-style-2'),(128520,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','left','20','3','','.b-menu-style-2'),(128521,'printshop-mobile','.b-preloader .preloader','left','0','','','.b-preloader'),(128522,'printshop-mobile','.b-preloader .preloader','left','calc(50% - 20px)','3','','.b-preloader'),(128523,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-search-choice-close','left','3','','','.b-select-suggest'),(128524,'printshop-mobile','.b-select-suggest .select2-drop-mask','left','0','','','.b-select-suggest'),(128525,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left','0','','','.b-select-suggest'),(128526,'printshop-mobile','.b-select-suggest .select2-measure-scrollbar','left','-10000','','','.b-select-suggest'),(128527,'printshop-mobile','.batchPr .checkbox input:checked + span:before','left','0','','','.batchPr'),(128528,'printshop-mobile','.batchPr .w-batch-products .products-listing .slick-prev','left','-10','','','.batchPr'),(128529,'printshop-mobile','.batchPr .checkbox input:not(checked) + span:before','left','1','','','.batchPr'),(128530,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','left','0','','','.p-account-samples-history'),(128531,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','left','15','','','.p-account-samples-history'),(128532,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','left','15','','','.p-account-samples-history'),(128533,'printshop-mobile','.p-account-samples-history .orders-table .status-name','left','0','','','.p-account-samples-history'),(128534,'printshop-mobile','.p-account-samples-history .orders-table .status-name','left','0','','','.p-account-samples-history'),(128535,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','left','0','','','.p-account-samples-history'),(128536,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','left','0','','','.p-account-samples-history'),(128537,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','left','0','','','.p-account-samples-history'),(128538,'printshop-mobile','.p-account-samples-history .orders-table .status-name','left','0','','','.p-account-samples-history'),(128539,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','left','0','','','.p-account-samples-history'),(128540,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','left','15','','','.p-account-samples-history'),(128541,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','left','0','','','.p-account-samples-history'),(128542,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','left','15','','','.p-account-samples-history'),(128543,'printshop-mobile','.p-account-samples-history .orders-table .status-name','left','0','','','.p-account-samples-history'),(128544,'printshop-mobile','.p-account-samples-history .orders-table .status-name','left','0','','','.p-account-samples-history'),(128545,'printshop-mobile','.p-account-samples-history .orders-table .status-name','left','0','','','.p-account-samples-history'),(128546,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','left','15','','','.p-account-samples-history'),(128547,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','left','15','','','.p-account-samples-history'),(128548,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-samples-history-info'),(128549,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-samples-history-info'),(128550,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','left','15','','','.p-account-samples-history-info'),(128551,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','left','15','','','.p-account-samples-history-info'),(128552,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-samples-history-info'),(128553,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-samples-history-info'),(128554,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-samples-history-info'),(128555,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-samples-history-info'),(128556,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','left','15','','','.p-account-samples-history-info'),(128557,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-samples-history-info'),(128558,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-samples-history-info'),(128559,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','left','1','3','','.p-account-samples-history-info'),(128560,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','left','1','3','','.p-account-samples-history-info'),(128561,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-samples-history-info'),(128562,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-samples-history-info'),(128563,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-samples-history-info'),(128564,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','left','15','','','.p-account-samples-history-info'),(128565,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','left','1','3','','.p-account-samples-history-info'),(128566,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','left','15','','','.p-account-samples-history-info'),(128567,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','left','1','3','','.p-account-samples-history-info'),(128568,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','left','1','3','','.p-account-samples-history-info'),(128569,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-samples-history-info'),(128570,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','left','1','3','','.p-account-samples-history-info'),(128571,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','left','15','','','.p-account-samples-history-info'),(128572,'printshop-mobile','.p-catalog-product .prev-product','left','0','','','.p-catalog-product'),(128573,'printshop-mobile','.p-catalog-product .prev-product .pn-image','left','20','3','','.p-catalog-product'),(128574,'printshop-mobile','.p-quick-order-index .all-scroll-div','left','0','','','.p-quick-order-index'),(128575,'printshop-mobile','.w-blog-widget-categories-list a','left','0','3','','.w-blog-widget-categories-list'),(128576,'printshop-mobile','.w-blog-widget-most-popular-posts a','left','0','3','','.w-blog-widget-most-popular-posts'),(128577,'printshop-mobile','.w-blog-widget-post-comments-count span','left','0','3','','.w-blog-widget-post-comments-count'),(128578,'printshop-mobile','.w-blog-widget-post-linked-products button.slick-prev','left','10','','','.w-blog-widget-post-linked-products'),(128579,'printshop-mobile','.w-blog-widget-post-listing .post_comment','left','0','3','','.w-blog-widget-post-listing'),(128580,'printshop-mobile','.w-blog-widget-post-share','left','112','0,4','','.w-blog-widget-post-share'),(128581,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev','left','13','','','.w-blog-widget-related-posts'),(128582,'printshop-mobile','.w-blog-widget-related-posts-by-category button.slick-prev','left','13','','','.w-blog-widget-related-posts-by-category'),(128583,'printshop-mobile','.w-cart-compare .dropdown .dropdown-menu','left','auto','','','.w-cart-compare'),(128584,'printshop-mobile','.w-catalog-b2b-add-button ','left','0','','','.w-catalog-b2b-add-button'),(128585,'printshop-mobile','.w-checkout-billing-address .addresses .address-item label input','left','0','','','.w-checkout-billing-address'),(128586,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item label input','left','0','','','.w-checkout-shipping-address'),(128587,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','left','50','','','.w-checkout-shipping-choice'),(128588,'printshop-mobile','.w-checkout-terms .required-message','left','0','','','.w-checkout-terms'),(128589,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','left','0','','','.w-image-maps'),(128590,'printshop-mobile','.w-image-maps .svg-wrap svg','left','0','','','.w-image-maps'),(128591,'printshop-mobile','.w-multi-cart-actions .dropdown .dropdown-menu','left','auto','','','.w-multi-cart-actions'),(128592,'printshop-mobile','.w-reviews-content .review','left','15','3','','.w-reviews-content'),(128593,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(128594,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(128595,'printshop-mobile','.w-wedding-registry-widgets-delete-link a','left','-3','4','','.w-wedding-registry-widgets-delete-link'),(128596,'printshop-mobile','.w-wedding-registry-widgets-share-link a','left','-3','4','','.w-wedding-registry-widgets-share-link'),(128597,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left_important','important','','','.b-select-suggest'),(128598,'printshop-mobile','.p-wedding-registry-index .search-list','left_measure','%','3','','.p-wedding-registry-index'),(128599,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no','left_measure','vw','','','.b-form'),(128600,'printshop-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left_measure','%','','','.b-slick'),(128601,'printshop-mobile','.w-search .search form','left_measure','vw','','','.w-search'),(128602,'printshop-mobile','.b-fancybox #fancybox-loading','left_measure','%','','','.b-fancybox'),(128603,'printshop-mobile','.w-search .suggest','left_measure','vw','','','.w-search'),(128604,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left_measure','%','','','.b-menu-lev_display-lra'),(128605,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left_measure','%','','','.b-menu-lev_display-lra'),(128606,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left_measure','%','','','.b-menu-lev_display-lra'),(128607,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left_measure','%','','','.b-menu-lev_display-lra'),(128608,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left_measure','%','','','.b-menu-lev_display-lra'),(128609,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left_measure','%','','','.b-menu-lev_display-right'),(128610,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left_measure','%','','','.b-menu-lev_display-right'),(128611,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left_measure','%','','','.b-menu-lev_display-right'),(128612,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left_measure','%','','','.b-menu-lev_display-right'),(128613,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left_measure','%','','','.b-menu-lev_display-right'),(128614,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left_measure','vw','','','.b-menu-lev_display-slide'),(128615,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left_measure','vw','','','.b-menu-lev_display-slide'),(128616,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left_measure','vw','','','.b-menu-lev_display-slide'),(128617,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left_measure','vw','','','.b-menu-lev_display-slide'),(128618,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left_measure','vw','','','.b-menu-lev_display-slide'),(128619,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left_measure','vw','','','.b-menu-open_from-left'),(128620,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','left_measure','%','','','.w-checkout-shipping-choice'),(128621,'printshop-mobile','.w-menu-slider .close','line-height','10','','','.w-menu-slider'),(128622,'printshop-mobile','.w-bestsellers .counter','line-height','34','','','.w-bestsellers'),(128623,'printshop-mobile','.w-bestsellers .item','line-height','33','3','','.w-bestsellers'),(128624,'printshop-mobile','.w-bestsellers .heading-3','line-height','1','3','','.w-bestsellers'),(128625,'printshop-mobile','.w-account .my-acc-link','line-height','39','3','','.w-account'),(128626,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line-height','18','','','.b-form'),(128627,'printshop-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','line-height','18','','','.b-form'),(128628,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','line-height','22','','','.b-form'),(128629,'printshop-mobile','.w-product-sale-ends .ends','line-height','1','','','.w-product-sale-ends'),(128630,'printshop-mobile','.w-menu-slider .menu-ico','line-height','54','','','.w-menu-slider'),(128631,'printshop-mobile','.w-list-type-2_2 .sale','line-height','22','4','','.w-list-type-2_2'),(128632,'printshop-mobile','.w-menu-horizontal .menu-ico','line-height','54','','','.w-menu-horizontal'),(128633,'printshop-mobile','.w-sale .name','line-height','1.2','','','.w-sale'),(128634,'printshop-mobile','.w-sale .badge','line-height','27','','','.w-sale'),(128635,'printshop-mobile','.w-menu-style-1 .menu-ico','line-height','48','','','.w-menu-style-1'),(128636,'printshop-mobile','.w-cart .cart-box-link','line-height','38','3','','.w-cart'),(128637,'printshop-mobile','.b-fancybox .fancybox-nav span','line-height','40','','','.b-fancybox'),(128638,'printshop-mobile','.p-account-history .order_history_table th','line-height','16','','','.p-account-history'),(128639,'printshop-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','line-height','20','','','.p-account-index'),(128640,'printshop-mobile','.w-quote .cart-box-link','line-height','0.75','3','','.w-quote'),(128641,'printshop-mobile','.w-reviews .heading-3','line-height','1','3','','.w-reviews'),(128642,'printshop-mobile','.w-catalog-listing-look .list','line-height','30','','','.w-catalog-listing-look'),(128643,'printshop-mobile','.w-catalog-listing-look .b2b','line-height','30','','','.w-catalog-listing-look'),(128644,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line-height','35','3','','.b-multi-page-checkout'),(128645,'printshop-mobile','.w-product-personal-catalog-button .btn','line-height','14','','','.w-product-personal-catalog-button'),(128646,'printshop-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','line-height','20','','','.p-account-history'),(128647,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line-height','31','','','.b-multi-page-checkout'),(128648,'printshop-mobile','.b-info-popup .info-popup div','line-height','1.7','','','.b-info-popup'),(128649,'printshop-mobile','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(128650,'printshop-mobile','.testimonials .heading-3','line-height','1','3','',''),(128651,'printshop-mobile','.b-pagination .pagination .prev','line-height','26','3','','.b-pagination'),(128652,'printshop-mobile','.b-pagination .pagination .prev','line-height','30','','','.b-pagination'),(128653,'printshop-mobile','.b-pagination .pagination .prev-pages','line-height','30','','','.b-pagination'),(128654,'printshop-mobile','.b-pagination .pagination .page-number','line-height','30','','','.b-pagination'),(128655,'printshop-mobile','.p-wedding-registry-manage .wr-search button','line-height','1.3','3','','.p-wedding-registry-manage'),(128656,'printshop-mobile','.b-pagination .pagination .next-pages','line-height','30','','','.b-pagination'),(128657,'printshop-mobile','.b-pagination .pagination .next','line-height','26','3','','.b-pagination'),(128658,'printshop-mobile','.b-pagination .pagination span','line-height','30','2','','.b-pagination'),(128659,'printshop-mobile','.b-pagination .pagination .next','line-height','30','','','.b-pagination'),(128660,'printshop-mobile','.p-account-history .view_link','line-height','17','4','','.p-account-history'),(128661,'printshop-mobile','.p-account-history .orders-table .td-alignright','line-height','35','720','','.p-account-history'),(128662,'printshop-mobile','.p-account-index .orders-table .td-alignright','line-height','35','720','','.p-account-index'),(128663,'printshop-mobile','.p-blog-index .nav-previous a','line-height','50','3','','.p-blog-index'),(128664,'printshop-mobile','.p-blog-index .nav-next a','line-height','50','3','','.p-blog-index'),(128665,'printshop-mobile','.w-list-type-2_2 .price','line-height','100','','','.w-list-type-2_2'),(128666,'printshop-mobile','.w-list-type-2_2 .sale','line-height','19','3','','.w-list-type-2_2'),(128667,'printshop-mobile','.w-list-type-2_2 .description','line-height','120','','','.w-list-type-2_2'),(128668,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','line-height','34','3','','.w-list-type-2_2'),(128669,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','line-height','28','','','.w-list-type-2_2'),(128670,'printshop-mobile','.w-list-type-2_2 .button-view a','line-height','28','','','.w-list-type-2_2'),(128671,'printshop-mobile','.w-list-type-2 .sale','line-height','19','3','','.w-list-type-2'),(128672,'printshop-mobile','.w-product-personal-catalog-button .btn','line-height','1','3','','.w-product-personal-catalog-button'),(128673,'printshop-mobile','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(128674,'printshop-mobile','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(128675,'printshop-mobile','.w-product-wedding-registry-button .btn','line-height','14','','','.w-product-wedding-registry-button'),(128676,'printshop-mobile','.b-fancybox .fancybox-close','line-height','1','','','.b-fancybox'),(128677,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','line-height','30','3','','.b-form'),(128678,'printshop-mobile','.p-wedding-registry-manage .links a.share-registry','line-height','30','','','.p-wedding-registry-manage'),(128679,'printshop-mobile','.p-wedding-registry-manage .links a','line-height','20','','','.p-wedding-registry-manage'),(128680,'printshop-mobile','.b-pagination .pagination a','line-height','30','','','.b-pagination'),(128681,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line-height','30','','','.b-switch'),(128682,'printshop-mobile','.w-quote .cart-box-link','line-height','39','702,3','','.w-quote'),(128683,'printshop-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','line-height','40','','','.b-quantity'),(128684,'printshop-mobile','.b-switch .bootstrap-switch','line-height','28','','','.b-switch'),(128685,'printshop-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line-height','36','','','.b-slick'),(128686,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','38','','','.b-slick'),(128687,'printshop-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','line-height','22','','','.w-filters'),(128688,'printshop-mobile','.w-search .search','line-height','48','3','','.w-search'),(128689,'printshop-mobile','.btn','line-height','20','','',''),(128690,'printshop-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','line-height','22','','','.w-filters'),(128691,'printshop-mobile','.w-currencies .current','line-height','1','3','','.w-currencies'),(128692,'printshop-mobile','.w-currencies .currencies-title','line-height','15','','','.w-currencies'),(128693,'printshop-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line-height','24','','','.w-compare-box-item'),(128694,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table th','line-height','16','','','.p-account-subscription-historyinfo'),(128695,'printshop-mobile','.b-info-popup .info-popup div','line-height','30','3','','.b-info-popup'),(128696,'printshop-mobile','.p-account-index .view_link','line-height','17','4','','.p-account-index'),(128697,'printshop-mobile','.b-info-popup .info-popup','line-height','2','','','.b-info-popup'),(128698,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','line-height','24','','','.b-fancybox'),(128699,'printshop-mobile','.w-menu-mobile .menu-ico','line-height','48','','','.w-menu-mobile'),(128700,'printshop-mobile','.w-sale .ends','line-height','1','','','.w-sale'),(128701,'printshop-mobile','.w-sale .old','line-height','0.8','','','.w-sale'),(128702,'printshop-mobile','.w-sale .special-price','line-height','0.8','','','.w-sale'),(128703,'printshop-mobile','.w-text .customer-service b','line-height','18','','','.w-text'),(128704,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','48','706','','.b-slick'),(128705,'printshop-mobile','.b-form .cart-popup .price','line-height','35','','','.b-form'),(128706,'printshop-mobile','.b-quantity .qty-box .bigger','line-height','35','','','.b-quantity'),(128707,'printshop-mobile','.b-quantity .qty-box .smaller','line-height','35','','','.b-quantity'),(128708,'printshop-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','line-height','16','3','','.w-cart-discount-coupon'),(128709,'printshop-mobile','.p-account-index .account_page h4','line-height','30','3','','.p-account-index'),(128710,'printshop-mobile','.b-form .form-inputs div.required-message','line-height','1.3','','','.b-form'),(128711,'printshop-mobile','.p-account-index .topAccount > li > div','line-height','40','3','','.p-account-index'),(128712,'printshop-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(128713,'printshop-mobile','.w-catalog-listing-look .grid','line-height','30','','','.w-catalog-listing-look'),(128714,'printshop-mobile','.w-list-type-2 .button-wishlist button','line-height','28','','','.w-list-type-2'),(128715,'printshop-mobile','.w-list-type-1_3 .sale','line-height','19','3','','.w-list-type-1_3'),(128716,'printshop-mobile','.w-list-type-2 .sale','line-height','22','4','','.w-list-type-2'),(128717,'printshop-mobile','.w-list-type-2 .description','line-height','120','','','.w-list-type-2'),(128718,'printshop-mobile','.w-list-type-2 .price','line-height','100','','','.w-list-type-2'),(128719,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','line-height','34','3','','.w-list-type-2'),(128720,'printshop-mobile','.w-list-type-1_3 .sale','line-height','22','4','','.w-list-type-1_3'),(128721,'printshop-mobile','.w-list-type-2 .button-view a','line-height','28','','','.w-list-type-2'),(128722,'printshop-mobile','.btn-3','line-height','20','','',''),(128723,'printshop-mobile','.w-list-type-1_3 .description','line-height','120','','','.w-list-type-1_3'),(128724,'printshop-mobile','.w-list-type-1_3 .price','line-height','100','','','.w-list-type-1_3'),(128725,'printshop-mobile','.btn-2','line-height','20','','',''),(128726,'printshop-mobile','.btn-1','line-height','24','','',''),(128727,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','line-height','34','3','','.w-list-type-1_3'),(128728,'printshop-mobile','.w-list-type-1_3 .button-view a','line-height','28','','','.w-list-type-1_3'),(128729,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','line-height','28','','','.w-list-type-1_3'),(128730,'printshop-mobile','.w-list-type-1_2 .sale','line-height','19','3','','.w-list-type-1_2'),(128731,'printshop-mobile','.w-list-type-1_2 .description','line-height','120','','','.w-list-type-1_2'),(128732,'printshop-mobile','.w-list-type-1_2 .sale','line-height','22','4','','.w-list-type-1_2'),(128733,'printshop-mobile','.w-list-type-1_2 .price','line-height','100','','','.w-list-type-1_2'),(128734,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','line-height','34','3','','.w-list-type-1_2'),(128735,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','line-height','28','','','.w-list-type-1_2'),(128736,'printshop-mobile','.b-bottom .pop-up-close','line-height','25','','','.b-bottom'),(128737,'printshop-mobile','.w-list-type-1_2 .button-view a','line-height','28','','','.w-list-type-1_2'),(128738,'printshop-mobile','.w-list-type-1 .sale','line-height','22','4','','.w-list-type-1'),(128739,'printshop-mobile','.w-list-type-1 .sale','line-height','19','3','','.w-list-type-1'),(128740,'printshop-mobile','.heading-4 .edit, h4 .edit','line-height','20','','',''),(128741,'printshop-mobile','.w-list-type-1 .description','line-height','120','','','.w-list-type-1'),(128742,'printshop-mobile','.heading-3 .edit, h3 .edit','line-height','20','','',''),(128743,'printshop-mobile','.heading-4 .right-text, h4 .right-text','line-height','20','','',''),(128744,'printshop-mobile','.heading-3 .right-text, h3 .right-text','line-height','20','','',''),(128745,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','line-height','34','3','','.w-list-type-1'),(128746,'printshop-mobile','.w-list-type-1 .price','line-height','100','','','.w-list-type-1'),(128747,'printshop-mobile','.w-list-type-1 .button-wishlist button','line-height','28','','','.w-list-type-1'),(128748,'printshop-mobile','.w-list-type-1 .button-view a','line-height','28','','','.w-list-type-1'),(128749,'printshop-mobile','.w-languages .current','line-height','1','3','','.w-languages'),(128750,'printshop-mobile','.p-account-index .date_value, .p-account-index .date_title','line-height','22','','','.p-account-index'),(128751,'printshop-mobile','.w-search .button-search','line-height','1.3','3','','.w-search'),(128752,'printshop-mobile','.w-socials .post_item > div','line-height','19','','','.w-socials'),(128753,'printshop-mobile','.b-info .info','line-height','1','3','','.b-info'),(128754,'printshop-mobile','.b-products-listing .btn-preloader','line-height','24','3','','.b-products-listing'),(128755,'printshop-mobile','.b-products-listing .loader','line-height','30','4','','.b-products-listing'),(128756,'printshop-mobile','.b-products-listing .products-listing .btn-buy','line-height','10','3','','.b-products-listing'),(128757,'printshop-mobile','.b-products-listing .products-listing .btn-preloader','line-height','8','','','.b-products-listing'),(128758,'printshop-mobile','.b-products-listing .products-listing .name a','line-height','1.5','','','.b-products-listing'),(128759,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.b-data-table'),(128760,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.b-data-table'),(128761,'printshop-mobile','.b-data-table table.dataTable thead td','line-height','1.5','','','.b-data-table'),(128762,'printshop-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line-height','30','','','.b-menu-burger_icon'),(128763,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(128764,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(128765,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(128766,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(128767,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(128768,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','line-height','1.2','','','.b-menu-style-1'),(128769,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','line-height','24','','','.b-menu-style-2'),(128770,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','line-height','24','','','.b-menu-style-2'),(128771,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','line-height','50','','','.b-menu-style-2'),(128772,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','line-height','16','3','','.b-menu-style-2'),(128773,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','line-height','16','3','','.b-menu-style-2'),(128774,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','line-height','1.2','','','.b-menu-style-3'),(128775,'printshop-mobile','.b-messages span.starred::before','line-height','10','','','.b-messages'),(128776,'printshop-mobile','.b-messages .messBtnMenuStarred','line-height','10','3','','.b-messages'),(128777,'printshop-mobile','.b-messages .messBtnMenuDelete','line-height','10','3','','.b-messages'),(128778,'printshop-mobile','.b-messages .messBtnMenuUnread','line-height','10','3','','.b-messages'),(128779,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line-height','14','','','.b-messages'),(128780,'printshop-mobile','.b-preloader .preloader','line-height','40','3','','.b-preloader'),(128781,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','line-height','26','','','.b-select-suggest'),(128782,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line-height','13','','','.b-select-suggest'),(128783,'printshop-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(128784,'printshop-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(128785,'printshop-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(128786,'printshop-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(128787,'printshop-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(128788,'printshop-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(128789,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(128790,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(128791,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(128792,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(128793,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(128794,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(128795,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(128796,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(128797,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(128798,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(128799,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(128800,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(128801,'printshop-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','line-height','1.3','','','.b-trade-approval'),(128802,'printshop-mobile','.b-upload-file .snapshot','line-height','38','','','.b-upload-file'),(128803,'printshop-mobile','.batchPr .btn-batch-remove','line-height','1','3','','.batchPr'),(128804,'printshop-mobile','.batchPr .batchSelect .checkbox','line-height','36','','','.batchPr'),(128805,'printshop-mobile','.batchPr .checkbox input:not(checked) + span:before','line-height','33','','','.batchPr'),(128806,'printshop-mobile','.batchPr .btn-batch-remove','line-height','0','','','.batchPr'),(128807,'printshop-mobile','.bell-ico .heading-2','line-height','10','3','','.bell-ico'),(128808,'printshop-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(128809,'printshop-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(128810,'printshop-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(128811,'printshop-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(128812,'printshop-mobile','.p-account-samples-history .order_history_table th','line-height','16','','','.p-account-samples-history'),(128813,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line-height','20','','','.p-account-samples-history'),(128814,'printshop-mobile','.p-account-samples-history .order_history_table th','line-height','16','','','.p-account-samples-history'),(128815,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','line-height','35','','','.p-account-samples-history'),(128816,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','line-height','35','','','.p-account-samples-history'),(128817,'printshop-mobile','.p-account-samples-history .view_link','line-height','17','4','','.p-account-samples-history'),(128818,'printshop-mobile','.p-account-samples-history .view_link','line-height','17','4','','.p-account-samples-history'),(128819,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','line-height','35','','','.p-account-samples-history'),(128820,'printshop-mobile','.p-account-samples-history .view_link','line-height','17','4','','.p-account-samples-history'),(128821,'printshop-mobile','.p-account-samples-history .order_history_table th','line-height','16','','','.p-account-samples-history'),(128822,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','line-height','35','','','.p-account-samples-history'),(128823,'printshop-mobile','.p-account-samples-history .order_history_table th','line-height','16','','','.p-account-samples-history'),(128824,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line-height','20','','','.p-account-samples-history'),(128825,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line-height','20','','','.p-account-samples-history'),(128826,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line-height','20','','','.p-account-samples-history'),(128827,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','line-height','35','','','.p-account-samples-history'),(128828,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line-height','20','','','.p-account-samples-history'),(128829,'printshop-mobile','.p-account-samples-history .view_link','line-height','17','4','','.p-account-samples-history'),(128830,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','line-height','35','','','.p-account-samples-history'),(128831,'printshop-mobile','.p-account-samples-history .view_link','line-height','17','4','','.p-account-samples-history'),(128832,'printshop-mobile','.p-account-samples-history .order_history_table th','line-height','16','','','.p-account-samples-history'),(128833,'printshop-mobile','.p-account-samples-history .order_history_table th','line-height','16','','','.p-account-samples-history'),(128834,'printshop-mobile','.p-account-samples-history .view_link','line-height','17','4','','.p-account-samples-history'),(128835,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line-height','20','','','.p-account-samples-history'),(128836,'printshop-mobile','.p-catalog-product .pn-direction','line-height','1.2','','','.p-catalog-product'),(128837,'printshop-mobile','.p-catalog-product .pn-image','line-height','24','3','','.p-catalog-product'),(128838,'printshop-mobile','.p-payer-order-confirmation .ship-ico','line-height','20','3','','.p-payer-order-confirmation'),(128839,'printshop-mobile','.p-payer-order-confirmation .discount-ico','line-height','20','3','','.p-payer-order-confirmation'),(128840,'printshop-mobile','.p-payer-order-confirmation .comment-ico','line-height','20','3','','.p-payer-order-confirmation'),(128841,'printshop-mobile','.p-payer-order-confirmation .order-ico','line-height','20','3','','.p-payer-order-confirmation'),(128842,'printshop-mobile','.p-payer-order-confirmation .pay-ico','line-height','20','3','','.p-payer-order-confirmation'),(128843,'printshop-mobile','.p-payer-order-pay .pay-ico','line-height','20','3','','.p-payer-order-pay'),(128844,'printshop-mobile','.p-payer-order-pay .order-ico','line-height','20','3','','.p-payer-order-pay'),(128845,'printshop-mobile','.p-payer-order-pay .ship-ico','line-height','20','3','','.p-payer-order-pay'),(128846,'printshop-mobile','.p-payer-order-pay .comment-ico','line-height','20','3','','.p-payer-order-pay'),(128847,'printshop-mobile','.p-payer-order-pay .discount-ico','line-height','20','3','','.p-payer-order-pay'),(128848,'printshop-mobile','.p-quick-order-index .paginate_button.previous','line-height','26','3','','.p-quick-order-index'),(128849,'printshop-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','line-height','1.2','','','.p-quick-order-index'),(128850,'printshop-mobile','.p-quick-order-index .stock','line-height','1.2','','','.p-quick-order-index'),(128851,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.p-quick-order-index'),(128852,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.p-quick-order-index'),(128853,'printshop-mobile','.p-quick-order-index .paginate_button.next','line-height','26','3','','.p-quick-order-index'),(128854,'printshop-mobile','.savings-ico .heading-2','line-height','10','3','','.savings-ico'),(128855,'printshop-mobile','.shipping-ico .heading-2','line-height','10','3','','.shipping-ico'),(128856,'printshop-mobile','.shipping-ico .heading-2','line-height','10','3','','.shipping-ico'),(128857,'printshop-mobile','.shipping-ico .heading-2','line-height','10','3','','.shipping-ico'),(128858,'printshop-mobile','.w-blog-widget-categories-list a','line-height','1','3','','.w-blog-widget-categories-list'),(128859,'printshop-mobile','.w-blog-widget-most-popular-posts a','line-height','1','3','','.w-blog-widget-most-popular-posts'),(128860,'printshop-mobile','.w-blog-widget-post-listing .post_date span + span','line-height','1','3','','.w-blog-widget-post-listing'),(128861,'printshop-mobile','.w-blog-widget-post-listing .post_name','line-height','1.2','','','.w-blog-widget-post-listing'),(128862,'printshop-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','line-height','1','','','.w-blog-widget-post-share'),(128863,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','line-height','35','','','.w-blog-widget-related-posts'),(128864,'printshop-mobile','.w-cart-compare .compare-table','line-height','1.3','','','.w-cart-compare'),(128865,'printshop-mobile','.w-cart-compare .delete-cart','line-height','1','','','.w-cart-compare'),(128866,'printshop-mobile','.w-cart-compare .price-cell','line-height','22','','','.w-cart-compare'),(128867,'printshop-mobile','.w-cart-compare .js-cart_totals_container','line-height','1.2','','','.w-cart-compare'),(128868,'printshop-mobile','.w-cart-compare .attributes-cell','line-height','22','','','.w-cart-compare'),(128869,'printshop-mobile','.w-cart-compare .cart-name a','line-height','1.2','','','.w-cart-compare'),(128870,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line-height','24','3','','.w-catalog-compare'),(128871,'printshop-mobile','.w-catalog-compare td','line-height','1.5','','','.w-catalog-compare'),(128872,'printshop-mobile','.w-catalog-compare span.btn-preloader','line-height','24','3','','.w-catalog-compare'),(128873,'printshop-mobile','.w-catalog-paging .next','line-height','26','3','','.w-catalog-paging'),(128874,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line-height','30','','','.w-catalog-paging'),(128875,'printshop-mobile','.w-catalog-paging .next','line-height','30','','','.w-catalog-paging'),(128876,'printshop-mobile','.w-catalog-paging ','line-height','30','2','','.w-catalog-paging'),(128877,'printshop-mobile','.w-catalog-paging .next-pages','line-height','30','','','.w-catalog-paging'),(128878,'printshop-mobile','.w-catalog-paging .page-number','line-height','30','','','.w-catalog-paging'),(128879,'printshop-mobile','.w-catalog-paging .prev-pages','line-height','30','','','.w-catalog-paging'),(128880,'printshop-mobile','.w-catalog-paging .prev','line-height','30','','','.w-catalog-paging'),(128881,'printshop-mobile','.w-catalog-paging .prev','line-height','26','3','','.w-catalog-paging'),(128882,'printshop-mobile','.w-checkout-billing-address .addresses .address-item label','line-height','1.3','','','.w-checkout-billing-address'),(128883,'printshop-mobile','.w-checkout-create-account .account-benefits strong','line-height','16','3','','.w-checkout-create-account'),(128884,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item label','line-height','1.3','','','.w-checkout-shipping-address'),(128885,'printshop-mobile','.w-checkout-shipping-choice span','line-height','19','','','.w-checkout-shipping-choice'),(128886,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','35','3','','.w-communication-new-topic'),(128887,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line-height','36','','','.w-communication-new-topic'),(128888,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','40','','','.w-communication-new-topic'),(128889,'printshop-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','line-height','1.2','','','.w-communication-new-topic'),(128890,'printshop-mobile','.w-delivery-day .ends','line-height','1','','','.w-delivery-day'),(128891,'printshop-mobile','.w-multi-cart-cart-switcher .cart-label','line-height','20','','','.w-multi-cart-cart-switcher'),(128892,'printshop-mobile','.w-personal-gift-status-bar .end-date','line-height','14','3','','.w-personal-gift-status-bar'),(128893,'printshop-mobile','.w-personal-gift-status-bar .inform','line-height','14','4','','.w-personal-gift-status-bar'),(128894,'printshop-mobile','.w-product-customers-activity .close','line-height','32','','','.w-product-customers-activity'),(128895,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','line-height','23','','','.w-promotions'),(128896,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','line-height','23','','','.w-promotions'),(128897,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','line-height','23','','','.w-promotions'),(128898,'printshop-mobile','.w-promotions .promo-salemaker .discount','line-height','23','','','.w-promotions'),(128899,'printshop-mobile','.w-promotions .heading-3','line-height','1','','','.w-promotions'),(128900,'printshop-mobile','.w-menu-slider .close','line_height_measure','px','','','.w-menu-slider'),(128901,'printshop-mobile','.w-catalog-listing-look .list','line_height_measure','px','','','.w-catalog-listing-look'),(128902,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','line_height_measure','px','','','.b-form'),(128903,'printshop-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','line_height_measure','px','','','.b-form'),(128904,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line_height_measure','px','','','.b-form'),(128905,'printshop-mobile','.w-sale .badge','line_height_measure','px','','','.w-sale'),(128906,'printshop-mobile','.w-product-wedding-registry-button .btn','line_height_measure','px','','','.w-product-wedding-registry-button'),(128907,'printshop-mobile','.p-account-history .order_history_table th','line_height_measure','px','','','.p-account-history'),(128908,'printshop-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','line_height_measure','px','','','.p-account-index'),(128909,'printshop-mobile','.w-bestsellers .item','line_height_measure','px','3','','.w-bestsellers'),(128910,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line_height_measure','px','3','','.b-multi-page-checkout'),(128911,'printshop-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-discount-coupon'),(128912,'printshop-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(128913,'printshop-mobile','.w-catalog-listing-look .b2b','line_height_measure','px','','','.w-catalog-listing-look'),(128914,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line_height_measure','px','','','.b-multi-page-checkout'),(128915,'printshop-mobile','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(128916,'printshop-mobile','.b-pagination .pagination .prev-pages','line_height_measure','px','','','.b-pagination'),(128917,'printshop-mobile','.b-pagination .pagination .prev','line_height_measure','px','3','','.b-pagination'),(128918,'printshop-mobile','.b-pagination .pagination .prev','line_height_measure','px','','','.b-pagination'),(128919,'printshop-mobile','.b-pagination .pagination .next-pages','line_height_measure','px','','','.b-pagination'),(128920,'printshop-mobile','.b-pagination .pagination .page-number','line_height_measure','px','','','.b-pagination'),(128921,'printshop-mobile','.b-pagination .pagination .next','line_height_measure','px','3','','.b-pagination'),(128922,'printshop-mobile','.b-pagination .pagination .next','line_height_measure','px','','','.b-pagination'),(128923,'printshop-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','line_height_measure','px','','','.p-account-history'),(128924,'printshop-mobile','.b-pagination .pagination span','line_height_measure','px','2','','.b-pagination'),(128925,'printshop-mobile','.p-account-history .view_link','line_height_measure','px','4','','.p-account-history'),(128926,'printshop-mobile','.p-account-history .orders-table .td-alignright','line_height_measure','px','720','','.p-account-history'),(128927,'printshop-mobile','.p-account-index .orders-table .td-alignright','line_height_measure','px','720','','.p-account-index'),(128928,'printshop-mobile','.p-blog-index .nav-previous a','line_height_measure','px','3','','.p-blog-index'),(128929,'printshop-mobile','.p-blog-index .nav-next a','line_height_measure','px','3','','.p-blog-index'),(128930,'printshop-mobile','.w-list-type-2_2 .price','line_height_measure','%','','','.w-list-type-2_2'),(128931,'printshop-mobile','.w-list-type-2_2 .description','line_height_measure','%','','','.w-list-type-2_2'),(128932,'printshop-mobile','.w-product-personal-catalog-button .btn','line_height_measure','px','','','.w-product-personal-catalog-button'),(128933,'printshop-mobile','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(128934,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','line_height_measure','px','3','','.b-form'),(128935,'printshop-mobile','.p-wedding-registry-manage .links a','line_height_measure','px','','','.p-wedding-registry-manage'),(128936,'printshop-mobile','.p-wedding-registry-manage .links a.share-registry','line_height_measure','px','','','.p-wedding-registry-manage'),(128937,'printshop-mobile','.b-pagination .pagination a','line_height_measure','px','','','.b-pagination'),(128938,'printshop-mobile','.b-switch .bootstrap-switch','line_height_measure','px','','','.b-switch'),(128939,'printshop-mobile','.w-quote .cart-box-link','line_height_measure','px','702,3','','.w-quote'),(128940,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line_height_measure','px','','','.b-switch'),(128941,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','line_height_measure','px','','','.b-fancybox'),(128942,'printshop-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(128943,'printshop-mobile','.w-catalog-listing-look .grid','line_height_measure','px','','','.w-catalog-listing-look'),(128944,'printshop-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line_height_measure','px','','','.b-slick'),(128945,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','','','.b-slick'),(128946,'printshop-mobile','.w-search .search','line_height_measure','px','3','','.w-search'),(128947,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table th','line_height_measure','px','','','.p-account-subscription-historyinfo'),(128948,'printshop-mobile','.b-info-popup .info-popup','line_height_measure','px','','','.b-info-popup'),(128949,'printshop-mobile','.p-account-index .view_link','line_height_measure','px','4','','.p-account-index'),(128950,'printshop-mobile','.w-menu-mobile .menu-ico','line_height_measure','px','','','.w-menu-mobile'),(128951,'printshop-mobile','.w-list-type-1_3 .price','line_height_measure','%','','','.w-list-type-1_3'),(128952,'printshop-mobile','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(128953,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','706','','.b-slick'),(128954,'printshop-mobile','.b-form .cart-popup .price','line_height_measure','px','','','.b-form'),(128955,'printshop-mobile','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(128956,'printshop-mobile','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(128957,'printshop-mobile','.w-cart .cart-box-link','line_height_measure','px','3','','.w-cart'),(128958,'printshop-mobile','.w-menu-style-1 .menu-ico','line_height_measure','px','','','.w-menu-style-1'),(128959,'printshop-mobile','.w-account .my-acc-link','line_height_measure','px','3','','.w-account'),(128960,'printshop-mobile','.b-fancybox .fancybox-nav span','line_height_measure','px','','','.b-fancybox'),(128961,'printshop-mobile','.btn','line_height_measure','px','','',''),(128962,'printshop-mobile','.p-account-index .account_page h4','line_height_measure','px','3','','.p-account-index'),(128963,'printshop-mobile','.p-account-index .topAccount > li > div','line_height_measure','px','3','','.p-account-index'),(128964,'printshop-mobile','.btn-3','line_height_measure','px','','',''),(128965,'printshop-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','line_height_measure','px','','','.w-filters'),(128966,'printshop-mobile','.btn-1','line_height_measure','px','','',''),(128967,'printshop-mobile','.heading-4 .right-text, h4 .right-text','line_height_measure','px','','',''),(128968,'printshop-mobile','.heading-3 .edit, h3 .edit','line_height_measure','px','','',''),(128969,'printshop-mobile','.btn-2','line_height_measure','px','','',''),(128970,'printshop-mobile','.w-currencies .currencies-title','line_height_measure','px','','','.w-currencies'),(128971,'printshop-mobile','.w-list-type-1 .sale','line_height_measure','px','4','','.w-list-type-1'),(128972,'printshop-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','line_height_measure','px','','','.w-filters'),(128973,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','line_height_measure','px','','','.w-list-type-1_2'),(128974,'printshop-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line_height_measure','px','','','.w-compare-box-item'),(128975,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-1_2'),(128976,'printshop-mobile','.w-list-type-1 .button-view a','line_height_measure','px','','','.w-list-type-1'),(128977,'printshop-mobile','.w-list-type-1 .sale','line_height_measure','px','3','','.w-list-type-1'),(128978,'printshop-mobile','.w-list-type-1_3 .button-view a','line_height_measure','px','','','.w-list-type-1_3'),(128979,'printshop-mobile','.w-list-type-1 .button-wishlist button','line_height_measure','px','','','.w-list-type-1'),(128980,'printshop-mobile','.w-list-type-1_2 .button-view a','line_height_measure','px','','','.w-list-type-1_2'),(128981,'printshop-mobile','.w-list-type-1_2 .sale','line_height_measure','px','4','','.w-list-type-1_2'),(128982,'printshop-mobile','.w-list-type-1_3 .sale','line_height_measure','px','3','','.w-list-type-1_3'),(128983,'printshop-mobile','.w-menu-slider .menu-ico','line_height_measure','px','','','.w-menu-slider'),(128984,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-1'),(128985,'printshop-mobile','.w-list-type-2 .button-wishlist button','line_height_measure','px','','','.w-list-type-2'),(128986,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-1_3'),(128987,'printshop-mobile','.w-list-type-2 .button-view a','line_height_measure','px','','','.w-list-type-2'),(128988,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','line_height_measure','px','','','.w-list-type-1_3'),(128989,'printshop-mobile','.w-list-type-1_3 .sale','line_height_measure','px','4','','.w-list-type-1_3'),(128990,'printshop-mobile','.w-list-type-1_2 .sale','line_height_measure','px','3','','.w-list-type-1_2'),(128991,'printshop-mobile','.w-list-type-2_2 .sale','line_height_measure','px','3','','.w-list-type-2_2'),(128992,'printshop-mobile','.w-list-type-2_2 .sale','line_height_measure','px','4','','.w-list-type-2_2'),(128993,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-2'),(128994,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','line_height_measure','px','','','.w-list-type-2_2'),(128995,'printshop-mobile','.w-menu-horizontal .menu-ico','line_height_measure','px','','','.w-menu-horizontal'),(128996,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-2_2'),(128997,'printshop-mobile','.w-list-type-2 .sale','line_height_measure','px','4','','.w-list-type-2'),(128998,'printshop-mobile','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(128999,'printshop-mobile','.w-list-type-2 .sale','line_height_measure','px','3','','.w-list-type-2'),(129000,'printshop-mobile','.w-list-type-2_2 .button-view a','line_height_measure','px','','','.w-list-type-2_2'),(129001,'printshop-mobile','.heading-4 .edit, h4 .edit','line_height_measure','px','','',''),(129002,'printshop-mobile','.p-account-index .date_value, .p-account-index .date_title','line_height_measure','px','','','.p-account-index'),(129003,'printshop-mobile','.heading-3 .right-text, h3 .right-text','line_height_measure','px','','',''),(129004,'printshop-mobile','.w-list-type-2 .description','line_height_measure','%','','','.w-list-type-2'),(129005,'printshop-mobile','.w-list-type-2 .price','line_height_measure','%','','','.w-list-type-2'),(129006,'printshop-mobile','.w-list-type-1_3 .description','line_height_measure','%','','','.w-list-type-1_3'),(129007,'printshop-mobile','.w-list-type-1_2 .price','line_height_measure','%','','','.w-list-type-1_2'),(129008,'printshop-mobile','.w-list-type-1_2 .description','line_height_measure','%','','','.w-list-type-1_2'),(129009,'printshop-mobile','.b-bottom .pop-up-close','line_height_measure','px','','','.b-bottom'),(129010,'printshop-mobile','.w-list-type-1 .price','line_height_measure','%','','','.w-list-type-1'),(129011,'printshop-mobile','.w-list-type-1 .description','line_height_measure','%','','','.w-list-type-1'),(129012,'printshop-mobile','.w-bestsellers .counter','line_height_measure','px','','','.w-bestsellers'),(129013,'printshop-mobile','.b-info-popup .info-popup div','line_height_measure','px','3','','.b-info-popup'),(129014,'printshop-mobile','.b-products-listing .btn-preloader','line_height_measure','px','3','','.b-products-listing'),(129015,'printshop-mobile','.b-products-listing .loader','line_height_measure','px','4','','.b-products-listing'),(129016,'printshop-mobile','.b-products-listing .products-listing .btn-buy','line_height_measure','px','3','','.b-products-listing'),(129017,'printshop-mobile','.b-products-listing .products-listing .btn-preloader','line_height_measure','px','','','.b-products-listing'),(129018,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.b-data-table'),(129019,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.b-data-table'),(129020,'printshop-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line_height_measure','px','','','.b-menu-burger_icon'),(129021,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(129022,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(129023,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(129024,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(129025,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(129026,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','line_height_measure','px','','','.b-menu-style-2'),(129027,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','line_height_measure','px','','','.b-menu-style-2'),(129028,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','line_height_measure','px','','','.b-menu-style-2'),(129029,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','line_height_measure','px','3','','.b-menu-style-2'),(129030,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','line_height_measure','px','3','','.b-menu-style-2'),(129031,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-messages'),(129032,'printshop-mobile','.b-messages span.starred::before','line_height_measure','px','','','.b-messages'),(129033,'printshop-mobile','.b-messages .messBtnMenuStarred','line_height_measure','px','3','','.b-messages'),(129034,'printshop-mobile','.b-messages .messBtnMenuDelete','line_height_measure','px','3','','.b-messages'),(129035,'printshop-mobile','.b-messages .messBtnMenuUnread','line_height_measure','px','3','','.b-messages'),(129036,'printshop-mobile','.b-preloader .preloader','line_height_measure','px','3','','.b-preloader'),(129037,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','line_height_measure','px','','','.b-select-suggest'),(129038,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-select-suggest'),(129039,'printshop-mobile','.b-upload-file .snapshot','line_height_measure','px','','','.b-upload-file'),(129040,'printshop-mobile','.batchPr .batchSelect .checkbox','line_height_measure','px','','','.batchPr'),(129041,'printshop-mobile','.batchPr .checkbox input:not(checked) + span:before','line_height_measure','px','','','.batchPr'),(129042,'printshop-mobile','.bell-ico .heading-2','line_height_measure','px','3','','.bell-ico'),(129043,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','line_height_measure','px','','','.p-account-samples-history'),(129044,'printshop-mobile','.p-account-samples-history .view_link','line_height_measure','px','4','','.p-account-samples-history'),(129045,'printshop-mobile','.p-account-samples-history .view_link','line_height_measure','px','4','','.p-account-samples-history'),(129046,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','line_height_measure','px','','','.p-account-samples-history'),(129047,'printshop-mobile','.p-account-samples-history .view_link','line_height_measure','px','4','','.p-account-samples-history'),(129048,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','line_height_measure','px','','','.p-account-samples-history'),(129049,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line_height_measure','px','','','.p-account-samples-history'),(129050,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line_height_measure','px','','','.p-account-samples-history'),(129051,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line_height_measure','px','','','.p-account-samples-history'),(129052,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','line_height_measure','px','','','.p-account-samples-history'),(129053,'printshop-mobile','.p-account-samples-history .view_link','line_height_measure','px','4','','.p-account-samples-history'),(129054,'printshop-mobile','.p-account-samples-history .order_history_table th','line_height_measure','px','','','.p-account-samples-history'),(129055,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line_height_measure','px','','','.p-account-samples-history'),(129056,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line_height_measure','px','','','.p-account-samples-history'),(129057,'printshop-mobile','.p-account-samples-history .view_link','line_height_measure','px','4','','.p-account-samples-history'),(129058,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line_height_measure','px','','','.p-account-samples-history'),(129059,'printshop-mobile','.p-account-samples-history .order_history_table th','line_height_measure','px','','','.p-account-samples-history'),(129060,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','line_height_measure','px','','','.p-account-samples-history'),(129061,'printshop-mobile','.p-account-samples-history .order_history_table th','line_height_measure','px','','','.p-account-samples-history'),(129062,'printshop-mobile','.p-account-samples-history .order_history_table th','line_height_measure','px','','','.p-account-samples-history'),(129063,'printshop-mobile','.p-account-samples-history .order_history_table th','line_height_measure','px','','','.p-account-samples-history'),(129064,'printshop-mobile','.p-account-samples-history .view_link','line_height_measure','px','4','','.p-account-samples-history'),(129065,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','line_height_measure','px','','','.p-account-samples-history'),(129066,'printshop-mobile','.p-account-samples-history .order_history_table th','line_height_measure','px','','','.p-account-samples-history'),(129067,'printshop-mobile','.p-catalog-product .pn-image','line_height_measure','px','3','','.p-catalog-product'),(129068,'printshop-mobile','.p-payer-order-confirmation .discount-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(129069,'printshop-mobile','.p-payer-order-confirmation .comment-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(129070,'printshop-mobile','.p-payer-order-confirmation .pay-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(129071,'printshop-mobile','.p-payer-order-confirmation .ship-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(129072,'printshop-mobile','.p-payer-order-confirmation .order-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(129073,'printshop-mobile','.p-payer-order-pay .ship-ico','line_height_measure','px','3','','.p-payer-order-pay'),(129074,'printshop-mobile','.p-payer-order-pay .pay-ico','line_height_measure','px','3','','.p-payer-order-pay'),(129075,'printshop-mobile','.p-payer-order-pay .order-ico','line_height_measure','px','3','','.p-payer-order-pay'),(129076,'printshop-mobile','.p-payer-order-pay .comment-ico','line_height_measure','px','3','','.p-payer-order-pay'),(129077,'printshop-mobile','.p-payer-order-pay .discount-ico','line_height_measure','px','3','','.p-payer-order-pay'),(129078,'printshop-mobile','.p-quick-order-index .paginate_button.next','line_height_measure','px','3','','.p-quick-order-index'),(129079,'printshop-mobile','.p-quick-order-index .paginate_button.previous','line_height_measure','px','3','','.p-quick-order-index'),(129080,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.p-quick-order-index'),(129081,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.p-quick-order-index'),(129082,'printshop-mobile','.savings-ico .heading-2','line_height_measure','px','3','','.savings-ico'),(129083,'printshop-mobile','.shipping-ico .heading-2','line_height_measure','px','3','','.shipping-ico'),(129084,'printshop-mobile','.shipping-ico .heading-2','line_height_measure','px','3','','.shipping-ico'),(129085,'printshop-mobile','.shipping-ico .heading-2','line_height_measure','px','3','','.shipping-ico'),(129086,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','line_height_measure','px','','','.w-blog-widget-related-posts'),(129087,'printshop-mobile','.w-cart-compare .attributes-cell','line_height_measure','px','','','.w-cart-compare'),(129088,'printshop-mobile','.w-cart-compare .price-cell','line_height_measure','px','','','.w-cart-compare'),(129089,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line_height_measure','px','3','','.w-catalog-compare'),(129090,'printshop-mobile','.w-catalog-compare span.btn-preloader','line_height_measure','px','3','','.w-catalog-compare'),(129091,'printshop-mobile','.w-catalog-paging ','line_height_measure','px','2','','.w-catalog-paging'),(129092,'printshop-mobile','.w-catalog-paging .next','line_height_measure','px','','','.w-catalog-paging'),(129093,'printshop-mobile','.w-catalog-paging .prev','line_height_measure','px','','','.w-catalog-paging'),(129094,'printshop-mobile','.w-catalog-paging .next','line_height_measure','px','3','','.w-catalog-paging'),(129095,'printshop-mobile','.w-catalog-paging .next-pages','line_height_measure','px','','','.w-catalog-paging'),(129096,'printshop-mobile','.w-catalog-paging .prev-pages','line_height_measure','px','','','.w-catalog-paging'),(129097,'printshop-mobile','.w-catalog-paging .page-number','line_height_measure','px','','','.w-catalog-paging'),(129098,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line_height_measure','px','','','.w-catalog-paging'),(129099,'printshop-mobile','.w-catalog-paging .prev','line_height_measure','px','3','','.w-catalog-paging'),(129100,'printshop-mobile','.w-checkout-create-account .account-benefits strong','line_height_measure','px','3','','.w-checkout-create-account'),(129101,'printshop-mobile','.w-checkout-shipping-choice span','line_height_measure','px','','','.w-checkout-shipping-choice'),(129102,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line_height_measure','px','','','.w-communication-new-topic'),(129103,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','3','','.w-communication-new-topic'),(129104,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','','','.w-communication-new-topic'),(129105,'printshop-mobile','.w-multi-cart-cart-switcher .cart-label','line_height_measure','px','','','.w-multi-cart-cart-switcher'),(129106,'printshop-mobile','.w-personal-gift-status-bar .end-date','line_height_measure','px','3','','.w-personal-gift-status-bar'),(129107,'printshop-mobile','.w-personal-gift-status-bar .inform','line_height_measure','px','4','','.w-personal-gift-status-bar'),(129108,'printshop-mobile','.w-product-customers-activity .close','line_height_measure','px','','','.w-product-customers-activity'),(129109,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','line_height_measure','px','','','.w-promotions'),(129110,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','line_height_measure','px','','','.w-promotions'),(129111,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','line_height_measure','px','','','.w-promotions'),(129112,'printshop-mobile','.w-promotions .promo-salemaker .discount','line_height_measure','px','','','.w-promotions'),(129113,'printshop-mobile','.w-menu-big ul','list-style','none','','','.w-menu-big'),(129114,'printshop-mobile','.w-menu-slider ul, .w-menu-slider li','list-style','none','','','.w-menu-slider'),(129115,'printshop-mobile','.w-menu-horizontal ul','list-style','none','','','.w-menu-horizontal'),(129116,'printshop-mobile','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(129117,'printshop-mobile','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(129118,'printshop-mobile','.p-blog-index .wp-widget ul','list-style','none','','','.p-blog-index'),(129119,'printshop-mobile','.p-blog-index .wp-widget li','list-style','none','','','.p-blog-index'),(129120,'printshop-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','list-style','none','','','.p-blog-index'),(129121,'printshop-mobile','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(129122,'printshop-mobile','.w-account ul, .w-account li','list-style','none','','','.w-account'),(129123,'printshop-mobile','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(129124,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(129125,'printshop-mobile','.w-tabs .tab-navigation','list-style','none','','','.w-tabs'),(129126,'printshop-mobile','.w-filters .filter-ul-content','list-style','none','','','.w-filters'),(129127,'printshop-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(129128,'printshop-mobile','.w-menu-style-1 ul','list-style','none','','','.w-menu-style-1'),(129129,'printshop-mobile','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(129130,'printshop-mobile','.p-account-index .topAccount','list-style','none','','','.p-account-index'),(129131,'printshop-mobile','.b-autocomplete .ui-autocomplete','list-style','none','','','.b-autocomplete'),(129132,'printshop-mobile','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(129133,'printshop-mobile','.p-account-index .account_info','list-style','none','','','.p-account-index'),(129134,'printshop-mobile','.p-account-address-book .leftMes ul','list-style','disc inside','','','.p-account-address-book'),(129135,'printshop-mobile','.p-account-address-book .rightMes ul','list-style','disc inside','','','.p-account-address-book'),(129136,'printshop-mobile','.b-info .info ul','list-style','disc inside','','','.b-info'),(129137,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(129138,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(129139,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(129140,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(129141,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(129142,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(129143,'printshop-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','list-style','none','','','.b-menu-style'),(129144,'printshop-mobile','.b-messages .messages-menu ul','list-style','none','','','.b-messages'),(129145,'printshop-mobile','.b-select-suggest .select2-results li','list-style','none','','','.b-select-suggest'),(129146,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices li','list-style','none','','','.b-select-suggest'),(129147,'printshop-mobile','.p-quick-order-index ul.token-input-list','list-style','none','','','.p-quick-order-index'),(129148,'printshop-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','list-style','none','','','.w-catalog-additional-images'),(129149,'printshop-mobile','.w-sitemap-delivery-location > ul','list-style','none','','','.w-sitemap-delivery-location'),(129150,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul','list-style','none','','','.w-sitemap-delivery-location'),(129151,'printshop-mobile','.b-product-images .additional-horizontal .additional-images .item, .b-product-images .additional-horizontal .additional-videos .item','margin','0 auto','','','.b-product-images'),(129152,'printshop-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','margin','0 auto','','','.b-product-images'),(129153,'printshop-mobile','.w-delivery-location-top-location-list .deliveryName','margin','5px auto','','','.w-delivery-location-top-location-list'),(129154,'printshop-mobile','.p-wedding-registry-manage .wr-search','margin','0 auto 20px','','','.p-wedding-registry-manage'),(129155,'printshop-mobile','.p-wedding-registry-index .middle-box','margin','0 auto','','','.p-wedding-registry-index'),(129156,'printshop-mobile','.b-form .middle-form','margin','0 auto','','','.b-form'),(129157,'printshop-mobile','.b-messages .msv_btn .btn','margin','0px auto 0px','','','.b-messages'),(129158,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','margin','3px auto 3px','','','.b-select-suggest'),(129159,'printshop-mobile','.b-select-suggest .select2-results','margin','4px auto 4px','','','.b-select-suggest'),(129160,'printshop-mobile','.b-trade-approval .middle-form','margin','0 auto','','','.b-trade-approval'),(129161,'printshop-mobile','.w-blog-widget-tag-cloud a','margin','0px auto 4px','','','.w-blog-widget-tag-cloud'),(129162,'printshop-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','margin','0 auto','','','.w-catalog-b2b-add-button'),(129163,'printshop-mobile','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(129164,'printshop-mobile','.w-menu-big li','margin-bottom','0','','','.w-menu-big'),(129165,'printshop-mobile','.w-menu .hided.menu ul li','margin-bottom','0','','','.w-menu'),(129166,'printshop-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-bottom','0','','','.w-menu'),(129167,'printshop-mobile','.w-menu-big ul','margin-bottom','0','','','.w-menu-big'),(129168,'printshop-mobile','.w-bestsellers .heading-3','margin-bottom','10','','','.w-bestsellers'),(129169,'printshop-mobile','.w-menu-slider ul, .w-menu-slider li','margin-bottom','0','','','.w-menu-slider'),(129170,'printshop-mobile','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(129171,'printshop-mobile','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(129172,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(129173,'printshop-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-bottom','0','','','.b-cookie-notice'),(129174,'printshop-mobile','.b-form .bootstrap-switch','margin-bottom','15','','','.b-form'),(129175,'printshop-mobile','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','margin-bottom','15','','','.b-form'),(129176,'printshop-mobile','.b-form .checkbox-style','margin-bottom','0','','','.b-form'),(129177,'printshop-mobile','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(129178,'printshop-mobile','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(129179,'printshop-mobile','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(129180,'printshop-mobile','.w-product-sale-ends .ends','margin-bottom','20','','','.w-product-sale-ends'),(129181,'printshop-mobile','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(129182,'printshop-mobile','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(129183,'printshop-mobile','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(129184,'printshop-mobile','.w-product-sale-ends .left','margin-bottom','30','','','.w-product-sale-ends'),(129185,'printshop-mobile','.w-list-type-2_2 .title','margin-bottom','10','','','.w-list-type-2_2'),(129186,'printshop-mobile','.w-sale .name','margin-bottom','20','','','.w-sale'),(129187,'printshop-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','margin-bottom','0','','','.b-product-images'),(129188,'printshop-mobile','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(129189,'printshop-mobile','.w-filters .filter-ul-content','margin-bottom','0','','','.w-filters'),(129190,'printshop-mobile','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(129191,'printshop-mobile','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(129192,'printshop-mobile','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(129193,'printshop-mobile','.p-account-index .account_info','margin-bottom','0','','','.p-account-index'),(129194,'printshop-mobile','.p-account-history-info .history_info','margin-bottom','20','','','.p-account-history-info'),(129195,'printshop-mobile','.p-account-index .account_page h1','margin-bottom','10','','','.p-account-index'),(129196,'printshop-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','margin-bottom','10','','','.p-account-trade-form'),(129197,'printshop-mobile','.b-price-box .checkout-index .price-box, .b-price-box .checkout-confirmation .price-box','margin-bottom','20','','','.b-price-box'),(129198,'printshop-mobile','.w-product-attributes .select-box:nth-child(2n+1)','margin-bottom','20','','','.w-product-attributes'),(129199,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','margin-bottom','5','','','.b-multi-page-checkout'),(129200,'printshop-mobile','.p-blog-index .wp-widget','margin-bottom','20','','','.p-blog-index'),(129201,'printshop-mobile','.p-blog-index .nav-previous','margin-bottom','20','718','','.p-blog-index'),(129202,'printshop-mobile','.p-blog-index .post_body','margin-bottom','30','','','.p-blog-index'),(129203,'printshop-mobile','.p-blog-index .autor_name_data','margin-bottom','10','','','.p-blog-index'),(129204,'printshop-mobile','.w-list-type-1_2 .image','margin-bottom','10','694','','.w-list-type-1_2'),(129205,'printshop-mobile','.w-socials .post_item_img','margin-bottom','0','','','.w-socials'),(129206,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-bottom','0','','','.b-multi-page-checkout'),(129207,'printshop-mobile','.w-search .search-input','margin-bottom','0','','','.w-search'),(129208,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(129209,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList','margin-bottom','0','','','.w-delivery-location-top-location-list'),(129210,'printshop-mobile','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(129211,'printshop-mobile','.w-delivery-location-top-location-list','margin-bottom','25','','','.w-delivery-location-top-location-list'),(129212,'printshop-mobile','.p-account-order-pay .buttons','margin-bottom','20','','','.p-account-order-pay'),(129213,'printshop-mobile','.p-account-order-pay .history_info','margin-bottom','20','','','.p-account-order-pay'),(129214,'printshop-mobile','.p-account-order-pay .history_info > div','margin-bottom','12','694','','.p-account-order-pay'),(129215,'printshop-mobile','.p-sample-checkout-index .price-box','margin-bottom','20','','','.p-sample-checkout-index'),(129216,'printshop-mobile','.testimonials .name','margin-bottom','20','','',''),(129217,'printshop-mobile','.p-sample-checkout-index .buttons','margin-bottom','20','','','.p-sample-checkout-index'),(129218,'printshop-mobile','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(129219,'printshop-mobile','.b-pagination .pagination','margin-bottom','20','','','.b-pagination'),(129220,'printshop-mobile','.testimonials .heading-3','margin-bottom','10','','',''),(129221,'printshop-mobile','.testimonials .reviews-list .name','margin-bottom','20','','',''),(129222,'printshop-mobile','.b-bottom .confirm-popup .buttons .btn','margin-bottom','0','','','.b-bottom'),(129223,'printshop-mobile','.p-account-history-info .buttons','margin-bottom','20','','','.p-account-history-info'),(129224,'printshop-mobile','.p-account-history .orders-table .item','margin-bottom','10','720','','.p-account-history'),(129225,'printshop-mobile','.p-account-index .orders-table .item','margin-bottom','10','720','','.p-account-index'),(129226,'printshop-mobile','.p-blog-index .comment-form p','margin-bottom','20','','','.p-blog-index'),(129227,'printshop-mobile','.p-blog-index .comments-area article','margin-bottom','10','','','.p-blog-index'),(129228,'printshop-mobile','.pop-up-content .buttons .left-buttons','margin-bottom','15','694','',''),(129229,'printshop-mobile','.w-list-type-2_2 .price','margin-bottom','10','','','.w-list-type-2_2'),(129230,'printshop-mobile','.w-list-type-2_2 .qty-input','margin-bottom','10','','','.w-list-type-2_2'),(129231,'printshop-mobile','.w-list-type-2_2 .properties','margin-bottom','5','','','.w-list-type-2_2'),(129232,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-2_2'),(129233,'printshop-mobile','.w-list-type-2_2 .description','margin-bottom','5','','','.w-list-type-2_2'),(129234,'printshop-mobile','.w-list-type-2 .title','margin-bottom','10','','','.w-list-type-2'),(129235,'printshop-mobile','.w-list-type-2 .qty-input','margin-bottom','10','','','.w-list-type-2'),(129236,'printshop-mobile','.w-list-type-2 .properties','margin-bottom','5','','','.w-list-type-2'),(129237,'printshop-mobile','.w-list-type-2 .price','margin-bottom','10','','','.w-list-type-2'),(129238,'printshop-mobile','.personal-buttons > div > div','margin-bottom','20','','','.personal-buttons'),(129239,'printshop-mobile','.w-bestsellers .item','margin-bottom','12','','','.w-bestsellers'),(129240,'printshop-mobile','.b-fancybox .fancybox-error','margin-bottom','0','','','.b-fancybox'),(129241,'printshop-mobile','.w-account ul, .w-account li','margin-bottom','0','','','.w-account'),(129242,'printshop-mobile','.w-menu-horizontal ul','margin-bottom','0','','','.w-menu-horizontal'),(129243,'printshop-mobile','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(129244,'printshop-mobile','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(129245,'printshop-mobile','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(129246,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-top-location-list'),(129247,'printshop-mobile','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(129248,'printshop-mobile','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(129249,'printshop-mobile','.b-form #shipping-address .radio-buttons','margin-bottom','10','','','.b-form'),(129250,'printshop-mobile','.b-form .radio-buttons','margin-bottom','20','','','.b-form'),(129251,'printshop-mobile','.p-quote-cart-index .w-quote-checkout-btn','margin-bottom','20','','','.p-quote-cart-index'),(129252,'printshop-mobile','.p-wedding-registry-index .main-content','margin-bottom','20','','','.p-wedding-registry-index'),(129253,'printshop-mobile','.p-wedding-registry-index .search-list','margin-bottom','10','','','.p-wedding-registry-index'),(129254,'printshop-mobile','.b-form .form-inputs label > span','margin-bottom','3','','','.b-form'),(129255,'printshop-mobile','.p-wedding-registry-index .search-list label','margin-bottom','10','','','.p-wedding-registry-index'),(129256,'printshop-mobile','.b-form .addresses','margin-bottom','20','','','.b-form'),(129257,'printshop-mobile','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(129258,'printshop-mobile','.p-wedding-registry-manage .wedding-date','margin-bottom','30','','','.p-wedding-registry-manage'),(129259,'printshop-mobile','.p-wedding-registry-search .result-table','margin-bottom','50','','','.p-wedding-registry-search'),(129260,'printshop-mobile','.p-wedding-registry-search .search-form','margin-bottom','30','','','.p-wedding-registry-search'),(129261,'printshop-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','margin-bottom','10','','','.p-account-address-book'),(129262,'printshop-mobile','.p-account-history .order_history_table h2','margin-bottom','8','','','.p-account-history'),(129263,'printshop-mobile','.p-account-address-book .address_book_row .column + .column, .p-account-address-book .topInfo > div + div','margin-bottom','15','','','.p-account-address-book'),(129264,'printshop-mobile','.p-account-history .buttonBox','margin-bottom','15','','','.p-account-history'),(129265,'printshop-mobile','.p-account-address-book .buttonBox .info','margin-bottom','0','','','.p-account-address-book'),(129266,'printshop-mobile','.p-account-address-book .address_book_row h2 a','margin-bottom','0','','','.p-account-address-book'),(129267,'printshop-mobile','.p-account-address-book .address_book h2','margin-bottom','15','','','.p-account-address-book'),(129268,'printshop-mobile','.p-account-address-book .address_book h1','margin-bottom','18','','','.p-account-address-book'),(129269,'printshop-mobile','.p-account-address-book .address_book .row-buttons a','margin-bottom','0','','','.p-account-address-book'),(129270,'printshop-mobile','.b-compare .clear_all','margin-bottom','0','4','','.b-compare'),(129271,'printshop-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin-bottom','0','','','.b-compare'),(129272,'printshop-mobile','.b-compare .col-two','margin-bottom','15','','','.b-compare'),(129273,'printshop-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-bottom','0','','','.b-switch'),(129274,'printshop-mobile','.p-account-edit .buttons','margin-bottom','20','','','.p-account-edit'),(129275,'printshop-mobile','.p-account-address-book .address_book_row .column','margin-bottom','12','693','','.p-account-address-book'),(129276,'printshop-mobile','.p-account-address-book .topInfo > div','margin-bottom','12','693','','.p-account-address-book'),(129277,'printshop-mobile','.p-account-history-info .history_info > div','margin-bottom','12','694','','.p-account-history-info'),(129278,'printshop-mobile','.w-top-categories .categories','margin-bottom','0','695','','.w-top-categories'),(129279,'printshop-mobile','.p-account-index .account_info','margin-bottom','20','706','','.p-account-index'),(129280,'printshop-mobile','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(129281,'printshop-mobile','.w-breadcrumb .breadcrumb-li','margin-bottom','0','','','.w-breadcrumb'),(129282,'printshop-mobile','.w-list-type-1_3 .qty-input','margin-bottom','10','','','.w-list-type-1_3'),(129283,'printshop-mobile','.heading-3, h3','margin-bottom','10','','',''),(129284,'printshop-mobile','.heading-2, h2','margin-bottom','15','','',''),(129285,'printshop-mobile','h1','margin-bottom','18','','',''),(129286,'printshop-mobile','.heading-4, h4','margin-bottom','5','','',''),(129287,'printshop-mobile','.w-list-type-1_3 .properties','margin-bottom','5','','','.w-list-type-1_3'),(129288,'printshop-mobile','.w-tabs .tab-li','margin-bottom','0','','','.w-tabs'),(129289,'printshop-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-bottom','0','','','.b-form'),(129290,'printshop-mobile','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(129291,'printshop-mobile','.w-top-categories .categories','margin-bottom','0','','','.w-top-categories'),(129292,'printshop-mobile','.w-tabs .tab-navigation','margin-bottom','0','','','.w-tabs'),(129293,'printshop-mobile','.p-account-trade-form .widget h3','margin-bottom','10','','','.p-account-trade-form'),(129294,'printshop-mobile','.p-account-trade-form .widget','margin-bottom','20','','','.p-account-trade-form'),(129295,'printshop-mobile','.p-blog-index .nav-previous a','margin-bottom','0','3','','.p-blog-index'),(129296,'printshop-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-bottom','0','','','.p-blog-index'),(129297,'printshop-mobile','.p-blog-index .wp-widget li','margin-bottom','0','3','','.p-blog-index'),(129298,'printshop-mobile','.p-account-trade-form .wl-td','margin-bottom','10','','','.p-account-trade-form'),(129299,'printshop-mobile','.p-blog-index .post-thumbnail','margin-bottom','20','','','.p-blog-index'),(129300,'printshop-mobile','.p-checkout-index .shipping-address, .p-checkout-index .billing-address','margin-bottom','30','','','.p-checkout-index'),(129301,'printshop-mobile','.p-blog-index .wp-widget ul','margin-bottom','0','','','.p-blog-index'),(129302,'printshop-mobile','.p-blog-index .wp-widget li','margin-bottom','0','','','.p-blog-index'),(129303,'printshop-mobile','.p-blog-index .nav-next a','margin-bottom','0','3','','.p-blog-index'),(129304,'printshop-mobile','.p-checkout-index .buttons','margin-bottom','20','','','.p-checkout-index'),(129305,'printshop-mobile','.p-checkout-index .shipping-estimator .info','margin-bottom','20','','','.p-checkout-index'),(129306,'printshop-mobile','.p-reviews-info .review-info-content','margin-bottom','20','','','.p-reviews-info'),(129307,'printshop-mobile','.p-reviews-info .review-info-reviewed_by','margin-bottom','0','','','.p-reviews-info'),(129308,'printshop-mobile','.p-reviews-info .review-info-text','margin-bottom','20','','','.p-reviews-info'),(129309,'printshop-mobile','.p-reviews-info .review-info-image','margin-bottom','0','','','.p-reviews-info'),(129310,'printshop-mobile','.p-reviews-info .reviews-info h1','margin-bottom','10','','','.p-reviews-info'),(129311,'printshop-mobile','.p-account-address-book .address_book_row .column + .column','margin-bottom','12','693','','.p-account-address-book'),(129312,'printshop-mobile','.p-account-address-book .topInfo > div + div','margin-bottom','12','693','','.p-account-address-book'),(129313,'printshop-mobile','.p-checkout-confirmation .confirm-info','margin-bottom','20','','','.p-checkout-confirmation'),(129314,'printshop-mobile','.w-filters .filter-box-head','margin-bottom','15','','','.w-filters'),(129315,'printshop-mobile','.p-account-address-book-process .buttons','margin-bottom','20','','','.p-account-address-book-process'),(129316,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap','margin-bottom','-35','','','.b-fancybox'),(129317,'printshop-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','margin-bottom','10','','','.p-account-trade-form'),(129318,'printshop-mobile','.p-account-trade-form .trade-form-area','margin-bottom','20','','','.p-account-trade-form'),(129319,'printshop-mobile','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(129320,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-bottom','8','','','.p-account-subscription-historyinfo'),(129321,'printshop-mobile','.p-account-index .account_info li','margin-bottom','20','','','.p-account-index'),(129322,'printshop-mobile','.p-account-password .buttonedit','margin-bottom','0','','','.p-account-password'),(129323,'printshop-mobile','.p-account-index .view_history','margin-bottom','0','3','','.p-account-index'),(129324,'printshop-mobile','.p-account-index .topAccount','margin-bottom','30','','','.p-account-index'),(129325,'printshop-mobile','.w-html_box .socials a','margin-bottom','0','','','.w-html_box'),(129326,'printshop-mobile','.w-info-content p','margin-bottom','10','','','.w-info-content'),(129327,'printshop-mobile','.w-filters .input-checkbox','margin-bottom','0','','','.w-filters'),(129328,'printshop-mobile','.p-checkout-confirmation .buttons','margin-bottom','20','','','.p-checkout-confirmation'),(129329,'printshop-mobile','.p-account-password .buttons','margin-bottom','20','','','.p-account-password'),(129330,'printshop-mobile','.p-checkout-index .discount-box','margin-bottom','20','','','.p-checkout-index'),(129331,'printshop-mobile','.w-categories .categories','margin-bottom','0','','','.w-categories'),(129332,'printshop-mobile','.w-cart-discount-coupon .gift-code p','margin-bottom','0','','','.w-cart-discount-coupon'),(129333,'printshop-mobile','.w-cart-give-away .ga_attributes > div','margin-bottom','1','','','.w-cart-give-away'),(129334,'printshop-mobile','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(129335,'printshop-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(129336,'printshop-mobile','.w-product-in-bundles .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(129337,'printshop-mobile','.w-product-quantity .qty_packs .price_1','margin-bottom','0','4','','.w-product-quantity'),(129338,'printshop-mobile','.w-product-configurator .pc_row','margin-bottom','20','','','.w-product-configurator'),(129339,'printshop-mobile','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(129340,'printshop-mobile','.w-product-bundle .bundle_item','margin-bottom','0','','','.w-product-bundle'),(129341,'printshop-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(129342,'printshop-mobile','.w-product-bundle .bundle_item + .bundle_item','margin-bottom','0','','','.w-product-bundle'),(129343,'printshop-mobile','.w-menu-style-1 ul','margin-bottom','0','','','.w-menu-style-1'),(129344,'printshop-mobile','.w-menu-style-1 li','margin-bottom','0','','','.w-menu-style-1'),(129345,'printshop-mobile','.w-sale .ends','margin-bottom','20','','','.w-sale'),(129346,'printshop-mobile','.w-sale .left','margin-bottom','30','','','.w-sale'),(129347,'printshop-mobile','.w-product-reviews .reviews-list','margin-bottom','10','','','.w-product-reviews'),(129348,'printshop-mobile','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(129349,'printshop-mobile','.w-categories .categories h2','margin-bottom','0','','','.w-categories'),(129350,'printshop-mobile','.w-top-categories .categories h2','margin-bottom','0','','','.w-top-categories'),(129351,'printshop-mobile','.b-form .col-full-padding','margin-bottom','10','','','.b-form'),(129352,'printshop-mobile','.b-form .terms-login .bootstrap-switch','margin-bottom','0','','','.b-form'),(129353,'printshop-mobile','.b-form .col-full-margin','margin-bottom','10','','','.b-form'),(129354,'printshop-mobile','.b-slick .slick-list','margin-bottom','0','','','.b-slick'),(129355,'printshop-mobile','.w-socials > li','margin-bottom','10','','','.w-socials'),(129356,'printshop-mobile','.w-list-type-1_3 .image','margin-bottom','10','694','','.w-list-type-1_3'),(129357,'printshop-mobile','.w-menu-horizontal li','margin-bottom','0','','','.w-menu-horizontal'),(129358,'printshop-mobile','.w-list-type-1_3 .price','margin-bottom','10','','','.w-list-type-1_3'),(129359,'printshop-mobile','.b-form #frmCheckout','margin-bottom','20','','','.b-form'),(129360,'printshop-mobile','.w-categories .categories','margin-bottom','0','693','','.w-categories'),(129361,'printshop-mobile','.w-categories .categories','margin-bottom','0','695','','.w-categories'),(129362,'printshop-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-bottom','0','','','.b-fancybox'),(129363,'printshop-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-bottom','0','','','.b-fancybox'),(129364,'printshop-mobile','.w-cart-give-away .ga_wrapper','margin-bottom','25','','','.w-cart-give-away'),(129365,'printshop-mobile','.w-top-categories .categories','margin-bottom','0','693','','.w-top-categories'),(129366,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-2'),(129367,'printshop-mobile','.w-list-type-1_3 .title','margin-bottom','10','','','.w-list-type-1_3'),(129368,'printshop-mobile','.w-list-type-2 .image','margin-bottom','20','','','.w-list-type-2'),(129369,'printshop-mobile','.w-list-type-2 .description','margin-bottom','5','','','.w-list-type-2'),(129370,'printshop-mobile','.w-list-type-1_3 .description','margin-bottom','5','','','.w-list-type-1_3'),(129371,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-1_3'),(129372,'printshop-mobile','.w-list-type-1_3 .attributes > .attributes > div','margin-bottom','5','','','.w-list-type-1_3'),(129373,'printshop-mobile','.w-list-type-1_2 .title','margin-bottom','10','','','.w-list-type-1_2'),(129374,'printshop-mobile','.w-list-type-1_2 .qty-input','margin-bottom','10','','','.w-list-type-1_2'),(129375,'printshop-mobile','.w-list-type-1_2 .price','margin-bottom','10','','','.w-list-type-1_2'),(129376,'printshop-mobile','.w-list-type-1_2 .properties','margin-bottom','5','','','.w-list-type-1_2'),(129377,'printshop-mobile','.w-list-type-1_2 .description','margin-bottom','5','','','.w-list-type-1_2'),(129378,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-1_2'),(129379,'printshop-mobile','.b-bottom .content-item','margin-bottom','20','','','.b-bottom'),(129380,'printshop-mobile','.b-bottom .pop-up-content .buttons','margin-bottom','0','','','.b-bottom'),(129381,'printshop-mobile','.w-list-type-1 .title','margin-bottom','10','','','.w-list-type-1'),(129382,'printshop-mobile','.w-list-type-1 .description','margin-bottom','5','','','.w-list-type-1'),(129383,'printshop-mobile','.w-list-type-1 .price','margin-bottom','10','','','.w-list-type-1'),(129384,'printshop-mobile','.w-list-type-1 .qty-input','margin-bottom','10','','','.w-list-type-1'),(129385,'printshop-mobile','.w-list-type-1 .properties','margin-bottom','5','','','.w-list-type-1'),(129386,'printshop-mobile','.w-list-type-1 .image','margin-bottom','20','','','.w-list-type-1'),(129387,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-1'),(129388,'printshop-mobile','.w-filters .ui-slider','margin-bottom','0','','','.w-filters'),(129389,'printshop-mobile','.w-reviews .heading-3','margin-bottom','10','','','.w-reviews'),(129390,'printshop-mobile','.w-reviews .name','margin-bottom','20','','','.w-reviews'),(129391,'printshop-mobile','.w-product-reviews .reviews-list .name','margin-bottom','20','','','.w-product-reviews'),(129392,'printshop-mobile','.w-reviews .reviews-list .name','margin-bottom','20','','','.w-reviews'),(129393,'printshop-mobile','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(129394,'printshop-mobile','.b-form .payment-method .item-radio','margin-bottom','5','','','.b-form'),(129395,'printshop-mobile','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','margin-bottom','15','','','.b-form'),(129396,'printshop-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin-bottom','10','','','.b-form'),(129397,'printshop-mobile','.b-form .required-message-wrap','margin-bottom','0','','','.b-form'),(129398,'printshop-mobile','.b-form .required-message','margin-bottom','0','','','.b-form'),(129399,'printshop-mobile','.b-info .info li','margin-bottom','0','','','.b-info'),(129400,'printshop-mobile','.b-info .info ul','margin-bottom','0','','','.b-info'),(129401,'printshop-mobile','.b-products-listing .products-listing .bonusPoints','margin-bottom','7','','','.b-products-listing'),(129402,'printshop-mobile','.b-products-listing .products-listing .description','margin-bottom','5','','','.b-products-listing'),(129403,'printshop-mobile','.b-products-listing .products-listing .description ul','margin-bottom','0','','','.b-products-listing'),(129404,'printshop-mobile','.b-products-listing .products-listing .model','margin-bottom','5','','','.b-products-listing'),(129405,'printshop-mobile','.b-products-listing .products-listing .mult-qty-input','margin-bottom','3','','','.b-products-listing'),(129406,'printshop-mobile','.b-products-listing .products-listing .name','margin-bottom','5','','','.b-products-listing'),(129407,'printshop-mobile','.b-products-listing .products-listing h2','margin-bottom','0','','','.b-products-listing'),(129408,'printshop-mobile','.b-products-listing .promos-info','margin-bottom','-30','','','.b-products-listing'),(129409,'printshop-mobile','.b-products-listing .select-attributes','margin-bottom','10','','','.b-products-listing'),(129410,'printshop-mobile','.b-products-listing .select-attributes select','margin-bottom','0','','','.b-products-listing'),(129411,'printshop-mobile','.b-products-listing .wedding-registry-count','margin-bottom','10','','','.b-products-listing'),(129412,'printshop-mobile','.b-delete-account .delete-box > div','margin-bottom','10','','','.b-delete-account'),(129413,'printshop-mobile','.b-delete-account .delete-box span','margin-bottom','0','','','.b-delete-account'),(129414,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(129415,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(129416,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(129417,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(129418,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(129419,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(129420,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-bottom','0','','','.b-h-inline'),(129421,'printshop-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-bottom','0','','','.b-menu-style'),(129422,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','margin-bottom','5','','','.b-menu-style-1'),(129423,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages','margin-bottom','10','','','.b-menu-style-2'),(129424,'printshop-mobile','.b-messages .messMenuButtonTop','margin-bottom','-39','','','.b-messages'),(129425,'printshop-mobile','.b-messages .dataTables_wrapper > .top','margin-bottom','8','','','.b-messages'),(129426,'printshop-mobile','.b-messages .messages-menu ul','margin-bottom','0','','','.b-messages'),(129427,'printshop-mobile','.b-messages .messages-sidebar .heading-2','margin-bottom','20','','','.b-messages'),(129428,'printshop-mobile','.b-messages .messages-sidebar .btn-2','margin-bottom','20','','','.b-messages'),(129429,'printshop-mobile','.b-messages .messages-menu li','margin-bottom','0','','','.b-messages'),(129430,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-bottom','5','','','.b-messages'),(129431,'printshop-mobile','.b-personal-catalog-popup #personal_catalog_popup .lists-message-box','margin-bottom','20','','','.b-personal-catalog-popup'),(129432,'printshop-mobile','.b-select-suggest .select2-search input','margin-bottom','0','','','.b-select-suggest'),(129433,'printshop-mobile','.b-select-suggest .select2-search','margin-bottom','0','','','.b-select-suggest'),(129434,'printshop-mobile','.b-select-suggest .select2-drop-mask','margin-bottom','0','','','.b-select-suggest'),(129435,'printshop-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-bottom','0','','','.b-select-suggest'),(129436,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-bottom','0','','','.b-select-suggest'),(129437,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-bottom','0','','','.b-select-suggest'),(129438,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-bottom','0','','','.b-select-suggest'),(129439,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-bottom','1','','','.b-select-suggest'),(129440,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','margin-bottom','0','','','.b-select-suggest'),(129441,'printshop-mobile','.b-select-suggest .select2-container','margin-bottom','0','','','.b-select-suggest'),(129442,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(129443,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(129444,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(129445,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(129446,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(129447,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(129448,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(129449,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(129450,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(129451,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(129452,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(129453,'printshop-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(129454,'printshop-mobile','.b-trade-approval .steps-bar','margin-bottom','25','','','.b-trade-approval'),(129455,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','margin-bottom','15','','','.b-trade-approval'),(129456,'printshop-mobile','.b-trade-approval .middle-form textarea','margin-bottom','15','','','.b-trade-approval'),(129457,'printshop-mobile','.b-upload-files .upload-files','margin-bottom','20','','','.b-upload-files'),(129458,'printshop-mobile','.b-warehouses-popup .warehouses-popup .heading','margin-bottom','20','','','.b-warehouses-popup'),(129459,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-bottom','20','','','.b-warehouses-popup'),(129460,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing','margin-bottom','0','','','.batchPr'),(129461,'printshop-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(129462,'printshop-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(129463,'printshop-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(129464,'printshop-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(129465,'printshop-mobile','.p-account-samples-history .buttonBox','margin-bottom','15','','','.p-account-samples-history'),(129466,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-bottom','8','','','.p-account-samples-history'),(129467,'printshop-mobile','.p-account-samples-history .buttonBox','margin-bottom','15','','','.p-account-samples-history'),(129468,'printshop-mobile','.p-account-samples-history .orders-table .item','margin-bottom','10','','','.p-account-samples-history'),(129469,'printshop-mobile','.p-account-samples-history .orders-table .item','margin-bottom','10','','','.p-account-samples-history'),(129470,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-bottom','8','','','.p-account-samples-history'),(129471,'printshop-mobile','.p-account-samples-history .orders-table .item','margin-bottom','10','','','.p-account-samples-history'),(129472,'printshop-mobile','.p-account-samples-history .buttonBox','margin-bottom','15','','','.p-account-samples-history'),(129473,'printshop-mobile','.p-account-samples-history .buttonBox','margin-bottom','15','','','.p-account-samples-history'),(129474,'printshop-mobile','.p-account-samples-history .buttonBox','margin-bottom','15','','','.p-account-samples-history'),(129475,'printshop-mobile','.p-account-samples-history .orders-table .item','margin-bottom','10','','','.p-account-samples-history'),(129476,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-bottom','8','','','.p-account-samples-history'),(129477,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-bottom','8','','','.p-account-samples-history'),(129478,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-bottom','8','','','.p-account-samples-history'),(129479,'printshop-mobile','.p-account-samples-history .buttonBox','margin-bottom','15','','','.p-account-samples-history'),(129480,'printshop-mobile','.p-account-samples-history .orders-table .item','margin-bottom','10','','','.p-account-samples-history'),(129481,'printshop-mobile','.p-account-samples-history .orders-table .item','margin-bottom','10','','','.p-account-samples-history'),(129482,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-bottom','8','','','.p-account-samples-history'),(129483,'printshop-mobile','.p-account-samples-history-info .history_info','margin-bottom','20','','','.p-account-samples-history-info'),(129484,'printshop-mobile','.p-account-samples-history-info .buttons','margin-bottom','20','','','.p-account-samples-history-info'),(129485,'printshop-mobile','.p-account-samples-history-info .buttons','margin-bottom','20','','','.p-account-samples-history-info'),(129486,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-bottom','12','','','.p-account-samples-history-info'),(129487,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-bottom','12','','','.p-account-samples-history-info'),(129488,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-bottom','12','','','.p-account-samples-history-info'),(129489,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-bottom','12','','','.p-account-samples-history-info'),(129490,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-bottom','12','','','.p-account-samples-history-info'),(129491,'printshop-mobile','.p-account-samples-history-info .history_info','margin-bottom','20','','','.p-account-samples-history-info'),(129492,'printshop-mobile','.p-account-samples-history-info .history_info','margin-bottom','20','','','.p-account-samples-history-info'),(129493,'printshop-mobile','.p-account-samples-history-info .buttons','margin-bottom','20','','','.p-account-samples-history-info'),(129494,'printshop-mobile','.p-account-samples-history-info .buttons','margin-bottom','20','','','.p-account-samples-history-info'),(129495,'printshop-mobile','.p-account-samples-history-info .history_info','margin-bottom','20','','','.p-account-samples-history-info'),(129496,'printshop-mobile','.p-account-samples-history-info .buttons','margin-bottom','20','','','.p-account-samples-history-info'),(129497,'printshop-mobile','.p-account-samples-history-info .buttons','margin-bottom','20','','','.p-account-samples-history-info'),(129498,'printshop-mobile','.p-account-samples-history-info .history_info','margin-bottom','20','','','.p-account-samples-history-info'),(129499,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-bottom','12','','','.p-account-samples-history-info'),(129500,'printshop-mobile','.p-account-samples-history-info .history_info','margin-bottom','20','','','.p-account-samples-history-info'),(129501,'printshop-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(129502,'printshop-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(129503,'printshop-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(129504,'printshop-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(129505,'printshop-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(129506,'printshop-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(129507,'printshop-mobile','.p-catalog-product .pn-direction','margin-bottom','15','','','.p-catalog-product'),(129508,'printshop-mobile','.p-payer-order-confirmation .input-wrapper','margin-bottom','10','','','.p-payer-order-confirmation'),(129509,'printshop-mobile','.p-payer-order-confirmation .dob-hide','margin-bottom','-10','','','.p-payer-order-confirmation'),(129510,'printshop-mobile','.p-payer-order-pay .input-wrapper','margin-bottom','10','','','.p-payer-order-pay'),(129511,'printshop-mobile','.p-payer-order-pay .dob-hide','margin-bottom','-10','','','.p-payer-order-pay'),(129512,'printshop-mobile','.p-quick-order-index ul.token-input-list','margin-bottom','0','','','.p-quick-order-index'),(129513,'printshop-mobile','.p-quick-order-index .filters','margin-bottom','20','','','.p-quick-order-index'),(129514,'printshop-mobile','.w-account-address-book .name','margin-bottom','5','','','.w-account-address-book'),(129515,'printshop-mobile','.w-account-address-book .address-wrapper','margin-bottom','20','','','.w-account-address-book'),(129516,'printshop-mobile','.w-account-address-book .address-book','margin-bottom','0','','','.w-account-address-book'),(129517,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(129518,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(129519,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(129520,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(129521,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(129522,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(129523,'printshop-mobile','.w-account-customer-additional-field .field-type-text','margin-bottom','10','','','.w-account-customer-additional-field'),(129524,'printshop-mobile','.w-account-customer-additional-field .field-type-checkbox','margin-bottom','10','','','.w-account-customer-additional-field'),(129525,'printshop-mobile','.w-account-personal-catalog .list-switcher','margin-bottom','20','','','.w-account-personal-catalog'),(129526,'printshop-mobile','.w-account-subscription .send-email','margin-bottom','20','','','.w-account-subscription'),(129527,'printshop-mobile','.w-account-subscription .subscription-list','margin-bottom','20','','','.w-account-subscription'),(129528,'printshop-mobile','.w-blog-widget-post-image ','margin-bottom','20','','','.w-blog-widget-post-image'),(129529,'printshop-mobile','.w-blog-widget-post-linked-products .heading-2','margin-bottom','25','','','.w-blog-widget-post-linked-products'),(129530,'printshop-mobile','.w-blog-widget-post-listing .post_content','margin-bottom','40','','','.w-blog-widget-post-listing'),(129531,'printshop-mobile','.w-blog-widget-post-listing .post_date span + span','margin-bottom','0','3','','.w-blog-widget-post-listing'),(129532,'printshop-mobile','.w-blog-widget-post-listing .post_name','margin-bottom','10','','','.w-blog-widget-post-listing'),(129533,'printshop-mobile','.w-blog-widget-post-listing ','margin-bottom','0','','','.w-blog-widget-post-listing'),(129534,'printshop-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-bottom','0','','','.w-blog-widget-post-share'),(129535,'printshop-mobile','.w-blog-widget-post-title ','margin-bottom','20','','','.w-blog-widget-post-title'),(129536,'printshop-mobile','.w-blog-widget-post-title h1','margin-bottom','0','','','.w-blog-widget-post-title'),(129537,'printshop-mobile','.w-cart-cart-tabs .w-tabs .tab-navigation','margin-bottom','25','','','.w-cart-cart-tabs'),(129538,'printshop-mobile','.w-cart-compare .product .image','margin-bottom','10','','','.w-cart-compare'),(129539,'printshop-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(129540,'printshop-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(129541,'printshop-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(129542,'printshop-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(129543,'printshop-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(129544,'printshop-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(129545,'printshop-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-bottom','0','','','.w-catalog-additional-images'),(129546,'printshop-mobile','.w-catalog-compare .cross-box .return','margin-bottom','30','','','.w-catalog-compare'),(129547,'printshop-mobile','.w-catalog-items-on-page select','margin-bottom','0','','','.w-catalog-items-on-page'),(129548,'printshop-mobile','.w-checkout-billing-address .addresses .address-item','margin-bottom','10','','','.w-checkout-billing-address'),(129549,'printshop-mobile','.w-checkout-billing-address .same-address','margin-bottom','10','','','.w-checkout-billing-address'),(129550,'printshop-mobile','.w-checkout-billing-address .genders-title','margin-bottom','5','','','.w-checkout-billing-address'),(129551,'printshop-mobile','.w-checkout-create-account .heading-2','margin-bottom','0','','','.w-checkout-create-account'),(129552,'printshop-mobile','.w-checkout-gdpr .privacy-row','margin-bottom','0','','','.w-checkout-gdpr'),(129553,'printshop-mobile','.w-checkout-gdpr .col-left','margin-bottom','20','','','.w-checkout-gdpr'),(129554,'printshop-mobile','.w-checkout-shipping-address #shippingchoice-choice','margin-bottom','10','','','.w-checkout-shipping-address'),(129555,'printshop-mobile','.w-checkout-shipping-address .genders-title','margin-bottom','5','','','.w-checkout-shipping-address'),(129556,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item','margin-bottom','10','','','.w-checkout-shipping-address'),(129557,'printshop-mobile','.w-communication-new-topic #communication_group_holder input, .w-communication-new-topic select','margin-bottom','0','','','.w-communication-new-topic'),(129558,'printshop-mobile','.w-communication-new-topic #rmaProductReturnButtonFilterHolder','margin-bottom','30','','','.w-communication-new-topic'),(129559,'printshop-mobile','.w-communication-new-topic .privacy-row','margin-bottom','10','','','.w-communication-new-topic'),(129560,'printshop-mobile','.w-communication-new-topic .text-container','margin-bottom','20','','','.w-communication-new-topic'),(129561,'printshop-mobile','.w-communication-post .communication-post','margin-bottom','5','','','.w-communication-post'),(129562,'printshop-mobile','.w-communication-post .communication-post-message','margin-bottom','20','','','.w-communication-post'),(129563,'printshop-mobile','.w-communication-post .text-container','margin-bottom','20','','','.w-communication-post'),(129564,'printshop-mobile','.w-delivery-day .time-left','margin-bottom','30','','','.w-delivery-day'),(129565,'printshop-mobile','.w-delivery-day .ends','margin-bottom','20','','','.w-delivery-day'),(129566,'printshop-mobile','.w-image-maps .categories-items .item .title','margin-bottom','10','','','.w-image-maps'),(129567,'printshop-mobile','.w-image-maps .float-items .item .title','margin-bottom','10','','','.w-image-maps'),(129568,'printshop-mobile','.w-image-maps .default-links .item .title','margin-bottom','10','','','.w-image-maps'),(129569,'printshop-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(129570,'printshop-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(129571,'printshop-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(129572,'printshop-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(129573,'printshop-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(129574,'printshop-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(129575,'printshop-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(129576,'printshop-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(129577,'printshop-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(129578,'printshop-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(129579,'printshop-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(129580,'printshop-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(129581,'printshop-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(129582,'printshop-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(129583,'printshop-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(129584,'printshop-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(129585,'printshop-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(129586,'printshop-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(129587,'printshop-mobile','.w-promotions .prom-multi-discount .heading','margin-bottom','10','','','.w-promotions'),(129588,'printshop-mobile','.w-promotions .nextdiscount .promo-for-each','margin-bottom','10','','','.w-promotions'),(129589,'printshop-mobile','.w-promotions .nextdiscount .heading','margin-bottom','20','','','.w-promotions'),(129590,'printshop-mobile','.w-promotions .promo-cart-discount .master .heading','margin-bottom','10','','','.w-promotions'),(129591,'printshop-mobile','.w-promotions .promo-cart-discount .master .item','margin-bottom','12','','','.w-promotions'),(129592,'printshop-mobile','.w-promotions .promo-date','margin-bottom','10','','','.w-promotions'),(129593,'printshop-mobile','.w-promotions .promo-item','margin-bottom','30','','','.w-promotions'),(129594,'printshop-mobile','.w-promotions .promo-salemaker .item','margin-bottom','2','','','.w-promotions'),(129595,'printshop-mobile','.w-promotions .promo-cart-discount .slave .item','margin-bottom','2','','','.w-promotions'),(129596,'printshop-mobile','.w-promotions .heading-3','margin-bottom','20','','','.w-promotions'),(129597,'printshop-mobile','.w-reviews-content .reviews-list','margin-bottom','20','','','.w-reviews-content'),(129598,'printshop-mobile','.w-sitemap-delivery-location > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(129599,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(129600,'printshop-mobile','.w-social-links a','margin-bottom','0','','','.w-social-links'),(129601,'printshop-mobile','.w-taxable select','margin-bottom','0','','','.w-taxable'),(129602,'printshop-mobile','.w-taxable label','margin-bottom','0','','','.w-taxable'),(129603,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','margin-bottom','20','','','.w-upload-customer-id-upload-customer-id-form'),(129604,'printshop-mobile','.w-wedding-registry-widgets-products .select-box, .w-wedding-registry-widgets-products .name','margin-bottom','10','','','.w-wedding-registry-widgets-products'),(129605,'printshop-mobile','.w-list-type-1_3 .rating-count','margin-left','5','','','.w-list-type-1_3'),(129606,'printshop-mobile','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(129607,'printshop-mobile','.w-menu .hided.menu ul li','margin-left','0','','','.w-menu'),(129608,'printshop-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-left','0','','','.w-menu'),(129609,'printshop-mobile','.w-catalog-listing-look .list','margin-left','5','','','.w-catalog-listing-look'),(129610,'printshop-mobile','.w-menu-big li','margin-left','0','','','.w-menu-big'),(129611,'printshop-mobile','.w-menu-big ul','margin-left','0','','','.w-menu-big'),(129612,'printshop-mobile','.w-menu-slider ul, .w-menu-slider li','margin-left','0','','','.w-menu-slider'),(129613,'printshop-mobile','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(129614,'printshop-mobile','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(129615,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(129616,'printshop-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-left','0','','','.b-cookie-notice'),(129617,'printshop-mobile','.b-form .checkbox-style','margin-left','0','','','.b-form'),(129618,'printshop-mobile','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(129619,'printshop-mobile','.w-product-sale-ends .left-count','margin-left','2','','','.w-product-sale-ends'),(129620,'printshop-mobile','.w-product-sale-ends .left-text-right','margin-left','2','','','.w-product-sale-ends'),(129621,'printshop-mobile','.w-filters .input-checkbox','margin-left','0','','','.w-filters'),(129622,'printshop-mobile','.w-filters .filter-ul-content','margin-left','0','','','.w-filters'),(129623,'printshop-mobile','.w-categories .categories','margin-left','-20','','','.w-categories'),(129624,'printshop-mobile','.w-cart .image','margin-left','-90','','','.w-cart'),(129625,'printshop-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','margin-left','0','','','.p-account-address-book'),(129626,'printshop-mobile','.p-account-history .order_history_table h2','margin-left','0','','','.p-account-history'),(129627,'printshop-mobile','.p-account-history-info .history_info','margin-left','0','','','.p-account-history-info'),(129628,'printshop-mobile','.p-account-index .account_page h1','margin-left','0','','','.p-account-index'),(129629,'printshop-mobile','.p-account-index .account_info','margin-left','0','','','.p-account-index'),(129630,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-left','0','','','.p-account-subscription-historyinfo'),(129631,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','margin-left','15','4','','.b-multi-page-checkout'),(129632,'printshop-mobile','.w-cart-give-away .ga_column','margin-left','0','693','','.w-cart-give-away'),(129633,'printshop-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','margin-left','1','','','.b-product-images'),(129634,'printshop-mobile','.w-list-type-1_2 .right-area .right-area-2','margin-left','2','','','.w-list-type-1_2'),(129635,'printshop-mobile','.w-list-type-1_2 .right-area .right-area-2','margin-left','0','694','','.w-list-type-1_2'),(129636,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-left','0','','','.b-multi-page-checkout'),(129637,'printshop-mobile','.w-search .search-input','margin-left','0','','','.w-search'),(129638,'printshop-mobile','.w-socials .post_item_img','margin-left','0','','','.w-socials'),(129639,'printshop-mobile','.w-delivery-location-top-location-list','margin-left','0','','','.w-delivery-location-top-location-list'),(129640,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList','margin-left','-1','','','.w-delivery-location-top-location-list'),(129641,'printshop-mobile','.b-form .columns .col-2:nth-child(2n)','margin-left','0','723','','.b-form'),(129642,'printshop-mobile','.p-account-order-pay .buttons','margin-left','0','','','.p-account-order-pay'),(129643,'printshop-mobile','.p-account-order-pay .history_info','margin-left','0','','','.p-account-order-pay'),(129644,'printshop-mobile','.p-account-order-pay .history_info > div','margin-left','0','694','','.p-account-order-pay'),(129645,'printshop-mobile','.b-pagination .pagination span','margin-left','5','2','','.b-pagination'),(129646,'printshop-mobile','.b-pagination .pagination .prev-pages','margin-left','5','','','.b-pagination'),(129647,'printshop-mobile','.b-pagination .pagination .page-number','margin-left','5','','','.b-pagination'),(129648,'printshop-mobile','.b-pagination .pagination .prev','margin-left','5','','','.b-pagination'),(129649,'printshop-mobile','.b-bottom .confirm-popup .buttons .btn','margin-left','20','','','.b-bottom'),(129650,'printshop-mobile','.b-pagination .pagination .next-pages','margin-left','5','','','.b-pagination'),(129651,'printshop-mobile','.b-pagination .pagination .next','margin-left','5','','','.b-pagination'),(129652,'printshop-mobile','.p-account-history-info .buttons','margin-left','0','','','.p-account-history-info'),(129653,'printshop-mobile','.w-list-type-1_3 .right-area .right-area-2','margin-left','2','','','.w-list-type-1_3'),(129654,'printshop-mobile','.w-list-type-2_2 .rating-count','margin-left','5','','','.w-list-type-2_2'),(129655,'printshop-mobile','.w-list-type-2 .rating-count','margin-left','5','','','.w-list-type-2'),(129656,'printshop-mobile','.buttons .right-buttons .btn','margin-left','10','','',''),(129657,'printshop-mobile','.w-account ul, .w-account li','margin-left','0','','','.w-account'),(129658,'printshop-mobile','.b-fancybox .fancybox-error','margin-left','0','','','.b-fancybox'),(129659,'printshop-mobile','.w-menu-horizontal ul','margin-left','0','','','.w-menu-horizontal'),(129660,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(129661,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList ul','margin-left','0','','','.w-delivery-location-top-location-list'),(129662,'printshop-mobile','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(129663,'printshop-mobile','.w-chat .w-chat-box','margin-left','5','','','.w-chat'),(129664,'printshop-mobile','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(129665,'printshop-mobile','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(129666,'printshop-mobile','.p-quote-cart-index .w-quote-checkout-btn','margin-left','0','','','.p-quote-cart-index'),(129667,'printshop-mobile','.p-wedding-registry-index .search-list','margin-left','-75','3','','.p-wedding-registry-index'),(129668,'printshop-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-left','0','','','.b-form'),(129669,'printshop-mobile','.p-wedding-registry-manage .links a.share-registry','margin-left','10','4','','.p-wedding-registry-manage'),(129670,'printshop-mobile','.p-wedding-registry-manage .links a.share-registry','margin-left','30','','','.p-wedding-registry-manage'),(129671,'printshop-mobile','.b-pagination .pagination a','margin-left','5','','','.b-pagination'),(129672,'printshop-mobile','.p-account-address-book .buttonBox .info','margin-left','0','','','.p-account-address-book'),(129673,'printshop-mobile','.p-account-history .buttonBox','margin-left','0','','','.p-account-history'),(129674,'printshop-mobile','.p-account-address-book .address_book_row h2 a','margin-left','15','','','.p-account-address-book'),(129675,'printshop-mobile','.p-account-address-book .address_book h2','margin-left','0','','','.p-account-address-book'),(129676,'printshop-mobile','.p-account-address-book .address_book_row .column + .column, .p-account-address-book .topInfo > div + div','margin-left','2','','','.p-account-address-book'),(129677,'printshop-mobile','.p-account-address-book .address_book h1','margin-left','0','','','.p-account-address-book'),(129678,'printshop-mobile','.p-account-address-book .address_book .row-buttons a','margin-left','0','','','.p-account-address-book'),(129679,'printshop-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin-left','0','','','.b-compare'),(129680,'printshop-mobile','.b-compare .clear_all','margin-left','7','4','','.b-compare'),(129681,'printshop-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-left','0','','','.b-switch'),(129682,'printshop-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-left','-20','','','.b-slick'),(129683,'printshop-mobile','.p-account-history-info .history_info > div','margin-left','0','694','','.p-account-history-info'),(129684,'printshop-mobile','.p-account-index .account_info','margin-left','0','706','','.p-account-index'),(129685,'printshop-mobile','.w-top-categories .categories','margin-left','-10','695','','.w-top-categories'),(129686,'printshop-mobile','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(129687,'printshop-mobile','.p-account-address-book .address_book_row .column + .column','margin-left','0','693','','.p-account-address-book'),(129688,'printshop-mobile','.w-tabs .tab-navigation','margin-left','0','','','.w-tabs'),(129689,'printshop-mobile','.w-top-categories .categories','margin-left','-20','','','.w-top-categories'),(129690,'printshop-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-left','0','','','.p-blog-index'),(129691,'printshop-mobile','.p-blog-index .nav-next a','margin-left','0','3','','.p-blog-index'),(129692,'printshop-mobile','.p-blog-index .wp-widget li','margin-left','-15','3','','.p-blog-index'),(129693,'printshop-mobile','.p-blog-index .post-thumbnail','margin-left','0','','','.p-blog-index'),(129694,'printshop-mobile','.p-blog-index .nav-previous a','margin-left','-50','3','','.p-blog-index'),(129695,'printshop-mobile','.p-blog-index .wp-widget ul','margin-left','0','','','.p-blog-index'),(129696,'printshop-mobile','.p-checkout-index .same-address div.bootstrap-switch','margin-left','30','','','.p-checkout-index'),(129697,'printshop-mobile','.p-blog-index .wp-widget li','margin-left','0','','','.p-blog-index'),(129698,'printshop-mobile','.p-reviews-info .review-info-content','margin-left','0','','','.p-reviews-info'),(129699,'printshop-mobile','.p-reviews-info .review-info-text','margin-left','0','','','.p-reviews-info'),(129700,'printshop-mobile','.p-reviews-info .review-info-reviewed_by','margin-left','0','','','.p-reviews-info'),(129701,'printshop-mobile','.p-reviews-info .reviews-info h1','margin-left','0','','','.p-reviews-info'),(129702,'printshop-mobile','.p-reviews-info .review-info-image','margin-left','0','','','.p-reviews-info'),(129703,'printshop-mobile','.p-account-address-book .address_book_row .column','margin-left','0','693','','.p-account-address-book'),(129704,'printshop-mobile','.p-account-address-book .topInfo > div','margin-left','0','693','','.p-account-address-book'),(129705,'printshop-mobile','.p-account-address-book .topInfo > div + div','margin-left','0','693','','.p-account-address-book'),(129706,'printshop-mobile','.w-top-categories .categories','margin-left','0','693','','.w-top-categories'),(129707,'printshop-mobile','.heading-3 .edit, h3 .edit','margin-left','10','4','',''),(129708,'printshop-mobile','.b-slick .slick-track','margin-left','auto','','','.b-slick'),(129709,'printshop-mobile','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(129710,'printshop-mobile','.p-account-trade-form .trade-form-area .btn','margin-left','30','','','.p-account-trade-form'),(129711,'printshop-mobile','.p-account-index .account_info li:nth-child(3n+1)','margin-left','0','','','.p-account-index'),(129712,'printshop-mobile','.p-account-password .buttonedit','margin-left','0','','','.p-account-password'),(129713,'printshop-mobile','.p-account-index .account_info li','margin-left','4.5','','','.p-account-index'),(129714,'printshop-mobile','.p-account-index .view_history','margin-left','0','3','','.p-account-index'),(129715,'printshop-mobile','.w-html_box .socials a','margin-left','5','','','.w-html_box'),(129716,'printshop-mobile','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(129717,'printshop-mobile','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(129718,'printshop-mobile','.w-cart-discount-coupon .gift-code p','margin-left','0','','','.w-cart-discount-coupon'),(129719,'printshop-mobile','.w-breadcrumb .breadcrumb-li','margin-left','0','','','.w-breadcrumb'),(129720,'printshop-mobile','.w-cart-give-away .ga_attributes > div','margin-left','1','','','.w-cart-give-away'),(129721,'printshop-mobile','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(129722,'printshop-mobile','.w-product-quantity .qty_packs .price_1','margin-left','15','4','','.w-product-quantity'),(129723,'printshop-mobile','.w-product-in-bundles .bundle_item','margin-left','0','','','.w-product-in-bundles'),(129724,'printshop-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin-left','2','','','.w-product-in-bundles'),(129725,'printshop-mobile','.w-product-bundle .bundle_item + .bundle_item','margin-left','2','','','.w-product-bundle'),(129726,'printshop-mobile','.w-product-bundle .bundle_item','margin-left','0','','','.w-product-bundle'),(129727,'printshop-mobile','.w-menu-style-1 ul','margin-left','0','','','.w-menu-style-1'),(129728,'printshop-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(129729,'printshop-mobile','.w-menu-style-1 li','margin-left','0','','','.w-menu-style-1'),(129730,'printshop-mobile','.w-sale .left-count','margin-left','2','','','.w-sale'),(129731,'printshop-mobile','.w-sale .left-text-right','margin-left','2','','','.w-sale'),(129732,'printshop-mobile','.w-product-reviews .reviews-list','margin-left','0','','','.w-product-reviews'),(129733,'printshop-mobile','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(129734,'printshop-mobile','.w-top-categories .categories h2','margin-left','0','','','.w-top-categories'),(129735,'printshop-mobile','.w-categories .categories h2','margin-left','0','','','.w-categories'),(129736,'printshop-mobile','.b-form .terms-login .bootstrap-switch','margin-left','0','','','.b-form'),(129737,'printshop-mobile','.b-slick .slick-list','margin-left','0','','','.b-slick'),(129738,'printshop-mobile','.w-socials > li','margin-left','10','','','.w-socials'),(129739,'printshop-mobile','.w-list-type-1_3 .right-area .right-area-2','margin-left','0','694','','.w-list-type-1_3'),(129740,'printshop-mobile','.b-fancybox #fancybox-loading','margin-left','-22','','','.b-fancybox'),(129741,'printshop-mobile','.w-menu-horizontal li','margin-left','0','','','.w-menu-horizontal'),(129742,'printshop-mobile','.w-cart-discount-coupon .gift-code button','margin-left','15','','','.w-cart-discount-coupon'),(129743,'printshop-mobile','.b-form .addresses .address-item:nth-child(2n)','margin-left','4','','','.b-form'),(129744,'printshop-mobile','.b-form .discount-box button','margin-left','15','','','.b-form'),(129745,'printshop-mobile','.w-catalog-listing-look .b2b','margin-left','5','','','.w-catalog-listing-look'),(129746,'printshop-mobile','.w-categories .categories','margin-left','-10','695','','.w-categories'),(129747,'printshop-mobile','.b-form #frmCheckout','margin-left','0','','','.b-form'),(129748,'printshop-mobile','.w-categories .categories','margin-left','0','693','','.w-categories'),(129749,'printshop-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-left','0','','','.b-fancybox'),(129750,'printshop-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-left','0','','','.b-fancybox'),(129751,'printshop-mobile','.w-cart-gift-certificate .gift-code button','margin-left','15','','','.w-cart-gift-certificate'),(129752,'printshop-mobile','.w-cart-give-away .ga_column','margin-left','2','','','.w-cart-give-away'),(129753,'printshop-mobile','.view-all .btn','margin-left','10','4','',''),(129754,'printshop-mobile','.w-list-type-1_2 .rating-count','margin-left','5','','','.w-list-type-1_2'),(129755,'printshop-mobile','.b-bottom .pop-up-content .buttons','margin-left','0','','','.b-bottom'),(129756,'printshop-mobile','.heading-3 .right-text, h3 .right-text','margin-left','10','','',''),(129757,'printshop-mobile','.heading-4 .right-text, h4 .right-text','margin-left','10','','',''),(129758,'printshop-mobile','.w-list-type-1 .rating-count','margin-left','5','','','.w-list-type-1'),(129759,'printshop-mobile','.heading-4 .edit, h4 .edit','margin-left','10','4','',''),(129760,'printshop-mobile','.w-filters .view_more','margin-left','5','4','','.w-filters'),(129761,'printshop-mobile','.b-form .columns .col-2:nth-child(2n)','margin-left','4','','','.b-form'),(129762,'printshop-mobile','.w-tabs .tab-li','margin-left','0','','','.w-tabs'),(129763,'printshop-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin-left','0','','','.b-form'),(129764,'printshop-mobile','.b-form .required-message-wrap','margin-left','0','','','.b-form'),(129765,'printshop-mobile','.b-form .required-message','margin-left','0','','','.b-form'),(129766,'printshop-mobile','.b-info .info','margin-left','-40','3','','.b-info'),(129767,'printshop-mobile','.b-info .info ul','margin-left','0','','','.b-info'),(129768,'printshop-mobile','.b-info .info li','margin-left','0','','','.b-info'),(129769,'printshop-mobile','.p-account-index .topAccount','margin-left','0','','','.p-account-index'),(129770,'printshop-mobile','.b-products-listing .products-listing .bonus-points-cost','margin-left','-20','3','','.b-products-listing'),(129771,'printshop-mobile','.b-products-listing .products-listing .bonus-points-price','margin-left','-20','3','','.b-products-listing'),(129772,'printshop-mobile','.b-products-listing .products-listing .description ul','margin-left','0','','','.b-products-listing'),(129773,'printshop-mobile','.b-products-listing .products-listing h2','margin-left','0','','','.b-products-listing'),(129774,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.b-data-table'),(129775,'printshop-mobile','.b-delete-account .delete-box span','margin-left','10','','','.b-delete-account'),(129776,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(129777,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(129778,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(129779,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(129780,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(129781,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(129782,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(129783,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(129784,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(129785,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(129786,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(129787,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(129788,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-left','0','','','.b-h-inline'),(129789,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(129790,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(129791,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(129792,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(129793,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(129794,'printshop-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-left','0','','','.b-menu-style'),(129795,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','margin-left','5','4','','.b-menu-style-1'),(129796,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','margin-left','10','4','','.b-menu-style-1'),(129797,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > .no-link','margin-left','5','4','','.b-menu-style-3'),(129798,'printshop-mobile','.b-messages .msv_content','margin-left','0','','','.b-messages'),(129799,'printshop-mobile','.b-messages .msv_history','margin-left','0','','','.b-messages'),(129800,'printshop-mobile','.b-messages .messages-menu ul','margin-left','0','','','.b-messages'),(129801,'printshop-mobile','.b-messages .messages-menu li','margin-left','0','','','.b-messages'),(129802,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-left','5','','','.b-messages'),(129803,'printshop-mobile','.b-select-suggest .select2-drop-mask','margin-left','0','','','.b-select-suggest'),(129804,'printshop-mobile','.b-select-suggest .select2-search','margin-left','0','','','.b-select-suggest'),(129805,'printshop-mobile','.b-select-suggest .select2-search input','margin-left','0','','','.b-select-suggest'),(129806,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-left','0','','','.b-select-suggest'),(129807,'printshop-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-left','0','','','.b-select-suggest'),(129808,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-left','0','','','.b-select-suggest'),(129809,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-left','0','','','.b-select-suggest'),(129810,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-left','0','','','.b-select-suggest'),(129811,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','margin-left','0','','','.b-select-suggest'),(129812,'printshop-mobile','.b-select-suggest .select2-container','margin-left','0','','','.b-select-suggest'),(129813,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(129814,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(129815,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(129816,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(129817,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(129818,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(129819,'printshop-mobile','.b-trade-approval .steps-bar','margin-left','0','','','.b-trade-approval'),(129820,'printshop-mobile','.b-trade-approval .col-3 + .col-3','margin-left','3','','','.b-trade-approval'),(129821,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','0','','','.b-warehouses-popup'),(129822,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','-17','3','','.b-warehouses-popup'),(129823,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing','margin-left','0','','','.batchPr'),(129824,'printshop-mobile','.p-account-samples-history .buttonBox','margin-left','0','','','.p-account-samples-history'),(129825,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-left','0','','','.p-account-samples-history'),(129826,'printshop-mobile','.p-account-samples-history .buttonBox','margin-left','0','','','.p-account-samples-history'),(129827,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-left','0','','','.p-account-samples-history'),(129828,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-left','0','','','.p-account-samples-history'),(129829,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-left','0','','','.p-account-samples-history'),(129830,'printshop-mobile','.p-account-samples-history .buttonBox','margin-left','0','','','.p-account-samples-history'),(129831,'printshop-mobile','.p-account-samples-history .buttonBox','margin-left','0','','','.p-account-samples-history'),(129832,'printshop-mobile','.p-account-samples-history .buttonBox','margin-left','0','','','.p-account-samples-history'),(129833,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-left','0','','','.p-account-samples-history'),(129834,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-left','0','','','.p-account-samples-history'),(129835,'printshop-mobile','.p-account-samples-history .buttonBox','margin-left','0','','','.p-account-samples-history'),(129836,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-left','0','','','.p-account-samples-history-info'),(129837,'printshop-mobile','.p-account-samples-history-info .buttons','margin-left','0','','','.p-account-samples-history-info'),(129838,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-left','0','','','.p-account-samples-history-info'),(129839,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-left','0','','','.p-account-samples-history-info'),(129840,'printshop-mobile','.p-account-samples-history-info .buttons','margin-left','0','','','.p-account-samples-history-info'),(129841,'printshop-mobile','.p-account-samples-history-info .history_info','margin-left','0','','','.p-account-samples-history-info'),(129842,'printshop-mobile','.p-account-samples-history-info .buttons','margin-left','0','','','.p-account-samples-history-info'),(129843,'printshop-mobile','.p-account-samples-history-info .buttons','margin-left','0','','','.p-account-samples-history-info'),(129844,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-left','0','','','.p-account-samples-history-info'),(129845,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-left','0','','','.p-account-samples-history-info'),(129846,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-left','0','','','.p-account-samples-history-info'),(129847,'printshop-mobile','.p-account-samples-history-info .history_info','margin-left','0','','','.p-account-samples-history-info'),(129848,'printshop-mobile','.p-account-samples-history-info .history_info','margin-left','0','','','.p-account-samples-history-info'),(129849,'printshop-mobile','.p-account-samples-history-info .history_info','margin-left','0','','','.p-account-samples-history-info'),(129850,'printshop-mobile','.p-account-samples-history-info .history_info','margin-left','0','','','.p-account-samples-history-info'),(129851,'printshop-mobile','.p-account-samples-history-info .buttons','margin-left','0','','','.p-account-samples-history-info'),(129852,'printshop-mobile','.p-account-samples-history-info .buttons','margin-left','0','','','.p-account-samples-history-info'),(129853,'printshop-mobile','.p-account-samples-history-info .history_info','margin-left','0','','','.p-account-samples-history-info'),(129854,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','margin-left','5','','','.p-quick-order-index'),(129855,'printshop-mobile','.p-quick-order-index ul.token-input-list','margin-left','5','','','.p-quick-order-index'),(129856,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.p-quick-order-index'),(129857,'printshop-mobile','.p-quick-order-index .filters .clear','margin-left','15','','','.p-quick-order-index'),(129858,'printshop-mobile','.w-account-address-book .address-book','margin-left','-10','','','.w-account-address-book'),(129859,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(129860,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(129861,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(129862,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(129863,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(129864,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(129865,'printshop-mobile','.w-account-personal-catalog .list-switcher','margin-left','0','','','.w-account-personal-catalog'),(129866,'printshop-mobile','.w-blog-widget-post-listing .post_date span + span','margin-left','10','3','','.w-blog-widget-post-listing'),(129867,'printshop-mobile','.w-blog-widget-post-listing ','margin-left','0','','','.w-blog-widget-post-listing'),(129868,'printshop-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-left','8','','','.w-blog-widget-post-share'),(129869,'printshop-mobile','.w-blog-widget-post-share a.mailto','margin-left','32','','','.w-blog-widget-post-share'),(129870,'printshop-mobile','.w-blog-widget-post-title h1','margin-left','0','','','.w-blog-widget-post-title'),(129871,'printshop-mobile','.w-blog-widget-related-posts .products','margin-left','-15','','','.w-blog-widget-related-posts'),(129872,'printshop-mobile','.w-blog-widget-related-posts-by-category .products','margin-left','-15','','','.w-blog-widget-related-posts-by-category'),(129873,'printshop-mobile','.w-cart-bonus-points .btn-remove','margin-left','-30','','','.w-cart-bonus-points'),(129874,'printshop-mobile','.w-cart-compare .product .image','margin-left','0','','','.w-cart-compare'),(129875,'printshop-mobile','.w-cart-credit-amount .btn-remove','margin-left','-30','','','.w-cart-credit-amount'),(129876,'printshop-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(129877,'printshop-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(129878,'printshop-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(129879,'printshop-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(129880,'printshop-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(129881,'printshop-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(129882,'printshop-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-left','0','','','.w-catalog-additional-images'),(129883,'printshop-mobile','.w-catalog-b2b-add-button .add-b2b-products','margin-left','50','','','.w-catalog-b2b-add-button'),(129884,'printshop-mobile','.w-catalog-items-on-page select','margin-left','10','','','.w-catalog-items-on-page'),(129885,'printshop-mobile','.w-catalog-paging .next','margin-left','2','','','.w-catalog-paging'),(129886,'printshop-mobile','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-billing-address'),(129887,'printshop-mobile','.w-checkout-bonus-points .btn-remove','margin-left','-30','','','.w-checkout-bonus-points'),(129888,'printshop-mobile','.w-checkout-credit-amount .btn-remove','margin-left','-30','','','.w-checkout-credit-amount'),(129889,'printshop-mobile','.w-checkout-gdpr .bootstrap-switch','margin-left','25','','','.w-checkout-gdpr'),(129890,'printshop-mobile','.w-checkout-gdpr .privacy-row','margin-left','0','','','.w-checkout-gdpr'),(129891,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-shipping-address'),(129892,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','margin-left','-5','','','.w-checkout-shipping-choice'),(129893,'printshop-mobile','.w-coupons-and-vauchers-checkout .btn-remove','margin-left','-30','','','.w-coupons-and-vauchers-checkout'),(129894,'printshop-mobile','.w-delivery-day .left-count','margin-left','2','','','.w-delivery-day'),(129895,'printshop-mobile','.w-delivery-day .left-text-right','margin-left','2','','','.w-delivery-day'),(129896,'printshop-mobile','.w-promotions .promo-cart-discount .master .item','margin-left','12','','','.w-promotions'),(129897,'printshop-mobile','.w-promotions .promo-salemaker .item','margin-left','2','','','.w-promotions'),(129898,'printshop-mobile','.w-promotions .promo-cart-discount .slave .item','margin-left','2','','','.w-promotions'),(129899,'printshop-mobile','.w-sitemap-delivery-location > ul','margin-left','0','','','.w-sitemap-delivery-location'),(129900,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-left','0','','','.w-sitemap-delivery-location'),(129901,'printshop-mobile','.w-social-links a','margin-left','5','','','.w-social-links'),(129902,'printshop-mobile','.w-taxable select','margin-left','5','','','.w-taxable'),(129903,'printshop-mobile','.w-taxable label','margin-left','5','','','.w-taxable'),(129904,'printshop-mobile','.b-quantity .qty-box input[type=\'text\']','margin-left','3','','','.b-quantity'),(129905,'printshop-mobile','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(129906,'printshop-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-right','0','','','.w-menu'),(129907,'printshop-mobile','.w-menu .hided.menu ul li','margin-right','0','','','.w-menu'),(129908,'printshop-mobile','.w-menu-big li','margin-right','0','','','.w-menu-big'),(129909,'printshop-mobile','.w-menu-big ul','margin-right','0','','','.w-menu-big'),(129910,'printshop-mobile','.w-menu-slider ul, .w-menu-slider li','margin-right','0','','','.w-menu-slider'),(129911,'printshop-mobile','.w-bestsellers .counter','margin-right','15','','','.w-bestsellers'),(129912,'printshop-mobile','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(129913,'printshop-mobile','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(129914,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(129915,'printshop-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-right','0','','','.b-cookie-notice'),(129916,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','margin-right','5','','','.b-form'),(129917,'printshop-mobile','.b-form .checkbox-style:checked + .checkbox-span','margin-right','5','','','.b-form'),(129918,'printshop-mobile','.b-form .checkbox-style','margin-right','0','','','.b-form'),(129919,'printshop-mobile','.w-filters .filter-ul-content','margin-right','0','','','.w-filters'),(129920,'printshop-mobile','.p-account-history-info .history_info','margin-right','0','','','.p-account-history-info'),(129921,'printshop-mobile','.p-account-index .account_info','margin-right','0','','','.p-account-index'),(129922,'printshop-mobile','.p-account-index .account_page h1','margin-right','0','','','.p-account-index'),(129923,'printshop-mobile','.w-catalog-listing-look .listing-look-title','margin-right','10','','','.w-catalog-listing-look'),(129924,'printshop-mobile','.w-cart-give-away .ga_column','margin-right','0','693','','.w-cart-give-away'),(129925,'printshop-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','margin-right','1','','','.b-product-images'),(129926,'printshop-mobile','.w-list-type-1_2 .image','margin-right','0','694','','.w-list-type-1_2'),(129927,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-right','0','','','.b-multi-page-checkout'),(129928,'printshop-mobile','.w-search .search-input','margin-right','0','','','.w-search'),(129929,'printshop-mobile','.w-socials .post_item_img','margin-right','10','','','.w-socials'),(129930,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(129931,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList','margin-right','-1','','','.w-delivery-location-top-location-list'),(129932,'printshop-mobile','.w-delivery-location-top-location-list','margin-right','0','','','.w-delivery-location-top-location-list'),(129933,'printshop-mobile','.p-account-order-pay .buttons','margin-right','0','','','.p-account-order-pay'),(129934,'printshop-mobile','.p-account-order-pay .history_info','margin-right','0','','','.p-account-order-pay'),(129935,'printshop-mobile','.p-account-order-pay .history_info > div','margin-right','0','694','','.p-account-order-pay'),(129936,'printshop-mobile','.js-stock-icon','margin-right','3','3','',''),(129937,'printshop-mobile','.b-bottom .confirm-popup .buttons .btn','margin-right','20','','','.b-bottom'),(129938,'printshop-mobile','.p-account-history-info .buttons','margin-right','0','','','.p-account-history-info'),(129939,'printshop-mobile','.p-blog-index .avatar','margin-right','10','','','.p-blog-index'),(129940,'printshop-mobile','.p-blog-index .author','margin-right','20','','','.p-blog-index'),(129941,'printshop-mobile','.w-list-type-2_2 .image','margin-right','20','','','.w-list-type-2_2'),(129942,'printshop-mobile','.buttons .left-buttons .btn','margin-right','10','','',''),(129943,'printshop-mobile','.w-product-bonus-points > div > div','margin-right','5','3','','.w-product-bonus-points'),(129944,'printshop-mobile','.w-account ul, .w-account li','margin-right','0','','','.w-account'),(129945,'printshop-mobile','.b-fancybox .fancybox-error','margin-right','0','','','.b-fancybox'),(129946,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList ul','margin-right','0','','','.w-delivery-location-top-location-list'),(129947,'printshop-mobile','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(129948,'printshop-mobile','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(129949,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','margin-right','5','3','','.b-form'),(129950,'printshop-mobile','.p-quote-cart-index .w-quote-checkout-btn','margin-right','0','','','.p-quote-cart-index'),(129951,'printshop-mobile','.b-form .radio-buttons .radio-button','margin-right','30','','','.b-form'),(129952,'printshop-mobile','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(129953,'printshop-mobile','.p-account-address-book .address_book_row .column + .column, .p-account-address-book .topInfo > div + div','margin-right','0','','','.p-account-address-book'),(129954,'printshop-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','margin-right','2','','','.p-account-address-book'),(129955,'printshop-mobile','.p-account-history .buttonBox','margin-right','0','','','.p-account-history'),(129956,'printshop-mobile','.p-account-address-book .address_book h1','margin-right','0','','','.p-account-address-book'),(129957,'printshop-mobile','.p-account-address-book .buttonBox .info','margin-right','25','','','.p-account-address-book'),(129958,'printshop-mobile','.p-account-address-book .address_book_row h2 a','margin-right','0','','','.p-account-address-book'),(129959,'printshop-mobile','.p-account-address-book .address_book h2','margin-right','0','','','.p-account-address-book'),(129960,'printshop-mobile','.p-account-history .order_history_table h2','margin-right','0','','','.p-account-history'),(129961,'printshop-mobile','.p-account-address-book .address_book .row-buttons a','margin-right','10','','','.p-account-address-book'),(129962,'printshop-mobile','.b-compare .clear_all','margin-right','0','4','','.b-compare'),(129963,'printshop-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin-right','5','','','.b-compare'),(129964,'printshop-mobile','.b-compare .compare-box-btn','margin-right','20','','','.b-compare'),(129965,'printshop-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-right','0','','','.b-switch'),(129966,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','margin-right','-100','','','.b-fancybox'),(129967,'printshop-mobile','.p-account-address-book .address_book_row .column','margin-right','0','693','','.p-account-address-book'),(129968,'printshop-mobile','.w-filters .input-checkbox:checked + .checkbox-span','margin-right','10','','','.w-filters'),(129969,'printshop-mobile','.p-account-history-info .history_info > div','margin-right','0','694','','.p-account-history-info'),(129970,'printshop-mobile','.p-account-index .account_info','margin-right','0','706','','.p-account-index'),(129971,'printshop-mobile','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(129972,'printshop-mobile','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(129973,'printshop-mobile','.w-breadcrumb .breadcrumb-li','margin-right','0','','','.w-breadcrumb'),(129974,'printshop-mobile','.p-account-address-book .topInfo > div','margin-right','0','693','','.p-account-address-book'),(129975,'printshop-mobile','.p-account-address-book .topInfo > div + div','margin-right','0','693','','.p-account-address-book'),(129976,'printshop-mobile','.w-top-categories .categories','margin-right','-20','','','.w-top-categories'),(129977,'printshop-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-right','0','','','.p-blog-index'),(129978,'printshop-mobile','.p-blog-index .nav-previous a','margin-right','0','3','','.p-blog-index'),(129979,'printshop-mobile','.p-blog-index .post-thumbnail','margin-right','40','','','.p-blog-index'),(129980,'printshop-mobile','.p-blog-index .wp-widget li','margin-right','0','','','.p-blog-index'),(129981,'printshop-mobile','.p-blog-index .nav-next a','margin-right','-50','3','','.p-blog-index'),(129982,'printshop-mobile','.p-blog-index .wp-widget li','margin-right','0','3','','.p-blog-index'),(129983,'printshop-mobile','.p-blog-index .wp-widget ul','margin-right','0','','','.p-blog-index'),(129984,'printshop-mobile','.p-reviews-info .review-info-text','margin-right','0','','','.p-reviews-info'),(129985,'printshop-mobile','.p-reviews-info .review-info-content','margin-right','0','','','.p-reviews-info'),(129986,'printshop-mobile','.p-reviews-info .review-info-image','margin-right','20','','','.p-reviews-info'),(129987,'printshop-mobile','.p-reviews-info .review-info-reviewed_by','margin-right','6','','','.p-reviews-info'),(129988,'printshop-mobile','.p-reviews-info .reviews-info h1','margin-right','0','','','.p-reviews-info'),(129989,'printshop-mobile','.p-account-address-book .address_book_row .column + .column','margin-right','0','693','','.p-account-address-book'),(129990,'printshop-mobile','.w-top-categories .categories','margin-right','0','693','','.w-top-categories'),(129991,'printshop-mobile','.b-slick .slick-track','margin-right','auto','','','.b-slick'),(129992,'printshop-mobile','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(129993,'printshop-mobile','.p-account-index .account_info li','margin-right','0','','','.p-account-index'),(129994,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-right','0','','','.p-account-subscription-historyinfo'),(129995,'printshop-mobile','.p-account-password .buttonedit','margin-right','0','','','.p-account-password'),(129996,'printshop-mobile','.p-account-index .view_history','margin-right','7','3','','.p-account-index'),(129997,'printshop-mobile','.w-filters .input-checkbox','margin-right','0','','','.w-filters'),(129998,'printshop-mobile','.w-html_box .socials a','margin-right','5','','','.w-html_box'),(129999,'printshop-mobile','.w-categories .categories','margin-right','-20','','','.w-categories'),(130000,'printshop-mobile','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(130001,'printshop-mobile','.w-cart-discount-coupon .gift-code p','margin-right','0','','','.w-cart-discount-coupon'),(130002,'printshop-mobile','.w-cart-give-away .ga_attributes > div','margin-right','1','','','.w-cart-give-away'),(130003,'printshop-mobile','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(130004,'printshop-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin-right','0','','','.w-product-in-bundles'),(130005,'printshop-mobile','.w-product-quantity .qty_packs .price_1','margin-right','25','4','','.w-product-quantity'),(130006,'printshop-mobile','.w-product-in-bundles .bundle_item','margin-right','2','','','.w-product-in-bundles'),(130007,'printshop-mobile','.w-product-bundle .bundle_item','margin-right','2','','','.w-product-bundle'),(130008,'printshop-mobile','.w-product-bundle .bundle_item + .bundle_item','margin-right','0','','','.w-product-bundle'),(130009,'printshop-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(130010,'printshop-mobile','.w-menu-style-1 ul','margin-right','0','','','.w-menu-style-1'),(130011,'printshop-mobile','.w-menu-style-1 li','margin-right','0','','','.w-menu-style-1'),(130012,'printshop-mobile','.w-product-reviews .reviews-list','margin-right','0','','','.w-product-reviews'),(130013,'printshop-mobile','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(130014,'printshop-mobile','.w-top-categories .categories h2','margin-right','0','','','.w-top-categories'),(130015,'printshop-mobile','.w-categories .categories h2','margin-right','0','','','.w-categories'),(130016,'printshop-mobile','.b-form .terms-login .bootstrap-switch','margin-right','-80','','','.b-form'),(130017,'printshop-mobile','.b-slick .slick-list','margin-right','0','','','.b-slick'),(130018,'printshop-mobile','.w-socials > li','margin-right','10','','','.w-socials'),(130019,'printshop-mobile','.w-list-type-1_3 .image','margin-right','0','694','','.w-list-type-1_3'),(130020,'printshop-mobile','.w-menu-horizontal li','margin-right','0','','','.w-menu-horizontal'),(130021,'printshop-mobile','.w-menu-horizontal ul','margin-right','0','','','.w-menu-horizontal'),(130022,'printshop-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','margin-right','10','3','','.w-cart-discount-coupon'),(130023,'printshop-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-right','0','','','.b-form'),(130024,'printshop-mobile','.w-categories .categories','margin-right','0','693','','.w-categories'),(130025,'printshop-mobile','.w-categories .categories','margin-right','-10','695','','.w-categories'),(130026,'printshop-mobile','.b-form #frmCheckout','margin-right','0','','','.b-form'),(130027,'printshop-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-right','0','','','.b-fancybox'),(130028,'printshop-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-right','0','','','.b-fancybox'),(130029,'printshop-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(130030,'printshop-mobile','.w-cart-give-away .ga_column','margin-right','2','','','.w-cart-give-away'),(130031,'printshop-mobile','.w-cart-give-away .ga_img','margin-right','2','','','.w-cart-give-away'),(130032,'printshop-mobile','.out-stock-icon','margin-right','3','3','',''),(130033,'printshop-mobile','.w-list-type-1_3 .image','margin-right','20','','','.w-list-type-1_3'),(130034,'printshop-mobile','.w-list-type-1_3 .attributes > .attributes > div','margin-right','5','','','.w-list-type-1_3'),(130035,'printshop-mobile','.w-list-type-1_2 .image','margin-right','20','','','.w-list-type-1_2'),(130036,'printshop-mobile','.b-bottom .pop-up-content .buttons','margin-right','0','','','.b-bottom'),(130037,'printshop-mobile','.w-filters .open','margin-right','10','3','','.w-filters'),(130038,'printshop-mobile','.transit-icon','margin-right','3','3','',''),(130039,'printshop-mobile','.in-stock-icon','margin-right','3','3','',''),(130040,'printshop-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','margin-right','10','','','.w-filters'),(130041,'printshop-mobile','.w-tabs .tab-li','margin-right','0','','','.w-tabs'),(130042,'printshop-mobile','.w-tabs .tab-navigation','margin-right','0','','','.w-tabs'),(130043,'printshop-mobile','.w-top-categories .categories','margin-right','-10','695','','.w-top-categories'),(130044,'printshop-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin-right','10','','','.b-form'),(130045,'printshop-mobile','.b-form .required-message','margin-right','0','','','.b-form'),(130046,'printshop-mobile','.b-form .required-message-wrap','margin-right','0','','','.b-form'),(130047,'printshop-mobile','.b-info .info ul','margin-right','0','','','.b-info'),(130048,'printshop-mobile','.b-info .info li','margin-right','0','','','.b-info'),(130049,'printshop-mobile','.p-account-index .topAccount','margin-right','0','','','.p-account-index'),(130050,'printshop-mobile','.b-products-listing .products-listing .bonus-points-cost','margin-right','5','3','','.b-products-listing'),(130051,'printshop-mobile','.b-products-listing .products-listing .bonus-points-cost','margin-right','10','','','.b-products-listing'),(130052,'printshop-mobile','.b-products-listing .products-listing .bonus-points-price','margin-right','10','','','.b-products-listing'),(130053,'printshop-mobile','.b-products-listing .products-listing .btn-buy','margin-right','10','3','','.b-products-listing'),(130054,'printshop-mobile','.b-products-listing .products-listing .description ul','margin-right','0','','','.b-products-listing'),(130055,'printshop-mobile','.b-products-listing .products-listing .radio-attributes label','margin-right','10','','','.b-products-listing'),(130056,'printshop-mobile','.b-products-listing .products-listing h2','margin-right','0','','','.b-products-listing'),(130057,'printshop-mobile','.b-delete-account .delete-box span','margin-right','10','','','.b-delete-account'),(130058,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(130059,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(130060,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(130061,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(130062,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(130063,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(130064,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-right','0','','','.b-h-inline'),(130065,'printshop-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-right','0','','','.b-menu-style'),(130066,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','margin-right','10','','','.b-menu-style-2'),(130067,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','margin-right','10','','','.b-menu-style-2'),(130068,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','margin-right','10','3','','.b-menu-style-2'),(130069,'printshop-mobile','.b-messages span.starred::before','margin-right','8','','','.b-messages'),(130070,'printshop-mobile','.b-messages .msv_content','margin-right','0','','','.b-messages'),(130071,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-right','5','','','.b-messages'),(130072,'printshop-mobile','.b-messages .msv_history','margin-right','0','','','.b-messages'),(130073,'printshop-mobile','.b-messages .messBtnMenuUnread','margin-right','8','3','','.b-messages'),(130074,'printshop-mobile','.b-messages .messBtnMenuDelete','margin-right','8','3','','.b-messages'),(130075,'printshop-mobile','.b-messages .messBtnMenuStarred','margin-right','8','3','','.b-messages'),(130076,'printshop-mobile','.b-messages .messages-menu ul','margin-right','0','','','.b-messages'),(130077,'printshop-mobile','.b-messages .messages-menu li','margin-right','0','','','.b-messages'),(130078,'printshop-mobile','.b-messages .content_management_attach span::before','margin-right','5','','','.b-messages'),(130079,'printshop-mobile','.b-messages .content_management_attach span','margin-right','10','','','.b-messages'),(130080,'printshop-mobile','.b-select-suggest .select2-search','margin-right','0','','','.b-select-suggest'),(130081,'printshop-mobile','.b-select-suggest .select2-drop-mask','margin-right','0','','','.b-select-suggest'),(130082,'printshop-mobile','.b-select-suggest .select2-search input','margin-right','0','','','.b-select-suggest'),(130083,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-right','0','','','.b-select-suggest'),(130084,'printshop-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-right','0','','','.b-select-suggest'),(130085,'printshop-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','margin-right','26','','','.b-select-suggest'),(130086,'printshop-mobile','.b-select-suggest .select2-container.select2-allowclear .select2-choice .select2-chosen','margin-right','42','','','.b-select-suggest'),(130087,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-right','0','','','.b-select-suggest'),(130088,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-right','0','','','.b-select-suggest'),(130089,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-right','0','','','.b-select-suggest'),(130090,'printshop-mobile','.b-select-suggest .select2-container','margin-right','0','','','.b-select-suggest'),(130091,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','margin-right','0','','','.b-select-suggest'),(130092,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(130093,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(130094,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(130095,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(130096,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(130097,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(130098,'printshop-mobile','.b-trade-approval .steps-bar','margin-right','0','','','.b-trade-approval'),(130099,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-right','20','','','.b-warehouses-popup'),(130100,'printshop-mobile','.b-warehouses-popup .warehouses-popup-link','margin-right','5','3','','.b-warehouses-popup'),(130101,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing','margin-right','0','','','.batchPr'),(130102,'printshop-mobile','.bell-ico .heading-2','margin-right','10','3','','.bell-ico'),(130103,'printshop-mobile','.heading-ordered-items .heading-4','margin-right','5','3','','.heading-ordered-items'),(130104,'printshop-mobile','.heading-saved-lists .heading-4','margin-right','5','3','','.heading-saved-lists'),(130105,'printshop-mobile','.heading-settings .heading-4','margin-right','5','3','','.heading-settings'),(130106,'printshop-mobile','.p-account-samples-history .buttonBox','margin-right','0','','','.p-account-samples-history'),(130107,'printshop-mobile','.p-account-samples-history .buttonBox','margin-right','0','','','.p-account-samples-history'),(130108,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-right','0','','','.p-account-samples-history'),(130109,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-right','0','','','.p-account-samples-history'),(130110,'printshop-mobile','.p-account-samples-history .buttonBox','margin-right','0','','','.p-account-samples-history'),(130111,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-right','0','','','.p-account-samples-history'),(130112,'printshop-mobile','.p-account-samples-history .buttonBox','margin-right','0','','','.p-account-samples-history'),(130113,'printshop-mobile','.p-account-samples-history .buttonBox','margin-right','0','','','.p-account-samples-history'),(130114,'printshop-mobile','.p-account-samples-history .buttonBox','margin-right','0','','','.p-account-samples-history'),(130115,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-right','0','','','.p-account-samples-history'),(130116,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-right','0','','','.p-account-samples-history'),(130117,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-right','0','','','.p-account-samples-history'),(130118,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-right','0','','','.p-account-samples-history-info'),(130119,'printshop-mobile','.p-account-samples-history-info .history_info','margin-right','0','','','.p-account-samples-history-info'),(130120,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-right','0','','','.p-account-samples-history-info'),(130121,'printshop-mobile','.p-account-samples-history-info .history_info','margin-right','0','','','.p-account-samples-history-info'),(130122,'printshop-mobile','.p-account-samples-history-info .history_info','margin-right','0','','','.p-account-samples-history-info'),(130123,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-right','0','','','.p-account-samples-history-info'),(130124,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-right','0','','','.p-account-samples-history-info'),(130125,'printshop-mobile','.p-account-samples-history-info .history_info','margin-right','0','','','.p-account-samples-history-info'),(130126,'printshop-mobile','.p-account-samples-history-info .history_info','margin-right','0','','','.p-account-samples-history-info'),(130127,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-right','0','','','.p-account-samples-history-info'),(130128,'printshop-mobile','.p-account-samples-history-info .buttons','margin-right','0','','','.p-account-samples-history-info'),(130129,'printshop-mobile','.p-account-samples-history-info .history_info','margin-right','0','','','.p-account-samples-history-info'),(130130,'printshop-mobile','.p-account-samples-history-info .buttons','margin-right','0','','','.p-account-samples-history-info'),(130131,'printshop-mobile','.p-account-samples-history-info .buttons','margin-right','0','','','.p-account-samples-history-info'),(130132,'printshop-mobile','.p-account-samples-history-info .buttons','margin-right','0','','','.p-account-samples-history-info'),(130133,'printshop-mobile','.p-account-samples-history-info .buttons','margin-right','0','','','.p-account-samples-history-info'),(130134,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-right','0','','','.p-account-samples-history-info'),(130135,'printshop-mobile','.p-account-samples-history-info .buttons','margin-right','0','','','.p-account-samples-history-info'),(130136,'printshop-mobile','.p-payer-order-confirmation .ship-ico','margin-right','10','3','','.p-payer-order-confirmation'),(130137,'printshop-mobile','.p-payer-order-confirmation .discount-ico','margin-right','10','3','','.p-payer-order-confirmation'),(130138,'printshop-mobile','.p-payer-order-confirmation .comment-ico','margin-right','10','3','','.p-payer-order-confirmation'),(130139,'printshop-mobile','.p-payer-order-confirmation .pay-ico','margin-right','10','3','','.p-payer-order-confirmation'),(130140,'printshop-mobile','.p-payer-order-confirmation .order-ico','margin-right','10','3','','.p-payer-order-confirmation'),(130141,'printshop-mobile','.p-payer-order-pay .ship-ico','margin-right','10','3','','.p-payer-order-pay'),(130142,'printshop-mobile','.p-payer-order-pay .order-ico','margin-right','10','3','','.p-payer-order-pay'),(130143,'printshop-mobile','.p-payer-order-pay .pay-ico','margin-right','10','3','','.p-payer-order-pay'),(130144,'printshop-mobile','.p-payer-order-pay .comment-ico','margin-right','10','3','','.p-payer-order-pay'),(130145,'printshop-mobile','.p-payer-order-pay .discount-ico','margin-right','10','3','','.p-payer-order-pay'),(130146,'printshop-mobile','.p-quick-order-index ul.token-input-list','margin-right','30','','','.p-quick-order-index'),(130147,'printshop-mobile','.savings-ico .heading-2','margin-right','10','3','','.savings-ico'),(130148,'printshop-mobile','.shipping-ico .heading-2','margin-right','10','3','','.shipping-ico'),(130149,'printshop-mobile','.shipping-ico .heading-2','margin-right','10','3','','.shipping-ico'),(130150,'printshop-mobile','.shipping-ico .heading-2','margin-right','10','3','','.shipping-ico'),(130151,'printshop-mobile','.w-account-address-book .address-book','margin-right','-10','','','.w-account-address-book'),(130152,'printshop-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','margin-right','10','','','.w-account-addresses-list'),(130153,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(130154,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(130155,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(130156,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(130157,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(130158,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(130159,'printshop-mobile','.w-account-personal-catalog .list-switcher','margin-right','0','','','.w-account-personal-catalog'),(130160,'printshop-mobile','.w-account-subscription .info-popup','margin-right','20','','','.w-account-subscription'),(130161,'printshop-mobile','.w-blog-widget-post-image ','margin-right','0','','','.w-blog-widget-post-image'),(130162,'printshop-mobile','.w-blog-widget-post-listing .post_date span + span','margin-right','10','3','','.w-blog-widget-post-listing'),(130163,'printshop-mobile','.w-blog-widget-post-listing .post_view','margin-right','15','','','.w-blog-widget-post-listing'),(130164,'printshop-mobile','.w-blog-widget-post-listing ','margin-right','0','','','.w-blog-widget-post-listing'),(130165,'printshop-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-right','8','','','.w-blog-widget-post-share'),(130166,'printshop-mobile','.w-blog-widget-post-title h1','margin-right','0','','','.w-blog-widget-post-title'),(130167,'printshop-mobile','.w-blog-widget-related-posts .products','margin-right','-15','','','.w-blog-widget-related-posts'),(130168,'printshop-mobile','.w-blog-widget-related-posts-by-category .products','margin-right','-15','','','.w-blog-widget-related-posts-by-category'),(130169,'printshop-mobile','.w-cart-compare .product .image','margin-right','10','','','.w-cart-compare'),(130170,'printshop-mobile','.w-cart-compare .product-actions .dropdown-toggle','margin-right','8','3','','.w-cart-compare'),(130171,'printshop-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(130172,'printshop-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(130173,'printshop-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(130174,'printshop-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(130175,'printshop-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(130176,'printshop-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(130177,'printshop-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-right','0','','','.w-catalog-additional-images'),(130178,'printshop-mobile','.w-catalog-items-on-page select','margin-right','10','','','.w-catalog-items-on-page'),(130179,'printshop-mobile','.w-catalog-paging .prev','margin-right','5','','','.w-catalog-paging'),(130180,'printshop-mobile','.w-checkout-billing-address .genders-title label','margin-right','20','','','.w-checkout-billing-address'),(130181,'printshop-mobile','.w-checkout-billing-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-billing-address'),(130182,'printshop-mobile','.w-checkout-billing-address .btn-cancel','margin-right','20','','','.w-checkout-billing-address'),(130183,'printshop-mobile','.w-checkout-create-account .account-benefits strong','margin-right','5','3','','.w-checkout-create-account'),(130184,'printshop-mobile','.w-checkout-gdpr .privacy-row','margin-right','0','','','.w-checkout-gdpr'),(130185,'printshop-mobile','.w-checkout-shipping-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-shipping-address'),(130186,'printshop-mobile','.w-checkout-shipping-address .genders-title label','margin-right','20','','','.w-checkout-shipping-address'),(130187,'printshop-mobile','.w-checkout-shipping-address .btn-cancel','margin-right','20','','','.w-checkout-shipping-address'),(130188,'printshop-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','margin-right','10','3','','.w-multi-cart-actions'),(130189,'printshop-mobile','.w-product-cross-sell .buy-all-checker','margin-right','5','','','.w-product-cross-sell'),(130190,'printshop-mobile','.w-promotions .nextdiscount .heading','margin-right','10','3','','.w-promotions'),(130191,'printshop-mobile','.w-promotions .promo-cart-discount .master .item','margin-right','12','','','.w-promotions'),(130192,'printshop-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','margin-right','5','3','','.w-promotions'),(130193,'printshop-mobile','.w-promotions .promo-cart-discount .slave .item','margin-right','2','','','.w-promotions'),(130194,'printshop-mobile','.w-promotions .promo-salemaker .item','margin-right','2','','','.w-promotions'),(130195,'printshop-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','margin-right','5','3','','.w-promotions'),(130196,'printshop-mobile','.w-promotions .prom-multi-discount > .heading','margin-right','5','3','','.w-promotions'),(130197,'printshop-mobile','.w-promotions .icon','margin-right','15','','','.w-promotions'),(130198,'printshop-mobile','.w-sitemap-delivery-location > ul','margin-right','0','','','.w-sitemap-delivery-location'),(130199,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-right','0','','','.w-sitemap-delivery-location'),(130200,'printshop-mobile','.w-social-links a','margin-right','5','','','.w-social-links'),(130201,'printshop-mobile','.w-taxable input[type=\"checkbox\"]','margin-right','5','','','.w-taxable'),(130202,'printshop-mobile','.w-taxable label','margin-right','5','','','.w-taxable'),(130203,'printshop-mobile','.w-taxable select','margin-right','0','','','.w-taxable'),(130204,'printshop-mobile','.w-wedding-registry-widgets-photos .upload-file-template','margin-right','20','','','.w-wedding-registry-widgets-photos'),(130205,'printshop-mobile','.w-wedding-registry-widgets-search-registry-button a','margin-right','10','3','','.w-wedding-registry-widgets-search-registry-button'),(130206,'printshop-mobile','.w-wedding-registry-widgets-share-link a','margin-right','5','3','','.w-wedding-registry-widgets-share-link'),(130207,'printshop-mobile','.b-quantity .qty-box input[type=\'text\']','margin-right','3','','','.b-quantity'),(130208,'printshop-mobile','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(130209,'printshop-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-top','0','','','.w-menu'),(130210,'printshop-mobile','.w-menu .hided.menu ul li','margin-top','0','','','.w-menu'),(130211,'printshop-mobile','.w-menu-big ul','margin-top','0','','','.w-menu-big'),(130212,'printshop-mobile','.w-menu-big li','margin-top','0','','','.w-menu-big'),(130213,'printshop-mobile','.w-menu-slider ul, .w-menu-slider li','margin-top','0','','','.w-menu-slider'),(130214,'printshop-mobile','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(130215,'printshop-mobile','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(130216,'printshop-mobile','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(130217,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(130218,'printshop-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-top','0','','','.b-cookie-notice'),(130219,'printshop-mobile','.b-form .checkbox-style','margin-top','0','','','.b-form'),(130220,'printshop-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','margin-top','0','','','.b-product-images'),(130221,'printshop-mobile','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(130222,'printshop-mobile','.w-filters .filter-ul-content','margin-top','0','','','.w-filters'),(130223,'printshop-mobile','.w-menu-horizontal li','margin-top','0','','','.w-menu-horizontal'),(130224,'printshop-mobile','.p-account-history .order_history_table h2','margin-top','0','','','.p-account-history'),(130225,'printshop-mobile','.p-account-history-info .history_info','margin-top','0','','','.p-account-history-info'),(130226,'printshop-mobile','.p-account-index .account_info','margin-top','0','','','.p-account-index'),(130227,'printshop-mobile','.p-account-index .account_page h1','margin-top','0','','','.p-account-index'),(130228,'printshop-mobile','.w-list-type-1_2 .right-area .right-area-2','margin-top','15','694','','.w-list-type-1_2'),(130229,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-top','0','','','.b-multi-page-checkout'),(130230,'printshop-mobile','.w-socials > li','margin-top','10','','','.w-socials'),(130231,'printshop-mobile','.w-socials .post_item_img','margin-top','0','','','.w-socials'),(130232,'printshop-mobile','.w-search .search-input','margin-top','0','','','.w-search'),(130233,'printshop-mobile','.p-account-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-history-info'),(130234,'printshop-mobile','.w-delivery-location-top-location-list','margin-top','25','','','.w-delivery-location-top-location-list'),(130235,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList','margin-top','0','','','.w-delivery-location-top-location-list'),(130236,'printshop-mobile','.p-account-order-pay .buttons','margin-top','20','','','.p-account-order-pay'),(130237,'printshop-mobile','.p-account-order-pay .history_info','margin-top','0','','','.p-account-order-pay'),(130238,'printshop-mobile','.p-account-order-pay .history_info > div','margin-top','0','694','','.p-account-order-pay'),(130239,'printshop-mobile','.b-bottom .confirm-popup .buttons .btn','margin-top','0','','','.b-bottom'),(130240,'printshop-mobile','.p-account-history-info .buttons','margin-top','20','','','.p-account-history-info'),(130241,'printshop-mobile','.w-account ul, .w-account li','margin-top','0','','','.w-account'),(130242,'printshop-mobile','.b-fancybox .fancybox-error','margin-top','0','','','.b-fancybox'),(130243,'printshop-mobile','.w-menu-horizontal ul','margin-top','0','','','.w-menu-horizontal'),(130244,'printshop-mobile','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(130245,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(130246,'printshop-mobile','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(130247,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList ul','margin-top','0','','','.w-delivery-location-top-location-list'),(130248,'printshop-mobile','.b-form .wedding-form .heading-2','margin-top','10','','','.b-form'),(130249,'printshop-mobile','.p-quote-cart-index .w-quote-checkout-btn','margin-top','20','','','.p-quote-cart-index'),(130250,'printshop-mobile','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(130251,'printshop-mobile','.p-account-address-book .address_book_row h2 a','margin-top','0','','','.p-account-address-book'),(130252,'printshop-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','margin-top','0','','','.p-account-address-book'),(130253,'printshop-mobile','.p-account-address-book .buttonBox .info','margin-top','0','','','.p-account-address-book'),(130254,'printshop-mobile','.p-account-history .buttonBox','margin-top','15','','','.p-account-history'),(130255,'printshop-mobile','.p-account-address-book .address_book h1','margin-top','0','','','.p-account-address-book'),(130256,'printshop-mobile','.p-account-address-book .address_book_row .column + .column, .p-account-address-book .topInfo > div + div','margin-top','0','','','.p-account-address-book'),(130257,'printshop-mobile','.p-account-address-book .address_book h2','margin-top','0','','','.p-account-address-book'),(130258,'printshop-mobile','.p-account-address-book .address_book .row-buttons a','margin-top','0','','','.p-account-address-book'),(130259,'printshop-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin-top','0','','','.b-compare'),(130260,'printshop-mobile','.b-compare .clear_all','margin-top','0','4','','.b-compare'),(130261,'printshop-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-top','0','','','.b-switch'),(130262,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','margin-top','-20','','','.b-slick'),(130263,'printshop-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-top','0','','','.b-slick'),(130264,'printshop-mobile','.p-account-edit .buttons','margin-top','-70','','','.p-account-edit'),(130265,'printshop-mobile','.p-account-address-book .address_book_row .column + .column','margin-top','0','693','','.p-account-address-book'),(130266,'printshop-mobile','.p-account-address-book .topInfo > div + div','margin-top','0','693','','.p-account-address-book'),(130267,'printshop-mobile','.p-account-history-info .history_info > div','margin-top','0','694','','.p-account-history-info'),(130268,'printshop-mobile','.w-cart-discount-coupon .gift-code p','margin-top','0','','','.w-cart-discount-coupon'),(130269,'printshop-mobile','.w-breadcrumb .breadcrumb-li','margin-top','0','','','.w-breadcrumb'),(130270,'printshop-mobile','.w-tabs .tab-li','margin-top','0','','','.w-tabs'),(130271,'printshop-mobile','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(130272,'printshop-mobile','.p-account-address-book .topInfo > div','margin-top','0','693','','.p-account-address-book'),(130273,'printshop-mobile','.w-tabs .tab-navigation','margin-top','0','','','.w-tabs'),(130274,'printshop-mobile','.w-top-categories .categories','margin-top','0','695','','.w-top-categories'),(130275,'printshop-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-top','0','','','.p-blog-index'),(130276,'printshop-mobile','.p-blog-index .wp-widget ul','margin-top','0','','','.p-blog-index'),(130277,'printshop-mobile','.p-blog-index .wp-widget li','margin-top','5','3','','.p-blog-index'),(130278,'printshop-mobile','.p-blog-index .nav-previous a','margin-top','0','3','','.p-blog-index'),(130279,'printshop-mobile','.p-blog-index .wp-widget li','margin-top','0','','','.p-blog-index'),(130280,'printshop-mobile','.p-blog-index .post-thumbnail','margin-top','0','','','.p-blog-index'),(130281,'printshop-mobile','.p-blog-index .nav-next a','margin-top','0','3','','.p-blog-index'),(130282,'printshop-mobile','.p-reviews-info .reviews-info h1','margin-top','0','','','.p-reviews-info'),(130283,'printshop-mobile','.p-reviews-info .review-info-image','margin-top','0','','','.p-reviews-info'),(130284,'printshop-mobile','.p-reviews-info .review-info-content','margin-top','0','','','.p-reviews-info'),(130285,'printshop-mobile','.p-reviews-info .review-info-reviewed_by','margin-top','0','','','.p-reviews-info'),(130286,'printshop-mobile','.p-reviews-info .review-info-text','margin-top','0','','','.p-reviews-info'),(130287,'printshop-mobile','.p-account-address-book .address_book_row .column','margin-top','0','693','','.p-account-address-book'),(130288,'printshop-mobile','.w-top-categories .categories','margin-top','0','693','','.w-top-categories'),(130289,'printshop-mobile','.p-account-password .buttons','margin-top','-70','','','.p-account-password'),(130290,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-top','0','','','.p-account-subscription-historyinfo'),(130291,'printshop-mobile','.p-account-index .account_info li','margin-top','0','','','.p-account-index'),(130292,'printshop-mobile','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(130293,'printshop-mobile','.p-account-password .buttonedit','margin-top','-40','','','.p-account-password'),(130294,'printshop-mobile','.p-account-index .view_history','margin-top','0','3','','.p-account-index'),(130295,'printshop-mobile','.p-account-index .topAccount','margin-top','0','','','.p-account-index'),(130296,'printshop-mobile','.w-filters .input-checkbox','margin-top','0','','','.w-filters'),(130297,'printshop-mobile','.w-html_box .socials a','margin-top','0','','','.w-html_box'),(130298,'printshop-mobile','.b-fancybox .fancybox-title-outside-wrap','margin-top','10','','','.b-fancybox'),(130299,'printshop-mobile','.p-account-address-book-process .buttons','margin-top','-70','','','.p-account-address-book-process'),(130300,'printshop-mobile','.b-fancybox .fancybox-nav span','margin-top','-18','','','.b-fancybox'),(130301,'printshop-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-top','0','','','.b-fancybox'),(130302,'printshop-mobile','.w-categories .categories','margin-top','0','','','.w-categories'),(130303,'printshop-mobile','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(130304,'printshop-mobile','.w-cart-give-away .ga_attributes > div','margin-top','1','','','.w-cart-give-away'),(130305,'printshop-mobile','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(130306,'printshop-mobile','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(130307,'printshop-mobile','.w-product-quantity .qty_packs .price_1','margin-top','0','4','','.w-product-quantity'),(130308,'printshop-mobile','.w-product-in-bundles .bundle_item','margin-top','0','','','.w-product-in-bundles'),(130309,'printshop-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin-top','0','','','.w-product-in-bundles'),(130310,'printshop-mobile','.w-product-bundle .bundle_item','margin-top','0','','','.w-product-bundle'),(130311,'printshop-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(130312,'printshop-mobile','.w-product-bundle .bundle_item + .bundle_item','margin-top','0','','','.w-product-bundle'),(130313,'printshop-mobile','.w-menu-style-1 ul','margin-top','0','','','.w-menu-style-1'),(130314,'printshop-mobile','.w-menu-style-1 li','margin-top','0','','','.w-menu-style-1'),(130315,'printshop-mobile','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(130316,'printshop-mobile','.w-product-reviews .reviews-list','margin-top','10','','','.w-product-reviews'),(130317,'printshop-mobile','.w-top-categories .categories h2','margin-top','0','','','.w-top-categories'),(130318,'printshop-mobile','.w-categories .categories h2','margin-top','0','','','.w-categories'),(130319,'printshop-mobile','.b-form .terms-login .bootstrap-switch','margin-top','0','','','.b-form'),(130320,'printshop-mobile','.b-slick .slick-list','margin-top','0','','','.b-slick'),(130321,'printshop-mobile','.b-fancybox #fancybox-loading','margin-top','-22','','','.b-fancybox'),(130322,'printshop-mobile','.w-list-type-1_3 .right-area .right-area-2','margin-top','15','694','','.w-list-type-1_3'),(130323,'printshop-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-top','0','','','.b-form'),(130324,'printshop-mobile','.w-categories .categories','margin-top','0','693','','.w-categories'),(130325,'printshop-mobile','.w-categories .categories','margin-top','0','695','','.w-categories'),(130326,'printshop-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-top','0','','','.b-fancybox'),(130327,'printshop-mobile','.b-form #frmCheckout','margin-top','20','','','.b-form'),(130328,'printshop-mobile','.b-bottom .pop-up-content .buttons','margin-top','15','','','.b-bottom'),(130329,'printshop-mobile','.w-filters .ui-slider','margin-top','5','','','.w-filters'),(130330,'printshop-mobile','.p-account-index .account_info','margin-top','0','706','','.p-account-index'),(130331,'printshop-mobile','.w-top-categories .categories','margin-top','0','','','.w-top-categories'),(130332,'printshop-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin-top','0','','','.b-form'),(130333,'printshop-mobile','.b-form .required-message','margin-top','0','','','.b-form'),(130334,'printshop-mobile','.b-form .required-message-wrap','margin-top','0','','','.b-form'),(130335,'printshop-mobile','.b-info .info','margin-top','-8','3','','.b-info'),(130336,'printshop-mobile','.b-info .info ul','margin-top','0','','','.b-info'),(130337,'printshop-mobile','.b-info .info li','margin-top','0','','','.b-info'),(130338,'printshop-mobile','.b-products-listing .products-listing .description ul','margin-top','0','','','.b-products-listing'),(130339,'printshop-mobile','.b-products-listing .products-listing h2','margin-top','0','','','.b-products-listing'),(130340,'printshop-mobile','.b-delete-account .delete-box span','margin-top','10','','','.b-delete-account'),(130341,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(130342,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(130343,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(130344,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(130345,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(130346,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(130347,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-top','0','','','.b-h-inline'),(130348,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(130349,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(130350,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(130351,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(130352,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(130353,'printshop-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-top','0','','','.b-menu-style'),(130354,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','margin-top','-8','3','','.b-menu-style-2'),(130355,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','margin-top','-10','3','','.b-menu-style-2'),(130356,'printshop-mobile','.b-messages .msv_content','margin-top','15','','','.b-messages'),(130357,'printshop-mobile','.b-messages .msv_btn','margin-top','10','','','.b-messages'),(130358,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-top','0','','','.b-messages'),(130359,'printshop-mobile','.b-messages .msv_history','margin-top','15','','','.b-messages'),(130360,'printshop-mobile','.b-messages .messages-menu ul','margin-top','0','','','.b-messages'),(130361,'printshop-mobile','.b-messages .messages-menu li','margin-top','0','','','.b-messages'),(130362,'printshop-mobile','.b-select-suggest .select2-search input','margin-top','0','','','.b-select-suggest'),(130363,'printshop-mobile','.b-select-suggest .select2-drop-mask','margin-top','0','','','.b-select-suggest'),(130364,'printshop-mobile','.b-select-suggest .select2-drop.select2-drop-above .select2-search input','margin-top','4','','','.b-select-suggest'),(130365,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-top','0','','','.b-select-suggest'),(130366,'printshop-mobile','.b-select-suggest .select2-drop','margin-top','-1','','','.b-select-suggest'),(130367,'printshop-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-top','0','','','.b-select-suggest'),(130368,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-top','0','','','.b-select-suggest'),(130369,'printshop-mobile','.b-select-suggest .select2-drop.select2-drop-above','margin-top','1','','','.b-select-suggest'),(130370,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-top','1','','','.b-select-suggest'),(130371,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-top','0','','','.b-select-suggest'),(130372,'printshop-mobile','.b-select-suggest .select2-search','margin-top','0','','','.b-select-suggest'),(130373,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','margin-top','0','','','.b-select-suggest'),(130374,'printshop-mobile','.b-select-suggest .select2-container','margin-top','0','','','.b-select-suggest'),(130375,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(130376,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(130377,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(130378,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(130379,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(130380,'printshop-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(130381,'printshop-mobile','.b-trade-approval .steps-bar','margin-top','0','','','.b-trade-approval'),(130382,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-top','0','','','.b-warehouses-popup'),(130383,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing','margin-top','0','','','.batchPr'),(130384,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-top','0','','','.p-account-samples-history'),(130385,'printshop-mobile','.p-account-samples-history .buttonBox','margin-top','15','','','.p-account-samples-history'),(130386,'printshop-mobile','.p-account-samples-history .buttonBox','margin-top','15','','','.p-account-samples-history'),(130387,'printshop-mobile','.p-account-samples-history .buttonBox','margin-top','15','','','.p-account-samples-history'),(130388,'printshop-mobile','.p-account-samples-history .buttonBox','margin-top','15','','','.p-account-samples-history'),(130389,'printshop-mobile','.p-account-samples-history .buttonBox','margin-top','15','','','.p-account-samples-history'),(130390,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-top','0','','','.p-account-samples-history'),(130391,'printshop-mobile','.p-account-samples-history .buttonBox','margin-top','15','','','.p-account-samples-history'),(130392,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-top','0','','','.p-account-samples-history'),(130393,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-top','0','','','.p-account-samples-history'),(130394,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-top','0','','','.p-account-samples-history'),(130395,'printshop-mobile','.p-account-samples-history .order_history_table h2','margin-top','0','','','.p-account-samples-history'),(130396,'printshop-mobile','.p-account-samples-history-info .buttons','margin-top','20','','','.p-account-samples-history-info'),(130397,'printshop-mobile','.p-account-samples-history-info .history_info','margin-top','0','','','.p-account-samples-history-info'),(130398,'printshop-mobile','.p-account-samples-history-info .buttons','margin-top','20','','','.p-account-samples-history-info'),(130399,'printshop-mobile','.p-account-samples-history-info .buttons','margin-top','20','','','.p-account-samples-history-info'),(130400,'printshop-mobile','.p-account-samples-history-info .buttons','margin-top','20','','','.p-account-samples-history-info'),(130401,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-top','0','','','.p-account-samples-history-info'),(130402,'printshop-mobile','.p-account-samples-history-info .history_info','margin-top','0','','','.p-account-samples-history-info'),(130403,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-samples-history-info'),(130404,'printshop-mobile','.p-account-samples-history-info .buttons','margin-top','20','','','.p-account-samples-history-info'),(130405,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-top','0','','','.p-account-samples-history-info'),(130406,'printshop-mobile','.p-account-samples-history-info .history_info','margin-top','0','','','.p-account-samples-history-info'),(130407,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-top','0','','','.p-account-samples-history-info'),(130408,'printshop-mobile','.p-account-samples-history-info .history_info','margin-top','0','','','.p-account-samples-history-info'),(130409,'printshop-mobile','.p-account-samples-history-info .history_info','margin-top','0','','','.p-account-samples-history-info'),(130410,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-top','0','','','.p-account-samples-history-info'),(130411,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-samples-history-info'),(130412,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-top','0','','','.p-account-samples-history-info'),(130413,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-samples-history-info'),(130414,'printshop-mobile','.p-account-samples-history-info .history_info','margin-top','0','','','.p-account-samples-history-info'),(130415,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-samples-history-info'),(130416,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-samples-history-info'),(130417,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-samples-history-info'),(130418,'printshop-mobile','.p-account-samples-history-info .history_info > div','margin-top','0','','','.p-account-samples-history-info'),(130419,'printshop-mobile','.p-account-samples-history-info .buttons','margin-top','20','','','.p-account-samples-history-info'),(130420,'printshop-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(130421,'printshop-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(130422,'printshop-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(130423,'printshop-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(130424,'printshop-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(130425,'printshop-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(130426,'printshop-mobile','.p-payer-order-confirmation .dob-hide','margin-top','20','','','.p-payer-order-confirmation'),(130427,'printshop-mobile','.p-payer-order-pay .dob-hide','margin-top','20','','','.p-payer-order-pay'),(130428,'printshop-mobile','.p-quick-order-index .dataTables_info','margin-top','5','','','.p-quick-order-index'),(130429,'printshop-mobile','.p-quick-order-index ul.token-input-list','margin-top','0','','','.p-quick-order-index'),(130430,'printshop-mobile','.w-account-address-book .address-book','margin-top','0','','','.w-account-address-book'),(130431,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(130432,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(130433,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(130434,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(130435,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(130436,'printshop-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(130437,'printshop-mobile','.w-account-personal-catalog .list-switcher','margin-top','0','','','.w-account-personal-catalog'),(130438,'printshop-mobile','.w-blog-widget-categories-list div ~ div','margin-top','10','','','.w-blog-widget-categories-list'),(130439,'printshop-mobile','.w-blog-widget-post-listing .post_date span + span','margin-top','0','3','','.w-blog-widget-post-listing'),(130440,'printshop-mobile','.w-blog-widget-post-listing ','margin-top','0','','','.w-blog-widget-post-listing'),(130441,'printshop-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-top','0','','','.w-blog-widget-post-share'),(130442,'printshop-mobile','.w-blog-widget-post-title h1','margin-top','0','','','.w-blog-widget-post-title'),(130443,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','margin-top','-17','','','.w-blog-widget-related-posts'),(130444,'printshop-mobile','.w-cart-compare .product .image','margin-top','0','','','.w-cart-compare'),(130445,'printshop-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(130446,'printshop-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(130447,'printshop-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(130448,'printshop-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(130449,'printshop-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(130450,'printshop-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(130451,'printshop-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-top','0','','','.w-catalog-additional-images'),(130452,'printshop-mobile','.w-catalog-items-on-page select','margin-top','0','','','.w-catalog-items-on-page'),(130453,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top','0','','','.w-catalog-paging'),(130454,'printshop-mobile','.w-checkout-billing-address .bootstrap-switch','margin-top','-2','','','.w-checkout-billing-address'),(130455,'printshop-mobile','.w-checkout-contact-information .contact-info-buttons','margin-top','5','','','.w-checkout-contact-information'),(130456,'printshop-mobile','.w-checkout-gdpr .privacy-row','margin-top','0','','','.w-checkout-gdpr'),(130457,'printshop-mobile','.w-checkout-gdpr .bootstrap-switch','margin-top','0','','','.w-checkout-gdpr'),(130458,'printshop-mobile','.w-checkout-shipping-address .change-ab','margin-top','5','','','.w-checkout-shipping-address'),(130459,'printshop-mobile','.w-communication-new-topic .files-box','margin-top','50','','','.w-communication-new-topic'),(130460,'printshop-mobile','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(130461,'printshop-mobile','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(130462,'printshop-mobile','.w-multi-cart-cart-switcher .cart-label','margin-top','-20','','','.w-multi-cart-cart-switcher'),(130463,'printshop-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(130464,'printshop-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(130465,'printshop-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(130466,'printshop-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(130467,'printshop-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(130468,'printshop-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(130469,'printshop-mobile','.w-product-customers-activity .buttons','margin-top','10','','','.w-product-customers-activity'),(130470,'printshop-mobile','.w-promotions .promo-cart-discount .master .image','margin-top','-16','','','.w-promotions'),(130471,'printshop-mobile','.w-promotions .promo-cart-discount .master .item','margin-top','12','','','.w-promotions'),(130472,'printshop-mobile','.w-promotions .promo-cart-discount .slave .item','margin-top','2','','','.w-promotions'),(130473,'printshop-mobile','.w-promotions .promo-salemaker .content','margin-top','-18','','','.w-promotions'),(130474,'printshop-mobile','.w-promotions .promo-salemaker .item','margin-top','2','','','.w-promotions'),(130475,'printshop-mobile','.w-sitemap-delivery-location > ul','margin-top','0','','','.w-sitemap-delivery-location'),(130476,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-top','0','','','.w-sitemap-delivery-location'),(130477,'printshop-mobile','.w-social-links a','margin-top','0','','','.w-social-links'),(130478,'printshop-mobile','.w-taxable select','margin-top','0','','','.w-taxable'),(130479,'printshop-mobile','.w-taxable label','margin-top','0','','','.w-taxable'),(130480,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-template .btn','margin-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(130481,'printshop-mobile','.w-wedding-registry-widgets-products .rating','margin-top','15','','','.w-wedding-registry-widgets-products'),(130482,'printshop-mobile','.w-wedding-registry-widgets-search-form .button','margin-top','-46','','','.w-wedding-registry-widgets-search-form'),(130483,'printshop-mobile','.w-multi-cart-save-cart .copy-cart','margin-top','10','','','.w-multi-cart-save-cart'),(130484,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top_important','important','','','.w-catalog-paging'),(130485,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(130486,'printshop-mobile','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(130487,'printshop-mobile','.w-cart-give-away .ga_attributes > div','margin_bottom_measure','%','','','.w-cart-give-away'),(130488,'printshop-mobile','.p-quick-order-index ul.token-input-list','margin_bottom_measure','pt','','','.p-quick-order-index'),(130489,'printshop-mobile','.w-sale .left-count','margin_left_measure','%','','','.w-sale'),(130490,'printshop-mobile','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(130491,'printshop-mobile','.w-product-sale-ends .left-count','margin_left_measure','%','','','.w-product-sale-ends'),(130492,'printshop-mobile','.w-product-sale-ends .left-text-right','margin_left_measure','%','','','.w-product-sale-ends'),(130493,'printshop-mobile','.w-list-type-1_2 .right-area .right-area-2','margin_left_measure','%','','','.w-list-type-1_2'),(130494,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(130495,'printshop-mobile','.w-list-type-1_3 .right-area .right-area-2','margin_left_measure','%','','','.w-list-type-1_3'),(130496,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(130497,'printshop-mobile','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(130498,'printshop-mobile','.p-account-address-book .address_book_row .column + .column, .p-account-address-book .topInfo > div + div','margin_left_measure','%','','','.p-account-address-book'),(130499,'printshop-mobile','.p-account-index .account_info li','margin_left_measure','%','','','.p-account-index'),(130500,'printshop-mobile','.w-cart-give-away .ga_attributes > div','margin_left_measure','%','','','.w-cart-give-away'),(130501,'printshop-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin_left_measure','%','','','.w-product-in-bundles'),(130502,'printshop-mobile','.w-product-bundle .bundle_item + .bundle_item','margin_left_measure','%','','','.w-product-bundle'),(130503,'printshop-mobile','.w-sale .left-text-right','margin_left_measure','%','','','.w-sale'),(130504,'printshop-mobile','.w-cart-give-away .ga_column','margin_left_measure','%','','','.w-cart-give-away'),(130505,'printshop-mobile','.b-form .columns .col-2:nth-child(2n)','margin_left_measure','%','','','.b-form'),(130506,'printshop-mobile','.b-form .addresses .address-item:nth-child(2n)','margin_left_measure','%','','','.b-form'),(130507,'printshop-mobile','.b-trade-approval .col-3 + .col-3','margin_left_measure','%','','','.b-trade-approval'),(130508,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_left_measure','pt','','','.b-warehouses-popup'),(130509,'printshop-mobile','.p-quick-order-index ul.token-input-list','margin_left_measure','pt','','','.p-quick-order-index'),(130510,'printshop-mobile','.w-delivery-day .left-count','margin_left_measure','%','','','.w-delivery-day'),(130511,'printshop-mobile','.w-delivery-day .left-text-right','margin_left_measure','%','','','.w-delivery-day'),(130512,'printshop-mobile','.w-taxable select','margin_left_measure','pt','','','.w-taxable'),(130513,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(130514,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(130515,'printshop-mobile','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(130516,'printshop-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','margin_right_measure','%','','','.p-account-address-book'),(130517,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','margin_right_measure','%','','','.b-fancybox'),(130518,'printshop-mobile','.w-cart-give-away .ga_attributes > div','margin_right_measure','%','','','.w-cart-give-away'),(130519,'printshop-mobile','.w-product-in-bundles .bundle_item','margin_right_measure','%','','','.w-product-in-bundles'),(130520,'printshop-mobile','.w-product-bundle .bundle_item','margin_right_measure','%','','','.w-product-bundle'),(130521,'printshop-mobile','.w-cart-give-away .ga_column','margin_right_measure','%','','','.w-cart-give-away'),(130522,'printshop-mobile','.w-cart-give-away .ga_img','margin_right_measure','%','','','.w-cart-give-away'),(130523,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_right_measure','pt','','','.b-warehouses-popup'),(130524,'printshop-mobile','.p-quick-order-index ul.token-input-list','margin_right_measure','pt','','','.p-quick-order-index'),(130525,'printshop-mobile','.w-taxable select','margin_right_measure','pt','','','.w-taxable'),(130526,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(130527,'printshop-mobile','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(130528,'printshop-mobile','.w-cart-give-away .ga_attributes > div','margin_top_measure','%','','','.w-cart-give-away'),(130529,'printshop-mobile','.p-quick-order-index ul.token-input-list','margin_top_measure','pt','','','.p-quick-order-index'),(130530,'printshop-mobile','.w-sale .image img','max-height','300','','','.w-sale'),(130531,'printshop-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','max-height','130','','','.b-product-images'),(130532,'printshop-mobile','.w-product-images img','max-height','450','','','.w-product-images'),(130533,'printshop-mobile','.b-fancybox .fancybox-image','max-height','100','','','.b-fancybox'),(130534,'printshop-mobile','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(130535,'printshop-mobile','.w-list-type-1 .image img','max-height','150','','','.w-list-type-1'),(130536,'printshop-mobile','.w-search .suggest','max-height','400','','','.w-search'),(130537,'printshop-mobile','.b-fancybox .fancybox-tmp','max-height','99999','','','.b-fancybox'),(130538,'printshop-mobile','.w-product-images .item-img','max-height','70','723','','.w-product-images'),(130539,'printshop-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-height','100','','','.b-products-listing'),(130540,'printshop-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(130541,'printshop-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(130542,'printshop-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(130543,'printshop-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(130544,'printshop-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(130545,'printshop-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(130546,'printshop-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','max-height','0','','','.b-menu-burger_icon'),(130547,'printshop-mobile','.b-menu-burger_icon .bi-opened .menu-style[data-open_from=\"top\"] .menu-content','max-height','2000','','','.b-menu-burger_icon'),(130548,'printshop-mobile','.b-select-suggest .select2-results','max-height','200','','','.b-select-suggest'),(130549,'printshop-mobile','.batchPr .w-batch-products .products-listing .image img','max-height','80','','','.batchPr'),(130550,'printshop-mobile','.batchPr .w-batch-selected-products .image img','max-height','40','','','.batchPr'),(130551,'printshop-mobile','.batchPr .w-batch-products .image img','max-height','160','','','.batchPr'),(130552,'printshop-mobile','.w-blog-widget-post-listing .post_image img','max-height','232','','','.w-blog-widget-post-listing'),(130553,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_img img','max-height','167','','','.w-blog-widget-related-posts-by-category'),(130554,'printshop-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(130555,'printshop-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(130556,'printshop-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(130557,'printshop-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(130558,'printshop-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(130559,'printshop-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(130560,'printshop-mobile','.w-promotions .prom-multi-discount .image img','max-height','80','','','.w-promotions'),(130561,'printshop-mobile','.w-promotions .promo-cart-discount .image img','max-height','80','','','.w-promotions'),(130562,'printshop-mobile','.w-promotions .promo-salemaker .image img','max-height','80','','','.w-promotions'),(130563,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-height','100','','','.w-upload-customer-id-upload-customer-id-form'),(130564,'printshop-mobile','.w-menu .hided.menu ul ul','max-width','none','','','.w-menu'),(130565,'printshop-mobile','.w-product-images img','max-width','100','','','.w-product-images'),(130566,'printshop-mobile','.p-blog-index .post-thumbnail','max-width','40','','','.p-blog-index'),(130567,'printshop-mobile','.w-list-type-1_2 .image','max-width','100','694','','.w-list-type-1_2'),(130568,'printshop-mobile','.p-wedding-registry-manage .wr-search','max-width','100','','','.p-wedding-registry-manage'),(130569,'printshop-mobile','.p-blog-index .avatar','max-width','28','','','.p-blog-index'),(130570,'printshop-mobile','.b-fancybox .fancybox-image','max-width','100','','','.b-fancybox'),(130571,'printshop-mobile','.p-wedding-registry-index .middle-box','max-width','600','','','.p-wedding-registry-index'),(130572,'printshop-mobile','.p-wedding-registry-index .main-content','max-width','none','','','.p-wedding-registry-index'),(130573,'printshop-mobile','.b-bottom .popup-credit-amount .popup-box','max-width','960','','','.b-bottom'),(130574,'printshop-mobile','textarea','max-width','100','','',''),(130575,'printshop-mobile','.b-fancybox .fancybox-tmp','max-width','99999','','','.b-fancybox'),(130576,'printshop-mobile','.w-product-video .frame-video iframe','max-width','100','','','.w-product-video'),(130577,'printshop-mobile','.w-product-images .item-img','max-width','70','723','','.w-product-images'),(130578,'printshop-mobile','.main-width, .type-1 > .block','max-width','1250','','',''),(130579,'printshop-mobile','.w-list-type-1_3 .image','max-width','100','694','','.w-list-type-1_3'),(130580,'printshop-mobile','.w-list-type-1_2 .image','max-width','170','','','.w-list-type-1_2'),(130581,'printshop-mobile','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(130582,'printshop-mobile','.b-form .middle-form','max-width','560','','','.b-form'),(130583,'printshop-mobile','div.cart-popup','max-width','95','','',''),(130584,'printshop-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-width','100','','','.b-products-listing'),(130585,'printshop-mobile','.b-products-listing .promo','max-width','30','','','.b-products-listing'),(130586,'printshop-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(130587,'printshop-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(130588,'printshop-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(130589,'printshop-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(130590,'printshop-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(130591,'printshop-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(130592,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max-width','100','','','.b-menu-lev_display-slide'),(130593,'printshop-mobile','.b-trade-approval .middle-form','max-width','560','','','.b-trade-approval'),(130594,'printshop-mobile','.b-upload-files .attached-block','max-width','300','','','.b-upload-files'),(130595,'printshop-mobile','.batchPr .w-batch-products .products-listing .image','max-width','100','','','.batchPr'),(130596,'printshop-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','max-width','1250','','','.w-catalog-b2b-add-button'),(130597,'printshop-mobile','.w-checkout-create-btn .btn-2','max-width','100','','','.w-checkout-create-btn'),(130598,'printshop-mobile','.w-checkout-guest-btn .btn-2','max-width','100','','','.w-checkout-guest-btn'),(130599,'printshop-mobile','.w-login-register .middle-form','max-width','100','','','.w-login-register'),(130600,'printshop-mobile','.w-login-returning .middle-form','max-width','100','','','.w-login-returning'),(130601,'printshop-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(130602,'printshop-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(130603,'printshop-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(130604,'printshop-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(130605,'printshop-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(130606,'printshop-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(130607,'printshop-mobile','.w-promotions .heading-3','max-width','calc(100% - 100px)','','','.w-promotions'),(130608,'printshop-mobile','.w-promotions .promo-cart-discount .master .item','max-width','calc(50% - 24px)','','','.w-promotions'),(130609,'printshop-mobile','.w-promotions .promo-cart-discount .slave .item','max-width','calc(50% - 4px)','','','.w-promotions'),(130610,'printshop-mobile','.w-promotions .promo-salemaker .item','max-width','calc(50% - 4px)','','','.w-promotions'),(130611,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-width','100','','','.w-upload-customer-id-upload-customer-id-form'),(130612,'printshop-mobile','.b-fancybox .fancybox-image','max_height_measure','%','','','.b-fancybox'),(130613,'printshop-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_height_measure','%','','','.b-products-listing'),(130614,'printshop-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(130615,'printshop-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(130616,'printshop-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(130617,'printshop-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(130618,'printshop-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(130619,'printshop-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(130620,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(130621,'printshop-mobile','.w-product-video .frame-video iframe','max_width_measure','%','','','.w-product-video'),(130622,'printshop-mobile','.w-product-images img','max_width_measure','%','','','.w-product-images'),(130623,'printshop-mobile','.p-blog-index .post-thumbnail','max_width_measure','%','','','.p-blog-index'),(130624,'printshop-mobile','.w-list-type-1_2 .image','max_width_measure','%','694','','.w-list-type-1_2'),(130625,'printshop-mobile','.p-wedding-registry-manage .wr-search','max_width_measure','%','','','.p-wedding-registry-manage'),(130626,'printshop-mobile','.b-fancybox .fancybox-image','max_width_measure','%','','','.b-fancybox'),(130627,'printshop-mobile','.w-list-type-1_3 .image','max_width_measure','%','694','','.w-list-type-1_3'),(130628,'printshop-mobile','textarea','max_width_measure','%','','',''),(130629,'printshop-mobile','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(130630,'printshop-mobile','div.cart-popup','max_width_measure','%','','',''),(130631,'printshop-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_width_measure','%','','','.b-products-listing'),(130632,'printshop-mobile','.b-products-listing .promo','max_width_measure','%','','','.b-products-listing'),(130633,'printshop-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(130634,'printshop-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(130635,'printshop-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(130636,'printshop-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(130637,'printshop-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(130638,'printshop-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(130639,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max_width_measure','vw','','','.b-menu-lev_display-slide'),(130640,'printshop-mobile','.w-checkout-create-btn .btn-2','max_width_measure','%','','','.w-checkout-create-btn'),(130641,'printshop-mobile','.w-checkout-guest-btn .btn-2','max_width_measure','%','','','.w-checkout-guest-btn'),(130642,'printshop-mobile','.w-login-register .middle-form','max_width_measure','%','','','.w-login-register'),(130643,'printshop-mobile','.w-login-returning .middle-form','max_width_measure','%','','','.w-login-returning'),(130644,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(130645,'printshop-mobile','.w-search .search-input','min-height','35','','','.w-search'),(130646,'printshop-mobile','.w-currencies .current','min-height','31','','','.w-currencies'),(130647,'printshop-mobile','.b-slick .slick-slide','min-height','1','','','.b-slick'),(130648,'printshop-mobile','.w-cart-discount-coupon .gift-code p','min-height','45','','','.w-cart-discount-coupon'),(130649,'printshop-mobile','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(130650,'printshop-mobile','.w-languages .current','min-height','31','','','.w-languages'),(130651,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','min-height','40','','','.b-menu-style-1'),(130652,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1','min-height','35','','','.b-menu-style-1'),(130653,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1','min-height','35','','','.b-menu-style-3'),(130654,'printshop-mobile','.b-select-suggest .select2-search input','min-height','26','','','.b-select-suggest'),(130655,'printshop-mobile','.b-select-suggest .select2-drop-mask','min-height','100','','','.b-select-suggest'),(130656,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','min-height','26','','','.b-select-suggest'),(130657,'printshop-mobile','.b-select-suggest .select2-search','min-height','26','','','.b-select-suggest'),(130658,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','min-height','1','','','.b-select-suggest'),(130659,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','min-height','0','','','.batchPr'),(130660,'printshop-mobile','.batchPr .w-batch-selected-products','min-height','0','','','.batchPr'),(130661,'printshop-mobile','.batchPr .w-batch-products .products-listing .product-holder','min-height_important','important','','','.batchPr'),(130662,'printshop-mobile','.batchPr .w-batch-selected-products','min-height_important','important','','','.batchPr'),(130663,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','min-width','150','','','.w-menu-horizontal'),(130664,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','min-width','150','','','.w-menu-style-1'),(130665,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li ul','min-width','150','','','.w-menu-style-1'),(130666,'printshop-mobile','.b-pagination .pagination .prev','min-width','30','','','.b-pagination'),(130667,'printshop-mobile','.b-bottom .confirm-popup .buttons .btn','min-width','120','','','.b-bottom'),(130668,'printshop-mobile','.b-pagination .pagination .prev-pages','min-width','30','','','.b-pagination'),(130669,'printshop-mobile','.b-pagination .pagination .page-number','min-width','30','','','.b-pagination'),(130670,'printshop-mobile','.b-pagination .pagination .next-pages','min-width','30','','','.b-pagination'),(130671,'printshop-mobile','.b-pagination .pagination span','min-width','30','2','','.b-pagination'),(130672,'printshop-mobile','.b-pagination .pagination .next','min-width','30','','','.b-pagination'),(130673,'printshop-mobile','.b-pagination .pagination a','min-width','30','','','.b-pagination'),(130674,'printshop-mobile','.b-bottom .popup-box.popupCompare','min-width','800','','','.b-bottom'),(130675,'printshop-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(130676,'printshop-mobile','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(130677,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li','min-width','150','','','.w-menu-horizontal'),(130678,'printshop-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','min-width','70','','','.b-form'),(130679,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.b-data-table'),(130680,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.b-data-table'),(130681,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','min-width','200','','','.b-menu-lev_display-down'),(130682,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','min-width','200','','','.b-menu-lev_display-down'),(130683,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','min-width','200','','','.b-menu-lev_display-down'),(130684,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','min-width','200','','','.b-menu-lev_display-down'),(130685,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','min-width','200','','','.b-menu-lev_display-down'),(130686,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','min-width','200','','','.b-menu-lev_display-left'),(130687,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','min-width','200','','','.b-menu-lev_display-left'),(130688,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','min-width','200','','','.b-menu-lev_display-left'),(130689,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','min-width','200','','','.b-menu-lev_display-left'),(130690,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','min-width','200','','','.b-menu-lev_display-left'),(130691,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','min-width','200','','','.b-menu-lev_display-lra'),(130692,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','min-width','200','','','.b-menu-lev_display-lra'),(130693,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','min-width','200','','','.b-menu-lev_display-lra'),(130694,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','min-width','200','','','.b-menu-lev_display-lra'),(130695,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','min-width','200','','','.b-menu-lev_display-lra'),(130696,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','min-width','200','','','.b-menu-lev_display-right'),(130697,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','min-width','200','','','.b-menu-lev_display-right'),(130698,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','min-width','200','','','.b-menu-lev_display-right'),(130699,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','min-width','200','','','.b-menu-lev_display-right'),(130700,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','min-width','200','','','.b-menu-lev_display-right'),(130701,'printshop-mobile','.b-select-suggest .select2-drop-mask','min-width','100','','','.b-select-suggest'),(130702,'printshop-mobile','.p-quick-order-index .al_incart, .p-quick-order-index .al-incart','min-width','60','','','.p-quick-order-index'),(130703,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.p-quick-order-index'),(130704,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.p-quick-order-index'),(130705,'printshop-mobile','.w-catalog-paging .prev','min-width','30','','','.w-catalog-paging'),(130706,'printshop-mobile','.w-catalog-paging ','min-width','30','2','','.w-catalog-paging'),(130707,'printshop-mobile','.w-catalog-paging .next','min-width','30','','','.w-catalog-paging'),(130708,'printshop-mobile','.w-catalog-paging .page-number','min-width','30','','','.w-catalog-paging'),(130709,'printshop-mobile','.w-catalog-paging .next-pages','min-width','30','','','.w-catalog-paging'),(130710,'printshop-mobile','.w-catalog-paging .prev-pages','min-width','30','','','.w-catalog-paging'),(130711,'printshop-mobile','.w-communication-new-topic #communication_group_holder table table','min-width','0','','','.w-communication-new-topic'),(130712,'printshop-mobile','.w-communication-new-topic .quantity','min-width','70','','','.w-communication-new-topic'),(130713,'printshop-mobile','.w-communication-new-topic #communication_group_holder table','min-width','800','','','.w-communication-new-topic'),(130714,'printshop-mobile','.w-communication-post .btn-submit','min-width','200','','','.w-communication-post'),(130715,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','min_height_measure','em','','','.b-select-suggest'),(130716,'printshop-mobile','.b-select-suggest .select2-drop-mask','min_height_measure','%','','','.b-select-suggest'),(130717,'printshop-mobile','.b-select-suggest .select2-drop-mask','min_width_measure','%','','','.b-select-suggest'),(130718,'printshop-mobile','.w-filters .input-checkbox','opacity','0','','','.w-filters'),(130719,'printshop-mobile','.p-account-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-history-info'),(130720,'printshop-mobile','.p-account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-order-pay'),(130721,'printshop-mobile','.b-pagination .pagination .paging span.prev, .b-pagination .pagination .paging span.next','opacity','0.3','','','.b-pagination'),(130722,'printshop-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','opacity','0','','','.b-switch'),(130723,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','opacity','0.5','','','.b-switch'),(130724,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','opacity','0.5','','','.b-switch'),(130725,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','opacity','0.5','','','.b-switch'),(130726,'printshop-mobile','.b-slick button.slick-disabled','opacity','0.3','','','.b-slick'),(130727,'printshop-mobile','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(130728,'printshop-mobile','.b-form .checkbox-style','opacity','0','','','.b-form'),(130729,'printshop-mobile','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(130730,'printshop-mobile','.b-form .hide-billing-address','opacity','0.7','','','.b-form'),(130731,'printshop-mobile','.b-fancybox #fancybox-loading','opacity','0.8','','','.b-fancybox'),(130732,'printshop-mobile','.b-products-listing .products-listing .qty-input.hidden','opacity','0.7','3','','.b-products-listing'),(130733,'printshop-mobile','.b-select-suggest .select2-drop-mask','opacity','0','','','.b-select-suggest'),(130734,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-samples-history-info'),(130735,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-samples-history-info'),(130736,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-samples-history-info'),(130737,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-samples-history-info'),(130738,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-samples-history-info'),(130739,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-samples-history-info'),(130740,'printshop-mobile','.p-quick-order-index .paginate_button.next.disabled','opacity','0.3','3','','.p-quick-order-index'),(130741,'printshop-mobile','.p-quick-order-index .paginate_button.previous.disabled','opacity','0.3','3','','.p-quick-order-index'),(130742,'printshop-mobile','.w-catalog-paging .paging span.prev, .w-catalog-paging .paging span.next','opacity','0.3','','','.w-catalog-paging'),(130743,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition','order','2','','','.w-promotions'),(130744,'printshop-mobile','.w-promotions .promo-cart-discount .slave .content','order','3','','','.w-promotions'),(130745,'printshop-mobile','.w-promotions .promo-cart-discount .slave .heading','order','1','','','.w-promotions'),(130746,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-focused','outline','0','','','.b-switch'),(130747,'printshop-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','outline','none','','','.b-fancybox'),(130748,'printshop-mobile','.b-slick .slick-list:focus','outline','none','','','.b-slick'),(130749,'printshop-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','outline','none','','','.b-fancybox'),(130750,'printshop-mobile','.b-product-images .additional-images div:focus, .b-product-images .additional-videos div:focus','outline','none','','','.b-product-images'),(130751,'printshop-mobile','.b-select-suggest .select2-search-choice-close','outline','none','','','.b-select-suggest'),(130752,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','outline','0','','','.b-select-suggest'),(130753,'printshop-mobile','.b-select-suggest .select2-container-active .select2-choice, .b-select-suggest .select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(130754,'printshop-mobile','.b-select-suggest .select2-search input','outline','0','','','.b-select-suggest'),(130755,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline','0','','','.b-select-suggest'),(130756,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(130757,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','outline','0','','','.b-select-suggest'),(130758,'printshop-mobile','.batchPr .products-listing .item','outline','none','','','.batchPr'),(130759,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline_important','important','','','.b-select-suggest'),(130760,'printshop-mobile','.w-list-type-2_2 .compare-box-item','overflow','hidden','','','.w-list-type-2_2'),(130761,'printshop-mobile','.b-switch .bootstrap-switch','overflow','hidden','','','.b-switch'),(130762,'printshop-mobile','.w-product-sale-ends .left','overflow','hidden','','','.w-product-sale-ends'),(130763,'printshop-mobile','.w-sale .sale-holder','overflow','hidden','','','.w-sale'),(130764,'printshop-mobile','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(130765,'printshop-mobile','.w-cart .no-text','overflow','hidden','','','.w-cart'),(130766,'printshop-mobile','.p-account-index .topAccount','overflow','hidden','','','.p-account-index'),(130767,'printshop-mobile','.w-quote .no-text','overflow','hidden','','','.w-quote'),(130768,'printshop-mobile','.w-product-images .img-holder','overflow','hidden','','','.w-product-images'),(130769,'printshop-mobile','.p-account-order-pay .history_info','overflow','hidden','','','.p-account-order-pay'),(130770,'printshop-mobile','.p-blog-index .nav-links','overflow','hidden','','','.p-blog-index'),(130771,'printshop-mobile','.w-list-type-2_2 .buttons','overflow','hidden','','','.w-list-type-2_2'),(130772,'printshop-mobile','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(130773,'printshop-mobile','.b-fancybox .fancybox-inner','overflow','hidden','','','.b-fancybox'),(130774,'printshop-mobile','.b-fancybox .fancybox-lock','overflow','hidden','','','.b-fancybox'),(130775,'printshop-mobile','.b-fancybox .fancybox-lock .fancybox-overlay','overflow','auto','','','.b-fancybox'),(130776,'printshop-mobile','.b-fancybox .fancybox-lock body','overflow','hidden','','','.b-fancybox'),(130777,'printshop-mobile','.b-compare .col-two','overflow','hidden','','','.b-compare'),(130778,'printshop-mobile','.b-compare .compare-box-item','overflow','hidden','','','.b-compare'),(130779,'printshop-mobile','.w-search .suggest','overflow','auto','','','.w-search'),(130780,'printshop-mobile','.w-search .item','overflow','hidden','','','.w-search'),(130781,'printshop-mobile','.w-list-type-1_2 .compare-box-item','overflow','hidden','','','.w-list-type-1_2'),(130782,'printshop-mobile','.w-banner .banner .image-box','overflow','hidden','','','.w-banner'),(130783,'printshop-mobile','.p-account-trade-form .widget','overflow','hidden','','','.p-account-trade-form'),(130784,'printshop-mobile','.p-checkout-index .sel_pr_values','overflow','hidden','','','.p-checkout-index'),(130785,'printshop-mobile','.w-list-type-2 .compare-box-item','overflow','hidden','','','.w-list-type-2'),(130786,'printshop-mobile','.w-list-type-1_3 .compare-box-item','overflow','hidden','','','.w-list-type-1_3'),(130787,'printshop-mobile','.w-list-type-1 .compare-box-item','overflow','hidden','','','.w-list-type-1'),(130788,'printshop-mobile','.b-fancybox .fancybox-tmp','overflow','visible','','','.b-fancybox'),(130789,'printshop-mobile','.w-menu-mobile .menu-slider .open','overflow','auto','','','.w-menu-mobile'),(130790,'printshop-mobile','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(130791,'printshop-mobile','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(130792,'printshop-mobile','.p-reviews-info .review-info-head','overflow','hidden','','','.p-reviews-info'),(130793,'printshop-mobile','.b-fancybox .fancybox-overlay','overflow','hidden','','','.b-fancybox'),(130794,'printshop-mobile','.w-sale .left','overflow','hidden','','','.w-sale'),(130795,'printshop-mobile','.b-slick .slick-list','overflow','hidden','','','.b-slick'),(130796,'printshop-mobile','.w-cart-discount-coupon .gift-code .input-apple > div','overflow','hidden','','','.w-cart-discount-coupon'),(130797,'printshop-mobile','.p-account-history-info .history_info','overflow','hidden','','','.p-account-history-info'),(130798,'printshop-mobile','.p-account-index .acount_row','overflow','hidden','','','.p-account-index'),(130799,'printshop-mobile','.p-account-index .account_page','overflow','hidden','','','.p-account-index'),(130800,'printshop-mobile','.w-cart-give-away .ga_ovr','overflow','hidden','','','.w-cart-give-away'),(130801,'printshop-mobile','.w-cart-give-away .ga_wrapper','overflow','hidden','','','.w-cart-give-away'),(130802,'printshop-mobile','.w-list-type-2 .buttons','overflow','hidden','','','.w-list-type-2'),(130803,'printshop-mobile','.b-autocomplete .ui-autocomplete','overflow','auto','','','.b-autocomplete'),(130804,'printshop-mobile','.w-list-type-1_3 .buttons','overflow','hidden','','','.w-list-type-1_3'),(130805,'printshop-mobile','.w-list-type-1_3 .attributes > .attributes','overflow','hidden','','','.w-list-type-1_3'),(130806,'printshop-mobile','.w-list-type-1_2 .buttons','overflow','hidden','','','.w-list-type-1_2'),(130807,'printshop-mobile','.w-list-type-1 .buttons','overflow','hidden','','','.w-list-type-1'),(130808,'printshop-mobile','.b-form .addresses .address-item span','overflow','hidden','','','.b-form'),(130809,'printshop-mobile','.b-form .discount-box .inp','overflow','hidden','','','.b-form'),(130810,'printshop-mobile','.b-form .payment-method .item-radio label span','overflow','hidden','','','.b-form'),(130811,'printshop-mobile','.p-account-address-book .buttonBox','overflow','hidden','','','.p-account-address-book'),(130812,'printshop-mobile','.b-products-listing .btn-preloader','overflow','hidden','3','','.b-products-listing'),(130813,'printshop-mobile','.b-products-listing .loader','overflow','hidden','4','','.b-products-listing'),(130814,'printshop-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','overflow','hidden','','','.b-menu-burger_icon'),(130815,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','overflow','auto','','','.b-menu-lev_display-width'),(130816,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','overflow','auto','','','.b-menu-lev_display-width'),(130817,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','overflow','auto','','','.b-menu-lev_display-width'),(130818,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','overflow','auto','','','.b-menu-lev_display-width'),(130819,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','overflow','auto','','','.b-menu-lev_display-width'),(130820,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','overflow','auto','','','.b-menu-lev_display-width_cont'),(130821,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','overflow','auto','','','.b-menu-lev_display-width_cont'),(130822,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','overflow','auto','','','.b-menu-lev_display-width_cont'),(130823,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','overflow','auto','','','.b-menu-lev_display-width_cont'),(130824,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','overflow','auto','','','.b-menu-lev_display-width_cont'),(130825,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','overflow','auto','','','.b-menu-open_from-left'),(130826,'printshop-mobile','.b-preloader .preloader','overflow','hidden','3','','.b-preloader'),(130827,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','overflow','hidden','','','.b-select-suggest'),(130828,'printshop-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','overflow','hidden','','','.b-select-suggest'),(130829,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow','hidden','','','.b-select-suggest'),(130830,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','overflow','hidden','','','.b-select-suggest'),(130831,'printshop-mobile','.b-select-suggest .select2-measure-scrollbar','overflow','scroll','','','.b-select-suggest'),(130832,'printshop-mobile','.b-trade-approval .steps-bar','overflow','hidden','','','.b-trade-approval'),(130833,'printshop-mobile','.b-upload-files .attach-active-holder','overflow','hidden','','','.b-upload-files'),(130834,'printshop-mobile','.b-upload-files .attached-block','overflow','hidden','','','.b-upload-files'),(130835,'printshop-mobile','.b-upload-files .attach-block','overflow','hidden','','','.b-upload-files'),(130836,'printshop-mobile','.b-upload-files .added-file','overflow','hidden','','','.b-upload-files'),(130837,'printshop-mobile','.batchPr .w-batch-products .products-listing .image + .type-1','overflow','hidden','','','.batchPr'),(130838,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','overflow','hidden','','','.batchPr'),(130839,'printshop-mobile','.batchPr .batch-selected-products-list','overflow','auto','','','.batchPr'),(130840,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(2)','overflow','hidden','','','.batchPr'),(130841,'printshop-mobile','.p-account-samples-history-info .history_info','overflow','hidden','','','.p-account-samples-history-info'),(130842,'printshop-mobile','.p-account-samples-history-info .history_info','overflow','hidden','','','.p-account-samples-history-info'),(130843,'printshop-mobile','.p-account-samples-history-info .history_info','overflow','hidden','','','.p-account-samples-history-info'),(130844,'printshop-mobile','.p-account-samples-history-info .history_info','overflow','hidden','','','.p-account-samples-history-info'),(130845,'printshop-mobile','.p-account-samples-history-info .history_info','overflow','hidden','','','.p-account-samples-history-info'),(130846,'printshop-mobile','.p-account-samples-history-info .history_info','overflow','hidden','','','.p-account-samples-history-info'),(130847,'printshop-mobile','.p-quick-order-index .top','overflow','hidden','','','.p-quick-order-index'),(130848,'printshop-mobile','.p-quick-order-index .bottom','overflow','hidden','','','.p-quick-order-index'),(130849,'printshop-mobile','.w-account-addresses-list ','overflow','hidden','','','.w-account-addresses-list'),(130850,'printshop-mobile','.w-blog-widget-post-linked-products .heading-2','overflow','hidden','','','.w-blog-widget-post-linked-products'),(130851,'printshop-mobile','.w-blog-widget-related-posts ','overflow','hidden','','','.w-blog-widget-related-posts'),(130852,'printshop-mobile','.w-blog-widget-related-posts-by-category ','overflow','hidden','','','.w-blog-widget-related-posts-by-category'),(130853,'printshop-mobile','.w-cart-compare .product .name','overflow','hidden','','','.w-cart-compare'),(130854,'printshop-mobile','.w-catalog-compare .compare','overflow','hidden','','','.w-catalog-compare'),(130855,'printshop-mobile','.w-catalog-paging .paging-holder','overflow','hidden','','','.w-catalog-paging'),(130856,'printshop-mobile','.w-catalog-paging .paging-holder.slick-slider','overflow','visible','','','.w-catalog-paging'),(130857,'printshop-mobile','.w-checkout-shipping-choice #shippingchoice-choice','overflow','hidden','','','.w-checkout-shipping-choice'),(130858,'printshop-mobile','.w-checkout-shipping-choice input','overflow','hidden','','','.w-checkout-shipping-choice'),(130859,'printshop-mobile','.w-communication-new-topic #communication_group_holder','overflow','auto','','','.w-communication-new-topic'),(130860,'printshop-mobile','.w-delivery-day .time-left','overflow','hidden','','','.w-delivery-day'),(130861,'printshop-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','overflow','hidden','','','.w-promotions'),(130862,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','overflow','hidden','','','.w-wedding-registry-widgets-photos'),(130863,'printshop-mobile','.b-compare .compare_list','overflow-x','hidden','','','.b-compare'),(130864,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-x','hidden','','','.b-menu-lev_display-slide'),(130865,'printshop-mobile','.b-select-suggest .select2-results','overflow-x','hidden','','','.b-select-suggest'),(130866,'printshop-mobile','.b-compare .compare_list','overflow-y','auto','','','.b-compare'),(130867,'printshop-mobile','.b-fancybox .fancybox-lock-test','overflow-y','hidden','','','.b-fancybox'),(130868,'printshop-mobile','.b-fancybox .fancybox-lock .fancybox-overlay','overflow-y','scroll','','','.b-fancybox'),(130869,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-y','auto','','','.b-menu-lev_display-slide'),(130870,'printshop-mobile','.b-select-suggest .select2-results','overflow-y','auto','','','.b-select-suggest'),(130871,'printshop-mobile','.b-fancybox .fancybox-lock-test','overflow-y_important','important','','','.b-fancybox'),(130872,'printshop-mobile','.b-fancybox .fancybox-lock','overflow_important','important','','','.b-fancybox'),(130873,'printshop-mobile','.b-fancybox .fancybox-lock body','overflow_important','important','','','.b-fancybox'),(130874,'printshop-mobile','.b-fancybox .fancybox-tmp','overflow_important','important','','','.b-fancybox'),(130875,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow_important','important','','','.b-select-suggest'),(130876,'printshop-mobile','.w-list-type-1_3 .compare-box-item','padding-bottom','7','','','.w-list-type-1_3'),(130877,'printshop-mobile','.w-list-type-2 .compare-box-item','padding-bottom','7','','','.w-list-type-2'),(130878,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-2'),(130879,'printshop-mobile','.w-list-type-2_2.products-listing','padding-bottom','20','','','.w-list-type-2_2'),(130880,'printshop-mobile','.w-list-type-1_3 .item','padding-bottom','20','','','.w-list-type-1_3'),(130881,'printshop-mobile','.w-list-type-2_2 .compare-box-item','padding-bottom','7','','','.w-list-type-2_2'),(130882,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-2_2'),(130883,'printshop-mobile','.w-list-type-2.products-listing','padding-bottom','20','','','.w-list-type-2'),(130884,'printshop-mobile','.w-list-type-2 .item','padding-bottom','21','','','.w-list-type-2'),(130885,'printshop-mobile','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(130886,'printshop-mobile','.w-list-type-3.products-listing','padding-bottom','20','','','.w-list-type-3'),(130887,'printshop-mobile','.w-menu .hided.menu ul li','padding-bottom','0','','','.w-menu'),(130888,'printshop-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-bottom','0','','','.w-menu'),(130889,'printshop-mobile','.w-menu-slider > ul > li > a','padding-bottom','5','','','.w-menu-slider'),(130890,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-bottom','2','','','.w-menu-horizontal'),(130891,'printshop-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','6','','','.w-menu-horizontal'),(130892,'printshop-mobile','.w-menu-big ul','padding-bottom','0','','','.w-menu-big'),(130893,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li','padding-bottom','2','','','.w-menu-horizontal'),(130894,'printshop-mobile','.w-menu-slider > ul > li > ul > li','padding-bottom','10','','','.w-menu-slider'),(130895,'printshop-mobile','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(130896,'printshop-mobile','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(130897,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-bottom','0','','','.b-slick'),(130898,'printshop-mobile','.w-top-categories .item','padding-bottom','30','693','','.w-top-categories'),(130899,'printshop-mobile','.w-menu-slider ul, .w-menu-slider li','padding-bottom','0','','','.w-menu-slider'),(130900,'printshop-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','5','','','.w-menu-style-1'),(130901,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(130902,'printshop-mobile','.b-bottom .popup-simple','padding-bottom','20','','','.b-bottom'),(130903,'printshop-mobile','.b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .buttons','padding-bottom','10','','','.b-cookie-notice'),(130904,'printshop-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.bottom .text','padding-bottom','5','','','.b-cookie-notice'),(130905,'printshop-mobile','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(130906,'printshop-mobile','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(130907,'printshop-mobile','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(130908,'printshop-mobile','.w-product-wedding-registry-button .btn','padding-bottom','0','','','.w-product-wedding-registry-button'),(130909,'printshop-mobile','.w-search .items-title','padding-bottom','5','','','.w-search'),(130910,'printshop-mobile','.w-sale .holder-2','padding-bottom','20','','','.w-sale'),(130911,'printshop-mobile','.w-sale .left-count','padding-bottom','0','','','.w-sale'),(130912,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','padding-bottom','10','','','.w-list-type-1_2'),(130913,'printshop-mobile','.w-product-sale-ends .left-text-left','padding-bottom','24','','','.w-product-sale-ends'),(130914,'printshop-mobile','.w-product-sale-ends .left-text-right','padding-bottom','24','','','.w-product-sale-ends'),(130915,'printshop-mobile','.w-currencies .select-link','padding-bottom','5','','','.w-currencies'),(130916,'printshop-mobile','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(130917,'printshop-mobile','.w-currencies .current','padding-bottom','3','','','.w-currencies'),(130918,'printshop-mobile','.w-categories .name','padding-bottom','3','','','.w-categories'),(130919,'printshop-mobile','.w-categories .item','padding-bottom','30','','','.w-categories'),(130920,'printshop-mobile','.w-filters .filter-ul-content','padding-bottom','0','','','.w-filters'),(130921,'printshop-mobile','.p-account-address-book .buttonBox','padding-bottom','15','','','.p-account-address-book'),(130922,'printshop-mobile','.p-account-history .order_history_table th','padding-bottom','10','','','.p-account-history'),(130923,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','padding-bottom','5','','','.p-account-history-info'),(130924,'printshop-mobile','.p-account-history-info .contentColumn','padding-bottom','10','','','.p-account-history-info'),(130925,'printshop-mobile','.p-account-history-info .historyTotal td','padding-bottom','2','','','.p-account-history-info'),(130926,'printshop-mobile','.p-account-history-info .history_info > div + div','padding-bottom','0','','','.p-account-history-info'),(130927,'printshop-mobile','.p-account-index .account_info','padding-bottom','0','','','.p-account-index'),(130928,'printshop-mobile','.p-account-index .account_info li','padding-bottom','0','','','.p-account-index'),(130929,'printshop-mobile','.p-account-index .account_block','padding-bottom','20','','','.p-account-index'),(130930,'printshop-mobile','.p-account-index .account_page','padding-bottom','0','','','.p-account-index'),(130931,'printshop-mobile','.p-account-index .date_title','padding-bottom','0','','','.p-account-index'),(130932,'printshop-mobile','.p-account-index .badc_bottom','padding-bottom','58','','','.p-account-index'),(130933,'printshop-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','padding-bottom','10','','','.p-account-index'),(130934,'printshop-mobile','.p-account-index .orders-table th','padding-bottom','2','','','.p-account-index'),(130935,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-bottom','10','','','.p-account-subscription-historyinfo'),(130936,'printshop-mobile','.b-bottom .popup-buttons','padding-bottom','15','','','.b-bottom'),(130937,'printshop-mobile','.w-product-images .img-holder','padding-bottom','20','','','.w-product-images'),(130938,'printshop-mobile','.b-bottom .popup-content','padding-bottom','15','','','.b-bottom'),(130939,'printshop-mobile','.b-compare .compare_pagination','padding-bottom','10','','','.b-compare'),(130940,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-bottom','20','','','.b-multi-page-checkout'),(130941,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-bottom','6','','','.b-multi-page-checkout'),(130942,'printshop-mobile','.w-sale .holder-1','padding-bottom','20','','','.w-sale'),(130943,'printshop-mobile','.w-search .suggest','padding-bottom','0','','','.w-search'),(130944,'printshop-mobile','.b-info-popup .info-popup div','padding-bottom','10','','','.b-info-popup'),(130945,'printshop-mobile','.w-search .name','padding-bottom','0','','','.w-search'),(130946,'printshop-mobile','.w-search .item','padding-bottom','10','','','.w-search'),(130947,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-bottom','0','','','.b-multi-page-checkout'),(130948,'printshop-mobile','.w-search .search-input','padding-bottom','5','','','.w-search'),(130949,'printshop-mobile','.w-socials > li','padding-bottom','15','','','.w-socials'),(130950,'printshop-mobile','.w-promo-code .holder','padding-bottom','20','723','','.w-promo-code'),(130951,'printshop-mobile','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(130952,'printshop-mobile','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(130953,'printshop-mobile','.p-wedding-registry-manage a.remove-btn','padding-bottom','5','','','.p-wedding-registry-manage'),(130954,'printshop-mobile','.p-account-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-history-info'),(130955,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','padding-bottom','5','','','.p-account-order-pay'),(130956,'printshop-mobile','.p-account-order-pay .contentColumn','padding-bottom','10','','','.p-account-order-pay'),(130957,'printshop-mobile','.p-account-order-pay .historyTotal td','padding-bottom','2','','','.p-account-order-pay'),(130958,'printshop-mobile','.p-account-order-pay .history_info > div + div','padding-bottom','0','','','.p-account-order-pay'),(130959,'printshop-mobile','.p-account-order-pay .history_info > div','padding-bottom','0','694','','.p-account-order-pay'),(130960,'printshop-mobile','.w-filters .head-filter-widget','padding-bottom','0','720','','.w-filters'),(130961,'printshop-mobile','.w-product-configurator .pc_attr','padding-bottom','5','693','','.w-product-configurator'),(130962,'printshop-mobile','.w-product-configurator .pc_item','padding-bottom','10','702','','.w-product-configurator'),(130963,'printshop-mobile','.testimonials .name','padding-bottom','5','','',''),(130964,'printshop-mobile','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(130965,'printshop-mobile','.p-account-order-pay .history_info > div + div','padding-bottom','0','694','','.p-account-order-pay'),(130966,'printshop-mobile','.testimonials .heading-3','padding-bottom','10','','',''),(130967,'printshop-mobile','.testimonials .review','padding-bottom','10','','',''),(130968,'printshop-mobile','.testimonials .reviews-list .name','padding-bottom','5','','',''),(130969,'printshop-mobile','.b-bottom .confirm-popup .buttons','padding-bottom','30','','','.b-bottom'),(130970,'printshop-mobile','.b-bottom .confirm-popup .confirm-text','padding-bottom','30','','','.b-bottom'),(130971,'printshop-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','padding-bottom','10','','','.p-account-history'),(130972,'printshop-mobile','.p-account-history .orders-table th','padding-bottom','2','','','.p-account-history'),(130973,'printshop-mobile','.p-account-history .view_link','padding-bottom','0','','','.p-account-history'),(130974,'printshop-mobile','.p-account-history .orders-table .item','padding-bottom','60','720','','.p-account-history'),(130975,'printshop-mobile','.p-account-history .orders-table td','padding-bottom','5','720','','.p-account-history'),(130976,'printshop-mobile','.p-account-history .orders-table .td-alignright','padding-bottom','5','720','','.p-account-history'),(130977,'printshop-mobile','.p-account-index .orders-table td','padding-bottom','5','720','','.p-account-index'),(130978,'printshop-mobile','.p-account-index .orders-table .td-alignright','padding-bottom','5','720','','.p-account-index'),(130979,'printshop-mobile','.p-account-index .orders-table .item','padding-bottom','45','720','','.p-account-index'),(130980,'printshop-mobile','.btn-1','padding-bottom','4','','',''),(130981,'printshop-mobile','.btn','padding-bottom','8','','',''),(130982,'printshop-mobile','.btn-2','padding-bottom','12','','',''),(130983,'printshop-mobile','.p-blog-index .comment-list','padding-bottom','30','','','.p-blog-index'),(130984,'printshop-mobile','.p-blog-index .comments-area article','padding-bottom','10','','','.p-blog-index'),(130985,'printshop-mobile','.btn-3','padding-bottom','10','','',''),(130986,'printshop-mobile','.w-list-type-2_2 .buttons','padding-bottom','3','','','.w-list-type-2_2'),(130987,'printshop-mobile','.no-found','padding-bottom','20','','',''),(130988,'printshop-mobile','.w-list-type-2_2 .item','padding-bottom','20','','','.w-list-type-2_2'),(130989,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','padding-bottom','10','','','.w-list-type-2_2'),(130990,'printshop-mobile','.w-product-personal-catalog-button .btn','padding-bottom','0','','','.w-product-personal-catalog-button'),(130991,'printshop-mobile','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(130992,'printshop-mobile','.w-account ul, .w-account li','padding-bottom','0','','','.w-account'),(130993,'printshop-mobile','.b-fancybox .fancybox-error','padding-bottom','15','','','.b-fancybox'),(130994,'printshop-mobile','.w-menu-horizontal ul','padding-bottom','0','','','.w-menu-horizontal'),(130995,'printshop-mobile','.w-chat .w-chat-box','padding-bottom','2','','','.w-chat'),(130996,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-bottom','0','','','.w-delivery-location-top-location-list'),(130997,'printshop-mobile','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(130998,'printshop-mobile','.p-wedding-registry-index .middle-box','padding-bottom','30','','','.p-wedding-registry-index'),(130999,'printshop-mobile','.p-wedding-registry-index .main-content','padding-bottom','70','','','.p-wedding-registry-index'),(131000,'printshop-mobile','.p-wedding-registry-index .main-button','padding-bottom','0','4','','.p-wedding-registry-index'),(131001,'printshop-mobile','.p-wedding-registry-index .main-button','padding-bottom','40','','','.p-wedding-registry-index'),(131002,'printshop-mobile','.p-wedding-registry-index .main-button','padding-bottom','0','3','','.p-wedding-registry-index'),(131003,'printshop-mobile','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(131004,'printshop-mobile','.b-form .form-buttons','padding-bottom','50','','','.b-form'),(131005,'printshop-mobile','.p-wedding-registry-manage .links a','padding-bottom','0','','','.p-wedding-registry-manage'),(131006,'printshop-mobile','.b-bottom .alert-message','padding-bottom','20','','','.b-bottom'),(131007,'printshop-mobile','.p-wedding-registry-manage .links','padding-bottom','10','','','.p-wedding-registry-manage'),(131008,'printshop-mobile','.p-wedding-registry-share .middle-form > input','padding-bottom','0','','','.p-wedding-registry-share'),(131009,'printshop-mobile','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(131010,'printshop-mobile','.b-table .table td','padding-bottom','15','','','.b-table'),(131011,'printshop-mobile','.header2 .ccc','padding-bottom','10','','',''),(131012,'printshop-mobile','.p-account-address-book .btn-edit','padding-bottom','0','4','','.p-account-address-book'),(131013,'printshop-mobile','.p-account-address-book .topButtons','padding-bottom','15','','','.p-account-address-book'),(131014,'printshop-mobile','.p-account-address-book .rightMes ul','padding-bottom','0','','','.p-account-address-book'),(131015,'printshop-mobile','.p-account-address-book .address_book h1','padding-bottom','5','','','.p-account-address-book'),(131016,'printshop-mobile','.p-account-address-book .address_book, .p-account-address-book .account_history_info','padding-bottom','10','','','.p-account-address-book'),(131017,'printshop-mobile','.p-account-address-book .address_book','padding-bottom','30','','','.p-account-address-book'),(131018,'printshop-mobile','.p-account-address-book .address_book h2','padding-bottom','10','','','.p-account-address-book'),(131019,'printshop-mobile','.b-bottom .popup-heading','padding-bottom','12','','','.b-bottom'),(131020,'printshop-mobile','.b-compare .col-gender','padding-bottom','10','','','.b-compare'),(131021,'printshop-mobile','.b-compare .col-two label','padding-bottom','5','','','.b-compare'),(131022,'printshop-mobile','.b-compare .compare-head','padding-bottom','0','','','.b-compare'),(131023,'printshop-mobile','.b-compare .compare-box-item','padding-bottom','10','','','.b-compare'),(131024,'printshop-mobile','.b-compare .column_wrapper','padding-bottom','10','','','.b-compare'),(131025,'printshop-mobile','.w-quote .cart-box-link','padding-bottom','5','702','','.w-quote'),(131026,'printshop-mobile','.w-tabs .accordion-heading','padding-bottom','6','2','','.w-tabs'),(131027,'printshop-mobile','.w-languages .current','padding-bottom','13','702','','.w-languages'),(131028,'printshop-mobile','.w-currencies .select-link','padding-bottom','12','702','','.w-currencies'),(131029,'printshop-mobile','.w-tabs .accordion-heading','padding-bottom','8','','','.w-tabs'),(131030,'printshop-mobile','.w-languages .lang-link','padding-bottom','13','702','','.w-languages'),(131031,'printshop-mobile','.w-currencies .current','padding-bottom','14','702','','.w-currencies'),(131032,'printshop-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','12','702','','.w-menu-horizontal'),(131033,'printshop-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','12','706','','.w-menu-style-1'),(131034,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-bottom','8','706','','.w-list-type-1'),(131035,'printshop-mobile','.w-search .button-search','padding-bottom','6','','','.w-search'),(131036,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-bottom','12','706','','.w-menu-style-1'),(131037,'printshop-mobile','.b-bottom .footerTitle','padding-bottom','9','693','','.b-bottom'),(131038,'printshop-mobile','.p-account-history-info .history_info > div','padding-bottom','0','694','','.p-account-history-info'),(131039,'printshop-mobile','.p-account-history-info .history_info > div + div','padding-bottom','0','694','','.p-account-history-info'),(131040,'printshop-mobile','.w-cart .cart-total','padding-bottom','10','','','.w-cart'),(131041,'printshop-mobile','.w-cart .cart-content','padding-bottom','5','','','.w-cart'),(131042,'printshop-mobile','.w-cart .cart-box-link','padding-bottom','5','','','.w-cart'),(131043,'printshop-mobile','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(131044,'printshop-mobile','.w-product-reviews .reviews-list .name','padding-bottom','5','','','.w-product-reviews'),(131045,'printshop-mobile','.w-reviews .name','padding-bottom','5','','','.w-reviews'),(131046,'printshop-mobile','.w-tabs .tab-a','padding-bottom','6','2','','.w-tabs'),(131047,'printshop-mobile','.w-bestsellers .heading-3','padding-bottom','15','','','.w-bestsellers'),(131048,'printshop-mobile','.w-account a.my-acc-link','padding-bottom','5','','','.w-account'),(131049,'printshop-mobile','.w-list-type-1_3 .item','padding-bottom','20','1','','.w-list-type-1_3'),(131050,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-1_2'),(131051,'printshop-mobile','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(131052,'printshop-mobile','.w-tabs .tab-navigation','padding-bottom','0','','','.w-tabs'),(131053,'printshop-mobile','.p-account-trade-form .widget','padding-bottom','20','','','.p-account-trade-form'),(131054,'printshop-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-bottom','0','','','.p-blog-index'),(131055,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-bottom','5','','','.p-blog-index'),(131056,'printshop-mobile','.p-blog-index .nav-links','padding-bottom','20','','','.p-blog-index'),(131057,'printshop-mobile','.p-checkout-index .same-address','padding-bottom','15','','','.p-checkout-index'),(131058,'printshop-mobile','.p-blog-index .wp-widget li','padding-bottom','10','','','.p-blog-index'),(131059,'printshop-mobile','.p-blog-index .wp-widget ul','padding-bottom','0','','','.p-blog-index'),(131060,'printshop-mobile','.p-checkout-index .shipping-method .item','padding-bottom','10','','','.p-checkout-index'),(131061,'printshop-mobile','.p-checkout-index .shipping-method .title','padding-bottom','0','','','.p-checkout-index'),(131062,'printshop-mobile','.p-checkout-index .shipping-method .row','padding-bottom','5','','','.p-checkout-index'),(131063,'printshop-mobile','.p-quote-cart-index .cart-page .empty','padding-bottom','100','','','.p-quote-cart-index'),(131064,'printshop-mobile','.p-reviews-info .review-info-image','padding-bottom','20','','','.p-reviews-info'),(131065,'printshop-mobile','.p-reviews-info .review-info-content','padding-bottom','20','','','.p-reviews-info'),(131066,'printshop-mobile','.p-quote-cart-index .cart-popup .cart-page, .p-quote-cart-index .cart-popup .wishlist-page','padding-bottom','10','','','.p-quote-cart-index'),(131067,'printshop-mobile','.p-reviews-info .review-info-text','padding-bottom','10','','','.p-reviews-info'),(131068,'printshop-mobile','.p-reviews-info .reviews-info .buttons','padding-bottom','20','','','.p-reviews-info'),(131069,'printshop-mobile','.p-shopping-cart-index .cart-popup .cart-page, .p-shopping-cart-index .cart-popup .wishlist-page','padding-bottom','10','','','.p-shopping-cart-index'),(131070,'printshop-mobile','.p-shopping-cart-index .cart-page .empty','padding-bottom','100','','','.p-shopping-cart-index'),(131071,'printshop-mobile','.p-account-index .account_info li','padding-bottom','10','693','','.p-account-index'),(131072,'printshop-mobile','.p-account-index .topAccount > li > div','padding-bottom','0','693','','.p-account-index'),(131073,'printshop-mobile','.w-filters .filter-box-content','padding-bottom','20','','','.w-filters'),(131074,'printshop-mobile','.w-filters .filter-box-head','padding-bottom','5','','','.w-filters'),(131075,'printshop-mobile','.w-filters .filter-li-content','padding-bottom','15','','','.w-filters'),(131076,'printshop-mobile','.b-slick .slick-vertical button.slick-next','padding-bottom','0','3','','.b-slick'),(131077,'printshop-mobile','.b-slick .slick-vertical button.slick-prev','padding-bottom','0','3','','.b-slick'),(131078,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-bottom','2','','','.b-fancybox'),(131079,'printshop-mobile','.p-account-trade-form .trade-form-area','padding-bottom','20','','','.p-account-trade-form'),(131080,'printshop-mobile','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(131081,'printshop-mobile','.b-info .info ul','padding-bottom','0','','','.b-info'),(131082,'printshop-mobile','.w-product-configurator .pc_item','padding-bottom','10','','','.w-product-configurator'),(131083,'printshop-mobile','.p-account-index th','padding-bottom','10','','','.p-account-index'),(131084,'printshop-mobile','.p-account-index .view_link','padding-bottom','0','','','.p-account-index'),(131085,'printshop-mobile','.p-account-index .topAccount','padding-bottom','17','','','.p-account-index'),(131086,'printshop-mobile','.p-account-index .topAccount > li','padding-bottom','0','','','.p-account-index'),(131087,'printshop-mobile','.w-list-type-2 .item','padding-bottom','20','1','','.w-list-type-2'),(131088,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-1_3'),(131089,'printshop-mobile','.w-list-type-1_2 .compare-box-item','padding-bottom','7','','','.w-list-type-1_2'),(131090,'printshop-mobile','.w-list-type-1 .item','padding-bottom','20','','','.w-list-type-1'),(131091,'printshop-mobile','.w-list-type-1 .compare-box-item','padding-bottom','7','','','.w-list-type-1'),(131092,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-1'),(131093,'printshop-mobile','.w-list-type-1 ','padding-bottom','20','','','.w-list-type-1'),(131094,'printshop-mobile','.w-list-type-1_2.products-listing','padding-bottom','20','','','.w-list-type-1_2'),(131095,'printshop-mobile','.w-filters .head-filter-widget','padding-bottom','10','','','.w-filters'),(131096,'printshop-mobile','.w-languages .lang-link','padding-bottom','5','','','.w-languages'),(131097,'printshop-mobile','.w-languages .current','padding-bottom','3','','','.w-languages'),(131098,'printshop-mobile','.w-filters .ui-slider-range','padding-bottom','0','','','.w-filters'),(131099,'printshop-mobile','.w-filters .fsl_handle','padding-bottom','15','','','.w-filters'),(131100,'printshop-mobile','.b-fancybox .fancybox-title-over-wrap','padding-bottom','10','','','.b-fancybox'),(131101,'printshop-mobile','.w-currencies .currencies-title','padding-bottom','0','','','.w-currencies'),(131102,'printshop-mobile','.w-categories .image','padding-bottom','75','','','.w-categories'),(131103,'printshop-mobile','.w-cart a.item','padding-bottom','5','','','.w-cart'),(131104,'printshop-mobile','.w-breadcrumb .breadcrumb-li','padding-bottom','0','','','.w-breadcrumb'),(131105,'printshop-mobile','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(131106,'printshop-mobile','.b-compare .popupCompare .pop-up-content','padding-bottom','10','','','.b-compare'),(131107,'printshop-mobile','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(131108,'printshop-mobile','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(131109,'printshop-mobile','.w-reviews .heading-3','padding-bottom','10','','','.w-reviews'),(131110,'printshop-mobile','.w-product-sale-ends .left-count','padding-bottom','0','','','.w-product-sale-ends'),(131111,'printshop-mobile','.w-product-reviews .reviews-list .review','padding-bottom','10','','','.w-product-reviews'),(131112,'printshop-mobile','.w-quote .cart-box-link','padding-bottom','5','','','.w-quote'),(131113,'printshop-mobile','.w-reviews .review','padding-bottom','10','','','.w-reviews'),(131114,'printshop-mobile','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(131115,'printshop-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(131116,'printshop-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(131117,'printshop-mobile','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(131118,'printshop-mobile','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(131119,'printshop-mobile','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(131120,'printshop-mobile','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(131121,'printshop-mobile','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(131122,'printshop-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(131123,'printshop-mobile','.w-menu-style-1 ul','padding-bottom','0','','','.w-menu-style-1'),(131124,'printshop-mobile','.w-sale .left-text-right','padding-bottom','24','','','.w-sale'),(131125,'printshop-mobile','.w-sale .left-text-left','padding-bottom','24','','','.w-sale'),(131126,'printshop-mobile','.w-tabs .accordion-heading','padding-bottom','9','693','','.w-tabs'),(131127,'printshop-mobile','.w-top-categories .categories h2','padding-bottom','0','','','.w-top-categories'),(131128,'printshop-mobile','.w-categories .categories h2','padding-bottom','0','','','.w-categories'),(131129,'printshop-mobile','.w-banner .carousel-text > span','padding-bottom','20','','','.w-banner'),(131130,'printshop-mobile','.b-form .col-full-padding','padding-bottom','30','','','.b-form'),(131131,'printshop-mobile','.b-slick .slick-list','padding-bottom','0','','','.b-slick'),(131132,'printshop-mobile','.w-tabs .tab-li','padding-bottom','0','','','.w-tabs'),(131133,'printshop-mobile','.w-tabs .tab-a','padding-bottom','8','','','.w-tabs'),(131134,'printshop-mobile','.p-account-index .account_info .info','padding-bottom','25','','','.p-account-index'),(131135,'printshop-mobile','.w-categories .item','padding-bottom','30','693','','.w-categories'),(131136,'printshop-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-bottom','0','','','.b-fancybox'),(131137,'printshop-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-bottom','0','','','.b-fancybox'),(131138,'printshop-mobile','.w-cart-give-away .ga_column','padding-bottom','15','','','.w-cart-give-away'),(131139,'printshop-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-bottom','4','','','.b-compare'),(131140,'printshop-mobile','.w-product-images .images','padding-bottom','20','723','','.w-product-images'),(131141,'printshop-mobile','.p-account-index .topAccount > li','padding-bottom','10','693','','.p-account-index'),(131142,'printshop-mobile','.w-search .search form','padding-bottom','5','','','.w-search'),(131143,'printshop-mobile','.w-list-type-2 .buttons','padding-bottom','3','','','.w-list-type-2'),(131144,'printshop-mobile','.w-list-type-2 .button-wishlist button','padding-bottom','10','','','.w-list-type-2'),(131145,'printshop-mobile','.b-autocomplete .ui-autocomplete','padding-bottom','0','','','.b-autocomplete'),(131146,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','padding-bottom','5','','',''),(131147,'printshop-mobile','textarea','padding-bottom','5','','',''),(131148,'printshop-mobile','.w-list-type-1_3 .buttons','padding-bottom','3','','','.w-list-type-1_3'),(131149,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','padding-bottom','10','','','.w-list-type-1_3'),(131150,'printshop-mobile','.b-autocomplete .ui-autocomplete li','padding-bottom','3','','','.b-autocomplete'),(131151,'printshop-mobile','.w-list-type-1_2 .item','padding-bottom','20','','','.w-list-type-1_2'),(131152,'printshop-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-bottom','10','','','.b-bottom'),(131153,'printshop-mobile','.w-list-type-1_2 .buttons','padding-bottom','3','','','.w-list-type-1_2'),(131154,'printshop-mobile','.b-bottom .pop-up-close','padding-bottom','1','','','.b-bottom'),(131155,'printshop-mobile','.b-bottom .pop-up-info','padding-bottom','20','','','.b-bottom'),(131156,'printshop-mobile','.heading-4, h4','padding-bottom','3','','',''),(131157,'printshop-mobile','.w-list-type-1 .buttons','padding-bottom','3','','','.w-list-type-1'),(131158,'printshop-mobile','.w-list-type-1 .button-wishlist button','padding-bottom','10','','','.w-list-type-1'),(131159,'printshop-mobile','.b-bottom .popup-box-wrap','padding-bottom','10','','','.b-bottom'),(131160,'printshop-mobile','.b-form .center-buttons','padding-bottom','20','','','.b-form'),(131161,'printshop-mobile','.w-reviews .reviews-list .name','padding-bottom','5','','','.w-reviews'),(131162,'printshop-mobile','.w-top-categories .name','padding-bottom','3','','','.w-top-categories'),(131163,'printshop-mobile','.p-account-index .account_info','padding-bottom','0','706','','.p-account-index'),(131164,'printshop-mobile','.w-top-categories .image','padding-bottom','75','','','.w-top-categories'),(131165,'printshop-mobile','.w-tabs > .block','padding-bottom','20','','','.w-tabs'),(131166,'printshop-mobile','.w-top-categories .item','padding-bottom','30','','','.w-top-categories'),(131167,'printshop-mobile','.b-form .middle-form','padding-bottom','20','','','.b-form'),(131168,'printshop-mobile','.b-form .payment-method .item-radio label','padding-bottom','5','','','.b-form'),(131169,'printshop-mobile','.b-form .required-message','padding-bottom','0','','','.b-form'),(131170,'printshop-mobile','.b-form .shipping-method .input','padding-bottom','0','','','.b-form'),(131171,'printshop-mobile','.b-form .required-message-wrap','padding-bottom','0','','','.b-form'),(131172,'printshop-mobile','.b-info .info','padding-bottom','15','','','.b-info'),(131173,'printshop-mobile','.b-info .info li','padding-bottom','0','','','.b-info'),(131174,'printshop-mobile','.b-products-listing .in-cart','padding-bottom','4','','','.b-products-listing'),(131175,'printshop-mobile','.b-products-listing .products-listing .btn-buy','padding-bottom','4','','','.b-products-listing'),(131176,'printshop-mobile','.b-products-listing .products-listing .buyButton .btn','padding-bottom','4','','','.b-products-listing'),(131177,'printshop-mobile','.b-products-listing .products-listing .compare','padding-bottom','6','','','.b-products-listing'),(131178,'printshop-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-bottom','6','','','.b-products-listing'),(131179,'printshop-mobile','.b-products-listing .products-listing a.btn.view-button','padding-bottom','6','','','.b-products-listing'),(131180,'printshop-mobile','.b-products-listing .products-listing h2','padding-bottom','0','','','.b-products-listing'),(131181,'printshop-mobile','.b-products-listing .promos-info .promo-item','padding-bottom','3','','','.b-products-listing'),(131182,'printshop-mobile','.b-products-listing .promos-info .promo-name','padding-bottom','3','','','.b-products-listing'),(131183,'printshop-mobile','.b-products-listing .list-productlisting div.BlockBox.item-holder','padding-bottom','25','','','.b-products-listing'),(131184,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.b-data-table'),(131185,'printshop-mobile','.b-data-table table.dataTable thead td','padding-bottom','10','','','.b-data-table'),(131186,'printshop-mobile','.b-data-table table.dataTable tbody td','padding-bottom','10','','','.b-data-table'),(131187,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom','0','','','.b-data-table'),(131188,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(131189,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(131190,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(131191,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(131192,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(131193,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(131194,'printshop-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(131195,'printshop-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(131196,'printshop-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(131197,'printshop-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(131198,'printshop-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(131199,'printshop-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(131200,'printshop-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(131201,'printshop-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(131202,'printshop-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(131203,'printshop-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(131204,'printshop-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(131205,'printshop-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(131206,'printshop-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(131207,'printshop-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(131208,'printshop-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(131209,'printshop-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(131210,'printshop-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(131211,'printshop-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(131212,'printshop-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(131213,'printshop-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(131214,'printshop-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(131215,'printshop-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(131216,'printshop-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(131217,'printshop-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(131218,'printshop-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(131219,'printshop-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(131220,'printshop-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(131221,'printshop-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(131222,'printshop-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(131223,'printshop-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(131224,'printshop-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(131225,'printshop-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(131226,'printshop-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(131227,'printshop-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(131228,'printshop-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(131229,'printshop-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(131230,'printshop-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(131231,'printshop-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(131232,'printshop-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(131233,'printshop-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(131234,'printshop-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(131235,'printshop-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(131236,'printshop-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(131237,'printshop-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(131238,'printshop-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(131239,'printshop-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(131240,'printshop-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(131241,'printshop-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(131242,'printshop-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(131243,'printshop-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(131244,'printshop-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(131245,'printshop-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(131246,'printshop-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(131247,'printshop-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(131248,'printshop-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(131249,'printshop-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(131250,'printshop-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(131251,'printshop-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(131252,'printshop-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(131253,'printshop-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(131254,'printshop-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(131255,'printshop-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(131256,'printshop-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(131257,'printshop-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(131258,'printshop-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(131259,'printshop-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(131260,'printshop-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(131261,'printshop-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(131262,'printshop-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(131263,'printshop-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(131264,'printshop-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(131265,'printshop-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(131266,'printshop-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(131267,'printshop-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(131268,'printshop-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(131269,'printshop-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(131270,'printshop-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(131271,'printshop-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(131272,'printshop-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(131273,'printshop-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(131274,'printshop-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(131275,'printshop-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(131276,'printshop-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(131277,'printshop-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(131278,'printshop-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(131279,'printshop-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(131280,'printshop-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(131281,'printshop-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(131282,'printshop-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(131283,'printshop-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(131284,'printshop-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(131285,'printshop-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(131286,'printshop-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(131287,'printshop-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(131288,'printshop-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(131289,'printshop-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(131290,'printshop-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(131291,'printshop-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(131292,'printshop-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(131293,'printshop-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(131294,'printshop-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(131295,'printshop-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(131296,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-bottom','0','','','.b-h-inline'),(131297,'printshop-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-bottom','0','','','.b-menu-style'),(131298,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-bottom','5','','','.b-menu-style-1'),(131299,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-bottom','5','','','.b-menu-style-1'),(131300,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-bottom','20','','','.b-menu-style-1'),(131301,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-bottom','0','','','.b-menu-style-1'),(131302,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-bottom','5','','','.b-menu-style-2'),(131303,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-bottom','5','','','.b-menu-style-2'),(131304,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-bottom','0','','','.b-menu-style-2'),(131305,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-bottom','0','','','.b-menu-style-2'),(131306,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-bottom','10','','','.b-menu-style-2'),(131307,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-bottom','0','','','.b-menu-style-2'),(131308,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-bottom','5','','','.b-menu-style-2'),(131309,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-bottom','10','','','.b-menu-style-2'),(131310,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-bottom','5','','','.b-menu-style-2'),(131311,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-bottom','10','','','.b-menu-style-2'),(131312,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-bottom','5','','','.b-menu-style-3'),(131313,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','padding-bottom','5','','','.b-menu-style-3'),(131314,'printshop-mobile','.b-messages .msv_btn','padding-bottom','12','','','.b-messages'),(131315,'printshop-mobile','.b-messages .msv_content','padding-bottom','10','','','.b-messages'),(131316,'printshop-mobile','.b-messages .msv_history','padding-bottom','10','','','.b-messages'),(131317,'printshop-mobile','.b-messages .messMenuButton span','padding-bottom','10','','','.b-messages'),(131318,'printshop-mobile','.b-messages .messages-menu ul','padding-bottom','0','','','.b-messages'),(131319,'printshop-mobile','.b-messages .messages-menu li a','padding-bottom','8','','','.b-messages'),(131320,'printshop-mobile','.b-messages .messages-menu li','padding-bottom','0','','','.b-messages'),(131321,'printshop-mobile','.b-messages .content_management_attach button','padding-bottom','1','','','.b-messages'),(131322,'printshop-mobile','.b-messages .email-heading','padding-bottom','15','','','.b-messages'),(131323,'printshop-mobile','.b-messages .content_management_attach','padding-bottom','8','','','.b-messages'),(131324,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-bottom','5','','','.b-messages'),(131325,'printshop-mobile','.b-messages .emailBtn','padding-bottom','10','','','.b-messages'),(131326,'printshop-mobile','.b-messages .msv_to_cc','padding-bottom','10','','','.b-messages'),(131327,'printshop-mobile','.b-messages .dataTables_wrapper > .bottom','padding-bottom','4','','','.b-messages'),(131328,'printshop-mobile','.b-messages .emailLineTextArea textarea','padding-bottom','30','','','.b-messages'),(131329,'printshop-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-bottom','20','','','.b-personal-catalog-popup'),(131330,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','padding-bottom','0','','','.b-select-suggest'),(131331,'printshop-mobile','.b-select-suggest .select2-search input','padding-bottom','4','','','.b-select-suggest'),(131332,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(131333,'printshop-mobile','.b-select-suggest .select2-drop-mask','padding-bottom','0','','','.b-select-suggest'),(131334,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-bottom','0','','','.b-select-suggest'),(131335,'printshop-mobile','.b-select-suggest .select2-results','padding-bottom','0','','','.b-select-suggest'),(131336,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-bottom','0','','','.b-select-suggest'),(131337,'printshop-mobile','.b-select-suggest .select2-locked','padding-bottom','3','','','.b-select-suggest'),(131338,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-bottom','0','','','.b-select-suggest'),(131339,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-bottom','5','','','.b-select-suggest'),(131340,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(131341,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','padding-bottom','4','','','.b-select-suggest'),(131342,'printshop-mobile','.b-sub-totals .historyTotal td','padding-bottom','2','','','.b-sub-totals'),(131343,'printshop-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(131344,'printshop-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(131345,'printshop-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(131346,'printshop-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(131347,'printshop-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(131348,'printshop-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(131349,'printshop-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(131350,'printshop-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(131351,'printshop-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(131352,'printshop-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(131353,'printshop-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(131354,'printshop-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(131355,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(131356,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(131357,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(131358,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(131359,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(131360,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(131361,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(131362,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(131363,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(131364,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(131365,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(131366,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(131367,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(131368,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(131369,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(131370,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(131371,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(131372,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(131373,'printshop-mobile','.b-trade-approval .steps-bar li a','padding-bottom','7','','','.b-trade-approval'),(131374,'printshop-mobile','.b-trade-approval .middle-form','padding-bottom','20','','','.b-trade-approval'),(131375,'printshop-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-bottom','5','','','.b-trade-approval'),(131376,'printshop-mobile','.b-trade-approval .steps-bar','padding-bottom','0','','','.b-trade-approval'),(131377,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-bottom','6','','','.b-trade-approval'),(131378,'printshop-mobile','.b-trade-approval .center-buttons','padding-bottom','20','','','.b-trade-approval'),(131379,'printshop-mobile','.b-upload-file .upload-file-template','padding-bottom','25','','','.b-upload-file'),(131380,'printshop-mobile','.b-upload-files .added-file','padding-bottom','5','','','.b-upload-files'),(131381,'printshop-mobile','.b-upload-files .upload-files','padding-bottom','10','','','.b-upload-files'),(131382,'printshop-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-bottom','20','','','.b-warehouses-popup'),(131383,'printshop-mobile','.batchPr .w-batch-products .products-listing .image','padding-bottom','0','','','.batchPr'),(131384,'printshop-mobile','.batchPr .w-batch-products','padding-bottom','0','','','.batchPr'),(131385,'printshop-mobile','.batchPr > .block:nth-child(2)','padding-bottom','12','','','.batchPr'),(131386,'printshop-mobile','.batchPr .w-batch-selected-products','padding-bottom','15','','','.batchPr'),(131387,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-bottom','0','','','.batchPr'),(131388,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-bottom','10','','','.batchPr'),(131389,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-bottom','0','','','.batchPr'),(131390,'printshop-mobile','.batchPr ','padding-bottom','0','','','.batchPr'),(131391,'printshop-mobile','.batchPr .batch-selected-products-empty','padding-bottom','10','','','.batchPr'),(131392,'printshop-mobile','.batchPr .batch-selected-products-total','padding-bottom','10','','','.batchPr'),(131393,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-bottom','0','','','.batchPr'),(131394,'printshop-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-bottom','15','','','.batchPr'),(131395,'printshop-mobile','.batchPr .w-batch-products .products-listing .image','padding-bottom','10','','','.batchPr'),(131396,'printshop-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(131397,'printshop-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(131398,'printshop-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(131399,'printshop-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(131400,'printshop-mobile','.p-account-samples-history .view_link','padding-bottom','0','','','.p-account-samples-history'),(131401,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-bottom','10','','','.p-account-samples-history'),(131402,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-bottom','10','','','.p-account-samples-history'),(131403,'printshop-mobile','.p-account-samples-history .orders-table td','padding-bottom','5','','','.p-account-samples-history'),(131404,'printshop-mobile','.p-account-samples-history .orders-table th','padding-bottom','2','','','.p-account-samples-history'),(131405,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-bottom','5','','','.p-account-samples-history'),(131406,'printshop-mobile','.p-account-samples-history .orders-table td','padding-bottom','5','','','.p-account-samples-history'),(131407,'printshop-mobile','.p-account-samples-history .orders-table .item','padding-bottom','60','','','.p-account-samples-history'),(131408,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-bottom','5','','','.p-account-samples-history'),(131409,'printshop-mobile','.p-account-samples-history .orders-table td','padding-bottom','5','','','.p-account-samples-history'),(131410,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-bottom','10','','','.p-account-samples-history'),(131411,'printshop-mobile','.p-account-samples-history .view_link','padding-bottom','0','','','.p-account-samples-history'),(131412,'printshop-mobile','.p-account-samples-history .orders-table .item','padding-bottom','60','','','.p-account-samples-history'),(131413,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-bottom','10','','','.p-account-samples-history'),(131414,'printshop-mobile','.p-account-samples-history .view_link','padding-bottom','0','','','.p-account-samples-history'),(131415,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-bottom','10','','','.p-account-samples-history'),(131416,'printshop-mobile','.p-account-samples-history .orders-table th','padding-bottom','2','','','.p-account-samples-history'),(131417,'printshop-mobile','.p-account-samples-history .orders-table .item','padding-bottom','60','','','.p-account-samples-history'),(131418,'printshop-mobile','.p-account-samples-history .orders-table .item','padding-bottom','60','','','.p-account-samples-history'),(131419,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-bottom','5','','','.p-account-samples-history'),(131420,'printshop-mobile','.p-account-samples-history .view_link','padding-bottom','0','','','.p-account-samples-history'),(131421,'printshop-mobile','.p-account-samples-history .orders-table th','padding-bottom','2','','','.p-account-samples-history'),(131422,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-bottom','5','','','.p-account-samples-history'),(131423,'printshop-mobile','.p-account-samples-history .orders-table .item','padding-bottom','60','','','.p-account-samples-history'),(131424,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-bottom','10','','','.p-account-samples-history'),(131425,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-bottom','10','','','.p-account-samples-history'),(131426,'printshop-mobile','.p-account-samples-history .orders-table td','padding-bottom','5','','','.p-account-samples-history'),(131427,'printshop-mobile','.p-account-samples-history .orders-table th','padding-bottom','2','','','.p-account-samples-history'),(131428,'printshop-mobile','.p-account-samples-history .orders-table th','padding-bottom','2','','','.p-account-samples-history'),(131429,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-bottom','10','','','.p-account-samples-history'),(131430,'printshop-mobile','.p-account-samples-history .view_link','padding-bottom','0','','','.p-account-samples-history'),(131431,'printshop-mobile','.p-account-samples-history .orders-table td','padding-bottom','5','','','.p-account-samples-history'),(131432,'printshop-mobile','.p-account-samples-history .orders-table th','padding-bottom','2','','','.p-account-samples-history'),(131433,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-bottom','5','','','.p-account-samples-history'),(131434,'printshop-mobile','.p-account-samples-history .view_link','padding-bottom','0','','','.p-account-samples-history'),(131435,'printshop-mobile','.p-account-samples-history .orders-table .item','padding-bottom','60','','','.p-account-samples-history'),(131436,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-bottom','10','','','.p-account-samples-history'),(131437,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-bottom','10','','','.p-account-samples-history'),(131438,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-bottom','10','','','.p-account-samples-history'),(131439,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-bottom','10','','','.p-account-samples-history'),(131440,'printshop-mobile','.p-account-samples-history .orders-table td','padding-bottom','5','','','.p-account-samples-history'),(131441,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-bottom','5','','','.p-account-samples-history'),(131442,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-bottom','10','','','.p-account-samples-history-info'),(131443,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-samples-history-info'),(131444,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(131445,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(131446,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-samples-history-info'),(131447,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-bottom','10','','','.p-account-samples-history-info'),(131448,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(131449,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(131450,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-samples-history-info'),(131451,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-bottom','10','','','.p-account-samples-history-info'),(131452,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-bottom','10','','','.p-account-samples-history-info'),(131453,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-bottom','0','','','.p-account-samples-history-info'),(131454,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-bottom','10','','','.p-account-samples-history-info'),(131455,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-bottom','0','','','.p-account-samples-history-info'),(131456,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-bottom','5','','','.p-account-samples-history-info'),(131457,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-bottom','0','','','.p-account-samples-history-info'),(131458,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(131459,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-bottom','5','','','.p-account-samples-history-info'),(131460,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-bottom','5','','','.p-account-samples-history-info'),(131461,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-bottom','0','','','.p-account-samples-history-info'),(131462,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-samples-history-info'),(131463,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-bottom','0','','','.p-account-samples-history-info'),(131464,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(131465,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(131466,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(131467,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-bottom','10','','','.p-account-samples-history-info'),(131468,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-bottom','5','','','.p-account-samples-history-info'),(131469,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(131470,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-bottom','5','','','.p-account-samples-history-info'),(131471,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-bottom','5','','','.p-account-samples-history-info'),(131472,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(131473,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-bottom','0','','','.p-account-samples-history-info'),(131474,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-samples-history-info'),(131475,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-samples-history-info'),(131476,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(131477,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(131478,'printshop-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(131479,'printshop-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(131480,'printshop-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(131481,'printshop-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(131482,'printshop-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(131483,'printshop-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(131484,'printshop-mobile','.p-catalog-product .prev-product','padding-bottom','20','','','.p-catalog-product'),(131485,'printshop-mobile','.p-catalog-product .next-product','padding-bottom','20','','','.p-catalog-product'),(131486,'printshop-mobile','.p-catalog-product .pn-image','padding-bottom','20','','','.p-catalog-product'),(131487,'printshop-mobile','.p-catalog-product .pn-direction','padding-bottom','0','','','.p-catalog-product'),(131488,'printshop-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-bottom','8','','','.p-quick-order-index'),(131489,'printshop-mobile','.p-quick-order-index .bottom','padding-bottom','10','','','.p-quick-order-index'),(131490,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.p-quick-order-index'),(131491,'printshop-mobile','.p-quick-order-index ul.token-input-list','padding-bottom','0','','','.p-quick-order-index'),(131492,'printshop-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-bottom','7','','','.p-quick-order-index'),(131493,'printshop-mobile','.p-quick-order-index .all-scroll-div','padding-bottom','10','','','.p-quick-order-index'),(131494,'printshop-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(131495,'printshop-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(131496,'printshop-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(131497,'printshop-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(131498,'printshop-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(131499,'printshop-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(131500,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(131501,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(131502,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(131503,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(131504,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(131505,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(131506,'printshop-mobile','.w-account-address-book .item','padding-bottom','20','','','.w-account-address-book'),(131507,'printshop-mobile','.w-account-address-book .wrap','padding-bottom','15','','','.w-account-address-book'),(131508,'printshop-mobile','.w-account-address-book .btn-del','padding-bottom','0','','','.w-account-address-book'),(131509,'printshop-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-bottom','20','','','.w-account-addresses-list'),(131510,'printshop-mobile','.w-account-personal-catalog .list-switcher','padding-bottom','0','','','.w-account-personal-catalog'),(131511,'printshop-mobile','.w-account-personal-catalog .list-switcher a','padding-bottom','12','','','.w-account-personal-catalog'),(131512,'printshop-mobile','.w-account-subscription .subscription-variant','padding-bottom','10','','','.w-account-subscription'),(131513,'printshop-mobile','.w-blog-widget-categories-list ','padding-bottom','25','','','.w-blog-widget-categories-list'),(131514,'printshop-mobile','.w-blog-widget-most-popular-posts ','padding-bottom','20','','','.w-blog-widget-most-popular-posts'),(131515,'printshop-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-bottom','10','','','.w-blog-widget-most-popular-posts'),(131516,'printshop-mobile','.w-blog-widget-post-listing .post','padding-bottom','0','','','.w-blog-widget-post-listing'),(131517,'printshop-mobile','.w-blog-widget-post-listing .post_content','padding-bottom','20','','','.w-blog-widget-post-listing'),(131518,'printshop-mobile','.w-blog-widget-post-listing .post_date','padding-bottom','10','','','.w-blog-widget-post-listing'),(131519,'printshop-mobile','.w-blog-widget-post-listing .post_name','padding-bottom','10','','','.w-blog-widget-post-listing'),(131520,'printshop-mobile','.w-blog-widget-post-listing .post','padding-bottom','0','','','.w-blog-widget-post-listing'),(131521,'printshop-mobile','.w-blog-widget-post-title h1','padding-bottom','0','','','.w-blog-widget-post-title'),(131522,'printshop-mobile','.w-blog-widget-post-title ','padding-bottom','20','','','.w-blog-widget-post-title'),(131523,'printshop-mobile','.w-blog-widget-related-posts .post','padding-bottom','0','','','.w-blog-widget-related-posts'),(131524,'printshop-mobile','.w-blog-widget-related-posts .post_content a','padding-bottom','20','','','.w-blog-widget-related-posts'),(131525,'printshop-mobile','.w-blog-widget-related-posts ','padding-bottom','20','','','.w-blog-widget-related-posts'),(131526,'printshop-mobile','.w-blog-widget-related-posts-by-category .post','padding-bottom','0','','','.w-blog-widget-related-posts-by-category'),(131527,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-bottom','20','','','.w-blog-widget-related-posts-by-category'),(131528,'printshop-mobile','.w-blog-widget-tag-cloud ','padding-bottom','25','','','.w-blog-widget-tag-cloud'),(131529,'printshop-mobile','.w-blog-widget-tag-cloud a','padding-bottom','10','','','.w-blog-widget-tag-cloud'),(131530,'printshop-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-bottom','0','','','.w-cart-cart-tabs'),(131531,'printshop-mobile','.w-cart-compare .attributes-label','padding-bottom','10','','','.w-cart-compare'),(131532,'printshop-mobile','.w-cart-compare .cart-cell','padding-bottom','20','','','.w-cart-compare'),(131533,'printshop-mobile','.w-cart-compare .price-cell','padding-bottom','8','','','.w-cart-compare'),(131534,'printshop-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-bottom','5','','','.w-cart-compare'),(131535,'printshop-mobile','.w-cart-compare .price-label','padding-bottom','10','','','.w-cart-compare'),(131536,'printshop-mobile','.w-cart-compare .delete-cart','padding-bottom','10','','','.w-cart-compare'),(131537,'printshop-mobile','.w-cart-compare .attributes-cell','padding-bottom','8','','','.w-cart-compare'),(131538,'printshop-mobile','.w-cart-compare .product-actions','padding-bottom','0','','','.w-cart-compare'),(131539,'printshop-mobile','.w-cart-compare .product','padding-bottom','10','','','.w-cart-compare'),(131540,'printshop-mobile','.w-cart-compare .product-label','padding-bottom','15','','','.w-cart-compare'),(131541,'printshop-mobile','.w-cart-compare .dropdown li','padding-bottom','5','','','.w-cart-compare'),(131542,'printshop-mobile','.w-cart-up-sell .w-list-type-1','padding-bottom','0','','','.w-cart-up-sell'),(131543,'printshop-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','0','1','','.w-cart-up-sell'),(131544,'printshop-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','1','','','.w-cart-up-sell'),(131545,'printshop-mobile','.w-catalog-additional-images li','padding-bottom','10','','','.w-catalog-additional-images'),(131546,'printshop-mobile','.w-catalog-additional-images ul','padding-bottom','0','','','.w-catalog-additional-images'),(131547,'printshop-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-bottom','5','','','.w-catalog-b2b-add-button'),(131548,'printshop-mobile','.w-catalog-compare td','padding-bottom','10','','','.w-catalog-compare'),(131549,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-bottom','0','','','.w-catalog-compare'),(131550,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','padding-bottom','11','2','','.w-catalog-compare'),(131551,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','padding-bottom','10','','','.w-catalog-compare'),(131552,'printshop-mobile','.w-catalog-paging .paging-item','padding-bottom','0','','','.w-catalog-paging'),(131553,'printshop-mobile','.w-checkout-billing-address .same-address','padding-bottom','10','','','.w-checkout-billing-address'),(131554,'printshop-mobile','.w-checkout-billing-address .edit-ab','padding-bottom','0','','','.w-checkout-billing-address'),(131555,'printshop-mobile','.w-checkout-create-account .create-account','padding-bottom','10','','','.w-checkout-create-account'),(131556,'printshop-mobile','.w-checkout-gdpr .privacy-row','padding-bottom','0','','','.w-checkout-gdpr'),(131557,'printshop-mobile','.w-checkout-gdpr .terms-login','padding-bottom','0','','','.w-checkout-gdpr'),(131558,'printshop-mobile','.w-checkout-shipping .sub-item','padding-bottom','5','','','.w-checkout-shipping'),(131559,'printshop-mobile','.w-checkout-shipping-address .edit-ab','padding-bottom','0','','','.w-checkout-shipping-address'),(131560,'printshop-mobile','.w-checkout-shipping-choice #shippingchoice-choice','padding-bottom','7','','','.w-checkout-shipping-choice'),(131561,'printshop-mobile','.w-checkout-shipping-choice span','padding-bottom','4','','','.w-checkout-shipping-choice'),(131562,'printshop-mobile','.w-checkout-shipping-choice span','padding-bottom','4','','','.w-checkout-shipping-choice'),(131563,'printshop-mobile','.w-checkout-terms .required-message','padding-bottom','5','','','.w-checkout-terms'),(131564,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-bottom','5','','','.w-communication-new-topic'),(131565,'printshop-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-bottom','0','','','.w-communication-new-topic'),(131566,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-bottom','5','','','.w-communication-new-topic'),(131567,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-bottom','0','','','.w-communication-new-topic'),(131568,'printshop-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-bottom','10','','','.w-communication-new-topic'),(131569,'printshop-mobile','.w-communication-post .communication-post','padding-bottom','5','','','.w-communication-post'),(131570,'printshop-mobile','.w-communication-post .communication-post-author','padding-bottom','10','','','.w-communication-post'),(131571,'printshop-mobile','.w-delivery-day .left-count','padding-bottom','0','','','.w-delivery-day'),(131572,'printshop-mobile','.w-delivery-day .left-text-left','padding-bottom','24','','','.w-delivery-day'),(131573,'printshop-mobile','.w-delivery-day .left-text-right','padding-bottom','24','','','.w-delivery-day'),(131574,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-bottom','10','','','.w-image-maps'),(131575,'printshop-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-bottom','3','','','.w-multi-cart-actions'),(131576,'printshop-mobile','.w-personal-gift-status-bar .inform','padding-bottom','0','4','','.w-personal-gift-status-bar'),(131577,'printshop-mobile','.w-personal-gift-status-bar .end-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(131578,'printshop-mobile','.w-personal-gift-status-bar .end-date','padding-bottom','0','3','','.w-personal-gift-status-bar'),(131579,'printshop-mobile','.w-personal-gift-status-bar .start-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(131580,'printshop-mobile','.w-personal-gift-status-bar .timeline','padding-bottom','16','','','.w-personal-gift-status-bar'),(131581,'printshop-mobile','.w-product-available-in-warehouses .warehouse-item','padding-bottom','20','','','.w-product-available-in-warehouses'),(131582,'printshop-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(131583,'printshop-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(131584,'printshop-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(131585,'printshop-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(131586,'printshop-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(131587,'printshop-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(131588,'printshop-mobile','.w-product-customers-activity .customers-activity','padding-bottom','20','','','.w-product-customers-activity'),(131589,'printshop-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(131590,'printshop-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(131591,'printshop-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(131592,'printshop-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(131593,'printshop-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(131594,'printshop-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(131595,'printshop-mobile','.w-promotions .nextdiscount .promo-for-each','padding-bottom','2','','','.w-promotions'),(131596,'printshop-mobile','.w-promotions .nextdiscount .content > div','padding-bottom','10','','','.w-promotions'),(131597,'printshop-mobile','.w-promotions .promo-cart-discount .master .item','padding-bottom','20','','','.w-promotions'),(131598,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-bottom','0','','','.w-promotions'),(131599,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-bottom','0','','','.w-promotions'),(131600,'printshop-mobile','.w-promotions .promo-cart-discount .slave .item','padding-bottom','20','','','.w-promotions'),(131601,'printshop-mobile','.w-promotions .promo-cart-discount .slave .heading','padding-bottom','1','','','.w-promotions'),(131602,'printshop-mobile','.w-promotions .promo-salemaker .discount','padding-bottom','0','','','.w-promotions'),(131603,'printshop-mobile','.w-promotions .promo-item','padding-bottom','20','','','.w-promotions'),(131604,'printshop-mobile','.w-promotions .promo-salemaker .item','padding-bottom','20','','','.w-promotions'),(131605,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','padding-bottom','0','','','.w-promotions'),(131606,'printshop-mobile','.w-promotions .prom-multi-discount .promo-product','padding-bottom','20','','','.w-promotions'),(131607,'printshop-mobile','.w-quote-products .empty','padding-bottom','100','','','.w-quote-products'),(131608,'printshop-mobile','.w-reviews-content .review','padding-bottom','10','','','.w-reviews-content'),(131609,'printshop-mobile','.w-reviews-content .product-name','padding-bottom','20','','','.w-reviews-content'),(131610,'printshop-mobile','.w-reviews-content .item','padding-bottom','25','','','.w-reviews-content'),(131611,'printshop-mobile','.w-reviews-content .author','padding-bottom','20','','','.w-reviews-content'),(131612,'printshop-mobile','.w-reviews-content .rating','padding-bottom','10','','','.w-reviews-content'),(131613,'printshop-mobile','.w-sitemap-delivery-location > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(131614,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(131615,'printshop-mobile','.w-top-text .top-text','padding-bottom','5','','','.w-top-text'),(131616,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-bottom','17','','','.w-wedding-registry-widgets-photos'),(131617,'printshop-mobile','.b-quantity .qty-box input[type=\'text\']','padding-bottom','5','','','.b-quantity'),(131618,'printshop-mobile','.p-blog-index .comment-list','padding-bottom_important','important','','','.p-blog-index'),(131619,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom_important','important','','','.b-data-table'),(131620,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom_important','important','','','.b-data-table'),(131621,'printshop-mobile','.b-data-table table.dataTable thead td','padding-bottom_important','important','','','.b-data-table'),(131622,'printshop-mobile','.b-data-table table.dataTable tbody td','padding-bottom_important','important','','','.b-data-table'),(131623,'printshop-mobile','.batchPr .w-batch-products','padding-bottom_important','important','','','.batchPr'),(131624,'printshop-mobile','.w-list-type-1_3 .item','padding-left','0','','','.w-list-type-1_3'),(131625,'printshop-mobile','.w-list-type-1_3 .compare-box-item','padding-left','7','','','.w-list-type-1_3'),(131626,'printshop-mobile','.w-list-type-1_3 .item','padding-left','0','1','','.w-list-type-1_3'),(131627,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','padding-left','15','','','.w-list-type-2'),(131628,'printshop-mobile','.w-list-type-1_2.products-listing','padding-left','20','','','.w-list-type-1_2'),(131629,'printshop-mobile','.w-list-type-2 .compare-box-item','padding-left','7','','','.w-list-type-2'),(131630,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','padding-left','15','','','.w-list-type-1_3'),(131631,'printshop-mobile','.w-list-type-2_2.products-listing','padding-left','20','','','.w-list-type-2_2'),(131632,'printshop-mobile','.w-list-type-2 .item','padding-left','21','','','.w-list-type-2'),(131633,'printshop-mobile','.w-list-type-2.products-listing','padding-left','20','','','.w-list-type-2'),(131634,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','padding-left','15','','','.w-list-type-2_2'),(131635,'printshop-mobile','.w-list-type-2 .item','padding-left','20','1','','.w-list-type-2'),(131636,'printshop-mobile','.w-list-type-2_2 .compare-box-item','padding-left','7','','','.w-list-type-2_2'),(131637,'printshop-mobile','.w-list-type-3.products-listing','padding-left','20','','','.w-list-type-3'),(131638,'printshop-mobile','.w-menu .hided.menu ul li','padding-left','0','','','.w-menu'),(131639,'printshop-mobile','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(131640,'printshop-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-left','0','','','.w-menu'),(131641,'printshop-mobile','.w-menu-slider > ul > li > a','padding-left','10','','','.w-menu-slider'),(131642,'printshop-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','','','.w-menu-horizontal'),(131643,'printshop-mobile','.w-menu-big ul','padding-left','0','','','.w-menu-big'),(131644,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li','padding-left','10','','','.w-menu-horizontal'),(131645,'printshop-mobile','.w-menu-slider > ul > li > ul > li','padding-left','10','','','.w-menu-slider'),(131646,'printshop-mobile','.w-menu-slider ul, .w-menu-slider li','padding-left','0','','','.w-menu-slider'),(131647,'printshop-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','','','.w-menu-style-1'),(131648,'printshop-mobile','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(131649,'printshop-mobile','.w-top-categories .item','padding-left','10','693','','.w-top-categories'),(131650,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(131651,'printshop-mobile','.b-bottom .popup-simple','padding-left','20','','','.b-bottom'),(131652,'printshop-mobile','.b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .buttons','padding-left','10','','','.b-cookie-notice'),(131653,'printshop-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.bottom .text','padding-left','10','','','.b-cookie-notice'),(131654,'printshop-mobile','.w-login-block .new','padding-left','40','','','.w-login-block'),(131655,'printshop-mobile','.w-login-block .guest','padding-left','40','','','.w-login-block'),(131656,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-left','20','','','.w-menu-style-1'),(131657,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','','','.w-menu-style-1'),(131658,'printshop-mobile','.w-sale .holder-2','padding-left','20','','','.w-sale'),(131659,'printshop-mobile','.w-product-wedding-registry-button .btn','padding-left','40','','','.w-product-wedding-registry-button'),(131660,'printshop-mobile','.w-reviews .review','padding-left','10','','','.w-reviews'),(131661,'printshop-mobile','.w-sale .left-count','padding-left','5','','','.w-sale'),(131662,'printshop-mobile','.w-filters .head-filter-widget','padding-left','0','','','.w-filters'),(131663,'printshop-mobile','.w-currencies .select-link','padding-left','10','','','.w-currencies'),(131664,'printshop-mobile','.w-filters .filter-ul-content','padding-left','0','','','.w-filters'),(131665,'printshop-mobile','.w-categories .name','padding-left','3','','','.w-categories'),(131666,'printshop-mobile','.w-currencies .current','padding-left','10','','','.w-currencies'),(131667,'printshop-mobile','.w-categories .image','padding-left','0','','','.w-categories'),(131668,'printshop-mobile','.w-currencies .currencies-title','padding-left','4','','','.w-currencies'),(131669,'printshop-mobile','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(131670,'printshop-mobile','.w-cart .no-text','padding-left','10','','','.w-cart'),(131671,'printshop-mobile','.w-cart .qty','padding-left','5','4','','.w-cart'),(131672,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','padding-left','40','','','.p-account-history-info'),(131673,'printshop-mobile','.p-account-history-info .historyTotal td','padding-left','5','','','.p-account-history-info'),(131674,'printshop-mobile','.p-account-history-info .contentColumn','padding-left','40','','','.p-account-history-info'),(131675,'printshop-mobile','.p-account-history-info .history_info > div + div','padding-left','2','','','.p-account-history-info'),(131676,'printshop-mobile','.p-account-index .account_page','padding-left','0','','','.p-account-index'),(131677,'printshop-mobile','.p-account-index .account_block','padding-left','40','','','.p-account-index'),(131678,'printshop-mobile','.p-account-index .badc_bottom','padding-left','0','','','.p-account-index'),(131679,'printshop-mobile','.p-account-index .account_info li','padding-left','0','','','.p-account-index'),(131680,'printshop-mobile','.p-account-index .account_info','padding-left','0','','','.p-account-index'),(131681,'printshop-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','padding-left','10','','','.p-account-index'),(131682,'printshop-mobile','.p-account-index .date_title','padding-left','0','','','.p-account-index'),(131683,'printshop-mobile','.p-account-index .orders-table th','padding-left','10','','','.p-account-index'),(131684,'printshop-mobile','.b-bottom .popup-buttons','padding-left','15','','','.b-bottom'),(131685,'printshop-mobile','.w-cart-checkout-btn a','padding-left','12','693','','.w-cart-checkout-btn'),(131686,'printshop-mobile','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(131687,'printshop-mobile','.w-quote .no-text','padding-left','10','','','.w-quote'),(131688,'printshop-mobile','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(131689,'printshop-mobile','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(131690,'printshop-mobile','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(131691,'printshop-mobile','.w-product-images .img-holder','padding-left','20','','','.w-product-images'),(131692,'printshop-mobile','.b-compare .compare_pagination','padding-left','0','','','.b-compare'),(131693,'printshop-mobile','.p-blog-index .comments-area ol ol','padding-left','20','718','','.p-blog-index'),(131694,'printshop-mobile','.header2 .ccc','padding-left','10','','',''),(131695,'printshop-mobile','.w-promo-code .holder','padding-left','20','723','','.w-promo-code'),(131696,'printshop-mobile','.w-sale .holder-1','padding-left','20','','','.w-sale'),(131697,'printshop-mobile','.w-search .item','padding-left','0','','','.w-search'),(131698,'printshop-mobile','.w-search .suggest','padding-left','20','','','.w-search'),(131699,'printshop-mobile','.w-search .search-input','padding-left','10','','','.w-search'),(131700,'printshop-mobile','.w-search .items-title','padding-left','0','','','.w-search'),(131701,'printshop-mobile','.w-socials > li','padding-left','15','','','.w-socials'),(131702,'printshop-mobile','.b-info-popup .info-popup div','padding-left','15','','','.b-info-popup'),(131703,'printshop-mobile','.w-menu .hided.menu li li a','padding-left','40','720','','.w-menu'),(131704,'printshop-mobile','.w-menu .hided.menu li li li a','padding-left','60','720','','.w-menu'),(131705,'printshop-mobile','.w-menu .hided.menu li a','padding-left','20','720','','.w-menu'),(131706,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-left','0','','','.b-multi-page-checkout'),(131707,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-left','10','','','.b-multi-page-checkout'),(131708,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-left','10','','','.b-multi-page-checkout'),(131709,'printshop-mobile','.w-search .name','padding-left','50','','','.w-search'),(131710,'printshop-mobile','.w-promo-code .heading-4','padding-left','30','723','','.w-promo-code'),(131711,'printshop-mobile','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(131712,'printshop-mobile','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(131713,'printshop-mobile','.p-wedding-registry-manage a.remove-btn','padding-left','5','','','.p-wedding-registry-manage'),(131714,'printshop-mobile','.p-account-history-info .popup-tracking-number','padding-left','10','','','.p-account-history-info'),(131715,'printshop-mobile','.p-account-order-pay .contentColumn','padding-left','40','','','.p-account-order-pay'),(131716,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','padding-left','40','','','.p-account-order-pay'),(131717,'printshop-mobile','.p-account-order-pay .historyTotal td','padding-left','5','','','.p-account-order-pay'),(131718,'printshop-mobile','.p-account-order-pay .history_info > div + div','padding-left','2','','','.p-account-order-pay'),(131719,'printshop-mobile','.p-account-order-pay .history_info > div','padding-left','0','694','','.p-account-order-pay'),(131720,'printshop-mobile','.testimonials .answer','padding-left','30','','',''),(131721,'printshop-mobile','.w-product-configurator .pc_item','padding-left','0','702','','.w-product-configurator'),(131722,'printshop-mobile','.p-account-order-pay .history_info > div + div','padding-left','0','694','','.p-account-order-pay'),(131723,'printshop-mobile','.w-product-configurator .pc_attr','padding-left','0','693','','.w-product-configurator'),(131724,'printshop-mobile','.w-filters .head-filter-widget','padding-left','10','720','','.w-filters'),(131725,'printshop-mobile','.testimonials .heading-3','padding-left','55','','',''),(131726,'printshop-mobile','.b-pagination .pagination span','padding-left','5','2','','.b-pagination'),(131727,'printshop-mobile','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(131728,'printshop-mobile','.testimonials .review','padding-left','10','','',''),(131729,'printshop-mobile','.b-pagination .pagination .page-number','padding-left','5','','','.b-pagination'),(131730,'printshop-mobile','.b-pagination .pagination .prev-pages','padding-left','5','','','.b-pagination'),(131731,'printshop-mobile','.b-pagination .pagination .prev','padding-left','5','','','.b-pagination'),(131732,'printshop-mobile','.b-bottom .confirm-popup .confirm-text','padding-left','0','','','.b-bottom'),(131733,'printshop-mobile','.b-pagination .pagination .next-pages','padding-left','5','','','.b-pagination'),(131734,'printshop-mobile','.b-pagination .pagination .next','padding-left','5','','','.b-pagination'),(131735,'printshop-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','padding-left','10','','','.p-account-history'),(131736,'printshop-mobile','.p-account-history .orders-table th','padding-left','10','','','.p-account-history'),(131737,'printshop-mobile','.p-account-history .view_link','padding-left','0','','','.p-account-history'),(131738,'printshop-mobile','.p-account-history .orders-table .td-alignright','padding-left','10','720','','.p-account-history'),(131739,'printshop-mobile','.btn-2','padding-left','25','','',''),(131740,'printshop-mobile','.p-account-history .orders-table td','padding-left','10','720','','.p-account-history'),(131741,'printshop-mobile','.p-account-index .orders-table td','padding-left','10','720','','.p-account-index'),(131742,'printshop-mobile','.p-blog-index .nav-previous','padding-left','50','','','.p-blog-index'),(131743,'printshop-mobile','.p-account-index .orders-table .td-alignright','padding-left','10','720','','.p-account-index'),(131744,'printshop-mobile','.btn','padding-left','12','','',''),(131745,'printshop-mobile','.btn-1','padding-left','25','','',''),(131746,'printshop-mobile','.p-blog-index .comments-area ol ol','padding-left','50','','','.p-blog-index'),(131747,'printshop-mobile','.btn-3','padding-left','25','','',''),(131748,'printshop-mobile','.w-product-personal-catalog-button .btn','padding-left','25','','','.w-product-personal-catalog-button'),(131749,'printshop-mobile','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(131750,'printshop-mobile','.w-account ul, .w-account li','padding-left','0','','','.w-account'),(131751,'printshop-mobile','.b-fancybox .fancybox-error','padding-left','15','','','.b-fancybox'),(131752,'printshop-mobile','.w-menu-horizontal ul','padding-left','0','','','.w-menu-horizontal'),(131753,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(131754,'printshop-mobile','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(131755,'printshop-mobile','.w-chat .w-chat-box','padding-left','12','','','.w-chat'),(131756,'printshop-mobile','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(131757,'printshop-mobile','.p-wedding-registry-index .main-button','padding-left','20','4','','.p-wedding-registry-index'),(131758,'printshop-mobile','.p-wedding-registry-index .main-content','padding-left','0','','','.p-wedding-registry-index'),(131759,'printshop-mobile','.p-wedding-registry-index .middle-box','padding-left','10','','','.p-wedding-registry-index'),(131760,'printshop-mobile','.p-wedding-registry-index .main-button','padding-left','20','3','','.p-wedding-registry-index'),(131761,'printshop-mobile','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(131762,'printshop-mobile','.b-form .form-buttons','padding-left','0','','','.b-form'),(131763,'printshop-mobile','.b-bottom .alert-message','padding-left','20','','','.b-bottom'),(131764,'printshop-mobile','.p-wedding-registry-manage .links','padding-left','10','','','.p-wedding-registry-manage'),(131765,'printshop-mobile','.p-wedding-registry-share .middle-form > input','padding-left','0','','','.p-wedding-registry-share'),(131766,'printshop-mobile','.p-wedding-registry-manage .links a','padding-left','10','','','.p-wedding-registry-manage'),(131767,'printshop-mobile','.p-wedding-registry-manage .links a.share-registry','padding-left','40','','','.p-wedding-registry-manage'),(131768,'printshop-mobile','.b-table .table td','padding-left','15','','','.b-table'),(131769,'printshop-mobile','.b-table .table .headings td','padding-left','10','','','.b-table'),(131770,'printshop-mobile','.b-pagination .pagination a','padding-left','5','','','.b-pagination'),(131771,'printshop-mobile','.p-account-history .order_history_table th','padding-left','10','','','.p-account-history'),(131772,'printshop-mobile','.p-account-address-book .topButtons','padding-left','0','','','.p-account-address-book'),(131773,'printshop-mobile','.p-account-address-book .buttonBox','padding-left','0','','','.p-account-address-book'),(131774,'printshop-mobile','.p-account-address-book .btn-edit','padding-left','10','4','','.p-account-address-book'),(131775,'printshop-mobile','.p-account-address-book .rightMes ul','padding-left','19','','','.p-account-address-book'),(131776,'printshop-mobile','.p-account-address-book .address_book h2','padding-left','10','','','.p-account-address-book'),(131777,'printshop-mobile','.p-account-address-book .address_book, .p-account-address-book .account_history_info','padding-left','0','','','.p-account-address-book'),(131778,'printshop-mobile','.p-account-address-book .address_book h1','padding-left','0','','','.p-account-address-book'),(131779,'printshop-mobile','.p-account-address-book .address_book','padding-left','0','','','.p-account-address-book'),(131780,'printshop-mobile','.b-compare .col-gender','padding-left','0','','','.b-compare'),(131781,'printshop-mobile','.b-bottom .popup-heading','padding-left','15','','','.b-bottom'),(131782,'printshop-mobile','.b-bottom .popup-content','padding-left','15','','','.b-bottom'),(131783,'printshop-mobile','.b-compare .col-two label','padding-left','0','','','.b-compare'),(131784,'printshop-mobile','.b-compare .compare-head','padding-left','10','','','.b-compare'),(131785,'printshop-mobile','.b-compare .compare-box-item','padding-left','10','','','.b-compare'),(131786,'printshop-mobile','.b-compare .column_wrapper','padding-left','10','','','.b-compare'),(131787,'printshop-mobile','.w-languages .current','padding-left','10','702','','.w-languages'),(131788,'printshop-mobile','.w-quote .cart-box-link','padding-left','14','702','','.w-quote'),(131789,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','padding-left','5','','','.b-switch'),(131790,'printshop-mobile','.w-languages .lang-link','padding-left','10','702','','.w-languages'),(131791,'printshop-mobile','.w-tabs .accordion-heading','padding-left','6','','','.w-tabs'),(131792,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-left','0','','','.b-slick'),(131793,'printshop-mobile','.w-search .button-search','padding-left','0','','','.w-search'),(131794,'printshop-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','706','','.w-menu-style-1'),(131795,'printshop-mobile','.w-currencies .select-link','padding-left','10','702','','.w-currencies'),(131796,'printshop-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','702','','.w-menu-horizontal'),(131797,'printshop-mobile','.w-currencies .current','padding-left','10','702','','.w-currencies'),(131798,'printshop-mobile','.b-slick button.slick-next','padding-left','4','3','','.b-slick'),(131799,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-left','18','706','','.w-list-type-1'),(131800,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','706','','.w-menu-style-1'),(131801,'printshop-mobile','.b-bottom .footerTitle','padding-left','0','693','','.b-bottom'),(131802,'printshop-mobile','.p-account-history-info .history_info > div + div','padding-left','0','694','','.p-account-history-info'),(131803,'printshop-mobile','.p-account-history-info .history_info > div','padding-left','0','694','','.p-account-history-info'),(131804,'printshop-mobile','.p-account-index .account_info','padding-left','0','706','','.p-account-index'),(131805,'printshop-mobile','.w-top-categories .name','padding-left','3','','','.w-top-categories'),(131806,'printshop-mobile','.w-cart .cart-total','padding-left','0','','','.w-cart'),(131807,'printshop-mobile','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(131808,'printshop-mobile','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(131809,'printshop-mobile','.w-breadcrumb .breadcrumb-li','padding-left','0','','','.w-breadcrumb'),(131810,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','padding-left','15','','','.w-list-type-1_2'),(131811,'printshop-mobile','.w-bestsellers .heading-3','padding-left','55','','','.w-bestsellers'),(131812,'printshop-mobile','.w-account a.my-acc-link','padding-left','17','','','.w-account'),(131813,'printshop-mobile','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(131814,'printshop-mobile','.w-tabs .tab-navigation','padding-left','0','','','.w-tabs'),(131815,'printshop-mobile','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block','padding-left','10','695','',''),(131816,'printshop-mobile','.w-top-categories .image','padding-left','0','','','.w-top-categories'),(131817,'printshop-mobile','.p-account-trade-form .trade-form-area','padding-left','20','','','.p-account-trade-form'),(131818,'printshop-mobile','.p-account-trade-form .widget','padding-left','0','','','.p-account-trade-form'),(131819,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-left','10','','','.p-blog-index'),(131820,'printshop-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-left','0','','','.p-blog-index'),(131821,'printshop-mobile','.p-blog-index .wp-widget li','padding-left','15','','','.p-blog-index'),(131822,'printshop-mobile','.p-checkout-index .shipping-method .item','padding-left','0','','','.p-checkout-index'),(131823,'printshop-mobile','.p-blog-index .nav-links','padding-left','0','','','.p-blog-index'),(131824,'printshop-mobile','.p-checkout-index .shipping-method .title','padding-left','5','','','.p-checkout-index'),(131825,'printshop-mobile','.p-quote-cart-index .cart-popup .cart-page, .p-quote-cart-index .cart-popup .wishlist-page','padding-left','20','','','.p-quote-cart-index'),(131826,'printshop-mobile','.p-blog-index .wp-widget ul','padding-left','0','','','.p-blog-index'),(131827,'printshop-mobile','.p-checkout-index .shipping-method .row','padding-left','5','','','.p-checkout-index'),(131828,'printshop-mobile','.p-reviews-info .review-info-image','padding-left','20','','','.p-reviews-info'),(131829,'printshop-mobile','.p-reviews-info .review-info-content','padding-left','20','','','.p-reviews-info'),(131830,'printshop-mobile','.p-reviews-info .review-info-text','padding-left','10','','','.p-reviews-info'),(131831,'printshop-mobile','.p-reviews-info .reviews-info .buttons','padding-left','0','','','.p-reviews-info'),(131832,'printshop-mobile','.p-shopping-cart-index .cart-popup .cart-page, .p-shopping-cart-index .cart-popup .wishlist-page','padding-left','20','','','.p-shopping-cart-index'),(131833,'printshop-mobile','.p-account-index .account_info li','padding-left','0','693','','.p-account-index'),(131834,'printshop-mobile','.p-account-index .topAccount > li','padding-left','0','693','','.p-account-index'),(131835,'printshop-mobile','.p-account-index .topAccount > li > div','padding-left','55','693','','.p-account-index'),(131836,'printshop-mobile','.w-product-images .images','padding-left','0','723','','.w-product-images'),(131837,'printshop-mobile','.b-bottom .popup-box-wrap','padding-left','10','','','.b-bottom'),(131838,'printshop-mobile','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(131839,'printshop-mobile','.b-slick .slick-vertical button.slick-prev','padding-left','0','3','','.b-slick'),(131840,'printshop-mobile','.b-slick .slick-vertical button.slick-next','padding-left','0','3','','.b-slick'),(131841,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-left','20','','','.b-fancybox'),(131842,'printshop-mobile','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(131843,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-left','10','','','.p-account-subscription-historyinfo'),(131844,'printshop-mobile','.w-product-configurator .pc_item','padding-left','0','','','.w-product-configurator'),(131845,'printshop-mobile','.p-account-index .view_link','padding-left','0','','','.p-account-index'),(131846,'printshop-mobile','.p-account-index th','padding-left','15','','','.p-account-index'),(131847,'printshop-mobile','.p-account-index .topAccount > li','padding-left','2','','','.p-account-index'),(131848,'printshop-mobile','.w-list-type-1 .item','padding-left','5','','','.w-list-type-1'),(131849,'printshop-mobile','.w-list-type-1 .compare-box-item','padding-left','7','','','.w-list-type-1'),(131850,'printshop-mobile','.w-list-type-1_2 .compare-box-item','padding-left','7','','','.w-list-type-1_2'),(131851,'printshop-mobile','.w-languages .lang-link','padding-left','10','','','.w-languages'),(131852,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-left','15','','','.w-list-type-1'),(131853,'printshop-mobile','.w-filters .fsl_handle','padding-left','0','','','.w-filters'),(131854,'printshop-mobile','.w-filters .ui-slider-range','padding-left','0','','','.w-filters'),(131855,'printshop-mobile','.w-languages .current','padding-left','10','','','.w-languages'),(131856,'printshop-mobile','.b-fancybox .fancybox-title-over-wrap','padding-left','10','','','.b-fancybox'),(131857,'printshop-mobile','.b-fancybox .fancybox-next span','padding-left','4','3','','.b-fancybox'),(131858,'printshop-mobile','.w-categories .item','padding-left','20','','','.w-categories'),(131859,'printshop-mobile','.w-cart a.item','padding-left','90','','','.w-cart'),(131860,'printshop-mobile','.w-cart .cart-content','padding-left','15','','','.w-cart'),(131861,'printshop-mobile','.w-cart .cart-box-link','padding-left','14','','','.w-cart'),(131862,'printshop-mobile','.b-compare .popupCompare .pop-up-content','padding-left','10','','','.b-compare'),(131863,'printshop-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(131864,'printshop-mobile','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(131865,'printshop-mobile','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(131866,'printshop-mobile','.w-quote .cart-box-link','padding-left','10','','','.w-quote'),(131867,'printshop-mobile','.w-product-reviews .reviews-list .review','padding-left','10','','','.w-product-reviews'),(131868,'printshop-mobile','.w-product-sale-ends .left-count','padding-left','5','','','.w-product-sale-ends'),(131869,'printshop-mobile','.w-reviews .heading-3','padding-left','55','','','.w-reviews'),(131870,'printshop-mobile','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(131871,'printshop-mobile','.w-product-properties li','padding-left','0','','','.w-product-properties'),(131872,'printshop-mobile','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(131873,'printshop-mobile','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(131874,'printshop-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(131875,'printshop-mobile','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(131876,'printshop-mobile','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(131877,'printshop-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(131878,'printshop-mobile','.w-menu-style-1 ul','padding-left','0','','','.w-menu-style-1'),(131879,'printshop-mobile','.w-tabs .accordion-heading','padding-left','8','693','','.w-tabs'),(131880,'printshop-mobile','.w-text .customer-service','padding-left','30','','','.w-text'),(131881,'printshop-mobile','.w-categories .categories h2','padding-left','0','','','.w-categories'),(131882,'printshop-mobile','.w-top-categories .categories h2','padding-left','0','','','.w-top-categories'),(131883,'printshop-mobile','.w-banner .carousel-text > span','padding-left','20','','','.w-banner'),(131884,'printshop-mobile','.b-slick .slick-list','padding-left','0','','','.b-slick'),(131885,'printshop-mobile','.w-tabs .tab-li','padding-left','0','','','.w-tabs'),(131886,'printshop-mobile','.w-tabs .tab-a','padding-left','6','','','.w-tabs'),(131887,'printshop-mobile','.w-list-type-1 ','padding-left','0','','','.w-list-type-1'),(131888,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-left','10','','','.w-menu-horizontal'),(131889,'printshop-mobile','.p-account-index .account_page h2.order-table-title','padding-left','30','','','.p-account-index'),(131890,'printshop-mobile','.p-account-index .account_page h4','padding-left','40','','','.p-account-index'),(131891,'printshop-mobile','.w-categories .item','padding-left','10','693','','.w-categories'),(131892,'printshop-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-left','0','','','.b-fancybox'),(131893,'printshop-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-left','0','','','.b-fancybox'),(131894,'printshop-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-left','6','','','.b-compare'),(131895,'printshop-mobile','.b-compare .popupCompare td.level-3:first-child','padding-left','18','','','.b-compare'),(131896,'printshop-mobile','.b-compare .popupCompare td.level-2:first-child','padding-left','12','','','.b-compare'),(131897,'printshop-mobile','.w-cart-give-away .ga_img','padding-left','1','','','.w-cart-give-away'),(131898,'printshop-mobile','.w-search .search form','padding-left','5','','','.w-search'),(131899,'printshop-mobile','.b-autocomplete .ui-autocomplete','padding-left','0','','','.b-autocomplete'),(131900,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','padding-left','10','','',''),(131901,'printshop-mobile','textarea','padding-left','10','','',''),(131902,'printshop-mobile','.b-autocomplete .ui-autocomplete li','padding-left','10','','','.b-autocomplete'),(131903,'printshop-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-left','20','','','.b-bottom'),(131904,'printshop-mobile','.b-bottom .pop-up-close','padding-left','1','','','.b-bottom'),(131905,'printshop-mobile','.b-bottom .pop-up-info','padding-left','20','','','.b-bottom'),(131906,'printshop-mobile','.b-form .addresses .address-item span','padding-left','5','','','.b-form'),(131907,'printshop-mobile','.b-form .center-buttons','padding-left','0','','','.b-form'),(131908,'printshop-mobile','.w-reviews .reviews','padding-left','10','','','.w-reviews'),(131909,'printshop-mobile','.w-top-categories .item','padding-left','20','','','.w-top-categories'),(131910,'printshop-mobile','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-left','10','695','',''),(131911,'printshop-mobile','.b-form .payment-method .item-radio label span','padding-left','5','','','.b-form'),(131912,'printshop-mobile','.b-form .payment-method .item-radio label','padding-left','5','','','.b-form'),(131913,'printshop-mobile','.b-form .middle-form','padding-left','0','','','.b-form'),(131914,'printshop-mobile','.b-form .required-message-wrap','padding-left','0','','','.b-form'),(131915,'printshop-mobile','.b-form .required-message','padding-left','3','','','.b-form'),(131916,'printshop-mobile','.p-account-address-book .leftMes ul','padding-left','0','','','.p-account-address-book'),(131917,'printshop-mobile','.b-form .shipping-method .input','padding-left','10','','','.b-form'),(131918,'printshop-mobile','.b-info .info','padding-left','40','','','.b-info'),(131919,'printshop-mobile','.b-info .info ul','padding-left','0','','','.b-info'),(131920,'printshop-mobile','.b-info .info li','padding-left','0','','','.b-info'),(131921,'printshop-mobile','.p-account-index .topAccount','padding-left','19','','','.p-account-index'),(131922,'printshop-mobile','.b-products-listing .in-cart','padding-left','10','','','.b-products-listing'),(131923,'printshop-mobile','.b-products-listing .products-listing .bonus-points-cost','padding-left','20','','','.b-products-listing'),(131924,'printshop-mobile','.b-products-listing .products-listing .bonus-points-price','padding-left','20','','','.b-products-listing'),(131925,'printshop-mobile','.b-products-listing .products-listing .btn-buy','padding-left','10','','','.b-products-listing'),(131926,'printshop-mobile','.b-products-listing .products-listing .buyButton .btn','padding-left','10','','','.b-products-listing'),(131927,'printshop-mobile','.b-products-listing .products-listing .compare','padding-left','6','','','.b-products-listing'),(131928,'printshop-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-left','2','','','.b-products-listing'),(131929,'printshop-mobile','.b-products-listing .products-listing a.btn.view-button','padding-left','0','','','.b-products-listing'),(131930,'printshop-mobile','.b-products-listing .products-listing h2','padding-left','0','','','.b-products-listing'),(131931,'printshop-mobile','.b-products-listing .promos-info .promo-item','padding-left','0','','','.b-products-listing'),(131932,'printshop-mobile','.b-products-listing .promos-info .promo-name','padding-left','15','','','.b-products-listing'),(131933,'printshop-mobile','.b-products-listing .list-productlisting div.BlockBox.item-holder','padding-left','10','','','.b-products-listing'),(131934,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.b-data-table'),(131935,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.b-data-table'),(131936,'printshop-mobile','.b-data-table table.dataTable thead td','padding-left','20','','','.b-data-table'),(131937,'printshop-mobile','.b-data-table table.dataTable tbody td','padding-left','20','','','.b-data-table'),(131938,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(131939,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(131940,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(131941,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(131942,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(131943,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(131944,'printshop-mobile','.b-email .model','padding-left','10','','','.b-email'),(131945,'printshop-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(131946,'printshop-mobile','.b-email .price','padding-left','10','','','.b-email'),(131947,'printshop-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(131948,'printshop-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(131949,'printshop-mobile','.b-email .image','padding-left','10','','','.b-email'),(131950,'printshop-mobile','.b-email .price','padding-left','10','','','.b-email'),(131951,'printshop-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(131952,'printshop-mobile','.b-email .model','padding-left','10','','','.b-email'),(131953,'printshop-mobile','.b-email .qty','padding-left','10','','','.b-email'),(131954,'printshop-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(131955,'printshop-mobile','.b-email .image','padding-left','10','','','.b-email'),(131956,'printshop-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(131957,'printshop-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(131958,'printshop-mobile','.b-email .price','padding-left','10','','','.b-email'),(131959,'printshop-mobile','.b-email .image','padding-left','10','','','.b-email'),(131960,'printshop-mobile','.b-email .model','padding-left','10','','','.b-email'),(131961,'printshop-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(131962,'printshop-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(131963,'printshop-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(131964,'printshop-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(131965,'printshop-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(131966,'printshop-mobile','.b-email .model','padding-left','10','','','.b-email'),(131967,'printshop-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(131968,'printshop-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(131969,'printshop-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(131970,'printshop-mobile','.b-email .name','padding-left','10','','','.b-email'),(131971,'printshop-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(131972,'printshop-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(131973,'printshop-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(131974,'printshop-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(131975,'printshop-mobile','.b-email .name','padding-left','10','','','.b-email'),(131976,'printshop-mobile','.b-email .model','padding-left','10','','','.b-email'),(131977,'printshop-mobile','.b-email .name','padding-left','10','','','.b-email'),(131978,'printshop-mobile','.b-email .qty','padding-left','10','','','.b-email'),(131979,'printshop-mobile','.b-email .image','padding-left','10','','','.b-email'),(131980,'printshop-mobile','.b-email .name','padding-left','10','','','.b-email'),(131981,'printshop-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(131982,'printshop-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(131983,'printshop-mobile','.b-email .qty','padding-left','10','','','.b-email'),(131984,'printshop-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(131985,'printshop-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(131986,'printshop-mobile','.b-email .name','padding-left','10','','','.b-email'),(131987,'printshop-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(131988,'printshop-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(131989,'printshop-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(131990,'printshop-mobile','.b-email .model','padding-left','10','','','.b-email'),(131991,'printshop-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(131992,'printshop-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(131993,'printshop-mobile','.b-email .name','padding-left','10','','','.b-email'),(131994,'printshop-mobile','.b-email .qty','padding-left','10','','','.b-email'),(131995,'printshop-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(131996,'printshop-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(131997,'printshop-mobile','.b-email .image','padding-left','10','','','.b-email'),(131998,'printshop-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(131999,'printshop-mobile','.b-email .image','padding-left','10','','','.b-email'),(132000,'printshop-mobile','.b-email .price','padding-left','10','','','.b-email'),(132001,'printshop-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(132002,'printshop-mobile','.b-email .qty','padding-left','10','','','.b-email'),(132003,'printshop-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(132004,'printshop-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(132005,'printshop-mobile','.b-email .price','padding-left','10','','','.b-email'),(132006,'printshop-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(132007,'printshop-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(132008,'printshop-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(132009,'printshop-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(132010,'printshop-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(132011,'printshop-mobile','.b-email .price','padding-left','10','','','.b-email'),(132012,'printshop-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(132013,'printshop-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(132014,'printshop-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(132015,'printshop-mobile','.b-email .qty','padding-left','10','','','.b-email'),(132016,'printshop-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(132017,'printshop-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(132018,'printshop-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(132019,'printshop-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(132020,'printshop-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(132021,'printshop-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(132022,'printshop-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(132023,'printshop-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(132024,'printshop-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(132025,'printshop-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(132026,'printshop-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(132027,'printshop-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(132028,'printshop-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(132029,'printshop-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(132030,'printshop-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(132031,'printshop-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(132032,'printshop-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(132033,'printshop-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(132034,'printshop-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(132035,'printshop-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(132036,'printshop-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(132037,'printshop-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(132038,'printshop-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(132039,'printshop-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(132040,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-left','0','','','.b-h-inline'),(132041,'printshop-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-left','0','','','.b-menu-style'),(132042,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-left','5','','','.b-menu-style-1'),(132043,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-left','20','','','.b-menu-style-1'),(132044,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-left','20','','','.b-menu-style-1'),(132045,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-left','20','','','.b-menu-style-1'),(132046,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-left','0','','','.b-menu-style-2'),(132047,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-left','0','','','.b-menu-style-2'),(132048,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-left','0','','','.b-menu-style-2'),(132049,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-left','0','','','.b-menu-style-2'),(132050,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-left','20','','','.b-menu-style-2'),(132051,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-left','0','','','.b-menu-style-2'),(132052,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-left','20','','','.b-menu-style-2'),(132053,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-left','20','','','.b-menu-style-2'),(132054,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-left','20','','','.b-menu-style-2'),(132055,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-left','50','','','.b-menu-style-2'),(132056,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-left','5','','','.b-menu-style-3'),(132057,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','padding-left','20','','','.b-menu-style-3'),(132058,'printshop-mobile','.b-messages .msv_btn','padding-left','0','','','.b-messages'),(132059,'printshop-mobile','.b-messages .msv_content','padding-left','20','','','.b-messages'),(132060,'printshop-mobile','.b-messages .msv_history','padding-left','20','','','.b-messages'),(132061,'printshop-mobile','.b-messages .messMenuButton span','padding-left','15','','','.b-messages'),(132062,'printshop-mobile','.b-messages .messages-menu ul','padding-left','0','','','.b-messages'),(132063,'printshop-mobile','.b-messages .development-content .type-6 .content','padding-left','0','','','.b-messages'),(132064,'printshop-mobile','.b-messages .messages-menu li a','padding-left','0','','','.b-messages'),(132065,'printshop-mobile','.b-messages .content_management_attach button','padding-left','27','','','.b-messages'),(132066,'printshop-mobile','.b-messages .messages-menu li','padding-left','0','','','.b-messages'),(132067,'printshop-mobile','.b-messages .content_management_attach','padding-left','8','','','.b-messages'),(132068,'printshop-mobile','.b-messages .email-heading','padding-left','15','','','.b-messages'),(132069,'printshop-mobile','.b-messages .msv_to_cc','padding-left','15','','','.b-messages'),(132070,'printshop-mobile','.b-messages .emailLineTextArea textarea','padding-left','10','','','.b-messages'),(132071,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-left','10','','','.b-messages'),(132072,'printshop-mobile','.b-messages .emailBtn','padding-left','10','','','.b-messages'),(132073,'printshop-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-left','0','','','.b-personal-catalog-popup'),(132074,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','padding-left','8','','','.b-select-suggest'),(132075,'printshop-mobile','.b-select-suggest .select2-search input','padding-left','5','','','.b-select-suggest'),(132076,'printshop-mobile','.b-select-suggest .select2-drop-mask','padding-left','0','','','.b-select-suggest'),(132077,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-left','5','','','.b-select-suggest'),(132078,'printshop-mobile','.b-select-suggest .select2-results ul.select2-result-sub > li .select2-result-label','padding-left','20','','','.b-select-suggest'),(132079,'printshop-mobile','.b-select-suggest .select2-results','padding-left','4','','','.b-select-suggest'),(132080,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-left','0','','','.b-select-suggest'),(132081,'printshop-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','40','','','.b-select-suggest'),(132082,'printshop-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','100','','','.b-select-suggest'),(132083,'printshop-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','80','','','.b-select-suggest'),(132084,'printshop-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','110','','','.b-select-suggest'),(132085,'printshop-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','120','','','.b-select-suggest'),(132086,'printshop-mobile','.b-select-suggest .select2-results ul.select2-result-sub','padding-left','0','','','.b-select-suggest'),(132087,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-left','0','','','.b-select-suggest'),(132088,'printshop-mobile','.b-select-suggest .select2-locked','padding-left','5','','','.b-select-suggest'),(132089,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-left','0','','','.b-select-suggest'),(132090,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-left','18','','','.b-select-suggest'),(132091,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-left','5','','','.b-select-suggest'),(132092,'printshop-mobile','.b-select-suggest .select2-search','padding-left','4','','','.b-select-suggest'),(132093,'printshop-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','60','','','.b-select-suggest'),(132094,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','padding-left','7','','','.b-select-suggest'),(132095,'printshop-mobile','.b-sub-totals .historyTotal td','padding-left','5','','','.b-sub-totals'),(132096,'printshop-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(132097,'printshop-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(132098,'printshop-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(132099,'printshop-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(132100,'printshop-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(132101,'printshop-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(132102,'printshop-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(132103,'printshop-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(132104,'printshop-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(132105,'printshop-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(132106,'printshop-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(132107,'printshop-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(132108,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(132109,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(132110,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(132111,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(132112,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(132113,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(132114,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(132115,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(132116,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(132117,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(132118,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(132119,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(132120,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(132121,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(132122,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(132123,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(132124,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(132125,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(132126,'printshop-mobile','.b-trade-approval .steps-bar li a','padding-left','0','','','.b-trade-approval'),(132127,'printshop-mobile','.b-trade-approval .middle-form','padding-left','0','','','.b-trade-approval'),(132128,'printshop-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-left','5','','','.b-trade-approval'),(132129,'printshop-mobile','.b-trade-approval .steps-bar','padding-left','12','','','.b-trade-approval'),(132130,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-left','10','','','.b-trade-approval'),(132131,'printshop-mobile','.b-trade-approval .center-buttons','padding-left','0','','','.b-trade-approval'),(132132,'printshop-mobile','.b-upload-file .upload-file-template','padding-left','1','','','.b-upload-file'),(132133,'printshop-mobile','.b-upload-files .added-file','padding-left','0','','','.b-upload-files'),(132134,'printshop-mobile','.b-upload-files .upload-files','padding-left','10','','','.b-upload-files'),(132135,'printshop-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-left','20','','','.b-warehouses-popup'),(132136,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','padding-left','17','','','.b-warehouses-popup'),(132137,'printshop-mobile','.batchPr .w-batch-products .products-listing .image','padding-left','0','','','.batchPr'),(132138,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-left','0','','','.batchPr'),(132139,'printshop-mobile','.batchPr .w-batch-products','padding-left','0','','','.batchPr'),(132140,'printshop-mobile','.batchPr > .block:nth-child(2)','padding-left','20','','','.batchPr'),(132141,'printshop-mobile','.batchPr .w-batch-selected-products','padding-left','15','','','.batchPr'),(132142,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-left','0','','','.batchPr'),(132143,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-left','0','','','.batchPr'),(132144,'printshop-mobile','.batchPr ','padding-left','0','','','.batchPr'),(132145,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-left','0','','','.batchPr'),(132146,'printshop-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-left','0','','','.batchPr'),(132147,'printshop-mobile','.batchPr .w-batch-products .products-listing .image','padding-left','0','','','.batchPr'),(132148,'printshop-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(132149,'printshop-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(132150,'printshop-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(132151,'printshop-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(132152,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-left','10','','','.p-account-samples-history'),(132153,'printshop-mobile','.p-account-samples-history .orders-table td','padding-left','10','','','.p-account-samples-history'),(132154,'printshop-mobile','.p-account-samples-history .view_link','padding-left','0','','','.p-account-samples-history'),(132155,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-left','10','','','.p-account-samples-history'),(132156,'printshop-mobile','.p-account-samples-history .view_link','padding-left','0','','','.p-account-samples-history'),(132157,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-left','10','','','.p-account-samples-history'),(132158,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-left','10','','','.p-account-samples-history'),(132159,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-left','10','','','.p-account-samples-history'),(132160,'printshop-mobile','.p-account-samples-history .orders-table td','padding-left','10','','','.p-account-samples-history'),(132161,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-left','10','','','.p-account-samples-history'),(132162,'printshop-mobile','.p-account-samples-history .orders-table td','padding-left','10','','','.p-account-samples-history'),(132163,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-left','10','','','.p-account-samples-history'),(132164,'printshop-mobile','.p-account-samples-history .view_link','padding-left','0','','','.p-account-samples-history'),(132165,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-left','10','','','.p-account-samples-history'),(132166,'printshop-mobile','.p-account-samples-history .orders-table th','padding-left','10','','','.p-account-samples-history'),(132167,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-left','10','','','.p-account-samples-history'),(132168,'printshop-mobile','.p-account-samples-history .view_link','padding-left','0','','','.p-account-samples-history'),(132169,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-left','10','','','.p-account-samples-history'),(132170,'printshop-mobile','.p-account-samples-history .orders-table th','padding-left','10','','','.p-account-samples-history'),(132171,'printshop-mobile','.p-account-samples-history .orders-table th','padding-left','10','','','.p-account-samples-history'),(132172,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-left','10','','','.p-account-samples-history'),(132173,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-left','10','','','.p-account-samples-history'),(132174,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-left','10','','','.p-account-samples-history'),(132175,'printshop-mobile','.p-account-samples-history .orders-table th','padding-left','10','','','.p-account-samples-history'),(132176,'printshop-mobile','.p-account-samples-history .orders-table td','padding-left','10','','','.p-account-samples-history'),(132177,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-left','10','','','.p-account-samples-history'),(132178,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-left','10','','','.p-account-samples-history'),(132179,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-left','10','','','.p-account-samples-history'),(132180,'printshop-mobile','.p-account-samples-history .view_link','padding-left','0','','','.p-account-samples-history'),(132181,'printshop-mobile','.p-account-samples-history .orders-table td','padding-left','10','','','.p-account-samples-history'),(132182,'printshop-mobile','.p-account-samples-history .orders-table th','padding-left','10','','','.p-account-samples-history'),(132183,'printshop-mobile','.p-account-samples-history .orders-table td','padding-left','10','','','.p-account-samples-history'),(132184,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-left','10','','','.p-account-samples-history'),(132185,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-left','10','','','.p-account-samples-history'),(132186,'printshop-mobile','.p-account-samples-history .view_link','padding-left','0','','','.p-account-samples-history'),(132187,'printshop-mobile','.p-account-samples-history .orders-table th','padding-left','10','','','.p-account-samples-history'),(132188,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','0','','','.p-account-samples-history-info'),(132189,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','0','','','.p-account-samples-history-info'),(132190,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-left','10','','','.p-account-samples-history-info'),(132191,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-left','0','','','.p-account-samples-history-info'),(132192,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-left','40','','','.p-account-samples-history-info'),(132193,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-left','0','','','.p-account-samples-history-info'),(132194,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','0','','','.p-account-samples-history-info'),(132195,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-left','40','','','.p-account-samples-history-info'),(132196,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','2','','','.p-account-samples-history-info'),(132197,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-left','10','','','.p-account-samples-history-info'),(132198,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-left','40','','','.p-account-samples-history-info'),(132199,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','2','','','.p-account-samples-history-info'),(132200,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-left','0','','','.p-account-samples-history-info'),(132201,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-left','0','','','.p-account-samples-history-info'),(132202,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-left','0','','','.p-account-samples-history-info'),(132203,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','0','','','.p-account-samples-history-info'),(132204,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-left','40','','','.p-account-samples-history-info'),(132205,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','0','','','.p-account-samples-history-info'),(132206,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','2','','','.p-account-samples-history-info'),(132207,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-left','40','','','.p-account-samples-history-info'),(132208,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','2','','','.p-account-samples-history-info'),(132209,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-left','40','','','.p-account-samples-history-info'),(132210,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-left','0','','','.p-account-samples-history-info'),(132211,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-left','10','','','.p-account-samples-history-info'),(132212,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','2','','','.p-account-samples-history-info'),(132213,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-left','10','','','.p-account-samples-history-info'),(132214,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','0','','','.p-account-samples-history-info'),(132215,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-left','40','','','.p-account-samples-history-info'),(132216,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','2','','','.p-account-samples-history-info'),(132217,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-left','40','','','.p-account-samples-history-info'),(132218,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-left','40','','','.p-account-samples-history-info'),(132219,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-left','10','','','.p-account-samples-history-info'),(132220,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-left','10','','','.p-account-samples-history-info'),(132221,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-left','40','','','.p-account-samples-history-info'),(132222,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-left','40','','','.p-account-samples-history-info'),(132223,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-left','40','','','.p-account-samples-history-info'),(132224,'printshop-mobile','.p-catalog-product .prev-product','padding-left','50','','','.p-catalog-product'),(132225,'printshop-mobile','.p-catalog-product .next-product','padding-left','20','','','.p-catalog-product'),(132226,'printshop-mobile','.p-catalog-product .pn-image','padding-left','5','','','.p-catalog-product'),(132227,'printshop-mobile','.p-catalog-product .next-product .pn-image','padding-left','2','3','','.p-catalog-product'),(132228,'printshop-mobile','.p-catalog-product .pn-direction','padding-left','4','','','.p-catalog-product'),(132229,'printshop-mobile','.p-quick-order-index .bottom','padding-left','0','','','.p-quick-order-index'),(132230,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.p-quick-order-index'),(132231,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.p-quick-order-index'),(132232,'printshop-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-left','10','','','.p-quick-order-index'),(132233,'printshop-mobile','.p-quick-order-index .all-scroll-div','padding-left','0','','','.p-quick-order-index'),(132234,'printshop-mobile','.p-quick-order-index ul.token-input-list','padding-left','0','','','.p-quick-order-index'),(132235,'printshop-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-left','10','','','.p-quick-order-index'),(132236,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(132237,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(132238,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(132239,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(132240,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(132241,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(132242,'printshop-mobile','.w-account-address-book .item','padding-left','10','','','.w-account-address-book'),(132243,'printshop-mobile','.w-account-address-book .wrap','padding-left','15','','','.w-account-address-book'),(132244,'printshop-mobile','.w-account-address-book .btn-del','padding-left','7','','','.w-account-address-book'),(132245,'printshop-mobile','.w-account-address-book .default-address','padding-left','7','','','.w-account-address-book'),(132246,'printshop-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-left','0','','','.w-account-addresses-list'),(132247,'printshop-mobile','.w-account-personal-catalog .list-switcher','padding-left','0','','','.w-account-personal-catalog'),(132248,'printshop-mobile','.w-account-personal-catalog .list-switcher a','padding-left','6','','','.w-account-personal-catalog'),(132249,'printshop-mobile','.w-account-subscription .subscription-variant','padding-left','10','','','.w-account-subscription'),(132250,'printshop-mobile','.w-blog-widget-categories-list a','padding-left','15','','','.w-blog-widget-categories-list'),(132251,'printshop-mobile','.w-blog-widget-most-popular-posts a','padding-left','15','','','.w-blog-widget-most-popular-posts'),(132252,'printshop-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-left','0','','','.w-blog-widget-most-popular-posts'),(132253,'printshop-mobile','.w-blog-widget-post-comments-count span','padding-left','22','','','.w-blog-widget-post-comments-count'),(132254,'printshop-mobile','.w-blog-widget-post-listing .post','padding-left','33','','','.w-blog-widget-post-listing'),(132255,'printshop-mobile','.w-blog-widget-post-listing .post_comment','padding-left','22','','','.w-blog-widget-post-listing'),(132256,'printshop-mobile','.w-blog-widget-post-listing .post_name','padding-left','0','','','.w-blog-widget-post-listing'),(132257,'printshop-mobile','.w-blog-widget-post-listing .post','padding-left','15','','','.w-blog-widget-post-listing'),(132258,'printshop-mobile','.w-blog-widget-post-title ','padding-left','0','','','.w-blog-widget-post-title'),(132259,'printshop-mobile','.w-blog-widget-post-title h1','padding-left','0','','','.w-blog-widget-post-title'),(132260,'printshop-mobile','.w-blog-widget-related-posts .post','padding-left','15','','','.w-blog-widget-related-posts'),(132261,'printshop-mobile','.w-blog-widget-related-posts .post_content a','padding-left','20','','','.w-blog-widget-related-posts'),(132262,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-left','20','','','.w-blog-widget-related-posts-by-category'),(132263,'printshop-mobile','.w-blog-widget-related-posts-by-category .post','padding-left','15','','','.w-blog-widget-related-posts-by-category'),(132264,'printshop-mobile','.w-blog-widget-related-posts-by-category ','padding-left','0','','','.w-blog-widget-related-posts-by-category'),(132265,'printshop-mobile','.w-blog-widget-related-posts-by-category ','padding-left','15','','','.w-blog-widget-related-posts-by-category'),(132266,'printshop-mobile','.w-blog-widget-tag-cloud a','padding-left','13','','','.w-blog-widget-tag-cloud'),(132267,'printshop-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-left','0','','','.w-cart-cart-tabs'),(132268,'printshop-mobile','.w-cart-compare .attributes-label','padding-left','10','','','.w-cart-compare'),(132269,'printshop-mobile','.w-cart-compare .product .stock','padding-left','3','','','.w-cart-compare'),(132270,'printshop-mobile','.w-cart-compare .product','padding-left','15','','','.w-cart-compare'),(132271,'printshop-mobile','.w-cart-compare .cart-cell','padding-left','7','','','.w-cart-compare'),(132272,'printshop-mobile','.w-cart-compare .price-cell','padding-left','20','','','.w-cart-compare'),(132273,'printshop-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-left','0','','','.w-cart-compare'),(132274,'printshop-mobile','.w-cart-compare .delete-cart','padding-left','10','','','.w-cart-compare'),(132275,'printshop-mobile','.w-cart-compare .dropdown li','padding-left','10','','','.w-cart-compare'),(132276,'printshop-mobile','.w-cart-compare .attributes-cell','padding-left','20','','','.w-cart-compare'),(132277,'printshop-mobile','.w-cart-compare .price-label','padding-left','10','','','.w-cart-compare'),(132278,'printshop-mobile','.w-cart-compare .product-label','padding-left','10','','','.w-cart-compare'),(132279,'printshop-mobile','.w-cart-up-sell .w-list-type-1','padding-left','0','','','.w-cart-up-sell'),(132280,'printshop-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-left','20','1','','.w-cart-up-sell'),(132281,'printshop-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-left','21','','','.w-cart-up-sell'),(132282,'printshop-mobile','.w-catalog-additional-images li','padding-left','10','','','.w-catalog-additional-images'),(132283,'printshop-mobile','.w-catalog-additional-images ul','padding-left','0','','','.w-catalog-additional-images'),(132284,'printshop-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-left','5','','','.w-catalog-b2b-add-button'),(132285,'printshop-mobile','.w-catalog-compare td','padding-left','20','','','.w-catalog-compare'),(132286,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-left','0','','','.w-catalog-compare'),(132287,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','padding-left','5','2','','.w-catalog-compare'),(132288,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','padding-left','5','','','.w-catalog-compare'),(132289,'printshop-mobile','.w-catalog-compare .cross-box .return','padding-left','20','','','.w-catalog-compare'),(132290,'printshop-mobile','.w-catalog-paging .prev','padding-left','5','','','.w-catalog-paging'),(132291,'printshop-mobile','.w-catalog-paging .next','padding-left','5','','','.w-catalog-paging'),(132292,'printshop-mobile','.w-catalog-paging ','padding-left','5','2','','.w-catalog-paging'),(132293,'printshop-mobile','.w-catalog-paging .paging-item','padding-left','2','','','.w-catalog-paging'),(132294,'printshop-mobile','.w-catalog-paging .next-pages','padding-left','5','','','.w-catalog-paging'),(132295,'printshop-mobile','.w-catalog-paging .prev-pages','padding-left','5','','','.w-catalog-paging'),(132296,'printshop-mobile','.w-catalog-paging .page-number','padding-left','5','','','.w-catalog-paging'),(132297,'printshop-mobile','.w-checkout-billing-address .same-address','padding-left','10','','','.w-checkout-billing-address'),(132298,'printshop-mobile','.w-checkout-billing-address .edit-ab','padding-left','15','','','.w-checkout-billing-address'),(132299,'printshop-mobile','.w-checkout-billing-address .addresses.address-main label','padding-left','0','','','.w-checkout-billing-address'),(132300,'printshop-mobile','.w-checkout-billing-address .addresses .address-item label','padding-left','15','','','.w-checkout-billing-address'),(132301,'printshop-mobile','.w-checkout-create-account .create-account','padding-left','0','','','.w-checkout-create-account'),(132302,'printshop-mobile','.w-checkout-create-account .account-benefits ul','padding-left','20','','','.w-checkout-create-account'),(132303,'printshop-mobile','.w-checkout-gdpr .terms-login','padding-left','0','','','.w-checkout-gdpr'),(132304,'printshop-mobile','.w-checkout-gdpr .privacy-row','padding-left','0','','','.w-checkout-gdpr'),(132305,'printshop-mobile','.w-checkout-shipping .sub-item','padding-left','0','','','.w-checkout-shipping'),(132306,'printshop-mobile','.w-checkout-shipping-address .addresses.address-main label','padding-left','0','','','.w-checkout-shipping-address'),(132307,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item label','padding-left','15','','','.w-checkout-shipping-address'),(132308,'printshop-mobile','.w-checkout-shipping-address .edit-ab','padding-left','15','','','.w-checkout-shipping-address'),(132309,'printshop-mobile','.w-checkout-shipping-choice span','padding-left','0','','','.w-checkout-shipping-choice'),(132310,'printshop-mobile','.w-checkout-shipping-choice span','padding-left','10','','','.w-checkout-shipping-choice'),(132311,'printshop-mobile','.w-checkout-terms .required-message','padding-left','10','','','.w-checkout-terms'),(132312,'printshop-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-left','10','','','.w-communication-new-topic'),(132313,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-left','5','','','.w-communication-new-topic'),(132314,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-left','5','','','.w-communication-new-topic'),(132315,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-left','10','','','.w-communication-new-topic'),(132316,'printshop-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-left','0','','','.w-communication-new-topic'),(132317,'printshop-mobile','.w-communication-post .communication-post-author','padding-left','0','','','.w-communication-post'),(132318,'printshop-mobile','.w-delivery-day .left-count','padding-left','5','','','.w-delivery-day'),(132319,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-left','10','','','.w-image-maps'),(132320,'printshop-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-left','0','','','.w-multi-cart-actions'),(132321,'printshop-mobile','.w-personal-gift-status-bar .timeline','padding-left','10','','','.w-personal-gift-status-bar'),(132322,'printshop-mobile','.w-personal-gift-status-bar .start-label','padding-left','30','','','.w-personal-gift-status-bar'),(132323,'printshop-mobile','.w-personal-gift-status-bar .end-date','padding-left','5','3','','.w-personal-gift-status-bar'),(132324,'printshop-mobile','.w-personal-gift-status-bar .end-label','padding-left','5','','','.w-personal-gift-status-bar'),(132325,'printshop-mobile','.w-personal-gift-status-bar .inform','padding-left','5','4','','.w-personal-gift-status-bar'),(132326,'printshop-mobile','.w-product-available-in-warehouses .warehouse-item','padding-left','0','','','.w-product-available-in-warehouses'),(132327,'printshop-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(132328,'printshop-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(132329,'printshop-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(132330,'printshop-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(132331,'printshop-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(132332,'printshop-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(132333,'printshop-mobile','.w-product-customers-activity .customers-activity','padding-left','20','','','.w-product-customers-activity'),(132334,'printshop-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(132335,'printshop-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(132336,'printshop-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(132337,'printshop-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(132338,'printshop-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(132339,'printshop-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(132340,'printshop-mobile','.w-promotions .nextdiscount .promo-for-each','padding-left','10','','','.w-promotions'),(132341,'printshop-mobile','.w-promotions .promo-cart-discount .master .item','padding-left','20','','','.w-promotions'),(132342,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-left','20','','','.w-promotions'),(132343,'printshop-mobile','.w-promotions .promo-cart-discount .slave','padding-left','15','','','.w-promotions'),(132344,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-left','20','','','.w-promotions'),(132345,'printshop-mobile','.w-promotions .promo-salemaker .item','padding-left','20','','','.w-promotions'),(132346,'printshop-mobile','.w-promotions .promo-salemaker .promo-manufacturers','padding-left','12','','','.w-promotions'),(132347,'printshop-mobile','.w-promotions .promo-item','padding-left','40','','','.w-promotions'),(132348,'printshop-mobile','.w-promotions .promo-salemaker .discount','padding-left','20','','','.w-promotions'),(132349,'printshop-mobile','.w-promotions .promo-cart-discount .slave .item','padding-left','20','','','.w-promotions'),(132350,'printshop-mobile','.w-promotions .prom-multi-discount .promo-product','padding-left','20','','','.w-promotions'),(132351,'printshop-mobile','.w-promotions .nextdiscount .content > div','padding-left','10','','','.w-promotions'),(132352,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','padding-left','20','','','.w-promotions'),(132353,'printshop-mobile','.w-reviews-content .author','padding-left','20','','','.w-reviews-content'),(132354,'printshop-mobile','.w-reviews-content .item','padding-left','0','','','.w-reviews-content'),(132355,'printshop-mobile','.w-reviews-content .review','padding-left','20','','','.w-reviews-content'),(132356,'printshop-mobile','.w-sitemap-delivery-location > ul','padding-left','0','','','.w-sitemap-delivery-location'),(132357,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul ul','padding-left','20','','','.w-sitemap-delivery-location'),(132358,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-left','0','','','.w-sitemap-delivery-location'),(132359,'printshop-mobile','.w-top-text .top-text','padding-left','10','','','.w-top-text'),(132360,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(132361,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-preview','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(132362,'printshop-mobile','.w-wedding-registry-widgets-delete-link a','padding-left','12','','','.w-wedding-registry-widgets-delete-link'),(132363,'printshop-mobile','.w-wedding-registry-widgets-photos ','padding-left','20','','','.w-wedding-registry-widgets-photos'),(132364,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-left','17','','','.w-wedding-registry-widgets-photos'),(132365,'printshop-mobile','.w-wedding-registry-widgets-share-link a','padding-left','12','','','.w-wedding-registry-widgets-share-link'),(132366,'printshop-mobile','.b-quantity .qty-box input[type=\'text\']','padding-left','3','','','.b-quantity'),(132367,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left_important','important','','','.b-data-table'),(132368,'printshop-mobile','.b-data-table table.dataTable thead td','padding-left_important','important','','','.b-data-table'),(132369,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left_important','important','','','.b-data-table'),(132370,'printshop-mobile','.b-data-table table.dataTable tbody td','padding-left_important','important','','','.b-data-table'),(132371,'printshop-mobile','.batchPr .w-batch-products','padding-left_important','important','','','.batchPr'),(132372,'printshop-mobile','.w-list-type-2 .item','padding-right','21','','','.w-list-type-2'),(132373,'printshop-mobile','.w-list-type-2 .compare-box-item','padding-right','7','','','.w-list-type-2'),(132374,'printshop-mobile','.w-list-type-1_3 .item','padding-right','0','1','','.w-list-type-1_3'),(132375,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','padding-right','15','','','.w-list-type-2'),(132376,'printshop-mobile','.w-list-type-1_3 .item','padding-right','0','','','.w-list-type-1_3'),(132377,'printshop-mobile','.w-list-type-1_3 .compare-box-item','padding-right','7','','','.w-list-type-1_3'),(132378,'printshop-mobile','.w-list-type-2_2 .compare-box-item','padding-right','7','','','.w-list-type-2_2'),(132379,'printshop-mobile','.w-list-type-2.products-listing','padding-right','20','','','.w-list-type-2'),(132380,'printshop-mobile','.w-list-type-2 .item','padding-right','20','1','','.w-list-type-2'),(132381,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','padding-right','15','','','.w-list-type-2_2'),(132382,'printshop-mobile','.w-list-type-2_2.products-listing','padding-right','20','','','.w-list-type-2_2'),(132383,'printshop-mobile','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(132384,'printshop-mobile','.w-list-type-3.products-listing','padding-right','20','','','.w-list-type-3'),(132385,'printshop-mobile','.w-menu .hided.menu ul li','padding-right','0','','','.w-menu'),(132386,'printshop-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-right','0','','','.w-menu'),(132387,'printshop-mobile','.w-menu-big ul','padding-right','0','','','.w-menu-big'),(132388,'printshop-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','','','.w-menu-horizontal'),(132389,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li','padding-right','10','','','.w-menu-horizontal'),(132390,'printshop-mobile','.w-menu-slider ul, .w-menu-slider li','padding-right','0','','','.w-menu-slider'),(132391,'printshop-mobile','.w-menu-slider > ul > li > a','padding-right','10','','','.w-menu-slider'),(132392,'printshop-mobile','.w-menu-slider > ul > li > ul > li','padding-right','50','','','.w-menu-slider'),(132393,'printshop-mobile','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(132394,'printshop-mobile','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(132395,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-right','0','','','.b-slick'),(132396,'printshop-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','','','.w-menu-style-1'),(132397,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(132398,'printshop-mobile','.b-bottom .popup-simple','padding-right','20','','','.b-bottom'),(132399,'printshop-mobile','.b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .buttons','padding-right','10','','','.b-cookie-notice'),(132400,'printshop-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.bottom .text','padding-right','10','','','.b-cookie-notice'),(132401,'printshop-mobile','.w-login-block .returning','padding-right','40','','','.w-login-block'),(132402,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','','','.w-menu-style-1'),(132403,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-right','20','','','.w-menu-style-1'),(132404,'printshop-mobile','.w-product-wedding-registry-button .btn','padding-right','0','','','.w-product-wedding-registry-button'),(132405,'printshop-mobile','.w-sale .holder-2','padding-right','20','','','.w-sale'),(132406,'printshop-mobile','.w-quote .cart-box-link','padding-right','10','','','.w-quote'),(132407,'printshop-mobile','.w-filters .filter-widget-horizontal .filter-box','padding-right','20','','','.w-filters'),(132408,'printshop-mobile','.w-categories .name','padding-right','3','','','.w-categories'),(132409,'printshop-mobile','.w-filters .filter-ul-content','padding-right','0','','','.w-filters'),(132410,'printshop-mobile','.w-currencies .currencies-title','padding-right','4','','','.w-currencies'),(132411,'printshop-mobile','.w-currencies .current','padding-right','27','','','.w-currencies'),(132412,'printshop-mobile','.w-currencies .select-link','padding-right','10','','','.w-currencies'),(132413,'printshop-mobile','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(132414,'printshop-mobile','.w-filters .ui-slider-range','padding-right','0','','','.w-filters'),(132415,'printshop-mobile','.w-filters .fsl_handle','padding-right','0','','','.w-filters'),(132416,'printshop-mobile','.w-top-categories .item','padding-right','10','693','','.w-top-categories'),(132417,'printshop-mobile','.p-account-history-info .contentColumn','padding-right','10','','','.p-account-history-info'),(132418,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','padding-right','0','','','.p-account-history-info'),(132419,'printshop-mobile','.p-account-history-info .historyTotal td','padding-right','5','','','.p-account-history-info'),(132420,'printshop-mobile','.p-account-history-info .history_attr div strong, .p-account-history-info .history_attr div span','padding-right','10','','','.p-account-history-info'),(132421,'printshop-mobile','.p-account-history-info .history_info > div + div','padding-right','0','','','.p-account-history-info'),(132422,'printshop-mobile','.p-account-index .account_block','padding-right','0','','','.p-account-index'),(132423,'printshop-mobile','.p-account-index .account_info','padding-right','0','','','.p-account-index'),(132424,'printshop-mobile','.p-account-index .date_title','padding-right','0','','','.p-account-index'),(132425,'printshop-mobile','.p-account-index .account_info li','padding-right','0','','','.p-account-index'),(132426,'printshop-mobile','.p-account-index .account_page','padding-right','0','','','.p-account-index'),(132427,'printshop-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','padding-right','10','','','.p-account-index'),(132428,'printshop-mobile','.p-account-index .badc_bottom','padding-right','0','','','.p-account-index'),(132429,'printshop-mobile','.p-account-index .orders-table th','padding-right','10','','','.p-account-index'),(132430,'printshop-mobile','.b-bottom .popup-buttons','padding-right','15','','','.b-bottom'),(132431,'printshop-mobile','.w-cart-checkout-btn a','padding-right','12','693','','.w-cart-checkout-btn'),(132432,'printshop-mobile','.w-product-reviews .reviews-list .name','padding-right','10','','','.w-product-reviews'),(132433,'printshop-mobile','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(132434,'printshop-mobile','.w-product-images .img-holder','padding-right','20','','','.w-product-images'),(132435,'printshop-mobile','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(132436,'printshop-mobile','.b-bottom .popup-content','padding-right','15','','','.b-bottom'),(132437,'printshop-mobile','.b-compare .compare_pagination','padding-right','0','','','.b-compare'),(132438,'printshop-mobile','.w-search .button-search','padding-right','0','','','.w-search'),(132439,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-right','10','','','.b-multi-page-checkout'),(132440,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-right','10','','','.b-multi-page-checkout'),(132441,'printshop-mobile','.w-search .name','padding-right','0','','','.w-search'),(132442,'printshop-mobile','.w-search .items-title','padding-right','0','','','.w-search'),(132443,'printshop-mobile','.w-sale .holder-1','padding-right','20','','','.w-sale'),(132444,'printshop-mobile','.w-search .item','padding-right','0','','','.w-search'),(132445,'printshop-mobile','.w-socials > li','padding-right','15','','','.w-socials'),(132446,'printshop-mobile','.b-info-popup .info-popup div','padding-right','15','','','.b-info-popup'),(132447,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-right','0','','','.b-multi-page-checkout'),(132448,'printshop-mobile','.w-search .search-input','padding-right','40','','','.w-search'),(132449,'printshop-mobile','.w-promo-code .holder','padding-right','20','723','','.w-promo-code'),(132450,'printshop-mobile','.w-search .suggest','padding-right','20','','','.w-search'),(132451,'printshop-mobile','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(132452,'printshop-mobile','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(132453,'printshop-mobile','.p-wedding-registry-manage a.remove-btn','padding-right','5','','','.p-wedding-registry-manage'),(132454,'printshop-mobile','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(132455,'printshop-mobile','.p-account-history-info .popup-tracking-number','padding-right','10','','','.p-account-history-info'),(132456,'printshop-mobile','.p-account-order-pay .contentColumn','padding-right','10','','','.p-account-order-pay'),(132457,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','padding-right','0','','','.p-account-order-pay'),(132458,'printshop-mobile','.p-account-order-pay .historyTotal td','padding-right','5','','','.p-account-order-pay'),(132459,'printshop-mobile','.p-account-order-pay .history_info > div + div','padding-right','0','694','','.p-account-order-pay'),(132460,'printshop-mobile','.p-account-order-pay .history_attr div strong, .p-account-order-pay .history_attr div span','padding-right','10','','','.p-account-order-pay'),(132461,'printshop-mobile','.p-account-order-pay .history_info > div','padding-right','0','694','','.p-account-order-pay'),(132462,'printshop-mobile','.p-account-order-pay .history_info > div + div','padding-right','0','','','.p-account-order-pay'),(132463,'printshop-mobile','.w-filters .head-filter-widget','padding-right','10','720','','.w-filters'),(132464,'printshop-mobile','.w-product-configurator .pc_attr','padding-right','0','693','','.w-product-configurator'),(132465,'printshop-mobile','.w-product-configurator .pc_item','padding-right','0','702','','.w-product-configurator'),(132466,'printshop-mobile','.testimonials .name','padding-right','10','','',''),(132467,'printshop-mobile','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(132468,'printshop-mobile','.b-pagination .pagination span','padding-right','5','2','','.b-pagination'),(132469,'printshop-mobile','.testimonials .heading-3','padding-right','0','','',''),(132470,'printshop-mobile','.testimonials .review','padding-right','10','','',''),(132471,'printshop-mobile','.b-pagination .pagination .prev-pages','padding-right','5','','','.b-pagination'),(132472,'printshop-mobile','.testimonials .reviews-list .name','padding-right','10','','',''),(132473,'printshop-mobile','.b-pagination .pagination .prev','padding-right','5','','','.b-pagination'),(132474,'printshop-mobile','.b-bottom .confirm-popup .confirm-text','padding-right','0','','','.b-bottom'),(132475,'printshop-mobile','.b-pagination .pagination .page-number','padding-right','5','','','.b-pagination'),(132476,'printshop-mobile','.b-pagination .pagination .next-pages','padding-right','5','','','.b-pagination'),(132477,'printshop-mobile','.b-pagination .pagination .next','padding-right','5','','','.b-pagination'),(132478,'printshop-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','padding-right','10','','','.p-account-history'),(132479,'printshop-mobile','.p-account-history .orders-table th','padding-right','10','','','.p-account-history'),(132480,'printshop-mobile','.p-account-history .view_link','padding-right','20','','','.p-account-history'),(132481,'printshop-mobile','.p-account-history .orders-table .td-alignright','padding-right','10','720','','.p-account-history'),(132482,'printshop-mobile','.p-account-history .orders-table td','padding-right','10','720','','.p-account-history'),(132483,'printshop-mobile','.p-account-index .orders-table td','padding-right','10','720','','.p-account-index'),(132484,'printshop-mobile','.p-account-index .orders-table .td-alignright','padding-right','10','720','','.p-account-index'),(132485,'printshop-mobile','.btn','padding-right','12','','',''),(132486,'printshop-mobile','.btn-1','padding-right','25','','',''),(132487,'printshop-mobile','.btn-2','padding-right','25','','',''),(132488,'printshop-mobile','.p-blog-index .nav-next','padding-right','50','','','.p-blog-index'),(132489,'printshop-mobile','.btn-3','padding-right','25','','',''),(132490,'printshop-mobile','.w-list-type-2_2 .button-view a','padding-right','10','','','.w-list-type-2_2'),(132491,'printshop-mobile','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(132492,'printshop-mobile','.w-product-personal-catalog-button .btn','padding-right','0','','','.w-product-personal-catalog-button'),(132493,'printshop-mobile','.b-fancybox .fancybox-error','padding-right','15','','','.b-fancybox'),(132494,'printshop-mobile','.w-menu-horizontal ul','padding-right','0','','','.w-menu-horizontal'),(132495,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-right','0','','','.w-delivery-location-top-location-list'),(132496,'printshop-mobile','.w-chat .w-chat-box','padding-right','12','','','.w-chat'),(132497,'printshop-mobile','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(132498,'printshop-mobile','.b-bottom .alert-message','padding-right','20','','','.b-bottom'),(132499,'printshop-mobile','.p-wedding-registry-index .middle-box','padding-right','10','','','.p-wedding-registry-index'),(132500,'printshop-mobile','.p-wedding-registry-index .main-content','padding-right','0','','','.p-wedding-registry-index'),(132501,'printshop-mobile','.p-wedding-registry-index .main-button','padding-right','20','3','','.p-wedding-registry-index'),(132502,'printshop-mobile','.p-wedding-registry-index .main-button','padding-right','20','4','','.p-wedding-registry-index'),(132503,'printshop-mobile','.b-form .form-buttons','padding-right','0','','','.b-form'),(132504,'printshop-mobile','.p-wedding-registry-manage .links','padding-right','10','','','.p-wedding-registry-manage'),(132505,'printshop-mobile','.p-wedding-registry-manage .links a','padding-right','10','','','.p-wedding-registry-manage'),(132506,'printshop-mobile','.p-wedding-registry-search .search-list','padding-right','20','','','.p-wedding-registry-search'),(132507,'printshop-mobile','.b-table .table td','padding-right','15','','','.b-table'),(132508,'printshop-mobile','.b-table .table .headings td','padding-right','10','','','.b-table'),(132509,'printshop-mobile','.p-wedding-registry-share .middle-form > input','padding-right','0','','','.p-wedding-registry-share'),(132510,'printshop-mobile','.b-pagination .pagination a','padding-right','5','','','.b-pagination'),(132511,'printshop-mobile','.p-account-address-book .topButtons','padding-right','0','','','.p-account-address-book'),(132512,'printshop-mobile','.header2 .ccc','padding-right','10','','',''),(132513,'printshop-mobile','.p-account-history .order_history_table th','padding-right','10','','','.p-account-history'),(132514,'printshop-mobile','.p-account-address-book .buttonBox','padding-right','0','','','.p-account-address-book'),(132515,'printshop-mobile','.p-account-address-book .rightMes ul','padding-right','0','','','.p-account-address-book'),(132516,'printshop-mobile','.p-account-address-book .btn-edit','padding-right','0','4','','.p-account-address-book'),(132517,'printshop-mobile','.p-account-address-book .address_book h2','padding-right','10','','','.p-account-address-book'),(132518,'printshop-mobile','.p-account-address-book .address_book','padding-right','0','','','.p-account-address-book'),(132519,'printshop-mobile','.p-account-address-book .address_book h1','padding-right','0','','','.p-account-address-book'),(132520,'printshop-mobile','.p-account-address-book .address_book, .p-account-address-book .account_history_info','padding-right','0','','','.p-account-address-book'),(132521,'printshop-mobile','.b-compare .col-gender','padding-right','0','','','.b-compare'),(132522,'printshop-mobile','.b-bottom .popup-heading','padding-right','15','','','.b-bottom'),(132523,'printshop-mobile','.b-compare .column_wrapper','padding-right','10','','','.b-compare'),(132524,'printshop-mobile','.b-compare .compare-box-item','padding-right','10','','','.b-compare'),(132525,'printshop-mobile','.b-compare .col-two label','padding-right','0','','','.b-compare'),(132526,'printshop-mobile','.b-compare .compare-head','padding-right','10','','','.b-compare'),(132527,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','padding-right','5','','','.b-switch'),(132528,'printshop-mobile','.w-languages .lang-link','padding-right','10','702','','.w-languages'),(132529,'printshop-mobile','.w-tabs .accordion-heading','padding-right','6','','','.w-tabs'),(132530,'printshop-mobile','.w-quote .cart-box-link','padding-right','14','702','','.w-quote'),(132531,'printshop-mobile','.w-currencies .select-link','padding-right','10','702','','.w-currencies'),(132532,'printshop-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','702','','.w-menu-horizontal'),(132533,'printshop-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','706','','.w-menu-style-1'),(132534,'printshop-mobile','.w-languages .current','padding-right','27','702','','.w-languages'),(132535,'printshop-mobile','.w-currencies .current','padding-right','27','702','','.w-currencies'),(132536,'printshop-mobile','.b-slick button.slick-prev','padding-right','4','3','','.b-slick'),(132537,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-right','18','706','','.w-list-type-1'),(132538,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','706','','.w-menu-style-1'),(132539,'printshop-mobile','.b-bottom .footerTitle','padding-right','0','693','','.b-bottom'),(132540,'printshop-mobile','.p-account-history-info .history_info > div + div','padding-right','0','694','','.p-account-history-info'),(132541,'printshop-mobile','.p-account-history-info .history_info > div','padding-right','0','694','','.p-account-history-info'),(132542,'printshop-mobile','.w-cart .cart-content','padding-right','15','','','.w-cart'),(132543,'printshop-mobile','.w-cart .cart-total','padding-right','0','','','.w-cart'),(132544,'printshop-mobile','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(132545,'printshop-mobile','.b-product-images .additional-vertical','padding-right','150','','','.b-product-images'),(132546,'printshop-mobile','.w-bestsellers .heading-3','padding-right','0','','','.w-bestsellers'),(132547,'printshop-mobile','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(132548,'printshop-mobile','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(132549,'printshop-mobile','.w-breadcrumb .breadcrumb-li','padding-right','0','','','.w-breadcrumb'),(132550,'printshop-mobile','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-right','10','695','',''),(132551,'printshop-mobile','.w-top-categories .image','padding-right','0','','','.w-top-categories'),(132552,'printshop-mobile','.w-account a.my-acc-link','padding-right','17','','','.w-account'),(132553,'printshop-mobile','.p-account-index .topAccount > li > div','padding-right','0','693','','.p-account-index'),(132554,'printshop-mobile','.p-account-trade-form .trade-form-area','padding-right','20','','','.p-account-trade-form'),(132555,'printshop-mobile','.p-account-trade-form .widget','padding-right','0','','','.p-account-trade-form'),(132556,'printshop-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-right','0','','','.p-blog-index'),(132557,'printshop-mobile','.p-blog-index .nav-links','padding-right','0','','','.p-blog-index'),(132558,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-right','10','','','.p-blog-index'),(132559,'printshop-mobile','.p-blog-index .wp-widget ul','padding-right','0','','','.p-blog-index'),(132560,'printshop-mobile','.p-blog-index .wp-widget li','padding-right','0','','','.p-blog-index'),(132561,'printshop-mobile','.p-checkout-index .shipping-method .item','padding-right','0','','','.p-checkout-index'),(132562,'printshop-mobile','.p-checkout-index .shipping-method .title','padding-right','5','','','.p-checkout-index'),(132563,'printshop-mobile','.p-reviews-info .review-info-content','padding-right','20','','','.p-reviews-info'),(132564,'printshop-mobile','.p-checkout-index .shipping-method .row','padding-right','5','','','.p-checkout-index'),(132565,'printshop-mobile','.p-reviews-info .review-info-text','padding-right','10','','','.p-reviews-info'),(132566,'printshop-mobile','.p-reviews-info .review-info-image','padding-right','20','','','.p-reviews-info'),(132567,'printshop-mobile','.p-reviews-info .reviews-info .buttons','padding-right','0','','','.p-reviews-info'),(132568,'printshop-mobile','.p-shopping-cart-index .cart-popup .cart-page, .p-shopping-cart-index .cart-popup .wishlist-page','padding-right','20','','','.p-shopping-cart-index'),(132569,'printshop-mobile','.p-account-index .account_info li','padding-right','0','693','','.p-account-index'),(132570,'printshop-mobile','.p-account-index .topAccount > li','padding-right','0','693','','.p-account-index'),(132571,'printshop-mobile','.w-product-images .images','padding-right','0','723','','.w-product-images'),(132572,'printshop-mobile','.w-filters .handle_tit','padding-right','5','','','.w-filters'),(132573,'printshop-mobile','.b-slick .slick-vertical button.slick-next','padding-right','0','3','','.b-slick'),(132574,'printshop-mobile','.b-slick .slick-vertical button.slick-prev','padding-right','0','3','','.b-slick'),(132575,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-right','20','','','.b-fancybox'),(132576,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-right','10','','','.p-account-subscription-historyinfo'),(132577,'printshop-mobile','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(132578,'printshop-mobile','.p-account-index th','padding-right','15','','','.p-account-index'),(132579,'printshop-mobile','.p-account-index .view_link','padding-right','20','','','.p-account-index'),(132580,'printshop-mobile','.p-account-index .topAccount','padding-right','19','','','.p-account-index'),(132581,'printshop-mobile','.w-list-type-1 ','padding-right','0','','','.w-list-type-1'),(132582,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','padding-right','15','','','.w-list-type-1_3'),(132583,'printshop-mobile','.w-list-type-1 .item','padding-right','5','','','.w-list-type-1'),(132584,'printshop-mobile','.w-list-type-1_2.products-listing','padding-right','20','','','.w-list-type-1_2'),(132585,'printshop-mobile','.w-list-type-1 .compare-box-item','padding-right','7','','','.w-list-type-1'),(132586,'printshop-mobile','.w-list-type-1_2 .compare-box-item','padding-right','7','','','.w-list-type-1_2'),(132587,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-right','15','','','.w-list-type-1'),(132588,'printshop-mobile','.w-languages .lang-link','padding-right','10','','','.w-languages'),(132589,'printshop-mobile','.w-languages .current','padding-right','27','','','.w-languages'),(132590,'printshop-mobile','.w-filters .head-filter-widget','padding-right','0','','','.w-filters'),(132591,'printshop-mobile','.b-fancybox .fancybox-title-over-wrap','padding-right','10','','','.b-fancybox'),(132592,'printshop-mobile','.p-quote-cart-index .cart-popup .cart-page, .p-quote-cart-index .cart-popup .wishlist-page','padding-right','20','','','.p-quote-cart-index'),(132593,'printshop-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-right','0','','','.b-fancybox'),(132594,'printshop-mobile','.w-categories .image','padding-right','0','','','.w-categories'),(132595,'printshop-mobile','.w-categories .item','padding-right','20','','','.w-categories'),(132596,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','padding-right','15','','','.w-list-type-1_2'),(132597,'printshop-mobile','.w-cart a.item','padding-right','0','','','.w-cart'),(132598,'printshop-mobile','.w-cart .cart-box-link','padding-right','14','','','.w-cart'),(132599,'printshop-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(132600,'printshop-mobile','.b-compare .popupCompare .pop-up-content','padding-right','10','','','.b-compare'),(132601,'printshop-mobile','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(132602,'printshop-mobile','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(132603,'printshop-mobile','.w-product-reviews .reviews-list .review','padding-right','10','','','.w-product-reviews'),(132604,'printshop-mobile','.w-product-sale-ends .left-count','padding-right','5','','','.w-product-sale-ends'),(132605,'printshop-mobile','.w-reviews .heading-3','padding-right','0','','','.w-reviews'),(132606,'printshop-mobile','.w-reviews .review','padding-right','10','','','.w-reviews'),(132607,'printshop-mobile','.w-sale .left-count','padding-right','5','','','.w-sale'),(132608,'printshop-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(132609,'printshop-mobile','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(132610,'printshop-mobile','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(132611,'printshop-mobile','.w-product-properties li','padding-right','5','','','.w-product-properties'),(132612,'printshop-mobile','.w-product-configurator .pc_item','padding-right','20','','','.w-product-configurator'),(132613,'printshop-mobile','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(132614,'printshop-mobile','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(132615,'printshop-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(132616,'printshop-mobile','.w-menu-style-1 ul','padding-right','0','','','.w-menu-style-1'),(132617,'printshop-mobile','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(132618,'printshop-mobile','.b-fancybox .fancybox-prev span','padding-right','4','3','','.b-fancybox'),(132619,'printshop-mobile','.p-wedding-registry-share .add-row','padding-right','40','','','.p-wedding-registry-share'),(132620,'printshop-mobile','.p-wedding-registry-share .address-row','padding-right','40','','','.p-wedding-registry-share'),(132621,'printshop-mobile','.w-tabs .accordion-heading','padding-right','8','693','','.w-tabs'),(132622,'printshop-mobile','.w-top-categories .categories h2','padding-right','0','','','.w-top-categories'),(132623,'printshop-mobile','.w-categories .categories h2','padding-right','0','','','.w-categories'),(132624,'printshop-mobile','.w-banner .carousel-text > span','padding-right','20','','','.w-banner'),(132625,'printshop-mobile','.b-form .terms-login','padding-right','80','','','.b-form'),(132626,'printshop-mobile','.b-slick .slick-list','padding-right','0','','','.b-slick'),(132627,'printshop-mobile','.w-tabs .tab-li','padding-right','0','','','.w-tabs'),(132628,'printshop-mobile','.w-tabs .tab-a','padding-right','6','','','.w-tabs'),(132629,'printshop-mobile','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(132630,'printshop-mobile','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(132631,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-right','10','','','.w-menu-horizontal'),(132632,'printshop-mobile','.w-cart .qty','padding-right','5','4','','.w-cart'),(132633,'printshop-mobile','.w-account ul, .w-account li','padding-right','0','','','.w-account'),(132634,'printshop-mobile','.p-account-index .account_info .info .info_span','padding-right','5','','','.p-account-index'),(132635,'printshop-mobile','.w-categories .item','padding-right','10','693','','.w-categories'),(132636,'printshop-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-right','0','','','.b-fancybox'),(132637,'printshop-mobile','.w-cart-give-away .ga_img','padding-right','1','','','.w-cart-give-away'),(132638,'printshop-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-right','6','','','.b-compare'),(132639,'printshop-mobile','.w-search .search form','padding-right','5','','','.w-search'),(132640,'printshop-mobile','.w-list-type-2 .button-view a','padding-right','10','','','.w-list-type-2'),(132641,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','padding-right','10','','',''),(132642,'printshop-mobile','.b-autocomplete .ui-autocomplete','padding-right','0','','','.b-autocomplete'),(132643,'printshop-mobile','textarea','padding-right','10','','',''),(132644,'printshop-mobile','.b-autocomplete .ui-autocomplete li','padding-right','10','','','.b-autocomplete'),(132645,'printshop-mobile','.w-list-type-1_3 .button-view a','padding-right','10','','','.w-list-type-1_3'),(132646,'printshop-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-right','20','','','.b-bottom'),(132647,'printshop-mobile','.w-list-type-1_2 .button-view a','padding-right','10','','','.w-list-type-1_2'),(132648,'printshop-mobile','.b-bottom .pop-up-close','padding-right','1','','','.b-bottom'),(132649,'printshop-mobile','.b-bottom .pop-up-info','padding-right','20','','','.b-bottom'),(132650,'printshop-mobile','.b-bottom .popup-box-wrap','padding-right','10','','','.b-bottom'),(132651,'printshop-mobile','.w-list-type-1 .button-view a','padding-right','10','','','.w-list-type-1'),(132652,'printshop-mobile','.b-form .center-buttons','padding-right','0','','','.b-form'),(132653,'printshop-mobile','.w-reviews .name','padding-right','10','','','.w-reviews'),(132654,'printshop-mobile','.w-reviews .reviews','padding-right','10','','','.w-reviews'),(132655,'printshop-mobile','.w-reviews .reviews-list .name','padding-right','10','','','.w-reviews'),(132656,'printshop-mobile','.w-top-categories .item','padding-right','20','','','.w-top-categories'),(132657,'printshop-mobile','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block','padding-right','10','695','',''),(132658,'printshop-mobile','.p-account-index .account_info','padding-right','0','706','','.p-account-index'),(132659,'printshop-mobile','.w-tabs .tab-navigation','padding-right','0','','','.w-tabs'),(132660,'printshop-mobile','.w-top-categories .name','padding-right','3','','','.w-top-categories'),(132661,'printshop-mobile','.b-form .middle-form','padding-right','0','','','.b-form'),(132662,'printshop-mobile','.b-form .payment-method .item-radio label','padding-right','5','','','.b-form'),(132663,'printshop-mobile','.b-form .shipping-method .input','padding-right','10','','','.b-form'),(132664,'printshop-mobile','.b-form .required-message','padding-right','3','','','.b-form'),(132665,'printshop-mobile','.b-form .required-message-wrap','padding-right','0','','','.b-form'),(132666,'printshop-mobile','.b-info .info','padding-right','0','','','.b-info'),(132667,'printshop-mobile','.b-info .info li','padding-right','0','','','.b-info'),(132668,'printshop-mobile','.b-info .info ul','padding-right','0','','','.b-info'),(132669,'printshop-mobile','.p-account-index .topAccount > li','padding-right','2','','','.p-account-index'),(132670,'printshop-mobile','.b-products-listing .in-cart','padding-right','10','','','.b-products-listing'),(132671,'printshop-mobile','.b-products-listing .products-listing .btn-buy','padding-right','10','','','.b-products-listing'),(132672,'printshop-mobile','.b-products-listing .products-listing .buyButton .btn','padding-right','10','','','.b-products-listing'),(132673,'printshop-mobile','.b-products-listing .products-listing .compare','padding-right','6','','','.b-products-listing'),(132674,'printshop-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-right','2','','','.b-products-listing'),(132675,'printshop-mobile','.b-products-listing .products-listing a.btn.view-button','padding-right','0','','','.b-products-listing'),(132676,'printshop-mobile','.b-products-listing .products-listing h2','padding-right','0','','','.b-products-listing'),(132677,'printshop-mobile','.b-products-listing .promos-info .promo-item','padding-right','10','','','.b-products-listing'),(132678,'printshop-mobile','.b-products-listing .promos-info .promo-name','padding-right','15','','','.b-products-listing'),(132679,'printshop-mobile','.b-products-listing .list-productlisting div.BlockBox.item-holder','padding-right','10','','','.b-products-listing'),(132680,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.b-data-table'),(132681,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.b-data-table'),(132682,'printshop-mobile','.b-data-table table.dataTable thead td','padding-right','20','','','.b-data-table'),(132683,'printshop-mobile','.b-data-table table.dataTable tbody td','padding-right','20','','','.b-data-table'),(132684,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(132685,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(132686,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(132687,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(132688,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(132689,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(132690,'printshop-mobile','.b-email .qty','padding-right','10','','','.b-email'),(132691,'printshop-mobile','.b-email .price','padding-right','10','','','.b-email'),(132692,'printshop-mobile','.b-email .price','padding-right','10','','','.b-email'),(132693,'printshop-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(132694,'printshop-mobile','.b-email .model','padding-right','10','','','.b-email'),(132695,'printshop-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(132696,'printshop-mobile','.b-email .model','padding-right','10','','','.b-email'),(132697,'printshop-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(132698,'printshop-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(132699,'printshop-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(132700,'printshop-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(132701,'printshop-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(132702,'printshop-mobile','.b-email .image','padding-right','10','','','.b-email'),(132703,'printshop-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(132704,'printshop-mobile','.b-email .price','padding-right','10','','','.b-email'),(132705,'printshop-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(132706,'printshop-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(132707,'printshop-mobile','.b-email .qty','padding-right','10','','','.b-email'),(132708,'printshop-mobile','.b-email .name','padding-right','10','','','.b-email'),(132709,'printshop-mobile','.b-email .name','padding-right','10','','','.b-email'),(132710,'printshop-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(132711,'printshop-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(132712,'printshop-mobile','.b-email .price','padding-right','10','','','.b-email'),(132713,'printshop-mobile','.b-email .model','padding-right','10','','','.b-email'),(132714,'printshop-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(132715,'printshop-mobile','.b-email .model','padding-right','10','','','.b-email'),(132716,'printshop-mobile','.b-email .price','padding-right','10','','','.b-email'),(132717,'printshop-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(132718,'printshop-mobile','.b-email .image','padding-right','10','','','.b-email'),(132719,'printshop-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(132720,'printshop-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(132721,'printshop-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(132722,'printshop-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(132723,'printshop-mobile','.b-email .image','padding-right','10','','','.b-email'),(132724,'printshop-mobile','.b-email .name','padding-right','10','','','.b-email'),(132725,'printshop-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(132726,'printshop-mobile','.b-email .image','padding-right','10','','','.b-email'),(132727,'printshop-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(132728,'printshop-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(132729,'printshop-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(132730,'printshop-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(132731,'printshop-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(132732,'printshop-mobile','.b-email .name','padding-right','10','','','.b-email'),(132733,'printshop-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(132734,'printshop-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(132735,'printshop-mobile','.b-email .image','padding-right','10','','','.b-email'),(132736,'printshop-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(132737,'printshop-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(132738,'printshop-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(132739,'printshop-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(132740,'printshop-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(132741,'printshop-mobile','.b-email .qty','padding-right','10','','','.b-email'),(132742,'printshop-mobile','.b-email .name','padding-right','10','','','.b-email'),(132743,'printshop-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(132744,'printshop-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(132745,'printshop-mobile','.b-email .model','padding-right','10','','','.b-email'),(132746,'printshop-mobile','.b-email .price','padding-right','10','','','.b-email'),(132747,'printshop-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(132748,'printshop-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(132749,'printshop-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(132750,'printshop-mobile','.b-email .qty','padding-right','10','','','.b-email'),(132751,'printshop-mobile','.b-email .image','padding-right','10','','','.b-email'),(132752,'printshop-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(132753,'printshop-mobile','.b-email .name','padding-right','10','','','.b-email'),(132754,'printshop-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(132755,'printshop-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(132756,'printshop-mobile','.b-email .qty','padding-right','10','','','.b-email'),(132757,'printshop-mobile','.b-email .model','padding-right','10','','','.b-email'),(132758,'printshop-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(132759,'printshop-mobile','.b-email .qty','padding-right','10','','','.b-email'),(132760,'printshop-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(132761,'printshop-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(132762,'printshop-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(132763,'printshop-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(132764,'printshop-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(132765,'printshop-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(132766,'printshop-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(132767,'printshop-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(132768,'printshop-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(132769,'printshop-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(132770,'printshop-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(132771,'printshop-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(132772,'printshop-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(132773,'printshop-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(132774,'printshop-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(132775,'printshop-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(132776,'printshop-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(132777,'printshop-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(132778,'printshop-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(132779,'printshop-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(132780,'printshop-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(132781,'printshop-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(132782,'printshop-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(132783,'printshop-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(132784,'printshop-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(132785,'printshop-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(132786,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-right','0','','','.b-h-inline'),(132787,'printshop-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-right','0','','','.b-menu-style'),(132788,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-right','5','','','.b-menu-style-1'),(132789,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-right','20','','','.b-menu-style-1'),(132790,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-right','20','','','.b-menu-style-1'),(132791,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-right','20','','','.b-menu-style-1'),(132792,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-right','20','','','.b-menu-style-2'),(132793,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-right','20','','','.b-menu-style-2'),(132794,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-right','0','','','.b-menu-style-2'),(132795,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-right','0','','','.b-menu-style-2'),(132796,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-right','20','','','.b-menu-style-2'),(132797,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-right','0','','','.b-menu-style-2'),(132798,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-right','20','','','.b-menu-style-2'),(132799,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-right','20','','','.b-menu-style-2'),(132800,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-right','50','','','.b-menu-style-2'),(132801,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-right','30','','','.b-menu-style-2'),(132802,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-right','5','','','.b-menu-style-3'),(132803,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','padding-right','20','','','.b-menu-style-3'),(132804,'printshop-mobile','.b-messages .emailLineTextArea textarea','padding-right','10','','','.b-messages'),(132805,'printshop-mobile','.b-messages .msv_btn','padding-right','0','','','.b-messages'),(132806,'printshop-mobile','.b-messages .msv_content','padding-right','20','','','.b-messages'),(132807,'printshop-mobile','.b-messages .development-content .type-6 .content','padding-right','40','','','.b-messages'),(132808,'printshop-mobile','.b-messages .msv_history','padding-right','20','','','.b-messages'),(132809,'printshop-mobile','.b-messages .messMenuButton span','padding-right','15','','','.b-messages'),(132810,'printshop-mobile','.b-messages .messages-menu ul','padding-right','0','','','.b-messages'),(132811,'printshop-mobile','.b-messages .messages-menu li a','padding-right','0','','','.b-messages'),(132812,'printshop-mobile','.b-messages .messages-menu li','padding-right','0','','','.b-messages'),(132813,'printshop-mobile','.b-messages .content_management_attach button','padding-right','27','','','.b-messages'),(132814,'printshop-mobile','.b-messages .email-heading','padding-right','15','','','.b-messages'),(132815,'printshop-mobile','.b-messages .content_management_attach','padding-right','8','','','.b-messages'),(132816,'printshop-mobile','.b-messages .emailBtn','padding-right','10','','','.b-messages'),(132817,'printshop-mobile','.b-messages .msv_to_cc','padding-right','15','','','.b-messages'),(132818,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-right','10','','','.b-messages'),(132819,'printshop-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-right','0','','','.b-personal-catalog-popup'),(132820,'printshop-mobile','.b-select-suggest .select2-search input','padding-right','20','','','.b-select-suggest'),(132821,'printshop-mobile','.b-select-suggest .select2-search','padding-right','4','','','.b-select-suggest'),(132822,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','padding-right','0','','','.b-select-suggest'),(132823,'printshop-mobile','.b-select-suggest .select2-drop-mask','padding-right','0','','','.b-select-suggest'),(132824,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-right','0','','','.b-select-suggest'),(132825,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(132826,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(132827,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-right','0','','','.b-select-suggest'),(132828,'printshop-mobile','.b-select-suggest .select2-locked','padding-right','5','','','.b-select-suggest'),(132829,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-right','0','','','.b-select-suggest'),(132830,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-right','5','','','.b-select-suggest'),(132831,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','padding-right','7','','','.b-select-suggest'),(132832,'printshop-mobile','.b-select-suggest .select2-results','padding-right','4','','','.b-select-suggest'),(132833,'printshop-mobile','.b-sub-totals .historyTotal td','padding-right','5','','','.b-sub-totals'),(132834,'printshop-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(132835,'printshop-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(132836,'printshop-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(132837,'printshop-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(132838,'printshop-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(132839,'printshop-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(132840,'printshop-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(132841,'printshop-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(132842,'printshop-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(132843,'printshop-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(132844,'printshop-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(132845,'printshop-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(132846,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(132847,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(132848,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(132849,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(132850,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(132851,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(132852,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(132853,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(132854,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(132855,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(132856,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(132857,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(132858,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(132859,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(132860,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(132861,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(132862,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(132863,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(132864,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(132865,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(132866,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(132867,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(132868,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(132869,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(132870,'printshop-mobile','.b-trade-approval .steps-bar li a','padding-right','0','','','.b-trade-approval'),(132871,'printshop-mobile','.b-trade-approval .middle-form','padding-right','0','','','.b-trade-approval'),(132872,'printshop-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-right','5','','','.b-trade-approval'),(132873,'printshop-mobile','.b-trade-approval .steps-bar','padding-right','0','','','.b-trade-approval'),(132874,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-right','10','','','.b-trade-approval'),(132875,'printshop-mobile','.b-trade-approval .center-buttons','padding-right','0','','','.b-trade-approval'),(132876,'printshop-mobile','.b-upload-file .upload-file-template','padding-right','1','','','.b-upload-file'),(132877,'printshop-mobile','.b-upload-files .added-file','padding-right','0','','','.b-upload-files'),(132878,'printshop-mobile','.b-upload-files .upload-files','padding-right','10','','','.b-upload-files'),(132879,'printshop-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-right','20','','','.b-warehouses-popup'),(132880,'printshop-mobile','.batchPr .w-batch-products .products-listing .image','padding-right','15','','','.batchPr'),(132881,'printshop-mobile','.batchPr .w-batch-products','padding-right','0','','','.batchPr'),(132882,'printshop-mobile','.batchPr > .block:nth-child(2)','padding-right','0','','','.batchPr'),(132883,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-right','0','','','.batchPr'),(132884,'printshop-mobile','.batchPr .w-batch-selected-products','padding-right','15','','','.batchPr'),(132885,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-right','0','','','.batchPr'),(132886,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-right','15','','','.batchPr'),(132887,'printshop-mobile','.batchPr .w-batch-selected-products .item','padding-right','40','','','.batchPr'),(132888,'printshop-mobile','.batchPr ','padding-right','0','','','.batchPr'),(132889,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-right','0','','','.batchPr'),(132890,'printshop-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-right','0','','','.batchPr'),(132891,'printshop-mobile','.batchPr .w-batch-products .products-listing .image','padding-right','0','','','.batchPr'),(132892,'printshop-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(132893,'printshop-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(132894,'printshop-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(132895,'printshop-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(132896,'printshop-mobile','.p-account-samples-history .view_link','padding-right','20','','','.p-account-samples-history'),(132897,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-right','10','','','.p-account-samples-history'),(132898,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-right','10','','','.p-account-samples-history'),(132899,'printshop-mobile','.p-account-samples-history .view_link','padding-right','20','','','.p-account-samples-history'),(132900,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-right','10','','','.p-account-samples-history'),(132901,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-right','10','','','.p-account-samples-history'),(132902,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-right','10','','','.p-account-samples-history'),(132903,'printshop-mobile','.p-account-samples-history .orders-table td','padding-right','10','','','.p-account-samples-history'),(132904,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-right','10','','','.p-account-samples-history'),(132905,'printshop-mobile','.p-account-samples-history .orders-table th','padding-right','10','','','.p-account-samples-history'),(132906,'printshop-mobile','.p-account-samples-history .orders-table td','padding-right','10','','','.p-account-samples-history'),(132907,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-right','10','','','.p-account-samples-history'),(132908,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-right','10','','','.p-account-samples-history'),(132909,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-right','10','','','.p-account-samples-history'),(132910,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-right','10','','','.p-account-samples-history'),(132911,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-right','10','','','.p-account-samples-history'),(132912,'printshop-mobile','.p-account-samples-history .orders-table td','padding-right','10','','','.p-account-samples-history'),(132913,'printshop-mobile','.p-account-samples-history .view_link','padding-right','20','','','.p-account-samples-history'),(132914,'printshop-mobile','.p-account-samples-history .orders-table td','padding-right','10','','','.p-account-samples-history'),(132915,'printshop-mobile','.p-account-samples-history .orders-table th','padding-right','10','','','.p-account-samples-history'),(132916,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-right','10','','','.p-account-samples-history'),(132917,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-right','10','','','.p-account-samples-history'),(132918,'printshop-mobile','.p-account-samples-history .view_link','padding-right','20','','','.p-account-samples-history'),(132919,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-right','10','','','.p-account-samples-history'),(132920,'printshop-mobile','.p-account-samples-history .orders-table th','padding-right','10','','','.p-account-samples-history'),(132921,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-right','10','','','.p-account-samples-history'),(132922,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-right','10','','','.p-account-samples-history'),(132923,'printshop-mobile','.p-account-samples-history .orders-table th','padding-right','10','','','.p-account-samples-history'),(132924,'printshop-mobile','.p-account-samples-history .view_link','padding-right','20','','','.p-account-samples-history'),(132925,'printshop-mobile','.p-account-samples-history .orders-table td','padding-right','10','','','.p-account-samples-history'),(132926,'printshop-mobile','.p-account-samples-history .orders-table th','padding-right','10','','','.p-account-samples-history'),(132927,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-right','10','','','.p-account-samples-history'),(132928,'printshop-mobile','.p-account-samples-history .view_link','padding-right','20','','','.p-account-samples-history'),(132929,'printshop-mobile','.p-account-samples-history .orders-table th','padding-right','10','','','.p-account-samples-history'),(132930,'printshop-mobile','.p-account-samples-history .orders-table td','padding-right','10','','','.p-account-samples-history'),(132931,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-right','10','','','.p-account-samples-history'),(132932,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(132933,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-right','0','','','.p-account-samples-history-info'),(132934,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-right','0','','','.p-account-samples-history-info'),(132935,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(132936,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-right','0','','','.p-account-samples-history-info'),(132937,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(132938,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-right','0','','','.p-account-samples-history-info'),(132939,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(132940,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(132941,'printshop-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','padding-right','10','','','.p-account-samples-history-info'),(132942,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-right','0','','','.p-account-samples-history-info'),(132943,'printshop-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','padding-right','10','','','.p-account-samples-history-info'),(132944,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(132945,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-right','0','','','.p-account-samples-history-info'),(132946,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(132947,'printshop-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','padding-right','10','','','.p-account-samples-history-info'),(132948,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-right','10','','','.p-account-samples-history-info'),(132949,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-right','10','','','.p-account-samples-history-info'),(132950,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(132951,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-right','0','','','.p-account-samples-history-info'),(132952,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(132953,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-right','10','','','.p-account-samples-history-info'),(132954,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-right','10','','','.p-account-samples-history-info'),(132955,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-right','0','','','.p-account-samples-history-info'),(132956,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(132957,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-right','10','','','.p-account-samples-history-info'),(132958,'printshop-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','padding-right','10','','','.p-account-samples-history-info'),(132959,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-right','10','','','.p-account-samples-history-info'),(132960,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-right','10','','','.p-account-samples-history-info'),(132961,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(132962,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-right','0','','','.p-account-samples-history-info'),(132963,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-right','0','','','.p-account-samples-history-info'),(132964,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-right','0','','','.p-account-samples-history-info'),(132965,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-right','10','','','.p-account-samples-history-info'),(132966,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-right','10','','','.p-account-samples-history-info'),(132967,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-right','10','','','.p-account-samples-history-info'),(132968,'printshop-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','padding-right','10','','','.p-account-samples-history-info'),(132969,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(132970,'printshop-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','padding-right','10','','','.p-account-samples-history-info'),(132971,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-right','10','','','.p-account-samples-history-info'),(132972,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-right','0','','','.p-account-samples-history-info'),(132973,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-right','10','','','.p-account-samples-history-info'),(132974,'printshop-mobile','.p-catalog-product .prev-product','padding-right','20','','','.p-catalog-product'),(132975,'printshop-mobile','.p-catalog-product .next-product','padding-right','50','','','.p-catalog-product'),(132976,'printshop-mobile','.p-catalog-product .pn-image','padding-right','5','','','.p-catalog-product'),(132977,'printshop-mobile','.p-catalog-product .prev-product .pn-image','padding-right','2','3','','.p-catalog-product'),(132978,'printshop-mobile','.p-catalog-product .pn-direction','padding-right','4','','','.p-catalog-product'),(132979,'printshop-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-right','10','','','.p-quick-order-index'),(132980,'printshop-mobile','.p-quick-order-index .all-scroll-div','padding-right','0','','','.p-quick-order-index'),(132981,'printshop-mobile','.p-quick-order-index .bottom','padding-right','0','','','.p-quick-order-index'),(132982,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.p-quick-order-index'),(132983,'printshop-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-right','10','','','.p-quick-order-index'),(132984,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.p-quick-order-index'),(132985,'printshop-mobile','.p-quick-order-index ul.token-input-list','padding-right','0','','','.p-quick-order-index'),(132986,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(132987,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(132988,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(132989,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(132990,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(132991,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(132992,'printshop-mobile','.w-account-address-book .item','padding-right','10','','','.w-account-address-book'),(132993,'printshop-mobile','.w-account-address-book .btn-del','padding-right','7','','','.w-account-address-book'),(132994,'printshop-mobile','.w-account-address-book .wrap','padding-right','15','','','.w-account-address-book'),(132995,'printshop-mobile','.w-account-address-book .btn-edit','padding-right','7','','','.w-account-address-book'),(132996,'printshop-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-right','20','','','.w-account-addresses-list'),(132997,'printshop-mobile','.w-account-personal-catalog .list-switcher','padding-right','0','','','.w-account-personal-catalog'),(132998,'printshop-mobile','.w-account-personal-catalog .list-switcher a','padding-right','6','','','.w-account-personal-catalog'),(132999,'printshop-mobile','.w-account-subscription .subscription-variant','padding-right','10','','','.w-account-subscription'),(133000,'printshop-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-right','0','','','.w-blog-widget-most-popular-posts'),(133001,'printshop-mobile','.w-blog-widget-post-listing .post','padding-right','33','','','.w-blog-widget-post-listing'),(133002,'printshop-mobile','.w-blog-widget-post-listing .post_name','padding-right','0','','','.w-blog-widget-post-listing'),(133003,'printshop-mobile','.w-blog-widget-post-listing .post_view','padding-right','15','','','.w-blog-widget-post-listing'),(133004,'printshop-mobile','.w-blog-widget-post-listing .post','padding-right','15','','','.w-blog-widget-post-listing'),(133005,'printshop-mobile','.w-blog-widget-post-title h1','padding-right','0','','','.w-blog-widget-post-title'),(133006,'printshop-mobile','.w-blog-widget-post-title ','padding-right','0','','','.w-blog-widget-post-title'),(133007,'printshop-mobile','.w-blog-widget-related-posts ','padding-right','15','','','.w-blog-widget-related-posts'),(133008,'printshop-mobile','.w-blog-widget-related-posts .post','padding-right','15','','','.w-blog-widget-related-posts'),(133009,'printshop-mobile','.w-blog-widget-related-posts .post_content a','padding-right','20','','','.w-blog-widget-related-posts'),(133010,'printshop-mobile','.w-blog-widget-related-posts ','padding-right','0','','','.w-blog-widget-related-posts'),(133011,'printshop-mobile','.w-blog-widget-related-posts-by-category .post','padding-right','15','','','.w-blog-widget-related-posts-by-category'),(133012,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-right','20','','','.w-blog-widget-related-posts-by-category'),(133013,'printshop-mobile','.w-blog-widget-tag-cloud a','padding-right','13','','','.w-blog-widget-tag-cloud'),(133014,'printshop-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-right','0','','','.w-cart-cart-tabs'),(133015,'printshop-mobile','.w-cart-compare .attributes-label','padding-right','10','','','.w-cart-compare'),(133016,'printshop-mobile','.w-cart-compare .price-label','padding-right','10','','','.w-cart-compare'),(133017,'printshop-mobile','.w-cart-compare .price-cell','padding-right','20','','','.w-cart-compare'),(133018,'printshop-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-right','0','','','.w-cart-compare'),(133019,'printshop-mobile','.w-cart-compare .delete-cart','padding-right','10','','','.w-cart-compare'),(133020,'printshop-mobile','.w-cart-compare .attributes-cell','padding-right','20','','','.w-cart-compare'),(133021,'printshop-mobile','.w-cart-compare .cart-cell','padding-right','7','','','.w-cart-compare'),(133022,'printshop-mobile','.w-cart-compare .dropdown li','padding-right','10','','','.w-cart-compare'),(133023,'printshop-mobile','.w-cart-compare .product-label','padding-right','10','','','.w-cart-compare'),(133024,'printshop-mobile','.w-cart-compare .product','padding-right','15','','','.w-cart-compare'),(133025,'printshop-mobile','.w-cart-compare .atr-col','padding-right','30','','','.w-cart-compare'),(133026,'printshop-mobile','.w-cart-up-sell .w-list-type-1','padding-right','0','','','.w-cart-up-sell'),(133027,'printshop-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-right','21','','','.w-cart-up-sell'),(133028,'printshop-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-right','20','1','','.w-cart-up-sell'),(133029,'printshop-mobile','.w-catalog-additional-images li','padding-right','10','','','.w-catalog-additional-images'),(133030,'printshop-mobile','.w-catalog-additional-images ul','padding-right','0','','','.w-catalog-additional-images'),(133031,'printshop-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-right','5','','','.w-catalog-b2b-add-button'),(133032,'printshop-mobile','.w-catalog-compare td','padding-right','20','','','.w-catalog-compare'),(133033,'printshop-mobile','.w-catalog-compare .image','padding-right','10','','','.w-catalog-compare'),(133034,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','padding-right','5','2','','.w-catalog-compare'),(133035,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','padding-right','5','','','.w-catalog-compare'),(133036,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-right','0','','','.w-catalog-compare'),(133037,'printshop-mobile','.w-catalog-paging .paging-item','padding-right','2','','','.w-catalog-paging'),(133038,'printshop-mobile','.w-catalog-paging .next','padding-right','5','','','.w-catalog-paging'),(133039,'printshop-mobile','.w-catalog-paging .prev','padding-right','5','','','.w-catalog-paging'),(133040,'printshop-mobile','.w-catalog-paging ','padding-right','5','2','','.w-catalog-paging'),(133041,'printshop-mobile','.w-catalog-paging .next-pages','padding-right','5','','','.w-catalog-paging'),(133042,'printshop-mobile','.w-catalog-paging .prev-pages','padding-right','5','','','.w-catalog-paging'),(133043,'printshop-mobile','.w-catalog-paging .page-number','padding-right','5','','','.w-catalog-paging'),(133044,'printshop-mobile','.w-checkout-billing-address .same-address','padding-right','10','','','.w-checkout-billing-address'),(133045,'printshop-mobile','.w-checkout-billing-address .edit-ab','padding-right','0','','','.w-checkout-billing-address'),(133046,'printshop-mobile','.w-checkout-billing-address .addresses .address-item label','padding-right','10','','','.w-checkout-billing-address'),(133047,'printshop-mobile','.w-checkout-create-account .create-account','padding-right','0','','','.w-checkout-create-account'),(133048,'printshop-mobile','.w-checkout-gdpr .privacy-row','padding-right','0','','','.w-checkout-gdpr'),(133049,'printshop-mobile','.w-checkout-gdpr .terms-login','padding-right','0','','','.w-checkout-gdpr'),(133050,'printshop-mobile','.w-checkout-shipping .sub-item','padding-right','0','','','.w-checkout-shipping'),(133051,'printshop-mobile','.w-checkout-shipping-address .edit-ab','padding-right','0','','','.w-checkout-shipping-address'),(133052,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item label','padding-right','10','','','.w-checkout-shipping-address'),(133053,'printshop-mobile','.w-checkout-shipping-choice span','padding-right','0','','','.w-checkout-shipping-choice'),(133054,'printshop-mobile','.w-checkout-shipping-choice span','padding-right','10','','','.w-checkout-shipping-choice'),(133055,'printshop-mobile','.w-checkout-terms .required-message','padding-right','10','','','.w-checkout-terms'),(133056,'printshop-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-right','0','','','.w-communication-new-topic'),(133057,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-right','5','','','.w-communication-new-topic'),(133058,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-right','10','','','.w-communication-new-topic'),(133059,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-right','0','','','.w-communication-new-topic'),(133060,'printshop-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-right','10','','','.w-communication-new-topic'),(133061,'printshop-mobile','.w-communication-post .communication-post-author','padding-right','0','','','.w-communication-post'),(133062,'printshop-mobile','.w-delivery-day .left-count','padding-right','5','','','.w-delivery-day'),(133063,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-right','10','','','.w-image-maps'),(133064,'printshop-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-right','0','','','.w-multi-cart-actions'),(133065,'printshop-mobile','.w-personal-gift-status-bar .end-label','padding-right','30','','','.w-personal-gift-status-bar'),(133066,'printshop-mobile','.w-personal-gift-status-bar .start-label','padding-right','5','','','.w-personal-gift-status-bar'),(133067,'printshop-mobile','.w-personal-gift-status-bar .timeline','padding-right','10','','','.w-personal-gift-status-bar'),(133068,'printshop-mobile','.w-personal-gift-status-bar .end-date','padding-right','5','3','','.w-personal-gift-status-bar'),(133069,'printshop-mobile','.w-personal-gift-status-bar .inform','padding-right','5','4','','.w-personal-gift-status-bar'),(133070,'printshop-mobile','.w-product-available-in-warehouses .warehouse-item','padding-right','20','','','.w-product-available-in-warehouses'),(133071,'printshop-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(133072,'printshop-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(133073,'printshop-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(133074,'printshop-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(133075,'printshop-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(133076,'printshop-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(133077,'printshop-mobile','.w-product-customers-activity .customers-activity','padding-right','20','','','.w-product-customers-activity'),(133078,'printshop-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(133079,'printshop-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(133080,'printshop-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(133081,'printshop-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(133082,'printshop-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(133083,'printshop-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(133084,'printshop-mobile','.w-promotions .promo-cart-discount .master .item','padding-right','20','','','.w-promotions'),(133085,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-right','20','','','.w-promotions'),(133086,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-right','20','','','.w-promotions'),(133087,'printshop-mobile','.w-promotions .promo-item','padding-right','40','','','.w-promotions'),(133088,'printshop-mobile','.w-promotions .promo-date > div','padding-right','50','','','.w-promotions'),(133089,'printshop-mobile','.w-promotions .promo-cart-discount .slave .item','padding-right','20','','','.w-promotions'),(133090,'printshop-mobile','.w-promotions .promo-salemaker .discount','padding-right','20','','','.w-promotions'),(133091,'printshop-mobile','.w-promotions .promo-salemaker .item','padding-right','20','','','.w-promotions'),(133092,'printshop-mobile','.w-promotions .promo-salemaker .promo-categories','padding-right','12','','','.w-promotions'),(133093,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','padding-right','20','','','.w-promotions'),(133094,'printshop-mobile','.w-promotions .heading','padding-right','10','','','.w-promotions'),(133095,'printshop-mobile','.w-promotions .nextdiscount .promo-for-each','padding-right','20','','','.w-promotions'),(133096,'printshop-mobile','.w-promotions .prom-multi-discount .promo-product','padding-right','20','','','.w-promotions'),(133097,'printshop-mobile','.w-promotions .nextdiscount .content > div','padding-right','10','','','.w-promotions'),(133098,'printshop-mobile','.w-promotions .nextdiscount .item-holder .image','padding-right','10','','','.w-promotions'),(133099,'printshop-mobile','.w-promotions .master','padding-right','15','','','.w-promotions'),(133100,'printshop-mobile','.w-reviews-content .item','padding-right','0','','','.w-reviews-content'),(133101,'printshop-mobile','.w-reviews-content .author','padding-right','20','','','.w-reviews-content'),(133102,'printshop-mobile','.w-reviews-content .review','padding-right','20','','','.w-reviews-content'),(133103,'printshop-mobile','.w-reviews-content .product-image','padding-right','10','','','.w-reviews-content'),(133104,'printshop-mobile','.w-sitemap-delivery-location > ul','padding-right','0','','','.w-sitemap-delivery-location'),(133105,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-right','0','','','.w-sitemap-delivery-location'),(133106,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul > li','padding-right','20','','','.w-sitemap-delivery-location'),(133107,'printshop-mobile','.w-top-text .top-text','padding-right','10','','','.w-top-text'),(133108,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-right','17','','','.w-wedding-registry-widgets-photos'),(133109,'printshop-mobile','.b-quantity .qty-box input[type=\'text\']','padding-right','3','','','.b-quantity'),(133110,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right_important','important','','','.b-data-table'),(133111,'printshop-mobile','.b-data-table table.dataTable thead td','padding-right_important','important','','','.b-data-table'),(133112,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right_important','important','','','.b-data-table'),(133113,'printshop-mobile','.b-data-table table.dataTable tbody td','padding-right_important','important','','','.b-data-table'),(133114,'printshop-mobile','.batchPr .w-batch-products','padding-right_important','important','','','.batchPr'),(133115,'printshop-mobile','.w-list-type-2 .compare-box-item','padding-top','7','','','.w-list-type-2'),(133116,'printshop-mobile','.w-list-type-1_3 .compare-box-item','padding-top','7','','','.w-list-type-1_3'),(133117,'printshop-mobile','.w-list-type-1_3 .item','padding-top','20','1','','.w-list-type-1_3'),(133118,'printshop-mobile','.w-list-type-1_3 .item','padding-top','20','','','.w-list-type-1_3'),(133119,'printshop-mobile','.w-list-type-2 .item','padding-top','21','','','.w-list-type-2'),(133120,'printshop-mobile','.w-list-type-3.products-listing','padding-top','20','','','.w-list-type-3'),(133121,'printshop-mobile','.w-list-type-2.products-listing','padding-top','20','','','.w-list-type-2'),(133122,'printshop-mobile','.w-list-type-2_2 .compare-box-item','padding-top','7','','','.w-list-type-2_2'),(133123,'printshop-mobile','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(133124,'printshop-mobile','.w-list-type-2_2.products-listing','padding-top','20','','','.w-list-type-2_2'),(133125,'printshop-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','padding-top','0','','','.w-list-type-1_3'),(133126,'printshop-mobile','.w-menu .hided.menu ul li','padding-top','0','','','.w-menu'),(133127,'printshop-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-top','0','','','.w-menu'),(133128,'printshop-mobile','.w-catalog-listing-look .listing-look-title','padding-top','4','','','.w-catalog-listing-look'),(133129,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li','padding-top','2','','','.w-menu-horizontal'),(133130,'printshop-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','6','','','.w-menu-horizontal'),(133131,'printshop-mobile','.w-menu-big ul','padding-top','0','','','.w-menu-big'),(133132,'printshop-mobile','.w-menu-slider ul, .w-menu-slider li','padding-top','0','','','.w-menu-slider'),(133133,'printshop-mobile','.w-menu-slider > ul > li > ul > li','padding-top','5','','','.w-menu-slider'),(133134,'printshop-mobile','.w-menu-slider > ul > li > a','padding-top','5','','','.w-menu-slider'),(133135,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-top','0','','','.b-slick'),(133136,'printshop-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','6','','','.w-menu-style-1'),(133137,'printshop-mobile','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(133138,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(133139,'printshop-mobile','.b-bottom .popup-simple','padding-top','20','','','.b-bottom'),(133140,'printshop-mobile','.b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .buttons','padding-top','5','','','.b-cookie-notice'),(133141,'printshop-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.bottom .text','padding-top','10','','','.b-cookie-notice'),(133142,'printshop-mobile','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(133143,'printshop-mobile','.w-product-wedding-registry-button .btn','padding-top','0','','','.w-product-wedding-registry-button'),(133144,'printshop-mobile','.w-product-sale-ends .left-text-right','padding-top','24','','','.w-product-sale-ends'),(133145,'printshop-mobile','.w-product-sale-ends .left-text-left','padding-top','24','','','.w-product-sale-ends'),(133146,'printshop-mobile','.w-filters .ui-slider-range','padding-top','0','','','.w-filters'),(133147,'printshop-mobile','.w-currencies .select-link','padding-top','5','','','.w-currencies'),(133148,'printshop-mobile','.w-filters .fsl_handle','padding-top','20','','','.w-filters'),(133149,'printshop-mobile','.w-categories .name','padding-top','3','','','.w-categories'),(133150,'printshop-mobile','.w-currencies .current','padding-top','4','','','.w-currencies'),(133151,'printshop-mobile','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(133152,'printshop-mobile','.w-currencies .currencies-title','padding-top','3','','','.w-currencies'),(133153,'printshop-mobile','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(133154,'printshop-mobile','.w-top-categories .item','padding-top','5','693','','.w-top-categories'),(133155,'printshop-mobile','.p-account-history-info .contentColumn','padding-top','10','','','.p-account-history-info'),(133156,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','padding-top','5','','','.p-account-history-info'),(133157,'printshop-mobile','.p-account-history-info .historyTotal td','padding-top','2','','','.p-account-history-info'),(133158,'printshop-mobile','.p-account-index .account_info li','padding-top','0','','','.p-account-index'),(133159,'printshop-mobile','.p-account-history-info .history_info > div + div','padding-top','0','','','.p-account-history-info'),(133160,'printshop-mobile','.p-account-index .account_info','padding-top','0','','','.p-account-index'),(133161,'printshop-mobile','.p-account-index .account_block','padding-top','10','','','.p-account-index'),(133162,'printshop-mobile','.p-account-index .account_page','padding-top','10','','','.p-account-index'),(133163,'printshop-mobile','.p-account-index .orders-table th','padding-top','2','','','.p-account-index'),(133164,'printshop-mobile','.p-account-index .date_title','padding-top','5','','','.p-account-index'),(133165,'printshop-mobile','.p-account-index .badc_bottom','padding-top','0','','','.p-account-index'),(133166,'printshop-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','padding-top','10','','','.p-account-index'),(133167,'printshop-mobile','.p-account-index .topAccount','padding-top','24','','','.p-account-index'),(133168,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-top','10','','','.p-account-subscription-historyinfo'),(133169,'printshop-mobile','.b-bottom .popup-buttons','padding-top','15','','','.b-bottom'),(133170,'printshop-mobile','.b-price-box .checkout-index .price-box, .b-price-box .checkout-confirmation .price-box','padding-top','10','','','.b-price-box'),(133171,'printshop-mobile','.w-tabs .accordion-heading','padding-top','9','693','','.w-tabs'),(133172,'printshop-mobile','.w-product-quantity .product-quantity-label','padding-top','4','','','.w-product-quantity'),(133173,'printshop-mobile','.b-compare .compare_pagination','padding-top','10','','','.b-compare'),(133174,'printshop-mobile','.p-checkout-success .page-success .text-1','padding-top','5','693','','.p-checkout-success'),(133175,'printshop-mobile','.w-search .button-search','padding-top','6','','','.w-search'),(133176,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-top','20','','','.b-multi-page-checkout'),(133177,'printshop-mobile','.w-search .name','padding-top','0','','','.w-search'),(133178,'printshop-mobile','.w-sale .holder-2','padding-top','20','','','.w-sale'),(133179,'printshop-mobile','.w-search .items-title','padding-top','10','','','.w-search'),(133180,'printshop-mobile','.w-socials > li','padding-top','15','','','.w-socials'),(133181,'printshop-mobile','.w-search .item','padding-top','10','','','.w-search'),(133182,'printshop-mobile','.b-info-popup .info-popup div','padding-top','10','','','.b-info-popup'),(133183,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout','padding-top','20','','','.b-multi-page-checkout'),(133184,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-top','0','','','.b-multi-page-checkout'),(133185,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-top','8','','','.b-multi-page-checkout'),(133186,'printshop-mobile','.w-search .suggest','padding-top','0','','','.w-search'),(133187,'printshop-mobile','.w-promo-code .holder','padding-top','20','723','','.w-promo-code'),(133188,'printshop-mobile','.w-search .search-input','padding-top','5','','','.w-search'),(133189,'printshop-mobile','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(133190,'printshop-mobile','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(133191,'printshop-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','padding-top','5','','','.p-wedding-registry-manage'),(133192,'printshop-mobile','.p-wedding-registry-manage a.remove-btn','padding-top','5','','','.p-wedding-registry-manage'),(133193,'printshop-mobile','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(133194,'printshop-mobile','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(133195,'printshop-mobile','.p-account-history-info .popup-tracking-number','padding-top','10','','','.p-account-history-info'),(133196,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','padding-top','5','','','.p-account-order-pay'),(133197,'printshop-mobile','.p-account-order-pay .contentColumn','padding-top','10','','','.p-account-order-pay'),(133198,'printshop-mobile','.p-account-order-pay .historyTotal td','padding-top','2','','','.p-account-order-pay'),(133199,'printshop-mobile','.p-account-order-pay .history_attr','padding-top','5','','','.p-account-order-pay'),(133200,'printshop-mobile','.p-account-order-pay .history_info > div + div','padding-top','0','','','.p-account-order-pay'),(133201,'printshop-mobile','.w-filters .head-filter-widget','padding-top','0','720','','.w-filters'),(133202,'printshop-mobile','.p-account-order-pay .history_info > div','padding-top','0','694','','.p-account-order-pay'),(133203,'printshop-mobile','.w-product-configurator .pc_item','padding-top','10','702','','.w-product-configurator'),(133204,'printshop-mobile','.p-account-order-pay .history_info > div + div','padding-top','0','694','','.p-account-order-pay'),(133205,'printshop-mobile','.w-product-configurator .pc_attr','padding-top','5','693','','.w-product-configurator'),(133206,'printshop-mobile','.testimonials .heading-3','padding-top','7','','',''),(133207,'printshop-mobile','.testimonials .reviews-list .name','padding-top','5','','',''),(133208,'printshop-mobile','.testimonials .reviews-list .answer .name','padding-top','10','','',''),(133209,'printshop-mobile','.testimonials .name','padding-top','5','','',''),(133210,'printshop-mobile','.testimonials .review','padding-top','10','','',''),(133211,'printshop-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','padding-top','10','','','.p-account-history'),(133212,'printshop-mobile','.b-bottom .confirm-popup .confirm-text','padding-top','40','','','.b-bottom'),(133213,'printshop-mobile','.p-account-history .orders-table th','padding-top','2','','','.p-account-history'),(133214,'printshop-mobile','.p-account-history .view_link','padding-top','0','','','.p-account-history'),(133215,'printshop-mobile','.p-account-history .orders-table .td-alignright','padding-top','5','720','','.p-account-history'),(133216,'printshop-mobile','.p-account-history .orders-table td','padding-top','5','720','','.p-account-history'),(133217,'printshop-mobile','.btn','padding-top','8','','',''),(133218,'printshop-mobile','.p-account-index .orders-table .td-alignright','padding-top','5','720','','.p-account-index'),(133219,'printshop-mobile','.p-account-index .orders-table td','padding-top','5','720','','.p-account-index'),(133220,'printshop-mobile','.btn-1','padding-top','5','','',''),(133221,'printshop-mobile','.btn-2','padding-top','14','','',''),(133222,'printshop-mobile','.p-blog-index .comment-metadata','padding-top','4','','','.p-blog-index'),(133223,'printshop-mobile','.btn-3','padding-top','12','','',''),(133224,'printshop-mobile','.no-found','padding-top','20','','',''),(133225,'printshop-mobile','.w-list-type-2_2 .buttons','padding-top','3','','','.w-list-type-2_2'),(133226,'printshop-mobile','.w-list-type-2_2 .item','padding-top','20','','','.w-list-type-2_2'),(133227,'printshop-mobile','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(133228,'printshop-mobile','.w-product-personal-catalog-button .btn','padding-top','0','','','.w-product-personal-catalog-button'),(133229,'printshop-mobile','.b-fancybox .fancybox-error','padding-top','15','','','.b-fancybox'),(133230,'printshop-mobile','.w-menu-horizontal ul','padding-top','0','','','.w-menu-horizontal'),(133231,'printshop-mobile','.w-chat .w-chat-box','padding-top','2','','','.w-chat'),(133232,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-top','0','','','.w-delivery-location-top-location-list'),(133233,'printshop-mobile','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(133234,'printshop-mobile','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(133235,'printshop-mobile','.b-bottom .alert-message','padding-top','20','','','.b-bottom'),(133236,'printshop-mobile','.p-wedding-registry-index .main-content','padding-top','70','','','.p-wedding-registry-index'),(133237,'printshop-mobile','.p-wedding-registry-index .search-list','padding-top','20','','','.p-wedding-registry-index'),(133238,'printshop-mobile','.p-wedding-registry-index .middle-box','padding-top','30','','','.p-wedding-registry-index'),(133239,'printshop-mobile','.p-wedding-registry-index .main-button','padding-top','0','4','','.p-wedding-registry-index'),(133240,'printshop-mobile','.p-wedding-registry-index .main-button','padding-top','0','3','','.p-wedding-registry-index'),(133241,'printshop-mobile','.b-form .form-buttons','padding-top','17','','','.b-form'),(133242,'printshop-mobile','.p-wedding-registry-manage .wedding-image','padding-top','15','','','.p-wedding-registry-manage'),(133243,'printshop-mobile','.p-wedding-registry-manage .links','padding-top','10','','','.p-wedding-registry-manage'),(133244,'printshop-mobile','.p-wedding-registry-manage .links a','padding-top','0','','','.p-wedding-registry-manage'),(133245,'printshop-mobile','.p-wedding-registry-share .middle-form > input','padding-top','0','','','.p-wedding-registry-share'),(133246,'printshop-mobile','.p-wedding-registry-share .wedding-image','padding-top','15','','','.p-wedding-registry-share'),(133247,'printshop-mobile','.b-table .table td','padding-top','15','','','.b-table'),(133248,'printshop-mobile','.b-table .table .headings td','padding-top','5','','','.b-table'),(133249,'printshop-mobile','.p-account-address-book .address_book, .p-account-address-book .account_history_info','padding-top','10','','','.p-account-address-book'),(133250,'printshop-mobile','.p-account-history .order_history_table th','padding-top','10','','','.p-account-history'),(133251,'printshop-mobile','.header2 .ccc','padding-top','10','','',''),(133252,'printshop-mobile','.p-account-address-book .topButtons','padding-top','0','','','.p-account-address-book'),(133253,'printshop-mobile','.p-account-address-book .btn-edit','padding-top','0','4','','.p-account-address-book'),(133254,'printshop-mobile','.p-account-address-book .buttonBox','padding-top','15','','','.p-account-address-book'),(133255,'printshop-mobile','.p-account-address-book .rightMes ul','padding-top','22','','','.p-account-address-book'),(133256,'printshop-mobile','.p-account-address-book .address_book h1','padding-top','0','','','.p-account-address-book'),(133257,'printshop-mobile','.p-account-address-book .address_book','padding-top','0','','','.p-account-address-book'),(133258,'printshop-mobile','.p-account-address-book .address_book h2','padding-top','15','','','.p-account-address-book'),(133259,'printshop-mobile','.b-bottom .popup-heading','padding-top','10','','','.b-bottom'),(133260,'printshop-mobile','.b-compare .col-gender','padding-top','0','','','.b-compare'),(133261,'printshop-mobile','.b-compare .col-two label','padding-top','5','','','.b-compare'),(133262,'printshop-mobile','.b-compare .column_wrapper','padding-top','0','','','.b-compare'),(133263,'printshop-mobile','.b-compare .compare-box-item','padding-top','10','','','.b-compare'),(133264,'printshop-mobile','.b-compare .compare-head','padding-top','10','','','.b-compare'),(133265,'printshop-mobile','.w-quote .cart-box-link','padding-top','5','702','','.w-quote'),(133266,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-top','8','706','','.w-list-type-1'),(133267,'printshop-mobile','.w-tabs .accordion-heading','padding-top','6','','','.w-tabs'),(133268,'printshop-mobile','.w-languages .current','padding-top','12','702','','.w-languages'),(133269,'printshop-mobile','.w-languages .lang-link','padding-top','13','702','','.w-languages'),(133270,'printshop-mobile','.w-currencies .current','padding-top','13','702','','.w-currencies'),(133271,'printshop-mobile','.w-currencies .select-link','padding-top','12','702','','.w-currencies'),(133272,'printshop-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','12','702','','.w-menu-horizontal'),(133273,'printshop-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','12','706','','.w-menu-style-1'),(133274,'printshop-mobile','.b-fancybox .fancybox-title-inside-wrap','padding-top','10','','','.b-fancybox'),(133275,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-top','12','706','','.w-menu-style-1'),(133276,'printshop-mobile','.b-bottom .footerTitle','padding-top','9','693','','.b-bottom'),(133277,'printshop-mobile','.p-account-history-info .history_info > div + div','padding-top','0','694','','.p-account-history-info'),(133278,'printshop-mobile','.p-account-history-info .history_info > div','padding-top','0','694','','.p-account-history-info'),(133279,'printshop-mobile','.w-top-categories .name','padding-top','3','','','.w-top-categories'),(133280,'printshop-mobile','.w-cart .cart-total','padding-top','10','','','.w-cart'),(133281,'printshop-mobile','.w-breadcrumb .breadcrumb-li','padding-top','0','','','.w-breadcrumb'),(133282,'printshop-mobile','.w-cart .cart-content','padding-top','15','','','.w-cart'),(133283,'printshop-mobile','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(133284,'printshop-mobile','.w-list-type-1_2 .compare-box-item','padding-top','7','','','.w-list-type-1_2'),(133285,'printshop-mobile','.w-product-reviews .reviews-list .name','padding-top','5','','','.w-product-reviews'),(133286,'printshop-mobile','.b-form .center-buttons','padding-top','20','','','.b-form'),(133287,'printshop-mobile','.w-bestsellers .heading-3','padding-top','7','','','.w-bestsellers'),(133288,'printshop-mobile','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(133289,'printshop-mobile','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(133290,'printshop-mobile','.w-top-categories .image','padding-top','0','','','.w-top-categories'),(133291,'printshop-mobile','.w-account a.my-acc-link','padding-top','5','','','.w-account'),(133292,'printshop-mobile','.p-shopping-cart-index .cart-popup .cart-page, .p-shopping-cart-index .cart-popup .wishlist-page','padding-top','0','','','.p-shopping-cart-index'),(133293,'printshop-mobile','.p-account-trade-form .widget','padding-top','10','','','.p-account-trade-form'),(133294,'printshop-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-top','0','','','.p-blog-index'),(133295,'printshop-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-top','5','','','.p-blog-index'),(133296,'printshop-mobile','.p-blog-index .nav-links','padding-top','20','','','.p-blog-index'),(133297,'printshop-mobile','.p-blog-index .wp-widget li','padding-top','0','','','.p-blog-index'),(133298,'printshop-mobile','.p-checkout-index .shipping-method .row','padding-top','5','','','.p-checkout-index'),(133299,'printshop-mobile','.p-checkout-index .shipping-method .item','padding-top','10','','','.p-checkout-index'),(133300,'printshop-mobile','.p-blog-index .wp-widget ul','padding-top','0','','','.p-blog-index'),(133301,'printshop-mobile','.p-quote-cart-index .cart-page .empty','padding-top','100','','','.p-quote-cart-index'),(133302,'printshop-mobile','.p-quote-cart-index .cart-popup .cart-page, .p-quote-cart-index .cart-popup .wishlist-page','padding-top','0','','','.p-quote-cart-index'),(133303,'printshop-mobile','.p-reviews-info .review-info-text','padding-top','10','','','.p-reviews-info'),(133304,'printshop-mobile','.p-reviews-info .review-info-content','padding-top','20','','','.p-reviews-info'),(133305,'printshop-mobile','.p-reviews-info .review-info-image','padding-top','20','','','.p-reviews-info'),(133306,'printshop-mobile','.p-checkout-index .shipping-method .title','padding-top','0','','','.p-checkout-index'),(133307,'printshop-mobile','.p-reviews-info .reviews-info .buttons','padding-top','0','','','.p-reviews-info'),(133308,'printshop-mobile','.p-shopping-cart-index .cart-page .empty','padding-top','100','','','.p-shopping-cart-index'),(133309,'printshop-mobile','.p-account-index .topAccount > li > div','padding-top','0','693','','.p-account-index'),(133310,'printshop-mobile','.w-product-images .images','padding-top','10','723','','.w-product-images'),(133311,'printshop-mobile','.p-account-index .topAccount > li','padding-top','0','693','','.p-account-index'),(133312,'printshop-mobile','.p-account-index .account_info li','padding-top','0','693','','.p-account-index'),(133313,'printshop-mobile','.b-slick .slick-vertical button.slick-next','padding-top','0','3','','.b-slick'),(133314,'printshop-mobile','.b-slick .slick-vertical button.slick-prev','padding-top','0','3','','.b-slick'),(133315,'printshop-mobile','.p-account-trade-form .trade-form-area','padding-top','20','','','.p-account-trade-form'),(133316,'printshop-mobile','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(133317,'printshop-mobile','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(133318,'printshop-mobile','.b-info .info ul','padding-top','0','','','.b-info'),(133319,'printshop-mobile','.p-account-index .topAccount > li','padding-top','0','','','.p-account-index'),(133320,'printshop-mobile','.p-account-index th','padding-top','10','','','.p-account-index'),(133321,'printshop-mobile','.p-account-index .view_link','padding-top','0','','','.p-account-index'),(133322,'printshop-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','padding-top','0','','','.w-list-type-2'),(133323,'printshop-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','padding-top','0','','','.w-list-type-2_2'),(133324,'printshop-mobile','.w-list-type-1 ','padding-top','20','','','.w-list-type-1'),(133325,'printshop-mobile','.w-list-type-1 .item','padding-top','0','','','.w-list-type-1'),(133326,'printshop-mobile','.w-list-type-1_2.products-listing','padding-top','20','','','.w-list-type-1_2'),(133327,'printshop-mobile','.w-list-type-2 .item','padding-top','20','1','','.w-list-type-2'),(133328,'printshop-mobile','.w-list-type-1 .compare-box-item','padding-top','7','','','.w-list-type-1'),(133329,'printshop-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-top','0','','','.w-list-type-1'),(133330,'printshop-mobile','.w-languages .lang-link','padding-top','5','','','.w-languages'),(133331,'printshop-mobile','.w-languages .current','padding-top','3','','','.w-languages'),(133332,'printshop-mobile','.w-filters .head-filter-widget','padding-top','0','','','.w-filters'),(133333,'printshop-mobile','.w-filters .filter-ul-content','padding-top','0','','','.w-filters'),(133334,'printshop-mobile','.b-fancybox .fancybox-title-over-wrap','padding-top','10','','','.b-fancybox'),(133335,'printshop-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-top','0','','','.b-fancybox'),(133336,'printshop-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-top','0','','','.b-fancybox'),(133337,'printshop-mobile','.w-categories .image','padding-top','0','','','.w-categories'),(133338,'printshop-mobile','.w-categories .item','padding-top','5','','','.w-categories'),(133339,'printshop-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','padding-top','0','','','.w-list-type-1_2'),(133340,'printshop-mobile','.w-cart .cart-box-link','padding-top','5','','','.w-cart'),(133341,'printshop-mobile','.w-cart a.item','padding-top','5','','','.w-cart'),(133342,'printshop-mobile','.b-compare .popupCompare .pop-up-content','padding-top','0','','','.b-compare'),(133343,'printshop-mobile','.b-bottom .popup-content','padding-top','15','','','.b-bottom'),(133344,'printshop-mobile','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(133345,'printshop-mobile','.w-product-sale-ends .left-count','padding-top','5','','','.w-product-sale-ends'),(133346,'printshop-mobile','.w-sale .holder-1','padding-top','20','','','.w-sale'),(133347,'printshop-mobile','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(133348,'printshop-mobile','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(133349,'printshop-mobile','.w-product-reviews .reviews-list .review','padding-top','10','','','.w-product-reviews'),(133350,'printshop-mobile','.w-quote .cart-box-link','padding-top','5','','','.w-quote'),(133351,'printshop-mobile','.w-sale .left-count','padding-top','5','','','.w-sale'),(133352,'printshop-mobile','.w-reviews .review','padding-top','10','','','.w-reviews'),(133353,'printshop-mobile','.w-reviews .heading-3','padding-top','7','','','.w-reviews'),(133354,'printshop-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(133355,'printshop-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(133356,'printshop-mobile','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(133357,'printshop-mobile','.w-product-properties li','padding-top','5','','','.w-product-properties'),(133358,'printshop-mobile','.w-product-configurator .pc_item','padding-top','10','','','.w-product-configurator'),(133359,'printshop-mobile','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(133360,'printshop-mobile','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(133361,'printshop-mobile','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(133362,'printshop-mobile','.w-menu-style-1 ul','padding-top','0','','','.w-menu-style-1'),(133363,'printshop-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(133364,'printshop-mobile','.p-checkout-success .page-success .text-1','padding-top','120','','','.p-checkout-success'),(133365,'printshop-mobile','.w-sale .left-text-left','padding-top','24','','','.w-sale'),(133366,'printshop-mobile','.w-sale .left-text-right','padding-top','24','','','.w-sale'),(133367,'printshop-mobile','.w-sale .text','padding-top','10','','','.w-sale'),(133368,'printshop-mobile','.w-categories .categories h2','padding-top','0','','','.w-categories'),(133369,'printshop-mobile','.w-top-categories .categories h2','padding-top','0','','','.w-top-categories'),(133370,'printshop-mobile','.w-banner .carousel-text > span','padding-top','20','','','.w-banner'),(133371,'printshop-mobile','.b-slick .slick-list','padding-top','0','','','.b-slick'),(133372,'printshop-mobile','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(133373,'printshop-mobile','.w-tabs .tab-li','padding-top','0','','','.w-tabs'),(133374,'printshop-mobile','.w-tabs .tab-a','padding-top','6','','','.w-tabs'),(133375,'printshop-mobile','.w-cart .buttons','padding-top','15','','','.w-cart'),(133376,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-top','2','','','.w-menu-horizontal'),(133377,'printshop-mobile','.w-account ul, .w-account li','padding-top','0','','','.w-account'),(133378,'printshop-mobile','h1','padding-top','20','','',''),(133379,'printshop-mobile','.p-account-history-info .history_attr','padding-top','5','','','.p-account-history-info'),(133380,'printshop-mobile','.b-form .middle-form','padding-top','20','','','.b-form'),(133381,'printshop-mobile','.w-categories .item','padding-top','5','693','','.w-categories'),(133382,'printshop-mobile','.w-cart-give-away .ga_column','padding-top','15','','','.w-cart-give-away'),(133383,'printshop-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-top','4','','','.b-compare'),(133384,'printshop-mobile','.w-search .search form','padding-top','5','','','.w-search'),(133385,'printshop-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','padding-top','5','','',''),(133386,'printshop-mobile','.w-list-type-2 .buttons','padding-top','3','','','.w-list-type-2'),(133387,'printshop-mobile','.b-autocomplete .ui-autocomplete','padding-top','0','','','.b-autocomplete'),(133388,'printshop-mobile','textarea','padding-top','5','','',''),(133389,'printshop-mobile','.heading-3 .right-text, h3 .right-text','padding-top','3','','',''),(133390,'printshop-mobile','.b-autocomplete .ui-autocomplete li','padding-top','3','','','.b-autocomplete'),(133391,'printshop-mobile','.w-list-type-1_3 .buttons','padding-top','3','','','.w-list-type-1_3'),(133392,'printshop-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-top','0','','','.b-bottom'),(133393,'printshop-mobile','.w-list-type-1_2 .item','padding-top','20','','','.w-list-type-1_2'),(133394,'printshop-mobile','.w-list-type-1_2 .buttons','padding-top','3','','','.w-list-type-1_2'),(133395,'printshop-mobile','.b-bottom .pop-up-close','padding-top','1','','','.b-bottom'),(133396,'printshop-mobile','.w-list-type-1_2 .button-view','padding-top','1','','','.w-list-type-1_2'),(133397,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-top','2','','','.b-fancybox'),(133398,'printshop-mobile','.b-bottom .pop-up-info','padding-top','20','','','.b-bottom'),(133399,'printshop-mobile','.heading-3 .edit, h3 .edit','padding-top','2','','',''),(133400,'printshop-mobile','.w-list-type-1 .buttons','padding-top','3','','','.w-list-type-1'),(133401,'printshop-mobile','.heading-4 .edit, h4 .edit','padding-top','2','','',''),(133402,'printshop-mobile','.heading-4 .right-text, h4 .right-text','padding-top','4','','',''),(133403,'printshop-mobile','.b-bottom .popup-box-wrap','padding-top','10','','','.b-bottom'),(133404,'printshop-mobile','.w-reviews .name','padding-top','5','','','.w-reviews'),(133405,'printshop-mobile','.w-reviews .reviews-list .name','padding-top','5','','','.w-reviews'),(133406,'printshop-mobile','.p-account-index .account_info','padding-top','0','706','','.p-account-index'),(133407,'printshop-mobile','.w-top-categories .item','padding-top','5','','','.w-top-categories'),(133408,'printshop-mobile','.w-tabs > .block','padding-top','20','','','.w-tabs'),(133409,'printshop-mobile','.w-tabs .tab-navigation','padding-top','0','','','.w-tabs'),(133410,'printshop-mobile','.b-form .payment-method .item-radio label','padding-top','5','','','.b-form'),(133411,'printshop-mobile','.b-form .required-message-wrap','padding-top','0','','','.b-form'),(133412,'printshop-mobile','.b-form .shipping-method .input','padding-top','0','','','.b-form'),(133413,'printshop-mobile','.b-form .required-message','padding-top','0','','','.b-form'),(133414,'printshop-mobile','.b-info .info','padding-top','20','','','.b-info'),(133415,'printshop-mobile','.b-info .info li','padding-top','0','','','.b-info'),(133416,'printshop-mobile','.b-products-listing .in-cart','padding-top','5','','','.b-products-listing'),(133417,'printshop-mobile','.b-products-listing .products-listing .btn-buy','padding-top','5','','','.b-products-listing'),(133418,'printshop-mobile','.b-products-listing .products-listing .buyButton .btn','padding-top','5','','','.b-products-listing'),(133419,'printshop-mobile','.b-products-listing .products-listing .compare','padding-top','6','','','.b-products-listing'),(133420,'printshop-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-top','4','','','.b-products-listing'),(133421,'printshop-mobile','.b-products-listing .products-listing a.btn.view-button','padding-top','6','','','.b-products-listing'),(133422,'printshop-mobile','.b-products-listing .products-listing h2','padding-top','0','','','.b-products-listing'),(133423,'printshop-mobile','.b-products-listing .promos-info .promo-item','padding-top','3','','','.b-products-listing'),(133424,'printshop-mobile','.b-products-listing .promos-info .promo-name','padding-top','3','','','.b-products-listing'),(133425,'printshop-mobile','.b-products-listing .select-attributes .item-title','padding-top','2','','','.b-products-listing'),(133426,'printshop-mobile','.b-products-listing .list-productlisting div.BlockBox.item-holder','padding-top','25','','','.b-products-listing'),(133427,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.b-data-table'),(133428,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top','0','','','.b-data-table'),(133429,'printshop-mobile','.b-data-table table.dataTable thead td','padding-top','10','','','.b-data-table'),(133430,'printshop-mobile','.b-data-table table.dataTable tbody td','padding-top','10','','','.b-data-table'),(133431,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(133432,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(133433,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(133434,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(133435,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(133436,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(133437,'printshop-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(133438,'printshop-mobile','.b-email .image','padding-top','5','','','.b-email'),(133439,'printshop-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(133440,'printshop-mobile','.b-email .qty','padding-top','5','','','.b-email'),(133441,'printshop-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(133442,'printshop-mobile','.b-email .image','padding-top','5','','','.b-email'),(133443,'printshop-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(133444,'printshop-mobile','.b-email .model','padding-top','5','','','.b-email'),(133445,'printshop-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(133446,'printshop-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(133447,'printshop-mobile','.b-email .image','padding-top','5','','','.b-email'),(133448,'printshop-mobile','.b-email .name','padding-top','5','','','.b-email'),(133449,'printshop-mobile','.b-email .qty','padding-top','5','','','.b-email'),(133450,'printshop-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(133451,'printshop-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(133452,'printshop-mobile','.b-email .model','padding-top','5','','','.b-email'),(133453,'printshop-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(133454,'printshop-mobile','.b-email .model','padding-top','5','','','.b-email'),(133455,'printshop-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(133456,'printshop-mobile','.b-email .qty','padding-top','5','','','.b-email'),(133457,'printshop-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(133458,'printshop-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(133459,'printshop-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(133460,'printshop-mobile','.b-email .model','padding-top','5','','','.b-email'),(133461,'printshop-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(133462,'printshop-mobile','.b-email .name','padding-top','5','','','.b-email'),(133463,'printshop-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(133464,'printshop-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(133465,'printshop-mobile','.b-email .image','padding-top','5','','','.b-email'),(133466,'printshop-mobile','.b-email .price','padding-top','5','','','.b-email'),(133467,'printshop-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(133468,'printshop-mobile','.b-email .name','padding-top','5','','','.b-email'),(133469,'printshop-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(133470,'printshop-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(133471,'printshop-mobile','.b-email .model','padding-top','5','','','.b-email'),(133472,'printshop-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(133473,'printshop-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(133474,'printshop-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(133475,'printshop-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(133476,'printshop-mobile','.b-email .name','padding-top','5','','','.b-email'),(133477,'printshop-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(133478,'printshop-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(133479,'printshop-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(133480,'printshop-mobile','.b-email .price','padding-top','5','','','.b-email'),(133481,'printshop-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(133482,'printshop-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(133483,'printshop-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(133484,'printshop-mobile','.b-email .price','padding-top','5','','','.b-email'),(133485,'printshop-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(133486,'printshop-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(133487,'printshop-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(133488,'printshop-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(133489,'printshop-mobile','.b-email .price','padding-top','5','','','.b-email'),(133490,'printshop-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(133491,'printshop-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(133492,'printshop-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(133493,'printshop-mobile','.b-email .qty','padding-top','5','','','.b-email'),(133494,'printshop-mobile','.b-email .model','padding-top','5','','','.b-email'),(133495,'printshop-mobile','.b-email .price','padding-top','5','','','.b-email'),(133496,'printshop-mobile','.b-email .image','padding-top','5','','','.b-email'),(133497,'printshop-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(133498,'printshop-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(133499,'printshop-mobile','.b-email .name','padding-top','5','','','.b-email'),(133500,'printshop-mobile','.b-email .image','padding-top','5','','','.b-email'),(133501,'printshop-mobile','.b-email .name','padding-top','5','','','.b-email'),(133502,'printshop-mobile','.b-email .qty','padding-top','5','','','.b-email'),(133503,'printshop-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(133504,'printshop-mobile','.b-email .price','padding-top','5','','','.b-email'),(133505,'printshop-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(133506,'printshop-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(133507,'printshop-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(133508,'printshop-mobile','.b-email .qty','padding-top','5','','','.b-email'),(133509,'printshop-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(133510,'printshop-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(133511,'printshop-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(133512,'printshop-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(133513,'printshop-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(133514,'printshop-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(133515,'printshop-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(133516,'printshop-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(133517,'printshop-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(133518,'printshop-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(133519,'printshop-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(133520,'printshop-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(133521,'printshop-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(133522,'printshop-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(133523,'printshop-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(133524,'printshop-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(133525,'printshop-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(133526,'printshop-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(133527,'printshop-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(133528,'printshop-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(133529,'printshop-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(133530,'printshop-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(133531,'printshop-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(133532,'printshop-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(133533,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-top','0','','','.b-h-inline'),(133534,'printshop-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-top','0','','','.b-menu-style'),(133535,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-top','5','','','.b-menu-style-1'),(133536,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-top','5','','','.b-menu-style-1'),(133537,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-top','20','','','.b-menu-style-1'),(133538,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','padding-top','40','','','.b-menu-style-1'),(133539,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-top','0','','','.b-menu-style-1'),(133540,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-top','5','','','.b-menu-style-2'),(133541,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-top','5','','','.b-menu-style-2'),(133542,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-top','0','','','.b-menu-style-2'),(133543,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-top','0','','','.b-menu-style-2'),(133544,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-top','10','','','.b-menu-style-2'),(133545,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-top','0','','','.b-menu-style-2'),(133546,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-top','5','','','.b-menu-style-2'),(133547,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-top','10','','','.b-menu-style-2'),(133548,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-top','5','','','.b-menu-style-2'),(133549,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-html_box','padding-top','7','','','.b-menu-style-2'),(133550,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-top','10','','','.b-menu-style-2'),(133551,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-top','5','','','.b-menu-style-3'),(133552,'printshop-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','padding-top','5','','','.b-menu-style-3'),(133553,'printshop-mobile','.b-messages .msv_content','padding-top','10','','','.b-messages'),(133554,'printshop-mobile','.b-messages .msv_btn','padding-top','12','','','.b-messages'),(133555,'printshop-mobile','.b-messages .emailLineTextArea textarea','padding-top','30','','','.b-messages'),(133556,'printshop-mobile','.b-messages .msv_history','padding-top','10','','','.b-messages'),(133557,'printshop-mobile','.b-messages .messages-menu li','padding-top','0','','','.b-messages'),(133558,'printshop-mobile','.b-messages .messages-menu ul','padding-top','0','','','.b-messages'),(133559,'printshop-mobile','.b-messages .messMenuButton span','padding-top','10','','','.b-messages'),(133560,'printshop-mobile','.b-messages .messages-menu li a','padding-top','10','','','.b-messages'),(133561,'printshop-mobile','.b-messages .content_management_attach','padding-top','8','','','.b-messages'),(133562,'printshop-mobile','.b-messages .content_management_attach button','padding-top','1','','','.b-messages'),(133563,'printshop-mobile','.b-messages .email-heading','padding-top','15','','','.b-messages'),(133564,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-top','5','','','.b-messages'),(133565,'printshop-mobile','.b-messages .messMenuButtonTop','padding-top','5','','','.b-messages'),(133566,'printshop-mobile','.b-messages .msv_to_cc','padding-top','10','','','.b-messages'),(133567,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','padding-top','4','','','.b-messages'),(133568,'printshop-mobile','.b-messages .emailBtn','padding-top','10','','','.b-messages'),(133569,'printshop-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-top','20','','','.b-personal-catalog-popup'),(133570,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','padding-top','0','','','.b-select-suggest'),(133571,'printshop-mobile','.b-select-suggest .select2-drop-mask','padding-top','0','','','.b-select-suggest'),(133572,'printshop-mobile','.b-select-suggest .select2-search input','padding-top','4','','','.b-select-suggest'),(133573,'printshop-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(133574,'printshop-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','padding-top','4','','','.b-select-suggest'),(133575,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-top','0','','','.b-select-suggest'),(133576,'printshop-mobile','.b-select-suggest .select2-results','padding-top','0','','','.b-select-suggest'),(133577,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','padding-top','3','3','','.b-select-suggest'),(133578,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','padding-top','3','','','.b-select-suggest'),(133579,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-top','0','','','.b-select-suggest'),(133580,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-top','5','','','.b-select-suggest'),(133581,'printshop-mobile','.b-select-suggest .select2-locked','padding-top','3','','','.b-select-suggest'),(133582,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-top','0','','','.b-select-suggest'),(133583,'printshop-mobile','.b-select-suggest .select2-drop-auto-width .select2-search','padding-top','4','','','.b-select-suggest'),(133584,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(133585,'printshop-mobile','.b-sub-totals .historyTotal td','padding-top','2','','','.b-sub-totals'),(133586,'printshop-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(133587,'printshop-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(133588,'printshop-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(133589,'printshop-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(133590,'printshop-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(133591,'printshop-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(133592,'printshop-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(133593,'printshop-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(133594,'printshop-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(133595,'printshop-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(133596,'printshop-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(133597,'printshop-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(133598,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(133599,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(133600,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(133601,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(133602,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(133603,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(133604,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(133605,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(133606,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(133607,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(133608,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(133609,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(133610,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(133611,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(133612,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(133613,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(133614,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(133615,'printshop-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(133616,'printshop-mobile','.b-trade-approval .steps-bar li a','padding-top','7','','','.b-trade-approval'),(133617,'printshop-mobile','.b-trade-approval .middle-form','padding-top','20','','','.b-trade-approval'),(133618,'printshop-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-top','5','','','.b-trade-approval'),(133619,'printshop-mobile','.b-trade-approval .steps-bar','padding-top','0','','','.b-trade-approval'),(133620,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-top','4','','','.b-trade-approval'),(133621,'printshop-mobile','.b-trade-approval .center-buttons','padding-top','20','','','.b-trade-approval'),(133622,'printshop-mobile','.b-upload-file .upload-file-template','padding-top','25','','','.b-upload-file'),(133623,'printshop-mobile','.b-upload-files .upload-files','padding-top','0','','','.b-upload-files'),(133624,'printshop-mobile','.b-upload-files .attached-block','padding-top','10','','','.b-upload-files'),(133625,'printshop-mobile','.b-upload-files .added-file','padding-top','5','','','.b-upload-files'),(133626,'printshop-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-top','20','','','.b-warehouses-popup'),(133627,'printshop-mobile','.batchPr .w-batch-products .products-listing .image','padding-top','0','','','.batchPr'),(133628,'printshop-mobile','.batchPr .w-batch-products .products-listing .image + .type-1','padding-top','5','','','.batchPr'),(133629,'printshop-mobile','.batchPr .w-batch-products','padding-top','0','','','.batchPr'),(133630,'printshop-mobile','.batchPr > .block:nth-child(2)','padding-top','12','','','.batchPr'),(133631,'printshop-mobile','.batchPr .w-batch-selected-products','padding-top','15','','','.batchPr'),(133632,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-top','0','','','.batchPr'),(133633,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .item + .item','padding-top','10','','','.batchPr'),(133634,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-top','0','','','.batchPr'),(133635,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-top','0','','','.batchPr'),(133636,'printshop-mobile','.batchPr ','padding-top','20','','','.batchPr'),(133637,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-top','0','','','.batchPr'),(133638,'printshop-mobile','.batchPr .w-batch-products .products-listing .image','padding-top','0','','','.batchPr'),(133639,'printshop-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-top','0','','','.batchPr'),(133640,'printshop-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(133641,'printshop-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(133642,'printshop-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(133643,'printshop-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(133644,'printshop-mobile','.p-account-samples-history .orders-table th','padding-top','2','','','.p-account-samples-history'),(133645,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-top','10','','','.p-account-samples-history'),(133646,'printshop-mobile','.p-account-samples-history .view_link','padding-top','0','','','.p-account-samples-history'),(133647,'printshop-mobile','.p-account-samples-history .view_link','padding-top','0','','','.p-account-samples-history'),(133648,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-top','10','','','.p-account-samples-history'),(133649,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-top','5','','','.p-account-samples-history'),(133650,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-top','10','','','.p-account-samples-history'),(133651,'printshop-mobile','.p-account-samples-history .orders-table th','padding-top','2','','','.p-account-samples-history'),(133652,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-top','10','','','.p-account-samples-history'),(133653,'printshop-mobile','.p-account-samples-history .orders-table th','padding-top','2','','','.p-account-samples-history'),(133654,'printshop-mobile','.p-account-samples-history .view_link','padding-top','0','','','.p-account-samples-history'),(133655,'printshop-mobile','.p-account-samples-history .orders-table td','padding-top','5','','','.p-account-samples-history'),(133656,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-top','5','','','.p-account-samples-history'),(133657,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-top','10','','','.p-account-samples-history'),(133658,'printshop-mobile','.p-account-samples-history .orders-table th','padding-top','2','','','.p-account-samples-history'),(133659,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-top','10','','','.p-account-samples-history'),(133660,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-top','5','','','.p-account-samples-history'),(133661,'printshop-mobile','.p-account-samples-history .view_link','padding-top','0','','','.p-account-samples-history'),(133662,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-top','10','','','.p-account-samples-history'),(133663,'printshop-mobile','.p-account-samples-history .orders-table th','padding-top','2','','','.p-account-samples-history'),(133664,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-top','10','','','.p-account-samples-history'),(133665,'printshop-mobile','.p-account-samples-history .orders-table td','padding-top','5','','','.p-account-samples-history'),(133666,'printshop-mobile','.p-account-samples-history .orders-table th','padding-top','2','','','.p-account-samples-history'),(133667,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-top','10','','','.p-account-samples-history'),(133668,'printshop-mobile','.p-account-samples-history .view_link','padding-top','0','','','.p-account-samples-history'),(133669,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-top','10','','','.p-account-samples-history'),(133670,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-top','5','','','.p-account-samples-history'),(133671,'printshop-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-top','10','','','.p-account-samples-history'),(133672,'printshop-mobile','.p-account-samples-history .orders-table td','padding-top','5','','','.p-account-samples-history'),(133673,'printshop-mobile','.p-account-samples-history .view_link','padding-top','0','','','.p-account-samples-history'),(133674,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-top','5','','','.p-account-samples-history'),(133675,'printshop-mobile','.p-account-samples-history .orders-table td','padding-top','5','','','.p-account-samples-history'),(133676,'printshop-mobile','.p-account-samples-history .order_history_table th','padding-top','10','','','.p-account-samples-history'),(133677,'printshop-mobile','.p-account-samples-history .orders-table td','padding-top','5','','','.p-account-samples-history'),(133678,'printshop-mobile','.p-account-samples-history .orders-table td','padding-top','5','','','.p-account-samples-history'),(133679,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','padding-top','5','','','.p-account-samples-history'),(133680,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-top','10','','','.p-account-samples-history-info'),(133681,'printshop-mobile','.p-account-samples-history-info .history_attr','padding-top','5','','','.p-account-samples-history-info'),(133682,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(133683,'printshop-mobile','.p-account-samples-history-info .history_attr','padding-top','5','','','.p-account-samples-history-info'),(133684,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(133685,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-top','10','','','.p-account-samples-history-info'),(133686,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(133687,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-top','0','','','.p-account-samples-history-info'),(133688,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-top','10','','','.p-account-samples-history-info'),(133689,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(133690,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-top','5','','','.p-account-samples-history-info'),(133691,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-top','10','','','.p-account-samples-history-info'),(133692,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-top','10','','','.p-account-samples-history-info'),(133693,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(133694,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-top','0','','','.p-account-samples-history-info'),(133695,'printshop-mobile','.p-account-samples-history-info .history_attr','padding-top','5','','','.p-account-samples-history-info'),(133696,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-top','5','','','.p-account-samples-history-info'),(133697,'printshop-mobile','.p-account-samples-history-info .history_attr','padding-top','5','','','.p-account-samples-history-info'),(133698,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-top','5','','','.p-account-samples-history-info'),(133699,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-top','0','','','.p-account-samples-history-info'),(133700,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-top','10','','','.p-account-samples-history-info'),(133701,'printshop-mobile','.p-account-samples-history-info .history_attr','padding-top','5','','','.p-account-samples-history-info'),(133702,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-top','0','','','.p-account-samples-history-info'),(133703,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(133704,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-top','10','','','.p-account-samples-history-info'),(133705,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(133706,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(133707,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(133708,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-top','10','','','.p-account-samples-history-info'),(133709,'printshop-mobile','.p-account-samples-history-info .history_attr','padding-top','5','','','.p-account-samples-history-info'),(133710,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-top','5','','','.p-account-samples-history-info'),(133711,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-top','5','','','.p-account-samples-history-info'),(133712,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(133713,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(133714,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-top','10','','','.p-account-samples-history-info'),(133715,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-top','5','','','.p-account-samples-history-info'),(133716,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(133717,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-top','10','','','.p-account-samples-history-info'),(133718,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','padding-top','10','','','.p-account-samples-history-info'),(133719,'printshop-mobile','.p-account-samples-history-info .contentColumn','padding-top','10','','','.p-account-samples-history-info'),(133720,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-top','0','','','.p-account-samples-history-info'),(133721,'printshop-mobile','.p-account-samples-history-info .history_info > div','padding-top','0','','','.p-account-samples-history-info'),(133722,'printshop-mobile','.p-catalog-product .prev-product','padding-top','20','','','.p-catalog-product'),(133723,'printshop-mobile','.p-catalog-product .next-product','padding-top','20','','','.p-catalog-product'),(133724,'printshop-mobile','.p-catalog-product .pn-image','padding-top','20','','','.p-catalog-product'),(133725,'printshop-mobile','.p-catalog-product .pn-name','padding-top','15','','','.p-catalog-product'),(133726,'printshop-mobile','.p-catalog-product .pn-direction','padding-top','0','','','.p-catalog-product'),(133727,'printshop-mobile','.p-checkout-login .password-forgotten-link','padding-top','0','','','.p-checkout-login'),(133728,'printshop-mobile','.p-payer-order-confirmation .dob-hide label','padding-top','5','','','.p-payer-order-confirmation'),(133729,'printshop-mobile','.p-payer-order-pay .dob-hide label','padding-top','5','','','.p-payer-order-pay'),(133730,'printshop-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-top','8','','','.p-quick-order-index'),(133731,'printshop-mobile','.p-quick-order-index .bottom','padding-top','10','','','.p-quick-order-index'),(133732,'printshop-mobile','.p-quick-order-index .all-scroll-div','padding-top','10','','','.p-quick-order-index'),(133733,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.p-quick-order-index'),(133734,'printshop-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-top','7','','','.p-quick-order-index'),(133735,'printshop-mobile','.p-quick-order-index ul.token-input-list','padding-top','0','','','.p-quick-order-index'),(133736,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(133737,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(133738,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(133739,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(133740,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(133741,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(133742,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(133743,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(133744,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(133745,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(133746,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(133747,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(133748,'printshop-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(133749,'printshop-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(133750,'printshop-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(133751,'printshop-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(133752,'printshop-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(133753,'printshop-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(133754,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(133755,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(133756,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(133757,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(133758,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(133759,'printshop-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(133760,'printshop-mobile','.p-sample-checkout-success .page-success .text-1','padding-top','120','','','.p-sample-checkout-success'),(133761,'printshop-mobile','.p-sample-checkout-success .page-success .text-1','padding-top','5','','','.p-sample-checkout-success'),(133762,'printshop-mobile','.w-account-address-book .wrap','padding-top','15','','','.w-account-address-book'),(133763,'printshop-mobile','.w-account-address-book .item','padding-top','0','','','.w-account-address-book'),(133764,'printshop-mobile','.w-account-address-book .btn-del','padding-top','0','','','.w-account-address-book'),(133765,'printshop-mobile','.w-account-address-book .name','padding-top','4','','','.w-account-address-book'),(133766,'printshop-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-top','0','','','.w-account-addresses-list'),(133767,'printshop-mobile','.w-account-personal-catalog .list-switcher','padding-top','0','','','.w-account-personal-catalog'),(133768,'printshop-mobile','.w-account-personal-catalog .list-switcher a','padding-top','14','','','.w-account-personal-catalog'),(133769,'printshop-mobile','.w-account-personal-catalog .list-switcher a','padding-top','12','2','','.w-account-personal-catalog'),(133770,'printshop-mobile','.w-account-subscription .subscription-variant','padding-top','10','','','.w-account-subscription'),(133771,'printshop-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-top','0','','','.w-blog-widget-most-popular-posts'),(133772,'printshop-mobile','.w-blog-widget-post-listing .post','padding-top','0','','','.w-blog-widget-post-listing'),(133773,'printshop-mobile','.w-blog-widget-post-listing .post_name','padding-top','10','','','.w-blog-widget-post-listing'),(133774,'printshop-mobile','.w-blog-widget-post-listing .post','padding-top','0','','','.w-blog-widget-post-listing'),(133775,'printshop-mobile','.w-blog-widget-post-share ','padding-top','15','','','.w-blog-widget-post-share'),(133776,'printshop-mobile','.w-blog-widget-post-title ','padding-top','0','','','.w-blog-widget-post-title'),(133777,'printshop-mobile','.w-blog-widget-post-title h1','padding-top','0','','','.w-blog-widget-post-title'),(133778,'printshop-mobile','.w-blog-widget-related-posts .post','padding-top','0','','','.w-blog-widget-related-posts'),(133779,'printshop-mobile','.w-blog-widget-related-posts .post_content a','padding-top','20','','','.w-blog-widget-related-posts'),(133780,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-top','20','','','.w-blog-widget-related-posts-by-category'),(133781,'printshop-mobile','.w-blog-widget-related-posts-by-category .post','padding-top','0','','','.w-blog-widget-related-posts-by-category'),(133782,'printshop-mobile','.w-blog-widget-tag-cloud a','padding-top','10','','','.w-blog-widget-tag-cloud'),(133783,'printshop-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-top','0','','','.w-cart-cart-tabs'),(133784,'printshop-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-top','5','','','.w-cart-compare'),(133785,'printshop-mobile','.w-cart-compare .attributes-label','padding-top','10','','','.w-cart-compare'),(133786,'printshop-mobile','.w-cart-compare .dropdown li','padding-top','5','','','.w-cart-compare'),(133787,'printshop-mobile','.w-cart-compare .delete-cart','padding-top','10','','','.w-cart-compare'),(133788,'printshop-mobile','.w-cart-compare .product','padding-top','10','','','.w-cart-compare'),(133789,'printshop-mobile','.w-cart-compare .cart-cell','padding-top','0','','','.w-cart-compare'),(133790,'printshop-mobile','.w-cart-compare .attributes-cell','padding-top','8','','','.w-cart-compare'),(133791,'printshop-mobile','.w-cart-compare .price-label','padding-top','10','','','.w-cart-compare'),(133792,'printshop-mobile','.w-cart-compare .price-cell','padding-top','8','','','.w-cart-compare'),(133793,'printshop-mobile','.w-cart-compare .product-label','padding-top','15','','','.w-cart-compare'),(133794,'printshop-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-top','1','','','.w-cart-up-sell'),(133795,'printshop-mobile','.w-cart-up-sell .w-list-type-1','padding-top','0','','','.w-cart-up-sell'),(133796,'printshop-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-top','0','1','','.w-cart-up-sell'),(133797,'printshop-mobile','.w-catalog-additional-images li','padding-top','10','','','.w-catalog-additional-images'),(133798,'printshop-mobile','.w-catalog-additional-images ul','padding-top','0','','','.w-catalog-additional-images'),(133799,'printshop-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-top','5','','','.w-catalog-b2b-add-button'),(133800,'printshop-mobile','.w-catalog-compare td','padding-top','10','','','.w-catalog-compare'),(133801,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','padding-top','12','','','.w-catalog-compare'),(133802,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','padding-top','10','2','','.w-catalog-compare'),(133803,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-top','0','','','.w-catalog-compare'),(133804,'printshop-mobile','.w-catalog-items-on-page .before, .w-catalog-items-on-page .after','padding-top','5','','','.w-catalog-items-on-page'),(133805,'printshop-mobile','.w-catalog-paging .paging-item','padding-top','0','','','.w-catalog-paging'),(133806,'printshop-mobile','.w-checkout-billing-address .same-address','padding-top','10','','','.w-checkout-billing-address'),(133807,'printshop-mobile','.w-checkout-billing-address .edit-ab','padding-top','5','','','.w-checkout-billing-address'),(133808,'printshop-mobile','.w-checkout-create-account .create-account-switcher','padding-top','3','','','.w-checkout-create-account'),(133809,'printshop-mobile','.w-checkout-create-account .create-account','padding-top','10','','','.w-checkout-create-account'),(133810,'printshop-mobile','.w-checkout-gdpr .privacy-row','padding-top','0','','','.w-checkout-gdpr'),(133811,'printshop-mobile','.w-checkout-gdpr .terms-login','padding-top','0','','','.w-checkout-gdpr'),(133812,'printshop-mobile','.w-checkout-shipping .sub-item','padding-top','5','','','.w-checkout-shipping'),(133813,'printshop-mobile','.w-checkout-shipping-address .buttons-under-drop .add-ab','padding-top','5','','','.w-checkout-shipping-address'),(133814,'printshop-mobile','.w-checkout-shipping-address .edit-ab','padding-top','5','','','.w-checkout-shipping-address'),(133815,'printshop-mobile','.w-checkout-shipping-choice span','padding-top','7','','','.w-checkout-shipping-choice'),(133816,'printshop-mobile','.w-checkout-shipping-choice span','padding-top','7','','','.w-checkout-shipping-choice'),(133817,'printshop-mobile','.w-checkout-terms .required-message','padding-top','5','','','.w-checkout-terms'),(133818,'printshop-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-top','20','','','.w-communication-new-topic'),(133819,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-top','5','','','.w-communication-new-topic'),(133820,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-top','0','','','.w-communication-new-topic'),(133821,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-top','5','','','.w-communication-new-topic'),(133822,'printshop-mobile','.w-communication-new-topic .topick-left-col','padding-top','24','','','.w-communication-new-topic'),(133823,'printshop-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-top','10','','','.w-communication-new-topic'),(133824,'printshop-mobile','.w-communication-post .communication-post-author','padding-top','10','','','.w-communication-post'),(133825,'printshop-mobile','.w-delivery-day .left-count','padding-top','5','','','.w-delivery-day'),(133826,'printshop-mobile','.w-delivery-day .left-text-left','padding-top','24','','','.w-delivery-day'),(133827,'printshop-mobile','.w-delivery-day .left-text-right','padding-top','24','','','.w-delivery-day'),(133828,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-top','10','','','.w-image-maps'),(133829,'printshop-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-top','3','','','.w-multi-cart-actions'),(133830,'printshop-mobile','.w-multi-cart-cart-switcher .carts-switcher','padding-top','20','','','.w-multi-cart-cart-switcher'),(133831,'printshop-mobile','.w-neighbour-checkout .neighbour-comment-box','padding-top','10','','','.w-neighbour-checkout'),(133832,'printshop-mobile','.w-personal-gift-status-bar .start-label','padding-top','0','','','.w-personal-gift-status-bar'),(133833,'printshop-mobile','.w-personal-gift-status-bar .end-label','padding-top','0','','','.w-personal-gift-status-bar'),(133834,'printshop-mobile','.w-personal-gift-status-bar .timeline','padding-top','16','','','.w-personal-gift-status-bar'),(133835,'printshop-mobile','.w-personal-gift-status-bar .inform','padding-top','0','4','','.w-personal-gift-status-bar'),(133836,'printshop-mobile','.w-personal-gift-status-bar .end-date','padding-top','0','3','','.w-personal-gift-status-bar'),(133837,'printshop-mobile','.w-product-available-in-warehouses .warehouse-item','padding-top','0','','','.w-product-available-in-warehouses'),(133838,'printshop-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(133839,'printshop-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(133840,'printshop-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(133841,'printshop-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(133842,'printshop-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(133843,'printshop-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(133844,'printshop-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(133845,'printshop-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(133846,'printshop-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(133847,'printshop-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(133848,'printshop-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(133849,'printshop-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(133850,'printshop-mobile','.w-product-customers-activity .customers-activity','padding-top','35','','','.w-product-customers-activity'),(133851,'printshop-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(133852,'printshop-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(133853,'printshop-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(133854,'printshop-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(133855,'printshop-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(133856,'printshop-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(133857,'printshop-mobile','.w-promotions .nextdiscount .content > div','padding-top','10','','','.w-promotions'),(133858,'printshop-mobile','.w-promotions .promo-cart-discount .master .item','padding-top','0','','','.w-promotions'),(133859,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-top','0','','','.w-promotions'),(133860,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-top','0','','','.w-promotions'),(133861,'printshop-mobile','.w-promotions .promo-salemaker .item','padding-top','20','','','.w-promotions'),(133862,'printshop-mobile','.w-promotions .promo-salemaker .discount','padding-top','0','','','.w-promotions'),(133863,'printshop-mobile','.w-promotions .promo-cart-discount .slave .item','padding-top','20','','','.w-promotions'),(133864,'printshop-mobile','.w-promotions .promo-item','padding-top','30','','','.w-promotions'),(133865,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','padding-top','0','','','.w-promotions'),(133866,'printshop-mobile','.w-promotions .prom-multi-discount .promo-product','padding-top','20','','','.w-promotions'),(133867,'printshop-mobile','.w-promotions .nextdiscount .promo-for-each','padding-top','3','','','.w-promotions'),(133868,'printshop-mobile','.w-quote-products .empty','padding-top','100','','','.w-quote-products'),(133869,'printshop-mobile','.w-reviews-content .author','padding-top','0','','','.w-reviews-content'),(133870,'printshop-mobile','.w-reviews-content .item','padding-top','20','','','.w-reviews-content'),(133871,'printshop-mobile','.w-reviews-content .review','padding-top','20','','','.w-reviews-content'),(133872,'printshop-mobile','.w-sitemap-delivery-location > ul','padding-top','0','','','.w-sitemap-delivery-location'),(133873,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-top','0','','','.w-sitemap-delivery-location'),(133874,'printshop-mobile','.w-top-text .top-text','padding-top','5','','','.w-top-text'),(133875,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-template','padding-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(133876,'printshop-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding-top','25','','','.w-wedding-registry-widgets-manage-banner'),(133877,'printshop-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding-top','15','','','.w-wedding-registry-widgets-manage-banner'),(133878,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-top','17','','','.w-wedding-registry-widgets-photos'),(133879,'printshop-mobile','.w-wedding-registry-widgets-products .price','padding-top','5','','','.w-wedding-registry-widgets-products'),(133880,'printshop-mobile','.w-wedding-registry-widgets-products .rating','padding-top','10','','','.w-wedding-registry-widgets-products'),(133881,'printshop-mobile','.w-wedding-registry-widgets-search-registry-button ','padding-top','5','','','.w-wedding-registry-widgets-search-registry-button'),(133882,'printshop-mobile','.b-quantity .qty-box input[type=\'text\']','padding-top','5','','','.b-quantity'),(133883,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top_important','important','','','.b-data-table'),(133884,'printshop-mobile','.b-data-table table.dataTable thead td','padding-top_important','important','','','.b-data-table'),(133885,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top_important','important','','','.b-data-table'),(133886,'printshop-mobile','.b-data-table table.dataTable tbody td','padding-top_important','important','','','.b-data-table'),(133887,'printshop-mobile','.batchPr .w-batch-products','padding-top_important','important','','','.batchPr'),(133888,'printshop-mobile','.w-categories .image','padding_bottom_measure','%','','','.w-categories'),(133889,'printshop-mobile','.w-top-categories .image','padding_bottom_measure','%','','','.w-top-categories'),(133890,'printshop-mobile','.p-account-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-history-info'),(133891,'printshop-mobile','.p-account-order-pay .history_info > div + div','padding_left_measure','%','','','.p-account-order-pay'),(133892,'printshop-mobile','.p-account-index .topAccount > li','padding_left_measure','%','','','.p-account-index'),(133893,'printshop-mobile','.w-cart-give-away .ga_img','padding_left_measure','%','','','.w-cart-give-away'),(133894,'printshop-mobile','.b-upload-file .upload-file-template','padding_left_measure','%','','','.b-upload-file'),(133895,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-samples-history-info'),(133896,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-samples-history-info'),(133897,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-samples-history-info'),(133898,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-samples-history-info'),(133899,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-samples-history-info'),(133900,'printshop-mobile','.p-account-samples-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-samples-history-info'),(133901,'printshop-mobile','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(133902,'printshop-mobile','.p-account-index .topAccount > li','padding_right_measure','%','','','.p-account-index'),(133903,'printshop-mobile','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(133904,'printshop-mobile','.w-cart-give-away .ga_img','padding_right_measure','%','','','.w-cart-give-away'),(133905,'printshop-mobile','.b-upload-file .upload-file-template','padding_right_measure','%','','','.b-upload-file'),(133906,'printshop-mobile','.p-wedding-registry-manage .wedding-image','padding_top_measure','%','','','.p-wedding-registry-manage'),(133907,'printshop-mobile','.p-wedding-registry-share .wedding-image','padding_top_measure','%','','','.p-wedding-registry-share'),(133908,'printshop-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding_top_measure','%','','','.w-wedding-registry-widgets-manage-banner'),(133909,'printshop-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding_top_measure','%','','','.w-wedding-registry-widgets-manage-banner'),(133910,'printshop-mobile','.b-slick .slick-slide.dragging img','pointer-events','none','','','.b-slick'),(133911,'printshop-mobile','.w-list-type-1_3 #add_all','position','fixed','','','.w-list-type-1_3'),(133912,'printshop-mobile','.w-menu .hided.menu > ul','position','absolute','','','.w-menu'),(133913,'printshop-mobile','.w-menu .hided.menu','position','relative','','','.w-menu'),(133914,'printshop-mobile','.w-menu .hided.menu ul li','position','static','','','.w-menu'),(133915,'printshop-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','position','static','','','.w-menu'),(133916,'printshop-mobile','.w-menu .menu .menu-ico','position','relative','','','.w-menu'),(133917,'printshop-mobile','.w-menu-big','position','relative','','','.w-menu-big'),(133918,'printshop-mobile','.w-menu-slider > ul','position','relative','','','.w-menu-slider'),(133919,'printshop-mobile','.w-menu-big > ul > li > ul','position','absolute','','','.w-menu-big'),(133920,'printshop-mobile','.w-menu-big li','position','static','','','.w-menu-big'),(133921,'printshop-mobile','.w-menu-slider > ul > li > ul','position','absolute','','','.w-menu-slider'),(133922,'printshop-mobile','.w-menu-slider .close','position','absolute','','','.w-menu-slider'),(133923,'printshop-mobile','.w-bestsellers .counter','position','relative','','','.w-bestsellers'),(133924,'printshop-mobile','.w-bestsellers .heading-3','position','relative','','','.w-bestsellers'),(133925,'printshop-mobile','.w-bestsellers .item','position','relative','','','.w-bestsellers'),(133926,'printshop-mobile','.w-bestsellers .item','position','absolute','3','','.w-bestsellers'),(133927,'printshop-mobile','.w-banner .banner','position','relative','','','.w-banner'),(133928,'printshop-mobile','.b-switch .bootstrap-switch','position','relative','','','.b-switch'),(133929,'printshop-mobile','.w-list-type-1 .rating-count','position','relative','','','.w-list-type-1'),(133930,'printshop-mobile','.w-bestsellers .heading-3','position','absolute','3','','.w-bestsellers'),(133931,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(133932,'printshop-mobile','.w-filters .input-checkbox','position','absolute','','','.w-filters'),(133933,'printshop-mobile','.w-list-type-2_2 .sale','position','absolute','4','','.w-list-type-2_2'),(133934,'printshop-mobile','.w-sale .sale-holder','position','relative','','','.w-sale'),(133935,'printshop-mobile','.w-sale .badge','position','absolute','','','.w-sale'),(133936,'printshop-mobile','.w-product-wedding-registry-button .btn','position','absolute','3','','.w-product-wedding-registry-button'),(133937,'printshop-mobile','.b-fancybox #fancybox-loading','position','fixed','','','.b-fancybox'),(133938,'printshop-mobile','.w-menu-horizontal li','position','relative','','','.w-menu-horizontal'),(133939,'printshop-mobile','.b-fancybox .fancybox-nav span','position','absolute','','','.b-fancybox'),(133940,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','position','relative','','','.p-account-history-info'),(133941,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','position','absolute','3','','.p-account-history-info'),(133942,'printshop-mobile','.p-account-history-info .not_fully_paid_td','position','absolute','','','.p-account-history-info'),(133943,'printshop-mobile','.p-account-index .not_fully_paid_td','position','absolute','','','.p-account-index'),(133944,'printshop-mobile','.p-account-index .moduleRowDue td','position','relative','','','.p-account-index'),(133945,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','position','relative','4','','.b-multi-page-checkout'),(133946,'printshop-mobile','.b-pass-strength .pass-strength','position','relative','','','.b-pass-strength'),(133947,'printshop-mobile','.b-pass-strength .pass-strength span','position','absolute','','','.b-pass-strength'),(133948,'printshop-mobile','.w-reviews .heading-3','position','absolute','3','','.w-reviews'),(133949,'printshop-mobile','.w-product-reviews .reviews-list .review','position','absolute','3','','.w-product-reviews'),(133950,'printshop-mobile','.w-product-reviews .reviews-list .review','position','relative','','','.w-product-reviews'),(133951,'printshop-mobile','.w-quote .cart-box','position','relative','','','.w-quote'),(133952,'printshop-mobile','.w-product-reviews .reviews-list span','position','relative','','','.w-product-reviews'),(133953,'printshop-mobile','.p-blog-index .author .avatar','position','relative','','','.p-blog-index'),(133954,'printshop-mobile','.w-product-personal-catalog-button .btn','position','relative','','','.w-product-personal-catalog-button'),(133955,'printshop-mobile','.b-info-popup .info-popup div','position','absolute','','','.b-info-popup'),(133956,'printshop-mobile','.w-menu-mobile .menu-slider .open','position','fixed','','','.w-menu-mobile'),(133957,'printshop-mobile','.w-promo-code .holder','position','relative','','','.w-promo-code'),(133958,'printshop-mobile','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(133959,'printshop-mobile','.p-wedding-registry-view h1','position','relative','3','','.p-wedding-registry-view'),(133960,'printshop-mobile','.p-account-order-pay .account_history_info.account_history_info_due','position','relative','','','.p-account-order-pay'),(133961,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','position','relative','','','.p-account-order-pay'),(133962,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','position','absolute','3','','.p-account-order-pay'),(133963,'printshop-mobile','.p-account-order-pay .not_fully_paid_td','position','absolute','','','.p-account-order-pay'),(133964,'printshop-mobile','.testimonials .heading-3','position','absolute','3','',''),(133965,'printshop-mobile','.testimonials .heading-3','position','relative','','',''),(133966,'printshop-mobile','.testimonials .rating','position','relative','','',''),(133967,'printshop-mobile','.testimonials .review','position','relative','','',''),(133968,'printshop-mobile','.testimonials .review','position','absolute','3','',''),(133969,'printshop-mobile','.testimonials .reviews-list span','position','relative','','',''),(133970,'printshop-mobile','.p-wedding-registry-manage .wr-search','position','relative','','','.p-wedding-registry-manage'),(133971,'printshop-mobile','.p-wedding-registry-manage .wr-search button','position','absolute','','','.p-wedding-registry-manage'),(133972,'printshop-mobile','.p-account-history .view_link','position','relative','','','.p-account-history'),(133973,'printshop-mobile','.p-account-history .view_link','position','absolute','4','','.p-account-history'),(133974,'printshop-mobile','.p-account-history .orders-table .item','position','relative','720','','.p-account-history'),(133975,'printshop-mobile','.p-account-history .orders-table .status-name','position','absolute','720','','.p-account-history'),(133976,'printshop-mobile','.p-account-history .orders-table .td-alignright','position','absolute','720','','.p-account-history'),(133977,'printshop-mobile','.p-account-index .orders-table .item','position','relative','720','','.p-account-index'),(133978,'printshop-mobile','.p-account-history .orders-table .order-total','position','absolute','720','','.p-account-history'),(133979,'printshop-mobile','.p-account-index .orders-table .order-total','position','absolute','720','','.p-account-index'),(133980,'printshop-mobile','.p-account-index .orders-table .td-alignright','position','absolute','720','','.p-account-index'),(133981,'printshop-mobile','.p-account-index .orders-table .status-name','position','absolute','720','','.p-account-index'),(133982,'printshop-mobile','.w-list-type-2_2 .sale','position','absolute','','','.w-list-type-2_2'),(133983,'printshop-mobile','.w-list-type-2_2 .sale','position','absolute','3','','.w-list-type-2_2'),(133984,'printshop-mobile','.w-list-type-2_2 .image','position','relative','','','.w-list-type-2_2'),(133985,'printshop-mobile','.w-list-type-2 .sale','position','absolute','','','.w-list-type-2'),(133986,'printshop-mobile','.w-list-type-2 .sale','position','absolute','3','','.w-list-type-2'),(133987,'printshop-mobile','.w-product-wedding-registry-button .btn','position','absolute','4','','.w-product-wedding-registry-button'),(133988,'printshop-mobile','.w-list-type-2 .sale','position','absolute','4','','.w-list-type-2'),(133989,'printshop-mobile','.w-product-wedding-registry-button .btn','position','relative','','','.w-product-wedding-registry-button'),(133990,'printshop-mobile','.w-product-personal-catalog-button .btn','position','absolute','3','','.w-product-personal-catalog-button'),(133991,'printshop-mobile','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(133992,'printshop-mobile','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(133993,'printshop-mobile','.w-account a.my-acc-link','position','relative','','','.w-account'),(133994,'printshop-mobile','.b-fancybox .fancybox-close','position','absolute','','','.b-fancybox'),(133995,'printshop-mobile','.w-menu-horizontal ul ul','position','absolute','','','.w-menu-horizontal'),(133996,'printshop-mobile','.b-fancybox .fancybox-nav','position','absolute','','','.b-fancybox'),(133997,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','position','relative','3','','.b-form'),(133998,'printshop-mobile','.b-form .radio-button input[type=\"radio\"]','position','relative','','','.b-form'),(133999,'printshop-mobile','.p-wedding-registry-index .search-list','position','absolute','3','','.p-wedding-registry-index'),(134000,'printshop-mobile','.p-wedding-registry-index .search-list','position','relative','','','.p-wedding-registry-index'),(134001,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no','position','absolute','','','.b-form'),(134002,'printshop-mobile','.b-form .radio-buttons .radio-button','position','relative','','','.b-form'),(134003,'printshop-mobile','.b-form .form-buttons','position','relative','','','.b-form'),(134004,'printshop-mobile','.p-wedding-registry-search h1','position','relative','4','','.p-wedding-registry-search'),(134005,'printshop-mobile','.p-account-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-history-info'),(134006,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','position','relative','3','','.b-switch'),(134007,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','position','relative','3','','.b-switch'),(134008,'printshop-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position','absolute','','','.b-switch'),(134009,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','position','absolute','','','.b-slick'),(134010,'printshop-mobile','.b-bottom .footerTitle','position','absolute','693,4','','.b-bottom'),(134011,'printshop-mobile','.b-bottom .footerTitle','position','relative','693','','.b-bottom'),(134012,'printshop-mobile','.w-search .search','position','relative','','','.w-search'),(134013,'printshop-mobile','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(134014,'printshop-mobile','.w-search .suggest','position','absolute','','','.w-search'),(134015,'printshop-mobile','.w-banner .image-text-banner','position','relative','','','.w-banner'),(134016,'printshop-mobile','.w-banner .banner img + img','position','absolute','','','.w-banner'),(134017,'printshop-mobile','.w-banner .image-text-banner .text-banner','position','absolute','','','.w-banner'),(134018,'printshop-mobile','.w-currencies .current','position','relative','','','.w-currencies'),(134019,'printshop-mobile','.w-currencies .select','position','absolute','','','.w-currencies'),(134020,'printshop-mobile','.w-filters .head-filter-widget','position','relative','','','.w-filters'),(134021,'printshop-mobile','.w-currencies .current','position','absolute','3','','.w-currencies'),(134022,'printshop-mobile','.w-currencies .currencies','position','relative','','','.w-currencies'),(134023,'printshop-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(134024,'printshop-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','position','absolute','','','.w-compare-box-item'),(134025,'printshop-mobile','.w-compare-box-item .checkbox:not(checked) + span','position','relative','','','.w-compare-box-item'),(134026,'printshop-mobile','.w-compare-box-item .checkbox:not(checked)','position','absolute','','','.w-compare-box-item'),(134027,'printshop-mobile','.b-slick .slick-slider','position','relative','','','.b-slick'),(134028,'printshop-mobile','.b-slick .slick-track','position','relative','','','.b-slick'),(134029,'printshop-mobile','.p-checkout-success .page-success','position','relative','','','.p-checkout-success'),(134030,'printshop-mobile','.p-checkout-success .page-success','position','absolute','3','','.p-checkout-success'),(134031,'printshop-mobile','.b-fancybox .fancybox-title-outside-wrap','position','relative','','','.b-fancybox'),(134032,'printshop-mobile','.b-fancybox .fancybox-title','position','relative','','','.b-fancybox'),(134033,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap','position','absolute','','','.b-fancybox'),(134034,'printshop-mobile','.b-info-popup .info-popup','position','relative','','','.b-info-popup'),(134035,'printshop-mobile','.p-account-index .view_link','position','absolute','4','','.p-account-index'),(134036,'printshop-mobile','.p-account-index .view_link','position','relative','','','.p-account-index'),(134037,'printshop-mobile','.b-info-popup .info-popup div','position','absolute','3','','.b-info-popup'),(134038,'printshop-mobile','.b-fancybox .fancybox-tmp','position','absolute','','','.b-fancybox'),(134039,'printshop-mobile','.b-fancybox .fancybox-skin','position','relative','','','.b-fancybox'),(134040,'printshop-mobile','.b-fancybox .fancybox-title-over-wrap','position','absolute','','','.b-fancybox'),(134041,'printshop-mobile','.b-fancybox .fancybox-wrap','position','absolute','','','.b-fancybox'),(134042,'printshop-mobile','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(134043,'printshop-mobile','.w-menu-style-1 li','position','relative','','','.w-menu-style-1'),(134044,'printshop-mobile','.w-menu-style-1 ul ul','position','absolute','','','.w-menu-style-1'),(134045,'printshop-mobile','.p-checkout-success .page-success > div','position','relative','','','.p-checkout-success'),(134046,'printshop-mobile','.b-fancybox .fancybox-overlay-fixed','position','fixed','','','.b-fancybox'),(134047,'printshop-mobile','.b-fancybox .fancybox-overlay','position','absolute','','','.b-fancybox'),(134048,'printshop-mobile','.b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner','position','relative','','','.b-fancybox'),(134049,'printshop-mobile','.p-account-history .not_fully_paid_td','position','absolute','','','.p-account-history'),(134050,'printshop-mobile','.p-wedding-registry-share .invite-remove','position','absolute','','','.p-wedding-registry-share'),(134051,'printshop-mobile','.p-wedding-registry-share .address-row','position','relative','','','.p-wedding-registry-share'),(134052,'printshop-mobile','.w-text .customer-service','position','absolute','3','','.w-text'),(134053,'printshop-mobile','.w-text .customer-service','position','relative','','','.w-text'),(134054,'printshop-mobile','.p-account-history .moduleRowDue td','position','relative','','','.p-account-history'),(134055,'printshop-mobile','.w-banner .carousel-text','position','absolute','','','.w-banner'),(134056,'printshop-mobile','.b-form .checkbox-style','position','absolute','','','.b-form'),(134057,'printshop-mobile','.w-banner .carousel .item','position','relative','','','.w-banner'),(134058,'printshop-mobile','.b-slick .slick-list','position','relative','','','.b-slick'),(134059,'printshop-mobile','.b-rating #stars-default .glyphicon','position','relative','','','.b-rating'),(134060,'printshop-mobile','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(134061,'printshop-mobile','.w-cart .cart-box','position','relative','','','.w-cart'),(134062,'printshop-mobile','.w-cart .cart-box.hover-box .cart-content','position','absolute','','','.w-cart'),(134063,'printshop-mobile','.p-reviews-info .review-info-text','position','absolute','4','','.p-reviews-info'),(134064,'printshop-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','position','relative','3','','.w-cart-discount-coupon'),(134065,'printshop-mobile','.w-cart .cart-box-link','position','relative','','','.w-cart'),(134066,'printshop-mobile','.p-account-index .topAccount > li > div','position','absolute','693,3','','.p-account-index'),(134067,'printshop-mobile','.p-account-index .topAccount > li > div','position','relative','693','','.p-account-index'),(134068,'printshop-mobile','.b-form .addresses .address-item input[type=\"radio\"]','position','relative','','','.b-form'),(134069,'printshop-mobile','.p-account-index .account_page h4','position','relative','','','.p-account-index'),(134070,'printshop-mobile','.b-form .hide-billing-address','position','absolute','','','.b-form'),(134071,'printshop-mobile','.p-account-index .account_page h4','position','absolute','3','','.p-account-index'),(134072,'printshop-mobile','.b-form .discount-box input[type=\"text\"]','position','relative','','','.b-form'),(134073,'printshop-mobile','.b-fancybox .filter-listing-preloader','position','absolute','','','.b-fancybox'),(134074,'printshop-mobile','.b-fancybox .filter-listing-loader','position','absolute','','','.b-fancybox'),(134075,'printshop-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(134076,'printshop-mobile','.b-datepicker .datepicker-dropdown','position','absolute','','','.b-datepicker'),(134077,'printshop-mobile','.b-form .columns .col-2','position','relative','','','.b-form'),(134078,'printshop-mobile','.view-all','position','absolute','3','',''),(134079,'printshop-mobile','.view-all','position','relative','','',''),(134080,'printshop-mobile','.w-list-type-1_3 .sale','position','absolute','4','','.w-list-type-1_3'),(134081,'printshop-mobile','.w-list-type-1_3 .sale','position','absolute','','','.w-list-type-1_3'),(134082,'printshop-mobile','.w-list-type-1_3 .sale','position','absolute','3','','.w-list-type-1_3'),(134083,'printshop-mobile','.w-list-type-2 .image','position','relative','','','.w-list-type-2'),(134084,'printshop-mobile','.p-wedding-registry-manage h1','position','relative','3','','.p-wedding-registry-manage'),(134085,'printshop-mobile','.p-wedding-registry-search h1','position','relative','3','','.p-wedding-registry-search'),(134086,'printshop-mobile','.view-all .btn','position','relative','','',''),(134087,'printshop-mobile','.b-autocomplete .ui-autocomplete','position','absolute','','','.b-autocomplete'),(134088,'printshop-mobile','.p-wedding-registry-manage h1','position','relative','4','','.p-wedding-registry-manage'),(134089,'printshop-mobile','.p-wedding-registry-view h1','position','relative','4','','.p-wedding-registry-view'),(134090,'printshop-mobile','.p-wedding-registry-share h1','position','relative','4','','.p-wedding-registry-share'),(134091,'printshop-mobile','.p-wedding-registry-share h1','position','relative','3','','.p-wedding-registry-share'),(134092,'printshop-mobile','.w-list-type-1_3 .image','position','relative','','','.w-list-type-1_3'),(134093,'printshop-mobile','.w-list-type-1_2 .sale','position','absolute','3','','.w-list-type-1_2'),(134094,'printshop-mobile','.w-list-type-1_2 .sale','position','absolute','4','','.w-list-type-1_2'),(134095,'printshop-mobile','.w-list-type-1_2 .sale','position','absolute','','','.w-list-type-1_2'),(134096,'printshop-mobile','.w-list-type-1_2 .image','position','relative','','','.w-list-type-1_2'),(134097,'printshop-mobile','.b-bottom .pop-up-close','position','absolute','','','.b-bottom'),(134098,'printshop-mobile','.p-reviews-info .review-info-text','position','relative','','','.p-reviews-info'),(134099,'printshop-mobile','.w-list-type-1 .sale','position','absolute','4','','.w-list-type-1'),(134100,'printshop-mobile','.w-list-type-1 .sale','position','absolute','3','','.w-list-type-1'),(134101,'printshop-mobile','.w-list-type-1 .sale','position','absolute','','','.w-list-type-1'),(134102,'printshop-mobile','.w-list-type-1 .image','position','relative','','','.w-list-type-1'),(134103,'printshop-mobile','.w-filters .mobileCollapse','position','absolute','','','.w-filters'),(134104,'printshop-mobile','.w-languages .current','position','absolute','3','','.w-languages'),(134105,'printshop-mobile','.w-languages .languages','position','relative','','','.w-languages'),(134106,'printshop-mobile','.w-languages .select','position','absolute','','','.w-languages'),(134107,'printshop-mobile','.w-languages .current','position','relative','','','.w-languages'),(134108,'printshop-mobile','.b-form .billing-address','position','relative','','','.b-form'),(134109,'printshop-mobile','.w-reviews .review','position','absolute','3','','.w-reviews'),(134110,'printshop-mobile','.w-quote .cart-box-link','position','relative','','','.w-quote'),(134111,'printshop-mobile','.w-reviews .heading-3','position','relative','','','.w-reviews'),(134112,'printshop-mobile','.w-reviews .review','position','relative','','','.w-reviews'),(134113,'printshop-mobile','.w-reviews .rating','position','relative','','','.w-reviews'),(134114,'printshop-mobile','.w-search .button-search','position','absolute','','','.w-search'),(134115,'printshop-mobile','.w-reviews .reviews-list span','position','relative','','','.w-reviews'),(134116,'printshop-mobile','.w-search .search form','position','absolute','','','.w-search'),(134117,'printshop-mobile','.b-form .payment-method .item-radio input','position','relative','','','.b-form'),(134118,'printshop-mobile','.b-form .required-message','position','absolute','','','.b-form'),(134119,'printshop-mobile','.b-info .info','position','relative','','','.b-info'),(134120,'printshop-mobile','.b-form .required-message-wrap','position','relative','','','.b-form'),(134121,'printshop-mobile','.b-form .shipping-method .input input','position','relative','','','.b-form'),(134122,'printshop-mobile','.b-form .same-address','position','relative','','','.b-form'),(134123,'printshop-mobile','.b-info .info','position','relative','3','','.b-info'),(134124,'printshop-mobile','.b-info-popup .info-popup','position','relative','3','','.b-info-popup'),(134125,'printshop-mobile','.b-products-listing .hover-box','position','relative','','','.b-products-listing'),(134126,'printshop-mobile','.b-products-listing .hover-box-content','position','absolute','3','','.b-products-listing'),(134127,'printshop-mobile','.b-products-listing .hover-box-content','position','absolute','','','.b-products-listing'),(134128,'printshop-mobile','.b-products-listing .loader','position','absolute','4','','.b-products-listing'),(134129,'printshop-mobile','.b-products-listing .loader','position','absolute','3','','.b-products-listing'),(134130,'printshop-mobile','.b-products-listing .loader','position','relative','','','.b-products-listing'),(134131,'printshop-mobile','.b-products-listing .products-listing .btn-buy','position','relative','3','','.b-products-listing'),(134132,'printshop-mobile','.b-products-listing .products-listing .image','position','relative','','','.b-products-listing'),(134133,'printshop-mobile','.b-products-listing .products-listing .promos-info','position','absolute','','','.b-products-listing'),(134134,'printshop-mobile','.b-products-listing .products-listing .qty-input.hidden','position','absolute','3','','.b-products-listing'),(134135,'printshop-mobile','.b-products-listing .products-listing .radio-attributes input','position','relative','','','.b-products-listing'),(134136,'printshop-mobile','.b-products-listing .promo','position','absolute','','','.b-products-listing'),(134137,'printshop-mobile','.b-products-listing .promo-icon','position','relative','','','.b-products-listing'),(134138,'printshop-mobile','.b-products-listing .promos-info','position','relative','','','.b-products-listing'),(134139,'printshop-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(134140,'printshop-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(134141,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(134142,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(134143,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(134144,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(134145,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(134146,'printshop-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(134147,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(134148,'printshop-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(134149,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(134150,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(134151,'printshop-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(134152,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(134153,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(134154,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(134155,'printshop-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(134156,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(134157,'printshop-mobile','.b-menu-burger_icon .menu-style[data-burger_icon]','position','relative','','','.b-menu-burger_icon'),(134158,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-1 > li','position','relative','','','.b-menu-lev_display-down'),(134159,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','position','absolute','','','.b-menu-lev_display-down'),(134160,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-2 > li','position','relative','','','.b-menu-lev_display-down'),(134161,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','position','absolute','','','.b-menu-lev_display-down'),(134162,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-3 > li','position','relative','','','.b-menu-lev_display-down'),(134163,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','position','absolute','','','.b-menu-lev_display-down'),(134164,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-4 > li','position','relative','','','.b-menu-lev_display-down'),(134165,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','position','absolute','','','.b-menu-lev_display-down'),(134166,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-5 > li','position','relative','','','.b-menu-lev_display-down'),(134167,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','position','absolute','','','.b-menu-lev_display-down'),(134168,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-1 > li','position','relative','','','.b-menu-lev_display-left'),(134169,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','position','absolute','','','.b-menu-lev_display-left'),(134170,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-2 > li','position','relative','','','.b-menu-lev_display-left'),(134171,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','position','absolute','','','.b-menu-lev_display-left'),(134172,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-3 > li','position','relative','','','.b-menu-lev_display-left'),(134173,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','position','absolute','','','.b-menu-lev_display-left'),(134174,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-4 > li','position','relative','','','.b-menu-lev_display-left'),(134175,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','position','absolute','','','.b-menu-lev_display-left'),(134176,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-5 > li','position','relative','','','.b-menu-lev_display-left'),(134177,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','position','absolute','','','.b-menu-lev_display-left'),(134178,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-1 > li','position','relative','','','.b-menu-lev_display-lra'),(134179,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','position','absolute','','','.b-menu-lev_display-lra'),(134180,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-2 > li','position','relative','','','.b-menu-lev_display-lra'),(134181,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','position','absolute','','','.b-menu-lev_display-lra'),(134182,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-3 > li','position','relative','','','.b-menu-lev_display-lra'),(134183,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','position','absolute','','','.b-menu-lev_display-lra'),(134184,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-4 > li','position','relative','','','.b-menu-lev_display-lra'),(134185,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','position','absolute','','','.b-menu-lev_display-lra'),(134186,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-5 > li','position','relative','','','.b-menu-lev_display-lra'),(134187,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','position','absolute','','','.b-menu-lev_display-lra'),(134188,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right'),(134189,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','position','absolute','','','.b-menu-lev_display-right'),(134190,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right'),(134191,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','position','absolute','','','.b-menu-lev_display-right'),(134192,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right'),(134193,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','position','absolute','','','.b-menu-lev_display-right'),(134194,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right'),(134195,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','position','absolute','','','.b-menu-lev_display-right'),(134196,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right'),(134197,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','position','absolute','','','.b-menu-lev_display-right'),(134198,'printshop-mobile','.b-menu-lev_display-right_top .menu-style[data-lev2_display=\"right_top\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right_top'),(134199,'printshop-mobile','.b-menu-lev_display-right_top .menu-style[data-lev3_display=\"right_top\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right_top'),(134200,'printshop-mobile','.b-menu-lev_display-right_top .menu-style[data-lev4_display=\"right_top\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right_top'),(134201,'printshop-mobile','.b-menu-lev_display-right_top .menu-style[data-lev5_display=\"right_top\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right_top'),(134202,'printshop-mobile','.b-menu-lev_display-right_top .menu-style[data-lev6_display=\"right_top\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right_top'),(134203,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .level-1','position','relative','','','.b-menu-lev_display-slide'),(134204,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] .level-2','position','relative','','','.b-menu-lev_display-slide'),(134205,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','position','absolute','','','.b-menu-lev_display-slide'),(134206,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] .level-3','position','relative','','','.b-menu-lev_display-slide'),(134207,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','position','absolute','','','.b-menu-lev_display-slide'),(134208,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] .level-4','position','relative','','','.b-menu-lev_display-slide'),(134209,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','position','absolute','','','.b-menu-lev_display-slide'),(134210,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] .level-5','position','relative','','','.b-menu-lev_display-slide'),(134211,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','position','absolute','','','.b-menu-lev_display-slide'),(134212,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','position','absolute','','','.b-menu-lev_display-slide'),(134213,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width'),(134214,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','position','absolute','','','.b-menu-lev_display-width'),(134215,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width'),(134216,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','position','absolute','','','.b-menu-lev_display-width'),(134217,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width'),(134218,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','position','absolute','','','.b-menu-lev_display-width'),(134219,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width'),(134220,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','position','absolute','','','.b-menu-lev_display-width'),(134221,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width'),(134222,'printshop-mobile','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','position','absolute','','','.b-menu-lev_display-width'),(134223,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width_cont'),(134224,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','position','absolute','','','.b-menu-lev_display-width_cont'),(134225,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width_cont'),(134226,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','position','absolute','','','.b-menu-lev_display-width_cont'),(134227,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width_cont'),(134228,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','position','absolute','','','.b-menu-lev_display-width_cont'),(134229,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width_cont'),(134230,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','position','absolute','','','.b-menu-lev_display-width_cont'),(134231,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width_cont'),(134232,'printshop-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','position','absolute','','','.b-menu-lev_display-width_cont'),(134233,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(134234,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(134235,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(134236,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(134237,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(134238,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','position','fixed','','','.b-menu-open_from-left'),(134239,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','position','absolute','','','.b-menu-style-1'),(134240,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','position','static','','','.b-menu-style-2'),(134241,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','position','relative','','','.b-menu-style-2'),(134242,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','position','absolute','3','','.b-menu-style-2'),(134243,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','position','static','','','.b-menu-style-2'),(134244,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','position','relative','','','.b-menu-style-2'),(134245,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','position','absolute','3','','.b-menu-style-2'),(134246,'printshop-mobile','.b-messages .messMenuButton span','position','relative','','','.b-messages'),(134247,'printshop-mobile','.b-messages .messBtnMenuDelete','position','relative','3','','.b-messages'),(134248,'printshop-mobile','.b-messages .messBtnMenuStarred','position','relative','3','','.b-messages'),(134249,'printshop-mobile','.b-messages span.starred::before','position','relative','','','.b-messages'),(134250,'printshop-mobile','.b-messages .messBtnMenuUnread','position','relative','3','','.b-messages'),(134251,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-messages'),(134252,'printshop-mobile','.b-preloader .preloader','position','absolute','','','.b-preloader'),(134253,'printshop-mobile','.b-preloader .preloader','position','absolute','3','','.b-preloader'),(134254,'printshop-mobile','.b-select-suggest .select2-search','position','relative','','','.b-select-suggest'),(134255,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','position','relative','','','.b-select-suggest'),(134256,'printshop-mobile','.b-select-suggest .select2-search-choice-close','position','absolute','','','.b-select-suggest'),(134257,'printshop-mobile','.b-select-suggest .select2-drop-mask','position','fixed','','','.b-select-suggest'),(134258,'printshop-mobile','.b-select-suggest .select2-drop','position','absolute','','','.b-select-suggest'),(134259,'printshop-mobile','.b-select-suggest .select2-results','position','relative','','','.b-select-suggest'),(134260,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position','absolute','','','.b-select-suggest'),(134261,'printshop-mobile','.b-select-suggest .select2-measure-scrollbar','position','absolute','','','.b-select-suggest'),(134262,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices','position','relative','','','.b-select-suggest'),(134263,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','position','absolute','','','.b-select-suggest'),(134264,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-select-suggest'),(134265,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','position','absolute','','','.b-select-suggest'),(134266,'printshop-mobile','.b-select-suggest .select2-container','position','relative','','','.b-select-suggest'),(134267,'printshop-mobile','.b-upload-file .snapshot','position','absolute','','','.b-upload-file'),(134268,'printshop-mobile','.b-upload-file .upload-remove','position','absolute','','','.b-upload-file'),(134269,'printshop-mobile','.b-upload-files .attach-active-holder .attach-file','position','absolute','','','.b-upload-files'),(134270,'printshop-mobile','.batchPr .w-batch-products .item-holder','position','relative','','','.batchPr'),(134271,'printshop-mobile','.batchPr .checkbox input:checked + span:before','position','static','','','.batchPr'),(134272,'printshop-mobile','.batchPr .checkbox input + span','position','absolute','','','.batchPr'),(134273,'printshop-mobile','.batchPr .batchSelect .checkbox','position','relative','','','.batchPr'),(134274,'printshop-mobile','.batchPr .batchSelect','position','static','','','.batchPr'),(134275,'printshop-mobile','.batchPr .w-batch-selected-products .item','position','relative','','','.batchPr'),(134276,'printshop-mobile','.batchPr .checkbox input:not(checked) + span:before','position','absolute','','','.batchPr'),(134277,'printshop-mobile','.batchPr .batchSelect','position','absolute','','','.batchPr'),(134278,'printshop-mobile','.batchPr .btn-batch-remove','position','absolute','','','.batchPr'),(134279,'printshop-mobile','.bell-ico .heading-2','position','relative','3','','.bell-ico'),(134280,'printshop-mobile','.heading-ordered-items .heading-4','position','relative','3','','.heading-ordered-items'),(134281,'printshop-mobile','.heading-saved-lists .heading-4','position','relative','3','','.heading-saved-lists'),(134282,'printshop-mobile','.heading-settings .heading-4','position','relative','3','','.heading-settings'),(134283,'printshop-mobile','.p-account-samples-history .view_link','position','absolute','4','','.p-account-samples-history'),(134284,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','position','absolute','','','.p-account-samples-history'),(134285,'printshop-mobile','.p-account-samples-history .moduleRowDue td','position','relative','','','.p-account-samples-history'),(134286,'printshop-mobile','.p-account-samples-history .orders-table .item','position','relative','','','.p-account-samples-history'),(134287,'printshop-mobile','.p-account-samples-history .orders-table .item','position','relative','','','.p-account-samples-history'),(134288,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','position','absolute','','','.p-account-samples-history'),(134289,'printshop-mobile','.p-account-samples-history .view_link','position','absolute','4','','.p-account-samples-history'),(134290,'printshop-mobile','.p-account-samples-history .moduleRowDue td','position','relative','','','.p-account-samples-history'),(134291,'printshop-mobile','.p-account-samples-history .orders-table .order-total','position','absolute','','','.p-account-samples-history'),(134292,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','position','absolute','','','.p-account-samples-history'),(134293,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','position','absolute','','','.p-account-samples-history'),(134294,'printshop-mobile','.p-account-samples-history .moduleRowDue td','position','relative','','','.p-account-samples-history'),(134295,'printshop-mobile','.p-account-samples-history .moduleRowDue td','position','relative','','','.p-account-samples-history'),(134296,'printshop-mobile','.p-account-samples-history .orders-table .status-name','position','absolute','','','.p-account-samples-history'),(134297,'printshop-mobile','.p-account-samples-history .orders-table .status-name','position','absolute','','','.p-account-samples-history'),(134298,'printshop-mobile','.p-account-samples-history .orders-table .order-total','position','absolute','','','.p-account-samples-history'),(134299,'printshop-mobile','.p-account-samples-history .view_link','position','relative','','','.p-account-samples-history'),(134300,'printshop-mobile','.p-account-samples-history .orders-table .item','position','relative','','','.p-account-samples-history'),(134301,'printshop-mobile','.p-account-samples-history .orders-table .item','position','relative','','','.p-account-samples-history'),(134302,'printshop-mobile','.p-account-samples-history .orders-table .status-name','position','absolute','','','.p-account-samples-history'),(134303,'printshop-mobile','.p-account-samples-history .view_link','position','absolute','4','','.p-account-samples-history'),(134304,'printshop-mobile','.p-account-samples-history .orders-table .item','position','relative','','','.p-account-samples-history'),(134305,'printshop-mobile','.p-account-samples-history .orders-table .status-name','position','absolute','','','.p-account-samples-history'),(134306,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','position','absolute','','','.p-account-samples-history'),(134307,'printshop-mobile','.p-account-samples-history .orders-table .item','position','relative','','','.p-account-samples-history'),(134308,'printshop-mobile','.p-account-samples-history .orders-table .status-name','position','absolute','','','.p-account-samples-history'),(134309,'printshop-mobile','.p-account-samples-history .view_link','position','absolute','4','','.p-account-samples-history'),(134310,'printshop-mobile','.p-account-samples-history .orders-table .order-total','position','absolute','','','.p-account-samples-history'),(134311,'printshop-mobile','.p-account-samples-history .orders-table .order-total','position','absolute','','','.p-account-samples-history'),(134312,'printshop-mobile','.p-account-samples-history .orders-table .order-total','position','absolute','','','.p-account-samples-history'),(134313,'printshop-mobile','.p-account-samples-history .orders-table .status-name','position','absolute','','','.p-account-samples-history'),(134314,'printshop-mobile','.p-account-samples-history .view_link','position','relative','','','.p-account-samples-history'),(134315,'printshop-mobile','.p-account-samples-history .orders-table .order-total','position','absolute','','','.p-account-samples-history'),(134316,'printshop-mobile','.p-account-samples-history .moduleRowDue td','position','relative','','','.p-account-samples-history'),(134317,'printshop-mobile','.p-account-samples-history .view_link','position','relative','','','.p-account-samples-history'),(134318,'printshop-mobile','.p-account-samples-history .view_link','position','relative','','','.p-account-samples-history'),(134319,'printshop-mobile','.p-account-samples-history .view_link','position','absolute','4','','.p-account-samples-history'),(134320,'printshop-mobile','.p-account-samples-history .moduleRowDue td','position','relative','','','.p-account-samples-history'),(134321,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','position','absolute','','','.p-account-samples-history'),(134322,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','position','absolute','','','.p-account-samples-history'),(134323,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','position','absolute','','','.p-account-samples-history'),(134324,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','position','absolute','','','.p-account-samples-history'),(134325,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','position','absolute','','','.p-account-samples-history'),(134326,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','position','absolute','','','.p-account-samples-history'),(134327,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','position','absolute','','','.p-account-samples-history'),(134328,'printshop-mobile','.p-account-samples-history .view_link','position','relative','','','.p-account-samples-history'),(134329,'printshop-mobile','.p-account-samples-history .view_link','position','relative','','','.p-account-samples-history'),(134330,'printshop-mobile','.p-account-samples-history .view_link','position','absolute','4','','.p-account-samples-history'),(134331,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-samples-history-info'),(134332,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','absolute','3','','.p-account-samples-history-info'),(134333,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-samples-history-info'),(134334,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','position','absolute','','','.p-account-samples-history-info'),(134335,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','absolute','3','','.p-account-samples-history-info'),(134336,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','position','absolute','','','.p-account-samples-history-info'),(134337,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','relative','','','.p-account-samples-history-info'),(134338,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-samples-history-info'),(134339,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-samples-history-info'),(134340,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','absolute','3','','.p-account-samples-history-info'),(134341,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','relative','','','.p-account-samples-history-info'),(134342,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','position','absolute','','','.p-account-samples-history-info'),(134343,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','absolute','3','','.p-account-samples-history-info'),(134344,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','position','absolute','','','.p-account-samples-history-info'),(134345,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-samples-history-info'),(134346,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','relative','','','.p-account-samples-history-info'),(134347,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','absolute','3','','.p-account-samples-history-info'),(134348,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','relative','','','.p-account-samples-history-info'),(134349,'printshop-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-samples-history-info'),(134350,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','relative','','','.p-account-samples-history-info'),(134351,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','absolute','3','','.p-account-samples-history-info'),(134352,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','position','absolute','','','.p-account-samples-history-info'),(134353,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','position','absolute','','','.p-account-samples-history-info'),(134354,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','relative','','','.p-account-samples-history-info'),(134355,'printshop-mobile','.p-catalog-product .prev-next-product','position','fixed','','','.p-catalog-product'),(134356,'printshop-mobile','.p-catalog-product .pn-image','position','absolute','3','','.p-catalog-product'),(134357,'printshop-mobile','.p-payer-order-confirmation .discount-ico','position','relative','3','','.p-payer-order-confirmation'),(134358,'printshop-mobile','.p-payer-order-confirmation .comment-ico','position','relative','3','','.p-payer-order-confirmation'),(134359,'printshop-mobile','.p-payer-order-confirmation .order-ico','position','relative','3','','.p-payer-order-confirmation'),(134360,'printshop-mobile','.p-payer-order-pay .order-ico','position','relative','3','','.p-payer-order-pay'),(134361,'printshop-mobile','.p-payer-order-pay .comment-ico','position','relative','3','','.p-payer-order-pay'),(134362,'printshop-mobile','.p-payer-order-pay .discount-ico','position','relative','3','','.p-payer-order-pay'),(134363,'printshop-mobile','.p-quick-order-index .all-scroll-div','position','fixed','','','.p-quick-order-index'),(134364,'printshop-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(134365,'printshop-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(134366,'printshop-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(134367,'printshop-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(134368,'printshop-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(134369,'printshop-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(134370,'printshop-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(134371,'printshop-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(134372,'printshop-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(134373,'printshop-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(134374,'printshop-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(134375,'printshop-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(134376,'printshop-mobile','.p-sample-checkout-success .page-success > div','position','relative','','','.p-sample-checkout-success'),(134377,'printshop-mobile','.p-sample-checkout-success .page-success','position','relative','','','.p-sample-checkout-success'),(134378,'printshop-mobile','.savings-ico .heading-2','position','relative','3','','.savings-ico'),(134379,'printshop-mobile','.shipping-ico .heading-2','position','relative','3','','.shipping-ico'),(134380,'printshop-mobile','.shipping-ico .heading-2','position','relative','3','','.shipping-ico'),(134381,'printshop-mobile','.shipping-ico .heading-2','position','relative','3','','.shipping-ico'),(134382,'printshop-mobile','.w-account-address-book .heading-4','position','relative','','','.w-account-address-book'),(134383,'printshop-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','position','relative','','','.w-account-addresses-list'),(134384,'printshop-mobile','.w-blog-widget-categories-list a','position','relative','','','.w-blog-widget-categories-list'),(134385,'printshop-mobile','.w-blog-widget-categories-list a','position','absolute','3','','.w-blog-widget-categories-list'),(134386,'printshop-mobile','.w-blog-widget-most-popular-posts a','position','absolute','3','','.w-blog-widget-most-popular-posts'),(134387,'printshop-mobile','.w-blog-widget-most-popular-posts a','position','relative','','','.w-blog-widget-most-popular-posts'),(134388,'printshop-mobile','.w-blog-widget-post-comments-count span','position','relative','','','.w-blog-widget-post-comments-count'),(134389,'printshop-mobile','.w-blog-widget-post-comments-count span','position','absolute','3','','.w-blog-widget-post-comments-count'),(134390,'printshop-mobile','.w-blog-widget-post-linked-products .heading-2','position','relative','','','.w-blog-widget-post-linked-products'),(134391,'printshop-mobile','.w-blog-widget-post-listing .post_comment','position','relative','','','.w-blog-widget-post-listing'),(134392,'printshop-mobile','.w-blog-widget-post-listing .post_comment','position','absolute','3','','.w-blog-widget-post-listing'),(134393,'printshop-mobile','.w-blog-widget-post-share ','position','absolute','4','','.w-blog-widget-post-share'),(134394,'printshop-mobile','.w-blog-widget-post-share ','position','relative','','','.w-blog-widget-post-share'),(134395,'printshop-mobile','.w-cart-bonus-points .btn-remove','position','relative','','','.w-cart-bonus-points'),(134396,'printshop-mobile','.w-cart-bonus-points .title','position','relative','3','','.w-cart-bonus-points'),(134397,'printshop-mobile','.w-cart-compare .remove-cart','position','absolute','','','.w-cart-compare'),(134398,'printshop-mobile','.w-cart-compare .cart-cell > div','position','relative','','','.w-cart-compare'),(134399,'printshop-mobile','.w-cart-compare .atr-col','position','absolute','3','','.w-cart-compare'),(134400,'printshop-mobile','.w-cart-compare .atr-col','position','relative','','','.w-cart-compare'),(134401,'printshop-mobile','.w-cart-credit-amount .btn-remove','position','relative','','','.w-cart-credit-amount'),(134402,'printshop-mobile','.w-catalog-b2b-add-button ','position','fixed','','','.w-catalog-b2b-add-button'),(134403,'printshop-mobile','.w-catalog-compare .compare .checkbox span','position','relative','','','.w-catalog-compare'),(134404,'printshop-mobile','.w-catalog-paging .paging-holder','position','relative','','','.w-catalog-paging'),(134405,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','position','static','','','.w-catalog-paging'),(134406,'printshop-mobile','.w-checkout-billing-address .addresses .address-item label','position','relative','','','.w-checkout-billing-address'),(134407,'printshop-mobile','.w-checkout-billing-address .addresses .address-item label input','position','absolute','','','.w-checkout-billing-address'),(134408,'printshop-mobile','.w-checkout-billing-address .genders-title input','position','relative','','','.w-checkout-billing-address'),(134409,'printshop-mobile','.w-checkout-bonus-points .btn-remove','position','relative','','','.w-checkout-bonus-points'),(134410,'printshop-mobile','.w-checkout-create-account .account-benefits strong','position','relative','3','','.w-checkout-create-account'),(134411,'printshop-mobile','.w-checkout-credit-amount .btn-remove','position','relative','','','.w-checkout-credit-amount'),(134412,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item label input','position','absolute','','','.w-checkout-shipping-address'),(134413,'printshop-mobile','.w-checkout-shipping-address .genders-title input','position','relative','','','.w-checkout-shipping-address'),(134414,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item label','position','relative','','','.w-checkout-shipping-address'),(134415,'printshop-mobile','.w-checkout-shipping-choice input:checked + span','position','relative','','','.w-checkout-shipping-choice'),(134416,'printshop-mobile','.w-checkout-shipping-choice input','position','absolute','','','.w-checkout-shipping-choice'),(134417,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','position','absolute','','','.w-checkout-shipping-choice'),(134418,'printshop-mobile','.w-checkout-terms input[type=\"checkbox\"]','position','relative','','','.w-checkout-terms'),(134419,'printshop-mobile','.w-checkout-terms .required-message-wrap','position','static','','','.w-checkout-terms'),(134420,'printshop-mobile','.w-checkout-terms .terms-box','position','relative','','','.w-checkout-terms'),(134421,'printshop-mobile','.w-coupons-and-vauchers-checkout .btn-remove','position','relative','','','.w-coupons-and-vauchers-checkout'),(134422,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','position','fixed','','','.w-image-maps'),(134423,'printshop-mobile','.w-image-maps .svg-wrap svg','position','absolute','','','.w-image-maps'),(134424,'printshop-mobile','.w-image-maps .svg-wrap','position','relative','','','.w-image-maps'),(134425,'printshop-mobile','.w-multi-cart-actions .cart-actions','position','relative','','','.w-multi-cart-actions'),(134426,'printshop-mobile','.w-neighbour-checkout .bootstrap-switch','position','relative','','','.w-neighbour-checkout'),(134427,'printshop-mobile','.w-personal-gift-status-bar .inform','position','relative','4','','.w-personal-gift-status-bar'),(134428,'printshop-mobile','.w-personal-gift-status-bar .end-date','position','relative','3','','.w-personal-gift-status-bar'),(134429,'printshop-mobile','.w-product-customers-activity .customers-activity','position','fixed','','','.w-product-customers-activity'),(134430,'printshop-mobile','.w-product-customers-activity .close','position','absolute','','','.w-product-customers-activity'),(134431,'printshop-mobile','.w-promotions .prom-multi-discount .products','position','relative','','','.w-promotions'),(134432,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition','position','relative','','','.w-promotions'),(134433,'printshop-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','position','relative','3','','.w-promotions'),(134434,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','position','relative','','','.w-promotions'),(134435,'printshop-mobile','.w-promotions .promo-date','position','relative','','','.w-promotions'),(134436,'printshop-mobile','.w-promotions .promo-cart-discount .slave .content','position','relative','','','.w-promotions'),(134437,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','position','relative','','','.w-promotions'),(134438,'printshop-mobile','.w-promotions .promo-salemaker .discount','position','relative','','','.w-promotions'),(134439,'printshop-mobile','.w-promotions .prom-multi-discount > .heading','position','relative','3','','.w-promotions'),(134440,'printshop-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','position','relative','3','','.w-promotions'),(134441,'printshop-mobile','.w-promotions .icon','position','relative','','','.w-promotions'),(134442,'printshop-mobile','.w-reviews-content .review','position','absolute','3','','.w-reviews-content'),(134443,'printshop-mobile','.w-reviews-content .review','position','relative','','','.w-reviews-content'),(134444,'printshop-mobile','.w-taxable input[type=\"radio\"]','position','relative','','','.w-taxable'),(134445,'printshop-mobile','.w-taxable input[type=\"checkbox\"]','position','relative','','','.w-taxable'),(134446,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(134447,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(134448,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(134449,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(134450,'printshop-mobile','.w-wedding-registry-widgets-delete-link a','position','absolute','4','','.w-wedding-registry-widgets-delete-link'),(134451,'printshop-mobile','.w-wedding-registry-widgets-delete-link a','position','relative','','','.w-wedding-registry-widgets-delete-link'),(134452,'printshop-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','position','relative','','','.w-wedding-registry-widgets-manage-banner'),(134453,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','position','relative','','','.w-wedding-registry-widgets-photos'),(134454,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','position','relative','','','.w-wedding-registry-widgets-photos'),(134455,'printshop-mobile','.w-wedding-registry-widgets-products .remove','position','absolute','','','.w-wedding-registry-widgets-products'),(134456,'printshop-mobile','.w-wedding-registry-widgets-share-link a','position','relative','','','.w-wedding-registry-widgets-share-link'),(134457,'printshop-mobile','.w-wedding-registry-widgets-share-link a','position','absolute','4','','.w-wedding-registry-widgets-share-link'),(134458,'printshop-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position_important','important','','','.b-switch'),(134459,'printshop-mobile','.w-menu .hided.menu > ul','position_important','important','','','.w-menu'),(134460,'printshop-mobile','.b-autocomplete .ui-autocomplete','position_important','important','','','.b-autocomplete'),(134461,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position_important','important','','','.b-select-suggest'),(134462,'printshop-mobile','.w-checkout-billing-address .addresses .address-item label input','position_important','important','','','.w-checkout-billing-address'),(134463,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item label input','position_important','important','','','.w-checkout-shipping-address'),(134464,'printshop-mobile','.w-menu-slider .close','right','10','','','.w-menu-slider'),(134465,'printshop-mobile','.w-menu-big > ul > li > ul','right','0','','','.w-menu-big'),(134466,'printshop-mobile','.w-list-type-2_2 .sale','right','0','4','','.w-list-type-2_2'),(134467,'printshop-mobile','.b-fancybox .fancybox-next span','right','10','','','.b-fancybox'),(134468,'printshop-mobile','.b-pass-strength .pass-strength span','right','10','','','.b-pass-strength'),(134469,'printshop-mobile','.b-info-popup .info-popup.top-left div','right','13','3','','.b-info-popup'),(134470,'printshop-mobile','.b-info-popup .info-popup.top-left div','right','-10','','','.b-info-popup'),(134471,'printshop-mobile','.p-wedding-registry-view h1','right','-10','4','','.p-wedding-registry-view'),(134472,'printshop-mobile','.p-wedding-registry-manage .wr-search button','right','5','','','.p-wedding-registry-manage'),(134473,'printshop-mobile','.p-account-history .orders-table .order-total','right','0','720','','.p-account-history'),(134474,'printshop-mobile','.p-account-index .orders-table .order-total','right','0','720','','.p-account-index'),(134475,'printshop-mobile','.w-list-type-2_2 .sale','right','0','3','','.w-list-type-2_2'),(134476,'printshop-mobile','.w-list-type-2_2 .sale','right','0','','','.w-list-type-2_2'),(134477,'printshop-mobile','.w-list-type-2 .sale','right','0','','','.w-list-type-2'),(134478,'printshop-mobile','.w-list-type-2 .sale','right','0','4','','.w-list-type-2'),(134479,'printshop-mobile','.b-fancybox .fancybox-close','right','0','','','.b-fancybox'),(134480,'printshop-mobile','.b-fancybox .fancybox-next','right','0','','','.b-fancybox'),(134481,'printshop-mobile','.p-wedding-registry-search h1','right','-10','4','','.p-wedding-registry-search'),(134482,'printshop-mobile','.b-bottom .footerTitle','right','0','693,4','','.b-bottom'),(134483,'printshop-mobile','.b-slick button.slick-prev','right','auto','','','.b-slick'),(134484,'printshop-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','right','auto','','','.b-slick'),(134485,'printshop-mobile','.b-slick button.slick-next','right','0','','','.b-slick'),(134486,'printshop-mobile','.w-socials .post_item > div','right','10','3','','.w-socials'),(134487,'printshop-mobile','.w-banner .image-text-banner.top-right .text-banner','right','0','','','.w-banner'),(134488,'printshop-mobile','.w-banner .image-text-banner.middle-right .text-banner','right','0','','','.w-banner'),(134489,'printshop-mobile','.w-banner .image-text-banner.bottom-right .text-banner','right','0','','','.w-banner'),(134490,'printshop-mobile','.w-currencies .current','right','0','3','','.w-currencies'),(134491,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap','right','50','','','.b-fancybox'),(134492,'printshop-mobile','.w-list-type-1_3 #add_all','right','20','','','.w-list-type-1_3'),(134493,'printshop-mobile','.b-fancybox .fancybox-overlay-fixed','right','0','','','.b-fancybox'),(134494,'printshop-mobile','.p-wedding-registry-share .invite-remove','right','0','','','.p-wedding-registry-share'),(134495,'printshop-mobile','.w-list-type-1_3 .sale','right','0','4','','.w-list-type-1_3'),(134496,'printshop-mobile','.w-list-type-1_3 .sale','right','0','','','.w-list-type-1_3'),(134497,'printshop-mobile','.p-wedding-registry-manage h1','right','-10','4','','.p-wedding-registry-manage'),(134498,'printshop-mobile','.w-list-type-1_3 .sale','right','0','3','','.w-list-type-1_3'),(134499,'printshop-mobile','.p-wedding-registry-share h1','right','-10','4','','.p-wedding-registry-share'),(134500,'printshop-mobile','.w-list-type-2 .sale','right','0','3','','.w-list-type-2'),(134501,'printshop-mobile','.w-list-type-1_2 .sale','right','0','3','','.w-list-type-1_2'),(134502,'printshop-mobile','.w-list-type-1_2 .sale','right','0','4','','.w-list-type-1_2'),(134503,'printshop-mobile','.w-list-type-1_2 .sale','right','0','','','.w-list-type-1_2'),(134504,'printshop-mobile','.b-bottom .pop-up-close','right','6','','','.b-bottom'),(134505,'printshop-mobile','.w-list-type-1 .sale','right','0','4','','.w-list-type-1'),(134506,'printshop-mobile','.w-list-type-1 .sale','right','0','3','','.w-list-type-1'),(134507,'printshop-mobile','.w-list-type-1 .sale','right','0','','','.w-list-type-1'),(134508,'printshop-mobile','.w-filters .mobileCollapse','right','12','','','.w-filters'),(134509,'printshop-mobile','.w-languages .current','right','0','3','','.w-languages'),(134510,'printshop-mobile','.w-search .button-search','right','0','','','.w-search'),(134511,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right','100','','','.b-menu-lev_display-left'),(134512,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right','100','','','.b-menu-lev_display-left'),(134513,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right','100','','','.b-menu-lev_display-left'),(134514,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right','100','','','.b-menu-lev_display-left'),(134515,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right','100','','','.b-menu-lev_display-left'),(134516,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right','100','','','.b-menu-lev_display-lra'),(134517,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right','100','','','.b-menu-lev_display-lra'),(134518,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right','100','','','.b-menu-lev_display-lra'),(134519,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right','100','','','.b-menu-lev_display-lra'),(134520,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right','100','','','.b-menu-lev_display-lra'),(134521,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','right','10','3','','.b-menu-style-2'),(134522,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .parent > .no-link','right','40','3','','.b-menu-style-2'),(134523,'printshop-mobile','.b-select-suggest .select2-search-choice-close','right','3','','','.b-select-suggest'),(134524,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','right','0','','','.b-select-suggest'),(134525,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','right','24','','','.b-select-suggest'),(134526,'printshop-mobile','.b-upload-file .snapshot','right','5','','','.b-upload-file'),(134527,'printshop-mobile','.b-upload-file .upload-remove','right','10','','','.b-upload-file'),(134528,'printshop-mobile','.batchPr .w-batch-products .products-listing .slick-next','right','-10','','','.batchPr'),(134529,'printshop-mobile','.batchPr .batchSelect','right','20','','','.batchPr'),(134530,'printshop-mobile','.batchPr .btn-batch-remove','right','0','','','.batchPr'),(134531,'printshop-mobile','.p-account-samples-history .orders-table .order-total','right','0','','','.p-account-samples-history'),(134532,'printshop-mobile','.p-account-samples-history .orders-table .order-total','right','0','','','.p-account-samples-history'),(134533,'printshop-mobile','.p-account-samples-history .orders-table .order-total','right','0','','','.p-account-samples-history'),(134534,'printshop-mobile','.p-account-samples-history .orders-table .order-total','right','0','','','.p-account-samples-history'),(134535,'printshop-mobile','.p-account-samples-history .orders-table .order-total','right','0','','','.p-account-samples-history'),(134536,'printshop-mobile','.p-account-samples-history .orders-table .order-total','right','0','','','.p-account-samples-history'),(134537,'printshop-mobile','.p-catalog-product .next-product','right','0','','','.p-catalog-product'),(134538,'printshop-mobile','.p-catalog-product .next-product .pn-image','right','20','3','','.p-catalog-product'),(134539,'printshop-mobile','.w-account-address-book .btn-del','right','0','','','.w-account-address-book'),(134540,'printshop-mobile','.w-blog-widget-post-linked-products button.slick-next','right','10','','','.w-blog-widget-post-linked-products'),(134541,'printshop-mobile','.w-blog-widget-post-share ','right','100','4','','.w-blog-widget-post-share'),(134542,'printshop-mobile','.w-blog-widget-post-share','right','auto','0,4','','.w-blog-widget-post-share'),(134543,'printshop-mobile','.w-blog-widget-related-posts button.slick-next','right','10','','','.w-blog-widget-related-posts'),(134544,'printshop-mobile','.w-blog-widget-related-posts-by-category button.slick-next','right','10','','','.w-blog-widget-related-posts-by-category'),(134545,'printshop-mobile','.w-cart-compare .dropdown .dropdown-menu','right','0','','','.w-cart-compare'),(134546,'printshop-mobile','.w-cart-compare .atr-col','right','0','3','','.w-cart-compare'),(134547,'printshop-mobile','.w-cart-compare .remove-cart','right','0','','','.w-cart-compare'),(134548,'printshop-mobile','.w-multi-cart-actions .dropdown .dropdown-menu','right','0','','','.w-multi-cart-actions'),(134549,'printshop-mobile','.w-product-customers-activity .customers-activity','right','20','','','.w-product-customers-activity'),(134550,'printshop-mobile','.w-product-customers-activity .close','right','5','','','.w-product-customers-activity'),(134551,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','right','5','','','.w-upload-customer-id-upload-customer-id-form'),(134552,'printshop-mobile','.w-wedding-registry-widgets-products .remove','right','0','','','.w-wedding-registry-widgets-products'),(134553,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap','right_measure','%','','','.b-fancybox'),(134554,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right_measure','%','','','.b-menu-lev_display-left'),(134555,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right_measure','%','','','.b-menu-lev_display-left'),(134556,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right_measure','%','','','.b-menu-lev_display-left'),(134557,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right_measure','%','','','.b-menu-lev_display-left'),(134558,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right_measure','%','','','.b-menu-lev_display-left'),(134559,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right_measure','%','','','.b-menu-lev_display-lra'),(134560,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right_measure','%','','','.b-menu-lev_display-lra'),(134561,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right_measure','%','','','.b-menu-lev_display-lra'),(134562,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right_measure','%','','','.b-menu-lev_display-lra'),(134563,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right_measure','%','','','.b-menu-lev_display-lra'),(134564,'printshop-mobile','.b-info-popup .info-popup.top-left div','rotate','-135','3','','.b-info-popup'),(134565,'printshop-mobile','.b-info-popup .info-popup div','rotate','-45','3','','.b-info-popup'),(134566,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','rotate','45','','','.w-checkout-shipping-choice'),(134567,'printshop-mobile','.w-image-maps circle:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(134568,'printshop-mobile','.w-image-maps rect:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(134569,'printshop-mobile','.w-image-maps polygon:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(134570,'printshop-mobile','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','stroke-width','0','','','.w-image-maps'),(134571,'printshop-mobile','.w-tabs .tab-navigation','table-layout','fixed','','','.w-tabs'),(134572,'printshop-mobile','.w-menu-big li a, .w-menu-big li .no-link','text-align','left','','','.w-menu-big'),(134573,'printshop-mobile','.w-menu-big li li li','text-align','left','','','.w-menu-big'),(134574,'printshop-mobile','.w-menu-slider > ul','text-align','center','','','.w-menu-slider'),(134575,'printshop-mobile','.w-menu-slider .close','text-align','center','','','.w-menu-slider'),(134576,'printshop-mobile','.w-menu-horizontal .box','text-align','center','','','.w-menu-horizontal'),(134577,'printshop-mobile','.w-menu-slider > ul > li > ul','text-align','center','','','.w-menu-slider'),(134578,'printshop-mobile','.w-bestsellers .item','text-align','center','3','','.w-bestsellers'),(134579,'printshop-mobile','.w-menu-slider > ul > li > ul li','text-align','left','','','.w-menu-slider'),(134580,'printshop-mobile','.w-bestsellers .counter','text-align','center','','','.w-bestsellers'),(134581,'printshop-mobile','.b-social-login .social-login','text-align','center','','','.b-social-login'),(134582,'printshop-mobile','.w-tabs .accordion-heading','text-align','center','','','.w-tabs'),(134583,'printshop-mobile','.w-menu-style-1 .box','text-align','center','','','.w-menu-style-1'),(134584,'printshop-mobile','.w-product-sale-ends .left','text-align','center','','','.w-product-sale-ends'),(134585,'printshop-mobile','.w-sale .btn','text-align','center','','','.w-sale'),(134586,'printshop-mobile','.w-login-block .buttons','text-align','right','','','.w-login-block'),(134587,'printshop-mobile','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(134588,'printshop-mobile','.w-menu-horizontal .menu-ico','text-align','center','','','.w-menu-horizontal'),(134589,'printshop-mobile','.w-list-type-2_2 .sale','text-align','center','4','','.w-list-type-2_2'),(134590,'printshop-mobile','.w-sale .image','text-align','center','','','.w-sale'),(134591,'printshop-mobile','.w-sale .badge','text-align','center','','','.w-sale'),(134592,'printshop-mobile','.w-menu-style-1 .menu-ico','text-align','center','','','.w-menu-style-1'),(134593,'printshop-mobile','.w-menu-style-1 > ul','text-align','center','','','.w-menu-style-1'),(134594,'printshop-mobile','.w-menu-slider .menu-ico','text-align','center','','','.w-menu-slider'),(134595,'printshop-mobile','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(134596,'printshop-mobile','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(134597,'printshop-mobile','.w-product-collection .item','text-align','center','','','.w-product-collection'),(134598,'printshop-mobile','.w-cart .price','text-align','right','','','.w-cart'),(134599,'printshop-mobile','.b-fancybox .fancybox-nav span','text-align','center','','','.b-fancybox'),(134600,'printshop-mobile','.p-reviews-info .review-info-image','text-align','center','','','.p-reviews-info'),(134601,'printshop-mobile','.b-product-images .additional-images .item > div, .b-product-images .additional-videos .item > div','text-align','center','','','.b-product-images'),(134602,'printshop-mobile','.w-product-buttons .btn, .w-product-buttons .btn-2, .w-product-buttons .btn-3, .w-product-buttons .btn-4','text-align','center','','','.w-product-buttons'),(134603,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','text-align','left','','','.p-account-history-info'),(134604,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','text-align','left','3','','.p-account-history-info'),(134605,'printshop-mobile','.p-account-index .badc_bottom','text-align','center','','','.p-account-index'),(134606,'printshop-mobile','.w-categories .categories','text-align','center','','','.w-categories'),(134607,'printshop-mobile','.w-categories .item','text-align','center','','','.w-categories'),(134608,'printshop-mobile','.w-cart-checkout-btn a','text-align','center','693','','.w-cart-checkout-btn'),(134609,'printshop-mobile','.b-price-box .price-box','text-align','right','','','.b-price-box'),(134610,'printshop-mobile','.w-product-images .images','text-align','center','','','.w-product-images'),(134611,'printshop-mobile','.w-success-continue-btn','text-align','center','694','','.w-success-continue-btn'),(134612,'printshop-mobile','.p-account-index .topAccount > li > div','text-align','left','693','','.p-account-index'),(134613,'printshop-mobile','.w-catalog-listing-look .b2b','text-align','center','','','.w-catalog-listing-look'),(134614,'printshop-mobile','.view-all','text-align','center','','',''),(134615,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','text-align','center','3','','.b-multi-page-checkout'),(134616,'printshop-mobile','.w-list-type-1_2 .image','text-align','center','694','','.w-list-type-1_2'),(134617,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','text-align','center','','','.b-multi-page-checkout'),(134618,'printshop-mobile','.b-multi-page-checkout .messageBox .info','text-align','left','','','.b-multi-page-checkout'),(134619,'printshop-mobile','.p-wedding-registry-manage .remove','text-align','right','','','.p-wedding-registry-manage'),(134620,'printshop-mobile','.w-delivery-location-top-location-list .deliveryName','text-align','center','','','.w-delivery-location-top-location-list'),(134621,'printshop-mobile','.p-account-history-info .trackings-nambers','text-align','center','','','.p-account-history-info'),(134622,'printshop-mobile','.p-account-history-info .popup-tracking-number','text-align','center','','','.p-account-history-info'),(134623,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','text-align','left','','','.p-account-order-pay'),(134624,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','text-align','left','3','','.p-account-order-pay'),(134625,'printshop-mobile','.p-account-order-pay .historyTotal table td','text-align','right','','','.p-account-order-pay'),(134626,'printshop-mobile','.p-account-order-pay .tableForm th','text-align','left','','','.p-account-order-pay'),(134627,'printshop-mobile','.w-product-configurator .pc_qty','text-align','left','693','','.w-product-configurator'),(134628,'printshop-mobile','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(134629,'printshop-mobile','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(134630,'printshop-mobile','.b-pagination .pagination .prev-pages','text-align','center','','','.b-pagination'),(134631,'printshop-mobile','.b-bottom .confirm-popup .confirm-text','text-align','center','','','.b-bottom'),(134632,'printshop-mobile','.b-bottom .confirm-popup .buttons','text-align','center','','','.b-bottom'),(134633,'printshop-mobile','.b-pagination .pagination .prev','text-align','center','','','.b-pagination'),(134634,'printshop-mobile','.b-pagination .pagination .page-number','text-align','center','','','.b-pagination'),(134635,'printshop-mobile','.b-pagination .pagination .p-blog-index','text-align','right','','','.b-pagination'),(134636,'printshop-mobile','.b-pagination .pagination .next','text-align','center','','','.b-pagination'),(134637,'printshop-mobile','.b-pagination .pagination .next-pages','text-align','center','','','.b-pagination'),(134638,'printshop-mobile','.b-pagination .pagination span','text-align','center','2','','.b-pagination'),(134639,'printshop-mobile','.p-account-history .orders-table td.td-alignright','text-align','right','','','.p-account-history'),(134640,'printshop-mobile','.p-account-history .orders-table th','text-align','left','','','.p-account-history'),(134641,'printshop-mobile','.p-account-history-info .tableForm th','text-align','left','','','.p-account-history-info'),(134642,'printshop-mobile','.p-blog-index .nav-next','text-align','right','','','.p-blog-index'),(134643,'printshop-mobile','.p-blog-index .form-submit','text-align','right','','','.p-blog-index'),(134644,'printshop-mobile','.pop-up-content .buttons .btn-2','text-align','center','694','',''),(134645,'printshop-mobile','.pop-up-content .buttons .btn','text-align','center','694','',''),(134646,'printshop-mobile','.no-found','text-align','center','','',''),(134647,'printshop-mobile','.w-list-type-2_2 .item','text-align','left','','','.w-list-type-2_2'),(134648,'printshop-mobile','.w-list-type-2_2 .image','text-align','center','','','.w-list-type-2_2'),(134649,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','text-align','left','','','.w-list-type-2_2'),(134650,'printshop-mobile','.w-list-type-2_2 .button-view a','text-align','left','','','.w-list-type-2_2'),(134651,'printshop-mobile','.w-product-bonus-points > div > div','text-align','center','','','.w-product-bonus-points'),(134652,'printshop-mobile','.w-account .account-title','text-align','center','','','.w-account'),(134653,'printshop-mobile','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(134654,'printshop-mobile','.b-fancybox .fancybox-close','text-align','center','','','.b-fancybox'),(134655,'printshop-mobile','.w-menu-horizontal ul ul li','text-align','left','','','.w-menu-horizontal'),(134656,'printshop-mobile','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(134657,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','text-align','center','3','','.b-form'),(134658,'printshop-mobile','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(134659,'printshop-mobile','.b-form .wedding-form .heading-2','text-align','left','','','.b-form'),(134660,'printshop-mobile','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(134661,'printshop-mobile','.p-quote-cart-index .w-quote-checkout-btn','text-align','right','','','.p-quote-cart-index'),(134662,'printshop-mobile','.p-wedding-registry-index .middle-box','text-align','center','','','.p-wedding-registry-index'),(134663,'printshop-mobile','.p-wedding-registry-manage .links','text-align','center','','','.p-wedding-registry-manage'),(134664,'printshop-mobile','.b-bottom .alert-message','text-align','center','','','.b-bottom'),(134665,'printshop-mobile','.p-wedding-registry-manage .wedding-date','text-align','center','','','.p-wedding-registry-manage'),(134666,'printshop-mobile','.p-wedding-registry-share .heading-3','text-align','center','','','.p-wedding-registry-share'),(134667,'printshop-mobile','.p-wedding-registry-search .result-table td:nth-child(4)','text-align','right','','','.p-wedding-registry-search'),(134668,'printshop-mobile','.p-wedding-registry-search #searchform-status label','text-align','right','','','.p-wedding-registry-search'),(134669,'printshop-mobile','.p-wedding-registry-search .button','text-align','right','','','.p-wedding-registry-search'),(134670,'printshop-mobile','.b-pagination .pagination a','text-align','center','','','.b-pagination'),(134671,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','text-align','center','3','','.b-switch'),(134672,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','text-align','center','3','','.b-switch'),(134673,'printshop-mobile','.b-compare .compare-head','text-align','left','','','.b-compare'),(134674,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-align','left','','','.b-switch'),(134675,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-label','text-align','center','','','.b-switch'),(134676,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-align','right','','','.b-switch'),(134677,'printshop-mobile','.b-switch .bootstrap-switch','text-align','left','','','.b-switch'),(134678,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','text-align','center','','','.b-slick'),(134679,'printshop-mobile','.b-form .center-buttons','text-align','center','','','.b-form'),(134680,'printshop-mobile','.w-top-categories .item','text-align','center','','','.w-top-categories'),(134681,'printshop-mobile','.w-top-categories .categories','text-align','center','','','.w-top-categories'),(134682,'printshop-mobile','.w-search .suggest','text-align','left','','','.w-search'),(134683,'printshop-mobile','.w-tabs .tab-a','text-align','center','','','.w-tabs'),(134684,'printshop-mobile','.w-search .search','text-align','center','3','','.w-search'),(134685,'printshop-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','text-align','center','','','.w-banner'),(134686,'printshop-mobile','.p-account-trade-form .widget h3','text-align','center','','','.p-account-trade-form'),(134687,'printshop-mobile','.p-checkout-index .shipping-estimator .info','text-align','center','','','.p-checkout-index'),(134688,'printshop-mobile','.p-quote-cart-index .cart-page .empty','text-align','center','','','.p-quote-cart-index'),(134689,'printshop-mobile','.p-shopping-cart-index .cart-page .empty','text-align','center','','','.p-shopping-cart-index'),(134690,'printshop-mobile','.w-filters .handle-to','text-align','right','','','.w-filters'),(134691,'printshop-mobile','.w-compare-box-item .checkbox:checked + span:before','text-align','center','','','.w-compare-box-item'),(134692,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap','text-align','center','','','.b-fancybox'),(134693,'printshop-mobile','.p-account-trade-form .trade-form-area','text-align','center','','','.p-account-trade-form'),(134694,'printshop-mobile','.w-menu .hided.menu ul li','text-align','left','720','','.w-menu'),(134695,'printshop-mobile','.p-account-index th.wish_remove_title, .p-account-index td.acc_wish_remove','text-align','center','','','.p-account-index'),(134696,'printshop-mobile','.p-account-index th, .p-account-index td','text-align','left','','','.p-account-index'),(134697,'printshop-mobile','.p-account-index td.td-alignright','text-align','right','','','.p-account-index'),(134698,'printshop-mobile','.p-checkout-success .page-success','text-align','center','','','.p-checkout-success'),(134699,'printshop-mobile','.w-menu-mobile .menu-ico','text-align','center','','','.w-menu-mobile'),(134700,'printshop-mobile','.p-account-index .topAccount > li > div','text-align','center','','','.p-account-index'),(134701,'printshop-mobile','.p-account-index .topAccount > li > div','text-align','center','3','','.p-account-index'),(134702,'printshop-mobile','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(134703,'printshop-mobile','.w-catalog-listing-look .list','text-align','center','','','.w-catalog-listing-look'),(134704,'printshop-mobile','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(134705,'printshop-mobile','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(134706,'printshop-mobile','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(134707,'printshop-mobile','.w-menu-style-1 ul ul li','text-align','left','','','.w-menu-style-1'),(134708,'printshop-mobile','.p-account-history-info .historyTotal table td','text-align','right','','','.p-account-history-info'),(134709,'printshop-mobile','.p-wedding-registry-share .add-row','text-align','right','','','.p-wedding-registry-share'),(134710,'printshop-mobile','.w-sale .left','text-align','center','','','.w-sale'),(134711,'printshop-mobile','.b-page-name .page-name','text-align','center','','','.b-page-name'),(134712,'printshop-mobile','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(134713,'printshop-mobile','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(134714,'printshop-mobile','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(134715,'printshop-mobile','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(134716,'printshop-mobile','.w-list-type-1_3 .image','text-align','center','694','','.w-list-type-1_3'),(134717,'printshop-mobile','.w-catalog-listing-look .grid','text-align','center','','','.w-catalog-listing-look'),(134718,'printshop-mobile','.p-account-index .orders-table th','text-align','left','','','.p-account-index'),(134719,'printshop-mobile','.w-cart-give-away .ga_img','text-align','center','','','.w-cart-give-away'),(134720,'printshop-mobile','.heading-2, h2','text-align','center','','',''),(134721,'printshop-mobile','h1','text-align','center','','',''),(134722,'printshop-mobile','.w-list-type-1_3 .sale','text-align','center','4','','.w-list-type-1_3'),(134723,'printshop-mobile','.w-list-type-2 .button-view a','text-align','left','','','.w-list-type-2'),(134724,'printshop-mobile','.w-list-type-2 .sale','text-align','center','4','','.w-list-type-2'),(134725,'printshop-mobile','.w-list-type-2 .item','text-align','left','','','.w-list-type-2'),(134726,'printshop-mobile','.w-list-type-2 .button-wishlist button','text-align','left','','','.w-list-type-2'),(134727,'printshop-mobile','.w-list-type-1_3 .image','text-align','center','','','.w-list-type-1_3'),(134728,'printshop-mobile','.w-list-type-1_3 .item','text-align','left','','','.w-list-type-1_3'),(134729,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','text-align','left','','','.w-list-type-1_3'),(134730,'printshop-mobile','.w-list-type-1_3 .button-view a','text-align','left','','','.w-list-type-1_3'),(134731,'printshop-mobile','.w-list-type-1_2 .sale','text-align','center','4','','.w-list-type-1_2'),(134732,'printshop-mobile','.w-list-type-1_2 .item','text-align','left','','','.w-list-type-1_2'),(134733,'printshop-mobile','.w-list-type-1_2 .image','text-align','center','','','.w-list-type-1_2'),(134734,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','text-align','left','','','.w-list-type-1_2'),(134735,'printshop-mobile','.w-list-type-1_2 .button-view a','text-align','left','','','.w-list-type-1_2'),(134736,'printshop-mobile','.b-bottom .pop-up-close','text-align','center','','','.b-bottom'),(134737,'printshop-mobile','.w-list-type-1 .sale','text-align','center','4','','.w-list-type-1'),(134738,'printshop-mobile','.w-list-type-1 .image a','text-align','center','','','.w-list-type-1'),(134739,'printshop-mobile','.w-list-type-1 .image','text-align','center','','','.w-list-type-1'),(134740,'printshop-mobile','.w-list-type-1 .item','text-align','left','','','.w-list-type-1'),(134741,'printshop-mobile','.w-list-type-1 .button-wishlist button','text-align','left','','','.w-list-type-1'),(134742,'printshop-mobile','.w-list-type-1 .button-view a','text-align','left','','','.w-list-type-1'),(134743,'printshop-mobile','.p-account-address-book .address_book h2','text-align','right','','','.p-account-address-book'),(134744,'printshop-mobile','.b-products-listing .btn-choose-options','text-align','center','','','.b-products-listing'),(134745,'printshop-mobile','.b-products-listing .products-listing','text-align','center','','','.b-products-listing'),(134746,'printshop-mobile','.b-products-listing .products-listing .btn-buy','text-align','center','','','.b-products-listing'),(134747,'printshop-mobile','.b-products-listing .products-listing .btn-preloader','text-align','center','','','.b-products-listing'),(134748,'printshop-mobile','.b-products-listing .products-listing .buyButton .btn','text-align','center','','','.b-products-listing'),(134749,'printshop-mobile','.b-products-listing .products-listing .image','text-align','center','','','.b-products-listing'),(134750,'printshop-mobile','.b-products-listing .products-listing .in-cart','text-align','center','','','.b-products-listing'),(134751,'printshop-mobile','.b-products-listing .products-listing .mult-qty-input','text-align','right','','','.b-products-listing'),(134752,'printshop-mobile','.b-products-listing .products-listing .properties','text-align','left','','','.b-products-listing'),(134753,'printshop-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','text-align','left','','','.b-products-listing'),(134754,'printshop-mobile','.b-products-listing .show-ofstock-products','text-align','center','','','.b-products-listing'),(134755,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.b-data-table'),(134756,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.b-data-table'),(134757,'printshop-mobile','.b-data-table .dt-body-center','text-align','center','','','.b-data-table'),(134758,'printshop-mobile','.b-data-table table.dataTable tbody td:last-child','text-align','right','','','.b-data-table'),(134759,'printshop-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(134760,'printshop-mobile','.b-email .qty','text-align','center','','','.b-email'),(134761,'printshop-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(134762,'printshop-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(134763,'printshop-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(134764,'printshop-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(134765,'printshop-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(134766,'printshop-mobile','.b-email .price','text-align','right','','','.b-email'),(134767,'printshop-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(134768,'printshop-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(134769,'printshop-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(134770,'printshop-mobile','.b-email .price','text-align','right','','','.b-email'),(134771,'printshop-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(134772,'printshop-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(134773,'printshop-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(134774,'printshop-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(134775,'printshop-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(134776,'printshop-mobile','.b-email .price','text-align','right','','','.b-email'),(134777,'printshop-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(134778,'printshop-mobile','.b-email .price','text-align','right','','','.b-email'),(134779,'printshop-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(134780,'printshop-mobile','.b-email .price','text-align','right','','','.b-email'),(134781,'printshop-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(134782,'printshop-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(134783,'printshop-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(134784,'printshop-mobile','.b-email .model','text-align','center','','','.b-email'),(134785,'printshop-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(134786,'printshop-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(134787,'printshop-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(134788,'printshop-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(134789,'printshop-mobile','.b-email .model','text-align','center','','','.b-email'),(134790,'printshop-mobile','.b-email .model','text-align','center','','','.b-email'),(134791,'printshop-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(134792,'printshop-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(134793,'printshop-mobile','.b-email .model','text-align','center','','','.b-email'),(134794,'printshop-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(134795,'printshop-mobile','.b-email .price','text-align','right','','','.b-email'),(134796,'printshop-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(134797,'printshop-mobile','.b-email .model','text-align','center','','','.b-email'),(134798,'printshop-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(134799,'printshop-mobile','.b-email .qty','text-align','center','','','.b-email'),(134800,'printshop-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(134801,'printshop-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(134802,'printshop-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(134803,'printshop-mobile','.b-email .qty','text-align','center','','','.b-email'),(134804,'printshop-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(134805,'printshop-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(134806,'printshop-mobile','.b-email .qty','text-align','center','','','.b-email'),(134807,'printshop-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(134808,'printshop-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(134809,'printshop-mobile','.b-email .model','text-align','center','','','.b-email'),(134810,'printshop-mobile','.b-email .qty','text-align','center','','','.b-email'),(134811,'printshop-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(134812,'printshop-mobile','.b-email .qty','text-align','center','','','.b-email'),(134813,'printshop-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(134814,'printshop-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(134815,'printshop-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(134816,'printshop-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(134817,'printshop-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(134818,'printshop-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(134819,'printshop-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(134820,'printshop-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(134821,'printshop-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(134822,'printshop-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(134823,'printshop-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(134824,'printshop-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(134825,'printshop-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(134826,'printshop-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(134827,'printshop-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(134828,'printshop-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(134829,'printshop-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(134830,'printshop-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(134831,'printshop-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(134832,'printshop-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(134833,'printshop-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(134834,'printshop-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(134835,'printshop-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(134836,'printshop-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(134837,'printshop-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','text-align','center','','','.b-menu-burger_icon'),(134838,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(134839,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(134840,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(134841,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(134842,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(134843,'printshop-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(134844,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','text-align','center','','','.b-menu-style-2'),(134845,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','text-align','center','','','.b-menu-style-2'),(134846,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','text-align','right','','','.b-menu-style-2'),(134847,'printshop-mobile','.b-messages .msv_to_cc, .b-messages .msv_btn','text-align','left','','','.b-messages'),(134848,'printshop-mobile','.b-messages .msv_content','text-align','left','','','.b-messages'),(134849,'printshop-mobile','.b-messages .attach-view','text-align','left','','','.b-messages'),(134850,'printshop-mobile','.b-messages .msv_history','text-align','left','','','.b-messages'),(134851,'printshop-mobile','.b-messages .development-content','text-align','left','','','.b-messages'),(134852,'printshop-mobile','.b-messages .messages-sidebar .heading-2','text-align','center','','','.b-messages'),(134853,'printshop-mobile','.b-messages .messages-sidebar .btn-2','text-align','center','','','.b-messages'),(134854,'printshop-mobile','.b-messages .emailBtn','text-align','right','','','.b-messages'),(134855,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','text-align','left','','','.b-messages'),(134856,'printshop-mobile','.b-personal-catalog-popup #personal_catalog_popup','text-align','left','','','.b-personal-catalog-popup'),(134857,'printshop-mobile','.b-sub-totals .historyTotal table td','text-align','right','','','.b-sub-totals'),(134858,'printshop-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(134859,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(134860,'printshop-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(134861,'printshop-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(134862,'printshop-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(134863,'printshop-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(134864,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(134865,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(134866,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(134867,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(134868,'printshop-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(134869,'printshop-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(134870,'printshop-mobile','.b-trade-approval .steps-bar li','text-align','center','','','.b-trade-approval'),(134871,'printshop-mobile','.b-trade-approval .steps-bar li a','text-align','center','','','.b-trade-approval'),(134872,'printshop-mobile','.b-trade-approval .orders-table td:nth-child(1), .b-trade-approval .orders-table th:nth-child(1)','text-align','left','','','.b-trade-approval'),(134873,'printshop-mobile','.b-trade-approval .orders-table td:nth-child(2)','text-align','right','','','.b-trade-approval'),(134874,'printshop-mobile','.b-trade-approval .w-login-block label','text-align','left','','','.b-trade-approval'),(134875,'printshop-mobile','.b-trade-approval .steps-bar','text-align','left','','','.b-trade-approval'),(134876,'printshop-mobile','.b-trade-approval .center-buttons','text-align','center','','','.b-trade-approval'),(134877,'printshop-mobile','.b-trade-approval .comments','text-align','left','','','.b-trade-approval'),(134878,'printshop-mobile','.b-upload-file .upload-file-template','text-align','center','','','.b-upload-file'),(134879,'printshop-mobile','.b-upload-file .snapshot','text-align','center','','','.b-upload-file'),(134880,'printshop-mobile','.batchPr .w-batch-products .products-listing .image + .type-1','text-align','left','','','.batchPr'),(134881,'printshop-mobile','.batchPr .checkbox input:not(checked) + span:before','text-align','center','','','.batchPr'),(134882,'printshop-mobile','.batchPr .checkbox input + span','text-align','center','','','.batchPr'),(134883,'printshop-mobile','.batchPr .btn-batch-remove','text-align','center','3','','.batchPr'),(134884,'printshop-mobile','.batchPr .buttons','text-align','center','','','.batchPr'),(134885,'printshop-mobile','.batchPr .batchSelect .checkbox','text-align','center','','','.batchPr'),(134886,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','text-align','left','','','.batchPr'),(134887,'printshop-mobile','.batchPr .checkbox input:checked + span:before','text-align','center','','','.batchPr'),(134888,'printshop-mobile','.batchPr .batch-selected-products-empty','text-align','center','','','.batchPr'),(134889,'printshop-mobile','.batchPr .batch-selected-products-total','text-align','center','','','.batchPr'),(134890,'printshop-mobile','.p-account-samples-history .orders-table th','text-align','left','','','.p-account-samples-history'),(134891,'printshop-mobile','.p-account-samples-history .orders-table th','text-align','left','','','.p-account-samples-history'),(134892,'printshop-mobile','.p-account-samples-history .orders-table td.td-alignright','text-align','right','','','.p-account-samples-history'),(134893,'printshop-mobile','.p-account-samples-history .orders-table th','text-align','left','','','.p-account-samples-history'),(134894,'printshop-mobile','.p-account-samples-history .orders-table td.td-alignright','text-align','right','','','.p-account-samples-history'),(134895,'printshop-mobile','.p-account-samples-history .orders-table th','text-align','left','','','.p-account-samples-history'),(134896,'printshop-mobile','.p-account-samples-history .orders-table td.td-alignright','text-align','right','','','.p-account-samples-history'),(134897,'printshop-mobile','.p-account-samples-history .orders-table th','text-align','left','','','.p-account-samples-history'),(134898,'printshop-mobile','.p-account-samples-history .orders-table td.td-alignright','text-align','right','','','.p-account-samples-history'),(134899,'printshop-mobile','.p-account-samples-history .orders-table td.td-alignright','text-align','right','','','.p-account-samples-history'),(134900,'printshop-mobile','.p-account-samples-history .orders-table th','text-align','left','','','.p-account-samples-history'),(134901,'printshop-mobile','.p-account-samples-history .orders-table td.td-alignright','text-align','right','','','.p-account-samples-history'),(134902,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','','','.p-account-samples-history-info'),(134903,'printshop-mobile','.p-account-samples-history-info .trackings-nambers','text-align','center','','','.p-account-samples-history-info'),(134904,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','text-align','center','','','.p-account-samples-history-info'),(134905,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','3','','.p-account-samples-history-info'),(134906,'printshop-mobile','.p-account-samples-history-info .tableForm th','text-align','left','','','.p-account-samples-history-info'),(134907,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','text-align','center','','','.p-account-samples-history-info'),(134908,'printshop-mobile','.p-account-samples-history-info .tableForm th','text-align','left','','','.p-account-samples-history-info'),(134909,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','3','','.p-account-samples-history-info'),(134910,'printshop-mobile','.p-account-samples-history-info .tableForm th','text-align','left','','','.p-account-samples-history-info'),(134911,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','','','.p-account-samples-history-info'),(134912,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','','','.p-account-samples-history-info'),(134913,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','text-align','center','','','.p-account-samples-history-info'),(134914,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','3','','.p-account-samples-history-info'),(134915,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','text-align','center','','','.p-account-samples-history-info'),(134916,'printshop-mobile','.p-account-samples-history-info .trackings-nambers','text-align','center','','','.p-account-samples-history-info'),(134917,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','text-align','center','','','.p-account-samples-history-info'),(134918,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','','','.p-account-samples-history-info'),(134919,'printshop-mobile','.p-account-samples-history-info .popup-tracking-number','text-align','center','','','.p-account-samples-history-info'),(134920,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','3','','.p-account-samples-history-info'),(134921,'printshop-mobile','.p-account-samples-history-info .trackings-nambers','text-align','center','','','.p-account-samples-history-info'),(134922,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','3','','.p-account-samples-history-info'),(134923,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','','','.p-account-samples-history-info'),(134924,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','','','.p-account-samples-history-info'),(134925,'printshop-mobile','.p-account-samples-history-info .trackings-nambers','text-align','center','','','.p-account-samples-history-info'),(134926,'printshop-mobile','.p-account-samples-history-info .tableForm th','text-align','left','','','.p-account-samples-history-info'),(134927,'printshop-mobile','.p-account-samples-history-info .trackings-nambers','text-align','center','','','.p-account-samples-history-info'),(134928,'printshop-mobile','.p-account-samples-history-info .tableForm th','text-align','left','','','.p-account-samples-history-info'),(134929,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','3','','.p-account-samples-history-info'),(134930,'printshop-mobile','.p-account-samples-history-info .trackings-nambers','text-align','center','','','.p-account-samples-history-info'),(134931,'printshop-mobile','.p-account-samples-history-info .tableForm th','text-align','left','','','.p-account-samples-history-info'),(134932,'printshop-mobile','.p-catalog-product .prev-next-product','text-align','center','','','.p-catalog-product'),(134933,'printshop-mobile','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align','left','','','.p-quick-order-index'),(134934,'printshop-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','text-align','center','','','.p-quick-order-index'),(134935,'printshop-mobile','.p-quick-order-index .all-scroll-div td + td','text-align','right','','','.p-quick-order-index'),(134936,'printshop-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','text-align','center','','','.p-quick-order-index'),(134937,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.p-quick-order-index'),(134938,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.p-quick-order-index'),(134939,'printshop-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(134940,'printshop-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(134941,'printshop-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(134942,'printshop-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(134943,'printshop-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(134944,'printshop-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(134945,'printshop-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(134946,'printshop-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(134947,'printshop-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(134948,'printshop-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(134949,'printshop-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(134950,'printshop-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(134951,'printshop-mobile','.p-sample-checkout-success .page-success','text-align','center','','','.p-sample-checkout-success'),(134952,'printshop-mobile','.w-account-address-book .button-add','text-align','right','','','.w-account-address-book'),(134953,'printshop-mobile','.w-account-address-book .add_item a','text-align','center','','','.w-account-address-book'),(134954,'printshop-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(134955,'printshop-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(134956,'printshop-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(134957,'printshop-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(134958,'printshop-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(134959,'printshop-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(134960,'printshop-mobile','.w-account-personal-catalog .list-switcher a','text-align','center','','','.w-account-personal-catalog'),(134961,'printshop-mobile','.w-blog-widget-post-date ','text-align','center','','','.w-blog-widget-post-date'),(134962,'printshop-mobile','.w-blog-widget-post-linked-products .heading-2','text-align','center','','','.w-blog-widget-post-linked-products'),(134963,'printshop-mobile','.w-blog-widget-post-listing .post_date','text-align','center','','','.w-blog-widget-post-listing'),(134964,'printshop-mobile','.w-blog-widget-post-listing .post_image','text-align','center','','','.w-blog-widget-post-listing'),(134965,'printshop-mobile','.w-blog-widget-post-listing .post_name','text-align','center','','','.w-blog-widget-post-listing'),(134966,'printshop-mobile','.w-blog-widget-post-title h1','text-align','center','','','.w-blog-widget-post-title'),(134967,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','text-align','center','','','.w-blog-widget-related-posts'),(134968,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_content a','text-align','center','','','.w-blog-widget-related-posts-by-category'),(134969,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_img','text-align','center','','','.w-blog-widget-related-posts-by-category'),(134970,'printshop-mobile','.w-cart-bonus-points .btn-remove','text-align','center','','','.w-cart-bonus-points'),(134971,'printshop-mobile','.w-cart-bonus-points .bonus_points_amount','text-align','center','','','.w-cart-bonus-points'),(134972,'printshop-mobile','.w-cart-credit-amount input','text-align','center','','','.w-cart-credit-amount'),(134973,'printshop-mobile','.w-cart-credit-amount .btn-remove','text-align','center','','','.w-cart-credit-amount'),(134974,'printshop-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','text-align','center','','','.w-catalog-additional-images'),(134975,'printshop-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','text-align','right','','','.w-catalog-b2b-add-button'),(134976,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','text-align','center','','','.w-catalog-compare'),(134977,'printshop-mobile','.w-catalog-paging .prev','text-align','center','','','.w-catalog-paging'),(134978,'printshop-mobile','.w-catalog-paging ','text-align','center','2','','.w-catalog-paging'),(134979,'printshop-mobile','.w-catalog-paging .next','text-align','center','','','.w-catalog-paging'),(134980,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align','center','','','.w-catalog-paging'),(134981,'printshop-mobile','.w-catalog-paging .p-blog-index','text-align','right','','','.w-catalog-paging'),(134982,'printshop-mobile','.w-catalog-paging .page-number','text-align','center','','','.w-catalog-paging'),(134983,'printshop-mobile','.w-catalog-paging .next-pages','text-align','center','','','.w-catalog-paging'),(134984,'printshop-mobile','.w-catalog-paging .prev-pages','text-align','center','','','.w-catalog-paging'),(134985,'printshop-mobile','.w-checkout-bonus-points .bonus_points_amount','text-align','center','','','.w-checkout-bonus-points'),(134986,'printshop-mobile','.w-checkout-bonus-points .btn-remove','text-align','center','','','.w-checkout-bonus-points'),(134987,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','text-align','center','3','','.w-checkout-contact-information'),(134988,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','text-align','center','3','','.w-checkout-contact-information'),(134989,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','text-align','center','3','','.w-checkout-contact-information'),(134990,'printshop-mobile','.w-checkout-credit-amount .btn-remove','text-align','center','','','.w-checkout-credit-amount'),(134991,'printshop-mobile','.w-checkout-credit-amount .cot_gv_amount','text-align','center','','','.w-checkout-credit-amount'),(134992,'printshop-mobile','.w-checkout-terms .required-message','text-align','left','','','.w-checkout-terms'),(134993,'printshop-mobile','.w-checkout-terms .terms-box','text-align','left','','','.w-checkout-terms'),(134994,'printshop-mobile','.w-communication-new-topic .quantity','text-align','center','','','.w-communication-new-topic'),(134995,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(5), .w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(7)','text-align','center','','','.w-communication-new-topic'),(134996,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','text-align','center','','','.w-communication-new-topic'),(134997,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','text-align','center','','','.w-communication-new-topic'),(134998,'printshop-mobile','.w-communication-new-topic .orders-id','text-align','center','','','.w-communication-new-topic'),(134999,'printshop-mobile','.w-communication-new-topic .model','text-align','center','','','.w-communication-new-topic'),(135000,'printshop-mobile','.w-communication-new-topic .date-purchased','text-align','right','','','.w-communication-new-topic'),(135001,'printshop-mobile','.w-communication-post .communication-post-attach','text-align','right','','','.w-communication-post'),(135002,'printshop-mobile','.w-coupons-and-vauchers-checkout .btn-remove','text-align','center','','','.w-coupons-and-vauchers-checkout'),(135003,'printshop-mobile','.w-delivery-day .time-left','text-align','center','','','.w-delivery-day'),(135004,'printshop-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(135005,'printshop-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(135006,'printshop-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(135007,'printshop-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(135008,'printshop-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(135009,'printshop-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(135010,'printshop-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(135011,'printshop-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(135012,'printshop-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(135013,'printshop-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(135014,'printshop-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(135015,'printshop-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(135016,'printshop-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(135017,'printshop-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(135018,'printshop-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(135019,'printshop-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(135020,'printshop-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(135021,'printshop-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(135022,'printshop-mobile','.w-product-customers-activity .customers-activity','text-align','center','','','.w-product-customers-activity'),(135023,'printshop-mobile','.w-product-customers-activity .close','text-align','center','','','.w-product-customers-activity'),(135024,'printshop-mobile','.w-promotions .prom-multi-discount .heading','text-align','center','','','.w-promotions'),(135025,'printshop-mobile','.w-promotions .promo-item','text-align','center','','','.w-promotions'),(135026,'printshop-mobile','.w-promotions .promo-date','text-align','center','','','.w-promotions'),(135027,'printshop-mobile','.w-quote-products .empty','text-align','center','','','.w-quote-products'),(135028,'printshop-mobile','.w-reviews-content .date','text-align','right','','','.w-reviews-content'),(135029,'printshop-mobile','.w-reviews-content .product-image','text-align','center','','','.w-reviews-content'),(135030,'printshop-mobile','.w-top-text .top-text','text-align','center','','','.w-top-text'),(135031,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','text-align','center','','','.w-upload-customer-id-upload-customer-id-form'),(135032,'printshop-mobile','.w-wedding-registry-widgets-products .rating','text-align','right','','','.w-wedding-registry-widgets-products'),(135033,'printshop-mobile','.b-quantity .qty-box input[type=\'text\']','text-align','center','','','.b-quantity'),(135034,'printshop-mobile','.w-success-continue-btn','text-align_important','important','694','','.w-success-continue-btn'),(135035,'printshop-mobile','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align_important','important','','','.p-quick-order-index'),(135036,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align_important','important','','','.w-catalog-paging'),(135037,'printshop-mobile','.w-tabs .accordion-heading','text-decoration','none','','','.w-tabs'),(135038,'printshop-mobile','.w-html_box .socials a','text-decoration','none','1','','.w-html_box'),(135039,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(135040,'printshop-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(135041,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','text-decoration','none','1','','.w-menu-style-1'),(135042,'printshop-mobile','.p-account-index .orders-table a, .p-account-index .order-info a','text-decoration','none','1','','.p-account-index'),(135043,'printshop-mobile','.p-blog-index a','text-decoration','none','1','','.p-blog-index'),(135044,'printshop-mobile','.p-account-history .orders-table a, .p-account-history .order-info a','text-decoration','none','1','','.p-account-history'),(135045,'printshop-mobile','.p-wedding-registry-manage a.remove-btn','text-decoration','none','1','','.p-wedding-registry-manage'),(135046,'printshop-mobile','.b-pagination .pagination span','text-decoration','none','1','','.b-pagination'),(135047,'printshop-mobile','.b-pagination .pagination a','text-decoration','none','1','','.b-pagination'),(135048,'printshop-mobile','.p-account-history .view_link','text-decoration','underline','','','.p-account-history'),(135049,'printshop-mobile','.w-list-type-2_2 .price .old','text-decoration','line-through','','','.w-list-type-2_2'),(135050,'printshop-mobile','.w-chat .w-chat-box a','text-decoration','none','1','','.w-chat'),(135051,'printshop-mobile','.w-chat .w-chat-box a','text-decoration','none','','','.w-chat'),(135052,'printshop-mobile','.w-socials > li a','text-decoration','none','','','.w-socials'),(135053,'printshop-mobile','.w-tabs .tab-a','text-decoration','none','','','.w-tabs'),(135054,'printshop-mobile','.p-account-index .view_link','text-decoration','underline','','','.p-account-index'),(135055,'printshop-mobile','.p-account-index .view_history','text-decoration','underline','','','.p-account-index'),(135056,'printshop-mobile','.w-list-type-1_3 .price .old','text-decoration','line-through','','','.w-list-type-1_3'),(135057,'printshop-mobile','.w-sale .old','text-decoration','line-through','','','.w-sale'),(135058,'printshop-mobile','.b-fancybox .fancybox-nav','text-decoration','none','','','.b-fancybox'),(135059,'printshop-mobile','.b-fancybox a.fancybox-close','text-decoration','none','1','','.b-fancybox'),(135060,'printshop-mobile','.w-cart a.item','text-decoration','none','1','','.w-cart'),(135061,'printshop-mobile','.price .old','text-decoration','line-through','','',''),(135062,'printshop-mobile','.w-list-type-2 .price .old','text-decoration','line-through','','','.w-list-type-2'),(135063,'printshop-mobile','.heading-3 .right-text, h3 .right-text','text-decoration','none','','',''),(135064,'printshop-mobile','.w-list-type-1_2 .price .old','text-decoration','line-through','','','.w-list-type-1_2'),(135065,'printshop-mobile','.w-filters .mobileCollapse','text-decoration','none','1','','.w-filters'),(135066,'printshop-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(135067,'printshop-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(135068,'printshop-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(135069,'printshop-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(135070,'printshop-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(135071,'printshop-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(135072,'printshop-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(135073,'printshop-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(135074,'printshop-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(135075,'printshop-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(135076,'printshop-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(135077,'printshop-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(135078,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','text-decoration','none','','','.b-select-suggest'),(135079,'printshop-mobile','.b-select-suggest .select2-result-selectable .select2-match, .b-select-suggest .select2-result-unselectable .select2-match','text-decoration','underline','','','.b-select-suggest'),(135080,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','text-decoration','none','','','.b-select-suggest'),(135081,'printshop-mobile','.p-account-samples-history .view_link','text-decoration','underline','','','.p-account-samples-history'),(135082,'printshop-mobile','.p-account-samples-history .orders-table a, .p-account-samples-history .order-info a','text-decoration','none','1','','.p-account-samples-history'),(135083,'printshop-mobile','.p-account-samples-history .orders-table a, .p-account-samples-history .order-info a','text-decoration','none','1','','.p-account-samples-history'),(135084,'printshop-mobile','.p-account-samples-history .orders-table a, .p-account-samples-history .order-info a','text-decoration','none','1','','.p-account-samples-history'),(135085,'printshop-mobile','.p-account-samples-history .view_link','text-decoration','underline','','','.p-account-samples-history'),(135086,'printshop-mobile','.p-account-samples-history .view_link','text-decoration','underline','','','.p-account-samples-history'),(135087,'printshop-mobile','.p-account-samples-history .view_link','text-decoration','underline','','','.p-account-samples-history'),(135088,'printshop-mobile','.p-account-samples-history .orders-table a, .p-account-samples-history .order-info a','text-decoration','none','1','','.p-account-samples-history'),(135089,'printshop-mobile','.p-account-samples-history .orders-table a, .p-account-samples-history .order-info a','text-decoration','none','1','','.p-account-samples-history'),(135090,'printshop-mobile','.p-account-samples-history .orders-table a, .p-account-samples-history .order-info a','text-decoration','none','1','','.p-account-samples-history'),(135091,'printshop-mobile','.p-account-samples-history .view_link','text-decoration','underline','','','.p-account-samples-history'),(135092,'printshop-mobile','.p-account-samples-history .view_link','text-decoration','underline','','','.p-account-samples-history'),(135093,'printshop-mobile','.p-catalog-product a.prev-next-product','text-decoration','none','1','','.p-catalog-product'),(135094,'printshop-mobile','.w-account-address-book .add_item a.disabled-link','text-decoration','none','1','','.w-account-address-book'),(135095,'printshop-mobile','.w-account-personal-catalog .list-switcher a','text-decoration','none','','','.w-account-personal-catalog'),(135096,'printshop-mobile','.w-blog-widget-post-share a','text-decoration','none','1','','.w-blog-widget-post-share'),(135097,'printshop-mobile','.w-catalog-paging span','text-decoration','none','1','','.w-catalog-paging'),(135098,'printshop-mobile','.w-catalog-paging a','text-decoration','none','1','','.w-catalog-paging'),(135099,'printshop-mobile','.w-image-maps .categories-items .item a','text-decoration','none','1','','.w-image-maps'),(135100,'printshop-mobile','.w-image-maps .float-items .item a','text-decoration','none','1','','.w-image-maps'),(135101,'printshop-mobile','.w-social-links a','text-decoration','none','1','','.w-social-links'),(135102,'printshop-mobile','.batchPr .btn-batch-remove','text-indent','-33333em','','','.batchPr'),(135103,'printshop-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','text-overflow','ellipsis','','','.b-select-suggest'),(135104,'printshop-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(135105,'printshop-mobile','.p-wedding-registry-index .main-button','text-shadow','0 0','3','','.p-wedding-registry-index'),(135106,'printshop-mobile','.b-fancybox .fancybox-skin','text-shadow','none','','','.b-fancybox'),(135107,'printshop-mobile','.b-fancybox .fancybox-title','text-shadow','none','','','.b-fancybox'),(135108,'printshop-mobile','.p-account-history .order_history_table h2','text-transform','uppercase','','','.p-account-history'),(135109,'printshop-mobile','.p-account-history .order_history_table th','text-transform','none','','','.p-account-history'),(135110,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-history-info'),(135111,'printshop-mobile','.p-account-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-history-info'),(135112,'printshop-mobile','.p-account-index .not_fully_paid_td','text-transform','uppercase','','','.p-account-index'),(135113,'printshop-mobile','.w-categories .name','text-transform','uppercase','','','.w-categories'),(135114,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','text-transform','none','','','.b-multi-page-checkout'),(135115,'printshop-mobile','.w-product-personal-catalog-button .btn','text-transform','none','','','.w-product-personal-catalog-button'),(135116,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','text-transform','uppercase','','','.b-multi-page-checkout'),(135117,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','text-transform','uppercase','','','.p-account-order-pay'),(135118,'printshop-mobile','.p-account-order-pay .not_fully_paid_td','text-transform','uppercase','','','.p-account-order-pay'),(135119,'printshop-mobile','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(135120,'printshop-mobile','.w-product-wedding-registry-button .btn','text-transform','none','','','.w-product-wedding-registry-button'),(135121,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-transform','uppercase','','','.b-switch'),(135122,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-transform','uppercase','','','.b-switch'),(135123,'printshop-mobile','.w-tabs .accordion-heading','text-transform','uppercase','','','.w-tabs'),(135124,'printshop-mobile','.heading-4 .edit, h4 .edit','text-transform','none','','',''),(135125,'printshop-mobile','.w-tabs .tab-a','text-transform','uppercase','','','.w-tabs'),(135126,'printshop-mobile','.heading-4, h4','text-transform','uppercase','','',''),(135127,'printshop-mobile','.heading-2, h2','text-transform','uppercase','','',''),(135128,'printshop-mobile','.p-account-trade-form .widget h3','text-transform','uppercase','','','.p-account-trade-form'),(135129,'printshop-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','text-transform','uppercase','','','.p-account-trade-form'),(135130,'printshop-mobile','.w-filters .filter-box-head','text-transform','uppercase','','','.w-filters'),(135131,'printshop-mobile','.w-filters .head-filter-widget','text-transform','uppercase','','','.w-filters'),(135132,'printshop-mobile','.heading-3 .edit, h3 .edit','text-transform','none','','',''),(135133,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table th','text-transform','none','','','.p-account-subscription-historyinfo'),(135134,'printshop-mobile','.p-account-subscription-historyinfo .order_history_table h2','text-transform','uppercase','','','.p-account-subscription-historyinfo'),(135135,'printshop-mobile','.p-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-checkout-success'),(135136,'printshop-mobile','.heading-3, h3','text-transform','uppercase','','',''),(135137,'printshop-mobile','.p-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-checkout-success'),(135138,'printshop-mobile','.p-account-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-history'),(135139,'printshop-mobile','.w-top-categories .categories h2','text-transform','inherit','','','.w-top-categories'),(135140,'printshop-mobile','.w-categories .categories h2','text-transform','inherit','','','.w-categories'),(135141,'printshop-mobile','.w-top-categories .name','text-transform','uppercase','','','.w-top-categories'),(135142,'printshop-mobile','.p-account-index .date_title','text-transform','uppercase','','','.p-account-index'),(135143,'printshop-mobile','h1','text-transform','uppercase','','',''),(135144,'printshop-mobile','.btn-2','text-transform','uppercase','','',''),(135145,'printshop-mobile','.btn','text-transform','uppercase','','',''),(135146,'printshop-mobile','.btn-1','text-transform','uppercase','','',''),(135147,'printshop-mobile','.btn-3','text-transform','uppercase','','',''),(135148,'printshop-mobile','.heading-4 .right-text, h4 .right-text','text-transform','none','','',''),(135149,'printshop-mobile','.p-account-address-book .leftMes div','text-transform','uppercase','','','.p-account-address-book'),(135150,'printshop-mobile','.p-account-address-book .address_book_row h2 a','text-transform','none','','','.p-account-address-book'),(135151,'printshop-mobile','.p-account-address-book .address_book h2','text-transform','uppercase','','','.p-account-address-book'),(135152,'printshop-mobile','.b-info .info strong','text-transform','uppercase','','','.b-info'),(135153,'printshop-mobile','.b-products-listing .products-listing a.btn.view-button','text-transform','none','','','.b-products-listing'),(135154,'printshop-mobile','.b-products-listing .products-listing h2','text-transform','inherit','','','.b-products-listing'),(135155,'printshop-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','text-transform','inherit','','','.b-h-inline'),(135156,'printshop-mobile','.b-messages .content-messages .heading-2','text-transform','none','','','.b-messages'),(135157,'printshop-mobile','.batchPr .batchSelect .checkbox','text-transform','uppercase','','','.batchPr'),(135158,'printshop-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(135159,'printshop-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(135160,'printshop-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(135161,'printshop-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(135162,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history'),(135163,'printshop-mobile','.p-account-samples-history .order_history_table h2','text-transform','uppercase','','','.p-account-samples-history'),(135164,'printshop-mobile','.p-account-samples-history .order_history_table th','text-transform','none','','','.p-account-samples-history'),(135165,'printshop-mobile','.p-account-samples-history .order_history_table th','text-transform','none','','','.p-account-samples-history'),(135166,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history'),(135167,'printshop-mobile','.p-account-samples-history .order_history_table th','text-transform','none','','','.p-account-samples-history'),(135168,'printshop-mobile','.p-account-samples-history .order_history_table th','text-transform','none','','','.p-account-samples-history'),(135169,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history'),(135170,'printshop-mobile','.p-account-samples-history .order_history_table h2','text-transform','uppercase','','','.p-account-samples-history'),(135171,'printshop-mobile','.p-account-samples-history .order_history_table h2','text-transform','uppercase','','','.p-account-samples-history'),(135172,'printshop-mobile','.p-account-samples-history .order_history_table h2','text-transform','uppercase','','','.p-account-samples-history'),(135173,'printshop-mobile','.p-account-samples-history .order_history_table h2','text-transform','uppercase','','','.p-account-samples-history'),(135174,'printshop-mobile','.p-account-samples-history .order_history_table th','text-transform','none','','','.p-account-samples-history'),(135175,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history'),(135176,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history'),(135177,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history'),(135178,'printshop-mobile','.p-account-samples-history .order_history_table h2','text-transform','uppercase','','','.p-account-samples-history'),(135179,'printshop-mobile','.p-account-samples-history .order_history_table th','text-transform','none','','','.p-account-samples-history'),(135180,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history-info'),(135181,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-samples-history-info'),(135182,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-samples-history-info'),(135183,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history-info'),(135184,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-samples-history-info'),(135185,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-samples-history-info'),(135186,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history-info'),(135187,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history-info'),(135188,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history-info'),(135189,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history-info'),(135190,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-samples-history-info'),(135191,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-samples-history-info'),(135192,'printshop-mobile','.p-catalog-product .pn-direction','text-transform','uppercase','','','.p-catalog-product'),(135193,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(135194,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(135195,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(135196,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(135197,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(135198,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(135199,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(135200,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(135201,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(135202,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(135203,'printshop-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(135204,'printshop-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(135205,'printshop-mobile','.p-sample-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-sample-checkout-success'),(135206,'printshop-mobile','.p-sample-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-sample-checkout-success'),(135207,'printshop-mobile','.w-account-address-book .btn-edit','text-transform','none','','','.w-account-address-book'),(135208,'printshop-mobile','.w-account-personal-catalog .list-switcher a','text-transform','uppercase','','','.w-account-personal-catalog'),(135209,'printshop-mobile','.w-blog-widget-post-listing .post_name a','text-transform','uppercase','','','.w-blog-widget-post-listing'),(135210,'printshop-mobile','.w-blog-widget-post-title h1','text-transform','none','','','.w-blog-widget-post-title'),(135211,'printshop-mobile','.w-blog-widget-related-posts-by-category .post_content a','text-transform','uppercase','','','.w-blog-widget-related-posts-by-category'),(135212,'printshop-mobile','.w-blog-widget-tag-cloud a','text-transform','uppercase','','','.w-blog-widget-tag-cloud'),(135213,'printshop-mobile','.w-cart-compare .cart-name a','text-transform','uppercase','','','.w-cart-compare'),(135214,'printshop-mobile','.w-checkout-shipping-choice span','text-transform','uppercase','','','.w-checkout-shipping-choice'),(135215,'printshop-mobile','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','text-transform','uppercase','','','.w-multi-cart-cart-switcher'),(135216,'printshop-mobile','.w-personal-gift-status-bar .end-date','text-transform','uppercase','','','.w-personal-gift-status-bar'),(135217,'printshop-mobile','.w-personal-gift-status-bar .inform','text-transform','uppercase','','','.w-personal-gift-status-bar'),(135218,'printshop-mobile','.w-promotions .heading-3','text-transform','uppercase','','','.w-promotions'),(135219,'printshop-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','text-transform','none','','','.w-taxable'),(135220,'printshop-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','text-transform','none','','','.w-taxable'),(135221,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_color','#222','','','.b-fancybox'),(135222,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left','0','','','.b-fancybox'),(135223,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left_measure','','','','.b-fancybox'),(135224,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size','2','','','.b-fancybox'),(135225,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size_measure','px','','','.b-fancybox'),(135226,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top','1','','','.b-fancybox'),(135227,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top_measure','px','','','.b-fancybox'),(135228,'printshop-mobile','.w-menu-slider > ul > li > ul','top','100','','','.w-menu-slider'),(135229,'printshop-mobile','.w-menu-slider .close','top','10','','','.w-menu-slider'),(135230,'printshop-mobile','.w-menu-big > ul > li > ul','top','100','','','.w-menu-big'),(135231,'printshop-mobile','.w-menu-horizontal > ul > li > ul','top','100','','','.w-menu-horizontal'),(135232,'printshop-mobile','.w-bestsellers .heading-3','top','0','3','','.w-bestsellers'),(135233,'printshop-mobile','.w-list-type-1 .rating-count','top','-1','','','.w-list-type-1'),(135234,'printshop-mobile','.w-menu-style-1 > ul > li > ul','top','100','','','.w-menu-style-1'),(135235,'printshop-mobile','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(135236,'printshop-mobile','.w-sale .badge','top','10','','','.w-sale'),(135237,'printshop-mobile','.w-product-wedding-registry-button .btn','top','1','3','','.w-product-wedding-registry-button'),(135238,'printshop-mobile','.w-product-wedding-registry-button .btn','top','1','4','','.w-product-wedding-registry-button'),(135239,'printshop-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(135240,'printshop-mobile','.b-fancybox #fancybox-loading','top','50','','','.b-fancybox'),(135241,'printshop-mobile','.b-fancybox .fancybox-nav','top','0','','','.b-fancybox'),(135242,'printshop-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','top','2','3','','.p-account-history-info'),(135243,'printshop-mobile','.p-account-history-info .not_fully_paid_td','top','19','','','.p-account-history-info'),(135244,'printshop-mobile','.p-account-index .not_fully_paid_td','top','19','','','.p-account-index'),(135245,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','top','-2','4','','.b-multi-page-checkout'),(135246,'printshop-mobile','.b-pass-strength .pass-strength span','top','6','','','.b-pass-strength'),(135247,'printshop-mobile','.p-account-index .topAccount > li > div','top','4','693,3','','.p-account-index'),(135248,'printshop-mobile','.p-blog-index .author .avatar','top','-2','','','.p-blog-index'),(135249,'printshop-mobile','.w-menu-mobile .menu-slider .open','top','0','','','.w-menu-mobile'),(135250,'printshop-mobile','.b-info-popup .info-popup.top-left div','top','auto','3','','.b-info-popup'),(135251,'printshop-mobile','.b-info-popup .info-popup.top-left div','top','auto','','','.b-info-popup'),(135252,'printshop-mobile','.w-promo-code .holder','top','2','723,3','','.w-promo-code'),(135253,'printshop-mobile','.b-info-popup .info-popup div','top','-12','','','.b-info-popup'),(135254,'printshop-mobile','.w-promo-code .holder','top','19','3','','.w-promo-code'),(135255,'printshop-mobile','.p-wedding-registry-view h1','top','-4','4','','.p-wedding-registry-view'),(135256,'printshop-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','top','2','3','','.p-account-order-pay'),(135257,'printshop-mobile','.p-account-order-pay .not_fully_paid_td','top','19','','','.p-account-order-pay'),(135258,'printshop-mobile','.testimonials .heading-3','top','0','3','',''),(135259,'printshop-mobile','.testimonials .rating','top','2','','',''),(135260,'printshop-mobile','.testimonials .reviews-list span','top','2','','',''),(135261,'printshop-mobile','.p-wedding-registry-manage .wr-search button','top','1','','','.p-wedding-registry-manage'),(135262,'printshop-mobile','.p-account-history .view_link','top','4','4','','.p-account-history'),(135263,'printshop-mobile','.w-product-personal-catalog-button .btn','top','1','3','','.w-product-personal-catalog-button'),(135264,'printshop-mobile','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(135265,'printshop-mobile','.b-fancybox .fancybox-close','top','0','','','.b-fancybox'),(135266,'printshop-mobile','.w-menu-horizontal ul ul ul','top','0','','','.w-menu-horizontal'),(135267,'printshop-mobile','.b-form .radio-button input[type=\"radio\"]','top','2','','','.b-form'),(135268,'printshop-mobile','.p-wedding-registry-index .search-list','top','0','3','','.p-wedding-registry-index'),(135269,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','top','1','3','','.b-form'),(135270,'printshop-mobile','.b-form .form-buttons','top','10','','','.b-form'),(135271,'printshop-mobile','.p-wedding-registry-search h1','top','-4','3','','.p-wedding-registry-search'),(135272,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','top','4','3','','.b-switch'),(135273,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','top','4','3','','.b-switch'),(135274,'printshop-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','top','0','','','.b-switch'),(135275,'printshop-mobile','.w-currencies .select','top','46','702','','.w-currencies'),(135276,'printshop-mobile','.w-languages .select','top','46','702','','.w-languages'),(135277,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container','top','0','','','.b-switch'),(135278,'printshop-mobile','.w-currencies .w-currencies .current','top','10','702,3','','.w-currencies'),(135279,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','top','50','','','.b-slick'),(135280,'printshop-mobile','.b-bottom .footerTitle','top','8','693,4','','.b-bottom'),(135281,'printshop-mobile','.w-search .suggest','top','220','','','.w-search'),(135282,'printshop-mobile','.w-socials .post_item > div','top','10','3','','.w-socials'),(135283,'printshop-mobile','.w-banner .image-text-banner.top-right .text-banner','top','0','','','.w-banner'),(135284,'printshop-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','top','0','','','.w-banner'),(135285,'printshop-mobile','.w-banner .image-text-banner.top-left .text-banner','top','0','','','.w-banner'),(135286,'printshop-mobile','.w-banner .banner img + img','top','0','','','.w-banner'),(135287,'printshop-mobile','.w-banner .image-text-banner.bottom-center .text-banner','top','auto','','','.w-banner'),(135288,'printshop-mobile','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','top','0','','','.w-banner'),(135289,'printshop-mobile','.w-currencies .current','top','1','3','','.w-currencies'),(135290,'printshop-mobile','.w-currencies .select','top','31','','','.w-currencies'),(135291,'printshop-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(135292,'printshop-mobile','.b-slick .slick-vertical button.slick-prev','top','0','','','.b-slick'),(135293,'printshop-mobile','.b-slick .slick-track','top','0','','','.b-slick'),(135294,'printshop-mobile','.b-slick .slick-vertical button.slick-next','top','auto','','','.b-slick'),(135295,'printshop-mobile','.p-checkout-success .page-success','top','-126','3','','.p-checkout-success'),(135296,'printshop-mobile','.p-account-index .view_link','top','4','4','','.p-account-index'),(135297,'printshop-mobile','.b-info-popup .info-popup div','top','15','3','','.b-info-popup'),(135298,'printshop-mobile','.b-fancybox .fancybox-tmp','top','-99999','','','.b-fancybox'),(135299,'printshop-mobile','.w-search .search form','top','100','','','.w-search'),(135300,'printshop-mobile','.b-fancybox .fancybox-wrap','top','0','','','.b-fancybox'),(135301,'printshop-mobile','.w-menu-style-1 ul ul ul','top','0','','','.w-menu-style-1'),(135302,'printshop-mobile','.b-fancybox .fancybox-overlay','top','0','','','.b-fancybox'),(135303,'printshop-mobile','.p-account-history .not_fully_paid_td','top','19','','','.p-account-history'),(135304,'printshop-mobile','.p-wedding-registry-share .invite-remove','top','27','','','.p-wedding-registry-share'),(135305,'printshop-mobile','.w-text .customer-service','top','5','3','','.w-text'),(135306,'printshop-mobile','.w-languages .current','top','10','702,3','','.w-languages'),(135307,'printshop-mobile','.w-banner .carousel-text','top','0','','','.w-banner'),(135308,'printshop-mobile','.b-rating #stars-default .glyphicon','top','1','','','.b-rating'),(135309,'printshop-mobile','.b-fancybox .fancybox-nav span','top','50','','','.b-fancybox'),(135310,'printshop-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','top','3','3','','.w-cart-discount-coupon'),(135311,'printshop-mobile','.p-account-index .account_page h4','top','-4','3','','.p-account-index'),(135312,'printshop-mobile','.b-form .hide-billing-address','top','0','','','.b-form'),(135313,'printshop-mobile','.b-form .form-inputs div.required-message','top','-15','','','.b-form'),(135314,'printshop-mobile','.p-wedding-registry-manage h1','top','-4','4','','.p-wedding-registry-manage'),(135315,'printshop-mobile','.p-wedding-registry-search h1','top','-4','4','','.p-wedding-registry-search'),(135316,'printshop-mobile','.view-all','top','50','3','',''),(135317,'printshop-mobile','.p-wedding-registry-share h1','top','-4','3','','.p-wedding-registry-share'),(135318,'printshop-mobile','.p-wedding-registry-manage h1','top','-4','3','','.p-wedding-registry-manage'),(135319,'printshop-mobile','.p-wedding-registry-share h1','top','-4','4','','.p-wedding-registry-share'),(135320,'printshop-mobile','.p-wedding-registry-view h1','top','-4','3','','.p-wedding-registry-view'),(135321,'printshop-mobile','.b-bottom .pop-up-close','top','7','','','.b-bottom'),(135322,'printshop-mobile','.w-filters .mobileCollapse','top','1','','','.w-filters'),(135323,'printshop-mobile','.w-filters .ui-slider-handle','top','-5','','','.w-filters'),(135324,'printshop-mobile','.w-languages .select','top','31','','','.w-languages'),(135325,'printshop-mobile','.w-languages .current','top','1','3','','.w-languages'),(135326,'printshop-mobile','.b-form .addresses .address-item input[type=\"radio\"]','top','4','','','.b-form'),(135327,'printshop-mobile','.w-product-reviews .reviews-list span','top','2','','','.w-product-reviews'),(135328,'printshop-mobile','.w-reviews .heading-3','top','0','3','','.w-reviews'),(135329,'printshop-mobile','.w-search .button-search','top','0','','','.w-search'),(135330,'printshop-mobile','.w-reviews .rating','top','2','','','.w-reviews'),(135331,'printshop-mobile','.w-reviews .reviews-list span','top','2','','','.w-reviews'),(135332,'printshop-mobile','.b-form .middle-form .required-message','top','-15','','','.b-form'),(135333,'printshop-mobile','.b-form .payment-method .item-radio input','top','5','','','.b-form'),(135334,'printshop-mobile','.b-form .shipping-method .input input','top','2','','','.b-form'),(135335,'printshop-mobile','.b-info .info','top','3','3','','.b-info'),(135336,'printshop-mobile','.b-info-popup .info-popup','top','5','3','','.b-info-popup'),(135337,'printshop-mobile','.b-products-listing .hover-box-content','top','-10','3','','.b-products-listing'),(135338,'printshop-mobile','.b-products-listing .hover-box-content','top','40','','','.b-products-listing'),(135339,'printshop-mobile','.b-products-listing .loader','top','calc(50% - 15px)','4','','.b-products-listing'),(135340,'printshop-mobile','.b-products-listing .loader','top','0','3','','.b-products-listing'),(135341,'printshop-mobile','.b-products-listing .products-listing .btn-buy','top','3','3','','.b-products-listing'),(135342,'printshop-mobile','.b-products-listing .products-listing .promos-info','top','0','','','.b-products-listing'),(135343,'printshop-mobile','.b-products-listing .products-listing .qty-input.hidden','top','0','3','','.b-products-listing'),(135344,'printshop-mobile','.b-products-listing .products-listing .radio-attributes input','top','2','','','.b-products-listing'),(135345,'printshop-mobile','.b-products-listing .promo','top','0','','','.b-products-listing'),(135346,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(135347,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(135348,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(135349,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(135350,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(135351,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(135352,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(135353,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(135354,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(135355,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(135356,'printshop-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(135357,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(135358,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top','100','','','.b-menu-lev_display-down'),(135359,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top','100','','','.b-menu-lev_display-down'),(135360,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top','100','','','.b-menu-lev_display-down'),(135361,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top','100','','','.b-menu-lev_display-down'),(135362,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top','100','','','.b-menu-lev_display-down'),(135363,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','top','0','','','.b-menu-lev_display-left'),(135364,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','top','0','','','.b-menu-lev_display-left'),(135365,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','top','0','','','.b-menu-lev_display-left'),(135366,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','top','0','','','.b-menu-lev_display-left'),(135367,'printshop-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','top','0','','','.b-menu-lev_display-left'),(135368,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','top','0','','','.b-menu-lev_display-lra'),(135369,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','top','0','','','.b-menu-lev_display-lra'),(135370,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','top','0','','','.b-menu-lev_display-lra'),(135371,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','top','0','','','.b-menu-lev_display-lra'),(135372,'printshop-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','top','0','','','.b-menu-lev_display-lra'),(135373,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','top','0','','','.b-menu-lev_display-right'),(135374,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','top','0','','','.b-menu-lev_display-right'),(135375,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','top','0','','','.b-menu-lev_display-right'),(135376,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','top','0','','','.b-menu-lev_display-right'),(135377,'printshop-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','top','0','','','.b-menu-lev_display-right'),(135378,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','top','0','','','.b-menu-lev_display-slide'),(135379,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','top','0','','','.b-menu-lev_display-slide'),(135380,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','top','0','','','.b-menu-lev_display-slide'),(135381,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','top','0','','','.b-menu-lev_display-slide'),(135382,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','top','0','','','.b-menu-lev_display-slide'),(135383,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','top','0','','','.b-menu-open_from-left'),(135384,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','top','8','','','.b-menu-style-1'),(135385,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','top','0','','','.b-menu-style-2'),(135386,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','top','50','3','','.b-menu-style-2'),(135387,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','top','0','','','.b-menu-style-2'),(135388,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','top','50','3','','.b-menu-style-2'),(135389,'printshop-mobile','.b-messages span.starred::before','top','3','','','.b-messages'),(135390,'printshop-mobile','.b-messages .messBtnMenuUnread','top','3','3','','.b-messages'),(135391,'printshop-mobile','.b-messages .messBtnMenuStarred','top','3','3','','.b-messages'),(135392,'printshop-mobile','.b-messages .messBtnMenuDelete','top','3','3','','.b-messages'),(135393,'printshop-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','top','5','','','.b-messages'),(135394,'printshop-mobile','.b-preloader .preloader','top','0','','','.b-preloader'),(135395,'printshop-mobile','.b-preloader .preloader','top','calc(50% - 20px)','3','','.b-preloader'),(135396,'printshop-mobile','.b-select-suggest .select2-search-choice-close','top','4','','','.b-select-suggest'),(135397,'printshop-mobile','.b-select-suggest .select2-drop','top','100','','','.b-select-suggest'),(135398,'printshop-mobile','.b-select-suggest .select2-drop-mask','top','0','','','.b-select-suggest'),(135399,'printshop-mobile','.b-select-suggest .select2-measure-scrollbar','top','-10000','','','.b-select-suggest'),(135400,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','top','8','','','.b-select-suggest'),(135401,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top','0','','','.b-select-suggest'),(135402,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','top','0','','','.b-select-suggest'),(135403,'printshop-mobile','.b-upload-file .upload-remove','top','5','','','.b-upload-file'),(135404,'printshop-mobile','.b-upload-files .attach-active-holder .attach-file','top','-200','','','.b-upload-files'),(135405,'printshop-mobile','.batchPr .batchSelect','top','15','','','.batchPr'),(135406,'printshop-mobile','.batchPr .btn-batch-remove','top','10','','','.batchPr'),(135407,'printshop-mobile','.bell-ico .heading-2','top','5','3','','.bell-ico'),(135408,'printshop-mobile','.heading-ordered-items .heading-4','top','2','3','','.heading-ordered-items'),(135409,'printshop-mobile','.heading-saved-lists .heading-4','top','2','3','','.heading-saved-lists'),(135410,'printshop-mobile','.heading-settings .heading-4','top','2','3','','.heading-settings'),(135411,'printshop-mobile','.p-account-samples-history .view_link','top','4','4','','.p-account-samples-history'),(135412,'printshop-mobile','.p-account-samples-history .view_link','top','4','4','','.p-account-samples-history'),(135413,'printshop-mobile','.p-account-samples-history .view_link','top','4','4','','.p-account-samples-history'),(135414,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','top','19','','','.p-account-samples-history'),(135415,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','top','19','','','.p-account-samples-history'),(135416,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','top','19','','','.p-account-samples-history'),(135417,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','top','19','','','.p-account-samples-history'),(135418,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','top','19','','','.p-account-samples-history'),(135419,'printshop-mobile','.p-account-samples-history .view_link','top','4','4','','.p-account-samples-history'),(135420,'printshop-mobile','.p-account-samples-history .view_link','top','4','4','','.p-account-samples-history'),(135421,'printshop-mobile','.p-account-samples-history .view_link','top','4','4','','.p-account-samples-history'),(135422,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','top','19','','','.p-account-samples-history'),(135423,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','top','2','3','','.p-account-samples-history-info'),(135424,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','top','19','','','.p-account-samples-history-info'),(135425,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','top','19','','','.p-account-samples-history-info'),(135426,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','top','2','3','','.p-account-samples-history-info'),(135427,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','top','2','3','','.p-account-samples-history-info'),(135428,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','top','2','3','','.p-account-samples-history-info'),(135429,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','top','2','3','','.p-account-samples-history-info'),(135430,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','top','19','','','.p-account-samples-history-info'),(135431,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','top','19','','','.p-account-samples-history-info'),(135432,'printshop-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','top','2','3','','.p-account-samples-history-info'),(135433,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','top','19','','','.p-account-samples-history-info'),(135434,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','top','19','','','.p-account-samples-history-info'),(135435,'printshop-mobile','.p-catalog-product .prev-next-product','top','calc(50% - 200px)','','','.p-catalog-product'),(135436,'printshop-mobile','.p-catalog-product .pn-image','top','120','3','','.p-catalog-product'),(135437,'printshop-mobile','.p-payer-order-confirmation .discount-ico','top','3','3','','.p-payer-order-confirmation'),(135438,'printshop-mobile','.p-payer-order-confirmation .order-ico','top','7','3','','.p-payer-order-confirmation'),(135439,'printshop-mobile','.p-payer-order-confirmation .comment-ico','top','7','3','','.p-payer-order-confirmation'),(135440,'printshop-mobile','.p-payer-order-pay .order-ico','top','7','3','','.p-payer-order-pay'),(135441,'printshop-mobile','.p-payer-order-pay .comment-ico','top','7','3','','.p-payer-order-pay'),(135442,'printshop-mobile','.p-payer-order-pay .discount-ico','top','3','3','','.p-payer-order-pay'),(135443,'printshop-mobile','.savings-ico .heading-2','top','5','3','','.savings-ico'),(135444,'printshop-mobile','.shipping-ico .heading-2','top','5','3','','.shipping-ico'),(135445,'printshop-mobile','.shipping-ico .heading-2','top','5','3','','.shipping-ico'),(135446,'printshop-mobile','.shipping-ico .heading-2','top','5','3','','.shipping-ico'),(135447,'printshop-mobile','.w-account-address-book .btn-del','top','0','','','.w-account-address-book'),(135448,'printshop-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','top','4','','','.w-account-addresses-list'),(135449,'printshop-mobile','.w-blog-widget-categories-list a','top','5','3','','.w-blog-widget-categories-list'),(135450,'printshop-mobile','.w-blog-widget-most-popular-posts a','top','5','3','','.w-blog-widget-most-popular-posts'),(135451,'printshop-mobile','.w-blog-widget-post-comments-count span','top','2','3','','.w-blog-widget-post-comments-count'),(135452,'printshop-mobile','.w-blog-widget-post-listing .post_comment','top','0','3','','.w-blog-widget-post-listing'),(135453,'printshop-mobile','.w-blog-widget-post-share ','top','0','4','','.w-blog-widget-post-share'),(135454,'printshop-mobile','.w-blog-widget-post-share','top','15','0,4','','.w-blog-widget-post-share'),(135455,'printshop-mobile','.w-cart-bonus-points .title','top','-2','3','','.w-cart-bonus-points'),(135456,'printshop-mobile','.w-cart-compare .remove-cart','top','0','','','.w-cart-compare'),(135457,'printshop-mobile','.w-cart-compare .atr-col','top','0','3','','.w-cart-compare'),(135458,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top','0','','','.w-catalog-paging'),(135459,'printshop-mobile','.w-checkout-billing-address .genders-title input','top','2','','','.w-checkout-billing-address'),(135460,'printshop-mobile','.w-checkout-create-account .account-benefits strong','top','3','3','','.w-checkout-create-account'),(135461,'printshop-mobile','.w-checkout-gdpr .candlestick-wrapper','top','0','','','.w-checkout-gdpr'),(135462,'printshop-mobile','.w-checkout-shipping-address .genders-title input','top','2','','','.w-checkout-shipping-address'),(135463,'printshop-mobile','.w-checkout-shipping-choice input','top','-200','','','.w-checkout-shipping-choice'),(135464,'printshop-mobile','.w-checkout-terms input[type=\"checkbox\"]','top','2','','','.w-checkout-terms'),(135465,'printshop-mobile','.w-checkout-terms .required-message','top','40','','','.w-checkout-terms'),(135466,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','top','0','','','.w-image-maps'),(135467,'printshop-mobile','.w-image-maps .svg-wrap svg','top','0','','','.w-image-maps'),(135468,'printshop-mobile','.w-multi-cart-actions .cart-actions','top','-3','','','.w-multi-cart-actions'),(135469,'printshop-mobile','.w-neighbour-checkout .bootstrap-switch','top','-2','','','.w-neighbour-checkout'),(135470,'printshop-mobile','.w-personal-gift-status-bar .inform','top','3','4','','.w-personal-gift-status-bar'),(135471,'printshop-mobile','.w-personal-gift-status-bar .end-date','top','4','3','','.w-personal-gift-status-bar'),(135472,'printshop-mobile','.w-product-customers-activity .close','top','5','','','.w-product-customers-activity'),(135473,'printshop-mobile','.w-promotions .prom-multi-discount .products','top','-13','','','.w-promotions'),(135474,'printshop-mobile','.w-promotions .prom-multi-discount > .heading','top','2','3','','.w-promotions'),(135475,'printshop-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','top','2','3','','.w-promotions'),(135476,'printshop-mobile','.w-promotions .promo-cart-discount .promo-min-qty','top','-19','','','.w-promotions'),(135477,'printshop-mobile','.w-promotions .promo-cart-discount .slave .content','top','-17','','','.w-promotions'),(135478,'printshop-mobile','.w-promotions .promo-date','top','-10','','','.w-promotions'),(135479,'printshop-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','top','2','3','','.w-promotions'),(135480,'printshop-mobile','.w-reviews-content .review','top','-16','3','','.w-reviews-content'),(135481,'printshop-mobile','.w-taxable input[type=\"checkbox\"]','top','2','','','.w-taxable'),(135482,'printshop-mobile','.w-taxable input[type=\"radio\"]','top','2','','','.w-taxable'),(135483,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(135484,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(135485,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(135486,'printshop-mobile','.w-wedding-registry-widgets-delete-link a','top','-1','4','','.w-wedding-registry-widgets-delete-link'),(135487,'printshop-mobile','.w-wedding-registry-widgets-products .remove','top','0','','','.w-wedding-registry-widgets-products'),(135488,'printshop-mobile','.w-wedding-registry-widgets-share-link a','top','-1','4','','.w-wedding-registry-widgets-share-link'),(135489,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top_important','important','','','.b-select-suggest'),(135490,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top_important','important','','','.w-catalog-paging'),(135491,'printshop-mobile','.w-menu-horizontal > ul > li > ul','top_measure','%','','','.w-menu-horizontal'),(135492,'printshop-mobile','.w-menu-big > ul > li > ul','top_measure','%','','','.w-menu-big'),(135493,'printshop-mobile','.w-menu-slider > ul > li > ul','top_measure','%','','','.w-menu-slider'),(135494,'printshop-mobile','.w-menu-style-1 > ul > li > ul','top_measure','%','','','.w-menu-style-1'),(135495,'printshop-mobile','.b-fancybox .fancybox-nav span','top_measure','%','','','.b-fancybox'),(135496,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','top_measure','%','','','.b-slick'),(135497,'printshop-mobile','.w-search .search form','top_measure','%','','','.w-search'),(135498,'printshop-mobile','.b-fancybox #fancybox-loading','top_measure','%','','','.b-fancybox'),(135499,'printshop-mobile','.w-search .suggest','top_measure','%','','','.w-search'),(135500,'printshop-mobile','.view-all','top_measure','%','3','',''),(135501,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(135502,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(135503,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(135504,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(135505,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(135506,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(135507,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top_measure','%','','','.b-menu-lev_display-down'),(135508,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top_measure','%','','','.b-menu-lev_display-down'),(135509,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top_measure','%','','','.b-menu-lev_display-down'),(135510,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top_measure','%','','','.b-menu-lev_display-down'),(135511,'printshop-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top_measure','%','','','.b-menu-lev_display-down'),(135512,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','top_measure','%','3','','.b-menu-style-2'),(135513,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','top_measure','%','3','','.b-menu-style-2'),(135514,'printshop-mobile','.b-select-suggest .select2-drop','top_measure','%','','','.b-select-suggest'),(135515,'printshop-mobile','.b-slick .slick-slider','touch-action','pan-y','','','.b-slick'),(135516,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container','transform','translate3d(0, 0, 0)','','','.b-switch'),(135517,'printshop-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','transform','translate3d(0, 0, 0)','','','.b-slick'),(135518,'printshop-mobile','.b-products-listing .hover-box-content','transform','rotate( 45deg )','3','','.b-products-listing'),(135519,'printshop-mobile','.b-menu-lev_display-slide .menu-style .slide-parent','transform','translateX(-100vw)','','','.b-menu-lev_display-slide'),(135520,'printshop-mobile','.b-switch .bootstrap-switch','transition','border-color ease-in-out .15s, box-shadow ease-in-out .15s','','','.b-switch'),(135521,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-animate .bootstrap-switch-container','transition','margin-left 0.5s','','','.b-switch'),(135522,'printshop-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','transition','max-height 1s','','','.b-menu-burger_icon'),(135523,'printshop-mobile','.b-menu-lev_display-slide .menu-style ul','transition','visibility 300ms, transform 300ms','','','.b-menu-lev_display-slide'),(135524,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','transition','left 300ms','','','.b-menu-open_from-left'),(135525,'printshop-mobile','.b-slick .slick-slider','user-select','none','','','.b-slick'),(135526,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','user-select','none','','','.b-select-suggest'),(135527,'printshop-mobile','.b-select-suggest .select2-results .select2-result-label','user-select','none','','','.b-select-suggest'),(135528,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','user-select','none','','','.b-select-suggest'),(135529,'printshop-mobile','.w-menu-big li li','vertical-align','top','','','.w-menu-big'),(135530,'printshop-mobile','.w-menu-big li a, .w-menu-big li .no-link','vertical-align','middle','','','.w-menu-big'),(135531,'printshop-mobile','.w-menu-slider > ul > li','vertical-align','top','','','.w-menu-slider'),(135532,'printshop-mobile','.w-menu-slider .close','vertical-align','20px','','','.w-menu-slider'),(135533,'printshop-mobile','.w-menu-slider > ul > li > ul > li','vertical-align','top','','','.w-menu-slider'),(135534,'printshop-mobile','.w-account .my-acc-link','vertical-align','middle','3','','.w-account'),(135535,'printshop-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','vertical-align','middle','','','.b-cookie-notice'),(135536,'printshop-mobile','.b-form .checkbox-style:checked + .checkbox-span','vertical-align','middle','','','.b-form'),(135537,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','vertical-align','middle','','','.b-form'),(135538,'printshop-mobile','.w-cart .cart-box-link','vertical-align','middle','3','','.w-cart'),(135539,'printshop-mobile','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','vertical-align','middle','','','.w-menu-horizontal'),(135540,'printshop-mobile','.b-product-images .additional-images .item > div, .b-product-images .additional-videos .item > div','vertical-align','middle','','','.b-product-images'),(135541,'printshop-mobile','.w-compare-box-item .checkbox','vertical-align','top','','','.w-compare-box-item'),(135542,'printshop-mobile','.w-compare-box-item .checkbox + span','vertical-align','middle','','','.w-compare-box-item'),(135543,'printshop-mobile','.w-categories .item','vertical-align','top','','','.w-categories'),(135544,'printshop-mobile','.w-quote .no-text','vertical-align','top','','','.w-quote'),(135545,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','vertical-align','middle','3','','.b-multi-page-checkout'),(135546,'printshop-mobile','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(135547,'printshop-mobile','.b-compare .compare_select_items','vertical-align','middle','','','.b-compare'),(135548,'printshop-mobile','.w-catalog-listing-look .b2b','vertical-align','top','','','.w-catalog-listing-look'),(135549,'printshop-mobile','.w-catalog-listing-look .list','vertical-align','top','','','.w-catalog-listing-look'),(135550,'printshop-mobile','.b-pagination .pagination .prev-pages','vertical-align','top','','','.b-pagination'),(135551,'printshop-mobile','.b-pagination .pagination .prev','vertical-align','top','','','.b-pagination'),(135552,'printshop-mobile','.b-pagination .pagination .page-number','vertical-align','top','','','.b-pagination'),(135553,'printshop-mobile','.b-pagination .pagination .next-pages','vertical-align','top','','','.b-pagination'),(135554,'printshop-mobile','.b-pagination .pagination .next','vertical-align','top','','','.b-pagination'),(135555,'printshop-mobile','.b-pagination .pagination span','vertical-align','top','2','','.b-pagination'),(135556,'printshop-mobile','.p-account-history .view_link','vertical-align','middle','4','','.p-account-history'),(135557,'printshop-mobile','.p-reviews-info .review_by span','vertical-align','middle','','','.p-reviews-info'),(135558,'printshop-mobile','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(135559,'printshop-mobile','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(135560,'printshop-mobile','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(135561,'printshop-mobile','.p-wedding-registry-manage .links a','vertical-align','middle','','','.p-wedding-registry-manage'),(135562,'printshop-mobile','.b-pagination .pagination a','vertical-align','top','','','.b-pagination'),(135563,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align','top','','','.b-switch'),(135564,'printshop-mobile','.b-switch .bootstrap-switch','vertical-align','middle','','','.b-switch'),(135565,'printshop-mobile','.w-filters .input-checkbox:checked + .checkbox-span','vertical-align','middle','','','.w-filters'),(135566,'printshop-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','vertical-align','middle','','','.w-filters'),(135567,'printshop-mobile','.w-quote .cart-box-link','vertical-align','middle','3','','.w-quote'),(135568,'printshop-mobile','.w-tabs .tab-li','vertical-align','bottom','','','.w-tabs'),(135569,'printshop-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','vertical-align','middle','','','.w-banner'),(135570,'printshop-mobile','.p-account-index .view_link','vertical-align','middle','4','','.p-account-index'),(135571,'printshop-mobile','.p-account-index td.acc_wish_remove','vertical-align','middle','','','.p-account-index'),(135572,'printshop-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','vertical-align','top','','','.b-fancybox'),(135573,'printshop-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','vertical-align','top','','','.b-fancybox'),(135574,'printshop-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(135575,'printshop-mobile','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(135576,'printshop-mobile','.w-product-configurator .item-content > div','vertical-align','middle','','','.w-product-configurator'),(135577,'printshop-mobile','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(135578,'printshop-mobile','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(135579,'printshop-mobile','.w-catalog-listing-look .grid','vertical-align','top','','','.w-catalog-listing-look'),(135580,'printshop-mobile','.w-cart .no-text','vertical-align','top','','','.w-cart'),(135581,'printshop-mobile','.w-top-categories .item','vertical-align','top','','','.w-top-categories'),(135582,'printshop-mobile','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','vertical-align','middle','','','.b-form'),(135583,'printshop-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','vertical-align','middle','','','.w-menu-style-1'),(135584,'printshop-mobile','.b-products-listing .products-listing .item','vertical-align','top','','','.b-products-listing'),(135585,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.b-data-table'),(135586,'printshop-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.b-data-table'),(135587,'printshop-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(135588,'printshop-mobile','.b-email .image','vertical-align','top','','','.b-email'),(135589,'printshop-mobile','.b-email .model','vertical-align','top','','','.b-email'),(135590,'printshop-mobile','.b-email .price','vertical-align','top','','','.b-email'),(135591,'printshop-mobile','.b-email .model','vertical-align','top','','','.b-email'),(135592,'printshop-mobile','.b-email .model','vertical-align','top','','','.b-email'),(135593,'printshop-mobile','.b-email .price','vertical-align','top','','','.b-email'),(135594,'printshop-mobile','.b-email .name','vertical-align','top','','','.b-email'),(135595,'printshop-mobile','.b-email .model','vertical-align','top','','','.b-email'),(135596,'printshop-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(135597,'printshop-mobile','.b-email .image','vertical-align','top','','','.b-email'),(135598,'printshop-mobile','.b-email .image','vertical-align','top','','','.b-email'),(135599,'printshop-mobile','.b-email .model','vertical-align','top','','','.b-email'),(135600,'printshop-mobile','.b-email .name','vertical-align','top','','','.b-email'),(135601,'printshop-mobile','.b-email .price','vertical-align','top','','','.b-email'),(135602,'printshop-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(135603,'printshop-mobile','.b-email .image','vertical-align','top','','','.b-email'),(135604,'printshop-mobile','.b-email .name','vertical-align','top','','','.b-email'),(135605,'printshop-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(135606,'printshop-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(135607,'printshop-mobile','.b-email .image','vertical-align','top','','','.b-email'),(135608,'printshop-mobile','.b-email .image','vertical-align','top','','','.b-email'),(135609,'printshop-mobile','.b-email .name','vertical-align','top','','','.b-email'),(135610,'printshop-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(135611,'printshop-mobile','.b-email .name','vertical-align','top','','','.b-email'),(135612,'printshop-mobile','.b-email .name','vertical-align','top','','','.b-email'),(135613,'printshop-mobile','.b-email .price','vertical-align','top','','','.b-email'),(135614,'printshop-mobile','.b-email .price','vertical-align','top','','','.b-email'),(135615,'printshop-mobile','.b-email .model','vertical-align','top','','','.b-email'),(135616,'printshop-mobile','.b-email .price','vertical-align','top','','','.b-email'),(135617,'printshop-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(135618,'printshop-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(135619,'printshop-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(135620,'printshop-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(135621,'printshop-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(135622,'printshop-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(135623,'printshop-mobile','.b-messages .msv_to_cc div span','vertical-align','middle','','','.b-messages'),(135624,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(135625,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(135626,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(135627,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(135628,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(135629,'printshop-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(135630,'printshop-mobile','.b-upload-file .upload-file-template','vertical-align','top','','','.b-upload-file'),(135631,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','vertical-align','top','','','.b-warehouses-popup'),(135632,'printshop-mobile','.batchPr .checkbox input + span','vertical-align','middle','','','.batchPr'),(135633,'printshop-mobile','.p-account-samples-history .view_link','vertical-align','middle','4','','.p-account-samples-history'),(135634,'printshop-mobile','.p-account-samples-history .view_link','vertical-align','middle','4','','.p-account-samples-history'),(135635,'printshop-mobile','.p-account-samples-history .view_link','vertical-align','middle','4','','.p-account-samples-history'),(135636,'printshop-mobile','.p-account-samples-history .view_link','vertical-align','middle','4','','.p-account-samples-history'),(135637,'printshop-mobile','.p-account-samples-history .view_link','vertical-align','middle','4','','.p-account-samples-history'),(135638,'printshop-mobile','.p-account-samples-history .view_link','vertical-align','middle','4','','.p-account-samples-history'),(135639,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.p-quick-order-index'),(135640,'printshop-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.p-quick-order-index'),(135641,'printshop-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','vertical-align','middle','','','.w-blog-widget-post-share'),(135642,'printshop-mobile','.w-cart-compare .product-label','vertical-align','bottom','','','.w-cart-compare'),(135643,'printshop-mobile','.w-cart-compare .product-actions .dropdown-toggle','vertical-align','middle','3','','.w-cart-compare'),(135644,'printshop-mobile','.w-cart-compare .product-cell','vertical-align','top','','','.w-cart-compare'),(135645,'printshop-mobile','.w-cart-credit-amount .amount-title','vertical-align','top','3','','.w-cart-credit-amount'),(135646,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','vertical-align','middle','3','','.w-catalog-compare'),(135647,'printshop-mobile','.w-catalog-paging ','vertical-align','top','2','','.w-catalog-paging'),(135648,'printshop-mobile','.w-catalog-paging .prev','vertical-align','top','','','.w-catalog-paging'),(135649,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','vertical-align','top','','','.w-catalog-paging'),(135650,'printshop-mobile','.w-catalog-paging .page-number','vertical-align','top','','','.w-catalog-paging'),(135651,'printshop-mobile','.w-catalog-paging .next-pages','vertical-align','top','','','.w-catalog-paging'),(135652,'printshop-mobile','.w-catalog-paging .next','vertical-align','top','','','.w-catalog-paging'),(135653,'printshop-mobile','.w-catalog-paging .prev-pages','vertical-align','top','','','.w-catalog-paging'),(135654,'printshop-mobile','.w-checkout-billing-address .genders-title > div','vertical-align','top','','','.w-checkout-billing-address'),(135655,'printshop-mobile','.w-checkout-shipping-address .genders-title > div','vertical-align','top','','','.w-checkout-shipping-address'),(135656,'printshop-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','vertical-align','bottom','','','.w-communication-new-topic'),(135657,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','vertical-align','top','','','.w-communication-new-topic'),(135658,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','3','','.w-communication-new-topic'),(135659,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','','','.w-communication-new-topic'),(135660,'printshop-mobile','.w-product-available-in-warehouses .warehouse-item','vertical-align','top','','','.w-product-available-in-warehouses'),(135661,'printshop-mobile','.w-promotions .heading-3','vertical-align','top','','','.w-promotions'),(135662,'printshop-mobile','.b-quantity .qty-box input[type=\'text\']','vertical-align','top','','','.b-quantity'),(135663,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align_important','important','','','.b-switch'),(135664,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no','visibility','hidden','','','.b-form'),(135665,'printshop-mobile','.w-compare-box-item .checkbox:not(checked)','visibility','hidden','','','.w-compare-box-item'),(135666,'printshop-mobile','.b-fancybox .fancybox-title','visibility','hidden','','','.b-fancybox'),(135667,'printshop-mobile','.b-fancybox .fancybox-tmp','visibility','hidden','','','.b-fancybox'),(135668,'printshop-mobile','.b-fancybox .fancybox-nav:hover span','visibility','visible','','','.b-fancybox'),(135669,'printshop-mobile','.b-fancybox .fancybox-opened .fancybox-title','visibility','visible','','','.b-fancybox'),(135670,'printshop-mobile','.b-slick .slick-loading .slick-track','visibility','hidden','','','.b-slick'),(135671,'printshop-mobile','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(135672,'printshop-mobile','.b-slick .slick-loading .slick-slide','visibility','hidden','','','.b-slick'),(135673,'printshop-mobile','.b-fancybox .fancybox-nav span','visibility','hidden','','','.b-fancybox'),(135674,'printshop-mobile','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(135675,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','visibility','hidden','','','.b-menu-lev_display-slide'),(135676,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-1 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(135677,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','visibility','hidden','','','.b-menu-lev_display-slide'),(135678,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','visibility','hidden','','','.b-menu-lev_display-slide'),(135679,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','visibility','hidden','','','.b-menu-lev_display-slide'),(135680,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','visibility','hidden','','','.b-menu-lev_display-slide'),(135681,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-2 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(135682,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-4 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(135683,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-5 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(135684,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-3 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(135685,'printshop-mobile','.b-upload-files .attach-active-holder .attach-file','visibility','hidden','','','.b-upload-files'),(135686,'printshop-mobile','.batchPr .checkbox input','visibility','hidden','','','.batchPr'),(135687,'printshop-mobile','.w-menu-horizontal > ul','white-space','nowrap','','','.w-menu-horizontal'),(135688,'printshop-mobile','.w-menu-style-1 > ul','white-space','nowrap','','','.w-menu-style-1'),(135689,'printshop-mobile','.w-menu-horizontal > ul','white-space','normal','694','','.w-menu-horizontal'),(135690,'printshop-mobile','.p-account-history .view_link','white-space','nowrap','','','.p-account-history'),(135691,'printshop-mobile','.b-fancybox .fancybox-error','white-space','nowrap','','','.b-fancybox'),(135692,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap .child','white-space','nowrap','','','.b-fancybox'),(135693,'printshop-mobile','.p-account-index .view_link','white-space','nowrap','','','.p-account-index'),(135694,'printshop-mobile','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(135695,'printshop-mobile','.b-select-suggest .select2-search','white-space','nowrap','','','.b-select-suggest'),(135696,'printshop-mobile','.b-select-suggest .select2-container .select2-choice','white-space','nowrap','','','.b-select-suggest'),(135697,'printshop-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','white-space','nowrap','','','.b-select-suggest'),(135698,'printshop-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','white-space','nowrap','','','.b-select-suggest'),(135699,'printshop-mobile','.p-account-samples-history .view_link','white-space','nowrap','','','.p-account-samples-history'),(135700,'printshop-mobile','.p-account-samples-history .view_link','white-space','nowrap','','','.p-account-samples-history'),(135701,'printshop-mobile','.p-account-samples-history .view_link','white-space','nowrap','','','.p-account-samples-history'),(135702,'printshop-mobile','.p-account-samples-history .view_link','white-space','nowrap','','','.p-account-samples-history'),(135703,'printshop-mobile','.p-account-samples-history .view_link','white-space','nowrap','','','.p-account-samples-history'),(135704,'printshop-mobile','.p-account-samples-history .view_link','white-space','nowrap','','','.p-account-samples-history'),(135705,'printshop-mobile','.w-checkout-shipping-choice span','white-space','nowrap','','','.w-checkout-shipping-choice'),(135706,'printshop-mobile','.w-menu .hided.menu ul li','width','auto','','','.w-menu'),(135707,'printshop-mobile','.w-menu .hided.menu ul ul','width','auto','','','.w-menu'),(135708,'printshop-mobile','.w-menu-big li','width','auto','','','.w-menu-big'),(135709,'printshop-mobile','.w-menu-slider > ul > li > ul','width','100','','','.w-menu-slider'),(135710,'printshop-mobile','.w-bestsellers .item','width','31','3','','.w-bestsellers'),(135711,'printshop-mobile','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(135712,'printshop-mobile','.w-bestsellers .counter','width','31','','','.w-bestsellers'),(135713,'printshop-mobile','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(135714,'printshop-mobile','.b-form .checkbox-style:checked + .checkbox-span','width','15','','','.b-form'),(135715,'printshop-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','width','15','','','.b-form'),(135716,'printshop-mobile','.b-form .checkbox-style','width','0','','','.b-form'),(135717,'printshop-mobile','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(135718,'printshop-mobile','.w-login-block .guest','width','50','','','.w-login-block'),(135719,'printshop-mobile','.w-login-block .input','width','100','','','.w-login-block'),(135720,'printshop-mobile','.w-login-block .returning','width','50','','','.w-login-block'),(135721,'printshop-mobile','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(135722,'printshop-mobile','.w-login-block .new','width','50','','','.w-login-block'),(135723,'printshop-mobile','.w-sale .left-count','width','23','','','.w-sale'),(135724,'printshop-mobile','.w-menu-horizontal .menu-ico','width','54','','','.w-menu-horizontal'),(135725,'printshop-mobile','.w-list-type-2_2 .sale','width','100','4','','.w-list-type-2_2'),(135726,'printshop-mobile','.w-sale .image','width','50','','','.w-sale'),(135727,'printshop-mobile','.w-sale .holder-1','width','25','','','.w-sale'),(135728,'printshop-mobile','.w-sale .holder-2','width','25','','','.w-sale'),(135729,'printshop-mobile','.w-sale .badge','width','80','','','.w-sale'),(135730,'printshop-mobile','.w-menu-style-1 .menu-ico','width','54','','','.w-menu-style-1'),(135731,'printshop-mobile','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(135732,'printshop-mobile','.w-product-attributes .select','width','100','','','.w-product-attributes'),(135733,'printshop-mobile','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(135734,'printshop-mobile','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(135735,'printshop-mobile','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(135736,'printshop-mobile','.w-product-wedding-registry-button .btn','width','18','4','','.w-product-wedding-registry-button'),(135737,'printshop-mobile','.w-product-sale-ends .left-count','width','23','','','.w-product-sale-ends'),(135738,'printshop-mobile','.w-product-sale-ends .left-text-left','width','24','','','.w-product-sale-ends'),(135739,'printshop-mobile','.w-product-sale-ends .left-text-right','width','24','','','.w-product-sale-ends'),(135740,'printshop-mobile','.w-product-collection .right-area','width','25','','','.w-product-collection'),(135741,'printshop-mobile','.w-product-collection .chosen-products','width','50','','','.w-product-collection'),(135742,'printshop-mobile','.w-product-collection .current-product','width','25','','','.w-product-collection'),(135743,'printshop-mobile','.b-fancybox .fancybox-nav','width','40','','','.b-fancybox'),(135744,'printshop-mobile','.w-top-categories .item','width','50','693','','.w-top-categories'),(135745,'printshop-mobile','.w-product-personal-catalog-button .btn','width','160','','','.w-product-personal-catalog-button'),(135746,'printshop-mobile','.w-currencies .select','width','100','','','.w-currencies'),(135747,'printshop-mobile','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(135748,'printshop-mobile','.w-categories .item','width','50','693','','.w-categories'),(135749,'printshop-mobile','.p-account-history-info .not_fully_paid_td','width','300','','','.p-account-history-info'),(135750,'printshop-mobile','.p-account-index .not_fully_paid_td','width','300','','','.p-account-index'),(135751,'printshop-mobile','.w-compare-box-item .checkbox','width','22','','','.w-compare-box-item'),(135752,'printshop-mobile','.w-compare-box-item .checkbox + span','width','24','','','.w-compare-box-item'),(135753,'printshop-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width','49','','','.p-account-trade-form'),(135754,'printshop-mobile','.w-categories .item','width','25','','','.w-categories'),(135755,'printshop-mobile','.w-cart-order-total.box','width','100','722','','.w-cart-order-total'),(135756,'printshop-mobile','.w-cart-checkout-btn','width','100','693','','.w-cart-checkout-btn'),(135757,'printshop-mobile','.b-product-images .additional-horizontal .additional-images, .b-product-images .additional-horizontal .additional-videos','width','100','','','.b-product-images'),(135758,'printshop-mobile','.b-price-box .price-box .price','width','200','','','.b-price-box'),(135759,'printshop-mobile','.w-cart-give-away .ga_column','width','100','693','','.w-cart-give-away'),(135760,'printshop-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','width','auto','','','.b-product-images'),(135761,'printshop-mobile','.w-product-properties li','width','50','','','.w-product-properties'),(135762,'printshop-mobile','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(135763,'printshop-mobile','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(135764,'printshop-mobile','.w-product-in-bundles .bundle_item','width','48','','','.w-product-in-bundles'),(135765,'printshop-mobile','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(135766,'printshop-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','width','48','','','.p-account-address-book'),(135767,'printshop-mobile','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(135768,'printshop-mobile','.w-product-bundle .bundle_item','width','48','','','.w-product-bundle'),(135769,'printshop-mobile','.w-menu-slider .menu-ico','width','54','','','.w-menu-slider'),(135770,'printshop-mobile','.w-catalog-listing-look .b2b','width','31','','','.w-catalog-listing-look'),(135771,'printshop-mobile','.w-catalog-listing-look .list','width','31','','','.w-catalog-listing-look'),(135772,'printshop-mobile','.p-account-address-book .topInfo > div','width','100','693','','.p-account-address-book'),(135773,'printshop-mobile','.p-account-address-book .address_book_row .column + .column','width','100','693','','.p-account-address-book'),(135774,'printshop-mobile','.p-account-address-book .address_book_row .column','width','100','693','','.p-account-address-book'),(135775,'printshop-mobile','.p-account-index .topAccount > li','width','100','693','','.p-account-index'),(135776,'printshop-mobile','.p-account-address-book .topInfo > div + div','width','100','693','','.p-account-address-book'),(135777,'printshop-mobile','.p-blog-index .nav-next','width','100','718','','.p-blog-index'),(135778,'printshop-mobile','.p-account-history-info .history_info > div','width','100','694','','.p-account-history-info'),(135779,'printshop-mobile','.p-blog-index .nav-previous','width','100','718','','.p-blog-index'),(135780,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','width','35','3','','.b-multi-page-checkout'),(135781,'printshop-mobile','.p-blog-index .post-thumbnail','width','200','','','.p-blog-index'),(135782,'printshop-mobile','.w-list-type-1_2 .right-area','width','100','694','','.w-list-type-1_2'),(135783,'printshop-mobile','.p-blog-index .comment-form p label','width','100','','','.p-blog-index'),(135784,'printshop-mobile','.w-list-type-1_2 .right-area .name','width','60','','','.w-list-type-1_2'),(135785,'printshop-mobile','.w-list-type-1_2 .image','width','100','694','','.w-list-type-1_2'),(135786,'printshop-mobile','.w-list-type-1_2 .right-area .right-area-2','width','100','694','','.w-list-type-1_2'),(135787,'printshop-mobile','.w-list-type-1_2 .right-area .right-area-2','width','38','','','.w-list-type-1_2'),(135788,'printshop-mobile','.w-list-type-1_2 .right-area .name','width','100','694','','.w-list-type-1_2'),(135789,'printshop-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','width','33','','','.b-multi-page-checkout'),(135790,'printshop-mobile','.b-info-popup .info-popup div','width','250','','','.b-info-popup'),(135791,'printshop-mobile','.w-menu-mobile .menu-slider .open','width','100','','','.w-menu-mobile'),(135792,'printshop-mobile','.w-promo-code .promo-text','width','100','694','','.w-promo-code'),(135793,'printshop-mobile','.w-promo-code .promo-code-form','width','100','694','','.w-promo-code'),(135794,'printshop-mobile','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(135795,'printshop-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 110px)','694','','.w-promo-code'),(135796,'printshop-mobile','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(135797,'printshop-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(135798,'printshop-mobile','.w-catalog-sorting select','width','100','','','.w-catalog-sorting'),(135799,'printshop-mobile','.b-form .col-right','width','100','720','','.b-form'),(135800,'printshop-mobile','.b-form .columns .col-2','width','100','723','','.b-form'),(135801,'printshop-mobile','.b-form .col-left','width','100','720','','.b-form'),(135802,'printshop-mobile','.p-account-order-pay .history_info > div','width','33.3','','','.p-account-order-pay'),(135803,'printshop-mobile','.p-account-order-pay .history_info > div','width','100','694','','.p-account-order-pay'),(135804,'printshop-mobile','.p-account-order-pay .not_fully_paid_td','width','300','','','.p-account-order-pay'),(135805,'printshop-mobile','.w-product-configurator .item-content','width','100','702','','.w-product-configurator'),(135806,'printshop-mobile','.w-product-configurator .pc_item','width','100','702','','.w-product-configurator'),(135807,'printshop-mobile','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(135808,'printshop-mobile','.p-wedding-registry-manage .wr-search input','width','100','','','.p-wedding-registry-manage'),(135809,'printshop-mobile','.p-wedding-registry-manage .wr-search','width','400','','','.p-wedding-registry-manage'),(135810,'printshop-mobile','.p-wedding-registry-manage .wr-search button','width','30','','','.p-wedding-registry-manage'),(135811,'printshop-mobile','.p-account-history .orders-table .hidden','width','130','720','','.p-account-history'),(135812,'printshop-mobile','.p-account-history .orders-table .td-alignright','width','100','720','','.p-account-history'),(135813,'printshop-mobile','.p-account-index .orders-table .hidden','width','130','720','','.p-account-index'),(135814,'printshop-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','50','720','','.p-blog-index'),(135815,'printshop-mobile','.p-account-index .orders-table .td-alignright','width','100','720','','.p-account-index'),(135816,'printshop-mobile','.p-blog-index .nav-next','width','50','','','.p-blog-index'),(135817,'printshop-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','100','723','','.p-blog-index'),(135818,'printshop-mobile','.p-blog-index .nav-previous','width','50','','','.p-blog-index'),(135819,'printshop-mobile','.pop-up-content .buttons .btn','width','100','694','',''),(135820,'printshop-mobile','.w-list-type-1_3 .right-area .right-area-2','width','38','','','.w-list-type-1_3'),(135821,'printshop-mobile','.pop-up-content .buttons .btn-2','width','100','694','',''),(135822,'printshop-mobile','.w-list-type-2_2 .sale','width','94','','','.w-list-type-2_2'),(135823,'printshop-mobile','.pop-up-content .buttons .right-buttons','width','100','694','',''),(135824,'printshop-mobile','.pop-up-content .buttons .left-buttons','width','100','694','',''),(135825,'printshop-mobile','.w-list-type-2_2 .image','width','170','','','.w-list-type-2_2'),(135826,'printshop-mobile','.w-list-type-2_2 .sale','width','100','3','','.w-list-type-2_2'),(135827,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','width','100','','','.w-list-type-2_2'),(135828,'printshop-mobile','.w-list-type-2 .sale','width','100','3','','.w-list-type-2'),(135829,'printshop-mobile','.w-list-type-2 .sale','width','94','','','.w-list-type-2'),(135830,'printshop-mobile','.w-list-type-2_2 .button-wishlist','width','50','','','.w-list-type-2_2'),(135831,'printshop-mobile','.personal-buttons > div > div','width','50','','','.personal-buttons'),(135832,'printshop-mobile','.w-product-bonus-points > div > div','width','50','','','.w-product-bonus-points'),(135833,'printshop-mobile','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(135834,'printshop-mobile','.w-cart-continue-btn a','width','100','693','','.w-cart-continue-btn'),(135835,'printshop-mobile','.b-fancybox #fancybox-loading div','width','44','','','.b-fancybox'),(135836,'printshop-mobile','.w-brands .brands-listing > div','width','16','','','.w-brands'),(135837,'printshop-mobile','.w-product-wedding-registry-button .btn','width','160','','','.w-product-wedding-registry-button'),(135838,'printshop-mobile','.b-fancybox .fancybox-close','width','36','','','.b-fancybox'),(135839,'printshop-mobile','.b-fancybox .fancybox-lock','width','auto','','','.b-fancybox'),(135840,'printshop-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width','100','','','.b-fancybox'),(135841,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList li','width','23','','','.w-delivery-location-top-location-list'),(135842,'printshop-mobile','.w-menu-horizontal li','width','auto','','','.w-menu-horizontal'),(135843,'printshop-mobile','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(135844,'printshop-mobile','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(135845,'printshop-mobile','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(135846,'printshop-mobile','.b-form .radio-button input[type=\"radio\"].no + span','width','30','3','','.b-form'),(135847,'printshop-mobile','.p-wedding-registry-index .search-list input','width','300','','','.p-wedding-registry-index'),(135848,'printshop-mobile','.p-wedding-registry-index .search-list','width','150','3','','.p-wedding-registry-index'),(135849,'printshop-mobile','.p-wedding-registry-search .search-list input','width','100','','','.p-wedding-registry-search'),(135850,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width','20','3','','.b-switch'),(135851,'printshop-mobile','.b-bottom .popup-credit-amount .popup-box','width','100','','','.b-bottom');
INSERT INTO `themes_styles` VALUES (135852,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width','20','3','','.b-switch'),(135853,'printshop-mobile','.b-compare .col-two label','width','20','','','.b-compare'),(135854,'printshop-mobile','.b-compare .col-two select','width','80','','','.b-compare'),(135855,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-label','width','30','','','.b-switch'),(135856,'printshop-mobile','.w-list-type-1 .image img','width','auto','','','.w-list-type-1'),(135857,'printshop-mobile','.w-search .search form','width','100','','','.w-search'),(135858,'printshop-mobile','.w-languages .lang-link','width','61','702','','.w-languages'),(135859,'printshop-mobile','.w-product-buttons .btn, .w-product-buttons .btn-2, .w-product-buttons .btn-3, .w-product-buttons .btn-4','width','100','','','.w-product-buttons'),(135860,'printshop-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','width','39','','','.b-quantity'),(135861,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','width','40','','','.b-slick'),(135862,'printshop-mobile','.w-filters .input-checkbox:checked + .checkbox-span','width','24','','','.w-filters'),(135863,'printshop-mobile','.b-form .col-left','width','48','','','.b-form'),(135864,'printshop-mobile','.w-search .suggest','width','100','','','.w-search'),(135865,'printshop-mobile','.w-search .image','width','40','','','.w-search'),(135866,'printshop-mobile','.w-search .search-input','width','100','','','.w-search'),(135867,'printshop-mobile','.w-socials .post_item_img','width','100','','','.w-socials'),(135868,'printshop-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width','100','','','.w-banner'),(135869,'printshop-mobile','textarea','width','100','','',''),(135870,'printshop-mobile','.w-filters .input-txt','width','60','','','.w-filters'),(135871,'printshop-mobile','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width','100','','','.w-banner'),(135872,'printshop-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width','48','','','.p-account-trade-form'),(135873,'printshop-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width','55','','','.p-account-trade-form'),(135874,'printshop-mobile','.p-account-trade-form .wl-td label','width','40','','','.p-account-trade-form'),(135875,'printshop-mobile','.p-account-trade-form .wl-td select','width','55','','','.p-account-trade-form'),(135876,'printshop-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width','48','','','.p-account-trade-form'),(135877,'printshop-mobile','.b-price-box .price-box .price','width','120','722','','.b-price-box'),(135878,'printshop-mobile','.w-filters .handle-from','width','50','','','.w-filters'),(135879,'printshop-mobile','.b-bottom .popup-box.popupCompare','width','80','','','.b-bottom'),(135880,'printshop-mobile','.w-filters .handle-to','width','50','','','.w-filters'),(135881,'printshop-mobile','.w-filters .input-checkbox','width','0','','','.w-filters'),(135882,'printshop-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','width','24','','','.w-filters'),(135883,'printshop-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(135884,'printshop-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','width','22','','','.w-compare-box-item'),(135885,'printshop-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width','49','','','.p-account-trade-form'),(135886,'printshop-mobile','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(135887,'printshop-mobile','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(135888,'printshop-mobile','.b-info-popup .info-popup div','width','20','3','','.b-info-popup'),(135889,'printshop-mobile','.p-reviews-info .review-info-image','width','24','','','.p-reviews-info'),(135890,'printshop-mobile','.b-fancybox .fancybox-nav span','width','40','','','.b-fancybox'),(135891,'printshop-mobile','.p-checkout-success .page-success','width','100','3','','.p-checkout-success'),(135892,'printshop-mobile','.w-menu-mobile .menu-ico','width','54','','','.w-menu-mobile'),(135893,'printshop-mobile','.w-product-quantity-discounts .quantity-discounts .count','width','40','','','.w-product-quantity-discounts'),(135894,'printshop-mobile','.w-product-wedding-registry-button .btn','width','18','3','','.w-product-wedding-registry-button'),(135895,'printshop-mobile','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(135896,'printshop-mobile','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(135897,'printshop-mobile','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(135898,'printshop-mobile','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(135899,'printshop-mobile','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(135900,'printshop-mobile','.w-menu-style-1 li','width','auto','','','.w-menu-style-1'),(135901,'printshop-mobile','.p-account-history .not_fully_paid_td','width','300','','','.p-account-history'),(135902,'printshop-mobile','.w-sale .left-text-right','width','24','','','.w-sale'),(135903,'printshop-mobile','.w-sale .left-text-left','width','24','','','.w-sale'),(135904,'printshop-mobile','.w-banner .carousel-text','width','100','','','.w-banner'),(135905,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','width','50','706','','.b-slick'),(135906,'printshop-mobile','.b-quantity .qty-box .smaller','width','35','','','.b-quantity'),(135907,'printshop-mobile','.b-quantity .qty-input input','width','40','','','.b-quantity'),(135908,'printshop-mobile','.b-quantity .qty-box .bigger','width','35','','','.b-quantity'),(135909,'printshop-mobile','.w-cart-checkout-btn a','width','100','693','','.w-cart-checkout-btn'),(135910,'printshop-mobile','.w-cart .cart-box.hover-box .cart-content','width','410','','','.w-cart'),(135911,'printshop-mobile','.p-account-index .account_info li','width','100','693','','.p-account-index'),(135912,'printshop-mobile','.w-product-images .item-div','width','80','723','','.w-product-images'),(135913,'printshop-mobile','.w-product-images .item','width','80','723','','.w-product-images'),(135914,'printshop-mobile','.w-list-type-1_3 .right-area .name','width','60','','','.w-list-type-1_3'),(135915,'printshop-mobile','.w-list-type-1_3 .right-area','width','100','694','','.w-list-type-1_3'),(135916,'printshop-mobile','.w-list-type-1_3 .right-area .right-area-2','width','100','694','','.w-list-type-1_3'),(135917,'printshop-mobile','.w-list-type-1_3 .image','width','100','694','','.w-list-type-1_3'),(135918,'printshop-mobile','.w-list-type-1_3 .right-area .name','width','100','694','','.w-list-type-1_3'),(135919,'printshop-mobile','.w-cart-order-total.box','width','100','','','.w-cart-order-total'),(135920,'printshop-mobile','.w-cart-discount-coupon .gift-code input','width','100','','','.w-cart-discount-coupon'),(135921,'printshop-mobile','.w-cart .image','width','70','','','.w-cart'),(135922,'printshop-mobile','.b-form .addresses .address-item','width','48','','','.b-form'),(135923,'printshop-mobile','.w-catalog-listing-look .grid','width','31','','','.w-catalog-listing-look'),(135924,'printshop-mobile','.b-form .discount-box input[type=\"text\"]','width','100','','','.b-form'),(135925,'printshop-mobile','.p-account-index .account_info li','width','30.33','','','.p-account-index'),(135926,'printshop-mobile','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width','100','','','.b-form'),(135927,'printshop-mobile','.b-form .hide-billing-address','width','100','','','.b-form'),(135928,'printshop-mobile','.b-form .col-right','width','48','','','.b-form'),(135929,'printshop-mobile','.b-form .columns .col-2','width','48','','','.b-form'),(135930,'printshop-mobile','.p-account-index .topAccount > li','width','20','','','.p-account-index'),(135931,'printshop-mobile','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(135932,'printshop-mobile','.w-cart-give-away .ga_attributes select','width','100','','','.w-cart-give-away'),(135933,'printshop-mobile','.w-cart-give-away .ga_column','width','46','','','.w-cart-give-away'),(135934,'printshop-mobile','.w-cart-give-away .ga_attributes > div','width','48','','','.w-cart-give-away'),(135935,'printshop-mobile','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','width','79','','','.b-datepicker'),(135936,'printshop-mobile','.w-cart-give-away .ga_img','width','30','','','.w-cart-give-away'),(135937,'printshop-mobile','.w-list-type-1_3 .right-area','width','calc(100% - 190px)','','','.w-list-type-1_3'),(135938,'printshop-mobile','.view-all','width','100','3','',''),(135939,'printshop-mobile','.w-list-type-2 .button-wishlist button','width','100','','','.w-list-type-2'),(135940,'printshop-mobile','.w-list-type-2 .button-wishlist','width','50','','','.w-list-type-2'),(135941,'printshop-mobile','.w-list-type-1_3 .sale','width','100','4','','.w-list-type-1_3'),(135942,'printshop-mobile','.w-list-type-1_3 .sale','width','100','3','','.w-list-type-1_3'),(135943,'printshop-mobile','.w-list-type-2 .sale','width','100','4','','.w-list-type-2'),(135944,'printshop-mobile','.w-list-type-1_3 .sale','width','94','','','.w-list-type-1_3'),(135945,'printshop-mobile','.w-list-type-1_3 .image','width','170','','','.w-list-type-1_3'),(135946,'printshop-mobile','.w-list-type-1_3 .button-wishlist','width','50','','','.w-list-type-1_3'),(135947,'printshop-mobile','.w-list-type-1_2 .sale','width','100','4','','.w-list-type-1_2'),(135948,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','width','100','','','.w-list-type-1_3'),(135949,'printshop-mobile','.w-list-type-1_3 .attributes > .attributes > div','width','48','','','.w-list-type-1_3'),(135950,'printshop-mobile','.w-list-type-1_2 .right-area','width','calc(100% - 190px)','','','.w-list-type-1_2'),(135951,'printshop-mobile','.w-list-type-1_2 .sale','width','100','3','','.w-list-type-1_2'),(135952,'printshop-mobile','.w-list-type-1_2 .sale','width','94','','','.w-list-type-1_2'),(135953,'printshop-mobile','.b-bottom .pop-up-close','width','31','','','.b-bottom'),(135954,'printshop-mobile','.w-list-type-1 .sale','width','100','4','','.w-list-type-1'),(135955,'printshop-mobile','.w-list-type-1_2 .button-view','width','50','','','.w-list-type-1_2'),(135956,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','width','100','','','.w-list-type-1_2'),(135957,'printshop-mobile','.w-list-type-1_2 .button-wishlist','width','50','','','.w-list-type-1_2'),(135958,'printshop-mobile','.w-list-type-1 .sale','width','94','','','.w-list-type-1'),(135959,'printshop-mobile','.w-list-type-1 .sale','width','100','3','','.w-list-type-1'),(135960,'printshop-mobile','.b-bottom .popup-box','width','530','','','.b-bottom'),(135961,'printshop-mobile','.w-list-type-1 .button-wishlist button','width','100','','','.w-list-type-1'),(135962,'printshop-mobile','.w-filters .mobileCollapse','width','17','','','.w-filters'),(135963,'printshop-mobile','.w-filters .input-txt-keywords','width','100','','','.w-filters'),(135964,'printshop-mobile','.w-filters .ui-slider-handle','width','15','','','.w-filters'),(135965,'printshop-mobile','.w-filters .ui-slider','width','92','','','.w-filters'),(135966,'printshop-mobile','.w-tabs .tab-navigation','width','100','','','.w-tabs'),(135967,'printshop-mobile','.w-list-type-1 .button-wishlist','width','50','','','.w-list-type-1'),(135968,'printshop-mobile','.p-account-index .ai_title','width','40','','','.p-account-index'),(135969,'printshop-mobile','.w-top-categories .item','width','25','','','.w-top-categories'),(135970,'printshop-mobile','.w-search .button-search','width','48','','','.w-search'),(135971,'printshop-mobile','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width','100','','','.b-form'),(135972,'printshop-mobile','.p-account-history-info .history_info > div','width','33.3','','','.p-account-history-info'),(135973,'printshop-mobile','.b-form .middle-form .dob-input input[type=\"text\"]','width','48','','','.b-form'),(135974,'printshop-mobile','div.cart-popup','width','850','','',''),(135975,'printshop-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width','80','','','.b-products-listing'),(135976,'printshop-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width','20','','','.b-products-listing'),(135977,'printshop-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width','40','','','.b-products-listing'),(135978,'printshop-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width','60','','','.b-products-listing'),(135979,'printshop-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width','60','','','.b-products-listing'),(135980,'printshop-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width','40','','','.b-products-listing'),(135981,'printshop-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width','20','','','.b-products-listing'),(135982,'printshop-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width','60','','','.b-products-listing'),(135983,'printshop-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width','20','','','.b-products-listing'),(135984,'printshop-mobile','.b-products-listing .BlockBox.type-14 > .col','width','25','','','.b-products-listing'),(135985,'printshop-mobile','.b-products-listing .BlockBox.type-15 > .col','width','20','','','.b-products-listing'),(135986,'printshop-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width','50','','','.b-products-listing'),(135987,'printshop-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width','50','','','.b-products-listing'),(135988,'printshop-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(135989,'printshop-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(135990,'printshop-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width','33.33','','','.b-products-listing'),(135991,'printshop-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width','66.66','','','.b-products-listing'),(135992,'printshop-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(135993,'printshop-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(135994,'printshop-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width','66.66','','','.b-products-listing'),(135995,'printshop-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width','25','','','.b-products-listing'),(135996,'printshop-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width','75','','','.b-products-listing'),(135997,'printshop-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width','75','','','.b-products-listing'),(135998,'printshop-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width','25','','','.b-products-listing'),(135999,'printshop-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width','25','','','.b-products-listing'),(136000,'printshop-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width','50','','','.b-products-listing'),(136001,'printshop-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width','25','','','.b-products-listing'),(136002,'printshop-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width','20','','','.b-products-listing'),(136003,'printshop-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width','80','','','.b-products-listing'),(136004,'printshop-mobile','.b-products-listing .btn-choose-options','width','100','','','.b-products-listing'),(136005,'printshop-mobile','.b-products-listing .btn-preloader','width','24','3','','.b-products-listing'),(136006,'printshop-mobile','.b-products-listing .hover-box-content','width','20','3','','.b-products-listing'),(136007,'printshop-mobile','.b-products-listing .loader','width','30','4','','.b-products-listing'),(136008,'printshop-mobile','.b-products-listing .loader','width','100','3','','.b-products-listing'),(136009,'printshop-mobile','.b-products-listing .products-listing .attribute-qty-block','width','47','','','.b-products-listing'),(136010,'printshop-mobile','.b-products-listing .products-listing .attribute-qty-block > span','width','50','','','.b-products-listing'),(136011,'printshop-mobile','.b-products-listing .products-listing .attributes select','width','100','','','.b-products-listing'),(136012,'printshop-mobile','.b-products-listing .products-listing .btn-buy','width','100','','','.b-products-listing'),(136013,'printshop-mobile','.b-products-listing .products-listing .btn-preloader','width','100','','','.b-products-listing'),(136014,'printshop-mobile','.b-products-listing .products-listing .buyButton .btn','width','100','','','.b-products-listing'),(136015,'printshop-mobile','.b-products-listing .products-listing .in-cart','width','100','','','.b-products-listing'),(136016,'printshop-mobile','.b-products-listing .products-listing .item','width','25','','','.b-products-listing'),(136017,'printshop-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','width','35','','','.b-products-listing'),(136018,'printshop-mobile','.b-products-listing .products-listing .qty-input.hidden','width','100','3','','.b-products-listing'),(136019,'printshop-mobile','.b-products-listing .products-listing .radio-attributes .item-title','width','33','','','.b-products-listing'),(136020,'printshop-mobile','.b-products-listing .products-listing a.btn.view-button','width','100','','','.b-products-listing'),(136021,'printshop-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','width','auto','','','.b-products-listing'),(136022,'printshop-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width','100','','','.b-products-listing'),(136023,'printshop-mobile','.b-products-listing .select-attributes .item-title','width','33','','','.b-products-listing'),(136024,'printshop-mobile','.b-products-listing .select-attributes select','width','66','','','.b-products-listing'),(136025,'printshop-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(136026,'printshop-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(136027,'printshop-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(136028,'printshop-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(136029,'printshop-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(136030,'printshop-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(136031,'printshop-mobile','.b-email .totals-title','width','70','','','.b-email'),(136032,'printshop-mobile','.b-email .heading-image','width','100','','','.b-email'),(136033,'printshop-mobile','.b-email .image','width','100','','','.b-email'),(136034,'printshop-mobile','.b-email .heading-image','width','100','','','.b-email'),(136035,'printshop-mobile','.b-email .totals-title','width','70','','','.b-email'),(136036,'printshop-mobile','.b-email .totals-table','width','100','','','.b-email'),(136037,'printshop-mobile','.b-email .image','width','100','','','.b-email'),(136038,'printshop-mobile','.b-email .totals-table','width','100','','','.b-email'),(136039,'printshop-mobile','.b-email .totals-table','width','100','','','.b-email'),(136040,'printshop-mobile','.b-email .totals-value','width','30','','','.b-email'),(136041,'printshop-mobile','.b-email .totals-value','width','30','','','.b-email'),(136042,'printshop-mobile','.b-email .products-table','width','100','','','.b-email'),(136043,'printshop-mobile','.b-email .products-table','width','100','','','.b-email'),(136044,'printshop-mobile','.b-email img','width','60','','','.b-email'),(136045,'printshop-mobile','.b-email .heading-image','width','100','','','.b-email'),(136046,'printshop-mobile','.b-email .totals-value','width','30','','','.b-email'),(136047,'printshop-mobile','.b-email .products-table','width','100','','','.b-email'),(136048,'printshop-mobile','.b-email .image','width','100','','','.b-email'),(136049,'printshop-mobile','.b-email .totals-value','width','30','','','.b-email'),(136050,'printshop-mobile','.b-email .totals-title','width','70','','','.b-email'),(136051,'printshop-mobile','.b-email .products-table','width','100','','','.b-email'),(136052,'printshop-mobile','.b-email .totals-title','width','70','','','.b-email'),(136053,'printshop-mobile','.b-email .image','width','100','','','.b-email'),(136054,'printshop-mobile','.b-email .totals-value','width','30','','','.b-email'),(136055,'printshop-mobile','.b-email .image','width','100','','','.b-email'),(136056,'printshop-mobile','.b-email img','width','60','','','.b-email'),(136057,'printshop-mobile','.b-email .totals-title','width','70','','','.b-email'),(136058,'printshop-mobile','.b-email .heading-image','width','100','','','.b-email'),(136059,'printshop-mobile','.b-email img','width','60','','','.b-email'),(136060,'printshop-mobile','.b-email .totals-table','width','100','','','.b-email'),(136061,'printshop-mobile','.b-email .products-table','width','100','','','.b-email'),(136062,'printshop-mobile','.b-email .totals-title','width','70','','','.b-email'),(136063,'printshop-mobile','.b-email img','width','60','','','.b-email'),(136064,'printshop-mobile','.b-email .totals-table','width','100','','','.b-email'),(136065,'printshop-mobile','.b-email .heading-image','width','100','','','.b-email'),(136066,'printshop-mobile','.b-email img','width','60','','','.b-email'),(136067,'printshop-mobile','.b-email img','width','60','','','.b-email'),(136068,'printshop-mobile','.b-email .products-table','width','100','','','.b-email'),(136069,'printshop-mobile','.b-email .totals-table','width','100','','','.b-email'),(136070,'printshop-mobile','.b-email .totals-value','width','30','','','.b-email'),(136071,'printshop-mobile','.b-email .image','width','100','','','.b-email'),(136072,'printshop-mobile','.b-email .heading-image','width','100','','','.b-email'),(136073,'printshop-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(136074,'printshop-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(136075,'printshop-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(136076,'printshop-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(136077,'printshop-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(136078,'printshop-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(136079,'printshop-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','width','30','','','.b-menu-burger_icon'),(136080,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width','100','','','.b-menu-lev_display-slide'),(136081,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width','100','','','.b-menu-lev_display-slide'),(136082,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width','100','','','.b-menu-lev_display-slide'),(136083,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width','100','','','.b-menu-lev_display-slide'),(136084,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width','100','','','.b-menu-lev_display-slide'),(136085,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(136086,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(136087,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(136088,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(136089,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(136090,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width','100','','','.b-menu-open_from-left'),(136091,'printshop-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(136092,'printshop-mobile','.b-menu-style-1 .menu-style[data-lev2_display=\"width\"] .level-2 > li','width','300','','','.b-menu-style-1'),(136093,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','width','100','','','.b-menu-style-1'),(136094,'printshop-mobile','.b-menu-style-1 .menu-style[data-lev2_display=\"width_cont\"] .level-2 > li','width','300','','','.b-menu-style-1'),(136095,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','width','100','','','.b-menu-style-1'),(136096,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','width','40','','','.b-menu-style-2'),(136097,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','width','50','','','.b-menu-style-2'),(136098,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','width','36','','','.b-menu-style-2'),(136099,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','width','40','','','.b-menu-style-2'),(136100,'printshop-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','width','36','','','.b-menu-style-2'),(136101,'printshop-mobile','.b-messages .msv_to_cc div span.msv_to_cc_bold','width','100','','','.b-messages'),(136102,'printshop-mobile','.b-messages .box-block.type-6 > .block:nth-child(1)','width','25','','','.b-messages'),(136103,'printshop-mobile','.b-messages .messages-sidebar .btn-2','width','100','','','.b-messages'),(136104,'printshop-mobile','.b-messages .pre_upload','width','auto','','','.b-messages'),(136105,'printshop-mobile','.b-messages .email-line input','width','100','','','.b-messages'),(136106,'printshop-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead td:last-child, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td:last-child','width','200','','','.b-messages'),(136107,'printshop-mobile','.b-messages .email-line label','width','150','','','.b-messages'),(136108,'printshop-mobile','.b-preloader .preloader','width','100','','','.b-preloader'),(136109,'printshop-mobile','.b-preloader .preloader','width','40','3','','.b-preloader'),(136110,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width','1','','','.b-select-suggest'),(136111,'printshop-mobile','.b-select-suggest .select2-drop','width','100','','','.b-select-suggest'),(136112,'printshop-mobile','.b-select-suggest .select2-drop-mask','width','auto','','','.b-select-suggest'),(136113,'printshop-mobile','.b-select-suggest .select2-drop-auto-width','width','auto','','','.b-select-suggest'),(136114,'printshop-mobile','.b-select-suggest .select2-measure-scrollbar','width','100','','','.b-select-suggest'),(136115,'printshop-mobile','.b-select-suggest .select2-container .select2-choice abbr','width','12','','','.b-select-suggest'),(136116,'printshop-mobile','.b-select-suggest .select2-container','width','100','','','.b-select-suggest'),(136117,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width','100','','','.b-select-suggest'),(136118,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','width','18','','','.b-select-suggest'),(136119,'printshop-mobile','.b-select-suggest .select2-search','width','100','','','.b-select-suggest'),(136120,'printshop-mobile','.b-select-suggest .select2-search-choice-close','width','12','','','.b-select-suggest'),(136121,'printshop-mobile','.b-select-suggest .select2-search input','width','100','','','.b-select-suggest'),(136122,'printshop-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(136123,'printshop-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(136124,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(136125,'printshop-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(136126,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(136127,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(136128,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(136129,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(136130,'printshop-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(136131,'printshop-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(136132,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(136133,'printshop-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(136134,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(136135,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(136136,'printshop-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(136137,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(136138,'printshop-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(136139,'printshop-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(136140,'printshop-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(136141,'printshop-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(136142,'printshop-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(136143,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(136144,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(136145,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(136146,'printshop-mobile','.b-trade-approval .steps-bar','width','100','','','.b-trade-approval'),(136147,'printshop-mobile','.b-trade-approval .col-right','width','48','','','.b-trade-approval'),(136148,'printshop-mobile','.b-trade-approval .col-left','width','48','','','.b-trade-approval'),(136149,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width','100','','','.b-trade-approval'),(136150,'printshop-mobile','.b-trade-approval .col-3','width','31.33','','','.b-trade-approval'),(136151,'printshop-mobile','.b-upload-file .upload-file-template','width','150','','','.b-upload-file'),(136152,'printshop-mobile','.b-upload-file .snapshot','width','38','','','.b-upload-file'),(136153,'printshop-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','width','230','','','.b-warehouses-popup'),(136154,'printshop-mobile','.b-warehouses-popup .warehouses-popup','width','570','','','.b-warehouses-popup'),(136155,'printshop-mobile','.batchPr .w-batch-products .products-listing .attribute-qty-block','width','100','','','.batchPr'),(136156,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(2)','width','auto','','','.batchPr'),(136157,'printshop-mobile','.batchPr .checkbox input + span','width','80','','','.batchPr'),(136158,'printshop-mobile','.batchPr .batchSelect .checkbox','width','80','','','.batchPr'),(136159,'printshop-mobile','.batchPr .box-block.type-5 > .block:nth-child(1), .batchPr .box-block.type-5 > .block:nth-child(2)','width','50','','','.batchPr'),(136160,'printshop-mobile','.batchPr .checkbox input + span','width','32','','','.batchPr'),(136161,'printshop-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','width','40','','','.batchPr'),(136162,'printshop-mobile','.batchPr .checkbox input:not(checked) + span:before','width','30','','','.batchPr'),(136163,'printshop-mobile','.batchPr .btn-batch-remove','width','20','','','.batchPr'),(136164,'printshop-mobile','.p-account-samples-history .orders-table .hidden','width','130','','','.p-account-samples-history'),(136165,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','width','100','','','.p-account-samples-history'),(136166,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','width','100','','','.p-account-samples-history'),(136167,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','width','300','','','.p-account-samples-history'),(136168,'printshop-mobile','.p-account-samples-history .orders-table .hidden','width','130','','','.p-account-samples-history'),(136169,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','width','100','','','.p-account-samples-history'),(136170,'printshop-mobile','.p-account-samples-history .orders-table .hidden','width','130','','','.p-account-samples-history'),(136171,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','width','100','','','.p-account-samples-history'),(136172,'printshop-mobile','.p-account-samples-history .orders-table .hidden','width','130','','','.p-account-samples-history'),(136173,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','width','300','','','.p-account-samples-history'),(136174,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','width','100','','','.p-account-samples-history'),(136175,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','width','300','','','.p-account-samples-history'),(136176,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','width','300','','','.p-account-samples-history'),(136177,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','width','100','','','.p-account-samples-history'),(136178,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','width','300','','','.p-account-samples-history'),(136179,'printshop-mobile','.p-account-samples-history .orders-table .hidden','width','130','','','.p-account-samples-history'),(136180,'printshop-mobile','.p-account-samples-history .not_fully_paid_td','width','300','','','.p-account-samples-history'),(136181,'printshop-mobile','.p-account-samples-history .orders-table .hidden','width','130','','','.p-account-samples-history'),(136182,'printshop-mobile','.p-account-samples-history-info .history_info > div','width','100','','','.p-account-samples-history-info'),(136183,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','width','300','','','.p-account-samples-history-info'),(136184,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','width','300','','','.p-account-samples-history-info'),(136185,'printshop-mobile','.p-account-samples-history-info .history_info > div','width','33.3','','','.p-account-samples-history-info'),(136186,'printshop-mobile','.p-account-samples-history-info .history_info > div','width','100','','','.p-account-samples-history-info'),(136187,'printshop-mobile','.p-account-samples-history-info .history_info > div','width','100','','','.p-account-samples-history-info'),(136188,'printshop-mobile','.p-account-samples-history-info .history_info > div','width','33.3','','','.p-account-samples-history-info'),(136189,'printshop-mobile','.p-account-samples-history-info .history_info > div','width','33.3','','','.p-account-samples-history-info'),(136190,'printshop-mobile','.p-account-samples-history-info .history_info > div','width','100','','','.p-account-samples-history-info'),(136191,'printshop-mobile','.p-account-samples-history-info .history_info > div','width','100','','','.p-account-samples-history-info'),(136192,'printshop-mobile','.p-account-samples-history-info .history_info > div','width','100','','','.p-account-samples-history-info'),(136193,'printshop-mobile','.p-account-samples-history-info .history_info > div','width','33.3','','','.p-account-samples-history-info'),(136194,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','width','300','','','.p-account-samples-history-info'),(136195,'printshop-mobile','.p-account-samples-history-info .history_info > div','width','33.3','','','.p-account-samples-history-info'),(136196,'printshop-mobile','.p-account-samples-history-info .history_info > div','width','33.3','','','.p-account-samples-history-info'),(136197,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','width','300','','','.p-account-samples-history-info'),(136198,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','width','300','','','.p-account-samples-history-info'),(136199,'printshop-mobile','.p-account-samples-history-info .not_fully_paid_td','width','300','','','.p-account-samples-history-info'),(136200,'printshop-mobile','.p-catalog-product .prev-next-product','width','190','','','.p-catalog-product'),(136201,'printshop-mobile','.p-catalog-product .pn-image','width','24','3','','.p-catalog-product'),(136202,'printshop-mobile','.p-checkout-login .middle-form .btn-2','width','100','','','.p-checkout-login'),(136203,'printshop-mobile','.p-checkout-login .col-left, .p-checkout-login .col-right','width','100','','','.p-checkout-login'),(136204,'printshop-mobile','.p-payer-order-confirmation .order-summary2 .btn-2','width','100','','','.p-payer-order-confirmation'),(136205,'printshop-mobile','.p-payer-order-confirmation .dob-hide > div','width','48','','','.p-payer-order-confirmation'),(136206,'printshop-mobile','.p-payer-order-pay .order-summary2 .btn-2','width','100','','','.p-payer-order-pay'),(136207,'printshop-mobile','.p-payer-order-pay .dob-hide > div','width','48','','','.p-payer-order-pay'),(136208,'printshop-mobile','.p-quick-order-index .all-scroll-div','width','100','','','.p-quick-order-index'),(136209,'printshop-mobile','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width','100','','','.p-quote-checkout-login'),(136210,'printshop-mobile','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width','100','','','.p-sample-checkout-login'),(136211,'printshop-mobile','.w-account-address-book .item','width','50','','','.w-account-address-book'),(136212,'printshop-mobile','.w-account-address-book .add_item a','width','100','','','.w-account-address-book'),(136213,'printshop-mobile','.w-account-addresses-list .addsess-suggestion-item','width','50','','','.w-account-addresses-list'),(136214,'printshop-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width','60','','','.w-account-customer-additional-field'),(136215,'printshop-mobile','.w-account-customer-additional-field .field-type-text label','width','40','','','.w-account-customer-additional-field'),(136216,'printshop-mobile','.w-account-customer-additional-field .field-type-checkbox label','width','40','','','.w-account-customer-additional-field'),(136217,'printshop-mobile','.w-account-personal-catalog .list-switcher','width','100','','','.w-account-personal-catalog'),(136218,'printshop-mobile','.w-blog-widget-post-date ','width','100','','','.w-blog-widget-post-date'),(136219,'printshop-mobile','.w-blog-widget-post-image ','width','100','','','.w-blog-widget-post-image'),(136220,'printshop-mobile','.w-blog-widget-post-listing .post','width','33.33','','','.w-blog-widget-post-listing'),(136221,'printshop-mobile','.w-blog-widget-post-listing .post','width','100','','','.w-blog-widget-post-listing'),(136222,'printshop-mobile','.w-blog-widget-post-listing .post','width','50','','','.w-blog-widget-post-listing'),(136223,'printshop-mobile','.w-blog-widget-post-share ','width','1','4','','.w-blog-widget-post-share'),(136224,'printshop-mobile','.w-blog-widget-post-title ','width','100','','','.w-blog-widget-post-title'),(136225,'printshop-mobile','.w-blog-widget-related-posts .post','width','50','','','.w-blog-widget-related-posts'),(136226,'printshop-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','width','35','','','.w-blog-widget-related-posts'),(136227,'printshop-mobile','.w-blog-widget-related-posts-by-category .post','width','50','','','.w-blog-widget-related-posts-by-category'),(136228,'printshop-mobile','.w-cart-bonus-points .bonus_points_amount','width','150','','','.w-cart-bonus-points'),(136229,'printshop-mobile','.w-cart-bonus-points .btn-remove','width','25','','','.w-cart-bonus-points'),(136230,'printshop-mobile','.w-cart-compare .product .image','width','50','','','.w-cart-compare'),(136231,'printshop-mobile','.w-cart-credit-amount .btn-remove','width','25','','','.w-cart-credit-amount'),(136232,'printshop-mobile','.w-cart-credit-amount input[type=\"text\"]','width','150','','','.w-cart-credit-amount'),(136233,'printshop-mobile','.w-catalog-b2b-add-button ','width','100','','','.w-catalog-b2b-add-button'),(136234,'printshop-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','width','auto','','','.w-catalog-compare'),(136235,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','width','50','','','.w-catalog-compare'),(136236,'printshop-mobile','.w-catalog-paging .paging-holder','width','150','','','.w-catalog-paging'),(136237,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width','30','','','.w-catalog-paging'),(136238,'printshop-mobile','.w-checkout-billing-address .addresses .address-item','width','50','','','.w-checkout-billing-address'),(136239,'printshop-mobile','.w-checkout-billing-address .addresses.address-main .address-item','width','100','','','.w-checkout-billing-address'),(136240,'printshop-mobile','.w-checkout-bonus-points .btn-remove','width','25','','','.w-checkout-bonus-points'),(136241,'printshop-mobile','.w-checkout-bonus-points .bonus_points_amount','width','150','','','.w-checkout-bonus-points'),(136242,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','width','25','3','','.w-checkout-contact-information'),(136243,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','width','25','3','','.w-checkout-contact-information'),(136244,'printshop-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','width','25','3','','.w-checkout-contact-information'),(136245,'printshop-mobile','.w-checkout-create-account .col-2','width','100','','','.w-checkout-create-account'),(136246,'printshop-mobile','.w-checkout-create-btn .btn-2','width','240','','','.w-checkout-create-btn'),(136247,'printshop-mobile','.w-checkout-credit-amount .cot_gv_amount','width','150','','','.w-checkout-credit-amount'),(136248,'printshop-mobile','.w-checkout-credit-amount .btn-remove','width','25','','','.w-checkout-credit-amount'),(136249,'printshop-mobile','.w-checkout-guest-btn .btn-2','width','240','','','.w-checkout-guest-btn'),(136250,'printshop-mobile','.w-checkout-shipping-address .addresses.address-main .address-item','width','100','','','.w-checkout-shipping-address'),(136251,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item','width','50','','','.w-checkout-shipping-address'),(136252,'printshop-mobile','.w-checkout-shipping-choice #shippingchoice-choice','width','430','','','.w-checkout-shipping-choice'),(136253,'printshop-mobile','.w-checkout-shipping-choice label','width','50','','','.w-checkout-shipping-choice'),(136254,'printshop-mobile','.w-checkout-shipping-choice input:checked + span:before','width','10','','','.w-checkout-shipping-choice'),(136255,'printshop-mobile','.w-checkout-shipping-choice label','width','auto','','','.w-checkout-shipping-choice'),(136256,'printshop-mobile','.w-checkout-shipping-choice #shippingchoice-choice','width','auto','','','.w-checkout-shipping-choice'),(136257,'printshop-mobile','.w-checkout-terms .required-message','width','100','','','.w-checkout-terms'),(136258,'printshop-mobile','.w-communication-new-topic .return-reason','width','150','','','.w-communication-new-topic'),(136259,'printshop-mobile','.w-communication-new-topic .request-type','width','150','','','.w-communication-new-topic'),(136260,'printshop-mobile','.w-communication-new-topic .date-purchased','width','130','','','.w-communication-new-topic'),(136261,'printshop-mobile','.w-communication-new-topic .middle-form select','width','100','','','.w-communication-new-topic'),(136262,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','width','36','','','.w-communication-new-topic'),(136263,'printshop-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateTo\"]','width','60','','','.w-communication-new-topic'),(136264,'printshop-mobile','.w-communication-new-topic .btn-submit','width','200','','','.w-communication-new-topic'),(136265,'printshop-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterOrderId\"]','width','60','','','.w-communication-new-topic'),(136266,'printshop-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','width','36','','','.w-communication-new-topic'),(136267,'printshop-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateFrom\"]','width','60','','','.w-communication-new-topic'),(136268,'printshop-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterName\"]','width','100','','','.w-communication-new-topic'),(136269,'printshop-mobile','.w-communication-new-topic .model','width','100','','','.w-communication-new-topic'),(136270,'printshop-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterSku\"]','width','60','','','.w-communication-new-topic'),(136271,'printshop-mobile','.w-coupons-and-vauchers-checkout .btn-remove','width','25','','','.w-coupons-and-vauchers-checkout'),(136272,'printshop-mobile','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width','150','','','.w-coupons-and-vauchers-checkout'),(136273,'printshop-mobile','.w-delayed-despatch-checkout #delivery_date','width','150','','','.w-delayed-despatch-checkout'),(136274,'printshop-mobile','.w-image-maps .svg-wrap svg','width','100','','','.w-image-maps'),(136275,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','width','250','','','.w-image-maps'),(136276,'printshop-mobile','.w-list-b2b .select-attributes','width','47','','','.w-list-b2b'),(136277,'printshop-mobile','.w-personal-gift-status-bar .progress-bar','width','230','','','.w-personal-gift-status-bar'),(136278,'printshop-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(136279,'printshop-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(136280,'printshop-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(136281,'printshop-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(136282,'printshop-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(136283,'printshop-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(136284,'printshop-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(136285,'printshop-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(136286,'printshop-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(136287,'printshop-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(136288,'printshop-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(136289,'printshop-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(136290,'printshop-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(136291,'printshop-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(136292,'printshop-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(136293,'printshop-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(136294,'printshop-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(136295,'printshop-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(136296,'printshop-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(136297,'printshop-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(136298,'printshop-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(136299,'printshop-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(136300,'printshop-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(136301,'printshop-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(136302,'printshop-mobile','.w-product-customers-activity .customers-activity','width','255','','','.w-product-customers-activity'),(136303,'printshop-mobile','.w-product-customers-activity .close','width','30','','','.w-product-customers-activity'),(136304,'printshop-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(136305,'printshop-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(136306,'printshop-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(136307,'printshop-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(136308,'printshop-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(136309,'printshop-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(136310,'printshop-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(136311,'printshop-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(136312,'printshop-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(136313,'printshop-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(136314,'printshop-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(136315,'printshop-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(136316,'printshop-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(136317,'printshop-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(136318,'printshop-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(136319,'printshop-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(136320,'printshop-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(136321,'printshop-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(136322,'printshop-mobile','.w-promotions .prom-multi-discount .list','width','100','','','.w-promotions'),(136323,'printshop-mobile','.w-promotions .nextdiscount .item-holder .image','width','40','','','.w-promotions'),(136324,'printshop-mobile','.w-promotions .promo-cart-discount .master .item','width','calc(50% - 24px)','','','.w-promotions'),(136325,'printshop-mobile','.w-promotions .promo-cart-discount .image img','width','auto','','','.w-promotions'),(136326,'printshop-mobile','.w-promotions .promo-cart-discount > div','width','50','','','.w-promotions'),(136327,'printshop-mobile','.w-promotions .promo-cart-discount .slave .item','width','calc(50% - 4px)','','','.w-promotions'),(136328,'printshop-mobile','.w-promotions .promo-salemaker .image img','width','auto','','','.w-promotions'),(136329,'printshop-mobile','.w-promotions .promo-salemaker .item','width','50','','','.w-promotions'),(136330,'printshop-mobile','.w-promotions .promo-salemaker > div','width','50','','','.w-promotions'),(136331,'printshop-mobile','.w-promotions .prom-multi-discount .image img','width','auto','','','.w-promotions'),(136332,'printshop-mobile','.w-promotions .nextdiscount .item-holder .name','width','60','','','.w-promotions'),(136333,'printshop-mobile','.w-promotions .icon','width','45','','','.w-promotions'),(136334,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul > li','width','25','','','.w-sitemap-delivery-location'),(136335,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(136336,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','width','150','','','.w-upload-customer-id-upload-customer-id-form'),(136337,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(136338,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box-full','width','auto','','','.w-wedding-registry-widgets-photos'),(136339,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-box','width','180','','','.w-wedding-registry-widgets-photos'),(136340,'printshop-mobile','.w-wedding-registry-widgets-photos .avatar-container','width','144','','','.w-wedding-registry-widgets-photos'),(136341,'printshop-mobile','.w-wedding-registry-widgets-products .products-listing .item','width','33','','','.w-wedding-registry-widgets-products'),(136342,'printshop-mobile','.w-wedding-registry-widgets-products .products-listing .item','width','50','','','.w-wedding-registry-widgets-products'),(136343,'printshop-mobile','.w-wedding-registry-widgets-products .products-listing .item','width','100','','','.w-wedding-registry-widgets-products'),(136344,'printshop-mobile','.w-wedding-registry-widgets-share-url input','width','100','','','.w-wedding-registry-widgets-share-url'),(136345,'printshop-mobile','.b-quantity .qty-box input[type=\'text\']','width','60','','','.b-quantity'),(136346,'printshop-mobile','.p-shopping-cart-index .order-summary .btn-2','width','100','','','.p-shopping-cart-index'),(136347,'printshop-mobile','.w-menu .hided.menu ul ul','width_important','important','','','.w-menu'),(136348,'printshop-mobile','.w-menu .hided.menu ul li','width_important','important','','','.w-menu'),(136349,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width_important','important','3','','.b-switch'),(136350,'printshop-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width_important','important','3','','.b-switch'),(136351,'printshop-mobile','.b-messages .pre_upload','width_important','important','','','.b-messages'),(136352,'printshop-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width_important','important','','','.b-select-suggest'),(136353,'printshop-mobile','.b-warehouses-popup .warehouses-popup','width_important','important','','','.b-warehouses-popup'),(136354,'printshop-mobile','.w-cart-bonus-points .bonus_points_amount','width_important','important','','','.w-cart-bonus-points'),(136355,'printshop-mobile','.w-cart-credit-amount input[type=\"text\"]','width_important','important','','','.w-cart-credit-amount'),(136356,'printshop-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width_important','important','','','.w-catalog-paging'),(136357,'printshop-mobile','.w-checkout-bonus-points .bonus_points_amount','width_important','important','','','.w-checkout-bonus-points'),(136358,'printshop-mobile','.w-checkout-credit-amount .cot_gv_amount','width_important','important','','','.w-checkout-credit-amount'),(136359,'printshop-mobile','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width_important','important','','','.w-coupons-and-vauchers-checkout'),(136360,'printshop-mobile','.w-menu-slider > ul > li > ul','width_measure','%','','','.w-menu-slider'),(136361,'printshop-mobile','.b-form .checkbox-style:checked + .checkbox-span','width_measure','x','','','.b-form'),(136362,'printshop-mobile','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(136363,'printshop-mobile','.w-login-block .returning','width_measure','%','','','.w-login-block'),(136364,'printshop-mobile','.w-login-block .new','width_measure','%','','','.w-login-block'),(136365,'printshop-mobile','.w-login-block .guest','width_measure','%','','','.w-login-block'),(136366,'printshop-mobile','.w-login-block .input','width_measure','%','','','.w-login-block'),(136367,'printshop-mobile','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(136368,'printshop-mobile','.w-list-type-2_2 .sale','width_measure','%','4','','.w-list-type-2_2'),(136369,'printshop-mobile','.w-sale .holder-1','width_measure','%','','','.w-sale'),(136370,'printshop-mobile','.w-sale .image','width_measure','%','','','.w-sale'),(136371,'printshop-mobile','.w-sale .holder-2','width_measure','%','','','.w-sale'),(136372,'printshop-mobile','.w-product-attributes .select','width_measure','%','','','.w-product-attributes'),(136373,'printshop-mobile','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(136374,'printshop-mobile','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(136375,'printshop-mobile','.w-menu-mobile .menu-slider .open','width_measure','vw','','','.w-menu-mobile'),(136376,'printshop-mobile','.w-product-sale-ends .left-count','width_measure','%','','','.w-product-sale-ends'),(136377,'printshop-mobile','.w-product-sale-ends .left-text-left','width_measure','%','','','.w-product-sale-ends'),(136378,'printshop-mobile','.w-product-sale-ends .left-text-right','width_measure','%','','','.w-product-sale-ends'),(136379,'printshop-mobile','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(136380,'printshop-mobile','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(136381,'printshop-mobile','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(136382,'printshop-mobile','.b-fancybox .fancybox-nav','width_measure','%','','','.b-fancybox'),(136383,'printshop-mobile','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(136384,'printshop-mobile','.w-categories .item','width_measure','%','693','','.w-categories'),(136385,'printshop-mobile','.w-top-categories .item','width_measure','%','693','','.w-top-categories'),(136386,'printshop-mobile','.w-currencies .select','width_measure','%','','','.w-currencies'),(136387,'printshop-mobile','.w-categories .item','width_measure','%','','','.w-categories'),(136388,'printshop-mobile','.w-cart-give-away .ga_column','width_measure','%','693','','.w-cart-give-away'),(136389,'printshop-mobile','.w-cart-order-total.box','width_measure','%','722','','.w-cart-order-total'),(136390,'printshop-mobile','.w-cart-checkout-btn','width_measure','%','693','','.w-cart-checkout-btn'),(136391,'printshop-mobile','.b-product-images .additional-horizontal .additional-images, .b-product-images .additional-horizontal .additional-videos','width_measure','%','','','.b-product-images'),(136392,'printshop-mobile','.w-product-properties li','width_measure','%','','','.w-product-properties'),(136393,'printshop-mobile','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(136394,'printshop-mobile','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(136395,'printshop-mobile','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(136396,'printshop-mobile','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(136397,'printshop-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','width_measure','%','','','.p-account-address-book'),(136398,'printshop-mobile','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(136399,'printshop-mobile','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(136400,'printshop-mobile','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(136401,'printshop-mobile','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(136402,'printshop-mobile','.p-account-index .topAccount > li','width_measure','%','693','','.p-account-index'),(136403,'printshop-mobile','.p-account-address-book .address_book_row .column','width_measure','%','693','','.p-account-address-book'),(136404,'printshop-mobile','.p-account-address-book .address_book_row .column + .column','width_measure','%','693','','.p-account-address-book'),(136405,'printshop-mobile','.p-account-history-info .history_info > div','width_measure','%','694','','.p-account-history-info'),(136406,'printshop-mobile','.p-account-address-book .topInfo > div','width_measure','%','693','','.p-account-address-book'),(136407,'printshop-mobile','.p-account-address-book .topInfo > div + div','width_measure','%','693','','.p-account-address-book'),(136408,'printshop-mobile','.p-blog-index .nav-next','width_measure','%','718','','.p-blog-index'),(136409,'printshop-mobile','.w-list-type-1_2 .right-area','width_measure','%','694','','.w-list-type-1_2'),(136410,'printshop-mobile','.w-list-type-1_2 .right-area .right-area-2','width_measure','%','694','','.w-list-type-1_2'),(136411,'printshop-mobile','.p-blog-index .nav-previous','width_measure','%','718','','.p-blog-index'),(136412,'printshop-mobile','.w-list-type-1_2 .image','width_measure','%','694','','.w-list-type-1_2'),(136413,'printshop-mobile','.w-list-type-1_2 .right-area .name','width_measure','%','694','','.w-list-type-1_2'),(136414,'printshop-mobile','.w-list-type-1_2 .right-area .name','width_measure','%','','','.w-list-type-1_2'),(136415,'printshop-mobile','.w-list-type-1_2 .right-area .right-area-2','width_measure','%','','','.w-list-type-1_2'),(136416,'printshop-mobile','.w-promo-code .promo-code-form','width_measure','%','694','','.w-promo-code'),(136417,'printshop-mobile','.w-promo-code .promo-text','width_measure','%','694','','.w-promo-code'),(136418,'printshop-mobile','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(136419,'printshop-mobile','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(136420,'printshop-mobile','.b-form .col-right','width_measure','%','720','','.b-form'),(136421,'printshop-mobile','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(136422,'printshop-mobile','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(136423,'printshop-mobile','.b-form .col-left','width_measure','%','720','','.b-form'),(136424,'printshop-mobile','.b-form .columns .col-2','width_measure','%','723','','.b-form'),(136425,'printshop-mobile','.p-account-order-pay .history_info > div','width_measure','%','694','','.p-account-order-pay'),(136426,'printshop-mobile','.p-account-order-pay .history_info > div','width_measure','%','','','.p-account-order-pay'),(136427,'printshop-mobile','.w-product-configurator .item-content','width_measure','%','702','','.w-product-configurator'),(136428,'printshop-mobile','.w-product-configurator .pc_item','width_measure','%','702','','.w-product-configurator'),(136429,'printshop-mobile','.p-wedding-registry-manage .wr-search input','width_measure','%','','','.p-wedding-registry-manage'),(136430,'printshop-mobile','.p-account-history .orders-table .td-alignright','width_measure','%','720','','.p-account-history'),(136431,'printshop-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','720','','.p-blog-index'),(136432,'printshop-mobile','.p-blog-index .nav-previous','width_measure','%','','','.p-blog-index'),(136433,'printshop-mobile','.p-account-index .orders-table .td-alignright','width_measure','%','720','','.p-account-index'),(136434,'printshop-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','723','','.p-blog-index'),(136435,'printshop-mobile','.p-blog-index .nav-next','width_measure','%','','','.p-blog-index'),(136436,'printshop-mobile','.w-list-type-1_3 .right-area .right-area-2','width_measure','%','','','.w-list-type-1_3'),(136437,'printshop-mobile','.pop-up-content .buttons .right-buttons','width_measure','%','694','',''),(136438,'printshop-mobile','.w-list-type-2_2 .sale','width_measure','%','3','','.w-list-type-2_2'),(136439,'printshop-mobile','.pop-up-content .buttons .btn-2','width_measure','%','694','',''),(136440,'printshop-mobile','.pop-up-content .buttons .left-buttons','width_measure','%','694','',''),(136441,'printshop-mobile','.pop-up-content .buttons .btn','width_measure','%','694','',''),(136442,'printshop-mobile','.b-form .columns .col-2','width_measure','%','','','.b-form'),(136443,'printshop-mobile','.w-list-type-2_2 .button-wishlist button','width_measure','%','','','.w-list-type-2_2'),(136444,'printshop-mobile','.w-list-type-2 .sale','width_measure','%','3','','.w-list-type-2'),(136445,'printshop-mobile','.w-list-type-2_2 .button-wishlist','width_measure','%','','','.w-list-type-2_2'),(136446,'printshop-mobile','.personal-buttons > div > div','width_measure','%','','','.personal-buttons'),(136447,'printshop-mobile','.w-product-bonus-points > div > div','width_measure','%','','','.w-product-bonus-points'),(136448,'printshop-mobile','.w-cart-checkout-btn a','width_measure','%','693','','.w-cart-checkout-btn'),(136449,'printshop-mobile','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(136450,'printshop-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width_measure','%','','','.b-fancybox'),(136451,'printshop-mobile','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(136452,'printshop-mobile','.p-wedding-registry-search .search-list input','width_measure','%','','','.p-wedding-registry-search'),(136453,'printshop-mobile','.b-bottom .popup-credit-amount .popup-box','width_measure','%','','','.b-bottom'),(136454,'printshop-mobile','.b-compare .col-two select','width_measure','%','','','.b-compare'),(136455,'printshop-mobile','.b-compare .col-two label','width_measure','%','','','.b-compare'),(136456,'printshop-mobile','.w-list-type-1 .button-wishlist','width_measure','%','','','.w-list-type-1'),(136457,'printshop-mobile','.w-search .suggest','width_measure','vw','','','.w-search'),(136458,'printshop-mobile','.w-search .search-input','width_measure','%','','','.w-search'),(136459,'printshop-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width_measure','%','','','.w-banner'),(136460,'printshop-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(136461,'printshop-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(136462,'printshop-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width_measure','%','','','.p-account-trade-form'),(136463,'printshop-mobile','.p-account-trade-form .wl-td label','width_measure','%','','','.p-account-trade-form'),(136464,'printshop-mobile','.p-account-trade-form .wl-td select','width_measure','%','','','.p-account-trade-form'),(136465,'printshop-mobile','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width_measure','%','','','.w-banner'),(136466,'printshop-mobile','.w-filters .handle-to','width_measure','%','','','.w-filters'),(136467,'printshop-mobile','.b-bottom .popup-box.popupCompare','width_measure','%','','','.b-bottom'),(136468,'printshop-mobile','.w-filters .handle-from','width_measure','%','','','.w-filters'),(136469,'printshop-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(136470,'printshop-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(136471,'printshop-mobile','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(136472,'printshop-mobile','.w-product-buttons .btn, .w-product-buttons .btn-2, .w-product-buttons .btn-3, .w-product-buttons .btn-4','width_measure','%','','','.w-product-buttons'),(136473,'printshop-mobile','.p-reviews-info .review-info-image','width_measure','%','','','.p-reviews-info'),(136474,'printshop-mobile','.w-search .search form','width_measure','vw','','','.w-search'),(136475,'printshop-mobile','.p-checkout-success .page-success','width_measure','%','3','','.p-checkout-success'),(136476,'printshop-mobile','.p-account-index .topAccount > li','width_measure','%','','','.p-account-index'),(136477,'printshop-mobile','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(136478,'printshop-mobile','.w-sale .left-text-right','width_measure','%','','','.w-sale'),(136479,'printshop-mobile','.w-sale .left-count','width_measure','%','','','.w-sale'),(136480,'printshop-mobile','.w-sale .left-text-left','width_measure','%','','','.w-sale'),(136481,'printshop-mobile','.w-banner .carousel-text','width_measure','%','','','.w-banner'),(136482,'printshop-mobile','.w-list-type-1_3 .right-area .name','width_measure','%','','','.w-list-type-1_3'),(136483,'printshop-mobile','.w-list-type-1_3 .right-area .right-area-2','width_measure','%','694','','.w-list-type-1_3'),(136484,'printshop-mobile','.w-list-type-1_3 .right-area .name','width_measure','%','694','','.w-list-type-1_3'),(136485,'printshop-mobile','.w-list-type-1_3 .right-area','width_measure','%','694','','.w-list-type-1_3'),(136486,'printshop-mobile','.w-list-type-1_3 .image','width_measure','%','694','','.w-list-type-1_3'),(136487,'printshop-mobile','.w-cart-continue-btn a','width_measure','%','693','','.w-cart-continue-btn'),(136488,'printshop-mobile','.w-top-categories .item','width_measure','%','','','.w-top-categories'),(136489,'printshop-mobile','.w-cart-discount-coupon .gift-code input','width_measure','%','','','.w-cart-discount-coupon'),(136490,'printshop-mobile','.w-cart-order-total.box','width_measure','%','','','.w-cart-order-total'),(136491,'printshop-mobile','.p-account-index .account_info li','width_measure','%','693','','.p-account-index'),(136492,'printshop-mobile','.p-account-index .ai_title','width_measure','%','','','.p-account-index'),(136493,'printshop-mobile','.b-form .addresses .address-item','width_measure','%','','','.b-form'),(136494,'printshop-mobile','textarea','width_measure','%','','',''),(136495,'printshop-mobile','.b-form .discount-box input[type=\"text\"]','width_measure','%','','','.b-form'),(136496,'printshop-mobile','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width_measure','%','','','.b-form'),(136497,'printshop-mobile','.p-account-index .account_info li','width_measure','%','','','.p-account-index'),(136498,'printshop-mobile','.p-account-history-info .history_info > div','width_measure','%','','','.p-account-history-info'),(136499,'printshop-mobile','.b-form .col-right','width_measure','%','','','.b-form'),(136500,'printshop-mobile','.w-cart-give-away .ga_attributes > div','width_measure','%','','','.w-cart-give-away'),(136501,'printshop-mobile','.w-cart-give-away .ga_attributes select','width_measure','%','','','.w-cart-give-away'),(136502,'printshop-mobile','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(136503,'printshop-mobile','.w-cart-give-away .ga_column','width_measure','%','','','.w-cart-give-away'),(136504,'printshop-mobile','.w-cart-give-away .ga_img','width_measure','%','','','.w-cart-give-away'),(136505,'printshop-mobile','.view-all','width_measure','%','3','',''),(136506,'printshop-mobile','.w-list-type-1_3 .sale','width_measure','%','4','','.w-list-type-1_3'),(136507,'printshop-mobile','.w-list-type-2 .button-wishlist','width_measure','%','','','.w-list-type-2'),(136508,'printshop-mobile','.w-list-type-1_3 .sale','width_measure','%','3','','.w-list-type-1_3'),(136509,'printshop-mobile','.w-list-type-2 .sale','width_measure','%','4','','.w-list-type-2'),(136510,'printshop-mobile','.w-list-type-2 .button-wishlist button','width_measure','%','','','.w-list-type-2'),(136511,'printshop-mobile','.w-list-type-1_3 .button-wishlist','width_measure','%','','','.w-list-type-1_3'),(136512,'printshop-mobile','.w-list-type-1_3 .button-wishlist button','width_measure','%','','','.w-list-type-1_3'),(136513,'printshop-mobile','.w-list-type-1_2 .sale','width_measure','%','3','','.w-list-type-1_2'),(136514,'printshop-mobile','.w-list-type-1_2 .sale','width_measure','%','4','','.w-list-type-1_2'),(136515,'printshop-mobile','.w-list-type-1_3 .attributes > .attributes > div','width_measure','%','','','.w-list-type-1_3'),(136516,'printshop-mobile','.w-list-type-1_2 .button-wishlist button','width_measure','%','','','.w-list-type-1_2'),(136517,'printshop-mobile','.w-list-type-1_2 .button-wishlist','width_measure','%','','','.w-list-type-1_2'),(136518,'printshop-mobile','.w-list-type-1_2 .button-view','width_measure','%','','','.w-list-type-1_2'),(136519,'printshop-mobile','.w-list-type-1 .sale','width_measure','%','4','','.w-list-type-1'),(136520,'printshop-mobile','.w-list-type-1 .sale','width_measure','%','3','','.w-list-type-1'),(136521,'printshop-mobile','.w-list-type-1 .button-wishlist button','width_measure','%','','','.w-list-type-1'),(136522,'printshop-mobile','.w-filters .input-txt','width_measure','%','','','.w-filters'),(136523,'printshop-mobile','.w-filters .input-txt-keywords','width_measure','%','','','.w-filters'),(136524,'printshop-mobile','.w-filters .ui-slider','width_measure','%','','','.w-filters'),(136525,'printshop-mobile','.w-tabs .tab-navigation','width_measure','%','','','.w-tabs'),(136526,'printshop-mobile','.b-form .hide-billing-address','width_measure','%','','','.b-form'),(136527,'printshop-mobile','.b-form .col-left','width_measure','%','','','.b-form'),(136528,'printshop-mobile','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width_measure','%','','','.b-form'),(136529,'printshop-mobile','.b-form .middle-form .dob-input input[type=\"text\"]','width_measure','%','','','.b-form'),(136530,'printshop-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(136531,'printshop-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(136532,'printshop-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(136533,'printshop-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(136534,'printshop-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(136535,'printshop-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(136536,'printshop-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(136537,'printshop-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(136538,'printshop-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(136539,'printshop-mobile','.b-products-listing .BlockBox.type-14 > .col','width_measure','%','','','.b-products-listing'),(136540,'printshop-mobile','.b-products-listing .BlockBox.type-15 > .col','width_measure','%','','','.b-products-listing'),(136541,'printshop-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(136542,'printshop-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(136543,'printshop-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(136544,'printshop-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(136545,'printshop-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(136546,'printshop-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(136547,'printshop-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(136548,'printshop-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(136549,'printshop-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(136550,'printshop-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(136551,'printshop-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(136552,'printshop-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(136553,'printshop-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(136554,'printshop-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(136555,'printshop-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(136556,'printshop-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(136557,'printshop-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(136558,'printshop-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(136559,'printshop-mobile','.b-products-listing .btn-choose-options','width_measure','%','','','.b-products-listing'),(136560,'printshop-mobile','.b-products-listing .loader','width_measure','%','3','','.b-products-listing'),(136561,'printshop-mobile','.b-products-listing .products-listing .attribute-qty-block','width_measure','%','','','.b-products-listing'),(136562,'printshop-mobile','.b-products-listing .products-listing .attribute-qty-block > span','width_measure','%','','','.b-products-listing'),(136563,'printshop-mobile','.b-products-listing .products-listing .attributes select','width_measure','%','','','.b-products-listing'),(136564,'printshop-mobile','.b-products-listing .products-listing .btn-buy','width_measure','%','','','.b-products-listing'),(136565,'printshop-mobile','.b-products-listing .products-listing .btn-preloader','width_measure','%','','','.b-products-listing'),(136566,'printshop-mobile','.b-products-listing .products-listing .buyButton .btn','width_measure','%','','','.b-products-listing'),(136567,'printshop-mobile','.b-products-listing .products-listing .in-cart','width_measure','%','','','.b-products-listing'),(136568,'printshop-mobile','.b-products-listing .products-listing .item','width_measure','%','','','.b-products-listing'),(136569,'printshop-mobile','.b-products-listing .products-listing .qty-input.hidden','width_measure','%','3','','.b-products-listing'),(136570,'printshop-mobile','.b-products-listing .products-listing .radio-attributes .item-title','width_measure','%','','','.b-products-listing'),(136571,'printshop-mobile','.b-products-listing .products-listing a.btn.view-button','width_measure','%','','','.b-products-listing'),(136572,'printshop-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width_measure','%','','','.b-products-listing'),(136573,'printshop-mobile','.b-products-listing .select-attributes .item-title','width_measure','%','','','.b-products-listing'),(136574,'printshop-mobile','.b-products-listing .select-attributes select','width_measure','%','','','.b-products-listing'),(136575,'printshop-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(136576,'printshop-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(136577,'printshop-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(136578,'printshop-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(136579,'printshop-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(136580,'printshop-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(136581,'printshop-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(136582,'printshop-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(136583,'printshop-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(136584,'printshop-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(136585,'printshop-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(136586,'printshop-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(136587,'printshop-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(136588,'printshop-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(136589,'printshop-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(136590,'printshop-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(136591,'printshop-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(136592,'printshop-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(136593,'printshop-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(136594,'printshop-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(136595,'printshop-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(136596,'printshop-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(136597,'printshop-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(136598,'printshop-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(136599,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width_measure','vw','','','.b-menu-lev_display-slide'),(136600,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width_measure','vw','','','.b-menu-lev_display-slide'),(136601,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width_measure','vw','','','.b-menu-lev_display-slide'),(136602,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width_measure','vw','','','.b-menu-lev_display-slide'),(136603,'printshop-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width_measure','vw','','','.b-menu-lev_display-slide'),(136604,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_measure','vw','','','.b-menu-open_from-left'),(136605,'printshop-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(136606,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','width_measure','%','','','.b-menu-style-1'),(136607,'printshop-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','width_measure','%','','','.b-menu-style-1'),(136608,'printshop-mobile','.b-messages .box-block.type-6 > .block:nth-child(1)','width_measure','%','','','.b-messages'),(136609,'printshop-mobile','.b-messages .messages-sidebar .btn-2','width_measure','%','','','.b-messages'),(136610,'printshop-mobile','.b-messages .email-line input','width_measure','%','','','.b-messages'),(136611,'printshop-mobile','.b-preloader .preloader','width_measure','%','','','.b-preloader'),(136612,'printshop-mobile','.b-select-suggest .select2-search input','width_measure','%','','','.b-select-suggest'),(136613,'printshop-mobile','.b-select-suggest .select2-container','width_measure','%','','','.b-select-suggest'),(136614,'printshop-mobile','.b-select-suggest .select2-drop','width_measure','%','','','.b-select-suggest'),(136615,'printshop-mobile','.b-select-suggest .select2-search','width_measure','%','','','.b-select-suggest'),(136616,'printshop-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width_measure','%','','','.b-select-suggest'),(136617,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(136618,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(136619,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(136620,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(136621,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(136622,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(136623,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(136624,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(136625,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(136626,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(136627,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(136628,'printshop-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(136629,'printshop-mobile','.b-trade-approval .steps-bar','width_measure','%','','','.b-trade-approval'),(136630,'printshop-mobile','.b-trade-approval .col-right','width_measure','%','','','.b-trade-approval'),(136631,'printshop-mobile','.b-trade-approval .col-left','width_measure','%','','','.b-trade-approval'),(136632,'printshop-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width_measure','%','','','.b-trade-approval'),(136633,'printshop-mobile','.b-trade-approval .col-3','width_measure','%','','','.b-trade-approval'),(136634,'printshop-mobile','.batchPr .w-batch-products .products-listing .attribute-qty-block','width_measure','%','','','.batchPr'),(136635,'printshop-mobile','.batchPr .box-block.type-5 > .block:nth-child(1), .batchPr .box-block.type-5 > .block:nth-child(2)','width_measure','%','','','.batchPr'),(136636,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','width_measure','%','','','.p-account-samples-history'),(136637,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','width_measure','%','','','.p-account-samples-history'),(136638,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','width_measure','%','','','.p-account-samples-history'),(136639,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','width_measure','%','','','.p-account-samples-history'),(136640,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','width_measure','%','','','.p-account-samples-history'),(136641,'printshop-mobile','.p-account-samples-history .orders-table .td-alignright','width_measure','%','','','.p-account-samples-history'),(136642,'printshop-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(136643,'printshop-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(136644,'printshop-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(136645,'printshop-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(136646,'printshop-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(136647,'printshop-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(136648,'printshop-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(136649,'printshop-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(136650,'printshop-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(136651,'printshop-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(136652,'printshop-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(136653,'printshop-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(136654,'printshop-mobile','.p-checkout-login .col-left, .p-checkout-login .col-right','width_measure','%','','','.p-checkout-login'),(136655,'printshop-mobile','.p-checkout-login .middle-form .btn-2','width_measure','%','','','.p-checkout-login'),(136656,'printshop-mobile','.p-payer-order-confirmation .dob-hide > div','width_measure','%','','','.p-payer-order-confirmation'),(136657,'printshop-mobile','.p-payer-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-confirmation'),(136658,'printshop-mobile','.p-payer-order-pay .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-pay'),(136659,'printshop-mobile','.p-payer-order-pay .dob-hide > div','width_measure','%','','','.p-payer-order-pay'),(136660,'printshop-mobile','.p-quick-order-index .all-scroll-div','width_measure','%','','','.p-quick-order-index'),(136661,'printshop-mobile','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width_measure','%','','','.p-quote-checkout-login'),(136662,'printshop-mobile','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width_measure','%','','','.p-sample-checkout-login'),(136663,'printshop-mobile','.w-account-address-book .item','width_measure','%','','','.w-account-address-book'),(136664,'printshop-mobile','.w-account-address-book .add_item a','width_measure','%','','','.w-account-address-book'),(136665,'printshop-mobile','.w-account-addresses-list .addsess-suggestion-item','width_measure','%','','','.w-account-addresses-list'),(136666,'printshop-mobile','.w-account-customer-additional-field .field-type-checkbox label','width_measure','%','','','.w-account-customer-additional-field'),(136667,'printshop-mobile','.w-account-customer-additional-field .field-type-text label','width_measure','%','','','.w-account-customer-additional-field'),(136668,'printshop-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width_measure','%','','','.w-account-customer-additional-field'),(136669,'printshop-mobile','.w-account-personal-catalog .list-switcher','width_measure','%','','','.w-account-personal-catalog'),(136670,'printshop-mobile','.w-blog-widget-post-date ','width_measure','%','','','.w-blog-widget-post-date'),(136671,'printshop-mobile','.w-blog-widget-post-image ','width_measure','%','','','.w-blog-widget-post-image'),(136672,'printshop-mobile','.w-blog-widget-post-listing .post','width_measure','%','','','.w-blog-widget-post-listing'),(136673,'printshop-mobile','.w-blog-widget-post-listing .post','width_measure','%','','','.w-blog-widget-post-listing'),(136674,'printshop-mobile','.w-blog-widget-post-listing .post','width_measure','%','','','.w-blog-widget-post-listing'),(136675,'printshop-mobile','.w-blog-widget-post-title ','width_measure','%','','','.w-blog-widget-post-title'),(136676,'printshop-mobile','.w-blog-widget-related-posts .post','width_measure','%','','','.w-blog-widget-related-posts'),(136677,'printshop-mobile','.w-blog-widget-related-posts-by-category .post','width_measure','%','','','.w-blog-widget-related-posts-by-category'),(136678,'printshop-mobile','.w-catalog-b2b-add-button ','width_measure','%','','','.w-catalog-b2b-add-button'),(136679,'printshop-mobile','.w-catalog-compare .cross-box .different-all > div','width_measure','%','','','.w-catalog-compare'),(136680,'printshop-mobile','.w-checkout-billing-address .addresses .address-item','width_measure','%','','','.w-checkout-billing-address'),(136681,'printshop-mobile','.w-checkout-billing-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-billing-address'),(136682,'printshop-mobile','.w-checkout-create-account .col-2','width_measure','%','','','.w-checkout-create-account'),(136683,'printshop-mobile','.w-checkout-shipping-address .addresses .address-item','width_measure','%','','','.w-checkout-shipping-address'),(136684,'printshop-mobile','.w-checkout-shipping-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-shipping-address'),(136685,'printshop-mobile','.w-checkout-shipping-choice label','width_measure','%','','','.w-checkout-shipping-choice'),(136686,'printshop-mobile','.w-checkout-terms .required-message','width_measure','%','','','.w-checkout-terms'),(136687,'printshop-mobile','.w-communication-new-topic .middle-form select','width_measure','%','','','.w-communication-new-topic'),(136688,'printshop-mobile','.w-image-maps .svg-wrap svg','width_measure','%','','','.w-image-maps'),(136689,'printshop-mobile','.w-list-b2b .select-attributes','width_measure','%','','','.w-list-b2b'),(136690,'printshop-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(136691,'printshop-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(136692,'printshop-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(136693,'printshop-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(136694,'printshop-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(136695,'printshop-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(136696,'printshop-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(136697,'printshop-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(136698,'printshop-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(136699,'printshop-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(136700,'printshop-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(136701,'printshop-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(136702,'printshop-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(136703,'printshop-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(136704,'printshop-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(136705,'printshop-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(136706,'printshop-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(136707,'printshop-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(136708,'printshop-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(136709,'printshop-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(136710,'printshop-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(136711,'printshop-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(136712,'printshop-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(136713,'printshop-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(136714,'printshop-mobile','.w-promotions .prom-multi-discount .list','width_measure','%','','','.w-promotions'),(136715,'printshop-mobile','.w-promotions .promo-cart-discount > div','width_measure','%','','','.w-promotions'),(136716,'printshop-mobile','.w-promotions .promo-salemaker .item','width_measure','%','','','.w-promotions'),(136717,'printshop-mobile','.w-promotions .promo-salemaker > div','width_measure','%','','','.w-promotions'),(136718,'printshop-mobile','.w-promotions .nextdiscount .item-holder .name','width_measure','%','','','.w-promotions'),(136719,'printshop-mobile','.w-promotions .nextdiscount .item-holder .image','width_measure','%','','','.w-promotions'),(136720,'printshop-mobile','.w-sitemap-delivery-location > ul > li > ul > li','width_measure','%','','','.w-sitemap-delivery-location'),(136721,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(136722,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(136723,'printshop-mobile','.w-wedding-registry-widgets-products .products-listing .item','width_measure','%','','','.w-wedding-registry-widgets-products'),(136724,'printshop-mobile','.w-wedding-registry-widgets-products .products-listing .item','width_measure','%','','','.w-wedding-registry-widgets-products'),(136725,'printshop-mobile','.w-wedding-registry-widgets-products .products-listing .item','width_measure','%','','','.w-wedding-registry-widgets-products'),(136726,'printshop-mobile','.w-wedding-registry-widgets-share-url input','width_measure','%','','','.w-wedding-registry-widgets-share-url'),(136727,'printshop-mobile','.p-shopping-cart-index .order-summary .btn-2','width_measure','%','','','.p-shopping-cart-index'),(136728,'printshop-mobile','.w-menu .hided.menu > ul','z-index','100','','','.w-menu'),(136729,'printshop-mobile','.w-menu-horizontal > ul','z-index','21','','','.w-menu-horizontal'),(136730,'printshop-mobile','.w-menu-slider > ul > li > ul','z-index','100','','','.w-menu-slider'),(136731,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-horizontal'),(136732,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-horizontal'),(136733,'printshop-mobile','.w-menu-horizontal > ul > li > ul','z-index','22','','','.w-menu-horizontal'),(136734,'printshop-mobile','.w-menu-horizontal > ul > li > ul > li > ul','z-index','23','','','.w-menu-horizontal'),(136735,'printshop-mobile','.w-menu-big li','z-index','20','','','.w-menu-big'),(136736,'printshop-mobile','.w-menu-big > ul > li > ul','z-index','100','','','.w-menu-big'),(136737,'printshop-mobile','.w-menu-style-1 > ul > li > ul','z-index','22','','','.w-menu-style-1'),(136738,'printshop-mobile','.w-menu-style-1 > ul','z-index','21','','','.w-menu-style-1'),(136739,'printshop-mobile','.w-cart .cart-box-link','z-index','1','','','.w-cart'),(136740,'printshop-mobile','.w-cart .cart-box','z-index','100','','','.w-cart'),(136741,'printshop-mobile','.b-fancybox .fancybox-opened','z-index','8030','','','.b-fancybox'),(136742,'printshop-mobile','.w-quote .cart-box','z-index','100','','','.w-quote'),(136743,'printshop-mobile','.w-quote .cart-box-link','z-index','1','','','.w-quote'),(136744,'printshop-mobile','.b-info-popup .info-popup div','z-index','1000','','','.b-info-popup'),(136745,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > ul','z-index','23','','','.w-menu-style-1'),(136746,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-style-1'),(136747,'printshop-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-style-1'),(136748,'printshop-mobile','.w-account a.my-acc-link','z-index','1','','','.w-account'),(136749,'printshop-mobile','.b-fancybox .fancybox-close','z-index','8040','','','.b-fancybox'),(136750,'printshop-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','z-index','-1','','','.b-switch'),(136751,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','z-index','1','','','.b-switch'),(136752,'printshop-mobile','.b-switch .bootstrap-switch .bootstrap-switch-label','z-index','100','','','.b-switch'),(136753,'printshop-mobile','.b-switch .bootstrap-switch','z-index','0','','','.b-switch'),(136754,'printshop-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','z-index','1','','','.b-slick'),(136755,'printshop-mobile','.w-languages .select','z-index','100','','','.w-languages'),(136756,'printshop-mobile','.w-search .suggest','z-index','500','','','.w-search'),(136757,'printshop-mobile','.w-banner .banner img + img','z-index','-1','','','.w-banner'),(136758,'printshop-mobile','.w-currencies .select','z-index','10','','','.w-currencies'),(136759,'printshop-mobile','.b-fancybox .fancybox-title','z-index','8050','','','.b-fancybox'),(136760,'printshop-mobile','.p-checkout-success .page-success','z-index','-1','','','.p-checkout-success'),(136761,'printshop-mobile','.b-fancybox .fancybox-title-float-wrap','z-index','8050','','','.b-fancybox'),(136762,'printshop-mobile','.b-fancybox .fancybox-wrap','z-index','8020','','','.b-fancybox'),(136763,'printshop-mobile','.p-checkout-success .page-success > div','z-index','1','','','.p-checkout-success'),(136764,'printshop-mobile','.b-fancybox .fancybox-overlay','z-index','8010','','','.b-fancybox'),(136765,'printshop-mobile','.b-fancybox #fancybox-loading','z-index','8060','','','.b-fancybox'),(136766,'printshop-mobile','.b-fancybox .fancybox-nav span','z-index','8040','','','.b-fancybox'),(136767,'printshop-mobile','.b-fancybox .fancybox-nav','z-index','8040','','','.b-fancybox'),(136768,'printshop-mobile','.b-form .form-inputs div.required-message','z-index','1','','','.b-form'),(136769,'printshop-mobile','.b-form .hide-billing-address','z-index','70','','','.b-form'),(136770,'printshop-mobile','.b-fancybox .filter-listing-preloader','z-index','100001','','','.b-fancybox'),(136771,'printshop-mobile','.b-fancybox .filter-listing-loader','z-index','100000','','','.b-fancybox'),(136772,'printshop-mobile','.b-bottom .pop-up-close','z-index','1','','','.b-bottom'),(136773,'printshop-mobile','.b-form .same-address','z-index','80','','','.b-form'),(136774,'printshop-mobile','.b-products-listing .promos-info','z-index','1','','','.b-products-listing'),(136775,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(136776,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(136777,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(136778,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(136779,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(136780,'printshop-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(136781,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(136782,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(136783,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(136784,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(136785,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(136786,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(136787,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(136788,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(136789,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(136790,'printshop-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(136791,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(136792,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(136793,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(136794,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(136795,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(136796,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(136797,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(136798,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(136799,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(136800,'printshop-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(136801,'printshop-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','z-index','1000','','','.b-menu-open_from-left'),(136802,'printshop-mobile','.b-messages .messMenuButton span','z-index','1','','','.b-messages'),(136803,'printshop-mobile','.b-preloader .preloader','z-index','10','','','.b-preloader'),(136804,'printshop-mobile','.b-select-suggest .select2-search','z-index','10000','','','.b-select-suggest'),(136805,'printshop-mobile','.b-select-suggest .select2-drop-mask','z-index','9998','','','.b-select-suggest'),(136806,'printshop-mobile','.b-select-suggest .select2-drop','z-index','9999','','','.b-select-suggest'),(136807,'printshop-mobile','.batchPr .batchSelect','z-index','1','','','.batchPr'),(136808,'printshop-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(136809,'printshop-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(136810,'printshop-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(136811,'printshop-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(136812,'printshop-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(136813,'printshop-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(136814,'printshop-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(136815,'printshop-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(136816,'printshop-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(136817,'printshop-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(136818,'printshop-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(136819,'printshop-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(136820,'printshop-mobile','.p-sample-checkout-success .page-success > div','z-index','1','','','.p-sample-checkout-success'),(136821,'printshop-mobile','.p-sample-checkout-success .page-success','z-index','-1','','','.p-sample-checkout-success'),(136822,'printshop-mobile','.w-catalog-b2b-add-button ','z-index','1','','','.w-catalog-b2b-add-button'),(136823,'printshop-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','z-index','1000','','','.w-image-maps'),(136824,'printshop-mobile','.w-promotions .promo-cart-discount .slave .condition','z-index','1','','','.w-promotions'),(136825,'printshop-mobile','.w-promotions .prom-multi-discount .promo-range','z-index','1','','','.w-promotions'),(136826,'printshop-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','z-index','10','','','.w-upload-customer-id-upload-customer-id-form'),(162565,'deals-mobile','.b-slick .slick-slider','-khtml-user-select','none','','','.b-slick'),(162566,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','-moz-border-radius','15px','','','.b-fancybox'),(162567,'deals-mobile','.b-fancybox .fancybox-skin','-moz-border-radius','4px','','','.b-fancybox'),(162568,'deals-mobile','.b-fancybox .fancybox-opened .fancybox-skin','-moz-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(162569,'deals-mobile','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-moz-box-sizing','border-box','','','.b-select-suggest'),(162570,'deals-mobile','.b-rating #stars-default .glyphicon','-moz-osx-font-smoothing','grayscale','','','.b-rating'),(162571,'deals-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-moz-transform','translate3d(0, 0, 0)','','','.b-slick'),(162572,'deals-mobile','.b-products-listing .hover-box-content','-moz-transform','rotate( 45deg )','3','','.b-products-listing'),(162573,'deals-mobile','.b-slick .slick-slider','-moz-user-select','none','','','.b-slick'),(162574,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','-moz-user-select','none','','','.b-select-suggest'),(162575,'deals-mobile','.b-select-suggest .select2-container .select2-choice','-moz-user-select','none','','','.b-select-suggest'),(162576,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-moz-user-select','none','','','.b-select-suggest'),(162577,'deals-mobile','.b-slick .slick-slider','-ms-touch-action','pan-y','','','.b-slick'),(162578,'deals-mobile','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(162579,'deals-mobile','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(162580,'deals-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-ms-transform','translate3d(0, 0, 0)','','','.b-slick'),(162581,'deals-mobile','.b-products-listing .hover-box-content','-ms-transform','rotate( 45deg )','3','','.b-products-listing'),(162582,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(162583,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(162584,'deals-mobile','.b-slick .slick-slider','-ms-user-select','none','','','.b-slick'),(162585,'deals-mobile','.b-select-suggest .select2-container .select2-choice','-ms-user-select','none','','','.b-select-suggest'),(162586,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','-ms-user-select','none','','','.b-select-suggest'),(162587,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-ms-user-select','none','','','.b-select-suggest'),(162588,'deals-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-o-transform','translate3d(0, 0, 0)','','','.b-slick'),(162589,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','-webkit-border-radius','15px','','','.b-fancybox'),(162590,'deals-mobile','.b-fancybox .fancybox-skin','-webkit-border-radius','4px','','','.b-fancybox'),(162591,'deals-mobile','.b-fancybox .fancybox-opened .fancybox-skin','-webkit-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(162592,'deals-mobile','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-webkit-box-sizing','border-box','','','.b-select-suggest'),(162593,'deals-mobile','.b-rating #stars-default .glyphicon','-webkit-font-smoothing','antialiased','','','.b-rating'),(162594,'deals-mobile','.b-fancybox .fancybox-type-iframe .fancybox-inner','-webkit-overflow-scrolling','touch','','','.b-fancybox'),(162595,'deals-mobile','.b-fancybox .fancybox-nav','-webkit-tap-highlight-color','rgba(0,0,0,0)','','','.b-fancybox'),(162596,'deals-mobile','.b-slick .slick-slider','-webkit-tap-highlight-color','transparent','','','.b-slick'),(162597,'deals-mobile','.b-select-suggest .select2-results','-webkit-tap-highlight-color','rgba(0, 0, 0, 0)','','','.b-select-suggest'),(162598,'deals-mobile','.b-slick .slick-slider','-webkit-touch-callout','none','','','.b-slick'),(162599,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(162600,'deals-mobile','.b-select-suggest .select2-container .select2-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(162601,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','-webkit-touch-callout','none','','','.b-select-suggest'),(162602,'deals-mobile','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(162603,'deals-mobile','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(162604,'deals-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-webkit-transform','translate3d(0, 0, 0)','','','.b-slick'),(162605,'deals-mobile','.b-products-listing .hover-box-content','-webkit-transform','rotate( 45deg )','3','','.b-products-listing'),(162606,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(162607,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(162608,'deals-mobile','.b-slick .slick-slider','-webkit-user-select','none','','','.b-slick'),(162609,'deals-mobile','.b-select-suggest .select2-container .select2-choice','-webkit-user-select','none','','','.b-select-suggest'),(162610,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','-webkit-user-select','none','','','.b-select-suggest'),(162611,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-user-select','none','','','.b-select-suggest'),(162612,'deals-mobile','.p-wedding-registry-search .search-form','align-items','center','','','.p-wedding-registry-search'),(162613,'deals-mobile','.w-banner .carousel .middle-center','align-items','center','','','.w-banner'),(162614,'deals-mobile','.w-banner .carousel .bottom-right','align-items','flex-end','','','.w-banner'),(162615,'deals-mobile','.w-banner .carousel .middle-right','align-items','center','','','.w-banner'),(162616,'deals-mobile','.w-banner .carousel .top-right','align-items','flex-start','','','.w-banner'),(162617,'deals-mobile','.w-banner .carousel .top-center','align-items','flex-start','','','.w-banner'),(162618,'deals-mobile','.w-banner .carousel .middle-left','align-items','center','','','.w-banner'),(162619,'deals-mobile','.w-banner .carousel .bottom-center','align-items','flex-end','','','.w-banner'),(162620,'deals-mobile','.w-banner .carousel .bottom-left','align-items','flex-end','','','.w-banner'),(162621,'deals-mobile','.w-banner .carousel .top-left','align-items','flex-start','','','.w-banner'),(162622,'deals-mobile','.b-products-listing .products-listing .attribute-qty-block','align-items','center','','','.b-products-listing'),(162623,'deals-mobile','.b-products-listing .promos-info .promo-item','align-items','center','','','.b-products-listing'),(162624,'deals-mobile','.b-products-listing .select-attributes','align-items','center','','','.b-products-listing'),(162625,'deals-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(162626,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','align-items','center','','','.b-menu-style-1'),(162627,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .languages','align-items','center','','','.b-menu-style-2'),(162628,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','align-items','center','','','.b-menu-style-2'),(162629,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies','align-items','center','','','.b-menu-style-2'),(162630,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','align-items','center','','','.b-menu-style-2'),(162631,'deals-mobile','.b-messages .email-line','align-items','center','','','.b-messages'),(162632,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(162633,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(162634,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(162635,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(162636,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(162637,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(162638,'deals-mobile','.p-quick-order-index .quick-order-total','align-items','center','','','.p-quick-order-index'),(162639,'deals-mobile','.w-account-customer-additional-field .field-type-text','align-items','center','','','.w-account-customer-additional-field'),(162640,'deals-mobile','.w-account-subscription .subscription-variant','align-items','center','','','.w-account-subscription'),(162641,'deals-mobile','.w-catalog-compare .cross-box .different-all','align-items','flex-end','','','.w-catalog-compare'),(162642,'deals-mobile','.w-communication-new-topic #communication_group_holder + .columns','align-items','flex-end','','','.w-communication-new-topic'),(162643,'deals-mobile','.w-personal-gift-status-bar .timeline','align-items','center','','','.w-personal-gift-status-bar'),(162644,'deals-mobile','.w-promotions .promo-cart-discount','align-items','flex-start','','','.w-promotions'),(162645,'deals-mobile','.w-taxable form','align-items','center','','','.w-taxable'),(162646,'deals-mobile','.b-products-listing .btn-preloader','animation','load8 1.5s infinite linear','3','','.b-products-listing'),(162647,'deals-mobile','.b-products-listing .loader','animation','load8 1.5s infinite linear','4','','.b-products-listing'),(162648,'deals-mobile','.b-preloader .preloader','animation','load8 1.5s infinite linear','3','','.b-preloader'),(162649,'deals-mobile','.w-product-customers-activity .customers-activity','animation','customers-activity-show 4s ease-in-out','','','.w-product-customers-activity'),(162650,'deals-mobile','.w-product-customers-activity .customers-activity.closed','animation','customers-activity-hide 2s ease-in-out','','','.w-product-customers-activity'),(162651,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(162652,'deals-mobile','.w-filters .ui-slider-range','background','none','','','.w-filters'),(162653,'deals-mobile','.w-filters .ui-slider','background','none','','','.w-filters'),(162654,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','background','transparent','','','.b-fancybox'),(162655,'deals-mobile','.w-top-categories .categories h2','background','none','','','.w-top-categories'),(162656,'deals-mobile','.w-categories .categories h2','background','none','','','.w-categories'),(162657,'deals-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','background','none','','','.b-products-listing'),(162658,'deals-mobile','.b-products-listing .products-listing h2','background','none','','','.b-products-listing'),(162659,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.b-data-table'),(162660,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.b-data-table'),(162661,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','background','none','','','.b-menu-style-2'),(162662,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','background','none','','','.b-menu-style-2'),(162663,'deals-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','background','transparent','','','.b-select-suggest'),(162664,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','background','none','','','.b-select-suggest'),(162665,'deals-mobile','.b-select-suggest .select2-results .select2-highlighted em','background','transparent','','','.b-select-suggest'),(162666,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background','transparent','','','.b-select-suggest'),(162667,'deals-mobile','.batchPr .checkbox input + span','background','none','','','.batchPr'),(162668,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.p-quick-order-index'),(162669,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.p-quick-order-index'),(162670,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','background','none','','','.w-catalog-compare'),(162671,'deals-mobile','.b-select-suggest .select2-container .select2-choice','background-clip','padding-box','','','.b-select-suggest'),(162672,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','background-clip','padding-box','','','.b-select-suggest'),(162673,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','background-clip','padding-box','','','.b-select-suggest'),(162674,'deals-mobile','.w-menu .hided.menu','background-color','inherit','','','.w-menu'),(162675,'deals-mobile','.w-menu .menu .menu-ico','background-color','inherit','','','.w-menu'),(162676,'deals-mobile','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','background-color','#ee4225','','','.b-cookie-notice'),(162677,'deals-mobile','.w-sale .left-count-days','background-color','#fff','','','.w-sale'),(162678,'deals-mobile','.w-menu-horizontal > ul > li > ul > li > ul','background-color','#ffffff','','','.w-menu-horizontal'),(162679,'deals-mobile','.w-menu-slider .menu-ico','background-color','#183d78','','','.w-menu-slider'),(162680,'deals-mobile','.w-menu-horizontal > ul > li > ul','background-color','#ffffff','','','.w-menu-horizontal'),(162681,'deals-mobile','.w-menu-slider > ul > li.active > ul','background-color','#183d78','','','.w-menu-slider'),(162682,'deals-mobile','.w-menu-style-1 .menu-ico','background-color','#183d78','','','.w-menu-style-1'),(162683,'deals-mobile','.w-sale .badge','background-color','#183d78','','','.w-sale'),(162684,'deals-mobile','.w-menu-style-1 > ul > li > ul','background-color','#183d78','','','.w-menu-style-1'),(162685,'deals-mobile','.w-menu-style-1 > ul','background-color','#183d78','','','.w-menu-style-1'),(162686,'deals-mobile','.w-menu-style-1 > ul > li','background-color','#0a204a','1','','.w-menu-style-1'),(162687,'deals-mobile','.w-menu-style-1 > ul > li > ul > li','background-color','#0a204a','1','','.w-menu-style-1'),(162688,'deals-mobile','.w-menu-style-1 > ul > li > ul > li ul','background-color','#183d78','','','.w-menu-style-1'),(162689,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > ul li','background-color','#0a204a','1','','.w-menu-style-1'),(162690,'deals-mobile','.w-product-sale-ends .left-count','background-color','#183d78','','','.w-product-sale-ends'),(162691,'deals-mobile','.w-product-sale-ends .left-count-hours','background-color','#fff','','','.w-product-sale-ends'),(162692,'deals-mobile','.p-account-history .order_history_table th','background-color','#eee','','','.p-account-history'),(162693,'deals-mobile','.w-product-sale-ends .left-count-days','background-color','#fff','','','.w-product-sale-ends'),(162694,'deals-mobile','.p-account-trade-form .trade-form-area','background-color','#eee','','','.p-account-trade-form'),(162695,'deals-mobile','.w-quote .cart-box','background-color','#ffffff','','','.w-quote'),(162696,'deals-mobile','.w-product-reviews .reviews-list .review','background-color','#ffffff','','','.w-product-reviews'),(162697,'deals-mobile','.w-quote .cart-box-link','background-color','#183d78','','','.w-quote'),(162698,'deals-mobile','.b-compare .popupCompare .pop-up-content','background-color','#e0e0e0','','','.b-compare'),(162699,'deals-mobile','.w-menu-slider > ul','background-color','#183d78','','','.w-menu-slider'),(162700,'deals-mobile','.w-menu-slider > ul > li > ul','background-color','#183d78','','','.w-menu-slider'),(162701,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','background-color','#00c853','3','','.b-multi-page-checkout'),(162702,'deals-mobile','.b-info-popup .info-popup div','background-color','#fff','','','.b-info-popup'),(162703,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','background-color','#092964','','','.b-multi-page-checkout'),(162704,'deals-mobile','.testimonials .review','background-color','#eeeeee','','',''),(162705,'deals-mobile','.p-wedding-registry-manage .wr-search button','background-color','transparent','','','.p-wedding-registry-manage'),(162706,'deals-mobile','.b-pagination .pagination span','background-color','#183d78','2','','.b-pagination'),(162707,'deals-mobile','.p-account-history .orders-table th','background-color','#eeeeee','','','.p-account-history'),(162708,'deals-mobile','.w-filters .head-filter-widget','background-color','#183d78','890','','.w-filters'),(162709,'deals-mobile','.w-list-type-2_2 .compare-box-item','background-color','#eeeeee','','','.w-list-type-2_2'),(162710,'deals-mobile','.w-list-type-2_2 .button-wishlist button','background-color','#ffffff','','','.w-list-type-2_2'),(162711,'deals-mobile','.w-chat .w-chat-box','background-color','#183d78','','','.w-chat'),(162712,'deals-mobile','.p-wedding-registry-index .middle-box','background-color','#fff','','','.p-wedding-registry-index'),(162713,'deals-mobile','.b-table .table .headings td','background-color','#eeeeee','','','.b-table'),(162714,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','background-color','#183d78','','','.b-switch'),(162715,'deals-mobile','.b-bottom .popup-heading','background-color','#f9f9f9','','','.b-bottom'),(162716,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label','background-color','#fff','3','','.b-switch'),(162717,'deals-mobile','.b-compare .compare-box-item','background-color','#e0e0e0','','','.b-compare'),(162718,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label','background-color','#fff','3','','.b-switch'),(162719,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','background-color','#9aa4b3','','','.b-switch'),(162720,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','background-color','rgba(0, 0, 0, 0.8)','','','.b-fancybox'),(162721,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','background-color','#fff','','','.b-slick'),(162722,'deals-mobile','.w-reviews .review','background-color','#ffffff','','','.w-reviews'),(162723,'deals-mobile','.w-search .suggest','background-color','#eee','','','.w-search'),(162724,'deals-mobile','.btn-1','background-color','#ee4225','','',''),(162725,'deals-mobile','body','background-color','#ffffff','','',''),(162726,'deals-mobile','.w-currencies .select','background-color','#ffffff','','','.w-currencies'),(162727,'deals-mobile','.b-bottom .popup-box.popupCompare','background-color','#e0e0e0','','','.b-bottom'),(162728,'deals-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','background-color','#fff','','','.w-compare-box-item'),(162729,'deals-mobile','.w-compare-box-item .checkbox:checked + span:before','background-color','#04a440','','','.w-compare-box-item'),(162730,'deals-mobile','.p-account-subscription-historyinfo .order_history_table th','background-color','#eee','','','.p-account-subscription-historyinfo'),(162731,'deals-mobile','.b-info-popup .info-popup div','background-color','#fff','3','','.b-info-popup'),(162732,'deals-mobile','.w-menu-mobile .menu-ico','background-color','#183d78','','','.w-menu-mobile'),(162733,'deals-mobile','.p-account-index th','background-color','#eeeeee','','','.p-account-index'),(162734,'deals-mobile','.w-search .search form','background-color','#ccc','','','.w-search'),(162735,'deals-mobile','.b-compare .popupCompare table','background-color','#fff','','','.b-compare'),(162736,'deals-mobile','.b-fancybox .fancybox-skin','background-color','#f9f9f9','','','.b-fancybox'),(162737,'deals-mobile','.b-fancybox .fancybox-overlay','background-color','rgba(0, 0, 0, 0.7)','','','.b-fancybox'),(162738,'deals-mobile','.p-reviews-info .review-info-content','background-color','#eeeeee','','','.p-reviews-info'),(162739,'deals-mobile','.p-reviews-info .review-info-image','background-color','#fff','','','.p-reviews-info'),(162740,'deals-mobile','.w-sale .left-count','background-color','#183d78','','','.w-sale'),(162741,'deals-mobile','.w-sale .left-count-hours','background-color','#fff','','','.w-sale'),(162742,'deals-mobile','.w-cart .cart-content','background-color','#ffffff','','','.w-cart'),(162743,'deals-mobile','.b-fancybox .fancybox-nav span','background-color','rgba(0, 0, 0, 0.7)','','','.b-fancybox'),(162744,'deals-mobile','.b-form .hide-billing-address','background-color','#fff','','','.b-form'),(162745,'deals-mobile','.p-account-index .topAccount','background-color','#eee','','','.p-account-index'),(162746,'deals-mobile','.p-account-index .orders-table th','background-color','#eeeeee','','','.p-account-index'),(162747,'deals-mobile','.b-fancybox .filter-listing-loader','background-color','rgba(255, 255, 255, 0.7)','','','.b-fancybox'),(162748,'deals-mobile','.b-compare .vary td','background-color','#f3f5a1','','','.b-compare'),(162749,'deals-mobile','.b-datepicker .datepicker-dropdown','background-color','#fff','','','.b-datepicker'),(162750,'deals-mobile','.w-list-type-2 .button-wishlist button','background-color','#ffffff','','','.w-list-type-2'),(162751,'deals-mobile','.w-list-type-2 .compare-box-item','background-color','#eeeeee','','','.w-list-type-2'),(162752,'deals-mobile','.btn-2','background-color','#ee4225','','',''),(162753,'deals-mobile','.btn','background-color','#ffffff','','',''),(162754,'deals-mobile','.w-list-type-1_3 .compare-box-item','background-color','#eeeeee','','','.w-list-type-1_3'),(162755,'deals-mobile','.w-list-type-1_3 .button-wishlist button','background-color','#ffffff','','','.w-list-type-1_3'),(162756,'deals-mobile','.b-bottom .around-pop-up','background-color','#212121','','','.b-bottom'),(162757,'deals-mobile','.w-list-type-1_2 .compare-box-item','background-color','#eeeeee','','','.w-list-type-1_2'),(162758,'deals-mobile','.w-list-type-1_2 .button-wishlist button','background-color','#ffffff','','','.w-list-type-1_2'),(162759,'deals-mobile','.b-bottom .pop-up-content','background-color','#fff','','','.b-bottom'),(162760,'deals-mobile','.p-reviews-info .review-info-text','background-color','#fff','','','.p-reviews-info'),(162761,'deals-mobile','.b-bottom .popup-box','background-color','#fff','','','.b-bottom'),(162762,'deals-mobile','.w-list-type-1 .compare-box-item','background-color','#eeeeee','','','.w-list-type-1'),(162763,'deals-mobile','.w-filters .ui-slider','background-color','#757575','','','.w-filters'),(162764,'deals-mobile','.w-filters .ui-slider-range','background-color','#15286f','','','.w-filters'),(162765,'deals-mobile','.w-list-type-1 .button-wishlist button','background-color','#ffffff','','','.w-list-type-1'),(162766,'deals-mobile','.w-languages .select','background-color','#ffffff','','','.w-languages'),(162767,'deals-mobile','.w-reviews .reviews','background-color','#eeeeee','','','.w-reviews'),(162768,'deals-mobile','.w-search .button-search','background-color','transparent','','','.w-search'),(162769,'deals-mobile','.b-form .required-message','background-color','#eee','','','.b-form'),(162770,'deals-mobile','.b-products-listing .loader','background-color','rgba(255, 255, 255, 0.7)','3','','.b-products-listing'),(162771,'deals-mobile','.b-products-listing .products-listing .qty-input.hidden','background-color','#ffffff','3','','.b-products-listing'),(162772,'deals-mobile','.b-products-listing .promos-info .promo-name','background-color','rgba(200, 200, 200, 0.7)','','','.b-products-listing'),(162773,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','#eeeeee','','','.b-data-table'),(162774,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.b-data-table'),(162775,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','#ffffff','','','.b-dropdown'),(162776,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','#ffffff','','','.b-dropdown'),(162777,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','#ffffff','','','.b-dropdown'),(162778,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','#ffffff','','','.b-dropdown'),(162779,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','#ffffff','','','.b-dropdown'),(162780,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','#ffffff','','','.b-dropdown'),(162781,'deals-mobile','.b-email .heading-products','background-color','#eeeeee','','','.b-email'),(162782,'deals-mobile','.b-email .heading-products','background-color','#eeeeee','','','.b-email'),(162783,'deals-mobile','.b-email .heading-products','background-color','#eeeeee','','','.b-email'),(162784,'deals-mobile','.b-email .heading-products','background-color','#eeeeee','','','.b-email'),(162785,'deals-mobile','.b-email .heading-products','background-color','#eeeeee','','','.b-email'),(162786,'deals-mobile','.b-email .heading-products','background-color','#eeeeee','','','.b-email'),(162787,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','background-color','#ddd','','','.b-menu-style-1'),(162788,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li:hover > a','background-color','#ddd','','','.b-menu-style-1'),(162789,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2','background-color','#eeeeee','','','.b-menu-style-1'),(162790,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .menu-content','background-color','#183d78','','','.b-menu-style-2'),(162791,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] ul','background-color','#183d78','','','.b-menu-style-3'),(162792,'deals-mobile','.b-messages .msv_to_cc','background-color','#eeeeee','','','.b-messages'),(162793,'deals-mobile','.b-messages .msv_history','background-color','#eeeeee','','','.b-messages'),(162794,'deals-mobile','.b-messages .email-heading','background-color','#eeeeee','','','.b-messages'),(162795,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','background-color','#eeeeee','','','.b-messages'),(162796,'deals-mobile','.b-preloader .preloader','background-color','rgba(255, 255, 255, 0.7)','','','.b-preloader'),(162797,'deals-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','background-color','#eeeeee','','','.b-select-suggest'),(162798,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-color','#eeeeee','','','.b-select-suggest'),(162799,'deals-mobile','.b-select-suggest .select2-search input','background-color','#ffffff','','','.b-select-suggest'),(162800,'deals-mobile','.b-select-suggest .select2-search input.select2-active','background-color','#ffffff','','','.b-select-suggest'),(162801,'deals-mobile','.b-select-suggest .select2-drop','background-color','#ffffff','','','.b-select-suggest'),(162802,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-color','#eeeeee','','','.b-select-suggest'),(162803,'deals-mobile','.b-select-suggest .select2-drop-mask','background-color','#ffffff','','','.b-select-suggest'),(162804,'deals-mobile','.b-select-suggest .select2-results .select2-disabled','background-color','#eeeeee','','','.b-select-suggest'),(162805,'deals-mobile','.b-select-suggest .select2-results .select2-highlighted','background-color','#eeeeee','','','.b-select-suggest'),(162806,'deals-mobile','.b-select-suggest .select2-results li em','background-color','#feffde','','','.b-select-suggest'),(162807,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-color','#eeeeee','','','.b-select-suggest'),(162808,'deals-mobile','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','background-color','#eeeeee','','','.b-select-suggest'),(162809,'deals-mobile','.b-select-suggest .select2-more-results.select2-active','background-color','#eeeeee','','','.b-select-suggest'),(162810,'deals-mobile','.b-select-suggest .select2-more-results','background-color','#eeeeee','','','.b-select-suggest'),(162811,'deals-mobile','.b-select-suggest .select2-results .select2-highlighted ul','background-color','#ffffff','','','.b-select-suggest'),(162812,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','background-color','#ffffff','','','.b-select-suggest'),(162813,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-color','#eeeeee','','','.b-select-suggest'),(162814,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color','#ffffff','','','.b-select-suggest'),(162815,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus','background-color','#eeeeee','','','.b-select-suggest'),(162816,'deals-mobile','.b-trade-approval .steps-bar','background-color','#eeeeee','','','.b-trade-approval'),(162817,'deals-mobile','.b-trade-approval .steps-bar li.current a','background-color','#183d78','','','.b-trade-approval'),(162818,'deals-mobile','.batchPr .checkbox input:checked + span','background-color','#1428a0','','','.batchPr'),(162819,'deals-mobile','.batchPr .checkbox input + span','background-color','#ffffff','','','.batchPr'),(162820,'deals-mobile','.batchPr .btn-batch-remove','background-color','red','','','.batchPr'),(162821,'deals-mobile','.p-account-samples-history .order_history_table th','background-color','#eeeeee','','','.p-account-samples-history'),(162822,'deals-mobile','.p-account-samples-history .order_history_table th','background-color','#eeeeee','','','.p-account-samples-history'),(162823,'deals-mobile','.p-account-samples-history .order_history_table th','background-color','#eeeeee','','','.p-account-samples-history'),(162824,'deals-mobile','.p-account-samples-history .order_history_table th','background-color','#eeeeee','','','.p-account-samples-history'),(162825,'deals-mobile','.p-account-samples-history .orders-table th','background-color','#eeeeee','','','.p-account-samples-history'),(162826,'deals-mobile','.p-account-samples-history .orders-table th','background-color','#eeeeee','','','.p-account-samples-history'),(162827,'deals-mobile','.p-account-samples-history .orders-table th','background-color','#eeeeee','','','.p-account-samples-history'),(162828,'deals-mobile','.p-account-samples-history .orders-table th','background-color','#eeeeee','','','.p-account-samples-history'),(162829,'deals-mobile','.p-account-samples-history .orders-table th','background-color','#eeeeee','','','.p-account-samples-history'),(162830,'deals-mobile','.p-account-samples-history .order_history_table th','background-color','#eeeeee','','','.p-account-samples-history'),(162831,'deals-mobile','.p-account-samples-history .orders-table th','background-color','#eeeeee','','','.p-account-samples-history'),(162832,'deals-mobile','.p-account-samples-history .order_history_table th','background-color','#eeeeee','','','.p-account-samples-history'),(162833,'deals-mobile','.p-catalog-product .prev-next-product','background-color','rgba(255, 255, 255, 0.7)','','','.p-catalog-product'),(162834,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.p-quick-order-index'),(162835,'deals-mobile','.p-quick-order-index .all-scroll-div','background-color','#183d78','','','.p-quick-order-index'),(162836,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','#eeeeee','','','.p-quick-order-index'),(162837,'deals-mobile','.w-account-personal-catalog .list-switcher a','background-color','#ffffff','2','','.w-account-personal-catalog'),(162838,'deals-mobile','.w-blog-widget-post-listing .post_content','background-color','#ffffff','','','.w-blog-widget-post-listing'),(162839,'deals-mobile','.w-blog-widget-post-listing .post_image','background-color','#ffffff','','','.w-blog-widget-post-listing'),(162840,'deals-mobile','.w-blog-widget-post-share ','background-color','#EDE5D5','4','','.w-blog-widget-post-share'),(162841,'deals-mobile','.w-blog-widget-related-posts .post_content a','background-color','#ffffff','','','.w-blog-widget-related-posts'),(162842,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','background-color','#E3D6BB','','','.w-blog-widget-related-posts'),(162843,'deals-mobile','.w-blog-widget-related-posts-by-category .post_img','background-color','#ffffff','','','.w-blog-widget-related-posts-by-category'),(162844,'deals-mobile','.w-blog-widget-related-posts-by-category .post_content','background-color','#ffffff','','','.w-blog-widget-related-posts-by-category'),(162845,'deals-mobile','.w-blog-widget-tag-cloud a','background-color','#eeeeee','','','.w-blog-widget-tag-cloud'),(162846,'deals-mobile','.w-cart-compare .price-cell','background-color','#fefdd6','','','.w-cart-compare'),(162847,'deals-mobile','.w-cart-compare .attributes-cell','background-color','#fefdd6','','','.w-cart-compare'),(162848,'deals-mobile','.w-cart-compare .price-block + .attributes-block .attributes-cell','background-color','#ffffff','','','.w-cart-compare'),(162849,'deals-mobile','.w-catalog-b2b-add-button ','background-color','#183d78','','','.w-catalog-b2b-add-button'),(162850,'deals-mobile','.w-catalog-compare tr','background-color','#eeeeee','1','','.w-catalog-compare'),(162851,'deals-mobile','.w-catalog-compare .compare .checkbox input:checked + span','background-color','#ffffff','','','.w-catalog-compare'),(162852,'deals-mobile','.w-catalog-compare .compare-fix-bar','background-color','#ffffff','','','.w-catalog-compare'),(162853,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','background-color','#ffffff','2','','.w-catalog-compare'),(162854,'deals-mobile','.w-catalog-paging ','background-color','#183d78','2','','.w-catalog-paging'),(162855,'deals-mobile','.w-checkout-billing-address .same-address','background-color','#eeeeee','','','.w-checkout-billing-address'),(162856,'deals-mobile','.w-checkout-shipping-choice input:checked + span','background-color','#183d78','','','.w-checkout-shipping-choice'),(162857,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','background-color','#183d78','','','.w-checkout-shipping-choice'),(162858,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','background-color','#F0F0F0','','','.w-communication-new-topic'),(162859,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','background-color','#F0F0F0','','','.w-communication-new-topic'),(162860,'deals-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','background-color','#ffffff','','','.w-delivery-day'),(162861,'deals-mobile','.w-delivery-day .left-count','background-color','#183d78','','','.w-delivery-day'),(162862,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','background-color','#ffffff','','','.w-image-maps'),(162863,'deals-mobile','.w-personal-gift-status-bar .progress-bar','background-color','#ffffff','','','.w-personal-gift-status-bar'),(162864,'deals-mobile','.w-personal-gift-status-bar .timeline','background-color','#c9d5f6','','','.w-personal-gift-status-bar'),(162865,'deals-mobile','.w-personal-gift-status-bar .progress-bar-content','background-color','#183d78','','','.w-personal-gift-status-bar'),(162866,'deals-mobile','.w-product-customers-activity .customers-activity','background-color','#eeeeee','','','.w-product-customers-activity'),(162867,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','background-color','#ffffff','','','.w-promotions'),(162868,'deals-mobile','.w-promotions .promo-cart-discount .master .item','background-color','#ffffff','','','.w-promotions'),(162869,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','background-color','#ffffff','','','.w-promotions'),(162870,'deals-mobile','.w-promotions .promo-cart-discount .slave .item','background-color','#ffffff','','','.w-promotions'),(162871,'deals-mobile','.w-promotions .promo-salemaker .item','background-color','#ffffff','','','.w-promotions'),(162872,'deals-mobile','.w-promotions .promo-item','background-color','#eeeeee','','','.w-promotions'),(162873,'deals-mobile','.w-promotions .promo-salemaker .discount','background-color','#ffffff','','','.w-promotions'),(162874,'deals-mobile','.w-promotions .nextdiscount .content > div','background-color','#ffffff','','','.w-promotions'),(162875,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','background-color','#ffffff','','','.w-promotions'),(162876,'deals-mobile','.w-promotions .nextdiscount .promo-for-each','background-color','#eeeeee','','','.w-promotions'),(162877,'deals-mobile','.w-promotions .prom-multi-discount .promo-product','background-color','#ffffff','','','.w-promotions'),(162878,'deals-mobile','.w-reviews-content .author','background-color','#eeeeee','','','.w-reviews-content'),(162879,'deals-mobile','.w-reviews-content .review','background-color','#eeeeee','','','.w-reviews-content'),(162880,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','background-color','#eee','','','.w-upload-customer-id-upload-customer-id-form'),(162881,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','background-color','#fff','','','.w-upload-customer-id-upload-customer-id-form'),(162882,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-color','#ffffff','','','.w-wedding-registry-widgets-photos'),(162883,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.b-data-table'),(162884,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color_important','important','','','.b-select-suggest'),(162885,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.p-quick-order-index'),(162886,'deals-mobile','.p-account-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-history-info'),(162887,'deals-mobile','.p-account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-order-pay'),(162888,'deals-mobile','.p-wedding-registry-share .wedding-image','background-image','url(themes/theme-1/img/wedding-registry-page.jpg)','','','.p-wedding-registry-share'),(162889,'deals-mobile','.p-account-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-history'),(162890,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-image','none','','','.b-select-suggest'),(162891,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(162892,'deals-mobile','.b-select-suggest .select2-more-results.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(162893,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-image','none','','','.b-select-suggest'),(162894,'deals-mobile','.b-select-suggest .select2-search input','background-image','url(\'\')','','','.b-select-suggest'),(162895,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-image','url(\'\')','','','.b-select-suggest'),(162896,'deals-mobile','.b-select-suggest .select2-results li','background-image','none','','','.b-select-suggest'),(162897,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-image','none','','','.b-select-suggest'),(162898,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-image','none','','','.b-select-suggest'),(162899,'deals-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-image','url(\'\')','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(162900,'deals-mobile','.b-select-suggest .select2-search-choice-close','background-image','url(\'\')','','','.b-select-suggest'),(162901,'deals-mobile','.b-select-suggest .select2-search input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(162902,'deals-mobile','.p-account-samples-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-samples-history'),(162903,'deals-mobile','.p-account-samples-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-samples-history'),(162904,'deals-mobile','.p-account-samples-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-samples-history'),(162905,'deals-mobile','.p-account-samples-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-samples-history'),(162906,'deals-mobile','.p-account-samples-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-samples-history'),(162907,'deals-mobile','.p-account-samples-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.p-account-samples-history'),(162908,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-samples-history-info'),(162909,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-samples-history-info'),(162910,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-samples-history-info'),(162911,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-samples-history-info'),(162912,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-samples-history-info'),(162913,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.p-account-samples-history-info'),(162914,'deals-mobile','.w-categories .image','background-position','50% 50%','','','.w-categories'),(162915,'deals-mobile','.p-wedding-registry-manage .wedding-image','background-position','50%','','','.p-wedding-registry-manage'),(162916,'deals-mobile','.p-wedding-registry-index .main-content','background-position','50%','','','.p-wedding-registry-index'),(162917,'deals-mobile','.p-wedding-registry-share .wedding-image','background-position','50%','','','.p-wedding-registry-share'),(162918,'deals-mobile','.w-top-categories .image','background-position','50% 50%','','','.w-top-categories'),(162919,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close','background-position','right -11px','1','','.b-select-suggest'),(162920,'deals-mobile','.b-select-suggest .select2-search-choice-close','background-position','top right','','','.b-select-suggest'),(162921,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close','background-position','right -11px','','','.b-select-suggest'),(162922,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-position','right -11px','1','','.b-select-suggest'),(162923,'deals-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow b','background-position','-18px 1px','','','.b-select-suggest'),(162924,'deals-mobile','.b-select-suggest .select2-search input','background-position','100% -22px','','','.b-select-suggest'),(162925,'deals-mobile','.b-select-suggest .select2-search input','background-position','100% -21px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(162926,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-position','top right','','','.b-select-suggest'),(162927,'deals-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','background-position','50%','','','.w-wedding-registry-widgets-manage-banner'),(162928,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-position','center','','','.w-wedding-registry-widgets-photos'),(162929,'deals-mobile','.b-select-suggest .select2-search input','background-position_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(162930,'deals-mobile','.b-select-suggest .select2-search-choice-close','background-repeat','no-repeat','','','.b-select-suggest'),(162931,'deals-mobile','.b-select-suggest .select2-search input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(162932,'deals-mobile','.b-select-suggest .select2-search input','background-repeat','no-repeat','','','.b-select-suggest'),(162933,'deals-mobile','.b-select-suggest .select2-more-results.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(162934,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-repeat','no-repeat','','','.b-select-suggest'),(162935,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','','.b-select-suggest'),(162936,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(162937,'deals-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(162938,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-repeat','no-repeat','','','.w-wedding-registry-widgets-photos'),(162939,'deals-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(162940,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat_important','important','','','.b-select-suggest'),(162941,'deals-mobile','.w-categories .image','background-size','cover','','','.w-categories'),(162942,'deals-mobile','.p-wedding-registry-index .main-content','background-size','cover','','','.p-wedding-registry-index'),(162943,'deals-mobile','.p-wedding-registry-manage .wedding-image','background-size','cover','','','.p-wedding-registry-manage'),(162944,'deals-mobile','.p-wedding-registry-share .wedding-image','background-size','cover','','','.p-wedding-registry-share'),(162945,'deals-mobile','.w-top-categories .image','background-size','cover','','','.w-top-categories'),(162946,'deals-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size','60px 40px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(162947,'deals-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','background-size','cover','','','.w-wedding-registry-widgets-manage-banner'),(162948,'deals-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(162949,'deals-mobile','.p-account-index .moduleRowDue td','background_image','themes/deals-mobile/img/pattern-1.png','','','.p-account-index'),(162950,'deals-mobile','.p-wedding-registry-manage .wedding-image','background_image','themes/deals-mobile/img/wedding-registry-page-1-1-1.jpg','','','.p-wedding-registry-manage'),(162951,'deals-mobile','.p-wedding-registry-index .main-content','background_image','themes/deals-mobile/img/wedding-registry-page-1-1-1.jpg','','','.p-wedding-registry-index'),(162952,'deals-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','background_image','themes/deals-mobile/img/wedding-registry-page-2.jpg','','','.w-wedding-registry-widgets-manage-banner'),(162953,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','background_image','themes/deals-mobile/img/avatar-bg-1.png','','','.w-wedding-registry-widgets-photos'),(162954,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.b-data-table'),(162955,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background_important','important','','','.b-select-suggest'),(162956,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.p-quick-order-index'),(162957,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(162958,'deals-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','border','none','','','.b-cookie-notice'),(162959,'deals-mobile','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(162960,'deals-mobile','.p-account-order-pay .historyTotal table','border','none','','','.p-account-order-pay'),(162961,'deals-mobile','.p-account-order-pay .historyTotal td','border','none','','','.p-account-order-pay'),(162962,'deals-mobile','.p-account-history .orders-table tr:first-child','border','none','','','.p-account-history'),(162963,'deals-mobile','.w-product-wedding-registry-button .btn','border','none','','','.w-product-wedding-registry-button'),(162964,'deals-mobile','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(162965,'deals-mobile','.p-wedding-registry-share .middle-form > input','border','none','','','.p-wedding-registry-share'),(162966,'deals-mobile','.b-compare .compare-head','border','none','','','.b-compare'),(162967,'deals-mobile','.w-product-personal-catalog-button .btn','border','none','','','.w-product-personal-catalog-button'),(162968,'deals-mobile','.w-filters .input-checkbox','border','none','','','.w-filters'),(162969,'deals-mobile','.b-bottom .popup-box.popupCompare','border','none','','','.b-bottom'),(162970,'deals-mobile','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(162971,'deals-mobile','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(162972,'deals-mobile','.w-compare-box-item .checkbox','border','none','','','.w-compare-box-item'),(162973,'deals-mobile','.p-account-history-info .historyTotal table','border','none','','','.p-account-history-info'),(162974,'deals-mobile','.w-categories .categories h2','border','none','','','.w-categories'),(162975,'deals-mobile','.w-top-categories .categories h2','border','none','','','.w-top-categories'),(162976,'deals-mobile','.b-form .checkbox-style','border','none','','','.b-form'),(162977,'deals-mobile','.p-account-index .orders-table tr:first-child','border','none','','','.p-account-index'),(162978,'deals-mobile','.p-account-history-info .historyTotal td','border','none','','','.p-account-history-info'),(162979,'deals-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input + span','border','none','','','.b-products-listing'),(162980,'deals-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','border','none','','','.b-products-listing'),(162981,'deals-mobile','.b-products-listing .products-listing a.btn.view-button','border','none','','','.b-products-listing'),(162982,'deals-mobile','.b-products-listing .products-listing h2','border','none','','','.b-products-listing'),(162983,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.b-data-table'),(162984,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.b-data-table'),(162985,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.b-data-table'),(162986,'deals-mobile','.b-data-table table.dataTable thead td','border','none','','','.b-data-table'),(162987,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','border','none','','','.b-menu-style-2'),(162988,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','border','none','','','.b-menu-style-2'),(162989,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','border','none','','','.b-menu-style-2'),(162990,'deals-mobile','.b-messages .select2-container-multi input.select2-input','border','none','','','.b-messages'),(162991,'deals-mobile','.b-messages .emailLineTextArea textarea','border','none','','','.b-messages'),(162992,'deals-mobile','.b-sub-totals .historyTotal td','border','none','','','.b-sub-totals'),(162993,'deals-mobile','.b-sub-totals .historyTotal table','border','none','','','.b-sub-totals'),(162994,'deals-mobile','.b-trade-approval .w-login-block .heading-3','border','none','','','.b-trade-approval'),(162995,'deals-mobile','.p-account-samples-history .orders-table tr:first-child','border','none','','','.p-account-samples-history'),(162996,'deals-mobile','.p-account-samples-history .orders-table tr:first-child','border','none','','','.p-account-samples-history'),(162997,'deals-mobile','.p-account-samples-history .orders-table tr:first-child','border','none','','','.p-account-samples-history'),(162998,'deals-mobile','.p-account-samples-history .orders-table tr:first-child','border','none','','','.p-account-samples-history'),(162999,'deals-mobile','.p-account-samples-history .orders-table tr:first-child','border','none','','','.p-account-samples-history'),(163000,'deals-mobile','.p-account-samples-history .orders-table tr:first-child','border','none','','','.p-account-samples-history'),(163001,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.p-quick-order-index'),(163002,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','1','','.p-quick-order-index'),(163003,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.p-quick-order-index'),(163004,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.p-quick-order-index'),(163005,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border','none','','','.w-blog-widget-related-posts'),(163006,'deals-mobile','.w-cart-cart-tabs .w-tabs > .block','border','none','','','.w-cart-cart-tabs'),(163007,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','border','none','','','.w-catalog-compare'),(163008,'deals-mobile','.w-checkout-gdpr .privacy-row','border','none','','','.w-checkout-gdpr'),(163009,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','border','none','','','.w-communication-new-topic'),(163010,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','border','none','','','.w-communication-new-topic'),(163011,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','border','none','','','.w-communication-new-topic'),(163012,'deals-mobile','.w-cart-shipping-estimator .addresses','border-bottom','none','','','.w-cart-shipping-estimator'),(163013,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable.no-footer','border-bottom','none','','','.b-messages'),(163014,'deals-mobile','.w-account-personal-catalog .list-switcher a','border-bottom','none','2','','.w-account-personal-catalog'),(163015,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','border-bottom','none','2','','.w-catalog-compare'),(163016,'deals-mobile','.w-promotions .heading-3','border-bottom','none','','','.w-promotions'),(163017,'deals-mobile','.w-sale .sale-holder','border-bottom-color','#ccc','','','.w-sale'),(163018,'deals-mobile','.w-product-wedding-registry-button .btn','border-bottom-color','#183d78','3','','.w-product-wedding-registry-button'),(163019,'deals-mobile','.w-product-sale-ends .left-text-left','border-bottom-color','#ccc','','','.w-product-sale-ends'),(163020,'deals-mobile','.w-product-sale-ends .left-text-right','border-bottom-color','#ccc','','','.w-product-sale-ends'),(163021,'deals-mobile','.w-currencies .select','border-bottom-color','#e0e0e0','','','.w-currencies'),(163022,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-history-info'),(163023,'deals-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-color','#04a440','','','.w-compare-box-item'),(163024,'deals-mobile','.w-catalog-listing-look .list','border-bottom-color','#e0e0e0','','','.w-catalog-listing-look'),(163025,'deals-mobile','.w-catalog-listing-look .grid','border-bottom-color','#e0e0e0','','','.w-catalog-listing-look'),(163026,'deals-mobile','.b-pagination .pagination span','border-bottom-color','#e0e0e0','2','','.b-pagination'),(163027,'deals-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-bottom-color','#bdbdbd','2','','.b-product-images'),(163028,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-color','#e0e0e0','','','.b-multi-page-checkout'),(163029,'deals-mobile','textarea','border-bottom-color','#e0e0e0','','',''),(163030,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-color','#e0e0e0','','','.p-blog-index'),(163031,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-color','#bdbdbd','','','.b-multi-page-checkout'),(163032,'deals-mobile','.b-info-popup .info-popup div','border-bottom-color','#e0e0e0','','','.b-info-popup'),(163033,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-color','#092964','','','.b-multi-page-checkout'),(163034,'deals-mobile','.w-promo-code .holder','border-bottom-color','#e0e0e0','','','.w-promo-code'),(163035,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-order-pay'),(163036,'deals-mobile','.testimonials .review','border-bottom-color','transparent','3','',''),(163037,'deals-mobile','.b-pagination .pagination .prev-pages','border-bottom-color','#e0e0e0','','','.b-pagination'),(163038,'deals-mobile','.b-pagination .pagination .page-number','border-bottom-color','#e0e0e0','','','.b-pagination'),(163039,'deals-mobile','.b-pagination .pagination .prev','border-bottom-color','#e0e0e0','','','.b-pagination'),(163040,'deals-mobile','.b-pagination .pagination .next-pages','border-bottom-color','#e0e0e0','','','.b-pagination'),(163041,'deals-mobile','.b-pagination .pagination .next','border-bottom-color','#e0e0e0','','','.b-pagination'),(163042,'deals-mobile','.p-account-history .orders-table .item','border-bottom-color','#ccc','890','','.p-account-history'),(163043,'deals-mobile','.p-account-index .orders-table .item','border-bottom-color','#ccc','890','','.p-account-index'),(163044,'deals-mobile','.w-cart .cart-content','border-bottom-color','#cccccc','','','.w-cart'),(163045,'deals-mobile','.p-blog-index .comments-area article','border-bottom-color','#e0e0e0','','','.p-blog-index'),(163046,'deals-mobile','.w-product-wedding-registry-button .btn','border-bottom-color','#183d78','4','','.w-product-wedding-registry-button'),(163047,'deals-mobile','.p-reviews-info .review-info-text','border-bottom-color','#fff','4','','.p-reviews-info'),(163048,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-color','#e0e0e0','3','','.b-form'),(163049,'deals-mobile','.p-wedding-registry-manage .links','border-bottom-color','#e0e0e0','','','.p-wedding-registry-manage'),(163050,'deals-mobile','.b-pagination .pagination a','border-bottom-color','#e0e0e0','','','.b-pagination'),(163051,'deals-mobile','.b-bottom .popup-heading','border-bottom-color','#d9d9d9','','','.b-bottom'),(163052,'deals-mobile','.b-compare .compare_pagination','border-bottom-color','#e0e0e0','','','.b-compare'),(163053,'deals-mobile','.w-tabs .accordion-heading','border-bottom-color','#183d78','2','','.w-tabs'),(163054,'deals-mobile','.w-tabs .accordion-heading','border-bottom-color','#e0e0e0','','','.w-tabs'),(163055,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-color','#ccc','','','.b-slick'),(163056,'deals-mobile','.b-bottom .footerTitle','border-bottom-color','#e0e0e0','863','','.b-bottom'),(163057,'deals-mobile','.btn','border-bottom-color','#183d78','','',''),(163058,'deals-mobile','.w-languages .select','border-bottom-color','#e0e0e0','','','.w-languages'),(163059,'deals-mobile','.w-tabs .tab-a','border-bottom-color','#e0e0e0','','','.w-tabs'),(163060,'deals-mobile','.w-tabs .tab-a','border-bottom-color','#183d78','2','','.w-tabs'),(163061,'deals-mobile','.w-socials > li','border-bottom-color','#dedede','','','.w-socials'),(163062,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-bottom-color','#e0e0e0','','',''),(163063,'deals-mobile','.heading-4, h4','border-bottom-color','#e2e2e2','','',''),(163064,'deals-mobile','.heading-2, h2','border-bottom-color','#e0e0e0','','',''),(163065,'deals-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-color','#eee','','','.p-account-trade-form'),(163066,'deals-mobile','.p-account-trade-form .widget .widget','border-bottom-color','#eee','','','.p-account-trade-form'),(163067,'deals-mobile','.w-filters .filter-box-head','border-bottom-color','#e0e0e0','','','.w-filters'),(163068,'deals-mobile','.w-currencies .currencies-title','border-bottom-color','#092964','','','.w-currencies'),(163069,'deals-mobile','.w-compare-box-item .checkbox + span','border-bottom-color','#bdbdbd','','','.w-compare-box-item'),(163070,'deals-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-color','#898989','','','.b-compare'),(163071,'deals-mobile','.w-cart-products .checkout-attention-message','border-bottom-color','#ee4225','','','.w-cart-products'),(163072,'deals-mobile','.w-product-quantity .qty_packs .qty-input','border-bottom-color','#ccc','','','.w-product-quantity'),(163073,'deals-mobile','.w-sale .left-text-left','border-bottom-color','#ccc','','','.w-sale'),(163074,'deals-mobile','.w-sale .left-text-right','border-bottom-color','#ccc','','','.w-sale'),(163075,'deals-mobile','.b-form .col-full-padding','border-bottom-color','#cccccc','','','.b-form'),(163076,'deals-mobile','.b-quantity .qty-box .smaller','border-bottom-color','#e0e0e0','','','.b-quantity'),(163077,'deals-mobile','.b-quantity .qty-box .bigger','border-bottom-color','#e0e0e0','','','.b-quantity'),(163078,'deals-mobile','.w-cart .cart-total','border-bottom-color','#eeeeee','','','.w-cart'),(163079,'deals-mobile','.w-cart-give-away .ga_column','border-bottom-color','#e0e0e0','','','.w-cart-give-away'),(163080,'deals-mobile','.w-catalog-listing-look .b2b','border-bottom-color','#e0e0e0','','','.w-catalog-listing-look'),(163081,'deals-mobile','.btn-3','border-bottom-color','#183d78','','',''),(163082,'deals-mobile','.b-bottom .popup-box','border-bottom-color','#d9d9d9','','','.b-bottom'),(163083,'deals-mobile','.w-reviews .review','border-bottom-color','transparent','3','','.w-reviews'),(163084,'deals-mobile','.b-form .required-error','border-bottom-color','#ed4224','','','.b-form'),(163085,'deals-mobile','.p-account-address-book .address_book h2','border-bottom-color','#e0e0e0','','','.p-account-address-book'),(163086,'deals-mobile','.p-account-address-book .address_book h1','border-bottom-color','#e0e0e0','','','.p-account-address-book'),(163087,'deals-mobile','.b-products-listing .products-listing .compare','border-bottom-color','#e0e0e0','','','.b-products-listing'),(163088,'deals-mobile','.b-data-table table.dataTable.no-footer','border-bottom-color','#e0e0e0','','','.b-data-table'),(163089,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','#e0e0e0','','','.b-dropdown'),(163090,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','#e0e0e0','','','.b-dropdown'),(163091,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','#e0e0e0','','','.b-dropdown'),(163092,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','#e0e0e0','','','.b-dropdown'),(163093,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','#e0e0e0','','','.b-dropdown'),(163094,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','#e0e0e0','','','.b-dropdown'),(163095,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-bottom-color','#ffffff','','','.b-menu-style-2'),(163096,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','border-bottom-color','#1a61ad','','','.b-menu-style-2'),(163097,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-bottom-color','#ffffff','','','.b-menu-style-2'),(163098,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-bottom-color','#ffffff','','','.b-menu-style-2'),(163099,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-bottom-color','#ffffff','','','.b-menu-style-2'),(163100,'deals-mobile','.b-messages .msv_btn','border-bottom-color','#e0e0e0','','','.b-messages'),(163101,'deals-mobile','.b-messages .content_management_attach button','border-bottom-color','#183d78','','','.b-messages'),(163102,'deals-mobile','.b-messages .content_management_attach','border-bottom-color','#e0e0e0','','','.b-messages'),(163103,'deals-mobile','.b-messages .email-heading','border-bottom-color','#e0e0e0','','','.b-messages'),(163104,'deals-mobile','.b-messages .dataTables_wrapper > .bottom','border-bottom-color','#e0e0e0','','','.b-messages'),(163105,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-color','#e0e0e0','','','.b-messages'),(163106,'deals-mobile','.b-messages .msv_to_cc','border-bottom-color','#e0e0e0','','','.b-messages'),(163107,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-color','#e0e0e0','','','.b-messages'),(163108,'deals-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-color','#e0e0e0','','','.b-messages'),(163109,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(163110,'deals-mobile','.b-select-suggest .select2-dropdown-open .select2-choice','border-bottom-color','transparent','','','.b-select-suggest'),(163111,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(163112,'deals-mobile','.b-select-suggest .select2-drop','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(163113,'deals-mobile','.b-select-suggest .select2-container .select2-choice','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(163114,'deals-mobile','.b-select-suggest .select2-container.select2-drop-above .select2-choice','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(163115,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(163116,'deals-mobile','.b-select-suggest .select2-search input','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(163117,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(163118,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(163119,'deals-mobile','.b-select-suggest .select2-drop-active','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(163120,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-color','#e0e0e0','','','.b-select-suggest'),(163121,'deals-mobile','.b-trade-approval .orders-table th','border-bottom-color','#e0e0e0','','','.b-trade-approval'),(163122,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-color','#e0e0e0','','','.b-trade-approval'),(163123,'deals-mobile','.b-upload-file .snapshot','border-bottom-color','#757575','','','.b-upload-file'),(163124,'deals-mobile','.b-upload-file .upload-file-template div','border-bottom-color','#e0e0e0','','','.b-upload-file'),(163125,'deals-mobile','.b-upload-file .upload-file-template','border-bottom-color','#e0e0e0','','','.b-upload-file'),(163126,'deals-mobile','.b-upload-files .upload-files','border-bottom-color','#e0e0e0','','','.b-upload-files'),(163127,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-color','#e0e0e0','','','.batchPr'),(163128,'deals-mobile','.batchPr .checkbox input + span','border-bottom-color','#e0e0e0','','','.batchPr'),(163129,'deals-mobile','.batchPr .checkbox input + span','border-bottom-color','#e0e0e0','','','.batchPr'),(163130,'deals-mobile','.batchPr .w-batch-selected-products','border-bottom-color','#e0e0e0','','','.batchPr'),(163131,'deals-mobile','.batchPr .checkbox input:checked + span','border-bottom-color','#1428a0','','','.batchPr'),(163132,'deals-mobile','.blogsidebar .heading-title','border-bottom-color','#e0e0e0','','','.blogsidebar'),(163133,'deals-mobile','.blogsidebar .heading-title','border-bottom-color','#e0e0e0','','','.blogsidebar'),(163134,'deals-mobile','.blogsidebar .heading-title','border-bottom-color','#e0e0e0','','','.blogsidebar'),(163135,'deals-mobile','.blogsidebar .heading-title','border-bottom-color','#e0e0e0','','','.blogsidebar'),(163136,'deals-mobile','.p-account-samples-history .orders-table .item','border-bottom-color','#e0e0e0','','','.p-account-samples-history'),(163137,'deals-mobile','.p-account-samples-history .orders-table .item','border-bottom-color','#e0e0e0','','','.p-account-samples-history'),(163138,'deals-mobile','.p-account-samples-history .orders-table .item','border-bottom-color','#e0e0e0','','','.p-account-samples-history'),(163139,'deals-mobile','.p-account-samples-history .orders-table .item','border-bottom-color','#e0e0e0','','','.p-account-samples-history'),(163140,'deals-mobile','.p-account-samples-history .orders-table .item','border-bottom-color','#e0e0e0','','','.p-account-samples-history'),(163141,'deals-mobile','.p-account-samples-history .orders-table .item','border-bottom-color','#e0e0e0','','','.p-account-samples-history'),(163142,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-samples-history-info'),(163143,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-samples-history-info'),(163144,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-samples-history-info'),(163145,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-samples-history-info'),(163146,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-samples-history-info'),(163147,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-color','#e0e0e0','','','.p-account-samples-history-info'),(163148,'deals-mobile','.p-catalog-product .prev-next-product','border-bottom-color','#e0e0e0','','','.p-catalog-product'),(163149,'deals-mobile','.p-catalog-product .pn-image','border-bottom-color','#e0e0e0','3','','.p-catalog-product'),(163150,'deals-mobile','.p-payer-order-confirmation .input-wrapper','border-bottom-color','#e0e0e0','','','.p-payer-order-confirmation'),(163151,'deals-mobile','.p-payer-order-pay .input-wrapper','border-bottom-color','#e0e0e0','','','.p-payer-order-pay'),(163152,'deals-mobile','.w-account-address-book .wrap','border-bottom-color','#c4c4c4','','','.w-account-address-book'),(163153,'deals-mobile','.w-account-personal-catalog .list-switcher a','border-bottom-color','#e0e0e0','','','.w-account-personal-catalog'),(163154,'deals-mobile','.w-blog-widget-post-listing .post_content','border-bottom-color','#e0e0e0','','','.w-blog-widget-post-listing'),(163155,'deals-mobile','.w-blog-widget-post-listing .post_name','border-bottom-color','#e0e0e0','','','.w-blog-widget-post-listing'),(163156,'deals-mobile','.w-blog-widget-post-title ','border-bottom-color','#e0e0e0','','','.w-blog-widget-post-title'),(163157,'deals-mobile','.w-cart-compare .compare-table','border-bottom-color','#e0e0e0','','','.w-cart-compare'),(163158,'deals-mobile','.w-cart-compare .cart-cell > div','border-bottom-color','#e0e0e0','','','.w-cart-compare'),(163159,'deals-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-color','#ffffff','','','.w-catalog-compare'),(163160,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','border-bottom-color','#e0e0e0','','','.w-catalog-compare'),(163161,'deals-mobile','.w-catalog-paging .next','border-bottom-color','#e0e0e0','','','.w-catalog-paging'),(163162,'deals-mobile','.w-catalog-paging .prev','border-bottom-color','#e0e0e0','','','.w-catalog-paging'),(163163,'deals-mobile','.w-catalog-paging ','border-bottom-color','#e0e0e0','2','','.w-catalog-paging'),(163164,'deals-mobile','.w-catalog-paging .next-pages','border-bottom-color','#e0e0e0','','','.w-catalog-paging'),(163165,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-color','#e0e0e0','','','.w-catalog-paging'),(163166,'deals-mobile','.w-catalog-paging .prev-pages','border-bottom-color','#e0e0e0','','','.w-catalog-paging'),(163167,'deals-mobile','.w-catalog-paging .page-number','border-bottom-color','#e0e0e0','','','.w-catalog-paging'),(163168,'deals-mobile','.w-checkout-shipping-choice span','border-bottom-color','#183d78','','','.w-checkout-shipping-choice'),(163169,'deals-mobile','.w-communication-post .communication-post','border-bottom-color','#e0e0e0','','','.w-communication-post'),(163170,'deals-mobile','.w-delivery-day .left-text-left','border-bottom-color','#e0e0e0','','','.w-delivery-day'),(163171,'deals-mobile','.w-delivery-day .left-text-right','border-bottom-color','#e0e0e0','','','.w-delivery-day'),(163172,'deals-mobile','.w-product-customers-activity .customers-activity','border-bottom-color','#e0e0e0','','','.w-product-customers-activity'),(163173,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-color','#ee4225','','','.w-promotions'),(163174,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-color','#ee4225','','','.w-promotions'),(163175,'deals-mobile','.w-promotions .promo-salemaker .discount','border-bottom-color','#ff6716','','','.w-promotions'),(163176,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-color','#ee4225','','','.w-promotions'),(163177,'deals-mobile','.w-reviews-content .item','border-bottom-color','#e0e0e0','','','.w-reviews-content'),(163178,'deals-mobile','.w-reviews-content .review','border-bottom-color','#e0e0e0','3','','.w-reviews-content'),(163179,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-color','#ccc','','','.w-upload-customer-id-upload-customer-id-form'),(163180,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-bottom-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(163181,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-bottom-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(163182,'deals-mobile','.b-data-table table.dataTable.no-footer','border-bottom-color_important','important','','','.b-data-table'),(163183,'deals-mobile','.w-product-sale-ends .left-count-days','border-bottom-left-radius','3','','','.w-product-sale-ends'),(163184,'deals-mobile','.w-sale .left-count-days','border-bottom-left-radius','3','','','.w-sale'),(163185,'deals-mobile','.w-sale .badge','border-bottom-left-radius','50','','','.w-sale'),(163186,'deals-mobile','.w-product-wedding-registry-button .btn','border-bottom-left-radius','50','3','','.w-product-wedding-registry-button'),(163187,'deals-mobile','.w-product-sale-ends .left-count','border-bottom-left-radius','3','','','.w-product-sale-ends'),(163188,'deals-mobile','.w-product-sale-ends .left-count-hours','border-bottom-left-radius','3','','','.w-product-sale-ends'),(163189,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-left-radius','50','3','','.b-multi-page-checkout'),(163190,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-left-radius','50','','','.b-multi-page-checkout'),(163191,'deals-mobile','.p-blog-index .avatar','border-bottom-left-radius','50','','','.p-blog-index'),(163192,'deals-mobile','.w-product-wedding-registry-button .btn','border-bottom-left-radius','50','4','','.w-product-wedding-registry-button'),(163193,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-left-radius','50','3','','.b-form'),(163194,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(163195,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(163196,'deals-mobile','.b-switch .bootstrap-switch','border-bottom-left-radius','14','','','.b-switch'),(163197,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border-bottom-left-radius','30','876','','.w-list-type-1'),(163198,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-left-radius','50','','','.b-slick'),(163199,'deals-mobile','.b-fancybox .fancybox-skin','border-bottom-left-radius','4','','','.b-fancybox'),(163200,'deals-mobile','.w-sale .left-count-hours','border-bottom-left-radius','3','','','.w-sale'),(163201,'deals-mobile','.w-sale .left-count','border-bottom-left-radius','3','','','.w-sale'),(163202,'deals-mobile','.b-fancybox .fancybox-nav span','border-bottom-left-radius','50','','','.b-fancybox'),(163203,'deals-mobile','.btn-3','border-bottom-left-radius','24','','',''),(163204,'deals-mobile','.btn-1','border-bottom-left-radius','20','','',''),(163205,'deals-mobile','.btn','border-bottom-left-radius','24','','',''),(163206,'deals-mobile','.btn-2','border-bottom-left-radius','24','','',''),(163207,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-left-radius','15','','','.b-fancybox'),(163208,'deals-mobile','.b-products-listing .promos-info .promo-name','border-bottom-left-radius','0','','','.b-products-listing'),(163209,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.b-data-table'),(163210,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.b-data-table'),(163211,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-left-radius','5','','','.b-messages'),(163212,'deals-mobile','.b-trade-approval .steps-bar','border-bottom-left-radius','18','','','.b-trade-approval'),(163213,'deals-mobile','.b-upload-file .snapshot','border-bottom-left-radius','50','','','.b-upload-file'),(163214,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-left-radius','10','','','.batchPr'),(163215,'deals-mobile','.batchPr .checkbox input + span','border-bottom-left-radius','18','','','.batchPr'),(163216,'deals-mobile','.batchPr .btn-batch-remove','border-bottom-left-radius','100','','','.batchPr'),(163217,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-bottom-left-radius','0','','','.batchPr'),(163218,'deals-mobile','.p-catalog-product .pn-image','border-bottom-left-radius','50','3','','.p-catalog-product'),(163219,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.p-quick-order-index'),(163220,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.p-quick-order-index'),(163221,'deals-mobile','.w-account-address-book .wrap','border-bottom-left-radius','5','','','.w-account-address-book'),(163222,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-bottom-left-radius','0','','','.w-blog-widget-related-posts'),(163223,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-left-radius','0','','','.w-catalog-paging'),(163224,'deals-mobile','.w-checkout-shipping-choice label:last-child span','border-bottom-left-radius','0','','','.w-checkout-shipping-choice'),(163225,'deals-mobile','.w-checkout-shipping-choice label:first-child span','border-bottom-left-radius','16','','','.w-checkout-shipping-choice'),(163226,'deals-mobile','.w-delivery-day .left-count','border-bottom-left-radius','3','','','.w-delivery-day'),(163227,'deals-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-left-radius','3','','','.w-delivery-day'),(163228,'deals-mobile','.w-personal-gift-status-bar .progress-bar-content','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(163229,'deals-mobile','.w-personal-gift-status-bar .progress-bar','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(163230,'deals-mobile','.w-product-customers-activity .customers-activity','border-bottom-left-radius','0','','','.w-product-customers-activity'),(163231,'deals-mobile','.w-product-customers-activity .close','border-bottom-left-radius','50','','','.w-product-customers-activity'),(163232,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-left-radius','12','','','.w-promotions'),(163233,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-left-radius','12','','','.w-promotions'),(163234,'deals-mobile','.w-promotions .promo-salemaker .discount','border-bottom-left-radius','12','','','.w-promotions'),(163235,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-left-radius','12','','','.w-promotions'),(163236,'deals-mobile','.w-product-sale-ends .left-count-days','border-bottom-right-radius','3','','','.w-product-sale-ends'),(163237,'deals-mobile','.w-sale .left-count-days','border-bottom-right-radius','3','','','.w-sale'),(163238,'deals-mobile','.w-sale .badge','border-bottom-right-radius','50','','','.w-sale'),(163239,'deals-mobile','.w-product-wedding-registry-button .btn','border-bottom-right-radius','50','3','','.w-product-wedding-registry-button'),(163240,'deals-mobile','.w-product-sale-ends .left-count','border-bottom-right-radius','3','','','.w-product-sale-ends'),(163241,'deals-mobile','.w-product-sale-ends .left-count-hours','border-bottom-right-radius','3','','','.w-product-sale-ends'),(163242,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-right-radius','50','3','','.b-multi-page-checkout'),(163243,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-right-radius','50','','','.b-multi-page-checkout'),(163244,'deals-mobile','.p-blog-index .avatar','border-bottom-right-radius','50','','','.p-blog-index'),(163245,'deals-mobile','.w-product-wedding-registry-button .btn','border-bottom-right-radius','50','4','','.w-product-wedding-registry-button'),(163246,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-right-radius','50','3','','.b-form'),(163247,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(163248,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(163249,'deals-mobile','.b-switch .bootstrap-switch','border-bottom-right-radius','14','','','.b-switch'),(163250,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border-bottom-right-radius','30','876','','.w-list-type-1'),(163251,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-right-radius','50','','','.b-slick'),(163252,'deals-mobile','.b-fancybox .fancybox-skin','border-bottom-right-radius','4','','','.b-fancybox'),(163253,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-right-radius','15','','','.b-fancybox'),(163254,'deals-mobile','.b-fancybox .fancybox-nav span','border-bottom-right-radius','50','','','.b-fancybox'),(163255,'deals-mobile','.w-sale .left-count-hours','border-bottom-right-radius','3','','','.w-sale'),(163256,'deals-mobile','.w-sale .left-count','border-bottom-right-radius','3','','','.w-sale'),(163257,'deals-mobile','.btn-3','border-bottom-right-radius','24','','',''),(163258,'deals-mobile','.btn-2','border-bottom-right-radius','24','','',''),(163259,'deals-mobile','.btn','border-bottom-right-radius','24','','',''),(163260,'deals-mobile','.btn-1','border-bottom-right-radius','20','','',''),(163261,'deals-mobile','.b-products-listing .promos-info .promo-name','border-bottom-right-radius','8','','','.b-products-listing'),(163262,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.b-data-table'),(163263,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.b-data-table'),(163264,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-right-radius','5','','','.b-messages'),(163265,'deals-mobile','.b-trade-approval .steps-bar','border-bottom-right-radius','18','','','.b-trade-approval'),(163266,'deals-mobile','.b-upload-file .snapshot','border-bottom-right-radius','50','','','.b-upload-file'),(163267,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-right-radius','10','','','.batchPr'),(163268,'deals-mobile','.batchPr .checkbox input + span','border-bottom-right-radius','18','','','.batchPr'),(163269,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-bottom-right-radius','0','','','.batchPr'),(163270,'deals-mobile','.batchPr .btn-batch-remove','border-bottom-right-radius','100','','','.batchPr'),(163271,'deals-mobile','.p-catalog-product .pn-image','border-bottom-right-radius','50','3','','.p-catalog-product'),(163272,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.p-quick-order-index'),(163273,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.p-quick-order-index'),(163274,'deals-mobile','.w-account-address-book .wrap','border-bottom-right-radius','5','','','.w-account-address-book'),(163275,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-bottom-right-radius','0','','','.w-blog-widget-related-posts'),(163276,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-right-radius','0','','','.w-catalog-paging'),(163277,'deals-mobile','.w-checkout-shipping-choice label:last-child span','border-bottom-right-radius','16','','','.w-checkout-shipping-choice'),(163278,'deals-mobile','.w-checkout-shipping-choice label:first-child span','border-bottom-right-radius','0','','','.w-checkout-shipping-choice'),(163279,'deals-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-right-radius','3','','','.w-delivery-day'),(163280,'deals-mobile','.w-delivery-day .left-count','border-bottom-right-radius','3','','','.w-delivery-day'),(163281,'deals-mobile','.w-personal-gift-status-bar .progress-bar','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(163282,'deals-mobile','.w-personal-gift-status-bar .progress-bar-content','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(163283,'deals-mobile','.w-product-customers-activity .customers-activity','border-bottom-right-radius','0','','','.w-product-customers-activity'),(163284,'deals-mobile','.w-product-customers-activity .close','border-bottom-right-radius','50','','','.w-product-customers-activity'),(163285,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-right-radius','12','','','.w-promotions'),(163286,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-right-radius','12','','','.w-promotions'),(163287,'deals-mobile','.w-promotions .promo-salemaker .discount','border-bottom-right-radius','12','','','.w-promotions'),(163288,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-right-radius','12','','','.w-promotions'),(163289,'deals-mobile','.b-upload-file .upload-file-template div','border-bottom-style','dotted','','','.b-upload-file'),(163290,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(163291,'deals-mobile','.w-sale .sale-holder','border-bottom-width','2','','','.w-sale'),(163292,'deals-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','border-bottom-width','2','','','.b-product-images'),(163293,'deals-mobile','.w-product-wedding-registry-button .btn','border-bottom-width','2','3','','.w-product-wedding-registry-button'),(163294,'deals-mobile','.w-product-sale-ends .left-text-right','border-bottom-width','2','','','.w-product-sale-ends'),(163295,'deals-mobile','.w-product-sale-ends .left-text-left','border-bottom-width','2','','','.w-product-sale-ends'),(163296,'deals-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-bottom-width','2','2','','.b-product-images'),(163297,'deals-mobile','.w-currencies .select','border-bottom-width','1','','','.w-currencies'),(163298,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-history-info'),(163299,'deals-mobile','.b-pagination .pagination span','border-bottom-width','1','2','','.b-pagination'),(163300,'deals-mobile','.w-product-reviews .reviews-list .review','border-bottom-width','13','3','','.w-product-reviews'),(163301,'deals-mobile','.w-catalog-listing-look .list','border-bottom-width','1','','','.w-catalog-listing-look'),(163302,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-width','1','','','.b-multi-page-checkout'),(163303,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-width','2','','','.p-blog-index'),(163304,'deals-mobile','textarea','border-bottom-width','2','','',''),(163305,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(163306,'deals-mobile','.b-info-popup .info-popup div','border-bottom-width','1','','','.b-info-popup'),(163307,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(163308,'deals-mobile','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(163309,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','border-bottom-width','1','','','.p-account-order-pay'),(163310,'deals-mobile','.testimonials .review','border-bottom-width','7','3','',''),(163311,'deals-mobile','.b-pagination .pagination .prev','border-bottom-width','1','','','.b-pagination'),(163312,'deals-mobile','.b-pagination .pagination .prev-pages','border-bottom-width','1','','','.b-pagination'),(163313,'deals-mobile','.p-wedding-registry-manage .wr-search button','border-bottom-width','0','','','.p-wedding-registry-manage'),(163314,'deals-mobile','.b-pagination .pagination .page-number','border-bottom-width','1','','','.b-pagination'),(163315,'deals-mobile','.b-pagination .pagination .next-pages','border-bottom-width','1','','','.b-pagination'),(163316,'deals-mobile','.b-pagination .pagination .next','border-bottom-width','1','','','.b-pagination'),(163317,'deals-mobile','.p-account-history .orders-table .item','border-bottom-width','1','890','','.p-account-history'),(163318,'deals-mobile','.p-account-index .orders-table .item','border-bottom-width','1','890','','.p-account-index'),(163319,'deals-mobile','.p-blog-index .comments-area article','border-bottom-width','1','','','.p-blog-index'),(163320,'deals-mobile','.w-cart .cart-content','border-bottom-width','1','','','.w-cart'),(163321,'deals-mobile','.w-list-type-2_2 .button-wishlist button','border-bottom-width','0','','','.w-list-type-2_2'),(163322,'deals-mobile','.w-product-wedding-registry-button .btn','border-bottom-width','2','4','','.w-product-wedding-registry-button'),(163323,'deals-mobile','.p-reviews-info .review-info-text','border-bottom-width','5','4','','.p-reviews-info'),(163324,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-width','2','3','','.b-form'),(163325,'deals-mobile','.p-wedding-registry-manage .links','border-bottom-width','1','','','.p-wedding-registry-manage'),(163326,'deals-mobile','.b-pagination .pagination a','border-bottom-width','1','','','.b-pagination'),(163327,'deals-mobile','.b-bottom .popup-heading','border-bottom-width','1','','','.b-bottom'),(163328,'deals-mobile','.b-compare .compare_pagination','border-bottom-width','1','','','.b-compare'),(163329,'deals-mobile','.w-tabs .accordion-heading','border-bottom-width','1','','','.w-tabs'),(163330,'deals-mobile','.w-tabs .accordion-heading','border-bottom-width','3','2','','.w-tabs'),(163331,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-width','2','','','.b-slick'),(163332,'deals-mobile','.b-bottom .footerTitle','border-bottom-width','1','863','','.b-bottom'),(163333,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-bottom-width','2','','',''),(163334,'deals-mobile','.btn','border-bottom-width','2','','',''),(163335,'deals-mobile','.w-tabs .tab-a','border-bottom-width','3','2','','.w-tabs'),(163336,'deals-mobile','.w-tabs .tab-a','border-bottom-width','1','','','.w-tabs'),(163337,'deals-mobile','.w-search .search-input','border-bottom-width','0','','','.w-search'),(163338,'deals-mobile','.p-account-trade-form .widget .widget','border-bottom-width','1','','','.p-account-trade-form'),(163339,'deals-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-width','1','','','.p-account-trade-form'),(163340,'deals-mobile','.w-filters .filter-box-head','border-bottom-width','1','','','.w-filters'),(163341,'deals-mobile','.w-currencies .currencies-title','border-bottom-width','2','','','.w-currencies'),(163342,'deals-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-width','1','','','.w-compare-box-item'),(163343,'deals-mobile','.w-compare-box-item .checkbox + span','border-bottom-width','1','','','.w-compare-box-item'),(163344,'deals-mobile','.b-slick .slick-vertical .slick-slide','border-bottom-width','1','','','.b-slick'),(163345,'deals-mobile','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(163346,'deals-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-width','1','','','.b-compare'),(163347,'deals-mobile','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(163348,'deals-mobile','.heading-4, h4','border-bottom-width','1','','',''),(163349,'deals-mobile','.heading-2, h2','border-bottom-width','1','','',''),(163350,'deals-mobile','.w-sale .left-text-right','border-bottom-width','2','','','.w-sale'),(163351,'deals-mobile','.w-sale .left-text-left','border-bottom-width','2','','','.w-sale'),(163352,'deals-mobile','.b-form .col-full-padding','border-bottom-width','1','','','.b-form'),(163353,'deals-mobile','.b-quantity .qty-box .smaller','border-bottom-width','2','','','.b-quantity'),(163354,'deals-mobile','.b-quantity .qty-box .bigger','border-bottom-width','2','','','.b-quantity'),(163355,'deals-mobile','.w-cart .cart-total','border-bottom-width','1','','','.w-cart'),(163356,'deals-mobile','.w-catalog-listing-look .grid','border-bottom-width','1','','','.w-catalog-listing-look'),(163357,'deals-mobile','.w-cart-give-away .ga_column','border-bottom-width','1','','','.w-cart-give-away'),(163358,'deals-mobile','.w-catalog-listing-look .b2b','border-bottom-width','1','','','.w-catalog-listing-look'),(163359,'deals-mobile','.w-list-type-2 .button-wishlist button','border-bottom-width','0','','','.w-list-type-2'),(163360,'deals-mobile','.b-autocomplete .ui-autocomplete li','border-bottom-width','1','','','.b-autocomplete'),(163361,'deals-mobile','.btn-3','border-bottom-width','2','','',''),(163362,'deals-mobile','.w-list-type-1_3 .button-wishlist button','border-bottom-width','0','','','.w-list-type-1_3'),(163363,'deals-mobile','.w-list-type-1_2 .button-wishlist button','border-bottom-width','0','','','.w-list-type-1_2'),(163364,'deals-mobile','.b-bottom .popup-box','border-bottom-width','1','','','.b-bottom'),(163365,'deals-mobile','.w-list-type-1 .button-wishlist button','border-bottom-width','0','','','.w-list-type-1'),(163366,'deals-mobile','.w-filters .ui-slider','border-bottom-width','0','','','.w-filters'),(163367,'deals-mobile','.w-filters .ui-slider-range','border-bottom-width','0','','','.w-filters'),(163368,'deals-mobile','.w-filters .ui-slider-handle','border-bottom-width','0','','','.w-filters'),(163369,'deals-mobile','.w-languages .select','border-bottom-width','1','','','.w-languages'),(163370,'deals-mobile','.w-reviews .review','border-bottom-width','7','3','','.w-reviews'),(163371,'deals-mobile','.w-search .button-search','border-bottom-width','0','','','.w-search'),(163372,'deals-mobile','.w-socials > li','border-bottom-width','1','','','.w-socials'),(163373,'deals-mobile','.b-form .required-error','border-bottom-width','1','','','.b-form'),(163374,'deals-mobile','.p-account-address-book .address_book h1','border-bottom-width','1','','','.p-account-address-book'),(163375,'deals-mobile','.p-account-address-book .address_book h2','border-bottom-width','1','','','.p-account-address-book'),(163376,'deals-mobile','.b-products-listing .products-listing .compare','border-bottom-width','1','','','.b-products-listing'),(163377,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(163378,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(163379,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(163380,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(163381,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(163382,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(163383,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','border-bottom-width','1','','','.b-menu-style-2'),(163384,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-bottom-width','1','','','.b-menu-style-2'),(163385,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-bottom-width','3','','','.b-menu-style-2'),(163386,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-bottom-width','1','','','.b-menu-style-2'),(163387,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-bottom-width','3','','','.b-menu-style-2'),(163388,'deals-mobile','.b-messages .msv_to_cc','border-bottom-width','1','','','.b-messages'),(163389,'deals-mobile','.b-messages .msv_btn','border-bottom-width','1','','','.b-messages'),(163390,'deals-mobile','.b-messages .email-heading','border-bottom-width','1','','','.b-messages'),(163391,'deals-mobile','.b-messages .content_management_attach button','border-bottom-width','1','','','.b-messages'),(163392,'deals-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-width','2','','','.b-messages'),(163393,'deals-mobile','.b-messages .content_management_attach','border-bottom-width','1','','','.b-messages'),(163394,'deals-mobile','.b-messages .dataTables_wrapper > .bottom','border-bottom-width','1','','','.b-messages'),(163395,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-width','1','','','.b-messages'),(163396,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-width','1','','','.b-messages'),(163397,'deals-mobile','.b-select-suggest .select2-search input','border-bottom-width','1','','','.b-select-suggest'),(163398,'deals-mobile','.b-select-suggest .select2-container .select2-choice','border-bottom-width','2','','','.b-select-suggest'),(163399,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(163400,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(163401,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(163402,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-width','1','','','.b-select-suggest'),(163403,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(163404,'deals-mobile','.b-select-suggest .select2-drop-active','border-bottom-width','1','','','.b-select-suggest'),(163405,'deals-mobile','.b-select-suggest .select2-drop','border-bottom-width','1','','','.b-select-suggest'),(163406,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(163407,'deals-mobile','.b-trade-approval .orders-table th','border-bottom-width','1','','','.b-trade-approval'),(163408,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-width','2','','','.b-trade-approval'),(163409,'deals-mobile','.b-upload-file .snapshot','border-bottom-width','1','','','.b-upload-file'),(163410,'deals-mobile','.b-upload-file .upload-file-template div','border-bottom-width','1','','','.b-upload-file'),(163411,'deals-mobile','.b-upload-file .upload-file-template','border-bottom-width','1','','','.b-upload-file'),(163412,'deals-mobile','.b-upload-files .upload-files','border-bottom-width','1','','','.b-upload-files'),(163413,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-width','1','','','.batchPr'),(163414,'deals-mobile','.batchPr .checkbox input + span','border-bottom-width','1','','','.batchPr'),(163415,'deals-mobile','.batchPr .checkbox input + span','border-bottom-width','1','','','.batchPr'),(163416,'deals-mobile','.batchPr .checkbox input:checked + span','border-bottom-width','1','','','.batchPr'),(163417,'deals-mobile','.batchPr .w-batch-selected-products','border-bottom-width','1','','','.batchPr'),(163418,'deals-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(163419,'deals-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(163420,'deals-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(163421,'deals-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(163422,'deals-mobile','.p-account-samples-history .orders-table .item','border-bottom-width','1','','','.p-account-samples-history'),(163423,'deals-mobile','.p-account-samples-history .orders-table .item','border-bottom-width','1','','','.p-account-samples-history'),(163424,'deals-mobile','.p-account-samples-history .orders-table .item','border-bottom-width','1','','','.p-account-samples-history'),(163425,'deals-mobile','.p-account-samples-history .orders-table .item','border-bottom-width','1','','','.p-account-samples-history'),(163426,'deals-mobile','.p-account-samples-history .orders-table .item','border-bottom-width','1','','','.p-account-samples-history'),(163427,'deals-mobile','.p-account-samples-history .orders-table .item','border-bottom-width','1','','','.p-account-samples-history'),(163428,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-samples-history-info'),(163429,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-samples-history-info'),(163430,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-samples-history-info'),(163431,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-samples-history-info'),(163432,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-samples-history-info'),(163433,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','border-bottom-width','1','','','.p-account-samples-history-info'),(163434,'deals-mobile','.p-catalog-product .prev-next-product','border-bottom-width','1','','','.p-catalog-product'),(163435,'deals-mobile','.p-catalog-product .pn-image','border-bottom-width','2','3','','.p-catalog-product'),(163436,'deals-mobile','.p-payer-order-confirmation .input-wrapper','border-bottom-width','2','','','.p-payer-order-confirmation'),(163437,'deals-mobile','.p-payer-order-pay .input-wrapper','border-bottom-width','2','','','.p-payer-order-pay'),(163438,'deals-mobile','.w-account-address-book .wrap','border-bottom-width','1','','','.w-account-address-book'),(163439,'deals-mobile','.w-account-personal-catalog .list-switcher a','border-bottom-width','1','','','.w-account-personal-catalog'),(163440,'deals-mobile','.w-blog-widget-post-listing .post_content','border-bottom-width','1','','','.w-blog-widget-post-listing'),(163441,'deals-mobile','.w-blog-widget-post-listing .post_name','border-bottom-width','1','','','.w-blog-widget-post-listing'),(163442,'deals-mobile','.w-blog-widget-post-title ','border-bottom-width','1','','','.w-blog-widget-post-title'),(163443,'deals-mobile','.w-cart-compare .cart-cell > div','border-bottom-width','1','','','.w-cart-compare'),(163444,'deals-mobile','.w-cart-compare .compare-table','border-bottom-width','1','','','.w-cart-compare'),(163445,'deals-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-width','1','','','.w-catalog-compare'),(163446,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','border-bottom-width','1','','','.w-catalog-compare'),(163447,'deals-mobile','.w-catalog-paging .prev','border-bottom-width','1','','','.w-catalog-paging'),(163448,'deals-mobile','.w-catalog-paging .page-number','border-bottom-width','1','','','.w-catalog-paging'),(163449,'deals-mobile','.w-catalog-paging .next','border-bottom-width','1','','','.w-catalog-paging'),(163450,'deals-mobile','.w-catalog-paging ','border-bottom-width','1','2','','.w-catalog-paging'),(163451,'deals-mobile','.w-catalog-paging .next-pages','border-bottom-width','1','','','.w-catalog-paging'),(163452,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-width','1','','','.w-catalog-paging'),(163453,'deals-mobile','.w-catalog-paging .prev-pages','border-bottom-width','1','','','.w-catalog-paging'),(163454,'deals-mobile','.w-checkout-shipping-choice span','border-bottom-width','2','','','.w-checkout-shipping-choice'),(163455,'deals-mobile','.w-communication-post .communication-post','border-bottom-width','1','','','.w-communication-post'),(163456,'deals-mobile','.w-delivery-day .left-text-right','border-bottom-width','2','','','.w-delivery-day'),(163457,'deals-mobile','.w-delivery-day .left-text-left','border-bottom-width','2','','','.w-delivery-day'),(163458,'deals-mobile','.w-product-customers-activity .customers-activity','border-bottom-width','1','','','.w-product-customers-activity'),(163459,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-width','1','','','.w-promotions'),(163460,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-width','1','','','.w-promotions'),(163461,'deals-mobile','.w-promotions .promo-salemaker .discount','border-bottom-width','1','','','.w-promotions'),(163462,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-width','1','','','.w-promotions'),(163463,'deals-mobile','.w-reviews-content .review','border-bottom-width','8','3','','.w-reviews-content'),(163464,'deals-mobile','.w-reviews-content .item','border-bottom-width','1','','','.w-reviews-content'),(163465,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(163466,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-bottom-width','1','','','.w-wedding-registry-widgets-photos'),(163467,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-bottom-width','1','','','.w-wedding-registry-widgets-photos'),(163468,'deals-mobile','.b-compare .popupCompare table','border-collapse','collapse','','','.b-compare'),(163469,'deals-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','border-left','none','','','.b-select-suggest'),(163470,'deals-mobile','.w-catalog-listing-look .list','border-left-color','#e0e0e0','','','.w-catalog-listing-look'),(163471,'deals-mobile','.w-sale .sale-holder','border-left-color','#ccc','','','.w-sale'),(163472,'deals-mobile','.w-product-wedding-registry-button .btn','border-left-color','#183d78','3','','.w-product-wedding-registry-button'),(163473,'deals-mobile','.w-cart-products .checkout-attention-message','border-left-color','#ee4225','','','.w-cart-products'),(163474,'deals-mobile','.w-currencies .select','border-left-color','#e0e0e0','','','.w-currencies'),(163475,'deals-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-left-color','#bdbdbd','2','','.b-product-images'),(163476,'deals-mobile','.b-pagination .pagination span','border-left-color','#e0e0e0','2','','.b-pagination'),(163477,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-color','#e0e0e0','','','.b-multi-page-checkout'),(163478,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-color','#e0e0e0','','','.p-blog-index'),(163479,'deals-mobile','textarea','border-left-color','#e0e0e0','','',''),(163480,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-color','#bdbdbd','','','.b-multi-page-checkout'),(163481,'deals-mobile','.b-info-popup .info-popup div','border-left-color','#e0e0e0','3','','.b-info-popup'),(163482,'deals-mobile','.b-info-popup .info-popup div','border-left-color','#e0e0e0','','','.b-info-popup'),(163483,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-color','#092964','','','.b-multi-page-checkout'),(163484,'deals-mobile','.w-promo-code .holder','border-left-color','#e0e0e0','','','.w-promo-code'),(163485,'deals-mobile','.testimonials .review','border-left-color','#eeeeee','3','',''),(163486,'deals-mobile','.b-pagination .pagination .prev-pages','border-left-color','#e0e0e0','','','.b-pagination'),(163487,'deals-mobile','.b-pagination .pagination .prev','border-left-color','#e0e0e0','','','.b-pagination'),(163488,'deals-mobile','.b-pagination .pagination .page-number','border-left-color','#e0e0e0','','','.b-pagination'),(163489,'deals-mobile','.b-pagination .pagination .next-pages','border-left-color','#e0e0e0','','','.b-pagination'),(163490,'deals-mobile','.b-pagination .pagination .next','border-left-color','#e0e0e0','','','.b-pagination'),(163491,'deals-mobile','.p-account-history .orders-table .item','border-left-color','#ccc','890','','.p-account-history'),(163492,'deals-mobile','.p-account-index .orders-table .item','border-left-color','#ccc','890','','.p-account-index'),(163493,'deals-mobile','.w-cart .cart-content','border-left-color','#cccccc','','','.w-cart'),(163494,'deals-mobile','.w-product-wedding-registry-button .btn','border-left-color','#183d78','4','','.w-product-wedding-registry-button'),(163495,'deals-mobile','.p-reviews-info .review-info-text','border-left-color','#fff','4','','.p-reviews-info'),(163496,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-left-color','#e0e0e0','3','','.b-form'),(163497,'deals-mobile','.p-wedding-registry-manage .links a + a','border-left-color','#e0e0e0','','','.p-wedding-registry-manage'),(163498,'deals-mobile','.b-pagination .pagination a','border-left-color','#e0e0e0','','','.b-pagination'),(163499,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-left-color','#ccc','','','.b-slick'),(163500,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-left-color','#e0e0e0','','',''),(163501,'deals-mobile','.w-socials > li','border-left-color','#dedede','','','.w-socials'),(163502,'deals-mobile','.w-currencies .currencies-title','border-left-color','#092964','','','.w-currencies'),(163503,'deals-mobile','.w-compare-box-item .checkbox:checked + span','border-left-color','#04a440','','','.w-compare-box-item'),(163504,'deals-mobile','.w-compare-box-item .checkbox + span','border-left-color','#bdbdbd','','','.w-compare-box-item'),(163505,'deals-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-color','#898989','','','.b-compare'),(163506,'deals-mobile','.b-quantity .qty-box .smaller','border-left-color','#e0e0e0','','','.b-quantity'),(163507,'deals-mobile','.b-quantity .qty-box .bigger','border-left-color','#e0e0e0','','','.b-quantity'),(163508,'deals-mobile','.w-catalog-listing-look .grid','border-left-color','#e0e0e0','','','.w-catalog-listing-look'),(163509,'deals-mobile','.w-catalog-listing-look .b2b','border-left-color','#e0e0e0','','','.w-catalog-listing-look'),(163510,'deals-mobile','.btn-3','border-left-color','#183d78','','',''),(163511,'deals-mobile','.btn','border-left-color','#183d78','','',''),(163512,'deals-mobile','.b-bottom .popup-box','border-left-color','#d9d9d9','','','.b-bottom'),(163513,'deals-mobile','.w-languages .select','border-left-color','#e0e0e0','','','.w-languages'),(163514,'deals-mobile','.w-reviews .review','border-left-color','#fff','3','','.w-reviews'),(163515,'deals-mobile','.b-form .required-error','border-left-color','#ed4224','','','.b-form'),(163516,'deals-mobile','.b-data-table table.dataTable.no-footer','border-left-color','#e0e0e0','','','.b-data-table'),(163517,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','#e0e0e0','','','.b-dropdown'),(163518,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','#e0e0e0','','','.b-dropdown'),(163519,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','#e0e0e0','','','.b-dropdown'),(163520,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','#e0e0e0','','','.b-dropdown'),(163521,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','#e0e0e0','','','.b-dropdown'),(163522,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','#e0e0e0','','','.b-dropdown'),(163523,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-left-color','#ffffff','','','.b-menu-style-2'),(163524,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-left-color','#ffffff','','','.b-menu-style-2'),(163525,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-left-color','#ffffff','','','.b-menu-style-2'),(163526,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-left-color','#ffffff','','','.b-menu-style-2'),(163527,'deals-mobile','.b-messages .content_management_attach button','border-left-color','#183d78','','','.b-messages'),(163528,'deals-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-color','#e0e0e0','','','.b-messages'),(163529,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-color','#e0e0e0','','','.b-select-suggest'),(163530,'deals-mobile','.b-select-suggest .select2-search input','border-left-color','#e0e0e0','','','.b-select-suggest'),(163531,'deals-mobile','.b-select-suggest .select2-container .select2-choice','border-left-color','#e0e0e0','','','.b-select-suggest'),(163532,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-color','#e0e0e0','','','.b-select-suggest'),(163533,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-color','#e0e0e0','','','.b-select-suggest'),(163534,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-color','#e0e0e0','','','.b-select-suggest'),(163535,'deals-mobile','.b-select-suggest .select2-drop-active','border-left-color','#e0e0e0','','','.b-select-suggest'),(163536,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-left-color','#e0e0e0','','','.b-select-suggest'),(163537,'deals-mobile','.b-select-suggest .select2-drop','border-left-color','#e0e0e0','','','.b-select-suggest'),(163538,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-color','#e0e0e0','','','.b-select-suggest'),(163539,'deals-mobile','.b-trade-approval .steps-bar li ~ li a','border-left-color','#fff','','','.b-trade-approval'),(163540,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-color','#e0e0e0','','','.b-trade-approval'),(163541,'deals-mobile','.b-upload-file .snapshot','border-left-color','#757575','','','.b-upload-file'),(163542,'deals-mobile','.b-upload-file .upload-file-template','border-left-color','#e0e0e0','','','.b-upload-file'),(163543,'deals-mobile','.b-upload-files .upload-files','border-left-color','#e0e0e0','','','.b-upload-files'),(163544,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-left-color','#e0e0e0','','','.batchPr'),(163545,'deals-mobile','.batchPr .checkbox input + span','border-left-color','#e0e0e0','','','.batchPr'),(163546,'deals-mobile','.batchPr .checkbox input + span','border-left-color','#e0e0e0','','','.batchPr'),(163547,'deals-mobile','.batchPr .checkbox input:checked + span','border-left-color','#1428a0','','','.batchPr'),(163548,'deals-mobile','.batchPr .w-batch-selected-products','border-left-color','#e0e0e0','','','.batchPr'),(163549,'deals-mobile','.p-account-samples-history .orders-table .item','border-left-color','#e0e0e0','','','.p-account-samples-history'),(163550,'deals-mobile','.p-account-samples-history .orders-table .item','border-left-color','#e0e0e0','','','.p-account-samples-history'),(163551,'deals-mobile','.p-account-samples-history .orders-table .item','border-left-color','#e0e0e0','','','.p-account-samples-history'),(163552,'deals-mobile','.p-account-samples-history .orders-table .item','border-left-color','#e0e0e0','','','.p-account-samples-history'),(163553,'deals-mobile','.p-account-samples-history .orders-table .item','border-left-color','#e0e0e0','','','.p-account-samples-history'),(163554,'deals-mobile','.p-account-samples-history .orders-table .item','border-left-color','#e0e0e0','','','.p-account-samples-history'),(163555,'deals-mobile','.p-catalog-product .next-product','border-left-color','#e0e0e0','','','.p-catalog-product'),(163556,'deals-mobile','.p-catalog-product .pn-image','border-left-color','#e0e0e0','3','','.p-catalog-product'),(163557,'deals-mobile','.p-payer-order-confirmation .input-wrapper','border-left-color','#e0e0e0','','','.p-payer-order-confirmation'),(163558,'deals-mobile','.p-payer-order-pay .input-wrapper','border-left-color','#e0e0e0','','','.p-payer-order-pay'),(163559,'deals-mobile','.w-account-address-book .wrap','border-left-color','#c4c4c4','','','.w-account-address-book'),(163560,'deals-mobile','.w-account-personal-catalog .list-switcher a','border-left-color','#e0e0e0','2','','.w-account-personal-catalog'),(163561,'deals-mobile','.w-cart-compare .attributes-block td:nth-child(1)','border-left-color','#e0e0e0','','','.w-cart-compare'),(163562,'deals-mobile','.w-cart-compare .price-block td:nth-child(1)','border-left-color','#e0e0e0','','','.w-cart-compare'),(163563,'deals-mobile','.w-cart-compare .product-block td:nth-child(1)','border-left-color','#e0e0e0','','','.w-cart-compare'),(163564,'deals-mobile','.w-cart-compare .cart-cell > div','border-left-color','#e0e0e0','','','.w-cart-compare'),(163565,'deals-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-left-color','#ffffff','','','.w-catalog-compare'),(163566,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','border-left-color','#e0e0e0','2','','.w-catalog-compare'),(163567,'deals-mobile','.w-catalog-paging ','border-left-color','#e0e0e0','2','','.w-catalog-paging'),(163568,'deals-mobile','.w-catalog-paging .prev','border-left-color','#e0e0e0','','','.w-catalog-paging'),(163569,'deals-mobile','.w-catalog-paging .next','border-left-color','#e0e0e0','','','.w-catalog-paging'),(163570,'deals-mobile','.w-catalog-paging .page-number','border-left-color','#e0e0e0','','','.w-catalog-paging'),(163571,'deals-mobile','.w-catalog-paging .next-pages','border-left-color','#e0e0e0','','','.w-catalog-paging'),(163572,'deals-mobile','.w-catalog-paging .prev-pages','border-left-color','#e0e0e0','','','.w-catalog-paging'),(163573,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-color','#e0e0e0','','','.w-catalog-paging'),(163574,'deals-mobile','.w-checkout-shipping-choice label:first-child span','border-left-color','#183d78','','','.w-checkout-shipping-choice'),(163575,'deals-mobile','.w-product-customers-activity .customers-activity','border-left-color','#e0e0e0','','','.w-product-customers-activity'),(163576,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-left-color','#ee4225','','','.w-promotions'),(163577,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-color','#ee4225','','','.w-promotions'),(163578,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border-left-color','#ee4225','','','.w-promotions'),(163579,'deals-mobile','.w-promotions .promo-salemaker .discount','border-left-color','#ff6716','','','.w-promotions'),(163580,'deals-mobile','.w-reviews-content .review','border-left-color','#e0e0e0','3','','.w-reviews-content'),(163581,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-color','#ccc','','','.w-upload-customer-id-upload-customer-id-form'),(163582,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-left-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(163583,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-left-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(163584,'deals-mobile','.b-data-table table.dataTable.no-footer','border-left-color_important','important','','','.b-data-table'),(163585,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(163586,'deals-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','border-left-width','2','','','.b-product-images'),(163587,'deals-mobile','.w-sale .sale-holder','border-left-width','2','','','.w-sale'),(163588,'deals-mobile','.w-product-wedding-registry-button .btn','border-left-width','2','3','','.w-product-wedding-registry-button'),(163589,'deals-mobile','.w-currencies .select','border-left-width','1','','','.w-currencies'),(163590,'deals-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-left-width','2','2','','.b-product-images'),(163591,'deals-mobile','.w-compare-box-item .checkbox + span','border-left-width','1','','','.w-compare-box-item'),(163592,'deals-mobile','.w-catalog-listing-look .b2b','border-left-width','1','','','.w-catalog-listing-look'),(163593,'deals-mobile','.w-catalog-listing-look .list','border-left-width','1','','','.w-catalog-listing-look'),(163594,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-width','1','','','.b-multi-page-checkout'),(163595,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-width','2','','','.p-blog-index'),(163596,'deals-mobile','textarea','border-left-width','2','','',''),(163597,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(163598,'deals-mobile','.btn','border-left-width','2','','',''),(163599,'deals-mobile','.btn-3','border-left-width','2','','',''),(163600,'deals-mobile','.b-info-popup .info-popup div','border-left-width','1','','','.b-info-popup'),(163601,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(163602,'deals-mobile','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(163603,'deals-mobile','.testimonials .review','border-left-width','10','3','',''),(163604,'deals-mobile','.b-pagination .pagination .prev-pages','border-left-width','1','','','.b-pagination'),(163605,'deals-mobile','.b-pagination .pagination .prev','border-left-width','1','','','.b-pagination'),(163606,'deals-mobile','.p-wedding-registry-manage .wr-search button','border-left-width','0','','','.p-wedding-registry-manage'),(163607,'deals-mobile','.b-pagination .pagination .page-number','border-left-width','1','','','.b-pagination'),(163608,'deals-mobile','.b-pagination .pagination .next-pages','border-left-width','1','','','.b-pagination'),(163609,'deals-mobile','.b-pagination .pagination .next','border-left-width','1','','','.b-pagination'),(163610,'deals-mobile','.b-pagination .pagination span','border-left-width','1','2','','.b-pagination'),(163611,'deals-mobile','.p-account-history .orders-table .item','border-left-width','1','890','','.p-account-history'),(163612,'deals-mobile','.p-account-index .orders-table .item','border-left-width','1','890','','.p-account-index'),(163613,'deals-mobile','.w-cart .cart-content','border-left-width','1','','','.w-cart'),(163614,'deals-mobile','.w-list-type-2_2 .button-wishlist button','border-left-width','0','','','.w-list-type-2_2'),(163615,'deals-mobile','.w-list-type-2_2 .button-wishlist','border-left-width','1','','','.w-list-type-2_2'),(163616,'deals-mobile','.w-product-wedding-registry-button .btn','border-left-width','2','4','','.w-product-wedding-registry-button'),(163617,'deals-mobile','.p-reviews-info .review-info-text','border-left-width','5','4','','.p-reviews-info'),(163618,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-left-width','2','3','','.b-form'),(163619,'deals-mobile','.p-wedding-registry-manage .links a + a','border-left-width','1','','','.p-wedding-registry-manage'),(163620,'deals-mobile','.b-pagination .pagination a','border-left-width','1','','','.b-pagination'),(163621,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-left-width','2','','','.b-slick'),(163622,'deals-mobile','.w-languages .select','border-left-width','1','','','.w-languages'),(163623,'deals-mobile','.w-search .search-input','border-left-width','0','','','.w-search'),(163624,'deals-mobile','.w-socials > li','border-left-width','1','','','.w-socials'),(163625,'deals-mobile','.w-currencies .currencies-title','border-left-width','2','','','.w-currencies'),(163626,'deals-mobile','.w-compare-box-item .checkbox:checked + span','border-left-width','1','','','.w-compare-box-item'),(163627,'deals-mobile','.b-slick .slick-vertical .slick-slide','border-left-width','1','','','.b-slick'),(163628,'deals-mobile','.b-info-popup .info-popup div','border-left-width','1','3','','.b-info-popup'),(163629,'deals-mobile','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(163630,'deals-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-width','1','','','.b-compare'),(163631,'deals-mobile','.w-catalog-listing-look .grid','border-left-width','1','','','.w-catalog-listing-look'),(163632,'deals-mobile','.b-quantity .qty-box .smaller','border-left-width','2','','','.b-quantity'),(163633,'deals-mobile','.b-quantity .qty-box .bigger','border-left-width','2','','','.b-quantity'),(163634,'deals-mobile','.b-autocomplete .ui-autocomplete li','border-left-width','1','','','.b-autocomplete'),(163635,'deals-mobile','.w-list-type-2 .button-wishlist button','border-left-width','0','','','.w-list-type-2'),(163636,'deals-mobile','.w-list-type-2 .button-wishlist','border-left-width','1','','','.w-list-type-2'),(163637,'deals-mobile','.w-list-type-1_3 .button-wishlist button','border-left-width','0','','','.w-list-type-1_3'),(163638,'deals-mobile','.w-list-type-1_3 .button-wishlist','border-left-width','1','','','.w-list-type-1_3'),(163639,'deals-mobile','.w-list-type-1_2 .button-wishlist button','border-left-width','0','','','.w-list-type-1_2'),(163640,'deals-mobile','.w-list-type-1_2 .button-wishlist','border-left-width','1','','','.w-list-type-1_2'),(163641,'deals-mobile','.b-bottom .popup-box','border-left-width','1','','','.b-bottom'),(163642,'deals-mobile','.w-list-type-1 .button-wishlist button','border-left-width','0','','','.w-list-type-1'),(163643,'deals-mobile','.w-filters .ui-slider','border-left-width','0','','','.w-filters'),(163644,'deals-mobile','.w-list-type-1 .button-wishlist','border-left-width','1','','','.w-list-type-1'),(163645,'deals-mobile','.w-filters .ui-slider-range','border-left-width','0','','','.w-filters'),(163646,'deals-mobile','.w-filters .ui-slider-handle','border-left-width','0','','','.w-filters'),(163647,'deals-mobile','.w-product-reviews .reviews-list .review','border-left-width','20','3','','.w-product-reviews'),(163648,'deals-mobile','.w-search .button-search','border-left-width','0','','','.w-search'),(163649,'deals-mobile','.w-reviews .review','border-left-width','10','3','','.w-reviews'),(163650,'deals-mobile','.b-form .required-error','border-left-width','1','','','.b-form'),(163651,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-left-width','2','','',''),(163652,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(163653,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(163654,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(163655,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(163656,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(163657,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(163658,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-left-width','1','','','.b-menu-style-2'),(163659,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-left-width','3','','','.b-menu-style-2'),(163660,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-left-width','1','','','.b-menu-style-2'),(163661,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-left-width','3','','','.b-menu-style-2'),(163662,'deals-mobile','.b-messages .content_management_attach button','border-left-width','1','','','.b-messages'),(163663,'deals-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-width','2','','','.b-messages'),(163664,'deals-mobile','.b-select-suggest .select2-container .select2-choice','border-left-width','2','','','.b-select-suggest'),(163665,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-width','1','','','.b-select-suggest'),(163666,'deals-mobile','.b-select-suggest .select2-search input','border-left-width','1','','','.b-select-suggest'),(163667,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(163668,'deals-mobile','.b-select-suggest .select2-drop','border-left-width','1','','','.b-select-suggest'),(163669,'deals-mobile','.b-select-suggest .select2-drop-active','border-left-width','1','','','.b-select-suggest'),(163670,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-width','1','','','.b-select-suggest'),(163671,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','border-left-width','0','','','.b-select-suggest'),(163672,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-left-width','1','','','.b-select-suggest'),(163673,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-width','1','','','.b-select-suggest'),(163674,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(163675,'deals-mobile','.b-trade-approval .steps-bar li ~ li a','border-left-width','1','','','.b-trade-approval'),(163676,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-width','2','','','.b-trade-approval'),(163677,'deals-mobile','.b-upload-file .upload-file-template','border-left-width','1','','','.b-upload-file'),(163678,'deals-mobile','.b-upload-file .snapshot','border-left-width','1','','','.b-upload-file'),(163679,'deals-mobile','.b-upload-files .upload-files','border-left-width','1','','','.b-upload-files'),(163680,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-left-width','1','','','.batchPr'),(163681,'deals-mobile','.batchPr .checkbox input + span','border-left-width','1','','','.batchPr'),(163682,'deals-mobile','.batchPr .checkbox input + span','border-left-width','1','','','.batchPr'),(163683,'deals-mobile','.batchPr .checkbox input:checked + span','border-left-width','1','','','.batchPr'),(163684,'deals-mobile','.batchPr .w-batch-selected-products','border-left-width','1','','','.batchPr'),(163685,'deals-mobile','.p-account-samples-history .orders-table .item','border-left-width','1','','','.p-account-samples-history'),(163686,'deals-mobile','.p-account-samples-history .orders-table .item','border-left-width','1','','','.p-account-samples-history'),(163687,'deals-mobile','.p-account-samples-history .orders-table .item','border-left-width','1','','','.p-account-samples-history'),(163688,'deals-mobile','.p-account-samples-history .orders-table .item','border-left-width','1','','','.p-account-samples-history'),(163689,'deals-mobile','.p-account-samples-history .orders-table .item','border-left-width','1','','','.p-account-samples-history'),(163690,'deals-mobile','.p-account-samples-history .orders-table .item','border-left-width','1','','','.p-account-samples-history'),(163691,'deals-mobile','.p-catalog-product .next-product','border-left-width','1','','','.p-catalog-product'),(163692,'deals-mobile','.p-catalog-product .pn-image','border-left-width','2','3','','.p-catalog-product'),(163693,'deals-mobile','.p-payer-order-confirmation .input-wrapper','border-left-width','2','','','.p-payer-order-confirmation'),(163694,'deals-mobile','.p-payer-order-pay .input-wrapper','border-left-width','2','','','.p-payer-order-pay'),(163695,'deals-mobile','.w-account-address-book .wrap','border-left-width','1','','','.w-account-address-book'),(163696,'deals-mobile','.w-account-personal-catalog .list-switcher a','border-left-width','1','2','','.w-account-personal-catalog'),(163697,'deals-mobile','.w-cart-compare .attributes-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(163698,'deals-mobile','.w-cart-compare .price-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(163699,'deals-mobile','.w-cart-compare .product-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(163700,'deals-mobile','.w-cart-compare .cart-cell > div','border-left-width','1','','','.w-cart-compare'),(163701,'deals-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-left-width','1','','','.w-catalog-compare'),(163702,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','border-left-width','1','2','','.w-catalog-compare'),(163703,'deals-mobile','.w-catalog-paging ','border-left-width','1','2','','.w-catalog-paging'),(163704,'deals-mobile','.w-catalog-paging .prev','border-left-width','1','','','.w-catalog-paging'),(163705,'deals-mobile','.w-catalog-paging .page-number','border-left-width','1','','','.w-catalog-paging'),(163706,'deals-mobile','.w-catalog-paging .next','border-left-width','1','','','.w-catalog-paging'),(163707,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-width','1','','','.w-catalog-paging'),(163708,'deals-mobile','.w-catalog-paging .next-pages','border-left-width','1','','','.w-catalog-paging'),(163709,'deals-mobile','.w-catalog-paging .prev-pages','border-left-width','1','','','.w-catalog-paging'),(163710,'deals-mobile','.w-checkout-shipping-choice label:first-child span','border-left-width','2','','','.w-checkout-shipping-choice'),(163711,'deals-mobile','.w-product-customers-activity .customers-activity','border-left-width','1','','','.w-product-customers-activity'),(163712,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-left-width','1','','','.w-promotions'),(163713,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-width','1','','','.w-promotions'),(163714,'deals-mobile','.w-promotions .promo-salemaker .discount','border-left-width','1','','','.w-promotions'),(163715,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border-left-width','1','','','.w-promotions'),(163716,'deals-mobile','.w-reviews-content .review','border-left-width','12','3','','.w-reviews-content'),(163717,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(163718,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-left-width','1','','','.w-wedding-registry-widgets-photos'),(163719,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-left-width','1','','','.w-wedding-registry-widgets-photos'),(163720,'deals-mobile','.w-sale .sale-holder','border-right-color','#ccc','','','.w-sale'),(163721,'deals-mobile','.w-product-wedding-registry-button .btn','border-right-color','#183d78','3','','.w-product-wedding-registry-button'),(163722,'deals-mobile','.w-currencies .select','border-right-color','#e0e0e0','','','.w-currencies'),(163723,'deals-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-right-color','#bdbdbd','2','','.b-product-images'),(163724,'deals-mobile','.b-pagination .pagination span','border-right-color','#e0e0e0','2','','.b-pagination'),(163725,'deals-mobile','.w-catalog-listing-look .grid','border-right-color','#e0e0e0','','','.w-catalog-listing-look'),(163726,'deals-mobile','.w-catalog-listing-look .list','border-right-color','#e0e0e0','','','.w-catalog-listing-look'),(163727,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-color','#e0e0e0','','','.b-multi-page-checkout'),(163728,'deals-mobile','textarea','border-right-color','#e0e0e0','','',''),(163729,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-color','#e0e0e0','','','.p-blog-index'),(163730,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-color','#bdbdbd','','','.b-multi-page-checkout'),(163731,'deals-mobile','.b-info-popup .info-popup div','border-right-color','#e0e0e0','','','.b-info-popup'),(163732,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-color','#092964','','','.b-multi-page-checkout'),(163733,'deals-mobile','.w-promo-code .holder','border-right-color','#e0e0e0','','','.w-promo-code'),(163734,'deals-mobile','.testimonials .review','border-right-color','transparent','3','',''),(163735,'deals-mobile','.b-pagination .pagination .prev-pages','border-right-color','#e0e0e0','','','.b-pagination'),(163736,'deals-mobile','.b-pagination .pagination .prev','border-right-color','#e0e0e0','','','.b-pagination'),(163737,'deals-mobile','.b-pagination .pagination .page-number','border-right-color','#e0e0e0','','','.b-pagination'),(163738,'deals-mobile','.b-pagination .pagination .next-pages','border-right-color','#e0e0e0','','','.b-pagination'),(163739,'deals-mobile','.b-pagination .pagination .next','border-right-color','#e0e0e0','','','.b-pagination'),(163740,'deals-mobile','.p-account-history .orders-table .item','border-right-color','#ccc','890','','.p-account-history'),(163741,'deals-mobile','.p-account-index .orders-table .item','border-right-color','#ccc','890','','.p-account-index'),(163742,'deals-mobile','.w-cart .cart-content','border-right-color','#cccccc','','','.w-cart'),(163743,'deals-mobile','.w-product-wedding-registry-button .btn','border-right-color','#183d78','4','','.w-product-wedding-registry-button'),(163744,'deals-mobile','.p-reviews-info .review-info-text','border-right-color','#fff','4','','.p-reviews-info'),(163745,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-right-color','#e0e0e0','3','','.b-form'),(163746,'deals-mobile','.b-pagination .pagination a','border-right-color','#e0e0e0','','','.b-pagination'),(163747,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-right-color','#ccc','','','.b-slick'),(163748,'deals-mobile','.w-socials > li','border-right-color','#dedede','','','.w-socials'),(163749,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-right-color','#e0e0e0','','',''),(163750,'deals-mobile','.w-currencies .currencies-title','border-right-color','#092964','','','.w-currencies'),(163751,'deals-mobile','.w-compare-box-item .checkbox:checked + span','border-right-color','#04a440','','','.w-compare-box-item'),(163752,'deals-mobile','.w-compare-box-item .checkbox + span','border-right-color','#bdbdbd','','','.w-compare-box-item'),(163753,'deals-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-color','#898989','','','.b-compare'),(163754,'deals-mobile','.w-cart-products .checkout-attention-message','border-right-color','#ee4225','','','.w-cart-products'),(163755,'deals-mobile','.b-quantity .qty-box .smaller','border-right-color','#e0e0e0','','','.b-quantity'),(163756,'deals-mobile','.b-quantity .qty-box .bigger','border-right-color','#e0e0e0','','','.b-quantity'),(163757,'deals-mobile','.w-catalog-listing-look .b2b','border-right-color','#e0e0e0','','','.w-catalog-listing-look'),(163758,'deals-mobile','.btn-3','border-right-color','#183d78','','',''),(163759,'deals-mobile','.btn','border-right-color','#183d78','','',''),(163760,'deals-mobile','.b-bottom .popup-box','border-right-color','#d9d9d9','','','.b-bottom'),(163761,'deals-mobile','.w-languages .select','border-right-color','#e0e0e0','','','.w-languages'),(163762,'deals-mobile','.w-reviews .review','border-right-color','transparent','3','','.w-reviews'),(163763,'deals-mobile','.b-form .required-error','border-right-color','#ed4224','','','.b-form'),(163764,'deals-mobile','.b-data-table table.dataTable.no-footer','border-right-color','#e0e0e0','','','.b-data-table'),(163765,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','#e0e0e0','','','.b-dropdown'),(163766,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','#e0e0e0','','','.b-dropdown'),(163767,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','#e0e0e0','','','.b-dropdown'),(163768,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','#e0e0e0','','','.b-dropdown'),(163769,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','#e0e0e0','','','.b-dropdown'),(163770,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','#e0e0e0','','','.b-dropdown'),(163771,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-right-color','#ffffff','','','.b-menu-style-2'),(163772,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-right-color','#ffffff','','','.b-menu-style-2'),(163773,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-right-color','#ffffff','','','.b-menu-style-2'),(163774,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-right-color','#ffffff','','','.b-menu-style-2'),(163775,'deals-mobile','.b-messages .content_management_attach button','border-right-color','#183d78','','','.b-messages'),(163776,'deals-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-color','#e0e0e0','','','.b-messages'),(163777,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-color','#e0e0e0','','','.b-select-suggest'),(163778,'deals-mobile','.b-select-suggest .select2-search input','border-right-color','#e0e0e0','','','.b-select-suggest'),(163779,'deals-mobile','.b-select-suggest .select2-container .select2-choice','border-right-color','#e0e0e0','','','.b-select-suggest'),(163780,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-color','#e0e0e0','','','.b-select-suggest'),(163781,'deals-mobile','.b-select-suggest .select2-drop','border-right-color','#e0e0e0','','','.b-select-suggest'),(163782,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-color','#e0e0e0','','','.b-select-suggest'),(163783,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-color','#e0e0e0','','','.b-select-suggest'),(163784,'deals-mobile','.b-select-suggest .select2-drop-active','border-right-color','#e0e0e0','','','.b-select-suggest'),(163785,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-right-color','#e0e0e0','','','.b-select-suggest'),(163786,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-color','#e0e0e0','','','.b-select-suggest'),(163787,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-color','#e0e0e0','','','.b-trade-approval'),(163788,'deals-mobile','.b-upload-file .snapshot','border-right-color','#757575','','','.b-upload-file'),(163789,'deals-mobile','.b-upload-file .upload-file-template','border-right-color','#e0e0e0','','','.b-upload-file'),(163790,'deals-mobile','.b-upload-files .upload-files','border-right-color','#e0e0e0','','','.b-upload-files'),(163791,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-right-color','#e0e0e0','','','.batchPr'),(163792,'deals-mobile','.batchPr .checkbox input + span','border-right-color','#e0e0e0','','','.batchPr'),(163793,'deals-mobile','.batchPr .checkbox input + span','border-right-color','#e0e0e0','','','.batchPr'),(163794,'deals-mobile','.batchPr .w-batch-selected-products','border-right-color','#e0e0e0','','','.batchPr'),(163795,'deals-mobile','.batchPr .checkbox input:checked + span','border-right-color','#1428a0','','','.batchPr'),(163796,'deals-mobile','.p-account-samples-history .orders-table .item','border-right-color','#e0e0e0','','','.p-account-samples-history'),(163797,'deals-mobile','.p-account-samples-history .orders-table .item','border-right-color','#e0e0e0','','','.p-account-samples-history'),(163798,'deals-mobile','.p-account-samples-history .orders-table .item','border-right-color','#e0e0e0','','','.p-account-samples-history'),(163799,'deals-mobile','.p-account-samples-history .orders-table .item','border-right-color','#e0e0e0','','','.p-account-samples-history'),(163800,'deals-mobile','.p-account-samples-history .orders-table .item','border-right-color','#e0e0e0','','','.p-account-samples-history'),(163801,'deals-mobile','.p-account-samples-history .orders-table .item','border-right-color','#e0e0e0','','','.p-account-samples-history'),(163802,'deals-mobile','.p-catalog-product .prev-product','border-right-color','#e0e0e0','','','.p-catalog-product'),(163803,'deals-mobile','.p-catalog-product .pn-image','border-right-color','#e0e0e0','3','','.p-catalog-product'),(163804,'deals-mobile','.p-payer-order-confirmation .input-wrapper','border-right-color','#e0e0e0','','','.p-payer-order-confirmation'),(163805,'deals-mobile','.p-payer-order-pay .input-wrapper','border-right-color','#e0e0e0','','','.p-payer-order-pay'),(163806,'deals-mobile','.w-account-address-book .btn-del','border-right-color','#c4c4c4','','','.w-account-address-book'),(163807,'deals-mobile','.w-account-address-book .wrap','border-right-color','#c4c4c4','','','.w-account-address-book'),(163808,'deals-mobile','.w-account-address-book .btn-edit','border-right-color','#c4c4c4','','','.w-account-address-book'),(163809,'deals-mobile','.w-account-personal-catalog .list-switcher a','border-right-color','#e0e0e0','2','','.w-account-personal-catalog'),(163810,'deals-mobile','.w-cart-compare .product-block td','border-right-color','#e0e0e0','','','.w-cart-compare'),(163811,'deals-mobile','.w-cart-compare .attributes-block td','border-right-color','#e0e0e0','','','.w-cart-compare'),(163812,'deals-mobile','.w-cart-compare .price-block td','border-right-color','#e0e0e0','','','.w-cart-compare'),(163813,'deals-mobile','.w-cart-compare .cart-cell > div','border-right-color','#e0e0e0','','','.w-cart-compare'),(163814,'deals-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-right-color','#ffffff','','','.w-catalog-compare'),(163815,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','border-right-color','#e0e0e0','2','','.w-catalog-compare'),(163816,'deals-mobile','.w-catalog-compare td:first-child','border-right-color','#e0e0e0','','','.w-catalog-compare'),(163817,'deals-mobile','.w-catalog-paging ','border-right-color','#e0e0e0','2','','.w-catalog-paging'),(163818,'deals-mobile','.w-catalog-paging .prev','border-right-color','#e0e0e0','','','.w-catalog-paging'),(163819,'deals-mobile','.w-catalog-paging .next','border-right-color','#e0e0e0','','','.w-catalog-paging'),(163820,'deals-mobile','.w-catalog-paging .next-pages','border-right-color','#e0e0e0','','','.w-catalog-paging'),(163821,'deals-mobile','.w-catalog-paging .prev-pages','border-right-color','#e0e0e0','','','.w-catalog-paging'),(163822,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-color','#e0e0e0','','','.w-catalog-paging'),(163823,'deals-mobile','.w-catalog-paging .page-number','border-right-color','#e0e0e0','','','.w-catalog-paging'),(163824,'deals-mobile','.w-checkout-shipping-choice label:last-child span','border-right-color','#183d78','','','.w-checkout-shipping-choice'),(163825,'deals-mobile','.w-product-customers-activity .customers-activity','border-right-color','#e0e0e0','','','.w-product-customers-activity'),(163826,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-right-color','#ee4225','','','.w-promotions'),(163827,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-color','#ee4225','','','.w-promotions'),(163828,'deals-mobile','.w-promotions .promo-salemaker .discount','border-right-color','#ff6716','','','.w-promotions'),(163829,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border-right-color','#ee4225','','','.w-promotions'),(163830,'deals-mobile','.w-reviews-content .review','border-right-color','transparent','3','','.w-reviews-content'),(163831,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-color','#ccc','','','.w-upload-customer-id-upload-customer-id-form'),(163832,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-right-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(163833,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-right-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(163834,'deals-mobile','.b-data-table table.dataTable.no-footer','border-right-color_important','important','','','.b-data-table'),(163835,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(163836,'deals-mobile','.w-sale .sale-holder','border-right-width','2','','','.w-sale'),(163837,'deals-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','border-right-width','2','','','.b-product-images'),(163838,'deals-mobile','.w-product-wedding-registry-button .btn','border-right-width','2','3','','.w-product-wedding-registry-button'),(163839,'deals-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-right-width','2','2','','.b-product-images'),(163840,'deals-mobile','.w-currencies .select','border-right-width','1','','','.w-currencies'),(163841,'deals-mobile','.w-catalog-listing-look .b2b','border-right-width','1','','','.w-catalog-listing-look'),(163842,'deals-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-width','1','','','.b-compare'),(163843,'deals-mobile','.w-catalog-listing-look .list','border-right-width','1','','','.w-catalog-listing-look'),(163844,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-width','1','','','.b-multi-page-checkout'),(163845,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-width','2','','','.p-blog-index'),(163846,'deals-mobile','textarea','border-right-width','2','','',''),(163847,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(163848,'deals-mobile','.b-info-popup .info-popup div','border-right-width','1','','','.b-info-popup'),(163849,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(163850,'deals-mobile','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(163851,'deals-mobile','.testimonials .review','border-right-width','10','3','',''),(163852,'deals-mobile','.b-pagination .pagination .prev-pages','border-right-width','1','','','.b-pagination'),(163853,'deals-mobile','.b-pagination .pagination .prev','border-right-width','1','','','.b-pagination'),(163854,'deals-mobile','.p-wedding-registry-manage .wr-search button','border-right-width','0','','','.p-wedding-registry-manage'),(163855,'deals-mobile','.b-pagination .pagination .page-number','border-right-width','1','','','.b-pagination'),(163856,'deals-mobile','.b-pagination .pagination .next-pages','border-right-width','1','','','.b-pagination'),(163857,'deals-mobile','.b-pagination .pagination .next','border-right-width','1','','','.b-pagination'),(163858,'deals-mobile','.b-pagination .pagination span','border-right-width','1','2','','.b-pagination'),(163859,'deals-mobile','.p-account-history .orders-table .item','border-right-width','1','890','','.p-account-history'),(163860,'deals-mobile','.p-account-index .orders-table .item','border-right-width','1','890','','.p-account-index'),(163861,'deals-mobile','.w-cart .cart-content','border-right-width','1','','','.w-cart'),(163862,'deals-mobile','.w-list-type-2_2 .button-wishlist button','border-right-width','0','','','.w-list-type-2_2'),(163863,'deals-mobile','.w-product-wedding-registry-button .btn','border-right-width','2','4','','.w-product-wedding-registry-button'),(163864,'deals-mobile','.p-reviews-info .review-info-text','border-right-width','5','4','','.p-reviews-info'),(163865,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-right-width','2','3','','.b-form'),(163866,'deals-mobile','.b-pagination .pagination a','border-right-width','1','','','.b-pagination'),(163867,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-right-width','2','','','.b-slick'),(163868,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-right-width','2','','',''),(163869,'deals-mobile','.w-search .search-input','border-right-width','0','','','.w-search'),(163870,'deals-mobile','.w-currencies .currencies-title','border-right-width','2','','','.w-currencies'),(163871,'deals-mobile','.w-compare-box-item .checkbox:checked + span','border-right-width','1','','','.w-compare-box-item'),(163872,'deals-mobile','.w-compare-box-item .checkbox + span','border-right-width','1','','','.w-compare-box-item'),(163873,'deals-mobile','.b-slick .slick-vertical .slick-slide','border-right-width','1','','','.b-slick'),(163874,'deals-mobile','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(163875,'deals-mobile','.b-quantity .qty-box .bigger','border-right-width','2','','','.b-quantity'),(163876,'deals-mobile','.b-quantity .qty-box .smaller','border-right-width','2','','','.b-quantity'),(163877,'deals-mobile','.w-catalog-listing-look .grid','border-right-width','1','','','.w-catalog-listing-look'),(163878,'deals-mobile','.w-list-type-2 .button-wishlist button','border-right-width','0','','','.w-list-type-2'),(163879,'deals-mobile','.btn-3','border-right-width','2','','',''),(163880,'deals-mobile','.b-autocomplete .ui-autocomplete li','border-right-width','1','','','.b-autocomplete'),(163881,'deals-mobile','.btn','border-right-width','2','','',''),(163882,'deals-mobile','.w-list-type-1_3 .button-wishlist button','border-right-width','0','','','.w-list-type-1_3'),(163883,'deals-mobile','.w-list-type-1_2 .button-wishlist button','border-right-width','0','','','.w-list-type-1_2'),(163884,'deals-mobile','.b-bottom .popup-box','border-right-width','1','','','.b-bottom'),(163885,'deals-mobile','.w-list-type-1 .button-wishlist button','border-right-width','0','','','.w-list-type-1'),(163886,'deals-mobile','.w-filters .ui-slider','border-right-width','0','','','.w-filters'),(163887,'deals-mobile','.w-filters .ui-slider-handle','border-right-width','0','','','.w-filters'),(163888,'deals-mobile','.w-filters .ui-slider-range','border-right-width','0','','','.w-filters'),(163889,'deals-mobile','.w-languages .select','border-right-width','1','','','.w-languages'),(163890,'deals-mobile','.w-reviews .review','border-right-width','10','3','','.w-reviews'),(163891,'deals-mobile','.w-search .button-search','border-right-width','0','','','.w-search'),(163892,'deals-mobile','.w-socials > li','border-right-width','1','','','.w-socials'),(163893,'deals-mobile','.b-form .required-error','border-right-width','1','','','.b-form'),(163894,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(163895,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(163896,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(163897,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(163898,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(163899,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(163900,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-right-width','1','','','.b-menu-style-2'),(163901,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-right-width','3','','','.b-menu-style-2'),(163902,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-right-width','1','','','.b-menu-style-2'),(163903,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-right-width','3','','','.b-menu-style-2'),(163904,'deals-mobile','.b-messages .content_management_attach button','border-right-width','1','','','.b-messages'),(163905,'deals-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-width','2','','','.b-messages'),(163906,'deals-mobile','.b-select-suggest .select2-container .select2-choice','border-right-width','2','','','.b-select-suggest'),(163907,'deals-mobile','.b-select-suggest .select2-search input','border-right-width','1','','','.b-select-suggest'),(163908,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-width','1','','','.b-select-suggest'),(163909,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(163910,'deals-mobile','.b-select-suggest .select2-drop-active','border-right-width','1','','','.b-select-suggest'),(163911,'deals-mobile','.b-select-suggest .select2-drop','border-right-width','1','','','.b-select-suggest'),(163912,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-right-width','1','','','.b-select-suggest'),(163913,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-width','1','','','.b-select-suggest'),(163914,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-width','1','','','.b-select-suggest'),(163915,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(163916,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-width','2','','','.b-trade-approval'),(163917,'deals-mobile','.b-upload-file .snapshot','border-right-width','1','','','.b-upload-file'),(163918,'deals-mobile','.b-upload-file .upload-file-template','border-right-width','1','','','.b-upload-file'),(163919,'deals-mobile','.b-upload-files .upload-files','border-right-width','1','','','.b-upload-files'),(163920,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-right-width','1','','','.batchPr'),(163921,'deals-mobile','.batchPr .checkbox input + span','border-right-width','1','','','.batchPr'),(163922,'deals-mobile','.batchPr .checkbox input + span','border-right-width','1','','','.batchPr'),(163923,'deals-mobile','.batchPr .checkbox input:checked + span','border-right-width','1','','','.batchPr'),(163924,'deals-mobile','.batchPr .w-batch-selected-products','border-right-width','1','','','.batchPr'),(163925,'deals-mobile','.p-account-samples-history .orders-table .item','border-right-width','1','','','.p-account-samples-history'),(163926,'deals-mobile','.p-account-samples-history .orders-table .item','border-right-width','1','','','.p-account-samples-history'),(163927,'deals-mobile','.p-account-samples-history .orders-table .item','border-right-width','1','','','.p-account-samples-history'),(163928,'deals-mobile','.p-account-samples-history .orders-table .item','border-right-width','1','','','.p-account-samples-history'),(163929,'deals-mobile','.p-account-samples-history .orders-table .item','border-right-width','1','','','.p-account-samples-history'),(163930,'deals-mobile','.p-account-samples-history .orders-table .item','border-right-width','1','','','.p-account-samples-history'),(163931,'deals-mobile','.p-catalog-product .prev-product','border-right-width','1','','','.p-catalog-product'),(163932,'deals-mobile','.p-catalog-product .pn-image','border-right-width','2','3','','.p-catalog-product'),(163933,'deals-mobile','.p-payer-order-confirmation .input-wrapper','border-right-width','2','','','.p-payer-order-confirmation'),(163934,'deals-mobile','.p-payer-order-pay .input-wrapper','border-right-width','2','','','.p-payer-order-pay'),(163935,'deals-mobile','.w-account-address-book .wrap','border-right-width','1','','','.w-account-address-book'),(163936,'deals-mobile','.w-account-address-book .btn-edit','border-right-width','1','','','.w-account-address-book'),(163937,'deals-mobile','.w-account-address-book .btn-del','border-right-width','1','','','.w-account-address-book'),(163938,'deals-mobile','.w-account-personal-catalog .list-switcher a','border-right-width','1','2','','.w-account-personal-catalog'),(163939,'deals-mobile','.w-cart-compare .attributes-block td','border-right-width','1','','','.w-cart-compare'),(163940,'deals-mobile','.w-cart-compare .cart-cell > div','border-right-width','1','','','.w-cart-compare'),(163941,'deals-mobile','.w-cart-compare .product-block td','border-right-width','1','','','.w-cart-compare'),(163942,'deals-mobile','.w-cart-compare .price-block td','border-right-width','1','','','.w-cart-compare'),(163943,'deals-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-right-width','1','','','.w-catalog-compare'),(163944,'deals-mobile','.w-catalog-compare td:first-child','border-right-width','1','','','.w-catalog-compare'),(163945,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','border-right-width','1','2','','.w-catalog-compare'),(163946,'deals-mobile','.w-catalog-paging ','border-right-width','1','2','','.w-catalog-paging'),(163947,'deals-mobile','.w-catalog-paging .prev','border-right-width','1','','','.w-catalog-paging'),(163948,'deals-mobile','.w-catalog-paging .page-number','border-right-width','1','','','.w-catalog-paging'),(163949,'deals-mobile','.w-catalog-paging .next','border-right-width','1','','','.w-catalog-paging'),(163950,'deals-mobile','.w-catalog-paging .next-pages','border-right-width','1','','','.w-catalog-paging'),(163951,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-width','1','','','.w-catalog-paging'),(163952,'deals-mobile','.w-catalog-paging .prev-pages','border-right-width','1','','','.w-catalog-paging'),(163953,'deals-mobile','.w-checkout-shipping-choice label:last-child span','border-right-width','2','','','.w-checkout-shipping-choice'),(163954,'deals-mobile','.w-product-customers-activity .customers-activity','border-right-width','1','','','.w-product-customers-activity'),(163955,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-right-width','1','','','.w-promotions'),(163956,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-width','1','','','.w-promotions'),(163957,'deals-mobile','.w-promotions .promo-salemaker .discount','border-right-width','1','','','.w-promotions'),(163958,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border-right-width','1','','','.w-promotions'),(163959,'deals-mobile','.w-reviews-content .review','border-right-width','12','3','','.w-reviews-content'),(163960,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(163961,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-right-width','1','','','.w-wedding-registry-widgets-photos'),(163962,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-right-width','1','','','.w-wedding-registry-widgets-photos'),(163963,'deals-mobile','.p-account-history .orders-table','border-top','none','','','.p-account-history'),(163964,'deals-mobile','.p-checkout-index .shipping-estimator .info','border-top','none','','','.p-checkout-index'),(163965,'deals-mobile','.p-account-index .orders-table','border-top','none','','','.p-account-index'),(163966,'deals-mobile','.b-select-suggest .select2-drop-active','border-top','none','','','.b-select-suggest'),(163967,'deals-mobile','.p-account-samples-history .orders-table','border-top','none','','','.p-account-samples-history'),(163968,'deals-mobile','.p-account-samples-history .orders-table','border-top','none','','','.p-account-samples-history'),(163969,'deals-mobile','.p-account-samples-history .orders-table','border-top','none','','','.p-account-samples-history'),(163970,'deals-mobile','.p-account-samples-history .orders-table','border-top','none','','','.p-account-samples-history'),(163971,'deals-mobile','.p-account-samples-history .orders-table','border-top','none','','','.p-account-samples-history'),(163972,'deals-mobile','.p-account-samples-history .orders-table','border-top','none','','','.p-account-samples-history'),(163973,'deals-mobile','.w-catalog-listing-look .list','border-top-color','#e0e0e0','','','.w-catalog-listing-look'),(163974,'deals-mobile','.b-social-login .social-login-text-2','border-top-color','#ddd','4','','.b-social-login'),(163975,'deals-mobile','.b-social-login .social-login-text-2','border-top-color','#ddd','3','','.b-social-login'),(163976,'deals-mobile','.w-sale .sale-holder','border-top-color','#ccc','','','.w-sale'),(163977,'deals-mobile','.w-menu-slider > ul > li > ul','border-top-color','#ffffff','','','.w-menu-slider'),(163978,'deals-mobile','.w-product-wedding-registry-button .btn','border-top-color','#183d78','3','','.w-product-wedding-registry-button'),(163979,'deals-mobile','.w-product-sale-ends .left-text-left','border-top-color','#ccc','','','.w-product-sale-ends'),(163980,'deals-mobile','.w-product-sale-ends .left-text-right','border-top-color','#ccc','','','.w-product-sale-ends'),(163981,'deals-mobile','.w-cart-products .checkout-attention-message','border-top-color','#ee4225','','','.w-cart-products'),(163982,'deals-mobile','.w-cart .cart-content','border-top-color','#cccccc','','','.w-cart'),(163983,'deals-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-top-color','#bdbdbd','2','','.b-product-images'),(163984,'deals-mobile','.b-pagination .pagination span','border-top-color','#e0e0e0','2','','.b-pagination'),(163985,'deals-mobile','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-color','#e0e0e0','','','.w-product-in-bundles'),(163986,'deals-mobile','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-color','#e0e0e0','','','.w-product-bundle'),(163987,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-color','#e0e0e0','','','.b-multi-page-checkout'),(163988,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-color','#e0e0e0','','','.p-blog-index'),(163989,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-color','#bdbdbd','','','.b-multi-page-checkout'),(163990,'deals-mobile','.btn-3','border-top-color','#183d78','','',''),(163991,'deals-mobile','.btn','border-top-color','#183d78','','',''),(163992,'deals-mobile','.b-info-popup .info-popup div','border-top-color','#e0e0e0','','','.b-info-popup'),(163993,'deals-mobile','.w-menu .hided.menu ul li','border-top-color','#0a204a','890','','.w-menu'),(163994,'deals-mobile','.b-info-popup .info-popup div','border-top-color','#e0e0e0','3','','.b-info-popup'),(163995,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-color','#092964','','','.b-multi-page-checkout'),(163996,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','border-top-color','#e0e0e0','','','.b-multi-page-checkout'),(163997,'deals-mobile','.view-all','border-top-color','#e0e0e0','3','',''),(163998,'deals-mobile','.p-wedding-registry-manage .remove','border-top-color','#e0e0e0','','','.p-wedding-registry-manage'),(163999,'deals-mobile','.w-promo-code .holder','border-top-color','#e0e0e0','','','.w-promo-code'),(164000,'deals-mobile','.testimonials .review','border-top-color','#eeeeee','3','',''),(164001,'deals-mobile','.b-pagination .pagination .page-number','border-top-color','#e0e0e0','','','.b-pagination'),(164002,'deals-mobile','.b-pagination .pagination .prev-pages','border-top-color','#e0e0e0','','','.b-pagination'),(164003,'deals-mobile','.b-pagination .pagination .prev','border-top-color','#e0e0e0','','','.b-pagination'),(164004,'deals-mobile','.b-pagination .pagination .next-pages','border-top-color','#e0e0e0','','','.b-pagination'),(164005,'deals-mobile','.b-pagination .pagination .next','border-top-color','#e0e0e0','','','.b-pagination'),(164006,'deals-mobile','.p-account-history .orders-table .item','border-top-color','#ccc','890','','.p-account-history'),(164007,'deals-mobile','.p-account-history .orders-table .td-alignright','border-top-color','#ccc','890','','.p-account-history'),(164008,'deals-mobile','.p-account-index .orders-table .item','border-top-color','#ccc','890','','.p-account-index'),(164009,'deals-mobile','.p-account-index .orders-table .td-alignright','border-top-color','#ccc','890','','.p-account-index'),(164010,'deals-mobile','.w-list-type-2_2 .compare-box-item','border-top-color','#e0e0e0','','','.w-list-type-2_2'),(164011,'deals-mobile','.w-list-type-2_2 .buttons','border-top-color','#e0e0e0','','','.w-list-type-2_2'),(164012,'deals-mobile','.w-product-wedding-registry-button .btn','border-top-color','#183d78','4','','.w-product-wedding-registry-button'),(164013,'deals-mobile','.p-reviews-info .review-info-text','border-top-color','#fff','4','','.p-reviews-info'),(164014,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-color','#e0e0e0','3','','.b-form'),(164015,'deals-mobile','.b-form .form-buttons','border-top-color','#e0e0e0','','','.b-form'),(164016,'deals-mobile','.p-wedding-registry-index .search-list','border-top-color','#e0e0e0','3','','.p-wedding-registry-index'),(164017,'deals-mobile','.b-table .table .headings + tr ~ tr td','border-top-color','#e0e0e0','','','.b-table'),(164018,'deals-mobile','.b-pagination .pagination a','border-top-color','#e0e0e0','','','.b-pagination'),(164019,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-color','#ccc','','','.b-slick'),(164020,'deals-mobile','.w-languages .select','border-top-color','#e0e0e0','','','.w-languages'),(164021,'deals-mobile','.w-socials > li','border-top-color','#dedede','','','.w-socials'),(164022,'deals-mobile','.p-checkout-index .shipping-method .item + .item','border-top-color','#e0e0e0','','','.p-checkout-index'),(164023,'deals-mobile','.w-currencies .select','border-top-color','#e0e0e0','','','.w-currencies'),(164024,'deals-mobile','.b-bottom .popup-buttons','border-top-color','#d9d9d9','','','.b-bottom'),(164025,'deals-mobile','.w-currencies .currencies-title','border-top-color','#092964','','','.w-currencies'),(164026,'deals-mobile','.w-compare-box-item .checkbox:checked + span','border-top-color','#04a440','','','.w-compare-box-item'),(164027,'deals-mobile','.w-compare-box-item .checkbox + span','border-top-color','#bdbdbd','','','.w-compare-box-item'),(164028,'deals-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-color','#898989','','','.b-compare'),(164029,'deals-mobile','.w-sale .left-text-left','border-top-color','#ccc','','','.w-sale'),(164030,'deals-mobile','.w-sale .left-text-right','border-top-color','#ccc','','','.w-sale'),(164031,'deals-mobile','.b-quantity .qty-box .smaller','border-top-color','#e0e0e0','','','.b-quantity'),(164032,'deals-mobile','.b-quantity .qty-box .bigger','border-top-color','#e0e0e0','','','.b-quantity'),(164033,'deals-mobile','.w-catalog-listing-look .b2b','border-top-color','#e0e0e0','','','.w-catalog-listing-look'),(164034,'deals-mobile','.w-catalog-listing-look .grid','border-top-color','#e0e0e0','','','.w-catalog-listing-look'),(164035,'deals-mobile','.w-list-type-2 .buttons','border-top-color','#e0e0e0','','','.w-list-type-2'),(164036,'deals-mobile','.w-list-type-2 .compare-box-item','border-top-color','#e0e0e0','','','.w-list-type-2'),(164037,'deals-mobile','.w-list-type-2 .item','border-top-color','#e0e0e0','1','','.w-list-type-2'),(164038,'deals-mobile','.w-list-type-1_3 .compare-box-item','border-top-color','#e0e0e0','','','.w-list-type-1_3'),(164039,'deals-mobile','.w-list-type-1_3 .buttons','border-top-color','#e0e0e0','','','.w-list-type-1_3'),(164040,'deals-mobile','.w-list-type-1_2 .buttons','border-top-color','#e0e0e0','','','.w-list-type-1_2'),(164041,'deals-mobile','.w-list-type-1_2 .compare-box-item','border-top-color','#e0e0e0','','','.w-list-type-1_2'),(164042,'deals-mobile','.w-list-type-1 .compare-box-item','border-top-color','#e0e0e0','','','.w-list-type-1'),(164043,'deals-mobile','.b-bottom .popup-box','border-top-color','#d9d9d9','','','.b-bottom'),(164044,'deals-mobile','.w-list-type-1 .buttons','border-top-color','#e0e0e0','','','.w-list-type-1'),(164045,'deals-mobile','.w-reviews .review','border-top-color','#fff','3','','.w-reviews'),(164046,'deals-mobile','.w-search .item + .item','border-top-color','#cccccc','','','.w-search'),(164047,'deals-mobile','.b-form .required-error','border-top-color','#ed4224','','','.b-form'),(164048,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-top-color','#e0e0e0','','',''),(164049,'deals-mobile','textarea','border-top-color','#e0e0e0','','',''),(164050,'deals-mobile','.b-info div + .info','border-top-color','#e0e0e0','','','.b-info'),(164051,'deals-mobile','.b-products-listing .products-listing .compare','border-top-color','#e0e0e0','','','.b-products-listing'),(164052,'deals-mobile','.b-data-table table.dataTable tbody td','border-top-color','#e0e0e0','','','.b-data-table'),(164053,'deals-mobile','.b-data-table table.dataTable.no-footer','border-top-color','#e0e0e0','','','.b-data-table'),(164054,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','#e0e0e0','','','.b-dropdown'),(164055,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','#e0e0e0','','','.b-dropdown'),(164056,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','#e0e0e0','','','.b-dropdown'),(164057,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','#e0e0e0','','','.b-dropdown'),(164058,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','#e0e0e0','','','.b-dropdown'),(164059,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','#e0e0e0','','','.b-dropdown'),(164060,'deals-mobile','.b-email .qty','border-top-color','#e0e0e0','','','.b-email'),(164061,'deals-mobile','.b-email .name','border-top-color','#e0e0e0','','','.b-email'),(164062,'deals-mobile','.b-email .totals-table','border-top-color','#e0e0e0','','','.b-email'),(164063,'deals-mobile','.b-email .price','border-top-color','#e0e0e0','','','.b-email'),(164064,'deals-mobile','.b-email .image','border-top-color','#e0e0e0','','','.b-email'),(164065,'deals-mobile','.b-email .totals-table','border-top-color','#e0e0e0','','','.b-email'),(164066,'deals-mobile','.b-email .image','border-top-color','#e0e0e0','','','.b-email'),(164067,'deals-mobile','.b-email .price','border-top-color','#e0e0e0','','','.b-email'),(164068,'deals-mobile','.b-email .model','border-top-color','#e0e0e0','','','.b-email'),(164069,'deals-mobile','.b-email .name','border-top-color','#e0e0e0','','','.b-email'),(164070,'deals-mobile','.b-email .image','border-top-color','#e0e0e0','','','.b-email'),(164071,'deals-mobile','.b-email .model','border-top-color','#e0e0e0','','','.b-email'),(164072,'deals-mobile','.b-email .image','border-top-color','#e0e0e0','','','.b-email'),(164073,'deals-mobile','.b-email .price','border-top-color','#e0e0e0','','','.b-email'),(164074,'deals-mobile','.b-email .price','border-top-color','#e0e0e0','','','.b-email'),(164075,'deals-mobile','.b-email .qty','border-top-color','#e0e0e0','','','.b-email'),(164076,'deals-mobile','.b-email .model','border-top-color','#e0e0e0','','','.b-email'),(164077,'deals-mobile','.b-email .name','border-top-color','#e0e0e0','','','.b-email'),(164078,'deals-mobile','.b-email .totals-table','border-top-color','#e0e0e0','','','.b-email'),(164079,'deals-mobile','.b-email .price','border-top-color','#e0e0e0','','','.b-email'),(164080,'deals-mobile','.b-email .name','border-top-color','#e0e0e0','','','.b-email'),(164081,'deals-mobile','.b-email .qty','border-top-color','#e0e0e0','','','.b-email'),(164082,'deals-mobile','.b-email .totals-table','border-top-color','#e0e0e0','','','.b-email'),(164083,'deals-mobile','.b-email .image','border-top-color','#e0e0e0','','','.b-email'),(164084,'deals-mobile','.b-email .name','border-top-color','#e0e0e0','','','.b-email'),(164085,'deals-mobile','.b-email .totals-table','border-top-color','#e0e0e0','','','.b-email'),(164086,'deals-mobile','.b-email .qty','border-top-color','#e0e0e0','','','.b-email'),(164087,'deals-mobile','.b-email .qty','border-top-color','#e0e0e0','','','.b-email'),(164088,'deals-mobile','.b-email .model','border-top-color','#e0e0e0','','','.b-email'),(164089,'deals-mobile','.b-email .name','border-top-color','#e0e0e0','','','.b-email'),(164090,'deals-mobile','.b-email .qty','border-top-color','#e0e0e0','','','.b-email'),(164091,'deals-mobile','.b-email .model','border-top-color','#e0e0e0','','','.b-email'),(164092,'deals-mobile','.b-email .price','border-top-color','#e0e0e0','','','.b-email'),(164093,'deals-mobile','.b-email .totals-table','border-top-color','#e0e0e0','','','.b-email'),(164094,'deals-mobile','.b-email .image','border-top-color','#e0e0e0','','','.b-email'),(164095,'deals-mobile','.b-email .model','border-top-color','#e0e0e0','','','.b-email'),(164096,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-top-color','#ffffff','','','.b-menu-style-2'),(164097,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-top-color','#ffffff','','','.b-menu-style-2'),(164098,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','border-top-color','#1a61ad','','','.b-menu-style-2'),(164099,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-top-color','#ffffff','','','.b-menu-style-2'),(164100,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-top-color','#ffffff','','','.b-menu-style-2'),(164101,'deals-mobile','.b-messages .messMenuButtonTop','border-top-color','#e0e0e0','','','.b-messages'),(164102,'deals-mobile','.b-messages .msv_btn','border-top-color','#e0e0e0','','','.b-messages'),(164103,'deals-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-color','#e0e0e0','','','.b-messages'),(164104,'deals-mobile','.b-messages .email-heading','border-top-color','#e0e0e0','','','.b-messages'),(164105,'deals-mobile','.b-messages .dataTable','border-top-color','#e0e0e0','','','.b-messages'),(164106,'deals-mobile','.b-messages .messages-menu li + li','border-top-color','#e0e0e0','','','.b-messages'),(164107,'deals-mobile','.b-messages .content_management_attach button','border-top-color','#183d78','','','.b-messages'),(164108,'deals-mobile','.b-messages .content_management_attach','border-top-color','#e0e0e0','','','.b-messages'),(164109,'deals-mobile','.b-select-suggest .select2-container .select2-choice','border-top-color','#e0e0e0','','','.b-select-suggest'),(164110,'deals-mobile','.b-select-suggest .select2-search input','border-top-color','#e0e0e0','','','.b-select-suggest'),(164111,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-color','#e0e0e0','','','.b-select-suggest'),(164112,'deals-mobile','.b-select-suggest .select2-drop-auto-width','border-top-color','#e0e0e0','','','.b-select-suggest'),(164113,'deals-mobile','.b-select-suggest .select2-drop','border-top-color','#e0e0e0','','','.b-select-suggest'),(164114,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-top-color','#e0e0e0','','','.b-select-suggest'),(164115,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-color','#e0e0e0','','','.b-select-suggest'),(164116,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-color','#e0e0e0','','','.b-select-suggest'),(164117,'deals-mobile','.b-select-suggest .select2-drop-active','border-top-color','#e0e0e0','','','.b-select-suggest'),(164118,'deals-mobile','.b-select-suggest .select2-drop.select2-drop-above','border-top-color','#e0e0e0','','','.b-select-suggest'),(164119,'deals-mobile','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-color','#e0e0e0','','','.b-select-suggest'),(164120,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-color','#e0e0e0','','','.b-select-suggest'),(164121,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-color','#e0e0e0','','','.b-select-suggest'),(164122,'deals-mobile','.b-table-list .table-list td','border-top-color','#e0e0e0','','','.b-table-list'),(164123,'deals-mobile','.b-table-list .table-list td','border-top-color','#e0e0e0','','','.b-table-list'),(164124,'deals-mobile','.b-table-list .table-list td','border-top-color','#e0e0e0','','','.b-table-list'),(164125,'deals-mobile','.b-table-list .table-list td','border-top-color','#e0e0e0','','','.b-table-list'),(164126,'deals-mobile','.b-table-list .table-list td','border-top-color','#e0e0e0','','','.b-table-list'),(164127,'deals-mobile','.b-table-list .table-list td','border-top-color','#e0e0e0','','','.b-table-list'),(164128,'deals-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','#e0e0e0','','','.b-tracking-numbers'),(164129,'deals-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','#e0e0e0','','','.b-tracking-numbers'),(164130,'deals-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','#e0e0e0','','','.b-tracking-numbers'),(164131,'deals-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','#e0e0e0','','','.b-tracking-numbers'),(164132,'deals-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','#e0e0e0','','','.b-tracking-numbers'),(164133,'deals-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','#e0e0e0','','','.b-tracking-numbers'),(164134,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-color','#e0e0e0','','','.b-trade-approval'),(164135,'deals-mobile','.b-upload-file .upload-file-template','border-top-color','#e0e0e0','','','.b-upload-file'),(164136,'deals-mobile','.b-upload-file .snapshot','border-top-color','#757575','','','.b-upload-file'),(164137,'deals-mobile','.b-upload-files .upload-files','border-top-color','#e0e0e0','','','.b-upload-files'),(164138,'deals-mobile','.b-upload-files .added-file','border-top-color','#e0e0e0','','','.b-upload-files'),(164139,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-color','#e0e0e0','','','.batchPr'),(164140,'deals-mobile','.batchPr .checkbox input + span','border-top-color','#e0e0e0','','','.batchPr'),(164141,'deals-mobile','.batchPr .checkbox input + span','border-top-color','#e0e0e0','','','.batchPr'),(164142,'deals-mobile','.batchPr .checkbox input:checked + span','border-top-color','#1428a0','','','.batchPr'),(164143,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .item + .item','border-top-color','#e0e0e0','','','.batchPr'),(164144,'deals-mobile','.batchPr .w-batch-selected-products','border-top-color','#e0e0e0','','','.batchPr'),(164145,'deals-mobile','.p-account-samples-history .orders-table .item','border-top-color','#e0e0e0','','','.p-account-samples-history'),(164146,'deals-mobile','.p-account-samples-history .orders-table .item','border-top-color','#e0e0e0','','','.p-account-samples-history'),(164147,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-color','#e0e0e0','','','.p-account-samples-history'),(164148,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-color','#e0e0e0','','','.p-account-samples-history'),(164149,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-color','#e0e0e0','','','.p-account-samples-history'),(164150,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-color','#e0e0e0','','','.p-account-samples-history'),(164151,'deals-mobile','.p-account-samples-history .orders-table .item','border-top-color','#e0e0e0','','','.p-account-samples-history'),(164152,'deals-mobile','.p-account-samples-history .orders-table .item','border-top-color','#e0e0e0','','','.p-account-samples-history'),(164153,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-color','#e0e0e0','','','.p-account-samples-history'),(164154,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-color','#e0e0e0','','','.p-account-samples-history'),(164155,'deals-mobile','.p-account-samples-history .orders-table .item','border-top-color','#e0e0e0','','','.p-account-samples-history'),(164156,'deals-mobile','.p-account-samples-history .orders-table .item','border-top-color','#e0e0e0','','','.p-account-samples-history'),(164157,'deals-mobile','.p-catalog-product .prev-next-product','border-top-color','#e0e0e0','','','.p-catalog-product'),(164158,'deals-mobile','.p-catalog-product .pn-image','border-top-color','#e0e0e0','','','.p-catalog-product'),(164159,'deals-mobile','.p-catalog-product .pn-name','border-top-color','#e0e0e0','','','.p-catalog-product'),(164160,'deals-mobile','.p-catalog-product .pn-image','border-top-color','#e0e0e0','3','','.p-catalog-product'),(164161,'deals-mobile','.p-payer-order-confirmation .input-wrapper','border-top-color','#e0e0e0','','','.p-payer-order-confirmation'),(164162,'deals-mobile','.p-payer-order-pay .input-wrapper','border-top-color','#e0e0e0','','','.p-payer-order-pay'),(164163,'deals-mobile','.w-account-address-book .wrap','border-top-color','#c4c4c4','','','.w-account-address-book'),(164164,'deals-mobile','.w-account-personal-catalog .list-switcher a','border-top-color','#183d78','2','','.w-account-personal-catalog'),(164165,'deals-mobile','.w-account-subscription .subscription-variant + .subscription-variant','border-top-color','#ccc','','','.w-account-subscription'),(164166,'deals-mobile','.w-cart-compare .attributes-block td','border-top-color','#e0e0e0','','','.w-cart-compare'),(164167,'deals-mobile','.w-cart-compare .price-block td','border-top-color','#e0e0e0','','','.w-cart-compare'),(164168,'deals-mobile','.w-cart-compare .product-block td','border-top-color','#e0e0e0','','','.w-cart-compare'),(164169,'deals-mobile','.w-cart-compare .cart-cell > div','border-top-color','#e0e0e0','','','.w-cart-compare'),(164170,'deals-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-top-color','#ffffff','','','.w-catalog-compare'),(164171,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','border-top-color','#183d78','2','','.w-catalog-compare'),(164172,'deals-mobile','.w-catalog-paging ','border-top-color','#e0e0e0','2','','.w-catalog-paging'),(164173,'deals-mobile','.w-catalog-paging .prev','border-top-color','#e0e0e0','','','.w-catalog-paging'),(164174,'deals-mobile','.w-catalog-paging .next','border-top-color','#e0e0e0','','','.w-catalog-paging'),(164175,'deals-mobile','.w-catalog-paging .page-number','border-top-color','#e0e0e0','','','.w-catalog-paging'),(164176,'deals-mobile','.w-catalog-paging .next-pages','border-top-color','#e0e0e0','','','.w-catalog-paging'),(164177,'deals-mobile','.w-catalog-paging .prev-pages','border-top-color','#e0e0e0','','','.w-catalog-paging'),(164178,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-color','#e0e0e0','','','.w-catalog-paging'),(164179,'deals-mobile','.w-checkout-shipping .sub-item + .sub-item','border-top-color','#e0e0e0','','','.w-checkout-shipping'),(164180,'deals-mobile','.w-checkout-shipping-choice span','border-top-color','#183d78','','','.w-checkout-shipping-choice'),(164181,'deals-mobile','.w-communication-new-topic td','border-top-color','#e0e0e0','','','.w-communication-new-topic'),(164182,'deals-mobile','.w-communication-post .communication-post','border-top-color','#e0e0e0','','','.w-communication-post'),(164183,'deals-mobile','.w-delivery-day .left-text-left','border-top-color','#e0e0e0','','','.w-delivery-day'),(164184,'deals-mobile','.w-delivery-day .left-text-right','border-top-color','#e0e0e0','','','.w-delivery-day'),(164185,'deals-mobile','.w-product-customers-activity .customers-activity','border-top-color','#e0e0e0','','','.w-product-customers-activity'),(164186,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-color','#ee4225','','','.w-promotions'),(164187,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-color','#ee4225','','','.w-promotions'),(164188,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-color','#ee4225','','','.w-promotions'),(164189,'deals-mobile','.w-promotions .promo-salemaker .discount','border-top-color','#ff6716','','','.w-promotions'),(164190,'deals-mobile','.w-reviews-content .review','border-top-color','transparent','3','','.w-reviews-content'),(164191,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-color','#ccc','','','.w-upload-customer-id-upload-customer-id-form'),(164192,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-top-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(164193,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-top-color','#e0e0e0','','','.w-wedding-registry-widgets-photos'),(164194,'deals-mobile','.w-wedding-registry-widgets-products .rating','border-top-color','#e0e0e0','','','.w-wedding-registry-widgets-products'),(164195,'deals-mobile','.b-data-table table.dataTable.no-footer','border-top-color_important','important','','','.b-data-table'),(164196,'deals-mobile','.w-sale .left-count-days','border-top-left-radius','3','','','.w-sale'),(164197,'deals-mobile','.w-sale .badge','border-top-left-radius','50','','','.w-sale'),(164198,'deals-mobile','.w-product-wedding-registry-button .btn','border-top-left-radius','50','3','','.w-product-wedding-registry-button'),(164199,'deals-mobile','.w-product-sale-ends .left-count-days','border-top-left-radius','3','','','.w-product-sale-ends'),(164200,'deals-mobile','.w-product-sale-ends .left-count','border-top-left-radius','3','','','.w-product-sale-ends'),(164201,'deals-mobile','.w-product-sale-ends .left-count-hours','border-top-left-radius','3','','','.w-product-sale-ends'),(164202,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-left-radius','50','3','','.b-multi-page-checkout'),(164203,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-left-radius','50','','','.b-multi-page-checkout'),(164204,'deals-mobile','.p-blog-index .avatar','border-top-left-radius','50','','','.p-blog-index'),(164205,'deals-mobile','.w-product-wedding-registry-button .btn','border-top-left-radius','50','4','','.w-product-wedding-registry-button'),(164206,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-left-radius','50','3','','.b-form'),(164207,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(164208,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(164209,'deals-mobile','.b-switch .bootstrap-switch','border-top-left-radius','14','','','.b-switch'),(164210,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-top-left-radius','15','','','.b-fancybox'),(164211,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border-top-left-radius','30','876','','.w-list-type-1'),(164212,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-left-radius','50','','','.b-slick'),(164213,'deals-mobile','.b-fancybox .fancybox-skin','border-top-left-radius','4','','','.b-fancybox'),(164214,'deals-mobile','.b-fancybox .fancybox-nav span','border-top-left-radius','50','','','.b-fancybox'),(164215,'deals-mobile','.w-sale .left-count','border-top-left-radius','3','','','.w-sale'),(164216,'deals-mobile','.w-sale .left-count-hours','border-top-left-radius','3','','','.w-sale'),(164217,'deals-mobile','.btn-3','border-top-left-radius','24','','',''),(164218,'deals-mobile','.btn','border-top-left-radius','24','','',''),(164219,'deals-mobile','.btn-1','border-top-left-radius','20','','',''),(164220,'deals-mobile','.btn-2','border-top-left-radius','24','','',''),(164221,'deals-mobile','.b-products-listing .promos-info .promo-name','border-top-left-radius','0','','','.b-products-listing'),(164222,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.b-data-table'),(164223,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.b-data-table'),(164224,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-left-radius','5','','','.b-messages'),(164225,'deals-mobile','.b-trade-approval .steps-bar','border-top-left-radius','18','','','.b-trade-approval'),(164226,'deals-mobile','.b-upload-file .snapshot','border-top-left-radius','50','','','.b-upload-file'),(164227,'deals-mobile','.batchPr .checkbox input + span','border-top-left-radius','18','','','.batchPr'),(164228,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-top-left-radius','0','','','.batchPr'),(164229,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-left-radius','10','','','.batchPr'),(164230,'deals-mobile','.batchPr .btn-batch-remove','border-top-left-radius','100','','','.batchPr'),(164231,'deals-mobile','.p-catalog-product .pn-image','border-top-left-radius','50','3','','.p-catalog-product'),(164232,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.p-quick-order-index'),(164233,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.p-quick-order-index'),(164234,'deals-mobile','.w-account-address-book .wrap','border-top-left-radius','5','','','.w-account-address-book'),(164235,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-top-left-radius','0','','','.w-blog-widget-related-posts'),(164236,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-left-radius','0','','','.w-catalog-paging'),(164237,'deals-mobile','.w-checkout-shipping-choice label:last-child span','border-top-left-radius','0','','','.w-checkout-shipping-choice'),(164238,'deals-mobile','.w-checkout-shipping-choice label:first-child span','border-top-left-radius','16','','','.w-checkout-shipping-choice'),(164239,'deals-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-left-radius','3','','','.w-delivery-day'),(164240,'deals-mobile','.w-delivery-day .left-count','border-top-left-radius','3','','','.w-delivery-day'),(164241,'deals-mobile','.w-personal-gift-status-bar .progress-bar-content','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(164242,'deals-mobile','.w-personal-gift-status-bar .progress-bar','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(164243,'deals-mobile','.w-product-customers-activity .customers-activity','border-top-left-radius','10','','','.w-product-customers-activity'),(164244,'deals-mobile','.w-product-customers-activity .close','border-top-left-radius','50','','','.w-product-customers-activity'),(164245,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-left-radius','12','','','.w-promotions'),(164246,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-left-radius','12','','','.w-promotions'),(164247,'deals-mobile','.w-promotions .promo-salemaker .discount','border-top-left-radius','12','','','.w-promotions'),(164248,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-left-radius','12','','','.w-promotions'),(164249,'deals-mobile','.w-product-sale-ends .left-count-days','border-top-right-radius','3','','','.w-product-sale-ends'),(164250,'deals-mobile','.w-sale .left-count-hours','border-top-right-radius','3','','','.w-sale'),(164251,'deals-mobile','.w-sale .left-count','border-top-right-radius','3','','','.w-sale'),(164252,'deals-mobile','.w-sale .left-count-days','border-top-right-radius','3','','','.w-sale'),(164253,'deals-mobile','.w-sale .badge','border-top-right-radius','50','','','.w-sale'),(164254,'deals-mobile','.w-product-wedding-registry-button .btn','border-top-right-radius','50','3','','.w-product-wedding-registry-button'),(164255,'deals-mobile','.w-product-sale-ends .left-count','border-top-right-radius','3','','','.w-product-sale-ends'),(164256,'deals-mobile','.w-product-sale-ends .left-count-hours','border-top-right-radius','3','','','.w-product-sale-ends'),(164257,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-right-radius','50','3','','.b-multi-page-checkout'),(164258,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-right-radius','50','','','.b-multi-page-checkout'),(164259,'deals-mobile','.p-blog-index .avatar','border-top-right-radius','50','','','.p-blog-index'),(164260,'deals-mobile','.w-product-wedding-registry-button .btn','border-top-right-radius','50','4','','.w-product-wedding-registry-button'),(164261,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-right-radius','50','3','','.b-form'),(164262,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(164263,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(164264,'deals-mobile','.b-switch .bootstrap-switch','border-top-right-radius','14','','','.b-switch'),(164265,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-right-radius','50','','','.b-slick'),(164266,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border-top-right-radius','30','876','','.w-list-type-1'),(164267,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-top-right-radius','15','','','.b-fancybox'),(164268,'deals-mobile','.b-fancybox .fancybox-skin','border-top-right-radius','4','','','.b-fancybox'),(164269,'deals-mobile','.b-fancybox .fancybox-nav span','border-top-right-radius','50','','','.b-fancybox'),(164270,'deals-mobile','.btn-3','border-top-right-radius','24','','',''),(164271,'deals-mobile','.btn-2','border-top-right-radius','24','','',''),(164272,'deals-mobile','.btn-1','border-top-right-radius','20','','',''),(164273,'deals-mobile','.btn','border-top-right-radius','24','','',''),(164274,'deals-mobile','.b-products-listing .promos-info .promo-name','border-top-right-radius','8','','','.b-products-listing'),(164275,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.b-data-table'),(164276,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.b-data-table'),(164277,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-right-radius','5','','','.b-messages'),(164278,'deals-mobile','.b-trade-approval .steps-bar','border-top-right-radius','18','','','.b-trade-approval'),(164279,'deals-mobile','.b-upload-file .snapshot','border-top-right-radius','50','','','.b-upload-file'),(164280,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-right-radius','10','','','.batchPr'),(164281,'deals-mobile','.batchPr .checkbox input + span','border-top-right-radius','18','','','.batchPr'),(164282,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-top-right-radius','0','','','.batchPr'),(164283,'deals-mobile','.batchPr .btn-batch-remove','border-top-right-radius','100','','','.batchPr'),(164284,'deals-mobile','.p-catalog-product .pn-image','border-top-right-radius','50','3','','.p-catalog-product'),(164285,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.p-quick-order-index'),(164286,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.p-quick-order-index'),(164287,'deals-mobile','.w-account-address-book .wrap','border-top-right-radius','5','','','.w-account-address-book'),(164288,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-top-right-radius','0','','','.w-blog-widget-related-posts'),(164289,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-right-radius','0','','','.w-catalog-paging'),(164290,'deals-mobile','.w-checkout-shipping-choice label:first-child span','border-top-right-radius','0','','','.w-checkout-shipping-choice'),(164291,'deals-mobile','.w-checkout-shipping-choice label:last-child span','border-top-right-radius','16','','','.w-checkout-shipping-choice'),(164292,'deals-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-right-radius','3','','','.w-delivery-day'),(164293,'deals-mobile','.w-delivery-day .left-count','border-top-right-radius','3','','','.w-delivery-day'),(164294,'deals-mobile','.w-personal-gift-status-bar .progress-bar-content','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(164295,'deals-mobile','.w-personal-gift-status-bar .progress-bar','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(164296,'deals-mobile','.w-product-customers-activity .customers-activity','border-top-right-radius','10','','','.w-product-customers-activity'),(164297,'deals-mobile','.w-product-customers-activity .close','border-top-right-radius','50','','','.w-product-customers-activity'),(164298,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-right-radius','12','','','.w-promotions'),(164299,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-right-radius','12','','','.w-promotions'),(164300,'deals-mobile','.w-promotions .promo-salemaker .discount','border-top-right-radius','12','','','.w-promotions'),(164301,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-right-radius','12','','','.w-promotions'),(164302,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(164303,'deals-mobile','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(164304,'deals-mobile','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(164305,'deals-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','border-top-width','2','','','.b-product-images'),(164306,'deals-mobile','.w-sale .sale-holder','border-top-width','2','','','.w-sale'),(164307,'deals-mobile','.w-menu-slider > ul > li > ul','border-top-width','1','','','.w-menu-slider'),(164308,'deals-mobile','.w-product-wedding-registry-button .btn','border-top-width','2','3','','.w-product-wedding-registry-button'),(164309,'deals-mobile','.w-product-sale-ends .left-text-left','border-top-width','2','','','.w-product-sale-ends'),(164310,'deals-mobile','.w-product-sale-ends .left-text-right','border-top-width','2','','','.w-product-sale-ends'),(164311,'deals-mobile','.b-product-images .additional-images .item , .b-product-images .additional-videos .item ','border-top-width','2','2','','.b-product-images'),(164312,'deals-mobile','.w-compare-box-item .checkbox + span','border-top-width','1','','','.w-compare-box-item'),(164313,'deals-mobile','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(164314,'deals-mobile','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-bundle'),(164315,'deals-mobile','.w-catalog-listing-look .b2b','border-top-width','1','','','.w-catalog-listing-look'),(164316,'deals-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-width','1','','','.b-compare'),(164317,'deals-mobile','.w-catalog-listing-look .list','border-top-width','1','','','.w-catalog-listing-look'),(164318,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-width','1','','','.b-multi-page-checkout'),(164319,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-width','2','','','.p-blog-index'),(164320,'deals-mobile','.btn','border-top-width','2','','',''),(164321,'deals-mobile','.btn-3','border-top-width','2','','',''),(164322,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(164323,'deals-mobile','.view-all','border-top-width','1','3','',''),(164324,'deals-mobile','.b-info-popup .info-popup div','border-top-width','1','','','.b-info-popup'),(164325,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(164326,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','border-top-width','1','','','.b-multi-page-checkout'),(164327,'deals-mobile','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(164328,'deals-mobile','.testimonials .review','border-top-width','7','3','',''),(164329,'deals-mobile','.b-pagination .pagination .prev-pages','border-top-width','1','','','.b-pagination'),(164330,'deals-mobile','.b-pagination .pagination .prev','border-top-width','1','','','.b-pagination'),(164331,'deals-mobile','.b-pagination .pagination .page-number','border-top-width','1','','','.b-pagination'),(164332,'deals-mobile','.p-wedding-registry-manage .wr-search button','border-top-width','0','','','.p-wedding-registry-manage'),(164333,'deals-mobile','.b-pagination .pagination .next-pages','border-top-width','1','','','.b-pagination'),(164334,'deals-mobile','.b-pagination .pagination .next','border-top-width','1','','','.b-pagination'),(164335,'deals-mobile','.b-pagination .pagination span','border-top-width','1','2','','.b-pagination'),(164336,'deals-mobile','.p-account-history .orders-table .item','border-top-width','1','890','','.p-account-history'),(164337,'deals-mobile','.p-account-history .orders-table .td-alignright','border-top-width','1','890','','.p-account-history'),(164338,'deals-mobile','.p-account-index .orders-table .td-alignright','border-top-width','1','890','','.p-account-index'),(164339,'deals-mobile','.p-account-index .orders-table .item','border-top-width','1','890','','.p-account-index'),(164340,'deals-mobile','.w-list-type-2_2 .compare-box-item','border-top-width','1','','','.w-list-type-2_2'),(164341,'deals-mobile','.w-list-type-2_2 .button-wishlist button','border-top-width','0','','','.w-list-type-2_2'),(164342,'deals-mobile','.w-list-type-2_2 .buttons','border-top-width','1','','','.w-list-type-2_2'),(164343,'deals-mobile','.w-product-wedding-registry-button .btn','border-top-width','2','4','','.w-product-wedding-registry-button'),(164344,'deals-mobile','.p-wedding-registry-index .search-list','border-top-width','1','3','','.p-wedding-registry-index'),(164345,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-width','2','3','','.b-form'),(164346,'deals-mobile','.b-form .form-buttons','border-top-width','1','','','.b-form'),(164347,'deals-mobile','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(164348,'deals-mobile','.b-pagination .pagination a','border-top-width','1','','','.b-pagination'),(164349,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-width','2','','','.b-slick'),(164350,'deals-mobile','.w-languages .select','border-top-width','1','','','.w-languages'),(164351,'deals-mobile','.w-search .item + .item','border-top-width','1','','','.w-search'),(164352,'deals-mobile','.w-search .search-input','border-top-width','0','','','.w-search'),(164353,'deals-mobile','.w-socials > li','border-top-width','1','','','.w-socials'),(164354,'deals-mobile','.p-checkout-index .shipping-method .item + .item','border-top-width','1','','','.p-checkout-index'),(164355,'deals-mobile','.w-currencies .currencies-title','border-top-width','2','','','.w-currencies'),(164356,'deals-mobile','.w-currencies .select','border-top-width','1','','','.w-currencies'),(164357,'deals-mobile','.b-bottom .popup-buttons','border-top-width','1','','','.b-bottom'),(164358,'deals-mobile','.w-compare-box-item .checkbox:checked + span','border-top-width','1','','','.w-compare-box-item'),(164359,'deals-mobile','.b-slick .slick-vertical .slick-slide','border-top-width','1','','','.b-slick'),(164360,'deals-mobile','.w-menu .hided.menu ul li','border-top-width','1','890','','.w-menu'),(164361,'deals-mobile','.b-info-popup .info-popup div','border-top-width','1','3','','.b-info-popup'),(164362,'deals-mobile','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(164363,'deals-mobile','.w-catalog-listing-look .grid','border-top-width','1','','','.w-catalog-listing-look'),(164364,'deals-mobile','.w-sale .left-text-left','border-top-width','2','','','.w-sale'),(164365,'deals-mobile','.w-sale .left-text-right','border-top-width','2','','','.w-sale'),(164366,'deals-mobile','.b-quantity .qty-box .bigger','border-top-width','2','','','.b-quantity'),(164367,'deals-mobile','.b-quantity .qty-box .smaller','border-top-width','2','','','.b-quantity'),(164368,'deals-mobile','.w-cart .cart-content','border-top-width','1','','','.w-cart'),(164369,'deals-mobile','.p-reviews-info .review-info-text','border-top-width','5','4','','.p-reviews-info'),(164370,'deals-mobile','.w-list-type-2 .button-wishlist button','border-top-width','0','','','.w-list-type-2'),(164371,'deals-mobile','.w-list-type-2 .buttons','border-top-width','1','','','.w-list-type-2'),(164372,'deals-mobile','.w-list-type-2 .item','border-top-width','1','1','','.w-list-type-2'),(164373,'deals-mobile','.w-list-type-2 .compare-box-item','border-top-width','1','','','.w-list-type-2'),(164374,'deals-mobile','.b-autocomplete .ui-autocomplete li','border-top-width','1','','','.b-autocomplete'),(164375,'deals-mobile','.p-wedding-registry-manage .remove','border-top-width','1','','','.p-wedding-registry-manage'),(164376,'deals-mobile','.w-list-type-1_3 .compare-box-item','border-top-width','1','','','.w-list-type-1_3'),(164377,'deals-mobile','.w-list-type-1_3 .buttons','border-top-width','1','','','.w-list-type-1_3'),(164378,'deals-mobile','.w-list-type-1_3 .button-wishlist button','border-top-width','0','','','.w-list-type-1_3'),(164379,'deals-mobile','.w-list-type-1_2 .compare-box-item','border-top-width','1','','','.w-list-type-1_2'),(164380,'deals-mobile','.w-list-type-1_2 .buttons','border-top-width','1','','','.w-list-type-1_2'),(164381,'deals-mobile','.w-list-type-1_2 .button-wishlist button','border-top-width','0','','','.w-list-type-1_2'),(164382,'deals-mobile','.b-bottom .popup-box','border-top-width','1','','','.b-bottom'),(164383,'deals-mobile','.w-list-type-1 .compare-box-item','border-top-width','1','','','.w-list-type-1'),(164384,'deals-mobile','.w-list-type-1 .button-wishlist button','border-top-width','0','','','.w-list-type-1'),(164385,'deals-mobile','.w-filters .ui-slider-range','border-top-width','0','','','.w-filters'),(164386,'deals-mobile','.w-list-type-1 .buttons','border-top-width','1','','','.w-list-type-1'),(164387,'deals-mobile','.w-filters .ui-slider','border-top-width','0','','','.w-filters'),(164388,'deals-mobile','.w-filters .ui-slider-handle','border-top-width','0','','','.w-filters'),(164389,'deals-mobile','.w-reviews .review','border-top-width','7','3','','.w-reviews'),(164390,'deals-mobile','.w-search .button-search','border-top-width','0','','','.w-search'),(164391,'deals-mobile','.b-form .required-error','border-top-width','1','','','.b-form'),(164392,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','border-top-width','2','','',''),(164393,'deals-mobile','textarea','border-top-width','2','','',''),(164394,'deals-mobile','.b-info div + .info','border-top-width','1','','','.b-info'),(164395,'deals-mobile','.b-products-listing .products-listing .compare','border-top-width','1','','','.b-products-listing'),(164396,'deals-mobile','.b-data-table table.dataTable tbody td','border-top-width','1','','','.b-data-table'),(164397,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(164398,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(164399,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(164400,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(164401,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(164402,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(164403,'deals-mobile','.b-email .model','border-top-width','1','','','.b-email'),(164404,'deals-mobile','.b-email .model','border-top-width','1','','','.b-email'),(164405,'deals-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(164406,'deals-mobile','.b-email .name','border-top-width','1','','','.b-email'),(164407,'deals-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(164408,'deals-mobile','.b-email .name','border-top-width','1','','','.b-email'),(164409,'deals-mobile','.b-email .model','border-top-width','1','','','.b-email'),(164410,'deals-mobile','.b-email .price','border-top-width','1','','','.b-email'),(164411,'deals-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(164412,'deals-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(164413,'deals-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(164414,'deals-mobile','.b-email .price','border-top-width','1','','','.b-email'),(164415,'deals-mobile','.b-email .image','border-top-width','1','','','.b-email'),(164416,'deals-mobile','.b-email .image','border-top-width','1','','','.b-email'),(164417,'deals-mobile','.b-email .name','border-top-width','1','','','.b-email'),(164418,'deals-mobile','.b-email .name','border-top-width','1','','','.b-email'),(164419,'deals-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(164420,'deals-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(164421,'deals-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(164422,'deals-mobile','.b-email .name','border-top-width','1','','','.b-email'),(164423,'deals-mobile','.b-email .image','border-top-width','1','','','.b-email'),(164424,'deals-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(164425,'deals-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(164426,'deals-mobile','.b-email .model','border-top-width','1','','','.b-email'),(164427,'deals-mobile','.b-email .image','border-top-width','1','','','.b-email'),(164428,'deals-mobile','.b-email .name','border-top-width','1','','','.b-email'),(164429,'deals-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(164430,'deals-mobile','.b-email .price','border-top-width','1','','','.b-email'),(164431,'deals-mobile','.b-email .image','border-top-width','1','','','.b-email'),(164432,'deals-mobile','.b-email .price','border-top-width','1','','','.b-email'),(164433,'deals-mobile','.b-email .model','border-top-width','1','','','.b-email'),(164434,'deals-mobile','.b-email .image','border-top-width','1','','','.b-email'),(164435,'deals-mobile','.b-email .price','border-top-width','1','','','.b-email'),(164436,'deals-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(164437,'deals-mobile','.b-email .model','border-top-width','1','','','.b-email'),(164438,'deals-mobile','.b-email .price','border-top-width','1','','','.b-email'),(164439,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-top-width','1','','','.b-menu-style-2'),(164440,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-top-width','3','','','.b-menu-style-2'),(164441,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','border-top-width','1','','','.b-menu-style-2'),(164442,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-top-width','1','','','.b-menu-style-2'),(164443,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-top-width','3','','','.b-menu-style-2'),(164444,'deals-mobile','.b-messages .msv_btn','border-top-width','1','','','.b-messages'),(164445,'deals-mobile','.b-messages .email-heading','border-top-width','1','','','.b-messages'),(164446,'deals-mobile','.b-messages .dataTable','border-top-width','1','','','.b-messages'),(164447,'deals-mobile','.b-messages .messMenuButtonTop','border-top-width','1','','','.b-messages'),(164448,'deals-mobile','.b-messages .content_management_attach button','border-top-width','1','','','.b-messages'),(164449,'deals-mobile','.b-messages .messages-menu li + li','border-top-width','1','','','.b-messages'),(164450,'deals-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-width','2','','','.b-messages'),(164451,'deals-mobile','.b-messages .content_management_attach','border-top-width','1','','','.b-messages'),(164452,'deals-mobile','.b-select-suggest .select2-container .select2-choice','border-top-width','2','','','.b-select-suggest'),(164453,'deals-mobile','.b-select-suggest .select2-search input','border-top-width','1','','','.b-select-suggest'),(164454,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-width','1','','','.b-select-suggest'),(164455,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(164456,'deals-mobile','.b-select-suggest .select2-drop-auto-width','border-top-width','1','','','.b-select-suggest'),(164457,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-width','1','','','.b-select-suggest'),(164458,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-top-width','1','','','.b-select-suggest'),(164459,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-width','1','','','.b-select-suggest'),(164460,'deals-mobile','.b-select-suggest .select2-drop.select2-drop-above','border-top-width','1','','','.b-select-suggest'),(164461,'deals-mobile','.b-select-suggest .select2-drop-active','border-top-width','1','','','.b-select-suggest'),(164462,'deals-mobile','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-width','1','','','.b-select-suggest'),(164463,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(164464,'deals-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(164465,'deals-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(164466,'deals-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(164467,'deals-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(164468,'deals-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(164469,'deals-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(164470,'deals-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(164471,'deals-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(164472,'deals-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(164473,'deals-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(164474,'deals-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(164475,'deals-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(164476,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-width','2','','','.b-trade-approval'),(164477,'deals-mobile','.b-upload-file .snapshot','border-top-width','1','','','.b-upload-file'),(164478,'deals-mobile','.b-upload-file .upload-file-template','border-top-width','1','','','.b-upload-file'),(164479,'deals-mobile','.b-upload-files .upload-files','border-top-width','1','','','.b-upload-files'),(164480,'deals-mobile','.b-upload-files .added-file','border-top-width','1','','','.b-upload-files'),(164481,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-width','1','','','.batchPr'),(164482,'deals-mobile','.batchPr .checkbox input + span','border-top-width','1','','','.batchPr'),(164483,'deals-mobile','.batchPr .checkbox input + span','border-top-width','1','','','.batchPr'),(164484,'deals-mobile','.batchPr .checkbox input:checked + span','border-top-width','1','','','.batchPr'),(164485,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .item + .item','border-top-width','1','','','.batchPr'),(164486,'deals-mobile','.batchPr .w-batch-selected-products','border-top-width','1','','','.batchPr'),(164487,'deals-mobile','.p-account-samples-history .orders-table .item','border-top-width','1','','','.p-account-samples-history'),(164488,'deals-mobile','.p-account-samples-history .orders-table .item','border-top-width','1','','','.p-account-samples-history'),(164489,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-width','1','','','.p-account-samples-history'),(164490,'deals-mobile','.p-account-samples-history .orders-table .item','border-top-width','1','','','.p-account-samples-history'),(164491,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-width','1','','','.p-account-samples-history'),(164492,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-width','1','','','.p-account-samples-history'),(164493,'deals-mobile','.p-account-samples-history .orders-table .item','border-top-width','1','','','.p-account-samples-history'),(164494,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-width','1','','','.p-account-samples-history'),(164495,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-width','1','','','.p-account-samples-history'),(164496,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','border-top-width','1','','','.p-account-samples-history'),(164497,'deals-mobile','.p-account-samples-history .orders-table .item','border-top-width','1','','','.p-account-samples-history'),(164498,'deals-mobile','.p-account-samples-history .orders-table .item','border-top-width','1','','','.p-account-samples-history'),(164499,'deals-mobile','.p-catalog-product .prev-next-product','border-top-width','1','','','.p-catalog-product'),(164500,'deals-mobile','.p-catalog-product .pn-image','border-top-width','1','','','.p-catalog-product'),(164501,'deals-mobile','.p-catalog-product .pn-name','border-top-width','1','','','.p-catalog-product'),(164502,'deals-mobile','.p-catalog-product .pn-image','border-top-width','2','3','','.p-catalog-product'),(164503,'deals-mobile','.p-payer-order-confirmation .input-wrapper','border-top-width','2','','','.p-payer-order-confirmation'),(164504,'deals-mobile','.p-payer-order-pay .input-wrapper','border-top-width','2','','','.p-payer-order-pay'),(164505,'deals-mobile','.w-account-address-book .wrap','border-top-width','1','','','.w-account-address-book'),(164506,'deals-mobile','.w-account-personal-catalog .list-switcher a','border-top-width','3','2','','.w-account-personal-catalog'),(164507,'deals-mobile','.w-account-subscription .subscription-variant + .subscription-variant','border-top-width','1','','','.w-account-subscription'),(164508,'deals-mobile','.w-cart-compare .attributes-block td','border-top-width','1','','','.w-cart-compare'),(164509,'deals-mobile','.w-cart-compare .price-block td','border-top-width','1','','','.w-cart-compare'),(164510,'deals-mobile','.w-cart-compare .product-block td','border-top-width','1','','','.w-cart-compare'),(164511,'deals-mobile','.w-cart-compare .cart-cell > div','border-top-width','1','','','.w-cart-compare'),(164512,'deals-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-top-width','1','','','.w-catalog-compare'),(164513,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','border-top-width','3','2','','.w-catalog-compare'),(164514,'deals-mobile','.w-catalog-paging .prev','border-top-width','1','','','.w-catalog-paging'),(164515,'deals-mobile','.w-catalog-paging .page-number','border-top-width','1','','','.w-catalog-paging'),(164516,'deals-mobile','.w-catalog-paging .next','border-top-width','1','','','.w-catalog-paging'),(164517,'deals-mobile','.w-catalog-paging ','border-top-width','1','2','','.w-catalog-paging'),(164518,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-width','1','','','.w-catalog-paging'),(164519,'deals-mobile','.w-catalog-paging .next-pages','border-top-width','1','','','.w-catalog-paging'),(164520,'deals-mobile','.w-catalog-paging .prev-pages','border-top-width','1','','','.w-catalog-paging'),(164521,'deals-mobile','.w-checkout-shipping .sub-item + .sub-item','border-top-width','1','','','.w-checkout-shipping'),(164522,'deals-mobile','.w-checkout-shipping-choice span','border-top-width','2','','','.w-checkout-shipping-choice'),(164523,'deals-mobile','.w-communication-new-topic td','border-top-width','1','','','.w-communication-new-topic'),(164524,'deals-mobile','.w-communication-post .communication-post','border-top-width','1','','','.w-communication-post'),(164525,'deals-mobile','.w-delivery-day .left-text-left','border-top-width','2','','','.w-delivery-day'),(164526,'deals-mobile','.w-delivery-day .left-text-right','border-top-width','2','','','.w-delivery-day'),(164527,'deals-mobile','.w-product-customers-activity .customers-activity','border-top-width','1','','','.w-product-customers-activity'),(164528,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-width','1','','','.w-promotions'),(164529,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-width','1','','','.w-promotions'),(164530,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-width','1','','','.w-promotions'),(164531,'deals-mobile','.w-promotions .promo-salemaker .discount','border-top-width','1','','','.w-promotions'),(164532,'deals-mobile','.w-reviews-content .review','border-top-width','8','3','','.w-reviews-content'),(164533,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(164534,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-top-width','1','','','.w-wedding-registry-widgets-photos'),(164535,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-top-width','1','','','.w-wedding-registry-widgets-photos'),(164536,'deals-mobile','.w-wedding-registry-widgets-products .rating','border-top-width','1','','','.w-wedding-registry-widgets-products'),(164537,'deals-mobile','.b-data-table table.dataTable thead td','border_important','important','','','.b-data-table'),(164538,'deals-mobile','.w-sale .left-count-days','border_radius_1_measure','px','','','.w-sale'),(164539,'deals-mobile','.w-sale .left-count-hours','border_radius_1_measure','px','','','.w-sale'),(164540,'deals-mobile','.w-sale .left-count','border_radius_1_measure','px','','','.w-sale'),(164541,'deals-mobile','.w-sale .badge','border_radius_1_measure','%','','','.w-sale'),(164542,'deals-mobile','.w-product-sale-ends .left-count','border_radius_1_measure','px','','','.w-product-sale-ends'),(164543,'deals-mobile','.w-product-sale-ends .left-count-hours','border_radius_1_measure','px','','','.w-product-sale-ends'),(164544,'deals-mobile','.w-product-sale-ends .left-count-days','border_radius_1_measure','px','','','.w-product-sale-ends'),(164545,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_1_measure','%','3','','.b-multi-page-checkout'),(164546,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_1_measure','%','','','.b-multi-page-checkout'),(164547,'deals-mobile','.p-blog-index .avatar','border_radius_1_measure','%','','','.p-blog-index'),(164548,'deals-mobile','.w-product-wedding-registry-button .btn','border_radius_1_measure','%','4','','.w-product-wedding-registry-button'),(164549,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_1_measure','%','3','','.b-form'),(164550,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(164551,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(164552,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_1_measure','px','','','.b-fancybox'),(164553,'deals-mobile','.b-switch .bootstrap-switch','border_radius_1_measure','px','','','.b-switch'),(164554,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_1_measure','%','','','.b-slick'),(164555,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border_radius_1_measure','px','876','','.w-list-type-1'),(164556,'deals-mobile','.btn-3','border_radius_1_measure','px','','',''),(164557,'deals-mobile','.btn-2','border_radius_1_measure','px','','',''),(164558,'deals-mobile','.btn-1','border_radius_1_measure','px','','',''),(164559,'deals-mobile','.btn','border_radius_1_measure','px','','',''),(164560,'deals-mobile','.b-fancybox .fancybox-skin','border_radius_1_measure','px','','','.b-fancybox'),(164561,'deals-mobile','.w-product-wedding-registry-button .btn','border_radius_1_measure','%','3','','.w-product-wedding-registry-button'),(164562,'deals-mobile','.b-fancybox .fancybox-nav span','border_radius_1_measure','%','','','.b-fancybox'),(164563,'deals-mobile','.b-products-listing .promos-info .promo-name','border_radius_1_measure','px','','','.b-products-listing'),(164564,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.b-data-table'),(164565,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.b-data-table'),(164566,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_1_measure','px','','','.b-messages'),(164567,'deals-mobile','.b-trade-approval .steps-bar','border_radius_1_measure','px','','','.b-trade-approval'),(164568,'deals-mobile','.b-upload-file .snapshot','border_radius_1_measure','%','','','.b-upload-file'),(164569,'deals-mobile','.batchPr .checkbox input + span','border_radius_1_measure','px','','','.batchPr'),(164570,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_1_measure','px','','','.batchPr'),(164571,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_1_measure','px','','','.batchPr'),(164572,'deals-mobile','.batchPr .btn-batch-remove','border_radius_1_measure','%','','','.batchPr'),(164573,'deals-mobile','.p-catalog-product .pn-image','border_radius_1_measure','%','3','','.p-catalog-product'),(164574,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.p-quick-order-index'),(164575,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.p-quick-order-index'),(164576,'deals-mobile','.w-account-address-book .wrap','border_radius_1_measure','px','','','.w-account-address-book'),(164577,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_1_measure','px','','','.w-blog-widget-related-posts'),(164578,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_1_measure','px','','','.w-catalog-paging'),(164579,'deals-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(164580,'deals-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(164581,'deals-mobile','.w-delivery-day .left-count','border_radius_1_measure','px','','','.w-delivery-day'),(164582,'deals-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_1_measure','px','','','.w-delivery-day'),(164583,'deals-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(164584,'deals-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(164585,'deals-mobile','.w-product-customers-activity .customers-activity','border_radius_1_measure','px','','','.w-product-customers-activity'),(164586,'deals-mobile','.w-product-customers-activity .close','border_radius_1_measure','%','','','.w-product-customers-activity'),(164587,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_1_measure','px','','','.w-promotions'),(164588,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_1_measure','px','','','.w-promotions'),(164589,'deals-mobile','.w-promotions .promo-salemaker .discount','border_radius_1_measure','px','','','.w-promotions'),(164590,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_1_measure','px','','','.w-promotions'),(164591,'deals-mobile','.w-sale .left-count-days','border_radius_2_measure','px','','','.w-sale'),(164592,'deals-mobile','.w-sale .left-count','border_radius_2_measure','px','','','.w-sale'),(164593,'deals-mobile','.w-sale .left-count-hours','border_radius_2_measure','px','','','.w-sale'),(164594,'deals-mobile','.w-sale .badge','border_radius_2_measure','%','','','.w-sale'),(164595,'deals-mobile','.w-product-wedding-registry-button .btn','border_radius_2_measure','%','3','','.w-product-wedding-registry-button'),(164596,'deals-mobile','.w-product-sale-ends .left-count','border_radius_2_measure','px','','','.w-product-sale-ends'),(164597,'deals-mobile','.w-product-sale-ends .left-count-days','border_radius_2_measure','px','','','.w-product-sale-ends'),(164598,'deals-mobile','.w-product-sale-ends .left-count-hours','border_radius_2_measure','px','','','.w-product-sale-ends'),(164599,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_2_measure','%','3','','.b-multi-page-checkout'),(164600,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_2_measure','%','','','.b-multi-page-checkout'),(164601,'deals-mobile','.p-blog-index .avatar','border_radius_2_measure','%','','','.p-blog-index'),(164602,'deals-mobile','.w-product-wedding-registry-button .btn','border_radius_2_measure','%','4','','.w-product-wedding-registry-button'),(164603,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_2_measure','%','3','','.b-form'),(164604,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(164605,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(164606,'deals-mobile','.b-switch .bootstrap-switch','border_radius_2_measure','px','','','.b-switch'),(164607,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_2_measure','%','','','.b-slick'),(164608,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border_radius_2_measure','px','876','','.w-list-type-1'),(164609,'deals-mobile','.btn-3','border_radius_2_measure','px','','',''),(164610,'deals-mobile','.btn-2','border_radius_2_measure','px','','',''),(164611,'deals-mobile','.btn-1','border_radius_2_measure','px','','',''),(164612,'deals-mobile','.btn','border_radius_2_measure','px','','',''),(164613,'deals-mobile','.b-fancybox .fancybox-skin','border_radius_2_measure','px','','','.b-fancybox'),(164614,'deals-mobile','.b-fancybox .fancybox-nav span','border_radius_2_measure','%','','','.b-fancybox'),(164615,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_2_measure','px','','','.b-fancybox'),(164616,'deals-mobile','.b-products-listing .promos-info .promo-name','border_radius_2_measure','px','','','.b-products-listing'),(164617,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.b-data-table'),(164618,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.b-data-table'),(164619,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_2_measure','px','','','.b-messages'),(164620,'deals-mobile','.b-trade-approval .steps-bar','border_radius_2_measure','px','','','.b-trade-approval'),(164621,'deals-mobile','.b-upload-file .snapshot','border_radius_2_measure','%','','','.b-upload-file'),(164622,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_2_measure','px','','','.batchPr'),(164623,'deals-mobile','.batchPr .checkbox input + span','border_radius_2_measure','px','','','.batchPr'),(164624,'deals-mobile','.batchPr .btn-batch-remove','border_radius_2_measure','%','','','.batchPr'),(164625,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_2_measure','px','','','.batchPr'),(164626,'deals-mobile','.p-catalog-product .pn-image','border_radius_2_measure','%','3','','.p-catalog-product'),(164627,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.p-quick-order-index'),(164628,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.p-quick-order-index'),(164629,'deals-mobile','.w-account-address-book .wrap','border_radius_2_measure','px','','','.w-account-address-book'),(164630,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_2_measure','px','','','.w-blog-widget-related-posts'),(164631,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_2_measure','px','','','.w-catalog-paging'),(164632,'deals-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(164633,'deals-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(164634,'deals-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_2_measure','px','','','.w-delivery-day'),(164635,'deals-mobile','.w-delivery-day .left-count','border_radius_2_measure','px','','','.w-delivery-day'),(164636,'deals-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(164637,'deals-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(164638,'deals-mobile','.w-product-customers-activity .customers-activity','border_radius_2_measure','px','','','.w-product-customers-activity'),(164639,'deals-mobile','.w-product-customers-activity .close','border_radius_2_measure','%','','','.w-product-customers-activity'),(164640,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_2_measure','px','','','.w-promotions'),(164641,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_2_measure','px','','','.w-promotions'),(164642,'deals-mobile','.w-promotions .promo-salemaker .discount','border_radius_2_measure','px','','','.w-promotions'),(164643,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_2_measure','px','','','.w-promotions'),(164644,'deals-mobile','.w-sale .left-count','border_radius_3_measure','px','','','.w-sale'),(164645,'deals-mobile','.w-sale .left-count-days','border_radius_3_measure','px','','','.w-sale'),(164646,'deals-mobile','.w-sale .badge','border_radius_3_measure','%','','','.w-sale'),(164647,'deals-mobile','.w-product-wedding-registry-button .btn','border_radius_3_measure','%','3','','.w-product-wedding-registry-button'),(164648,'deals-mobile','.w-product-sale-ends .left-count-days','border_radius_3_measure','px','','','.w-product-sale-ends'),(164649,'deals-mobile','.w-product-sale-ends .left-count','border_radius_3_measure','px','','','.w-product-sale-ends'),(164650,'deals-mobile','.w-product-sale-ends .left-count-hours','border_radius_3_measure','px','','','.w-product-sale-ends'),(164651,'deals-mobile','.b-fancybox .fancybox-nav span','border_radius_3_measure','%','','','.b-fancybox'),(164652,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_3_measure','%','3','','.b-multi-page-checkout'),(164653,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_3_measure','%','','','.b-multi-page-checkout'),(164654,'deals-mobile','.p-blog-index .avatar','border_radius_3_measure','%','','','.p-blog-index'),(164655,'deals-mobile','.w-product-wedding-registry-button .btn','border_radius_3_measure','%','4','','.w-product-wedding-registry-button'),(164656,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_3_measure','%','3','','.b-form'),(164657,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(164658,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(164659,'deals-mobile','.b-switch .bootstrap-switch','border_radius_3_measure','px','','','.b-switch'),(164660,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_3_measure','%','','','.b-slick'),(164661,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border_radius_3_measure','px','876','','.w-list-type-1'),(164662,'deals-mobile','.btn-3','border_radius_3_measure','px','','',''),(164663,'deals-mobile','.btn-2','border_radius_3_measure','px','','',''),(164664,'deals-mobile','.btn-1','border_radius_3_measure','px','','',''),(164665,'deals-mobile','.btn','border_radius_3_measure','px','','',''),(164666,'deals-mobile','.b-fancybox .fancybox-skin','border_radius_3_measure','px','','','.b-fancybox'),(164667,'deals-mobile','.w-sale .left-count-hours','border_radius_3_measure','px','','','.w-sale'),(164668,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_3_measure','px','','','.b-fancybox'),(164669,'deals-mobile','.b-products-listing .promos-info .promo-name','border_radius_3_measure','px','','','.b-products-listing'),(164670,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.b-data-table'),(164671,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.b-data-table'),(164672,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_3_measure','px','','','.b-messages'),(164673,'deals-mobile','.b-trade-approval .steps-bar','border_radius_3_measure','px','','','.b-trade-approval'),(164674,'deals-mobile','.b-upload-file .snapshot','border_radius_3_measure','%','','','.b-upload-file'),(164675,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_3_measure','px','','','.batchPr'),(164676,'deals-mobile','.batchPr .checkbox input + span','border_radius_3_measure','px','','','.batchPr'),(164677,'deals-mobile','.batchPr .btn-batch-remove','border_radius_3_measure','%','','','.batchPr'),(164678,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_3_measure','px','','','.batchPr'),(164679,'deals-mobile','.p-catalog-product .pn-image','border_radius_3_measure','%','3','','.p-catalog-product'),(164680,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.p-quick-order-index'),(164681,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.p-quick-order-index'),(164682,'deals-mobile','.w-account-address-book .wrap','border_radius_3_measure','px','','','.w-account-address-book'),(164683,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_3_measure','px','','','.w-blog-widget-related-posts'),(164684,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_3_measure','px','','','.w-catalog-paging'),(164685,'deals-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(164686,'deals-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(164687,'deals-mobile','.w-delivery-day .left-count','border_radius_3_measure','px','','','.w-delivery-day'),(164688,'deals-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_3_measure','px','','','.w-delivery-day'),(164689,'deals-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(164690,'deals-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(164691,'deals-mobile','.w-product-customers-activity .customers-activity','border_radius_3_measure','px','','','.w-product-customers-activity'),(164692,'deals-mobile','.w-product-customers-activity .close','border_radius_3_measure','%','','','.w-product-customers-activity'),(164693,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_3_measure','px','','','.w-promotions'),(164694,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_3_measure','px','','','.w-promotions'),(164695,'deals-mobile','.w-promotions .promo-salemaker .discount','border_radius_3_measure','px','','','.w-promotions'),(164696,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_3_measure','px','','','.w-promotions'),(164697,'deals-mobile','.w-sale .left-count-days','border_radius_4_measure','px','','','.w-sale'),(164698,'deals-mobile','.w-sale .left-count-hours','border_radius_4_measure','px','','','.w-sale'),(164699,'deals-mobile','.w-sale .left-count','border_radius_4_measure','px','','','.w-sale'),(164700,'deals-mobile','.w-sale .badge','border_radius_4_measure','%','','','.w-sale'),(164701,'deals-mobile','.w-product-wedding-registry-button .btn','border_radius_4_measure','%','3','','.w-product-wedding-registry-button'),(164702,'deals-mobile','.w-product-wedding-registry-button .btn','border_radius_4_measure','%','4','','.w-product-wedding-registry-button'),(164703,'deals-mobile','.w-product-sale-ends .left-count','border_radius_4_measure','px','','','.w-product-sale-ends'),(164704,'deals-mobile','.w-product-sale-ends .left-count-days','border_radius_4_measure','px','','','.w-product-sale-ends'),(164705,'deals-mobile','.w-product-sale-ends .left-count-hours','border_radius_4_measure','px','','','.w-product-sale-ends'),(164706,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_4_measure','%','3','','.b-multi-page-checkout'),(164707,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_4_measure','%','','','.b-multi-page-checkout'),(164708,'deals-mobile','.p-blog-index .avatar','border_radius_4_measure','%','','','.p-blog-index'),(164709,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_4_measure','%','3','','.b-form'),(164710,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(164711,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(164712,'deals-mobile','.b-switch .bootstrap-switch','border_radius_4_measure','px','','','.b-switch'),(164713,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','border_radius_4_measure','px','876','','.w-list-type-1'),(164714,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_4_measure','%','','','.b-slick'),(164715,'deals-mobile','.btn-3','border_radius_4_measure','px','','',''),(164716,'deals-mobile','.btn-2','border_radius_4_measure','px','','',''),(164717,'deals-mobile','.btn-1','border_radius_4_measure','px','','',''),(164718,'deals-mobile','.btn','border_radius_4_measure','px','','',''),(164719,'deals-mobile','.b-fancybox .fancybox-skin','border_radius_4_measure','px','','','.b-fancybox'),(164720,'deals-mobile','.b-fancybox .fancybox-nav span','border_radius_4_measure','%','','','.b-fancybox'),(164721,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_4_measure','px','','','.b-fancybox'),(164722,'deals-mobile','.b-products-listing .promos-info .promo-name','border_radius_4_measure','px','','','.b-products-listing'),(164723,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.b-data-table'),(164724,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.b-data-table'),(164725,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_4_measure','px','','','.b-messages'),(164726,'deals-mobile','.b-trade-approval .steps-bar','border_radius_4_measure','px','','','.b-trade-approval'),(164727,'deals-mobile','.b-upload-file .snapshot','border_radius_4_measure','%','','','.b-upload-file'),(164728,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_4_measure','px','','','.batchPr'),(164729,'deals-mobile','.batchPr .checkbox input + span','border_radius_4_measure','px','','','.batchPr'),(164730,'deals-mobile','.batchPr .btn-batch-remove','border_radius_4_measure','%','','','.batchPr'),(164731,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_4_measure','px','','','.batchPr'),(164732,'deals-mobile','.p-catalog-product .pn-image','border_radius_4_measure','%','3','','.p-catalog-product'),(164733,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.p-quick-order-index'),(164734,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.p-quick-order-index'),(164735,'deals-mobile','.w-account-address-book .wrap','border_radius_4_measure','px','','','.w-account-address-book'),(164736,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_4_measure','px','','','.w-blog-widget-related-posts'),(164737,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_4_measure','px','','','.w-catalog-paging'),(164738,'deals-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(164739,'deals-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(164740,'deals-mobile','.w-delivery-day .left-count','border_radius_4_measure','px','','','.w-delivery-day'),(164741,'deals-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_4_measure','px','','','.w-delivery-day'),(164742,'deals-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(164743,'deals-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(164744,'deals-mobile','.w-product-customers-activity .customers-activity','border_radius_4_measure','px','','','.w-product-customers-activity'),(164745,'deals-mobile','.w-product-customers-activity .close','border_radius_4_measure','%','','','.w-product-customers-activity'),(164746,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_4_measure','px','','','.w-promotions'),(164747,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_4_measure','px','','','.w-promotions'),(164748,'deals-mobile','.w-promotions .promo-salemaker .discount','border_radius_4_measure','px','','','.w-promotions'),(164749,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_4_measure','px','','','.w-promotions'),(164750,'deals-mobile','.p-reviews-info .review-info-text','bottom','-10','4','','.p-reviews-info'),(164751,'deals-mobile','.b-info-popup .info-popup.top-left div','bottom','-11','3','','.b-info-popup'),(164752,'deals-mobile','.b-info-popup .info-popup.top-left div','bottom','30','','','.b-info-popup'),(164753,'deals-mobile','.testimonials .review','bottom','-13','3','',''),(164754,'deals-mobile','.p-account-history .orders-table .status-name','bottom','7','890','','.p-account-history'),(164755,'deals-mobile','.p-account-history .orders-table .td-alignright','bottom','0','890','','.p-account-history'),(164756,'deals-mobile','.p-account-history .orders-table .order-total','bottom','45','890','','.p-account-history'),(164757,'deals-mobile','.p-account-index .orders-table .status-name','bottom','7','890','','.p-account-index'),(164758,'deals-mobile','.p-account-index .orders-table .order-total','bottom','45','890','','.p-account-index'),(164759,'deals-mobile','.p-account-index .orders-table .td-alignright','bottom','0','890','','.p-account-index'),(164760,'deals-mobile','.w-list-type-2_2 .sale','bottom','0','','','.w-list-type-2_2'),(164761,'deals-mobile','.w-list-type-2_2 .sale','bottom','0','3','','.w-list-type-2_2'),(164762,'deals-mobile','.w-list-type-2 .sale','bottom','0','','','.w-list-type-2'),(164763,'deals-mobile','.w-list-type-2 .sale','bottom','0','4','','.w-list-type-2'),(164764,'deals-mobile','.w-list-type-2 .sale','bottom','0','3','','.w-list-type-2'),(164765,'deals-mobile','.w-banner .image-text-banner.bottom-center .text-banner','bottom','0','','','.w-banner'),(164766,'deals-mobile','.w-banner .image-text-banner.bottom-left .text-banner','bottom','0','','','.w-banner'),(164767,'deals-mobile','.w-banner .image-text-banner.bottom-right .text-banner','bottom','0','','','.w-banner'),(164768,'deals-mobile','.b-slick .slick-vertical button.slick-next','bottom','0','','','.b-slick'),(164769,'deals-mobile','.b-slick .slick-vertical button.slick-prev','bottom','auto','','','.b-slick'),(164770,'deals-mobile','.b-fancybox .fancybox-title-float-wrap','bottom','0','','','.b-fancybox'),(164771,'deals-mobile','.w-list-type-1_3 #add_all','bottom','20','','','.w-list-type-1_3'),(164772,'deals-mobile','.b-fancybox .fancybox-title-over-wrap','bottom','0','','','.b-fancybox'),(164773,'deals-mobile','.b-fancybox .fancybox-overlay-fixed','bottom','0','','','.b-fancybox'),(164774,'deals-mobile','.w-list-type-2_2 .sale','bottom','0','4','','.w-list-type-2_2'),(164775,'deals-mobile','.w-list-type-1_3 .sale','bottom','0','3','','.w-list-type-1_3'),(164776,'deals-mobile','.w-list-type-1_3 .sale','bottom','0','4','','.w-list-type-1_3'),(164777,'deals-mobile','.w-list-type-1_3 .sale','bottom','0','','','.w-list-type-1_3'),(164778,'deals-mobile','.w-list-type-1_2 .sale','bottom','0','','','.w-list-type-1_2'),(164779,'deals-mobile','.w-list-type-1_2 .sale','bottom','0','3','','.w-list-type-1_2'),(164780,'deals-mobile','.w-list-type-1_2 .sale','bottom','0','4','','.w-list-type-1_2'),(164781,'deals-mobile','.w-list-type-1 .sale','bottom','0','4','','.w-list-type-1'),(164782,'deals-mobile','.w-list-type-1 .sale','bottom','0','3','','.w-list-type-1'),(164783,'deals-mobile','.w-list-type-1 .sale','bottom','0','','','.w-list-type-1'),(164784,'deals-mobile','.w-product-reviews .reviews-list .review','bottom','-13','3','','.w-product-reviews'),(164785,'deals-mobile','.w-reviews .review','bottom','-13','3','','.w-reviews'),(164786,'deals-mobile','.b-upload-file .snapshot','bottom','5','','','.b-upload-file'),(164787,'deals-mobile','.p-account-samples-history .orders-table .status-name','bottom','7','','','.p-account-samples-history'),(164788,'deals-mobile','.p-account-samples-history .orders-table .status-name','bottom','7','','','.p-account-samples-history'),(164789,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','bottom','0','','','.p-account-samples-history'),(164790,'deals-mobile','.p-account-samples-history .orders-table .order-total','bottom','45','','','.p-account-samples-history'),(164791,'deals-mobile','.p-account-samples-history .orders-table .status-name','bottom','7','','','.p-account-samples-history'),(164792,'deals-mobile','.p-account-samples-history .orders-table .order-total','bottom','45','','','.p-account-samples-history'),(164793,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','bottom','0','','','.p-account-samples-history'),(164794,'deals-mobile','.p-account-samples-history .orders-table .status-name','bottom','7','','','.p-account-samples-history'),(164795,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','bottom','0','','','.p-account-samples-history'),(164796,'deals-mobile','.p-account-samples-history .orders-table .status-name','bottom','7','','','.p-account-samples-history'),(164797,'deals-mobile','.p-account-samples-history .orders-table .order-total','bottom','45','','','.p-account-samples-history'),(164798,'deals-mobile','.p-account-samples-history .orders-table .order-total','bottom','45','','','.p-account-samples-history'),(164799,'deals-mobile','.p-account-samples-history .orders-table .order-total','bottom','45','','','.p-account-samples-history'),(164800,'deals-mobile','.p-account-samples-history .orders-table .status-name','bottom','7','','','.p-account-samples-history'),(164801,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','bottom','0','','','.p-account-samples-history'),(164802,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','bottom','0','','','.p-account-samples-history'),(164803,'deals-mobile','.p-account-samples-history .orders-table .order-total','bottom','45','','','.p-account-samples-history'),(164804,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','bottom','0','','','.p-account-samples-history'),(164805,'deals-mobile','.p-quick-order-index .all-scroll-div','bottom','0','','','.p-quick-order-index'),(164806,'deals-mobile','.w-catalog-b2b-add-button ','bottom','0','','','.w-catalog-b2b-add-button'),(164807,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','bottom','-7','','','.w-checkout-shipping-choice'),(164808,'deals-mobile','.w-product-customers-activity .customers-activity','bottom','0','','','.w-product-customers-activity'),(164809,'deals-mobile','.w-product-customers-activity .customers-activity.closed','bottom','-1000','','','.w-product-customers-activity'),(164810,'deals-mobile','.w-menu .hided.menu ul ul','box-shadow','none','','','.w-menu'),(164811,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(164812,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','box-shadow','0 2px 9px 0 rgba(0, 0, 0, 0.2)','2','','.b-multi-page-checkout'),(164813,'deals-mobile','.b-fancybox .fancybox-opened .fancybox-skin','box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(164814,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','box-shadow','none','','','.batchPr'),(164815,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','box-shadow','none','','','.batchPr'),(164816,'deals-mobile','.w-catalog-compare .compare-fix-bar.fix-bar-fix','box-shadow','0 10px 10px -10px #cccccc','','','.w-catalog-compare'),(164817,'deals-mobile','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(164818,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','box-sizing','border-box','','','.b-switch'),(164819,'deals-mobile','.b-slick .slick-slider','box-sizing','border-box','','','.b-slick'),(164820,'deals-mobile','.b-fancybox .filter-listing-loader','box-sizing','content-box','','','.b-fancybox'),(164821,'deals-mobile','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','box-sizing','border-box','','','.b-select-suggest'),(164822,'deals-mobile','.b-info-popup .info-popup div','box_shadow_blur','10','','','.b-info-popup'),(164823,'deals-mobile','.b-datepicker .datepicker-dropdown','box_shadow_blur','10','','','.b-datepicker'),(164824,'deals-mobile','.w-account-address-book .wrap','box_shadow_blur','4','','','.w-account-address-book'),(164825,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur','5','','','.w-image-maps'),(164826,'deals-mobile','.w-product-customers-activity .customers-activity','box_shadow_blur','20','','','.w-product-customers-activity'),(164827,'deals-mobile','.b-info-popup .info-popup div','box_shadow_blur_measure','px','','','.b-info-popup'),(164828,'deals-mobile','.b-datepicker .datepicker-dropdown','box_shadow_blur_measure','px','','','.b-datepicker'),(164829,'deals-mobile','.w-account-address-book .wrap','box_shadow_blur_measure','px','','','.w-account-address-book'),(164830,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur_measure','px','','','.w-image-maps'),(164831,'deals-mobile','.w-product-customers-activity .customers-activity','box_shadow_blur_measure','px','','','.w-product-customers-activity'),(164832,'deals-mobile','.b-info-popup .info-popup div','box_shadow_color','#ccc','','','.b-info-popup'),(164833,'deals-mobile','.b-datepicker .datepicker-dropdown','box_shadow_color','#ccc','','','.b-datepicker'),(164834,'deals-mobile','.w-account-address-book .wrap','box_shadow_color','#c4c4c4','','','.w-account-address-book'),(164835,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_color','#ccc','','','.w-image-maps'),(164836,'deals-mobile','.w-product-customers-activity .customers-activity','box_shadow_color','#eee','','','.w-product-customers-activity'),(164837,'deals-mobile','.b-info-popup .info-popup div','box_shadow_left','0','','','.b-info-popup'),(164838,'deals-mobile','.b-datepicker .datepicker-dropdown','box_shadow_left','0','','','.b-datepicker'),(164839,'deals-mobile','.w-account-address-book .wrap','box_shadow_left','1','','','.w-account-address-book'),(164840,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left','0','','','.w-image-maps'),(164841,'deals-mobile','.w-product-customers-activity .customers-activity','box_shadow_left','0','','','.w-product-customers-activity'),(164842,'deals-mobile','.b-info-popup .info-popup div','box_shadow_left_measure','','','','.b-info-popup'),(164843,'deals-mobile','.b-datepicker .datepicker-dropdown','box_shadow_left_measure','','','','.b-datepicker'),(164844,'deals-mobile','.w-account-address-book .wrap','box_shadow_left_measure','px','','','.w-account-address-book'),(164845,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left_measure','','','','.w-image-maps'),(164846,'deals-mobile','.w-product-customers-activity .customers-activity','box_shadow_left_measure','','','','.w-product-customers-activity'),(164847,'deals-mobile','.b-info-popup .info-popup div','box_shadow_top','0','','','.b-info-popup'),(164848,'deals-mobile','.b-datepicker .datepicker-dropdown','box_shadow_top','0','','','.b-datepicker'),(164849,'deals-mobile','.w-account-address-book .wrap','box_shadow_top','1','','','.w-account-address-book'),(164850,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top','0','','','.w-image-maps'),(164851,'deals-mobile','.w-product-customers-activity .customers-activity','box_shadow_top','0','','','.w-product-customers-activity'),(164852,'deals-mobile','.b-info-popup .info-popup div','box_shadow_top_measure','','','','.b-info-popup'),(164853,'deals-mobile','.b-datepicker .datepicker-dropdown','box_shadow_top_measure','','','','.b-datepicker'),(164854,'deals-mobile','.w-account-address-book .wrap','box_shadow_top_measure','px','','','.w-account-address-book'),(164855,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top_measure','','','','.w-image-maps'),(164856,'deals-mobile','.w-product-customers-activity .customers-activity','box_shadow_top_measure','','','','.w-product-customers-activity'),(164857,'deals-mobile','.w-menu-big li','clear','none','','','.w-menu-big'),(164858,'deals-mobile','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(164859,'deals-mobile','.w-login-block .cols','clear','both','4','','.w-login-block'),(164860,'deals-mobile','.w-login-block .guest','clear','right','','','.w-login-block'),(164861,'deals-mobile','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(164862,'deals-mobile','.w-login-block .buttons','clear','none','','','.w-login-block'),(164863,'deals-mobile','.w-product-attributes .attributes','clear','both','4','','.w-product-attributes'),(164864,'deals-mobile','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(164865,'deals-mobile','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(164866,'deals-mobile','.w-cart a.item','clear','both','4','','.w-cart'),(164867,'deals-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','clear','both','','','.p-account-trade-form'),(164868,'deals-mobile','.w-categories .item:nth-child(4n + 1)','clear','both','','','.w-categories'),(164869,'deals-mobile','.w-categories .categories','clear','both','4','','.w-categories'),(164870,'deals-mobile','.b-pagination .pagination','clear','both','4','','.b-pagination'),(164871,'deals-mobile','.w-cart-shipping-estimator .shipping-estimator','clear','both','4','','.w-cart-shipping-estimator'),(164872,'deals-mobile','.w-list-type-1_2 .right-area','clear','both','4','','.w-list-type-1_2'),(164873,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','clear','both','4','','.b-multi-page-checkout'),(164874,'deals-mobile','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(164875,'deals-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','clear','none','','','.p-wedding-registry-manage'),(164876,'deals-mobile','.w-product-bonus-points > div','clear','both','4','','.w-product-bonus-points'),(164877,'deals-mobile','.w-product-configurator .pc_attr','clear','both','863','','.w-product-configurator'),(164878,'deals-mobile','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(164879,'deals-mobile','.w-product-configurator .pc_qty','clear','both','863','','.w-product-configurator'),(164880,'deals-mobile','.p-account-address-book .address_book_row','clear','both','','','.p-account-address-book'),(164881,'deals-mobile','.p-blog-index .w-blog-sidebar .wp-widget:nth-child(2n + 1)','clear','both','890','','.p-blog-index'),(164882,'deals-mobile','.p-blog-index .entry-content','clear','both','4','','.p-blog-index'),(164883,'deals-mobile','.p-blog-index .comment-meta','clear','both','4','','.p-blog-index'),(164884,'deals-mobile','.buttons','clear','both','','',''),(164885,'deals-mobile','.w-list-type-2_2 .qty-input','clear','left','','','.w-list-type-2_2'),(164886,'deals-mobile','.w-list-type-2_2 .compare-box-item','clear','both','','','.w-list-type-2_2'),(164887,'deals-mobile','.w-list-type-2_2 .item','clear','both','','','.w-list-type-2_2'),(164888,'deals-mobile','.buttons','clear','both','4','',''),(164889,'deals-mobile','.w-list-type-2_2 .item','clear','both','4','','.w-list-type-2_2'),(164890,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','clear','right','','','.w-list-type-2_2'),(164891,'deals-mobile','.w-list-type-2_2 .add-height','clear','both','4','','.w-list-type-2_2'),(164892,'deals-mobile','.w-list-type-2 .qty-input','clear','left','','','.w-list-type-2'),(164893,'deals-mobile','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(164894,'deals-mobile','.b-form .center-buttons','clear','both','','','.b-form'),(164895,'deals-mobile','.b-product-images .main-image-box','clear','both','4','','.b-product-images'),(164896,'deals-mobile','.w-top-categories .categories','clear','both','4','','.w-top-categories'),(164897,'deals-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(164898,'deals-mobile','.p-account-trade-form .widget','clear','both','','','.p-account-trade-form'),(164899,'deals-mobile','.b-slick .slick-track','clear','both','4','','.b-slick'),(164900,'deals-mobile','.p-account-trade-form .wd-line-row-2','clear','both','4','','.p-account-trade-form'),(164901,'deals-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','clear','left','','','.p-account-trade-form'),(164902,'deals-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(164903,'deals-mobile','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(164904,'deals-mobile','.w-list-type-1_3 .qty-input','clear','left','','','.w-list-type-1_3'),(164905,'deals-mobile','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(164906,'deals-mobile','.p-wedding-registry-share .add-row','clear','both','','','.p-wedding-registry-share'),(164907,'deals-mobile','.p-wedding-registry-share .address-row','clear','both','','','.p-wedding-registry-share'),(164908,'deals-mobile','.b-slick .slick-slide','clear','none','','','.b-slick'),(164909,'deals-mobile','.w-menu-horizontal li','clear','none','','','.w-menu-horizontal'),(164910,'deals-mobile','.b-form .addresses .address-item:nth-child(2n + 1)','clear','left','','','.b-form'),(164911,'deals-mobile','.b-form .columns','clear','both','4','','.b-form'),(164912,'deals-mobile','.b-form .columns .col-2:nth-child(2n + 1)','clear','left','','','.b-form'),(164913,'deals-mobile','.b-form .addresses','clear','both','4','','.b-form'),(164914,'deals-mobile','.w-cart-give-away .ga_name','clear','both','4','','.w-cart-give-away'),(164915,'deals-mobile','.w-cart-give-away .ga_column:nth-child(2n + 1)','clear','both','','','.w-cart-give-away'),(164916,'deals-mobile','.b-form .col-right + .col-left','clear','both','','','.b-form'),(164917,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','clear','right','','','.w-list-type-2'),(164918,'deals-mobile','.w-list-type-2 .compare-box-item','clear','both','','','.w-list-type-2'),(164919,'deals-mobile','.w-list-type-2 .add-height','clear','both','4','','.w-list-type-2'),(164920,'deals-mobile','.w-list-type-1_3 .item','clear','both','','','.w-list-type-1_3'),(164921,'deals-mobile','.w-list-type-1_3 .item','clear','both','4','','.w-list-type-1_3'),(164922,'deals-mobile','.w-list-type-1_3 .compare-box-item','clear','both','','','.w-list-type-1_3'),(164923,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','clear','right','','','.w-list-type-1_3'),(164924,'deals-mobile','.w-list-type-1_3 .attributes > .attributes','clear','both','4','','.w-list-type-1_3'),(164925,'deals-mobile','.w-list-type-1_3 .add-height','clear','both','4','','.w-list-type-1_3'),(164926,'deals-mobile','.w-list-type-1_2 .qty-input','clear','left','','','.w-list-type-1_2'),(164927,'deals-mobile','.w-list-type-1_2 .item','clear','both','','','.w-list-type-1_2'),(164928,'deals-mobile','.w-list-type-1_2 .item','clear','both','4','','.w-list-type-1_2'),(164929,'deals-mobile','.w-list-type-1_2 .compare-box-item','clear','both','','','.w-list-type-1_2'),(164930,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','clear','right','','','.w-list-type-1_2'),(164931,'deals-mobile','.w-list-type-1_2 .add-height','clear','both','4','','.w-list-type-1_2'),(164932,'deals-mobile','.w-list-type-1 .qty-input','clear','left','','','.w-list-type-1'),(164933,'deals-mobile','.w-list-type-1 .compare-box-item','clear','both','','','.w-list-type-1'),(164934,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','clear','right','','','.w-list-type-1'),(164935,'deals-mobile','.w-list-type-1 .add-height','clear','both','4','','.w-list-type-1'),(164936,'deals-mobile','.w-top-categories .item:nth-child(4n + 1)','clear','both','','','.w-top-categories'),(164937,'deals-mobile','.b-form .col-right','clear','right','','','.b-form'),(164938,'deals-mobile','.b-form .col-full','clear','both','','','.b-form'),(164939,'deals-mobile','.b-form .col-left','clear','left','','','.b-form'),(164940,'deals-mobile','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(164941,'deals-mobile','.b-form .requiredM','clear','both','','','.b-form'),(164942,'deals-mobile','.w-menu-style-1 li','clear','none','','','.w-menu-style-1'),(164943,'deals-mobile','.b-products-listing .BlockBox','clear','both','4','','.b-products-listing'),(164944,'deals-mobile','.b-products-listing .products-listing','clear','both','4','','.b-products-listing'),(164945,'deals-mobile','.b-products-listing .products-listing .mix-attributes','clear','bpth','4','','.b-products-listing'),(164946,'deals-mobile','.b-messages .dataTables_wrapper > .top','clear','both','4','','.b-messages'),(164947,'deals-mobile','.b-messages .dataTables_wrapper > .bottom','clear','both','4','','.b-messages'),(164948,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(164949,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(164950,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(164951,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(164952,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(164953,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(164954,'deals-mobile','.b-trade-approval .col-right','clear','right','','','.b-trade-approval'),(164955,'deals-mobile','.b-trade-approval .col-left','clear','left','','','.b-trade-approval'),(164956,'deals-mobile','.b-trade-approval .center-buttons','clear','both','','','.b-trade-approval'),(164957,'deals-mobile','.b-trade-approval .columns','clear','both','4','','.b-trade-approval'),(164958,'deals-mobile','.w-account-address-book .button-add','clear','both','','','.w-account-address-book'),(164959,'deals-mobile','.w-account-address-book .item:nth-child(2n + 1)','clear','both','','','.w-account-address-book'),(164960,'deals-mobile','.w-blog-widget-post-listing .post:nth-child(2n+1)','clear','both','','','.w-blog-widget-post-listing'),(164961,'deals-mobile','.w-blog-widget-post-listing .post:nth-child(3n+1)','clear','none','','','.w-blog-widget-post-listing'),(164962,'deals-mobile','.w-blog-widget-post-listing .products','clear','both','4','','.w-blog-widget-post-listing'),(164963,'deals-mobile','.w-blog-widget-post-share ','clear','both','','','.w-blog-widget-post-share'),(164964,'deals-mobile','.w-cart-compare .product .image','clear','both','','','.w-cart-compare'),(164965,'deals-mobile','.w-cart-compare .product','clear','both','4','','.w-cart-compare'),(164966,'deals-mobile','.w-cart-compare .buttons','clear','none','','','.w-cart-compare'),(164967,'deals-mobile','.w-cart-compare .product .name','clear','right','','','.w-cart-compare'),(164968,'deals-mobile','.w-catalog-compare .BlockBox','clear','both','','','.w-catalog-compare'),(164969,'deals-mobile','.w-checkout-billing-address .addresses','clear','both','4','','.w-checkout-billing-address'),(164970,'deals-mobile','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-billing-address'),(164971,'deals-mobile','.w-checkout-billing-address .btn-cancel','clear','both','','','.w-checkout-billing-address'),(164972,'deals-mobile','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-shipping-address'),(164973,'deals-mobile','.w-checkout-shipping-address .addresses','clear','both','4','','.w-checkout-shipping-address'),(164974,'deals-mobile','.w-checkout-shipping-address .btn-cancel','clear','both','','','.w-checkout-shipping-address'),(164975,'deals-mobile','.w-list-b2b .attributes','clear','both','4','','.w-list-b2b'),(164976,'deals-mobile','.w-list-b2b .mix-attributes','clear','both','','','.w-list-b2b'),(164977,'deals-mobile','.w-product-available-in-warehouses .content','clear','both','4','','.w-product-available-in-warehouses'),(164978,'deals-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(164979,'deals-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(164980,'deals-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(164981,'deals-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(164982,'deals-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(164983,'deals-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(164984,'deals-mobile','.w-promotions .prom-multi-discount','clear','both','4','','.w-promotions'),(164985,'deals-mobile','.w-wedding-registry-widgets-products .qty-input','clear','none','','','.w-wedding-registry-widgets-products'),(164986,'deals-mobile','.w-wedding-registry-widgets-search-form .button','clear','both','','','.w-wedding-registry-widgets-search-form'),(164987,'deals-mobile','.w-menu-big li','clear_important','important','','','.w-menu-big'),(164988,'deals-mobile','.w-menu-style-1 li','clear_important','important','','','.w-menu-style-1'),(164989,'deals-mobile','.b-slick .slick-slide','clear_important','important','','','.b-slick'),(164990,'deals-mobile','.w-menu-horizontal li','clear_important','important','','','.w-menu-horizontal'),(164991,'deals-mobile','.w-blog-widget-post-share ','clear_important','important','','','.w-blog-widget-post-share'),(164992,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip','rect(0 0 0 0)','','','.b-select-suggest'),(164993,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip_important','important','','','.b-select-suggest'),(164994,'deals-mobile','.w-menu .menu .menu-ico','color','inherit','','','.w-menu'),(164995,'deals-mobile','.w-menu-big a','color','inherit','','','.w-menu-big'),(164996,'deals-mobile','.w-bestsellers .item','color','#183d78','3','','.w-bestsellers'),(164997,'deals-mobile','.w-bestsellers .item:first-child .counter','color','#ffffff','','','.w-bestsellers'),(164998,'deals-mobile','.w-bestsellers .counter','color','#183d78','','','.w-bestsellers'),(164999,'deals-mobile','.w-bestsellers .heading-3','color','#183d78','3','','.w-bestsellers'),(165000,'deals-mobile','.w-account .my-acc-link','color','#ffffff','3','','.w-account'),(165001,'deals-mobile','a','color','inherit','','',''),(165002,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(165003,'deals-mobile','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','color','#ffffff','','','.b-cookie-notice'),(165004,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','color','#e0e0e0','','','.b-form'),(165005,'deals-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','color','#1b4388','','','.b-form'),(165006,'deals-mobile','.w-sale .left-count-days-text','color','#fff','','','.w-sale'),(165007,'deals-mobile','.w-product-sale-ends .ends','color','#ee4225','','','.w-product-sale-ends'),(165008,'deals-mobile','.w-sale .left-count-hours-text','color','#fff','','','.w-sale'),(165009,'deals-mobile','.w-html_box .linkedin','color','#0073b0','3','','.w-html_box'),(165010,'deals-mobile','.w-html_box .instagram','color','#d02f7a','3','','.w-html_box'),(165011,'deals-mobile','.w-html_box .stumbleupon','color','#eb4924','3','','.w-html_box'),(165012,'deals-mobile','.w-html_box .pinterest','color','#bd081c','3','','.w-html_box'),(165013,'deals-mobile','.w-html_box .twitter','color','#1b95e0','3','','.w-html_box'),(165014,'deals-mobile','.w-html_box .facebook','color','#4267b2','3','','.w-html_box'),(165015,'deals-mobile','.w-sale .badge','color','#fff','','','.w-sale'),(165016,'deals-mobile','.w-html_box .google-plus','color','#dc4a38','3','','.w-html_box'),(165017,'deals-mobile','.w-menu-style-1 > ul','color','#ffffff','','','.w-menu-style-1'),(165018,'deals-mobile','.w-menu-style-1 .menu-ico','color','#ffffff','','','.w-menu-style-1'),(165019,'deals-mobile','.w-product-sale-ends .left-count-days-text','color','#fff','','','.w-product-sale-ends'),(165020,'deals-mobile','.w-product-sale-ends .left-count-hours-text','color','#fff','','','.w-product-sale-ends'),(165021,'deals-mobile','.w-cart .cart-box-link','color','#ffffff','','','.w-cart'),(165022,'deals-mobile','.w-menu-horizontal a','color','inherit','','','.w-menu-horizontal'),(165023,'deals-mobile','.w-product-collection .save','color','#00a858','','','.w-product-collection'),(165024,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','color','#1d3d76','3','','.p-account-history-info'),(165025,'deals-mobile','.p-account-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-history-info'),(165026,'deals-mobile','.p-account-index .not_fully_paid_td','color','#ee4225','','','.p-account-index'),(165027,'deals-mobile','.p-account-index .moduleRowDue td','color','#ccc','','','.p-account-index'),(165028,'deals-mobile','.w-categories .name','color','#424242','','','.w-categories'),(165029,'deals-mobile','.heading-3 .edit, h3 .edit','color','#092964','','',''),(165030,'deals-mobile','.w-catalog-listing-look .list','color','#424242','2','','.w-catalog-listing-look'),(165031,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','#000','','','.b-multi-page-checkout'),(165032,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','#616161','','','.b-multi-page-checkout'),(165033,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','#092964','4','','.b-multi-page-checkout'),(165034,'deals-mobile','.b-pass-strength span.strong-pass, .b-pass-strength span.pass-match','color','#00C853','','','.b-pass-strength'),(165035,'deals-mobile','.b-pass-strength span.bad-pass','color','#FF6D00','','','.b-pass-strength'),(165036,'deals-mobile','.b-pass-strength .short-pass, .b-pass-strength .pass-strength, .b-pass-strength .pass-no-match','color','#D32F2F','','','.b-pass-strength'),(165037,'deals-mobile','.b-pass-strength span.good-pass','color','#7CB342','','','.b-pass-strength'),(165038,'deals-mobile','.w-reviews .date','color','#999999','','','.w-reviews'),(165039,'deals-mobile','.w-quote .cart-box-link','color','#ffffff','','','.w-quote'),(165040,'deals-mobile','.w-product-reviews .reviews-list .date','color','#999999','','','.w-product-reviews'),(165041,'deals-mobile','.w-product-in-bundles .product-link','color','#424242','','','.w-product-in-bundles'),(165042,'deals-mobile','.w-catalog-listing-look .list','color','#cccccc','','','.w-catalog-listing-look'),(165043,'deals-mobile','.w-menu-slider > ul','color','#ffffff','','','.w-menu-slider'),(165044,'deals-mobile','.w-catalog-listing-look .b2b','color','#cccccc','','','.w-catalog-listing-look'),(165045,'deals-mobile','.p-blog-index .posted-on','color','#666','','','.p-blog-index'),(165046,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','#fff','3','','.b-multi-page-checkout'),(165047,'deals-mobile','.p-blog-index .reply a','color','#183d78','','','.p-blog-index'),(165048,'deals-mobile','.p-blog-index .wp-widget li','color','#183d78','3','','.p-blog-index'),(165049,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','color','#bdbdbd','','','.b-multi-page-checkout'),(165050,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading','color','#092964','','','.b-multi-page-checkout'),(165051,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','color','#fff','','','.b-multi-page-checkout'),(165052,'deals-mobile','.w-promo-code .holder','color','#e4452f','3','','.w-promo-code'),(165053,'deals-mobile','.p-wedding-registry-manage a.remove-btn','color','#000','1','','.p-wedding-registry-manage'),(165054,'deals-mobile','.p-wedding-registry-manage a.remove-btn','color','#757575','','','.p-wedding-registry-manage'),(165055,'deals-mobile','.p-wedding-registry-share h1','color','#ee4225','4','','.p-wedding-registry-share'),(165056,'deals-mobile','.w-product-bonus-points > div > div','color','#183d78','','','.w-product-bonus-points'),(165057,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','color','#1d3d76','3','','.p-account-order-pay'),(165058,'deals-mobile','.p-account-order-pay .not_fully_paid_td','color','#ee4225','','','.p-account-order-pay'),(165059,'deals-mobile','.testimonials .date','color','#999999','','',''),(165060,'deals-mobile','.testimonials .heading-3','color','#183d78','3','',''),(165061,'deals-mobile','.js-stock','color','#00a858','','',''),(165062,'deals-mobile','.testimonials .reviews-list .date','color','#999999','','',''),(165063,'deals-mobile','.p-wedding-registry-manage .wr-search button','color','#092964','3','','.p-wedding-registry-manage'),(165064,'deals-mobile','.b-pagination .pagination span','color','#ffffff','2','','.b-pagination'),(165065,'deals-mobile','.p-account-history .view_link','color','#092964','','','.p-account-history'),(165066,'deals-mobile','.p-blog-index .nav-next a','color','#999','3','','.p-blog-index'),(165067,'deals-mobile','.p-blog-index .nav-previous a','color','#999','3','','.p-blog-index'),(165068,'deals-mobile','.w-list-type-2_2 .sale','color','#ee4225','3','','.w-list-type-2_2'),(165069,'deals-mobile','.w-list-type-2_2 .price .specials','color','#ee4225','','','.w-list-type-2_2'),(165070,'deals-mobile','.w-list-type-2_2 .button-wishlist button','color','#183d78','','','.w-list-type-2_2'),(165071,'deals-mobile','.w-list-type-2_2 .button-view a','color','#183d78','','','.w-list-type-2_2'),(165072,'deals-mobile','.w-list-type-2 .sale','color','#ee4225','3','','.w-list-type-2'),(165073,'deals-mobile','.w-list-type-2 .price .specials','color','#ee4225','','','.w-list-type-2'),(165074,'deals-mobile','.p-reviews-info .review-info-text, .p-reviews-info .review-info-reviewed_by, .p-reviews-info .review-info-date','color','#424242','','','.p-reviews-info'),(165075,'deals-mobile','.rating-1, .rating-2, .rating-3, .rating-4, .rating-5','color','#183d78','','',''),(165076,'deals-mobile','.w-chat .w-chat-box a','color','#fff','3','','.w-chat'),(165077,'deals-mobile','.w-delivery-location-top-location-list .deliveryName a','color','#424242','','','.w-delivery-location-top-location-list'),(165078,'deals-mobile','.w-product-promotions .promotion-data-2 .save','color','#00a858','','','.w-product-promotions'),(165079,'deals-mobile','.w-product-promotions .promotion-full-price-discount','color','#ee4225','','','.w-product-promotions'),(165080,'deals-mobile','.p-wedding-registry-index .main-button','color','#183d78','4','','.p-wedding-registry-index'),(165081,'deals-mobile','.b-form .radio-button input[type=\"radio\"]:checked + span:before','color','#444','','','.b-form'),(165082,'deals-mobile','.p-wedding-registry-index .main-button','color','#183d78','3','','.p-wedding-registry-index'),(165083,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','color','#fff','3','','.b-form'),(165084,'deals-mobile','.p-wedding-registry-manage .links a.share-registry','color','#183d78','4','','.p-wedding-registry-manage'),(165085,'deals-mobile','.p-wedding-registry-search h1','color','#ee4225','4','','.p-wedding-registry-search'),(165086,'deals-mobile','.p-wedding-registry-search h1','color','#ee4225','3','','.p-wedding-registry-search'),(165087,'deals-mobile','.p-wedding-registry-manage h1','color','#ee4225','4','','.p-wedding-registry-manage'),(165088,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','color','#fff','','','.b-switch'),(165089,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','color','#fff','','','.b-switch'),(165090,'deals-mobile','.b-fancybox .fancybox-title-outside-wrap','color','#fff','','','.b-fancybox'),(165091,'deals-mobile','.w-tabs .accordion-heading','color','#183d78','2','','.w-tabs'),(165092,'deals-mobile','.w-list-type-1 .rating','color','#183d78','','','.w-list-type-1'),(165093,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','color','#ccc','','','.b-slick'),(165094,'deals-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','color','#1b4388','','','.w-filters'),(165095,'deals-mobile','.w-filters .mobileCollapse','color','#fff','4','','.w-filters'),(165096,'deals-mobile','.p-account-index .date_value','color','#ee4225','','','.p-account-index'),(165097,'deals-mobile','.w-tabs .tab-a','color','#183d78','2','','.w-tabs'),(165098,'deals-mobile','.btn-1','color','#ffffff','','',''),(165099,'deals-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','color','#e0e0e0','','','.w-filters'),(165100,'deals-mobile','.w-currencies .select-link','color','#092964','','','.w-currencies'),(165101,'deals-mobile','.w-filters .filter-box-head','color','#000000','','','.w-filters'),(165102,'deals-mobile','.w-filters .head-filter-widget','color','#fff','890','','.w-filters'),(165103,'deals-mobile','.w-currencies .current','color','#b0b0b0','3','','.w-currencies'),(165104,'deals-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','#bbb','3','','.w-contact-contacts'),(165105,'deals-mobile','.w-currencies .currencies-title','color','#092964','','','.w-currencies'),(165106,'deals-mobile','.w-compare-box-item .checkbox:checked + span:before','color','#fff','','','.w-compare-box-item'),(165107,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','color','#FFF','','','.b-fancybox'),(165108,'deals-mobile','.p-checkout-success .page-success','color','#eeeeee','3','','.p-checkout-success'),(165109,'deals-mobile','.b-info .info a','color','#183d78','','','.b-info'),(165110,'deals-mobile','.p-account-index .view_link','color','#092964','','','.p-account-index'),(165111,'deals-mobile','.p-account-index .view_history','color','#092964','','','.p-account-index'),(165112,'deals-mobile','.w-menu-style-1 a','color','inherit','','','.w-menu-style-1'),(165113,'deals-mobile','.w-menu-mobile .menu-ico','color','#ffffff','','','.w-menu-mobile'),(165114,'deals-mobile','.w-list-type-2_2 .sale','color','#ffffff','4','','.w-list-type-2_2'),(165115,'deals-mobile','.b-fancybox .fancybox-title-over-wrap','color','#fff','','','.b-fancybox'),(165116,'deals-mobile','.p-account-index .topAccount > li > div.points_earnt .date_value, .p-account-index .topAccount > li > div.points_earnt, .p-account-index .topAccount > li > div.points_earnt .date_title','color','#989898','3','','.p-account-index'),(165117,'deals-mobile','.p-account-index .topAccount > li > div','color','#ee4225','3','','.p-account-index'),(165118,'deals-mobile','.w-product-quantity .qty_packs .price_1','color','#bcbcbc','4','','.w-product-quantity'),(165119,'deals-mobile','.p-checkout-success .page-success .text-1','color','#092964','3','','.p-checkout-success'),(165120,'deals-mobile','.b-fancybox .fancybox-skin','color','#444','','','.b-fancybox'),(165121,'deals-mobile','.b-form .inputRequirement','color','#ee4225','','','.b-form'),(165122,'deals-mobile','.p-checkout-success .page-success .text-3','color','#ee4225','','','.p-checkout-success'),(165123,'deals-mobile','.w-sale .ends','color','#ee4225','','','.w-sale'),(165124,'deals-mobile','.w-sale .special-price','color','#ee4225','','','.w-sale'),(165125,'deals-mobile','.p-wedding-registry-share .invite-remove','color','#ee4225','','','.p-wedding-registry-share'),(165126,'deals-mobile','.w-menu-slider .menu-ico','color','#ffffff','','','.w-menu-slider'),(165127,'deals-mobile','.p-account-history .not_fully_paid_td','color','#ee4225','','','.p-account-history'),(165128,'deals-mobile','.p-account-history .moduleRowDue td','color','#ccc','','','.p-account-history'),(165129,'deals-mobile','.w-text .customer-service','color','#183d78','3','','.w-text'),(165130,'deals-mobile','.w-text .customer-service b','color','#183d78','','','.w-text'),(165131,'deals-mobile','.w-top-categories .categories h2','color','inherit','','','.w-top-categories'),(165132,'deals-mobile','.w-categories .categories h2','color','inherit','','','.w-categories'),(165133,'deals-mobile','.b-rating #stars-default .glyphicon.coloron','color','#092964','','','.b-rating'),(165134,'deals-mobile','.b-rating #stars-default .glyphicon','color','#ccc','','','.b-rating'),(165135,'deals-mobile','.b-quantity .qty-box .smaller','color','#183d78','','','.b-quantity'),(165136,'deals-mobile','.b-quantity .qty-box .bigger','color','#183d78','','','.b-quantity'),(165137,'deals-mobile','.b-fancybox .fancybox-nav span','color','#fff','','','.b-fancybox'),(165138,'deals-mobile','.w-top-categories .name','color','#424242','','','.w-top-categories'),(165139,'deals-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','color','#183d78','3','','.w-cart-discount-coupon'),(165140,'deals-mobile','.p-account-index .date_title','color','#000','','','.p-account-index'),(165141,'deals-mobile','.w-catalog-listing-look .grid','color','#424242','2','','.w-catalog-listing-look'),(165142,'deals-mobile','.w-list-type-1_3 .price .specials','color','#ee4225','','','.w-list-type-1_3'),(165143,'deals-mobile','.p-account-index .account_info .info .info_span','color','#000','','','.p-account-index'),(165144,'deals-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','color','#183d78','3','','.w-cart-gift-certificate'),(165145,'deals-mobile','.w-catalog-listing-look .grid','color','#cccccc','','','.w-catalog-listing-look'),(165146,'deals-mobile','.w-search .search','color','#fff','3','','.w-search'),(165147,'deals-mobile','.w-catalog-listing-look .b2b','color','#424242','2','','.w-catalog-listing-look'),(165148,'deals-mobile','.price .specials','color','#ee4225','','',''),(165149,'deals-mobile','.w-list-type-2 .button-view a','color','#183d78','','','.w-list-type-2'),(165150,'deals-mobile','.w-list-type-1_3 .sale','color','#ffffff','4','','.w-list-type-1_3'),(165151,'deals-mobile','.w-list-type-1_3 .sale','color','#ee4225','3','','.w-list-type-1_3'),(165152,'deals-mobile','.p-wedding-registry-view h1','color','#ee4225','4','','.p-wedding-registry-view'),(165153,'deals-mobile','.w-list-type-2 .button-wishlist button','color','#183d78','','','.w-list-type-2'),(165154,'deals-mobile','.price .special','color','#ee4225','','',''),(165155,'deals-mobile','.p-wedding-registry-manage h1','color','#ee4225','3','','.p-wedding-registry-manage'),(165156,'deals-mobile','.p-wedding-registry-share h1','color','#ee4225','3','','.p-wedding-registry-share'),(165157,'deals-mobile','.p-wedding-registry-view h1','color','#ee4225','3','','.p-wedding-registry-view'),(165158,'deals-mobile','.w-list-type-2 .sale','color','#ffffff','4','','.w-list-type-2'),(165159,'deals-mobile','.btn-3','color','#183d78','','',''),(165160,'deals-mobile','.btn-2','color','#ffffff','','',''),(165161,'deals-mobile','.btn','color','#183d78','','',''),(165162,'deals-mobile','.w-list-type-1_3 .button-wishlist button','color','#183d78','','','.w-list-type-1_3'),(165163,'deals-mobile','.w-list-type-1_3 .button-view a','color','#183d78','','','.w-list-type-1_3'),(165164,'deals-mobile','.w-list-type-1_2 .sale','color','#ffffff','4','','.w-list-type-1_2'),(165165,'deals-mobile','.w-list-type-1_2 .price .specials','color','#ee4225','','','.w-list-type-1_2'),(165166,'deals-mobile','.w-list-type-1_2 .sale','color','#ee4225','3','','.w-list-type-1_2'),(165167,'deals-mobile','.b-bottom .pop-up-close','color','#999','','','.b-bottom'),(165168,'deals-mobile','.w-list-type-1_2 .button-wishlist button','color','#183d78','','','.w-list-type-1_2'),(165169,'deals-mobile','.b-bottom .pop-up-close','color','#777','1','','.b-bottom'),(165170,'deals-mobile','.w-list-type-1 .sale','color','#ffffff','4','','.w-list-type-1'),(165171,'deals-mobile','.w-list-type-1 .sale','color','#ee4225','3','','.w-list-type-1'),(165172,'deals-mobile','.w-list-type-1_2 .button-view a','color','#183d78','','','.w-list-type-1_2'),(165173,'deals-mobile','.heading-4 .edit, h4 .edit','color','#092964','','',''),(165174,'deals-mobile','.w-list-type-1 .button-wishlist button','color','#183d78','','','.w-list-type-1'),(165175,'deals-mobile','.w-filters .open','color','#15286f','3','','.w-filters'),(165176,'deals-mobile','.in-stock','color','#00a858','','',''),(165177,'deals-mobile','.out-stock','color','#ee4225','','',''),(165178,'deals-mobile','.transit','color','#a47615','','',''),(165179,'deals-mobile','.w-filters .view_more','color','#15286f','','','.w-filters'),(165180,'deals-mobile','.w-list-type-1 .button-view a','color','#183d78','','','.w-list-type-1'),(165181,'deals-mobile','.w-languages .current','color','#b0b0b0','3','','.w-languages'),(165182,'deals-mobile','.p-account-index .date_value strong','color','#000','','','.p-account-index'),(165183,'deals-mobile','.w-reviews .reviews-list .date','color','#999999','','','.w-reviews'),(165184,'deals-mobile','.w-reviews .heading-3','color','#183d78','3','','.w-reviews'),(165185,'deals-mobile','.w-search .button-search','color','#092964','3','','.w-search'),(165186,'deals-mobile','.w-socials .post_item > div.fb_post_item','color','#4267b2','3','','.w-socials'),(165187,'deals-mobile','.w-socials .post_item > div.tw_post_item','color','#1da1f2','3','','.w-socials'),(165188,'deals-mobile','.w-socials .post_item_name a','color','#424242','','','.w-socials'),(165189,'deals-mobile','.w-socials .post_item > div.insta_post_item','color','#f53d42','3','','.w-socials'),(165190,'deals-mobile','.btn-del','color','#de0404','4','',''),(165191,'deals-mobile','.b-form .required','color','#ed4224','','','.b-form'),(165192,'deals-mobile','.b-form .required-message','color','#ed4224','','','.b-form'),(165193,'deals-mobile','.b-form .middle-form label','color','#000','','','.b-form'),(165194,'deals-mobile','.p-account-address-book .rightMes ul','color','#ee4225','','','.p-account-address-book'),(165195,'deals-mobile','.p-account-address-book .leftMes ul','color','#ee4225','','','.p-account-address-book'),(165196,'deals-mobile','.p-account-address-book .leftMes div','color','#ee4225','','','.p-account-address-book'),(165197,'deals-mobile','.b-info .info','color','#ee4225','','','.b-info'),(165198,'deals-mobile','.b-info-popup .info-popup','color','#ee4225','3','','.b-info-popup'),(165199,'deals-mobile','.b-products-listing .products-listing .bonus-points span:first-child','color','#183d78','','','.b-products-listing'),(165200,'deals-mobile','.b-products-listing .products-listing .bonus-points-cost','color','#183d78','3','','.b-products-listing'),(165201,'deals-mobile','.b-products-listing .products-listing .bonus-points-price','color','#183d78','3','','.b-products-listing'),(165202,'deals-mobile','.b-products-listing .products-listing .name a','color','#424242','','','.b-products-listing'),(165203,'deals-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','color','#00a858','','','.b-products-listing'),(165204,'deals-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','color','#00a858','','','.b-products-listing'),(165205,'deals-mobile','.b-products-listing .products-listing h2','color','inherit','','','.b-products-listing'),(165206,'deals-mobile','.b-products-listing .promos-info .promo-name','color','#ee4225','','','.b-products-listing'),(165207,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','#424242','','','.b-data-table'),(165208,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','#183d78','','','.b-data-table'),(165209,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','#183d78','1','','.b-data-table'),(165210,'deals-mobile','.b-delete-account .delete-box .delete-message','color','#ee4225','','','.b-delete-account'),(165211,'deals-mobile','.b-email-editor .special-price','color','#ee4225','','','.b-email-editor'),(165212,'deals-mobile','.b-email-editor .name a','color','#424242','','','.b-email-editor'),(165213,'deals-mobile','.b-email-editor a','color','#424242','','','.b-email-editor'),(165214,'deals-mobile','.b-email-editor .name a','color','#424242','','','.b-email-editor'),(165215,'deals-mobile','.b-email-editor .special-price','color','#ee4225','','','.b-email-editor'),(165216,'deals-mobile','.b-email-editor .price','color','#183d78','','','.b-email-editor'),(165217,'deals-mobile','.b-email-editor .price','color','#183d78','','','.b-email-editor'),(165218,'deals-mobile','.b-email-editor .price','color','#183d78','','','.b-email-editor'),(165219,'deals-mobile','.b-email-editor a','color','#424242','','','.b-email-editor'),(165220,'deals-mobile','.b-email-editor .special-price','color','#ee4225','','','.b-email-editor'),(165221,'deals-mobile','.b-email-editor .name a','color','#424242','','','.b-email-editor'),(165222,'deals-mobile','.b-email-editor .price','color','#183d78','','','.b-email-editor'),(165223,'deals-mobile','.b-email-editor .special-price','color','#ee4225','','','.b-email-editor'),(165224,'deals-mobile','.b-email-editor .name a','color','#424242','','','.b-email-editor'),(165225,'deals-mobile','.b-email-editor .name a','color','#424242','','','.b-email-editor'),(165226,'deals-mobile','.b-email-editor a','color','#424242','','','.b-email-editor'),(165227,'deals-mobile','.b-email-editor a','color','#424242','','','.b-email-editor'),(165228,'deals-mobile','.b-email-editor .name a','color','#424242','','','.b-email-editor'),(165229,'deals-mobile','.b-email-editor a','color','#424242','','','.b-email-editor'),(165230,'deals-mobile','.b-email-editor a','color','#424242','','','.b-email-editor'),(165231,'deals-mobile','.b-email-editor .special-price','color','#ee4225','','','.b-email-editor'),(165232,'deals-mobile','.b-email-editor .special-price','color','#ee4225','','','.b-email-editor'),(165233,'deals-mobile','.b-email-editor .price','color','#183d78','','','.b-email-editor'),(165234,'deals-mobile','.b-email-editor .price','color','#183d78','','','.b-email-editor'),(165235,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2','color','#141412','','','.b-menu-style-1'),(165236,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','color','#183d78','','','.b-menu-style-1'),(165237,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','color','#fff','','','.b-menu-style-2'),(165238,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','color','#fff','','','.b-menu-style-2'),(165239,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','color','#183d78','','','.b-menu-style-2'),(165240,'deals-mobile','.b-messages .messMenuButton span','color','#183d78','','','.b-messages'),(165241,'deals-mobile','.b-messages .messages-menu li a','color','#424242','','','.b-messages'),(165242,'deals-mobile','.b-messages .content_management_attach','color','#183d78','','','.b-messages'),(165243,'deals-mobile','.b-messages .content_management_attach button','color','#183d78','','','.b-messages'),(165244,'deals-mobile','.b-messages .select2-search-choice-close','color','#757575','3','','.b-messages'),(165245,'deals-mobile','.b-personal-catalog-popup #personal_catalog_popup .show-all-lists','color','#183d78','','','.b-personal-catalog-popup'),(165246,'deals-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','color','#424242','','','.b-select-suggest'),(165247,'deals-mobile','.b-select-suggest .select2-drop','color','#424242','','','.b-select-suggest'),(165248,'deals-mobile','.b-select-suggest .select2-container .select2-choice','color','#424242','','','.b-select-suggest'),(165249,'deals-mobile','.b-select-suggest .select2-results .select2-highlighted','color','#424242','','','.b-select-suggest'),(165250,'deals-mobile','.b-select-suggest .select2-results .select2-highlighted ul','color','#424242','','','.b-select-suggest'),(165251,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','color','#424242','','','.b-select-suggest'),(165252,'deals-mobile','.b-select-suggest .select2-default','color','#757575','','','.b-select-suggest'),(165253,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','color','#424242','','','.b-select-suggest'),(165254,'deals-mobile','.b-trade-approval .steps-bar li.current a','color','#fff','','','.b-trade-approval'),(165255,'deals-mobile','.b-trade-approval .middle-form label','color','#424242','','','.b-trade-approval'),(165256,'deals-mobile','.b-upload-file .snapshot','color','#757575','','','.b-upload-file'),(165257,'deals-mobile','.b-upload-files .remove-file','color','#ee4225','3','','.b-upload-files'),(165258,'deals-mobile','.b-warehouses-popup a.warehouses-popup-link','color','#424242','','','.b-warehouses-popup'),(165259,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','color','#ee4225','','','.b-warehouses-popup'),(165260,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','color','#00a858','','','.b-warehouses-popup'),(165261,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','color','#183d78','','','.b-warehouses-popup'),(165262,'deals-mobile','.batchPr .checkbox input:checked + span:before','color','#ffffff','','','.batchPr'),(165263,'deals-mobile','.batchPr .btn-batch-remove','color','#fff','','','.batchPr'),(165264,'deals-mobile','.bell-ico .heading-2','color','#183d78','3','','.bell-ico'),(165265,'deals-mobile','.heading-ordered-items .heading-4','color','#183d78','3','','.heading-ordered-items'),(165266,'deals-mobile','.heading-saved-lists .heading-4','color','#183d78','3','','.heading-saved-lists'),(165267,'deals-mobile','.heading-settings .heading-4','color','#183d78','3','','.heading-settings'),(165268,'deals-mobile','.p-account-samples-history .moduleRowDue td','color','#cccccc','','','.p-account-samples-history'),(165269,'deals-mobile','.p-account-samples-history .moduleRowDue td','color','#cccccc','','','.p-account-samples-history'),(165270,'deals-mobile','.p-account-samples-history .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history'),(165271,'deals-mobile','.p-account-samples-history .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history'),(165272,'deals-mobile','.p-account-samples-history .view_link','color','#183d78','','','.p-account-samples-history'),(165273,'deals-mobile','.p-account-samples-history .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history'),(165274,'deals-mobile','.p-account-samples-history .view_link','color','#183d78','','','.p-account-samples-history'),(165275,'deals-mobile','.p-account-samples-history .moduleRowDue td','color','#cccccc','','','.p-account-samples-history'),(165276,'deals-mobile','.p-account-samples-history .moduleRowDue td','color','#cccccc','','','.p-account-samples-history'),(165277,'deals-mobile','.p-account-samples-history .moduleRowDue td','color','#cccccc','','','.p-account-samples-history'),(165278,'deals-mobile','.p-account-samples-history .view_link','color','#183d78','','','.p-account-samples-history'),(165279,'deals-mobile','.p-account-samples-history .moduleRowDue td','color','#cccccc','','','.p-account-samples-history'),(165280,'deals-mobile','.p-account-samples-history .view_link','color','#183d78','','','.p-account-samples-history'),(165281,'deals-mobile','.p-account-samples-history .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history'),(165282,'deals-mobile','.p-account-samples-history .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history'),(165283,'deals-mobile','.p-account-samples-history .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history'),(165284,'deals-mobile','.p-account-samples-history .view_link','color','#183d78','','','.p-account-samples-history'),(165285,'deals-mobile','.p-account-samples-history .view_link','color','#183d78','','','.p-account-samples-history'),(165286,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history-info'),(165287,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history-info'),(165288,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','color','#183d78','3','','.p-account-samples-history-info'),(165289,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','color','#183d78','3','','.p-account-samples-history-info'),(165290,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','color','#183d78','3','','.p-account-samples-history-info'),(165291,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','color','#183d78','3','','.p-account-samples-history-info'),(165292,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history-info'),(165293,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history-info'),(165294,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','color','#183d78','3','','.p-account-samples-history-info'),(165295,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','color','#183d78','3','','.p-account-samples-history-info'),(165296,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history-info'),(165297,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','color','#ee4225','','','.p-account-samples-history-info'),(165298,'deals-mobile','.p-account-update .main-text a','color','#183d78','','','.p-account-update'),(165299,'deals-mobile','.p-account-update .main-text a','color','#183d78','','','.p-account-update'),(165300,'deals-mobile','.p-account-update .main-text a','color','#183d78','','','.p-account-update'),(165301,'deals-mobile','.p-account-update .main-text a','color','#183d78','','','.p-account-update'),(165302,'deals-mobile','.p-account-update .main-text a','color','#183d78','','','.p-account-update'),(165303,'deals-mobile','.p-account-update .main-text a','color','#183d78','','','.p-account-update'),(165304,'deals-mobile','.p-catalog-product .pn-direction','color','#183d78','','','.p-catalog-product'),(165305,'deals-mobile','.p-catalog-product .pn-image','color','#cccccc','3','','.p-catalog-product'),(165306,'deals-mobile','.p-payer-order-confirmation .discount-ico','color','#183d78','3','','.p-payer-order-confirmation'),(165307,'deals-mobile','.p-payer-order-confirmation .ship-ico','color','#183d78','3','','.p-payer-order-confirmation'),(165308,'deals-mobile','.p-payer-order-confirmation .comment-ico','color','#183d78','3','','.p-payer-order-confirmation'),(165309,'deals-mobile','.p-payer-order-confirmation .order-ico','color','#183d78','3','','.p-payer-order-confirmation'),(165310,'deals-mobile','.p-payer-order-confirmation .pay-ico','color','#183d78','3','','.p-payer-order-confirmation'),(165311,'deals-mobile','.p-payer-order-pay .ship-ico','color','#183d78','3','','.p-payer-order-pay'),(165312,'deals-mobile','.p-payer-order-pay .pay-ico','color','#183d78','3','','.p-payer-order-pay'),(165313,'deals-mobile','.p-payer-order-pay .comment-ico','color','#183d78','3','','.p-payer-order-pay'),(165314,'deals-mobile','.p-payer-order-pay .order-ico','color','#183d78','3','','.p-payer-order-pay'),(165315,'deals-mobile','.p-payer-order-pay .discount-ico','color','#183d78','3','','.p-payer-order-pay'),(165316,'deals-mobile','.p-quick-order-index .all-scroll-div','color','#ffffff','','','.p-quick-order-index'),(165317,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','#183d78','1','','.p-quick-order-index'),(165318,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','#183d78','','','.p-quick-order-index'),(165319,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','#424242','','','.p-quick-order-index'),(165320,'deals-mobile','.p-quote-checkout-success .page-success .text-1','color','#183d78','3','','.p-quote-checkout-success'),(165321,'deals-mobile','.p-quote-checkout-success .page-success .text-1','color','#183d78','3','','.p-quote-checkout-success'),(165322,'deals-mobile','.p-quote-checkout-success .page-success .text-3','color','#ee4225','','','.p-quote-checkout-success'),(165323,'deals-mobile','.p-quote-checkout-success .page-success .text-3','color','#ee4225','','','.p-quote-checkout-success'),(165324,'deals-mobile','.p-quote-checkout-success .page-success .text-3','color','#ee4225','','','.p-quote-checkout-success'),(165325,'deals-mobile','.p-quote-checkout-success .page-success .text-1','color','#183d78','3','','.p-quote-checkout-success'),(165326,'deals-mobile','.p-quote-checkout-success .page-success .text-1','color','#183d78','3','','.p-quote-checkout-success'),(165327,'deals-mobile','.p-quote-checkout-success .page-success .text-3','color','#ee4225','','','.p-quote-checkout-success'),(165328,'deals-mobile','.p-quote-checkout-success .page-success .text-1','color','#183d78','3','','.p-quote-checkout-success'),(165329,'deals-mobile','.p-quote-checkout-success .page-success .text-1','color','#183d78','3','','.p-quote-checkout-success'),(165330,'deals-mobile','.p-quote-checkout-success .page-success .text-3','color','#ee4225','','','.p-quote-checkout-success'),(165331,'deals-mobile','.p-quote-checkout-success .page-success .text-3','color','#ee4225','','','.p-quote-checkout-success'),(165332,'deals-mobile','.p-sample-checkout-success .page-success .text-3','color','#ee4225','','','.p-sample-checkout-success'),(165333,'deals-mobile','.p-sample-checkout-success .page-success .text-1','color','#183d78','3','','.p-sample-checkout-success'),(165334,'deals-mobile','.savings-ico .heading-2','color','#00a858','3','','.savings-ico'),(165335,'deals-mobile','.shipping-ico .heading-2','color','#183d78','3','','.shipping-ico'),(165336,'deals-mobile','.shipping-ico .heading-2','color','#00a858','3','','.shipping-ico'),(165337,'deals-mobile','.shipping-ico .heading-2','color','#00a858','3','','.shipping-ico'),(165338,'deals-mobile','.w-account-address-book .add_item a.disabled-link','color','#eaeaea','','','.w-account-address-book'),(165339,'deals-mobile','.w-account-address-book .add_item a','color','#c4c4c4','','','.w-account-address-book'),(165340,'deals-mobile','.w-account-personal-catalog .list-switcher a','color','#183d78','2','','.w-account-personal-catalog'),(165341,'deals-mobile','.w-blog-widget-categories-list a','color','#424242','','','.w-blog-widget-categories-list'),(165342,'deals-mobile','.w-blog-widget-most-popular-posts a','color','#424242','','','.w-blog-widget-most-popular-posts'),(165343,'deals-mobile','.w-blog-widget-post-comments-count span','color','#CEC0A6','3','','.w-blog-widget-post-comments-count'),(165344,'deals-mobile','.w-blog-widget-post-date ','color','#424242','','','.w-blog-widget-post-date'),(165345,'deals-mobile','.w-blog-widget-post-listing .post_comment','color','#CEC0A6','3','','.w-blog-widget-post-listing'),(165346,'deals-mobile','.w-blog-widget-post-listing .post_tagged a','color','#424242','','','.w-blog-widget-post-listing'),(165347,'deals-mobile','.w-blog-widget-post-listing .post_name a','color','#424242','','','.w-blog-widget-post-listing'),(165348,'deals-mobile','.w-blog-widget-post-share .facebook-btn','color','#424242','3','','.w-blog-widget-post-share'),(165349,'deals-mobile','.w-blog-widget-post-share .pinterest-btn','color','#424242','3','','.w-blog-widget-post-share'),(165350,'deals-mobile','.w-blog-widget-post-share .twitter-btn','color','#424242','3','','.w-blog-widget-post-share'),(165351,'deals-mobile','.w-blog-widget-post-share .printto','color','#CEC0A6','3','','.w-blog-widget-post-share'),(165352,'deals-mobile','.w-blog-widget-post-share .mailto','color','#CEC0A6','3','','.w-blog-widget-post-share'),(165353,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','color','#424242','3','','.w-blog-widget-related-posts'),(165354,'deals-mobile','.w-blog-widget-related-posts .post_content a','color','#AC4A4B','','','.w-blog-widget-related-posts'),(165355,'deals-mobile','.w-blog-widget-related-posts-by-category .post_content a','color','#424242','','','.w-blog-widget-related-posts-by-category'),(165356,'deals-mobile','.w-blog-widget-tag-cloud a','color','#424242','','','.w-blog-widget-tag-cloud'),(165357,'deals-mobile','.w-cart-bonus-points .title','color','#00a858','3','','.w-cart-bonus-points'),(165358,'deals-mobile','.w-cart-compare .product .name a','color','#424242','','','.w-cart-compare'),(165359,'deals-mobile','.w-cart-compare .cart-name a','color','#424242','','','.w-cart-compare'),(165360,'deals-mobile','.w-cart-compare .delete-cart','color','#424242','3','','.w-cart-compare'),(165361,'deals-mobile','.w-cart-compare .product-actions .dropdown-toggle','color','#757575','','','.w-cart-compare'),(165362,'deals-mobile','.w-cart-credit-amount .amount-title','color','#00a858','3','','.w-cart-credit-amount'),(165363,'deals-mobile','.w-cart-credit-amount #credit_modules_message.error','color','#ee4225','','','.w-cart-credit-amount'),(165364,'deals-mobile','.w-cart-credit-amount #credit_modules_message','color','#00a858','','','.w-cart-credit-amount'),(165365,'deals-mobile','.w-catalog-b2b-add-button ','color','#ffffff','','','.w-catalog-b2b-add-button'),(165366,'deals-mobile','.w-catalog-compare .checkbox input:checked + span:before','color','#999999','','','.w-catalog-compare'),(165367,'deals-mobile','.w-catalog-compare span.btn-preloader','color','#183d78','3','','.w-catalog-compare'),(165368,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','color','#183d78','2','','.w-catalog-compare'),(165369,'deals-mobile','.w-catalog-compare .cross-box .return','color','#183d78','','','.w-catalog-compare'),(165370,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','color','#183d78','3','','.w-catalog-compare'),(165371,'deals-mobile','.w-catalog-paging ','color','#ffffff','2','','.w-catalog-paging'),(165372,'deals-mobile','.w-checkout-shipping-choice span','color','#183d78','','','.w-checkout-shipping-choice'),(165373,'deals-mobile','.w-checkout-shipping-choice input:checked + span','color','#ffffff','','','.w-checkout-shipping-choice'),(165374,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','color','#4a4a4a','','','.w-communication-new-topic'),(165375,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','color','#4a4a4a','','','.w-communication-new-topic'),(165376,'deals-mobile','.w-coupons-and-vauchers-checkout #credit_modules_message.error','color','#ee4225','','','.w-coupons-and-vauchers-checkout'),(165377,'deals-mobile','.w-coupons-and-vauchers-checkout #credit_modules_message','color','#00a858','','','.w-coupons-and-vauchers-checkout'),(165378,'deals-mobile','.w-delivery-day .ends','color','#ee4225','','','.w-delivery-day'),(165379,'deals-mobile','.w-delivery-day .left-count-days-text, .w-delivery-day .left-count-hours-text, .w-delivery-day .left-count-minutes-text, .w-delivery-day .left-count-seconds-text','color','#ffffff','','','.w-delivery-day'),(165380,'deals-mobile','.w-image-maps .float-items .item .description','color','#424242','','','.w-image-maps'),(165381,'deals-mobile','.w-image-maps .categories-items .item .description','color','#424242','','','.w-image-maps'),(165382,'deals-mobile','.w-image-maps .default-links .item .description','color','#424242','','','.w-image-maps'),(165383,'deals-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','color','#757575','3','','.w-multi-cart-actions'),(165384,'deals-mobile','.w-personal-gift-status-bar .end-date','color','#183d78','3','','.w-personal-gift-status-bar'),(165385,'deals-mobile','.w-personal-gift-status-bar .end-label','color','#183d78','','','.w-personal-gift-status-bar'),(165386,'deals-mobile','.w-personal-gift-status-bar .inform','color','#183d78','4','','.w-personal-gift-status-bar'),(165387,'deals-mobile','.w-personal-gift-status-bar .start-label','color','#183d78','','','.w-personal-gift-status-bar'),(165388,'deals-mobile','.w-product-custom-bundle .save','color','#00a858','','','.w-product-custom-bundle'),(165389,'deals-mobile','.w-product-custom-bundle .save','color','#00a858','','','.w-product-custom-bundle'),(165390,'deals-mobile','.w-product-custom-bundle .save','color','#00a858','','','.w-product-custom-bundle'),(165391,'deals-mobile','.w-product-custom-bundle .save','color','#00a858','','','.w-product-custom-bundle'),(165392,'deals-mobile','.w-product-custom-bundle .save','color','#00a858','','','.w-product-custom-bundle'),(165393,'deals-mobile','.w-product-custom-bundle .save','color','#00a858','','','.w-product-custom-bundle'),(165394,'deals-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','color','#f8a100','3','','.w-promotions'),(165395,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','color','#ee4225','','','.w-promotions'),(165396,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','color','#ee4225','','','.w-promotions'),(165397,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','color','#ee4225','','','.w-promotions'),(165398,'deals-mobile','.w-promotions .promo-salemaker .discount','color','#ff6d00','','','.w-promotions'),(165399,'deals-mobile','.w-promotions .promo-cart-discount .item a','color','#424242','','','.w-promotions'),(165400,'deals-mobile','.w-promotions .promo-salemaker .content a','color','#424242','','','.w-promotions'),(165401,'deals-mobile','.w-promotions .specials_category .heading-3','color','#ff6d00','','','.w-promotions'),(165402,'deals-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .specials_category .promo-conditions','color','#ff6d00','3','','.w-promotions'),(165403,'deals-mobile','.w-promotions .specials_category .promo-salemaker .content a, .w-promotions .specials_category .promo-date','color','#ff6d00','3','','.w-promotions'),(165404,'deals-mobile','.w-promotions .cart_discount .heading-3','color','#f8a100','','','.w-promotions'),(165405,'deals-mobile','.w-promotions .cart_discount .promo-date','color','#f8a100','3','','.w-promotions'),(165406,'deals-mobile','.w-promotions .prom-multi-discount .promo-range, .w-promotions .prom-multi-discount > .heading','color','#ee4225','3','','.w-promotions'),(165407,'deals-mobile','.w-promotions .multidiscount .promo-date, .w-promotions .multidiscount .heading-3','color','#ee4225','','','.w-promotions'),(165408,'deals-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','color','#424242','','','.w-promotions'),(165409,'deals-mobile','.w-reviews-content .date','color','#cccccc','','','.w-reviews-content'),(165410,'deals-mobile','.w-reviews-content .product-name a','color','#183d78','','','.w-reviews-content'),(165411,'deals-mobile','.w-social-links .google-plus','color','#ee4225','3','','.w-social-links'),(165412,'deals-mobile','.w-social-links .twitter','color','#1da1f2','3','','.w-social-links'),(165413,'deals-mobile','.w-social-links .stumbleupon','color','#ee4225','3','','.w-social-links'),(165414,'deals-mobile','.w-social-links .facebook','color','#183d78','3','','.w-social-links'),(165415,'deals-mobile','.w-social-links .linkedin','color','#183d78','3','','.w-social-links'),(165416,'deals-mobile','.w-social-links .instagram','color','#ee4225','3','','.w-social-links'),(165417,'deals-mobile','.w-social-links .pinterest','color','#ee4225','3','','.w-social-links'),(165418,'deals-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','color','#fff','','','.w-taxable'),(165419,'deals-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','color','#fff','','','.w-taxable'),(165420,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','color','#f52f1b','','','.w-upload-customer-id-upload-customer-id-form'),(165421,'deals-mobile','.w-wedding-registry-widgets-delete-link a','color','#cccccc','4','','.w-wedding-registry-widgets-delete-link'),(165422,'deals-mobile','.w-wedding-registry-widgets-manage-names .names-separator','color','#ee4225','','','.w-wedding-registry-widgets-manage-names'),(165423,'deals-mobile','.w-wedding-registry-widgets-products .remove-btn','color','#757575','3','','.w-wedding-registry-widgets-products'),(165424,'deals-mobile','.w-wedding-registry-widgets-share-link a','color','#cccccc','4','','.w-wedding-registry-widgets-share-link'),(165425,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.b-data-table'),(165426,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.b-data-table'),(165427,'deals-mobile','.b-select-suggest .select2-default','color_important','important','','','.b-select-suggest'),(165428,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.p-quick-order-index'),(165429,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.p-quick-order-index'),(165430,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','column-count','4','','','.b-menu-style-1'),(165431,'deals-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','content','\\f067','3','','.w-menu'),(165432,'deals-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','content','\\f068','3','','.w-menu'),(165433,'deals-mobile','.w-menu .menu .menu-ico','content','\\e91b','3','','.w-menu'),(165434,'deals-mobile','.w-menu-slider .close','content','\\f00d','3','','.w-menu-slider'),(165435,'deals-mobile','.w-bestsellers .item:first-child:before','content','\\e90c','','','.w-bestsellers'),(165436,'deals-mobile','.w-bestsellers .heading-3','content','\\e903','3','','.w-bestsellers'),(165437,'deals-mobile','.w-bestsellers .item','content','\\e90b','3','','.w-bestsellers'),(165438,'deals-mobile','.w-account .my-acc-link','content','\\f007','3','','.w-account'),(165439,'deals-mobile','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(165440,'deals-mobile','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(165441,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','content','\\f1db','','','.b-form'),(165442,'deals-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','content','\\f058','','','.b-form'),(165443,'deals-mobile','.w-login-block .cols','content','\\_','4','','.w-login-block'),(165444,'deals-mobile','.w-list-type-2_2 .sale','content','SALE','4','','.w-list-type-2_2'),(165445,'deals-mobile','.w-html_box .stumbleupon','content','\\f1a4','3','','.w-html_box'),(165446,'deals-mobile','.w-html_box .twitter','content','\\f099','3','','.w-html_box'),(165447,'deals-mobile','.w-html_box .linkedin','content','\\f0e1','3','','.w-html_box'),(165448,'deals-mobile','.w-html_box .instagram','content','\\f16d','3','','.w-html_box'),(165449,'deals-mobile','.w-html_box .pinterest','content','\\f0d2','3','','.w-html_box'),(165450,'deals-mobile','.w-html_box .facebook','content','\\f230','3','','.w-html_box'),(165451,'deals-mobile','.w-html_box .google-plus','content','\\f2b3','3','','.w-html_box'),(165452,'deals-mobile','.w-product-attributes .attributes','content','\\_','4','','.w-product-attributes'),(165453,'deals-mobile','.w-product-wedding-registry-button .btn','content','\\_','3','','.w-product-wedding-registry-button'),(165454,'deals-mobile','.w-cart a.item','content','\\_','4','','.w-cart'),(165455,'deals-mobile','.w-cart .cart-box-link','content','\\e90d','3','','.w-cart'),(165456,'deals-mobile','.w-cart .qty','content','\\274c','4','','.w-cart'),(165457,'deals-mobile','.w-categories .categories','content','\\_','4','','.w-categories'),(165458,'deals-mobile','.w-catalog-listing-look .list','content','\\f00b','3','','.w-catalog-listing-look'),(165459,'deals-mobile','.b-pagination .pagination .prev','content','\\f104','3','','.b-pagination'),(165460,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','content','\\e917','4','','.b-multi-page-checkout'),(165461,'deals-mobile','.b-pagination .pagination','content','\\_','4','','.b-pagination'),(165462,'deals-mobile','.b-pagination .pagination .next','content','\\f105','3','','.b-pagination'),(165463,'deals-mobile','.w-quote .cart-box-link','content','\\e90d','3','','.w-quote'),(165464,'deals-mobile','.b-product-images .main-image-box','content','\\_','4','','.b-product-images'),(165465,'deals-mobile','.p-checkout-success .page-success','content','\\_','863,3','','.p-checkout-success'),(165466,'deals-mobile','.w-cart-shipping-estimator .shipping-estimator','content','\\_','4','','.w-cart-shipping-estimator'),(165467,'deals-mobile','.w-list-type-2_2 .sale','content','\\e909','3','','.w-list-type-2_2'),(165468,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','content','\\f00c','3','','.b-multi-page-checkout'),(165469,'deals-mobile','.p-blog-index .nav-previous a','content','\\f137','3','','.p-blog-index'),(165470,'deals-mobile','.p-blog-index .wp-widget li','content','\\f111','3','','.p-blog-index'),(165471,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','content','\\_','4','','.b-multi-page-checkout'),(165472,'deals-mobile','.p-checkout-success .page-success','content','\\e90c','3','','.p-checkout-success'),(165473,'deals-mobile','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(165474,'deals-mobile','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(165475,'deals-mobile','.p-wedding-registry-manage .remove-btn','content','\\e913','3','','.p-wedding-registry-manage'),(165476,'deals-mobile','.p-wedding-registry-view h1','content','\\f004','4','','.p-wedding-registry-view'),(165477,'deals-mobile','.w-product-bonus-points > div','content','\\_','4','','.w-product-bonus-points'),(165478,'deals-mobile','.p-wedding-registry-view h1','content','\\f004','3','','.p-wedding-registry-view'),(165479,'deals-mobile','.p-account-order-pay .historyInfoColumn h2.title-delivery-address, .p-account-order-pay .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-order-pay'),(165480,'deals-mobile','.p-account-order-pay .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-order-pay'),(165481,'deals-mobile','.p-account-order-pay .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-order-pay'),(165482,'deals-mobile','.js-stock-icon','content','\\f058','3','',''),(165483,'deals-mobile','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(165484,'deals-mobile','.testimonials .heading-3','content','\\e908','3','',''),(165485,'deals-mobile','.testimonials .review','content','\\_','3','',''),(165486,'deals-mobile','.p-wedding-registry-manage .wr-search button','content','\\e90a','3','','.p-wedding-registry-manage'),(165487,'deals-mobile','.p-account-history .view_link','content','\\e901','4','','.p-account-history'),(165488,'deals-mobile','.p-blog-index .nav-next a','content','\\f138','3','','.p-blog-index'),(165489,'deals-mobile','.p-blog-index .entry-content','content','\\_','4','','.p-blog-index'),(165490,'deals-mobile','.p-blog-index .comment-meta','content','\\_','4','','.p-blog-index'),(165491,'deals-mobile','.w-list-type-2_2 .item','content','\\_','4','','.w-list-type-2_2'),(165492,'deals-mobile','.out-stock-icon','content','\\f10c','3','',''),(165493,'deals-mobile','.w-list-type-2_2 .button-wishlist button','content','\\e98e','4','','.w-list-type-2_2'),(165494,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-2_2'),(165495,'deals-mobile','.buttons','content','\\_','4','',''),(165496,'deals-mobile','.w-list-type-2_2 .button-view a','content','\\e98f','4','','.w-list-type-2_2'),(165497,'deals-mobile','.w-list-type-2_2 .add-height','content','\\_','4','','.w-list-type-2_2'),(165498,'deals-mobile','.w-product-personal-catalog-button .btn','content','\\f097','3','','.w-product-personal-catalog-button'),(165499,'deals-mobile','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(165500,'deals-mobile','.w-product-wedding-registry-button .btn','content','\\_','4','','.w-product-wedding-registry-button'),(165501,'deals-mobile','.w-product-bonus-points > div > div','content','\\f219','3','','.w-product-bonus-points'),(165502,'deals-mobile','.w-chat .w-chat-box a','content','\\f075','3','','.w-chat'),(165503,'deals-mobile','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(165504,'deals-mobile','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(165505,'deals-mobile','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(165506,'deals-mobile','.p-wedding-registry-index .search-list','content','\\_','3','','.p-wedding-registry-index'),(165507,'deals-mobile','.p-wedding-registry-index .main-button','content','\\f004','4','','.p-wedding-registry-index'),(165508,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','content','\\f00c','3','','.b-form'),(165509,'deals-mobile','.p-wedding-registry-index .main-button','content','\\f004','3','','.p-wedding-registry-index'),(165510,'deals-mobile','.p-wedding-registry-search h1','content','\\f004','4','','.p-wedding-registry-search'),(165511,'deals-mobile','.p-wedding-registry-manage .links a.share-registry','content','\\f14d','4','','.p-wedding-registry-manage'),(165512,'deals-mobile','.p-wedding-registry-search h1','content','\\f004','3','','.p-wedding-registry-search'),(165513,'deals-mobile','.p-wedding-registry-manage h1','content','\\f004','3','','.p-wedding-registry-manage'),(165514,'deals-mobile','.p-wedding-registry-manage h1','content','\\f004','4','','.p-wedding-registry-manage'),(165515,'deals-mobile','.p-account-address-book .btn-edit','content','\\e917','4','','.p-account-address-book'),(165516,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','content',' ','3','','.b-switch'),(165517,'deals-mobile','.b-compare .clear_all','content','\\f00d','4','','.b-compare'),(165518,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','content',' ','3','','.b-switch'),(165519,'deals-mobile','.b-slick button.slick-prev','content','\\f053','3','','.b-slick'),(165520,'deals-mobile','.b-bottom .footerTitle','content','\\f067','863,4','','.b-bottom'),(165521,'deals-mobile','.b-slick button.slick-next','content','\\f054','3','','.b-slick'),(165522,'deals-mobile','.heading-3 .edit, h3 .edit','content','\\e917','4','',''),(165523,'deals-mobile','.w-list-type-1 .button-view a','content','\\e98f','4','','.w-list-type-1'),(165524,'deals-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','content','\\f1db','','','.w-filters'),(165525,'deals-mobile','.w-top-categories .categories','content','\\_','4','','.w-top-categories'),(165526,'deals-mobile','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(165527,'deals-mobile','.w-search .search','content','\\e90a','3','','.w-search'),(165528,'deals-mobile','.b-bottom .footerTitle','content','\\f068','863,2,4','','.b-bottom'),(165529,'deals-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','content','\\f058','','','.w-filters'),(165530,'deals-mobile','.w-currencies .current','content','\\e902','3','','.w-currencies'),(165531,'deals-mobile','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(165532,'deals-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(165533,'deals-mobile','.w-compare-box-item .checkbox:checked + span:before','content','\\f00c','','','.w-compare-box-item'),(165534,'deals-mobile','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(165535,'deals-mobile','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(165536,'deals-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','content','\\_','','','.w-compare-box-item'),(165537,'deals-mobile','.b-slick .slick-vertical button.slick-prev','content','\\f077','3','','.b-slick'),(165538,'deals-mobile','.b-slick .slick-track, .b-slick .slick-track:after','content','\\_','3','','.b-slick'),(165539,'deals-mobile','.b-slick .slick-vertical button.slick-next','content','\\f078','3','','.b-slick'),(165540,'deals-mobile','.p-account-trade-form .wd-line-row-2','content','\\_','4','','.p-account-trade-form'),(165541,'deals-mobile','.p-account-index .view_link','content','\\e901','4','','.p-account-index'),(165542,'deals-mobile','.b-info-popup .info-popup','content','\\e918','3','','.b-info-popup'),(165543,'deals-mobile','.p-account-index .view_history','content','\\e991','3','','.p-account-index'),(165544,'deals-mobile','.b-info-popup .info-popup div','content','\\_','3','','.b-info-popup'),(165545,'deals-mobile','.p-account-index .topAccount > li > div.order_count','content','\\e928','3','','.p-account-index'),(165546,'deals-mobile','.p-account-index .topAccount > li > div.total_count','content','\\e922','3','','.p-account-index'),(165547,'deals-mobile','.p-account-index .topAccount > li > div.dateLast','content','\\e920','3','','.p-account-index'),(165548,'deals-mobile','.p-account-index .topAccount > li > div.points_earnt','content','\\e990','3','','.p-account-index'),(165549,'deals-mobile','.w-menu-mobile .menu-ico','content','\\e91b','3','','.w-menu-mobile'),(165550,'deals-mobile','.p-checkout-success .page-success .text-1','content','\\e916','3','','.p-checkout-success'),(165551,'deals-mobile','.b-fancybox .fancybox-next span','content','\\e901','3','','.b-fancybox'),(165552,'deals-mobile','.p-account-index .topAccount > li > div.credit_amount_ac','content','\\e994','3','','.p-account-index'),(165553,'deals-mobile','.w-product-quantity-discounts .quantity-discounts .count','content','+','4','','.w-product-quantity-discounts'),(165554,'deals-mobile','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(165555,'deals-mobile','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(165556,'deals-mobile','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(165557,'deals-mobile','.b-fancybox .fancybox-prev span','content','\\e900','3','','.b-fancybox'),(165558,'deals-mobile','.p-wedding-registry-share .invite-remove','content','\\e913','3','','.p-wedding-registry-share'),(165559,'deals-mobile','.w-text .customer-service','content','\\e907','3','','.w-text'),(165560,'deals-mobile','.b-rating .glyphicon-chevron-right','content','\\f105','3','','.b-rating'),(165561,'deals-mobile','.b-rating .glyphicon-calendar','content','\\f073','3','','.b-rating'),(165562,'deals-mobile','.b-rating .glyphicon-chevron-up','content','\\f106','3','','.b-rating'),(165563,'deals-mobile','.b-rating .glyphicon-time','content','\\f017','3','','.b-rating'),(165564,'deals-mobile','.b-rating .glyphicon-chevron-left','content','\\f104','3','','.b-rating'),(165565,'deals-mobile','.b-rating .glyphicon-chevron-down','content','\\f107','3','','.b-rating'),(165566,'deals-mobile','.b-rating #stars-default .glyphicon-star','content','\\e90f','3','','.b-rating'),(165567,'deals-mobile','.b-quantity .qty-box .smaller','content','-','3','','.b-quantity'),(165568,'deals-mobile','.b-quantity .qty-box .bigger','content','+','3','','.b-quantity'),(165569,'deals-mobile','.w-breadcrumb .breadcrumb-li + .breadcrumb-li','content','/','3','','.w-breadcrumb'),(165570,'deals-mobile','.b-fancybox .fancybox-close','content','\\f00d','3','','.b-fancybox'),(165571,'deals-mobile','.p-reviews-info .review-info-text','content','\\_','4','','.p-reviews-info'),(165572,'deals-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','content','\\e912','3','','.w-cart-discount-coupon'),(165573,'deals-mobile','.p-account-index .account_page .icon-address','content','\\e905','3','','.p-account-index'),(165574,'deals-mobile','.p-account-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-history-info'),(165575,'deals-mobile','.p-account-index .account_page h4.icon-user','content','\\e921','3','','.p-account-index'),(165576,'deals-mobile','.p-account-index .account_page h4.icon-password','content','\\e906','3','','.p-account-index'),(165577,'deals-mobile','.b-form .columns','content','\\_','4','','.b-form'),(165578,'deals-mobile','.b-form .addresses','content','\\_','4','','.b-form'),(165579,'deals-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(165580,'deals-mobile','.w-cart-give-away .ga_name','content','\\_','4','','.w-cart-give-away'),(165581,'deals-mobile','.p-account-index .account_page h4.icon-mail','content','\\e927','3','','.p-account-index'),(165582,'deals-mobile','.w-catalog-listing-look .b2b','content','\\f0c9','3','','.w-catalog-listing-look'),(165583,'deals-mobile','.w-list-type-2 .button-wishlist button','content','\\e98e','4','','.w-list-type-2'),(165584,'deals-mobile','.w-list-type-1_3 .sale','content','SALE','4','','.w-list-type-1_3'),(165585,'deals-mobile','.w-list-type-1_3 .sale','content','\\e909','3','','.w-list-type-1_3'),(165586,'deals-mobile','.w-list-type-2 .add-height','content','\\_','4','','.w-list-type-2'),(165587,'deals-mobile','.w-list-type-2 .button-view a','content','\\e98f','4','','.w-list-type-2'),(165588,'deals-mobile','.transit-icon','content','\\f133','3','',''),(165589,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-2'),(165590,'deals-mobile','.in-stock-icon','content','\\f058','3','',''),(165591,'deals-mobile','.w-list-type-2 .sale','content','SALE','4','','.w-list-type-2'),(165592,'deals-mobile','.p-wedding-registry-share h1','content','\\f004','3','','.p-wedding-registry-share'),(165593,'deals-mobile','.w-catalog-listing-look .grid','content','\\f009','3','','.w-catalog-listing-look'),(165594,'deals-mobile','.view-all .btn','content','\\f054','4','',''),(165595,'deals-mobile','.view-all','content','\\_','3','',''),(165596,'deals-mobile','.p-wedding-registry-share h1','content','\\f004','4','','.p-wedding-registry-share'),(165597,'deals-mobile','.w-list-type-2 .sale','content','\\e909','3','','.w-list-type-2'),(165598,'deals-mobile','.w-list-type-1_3 .item','content','\\_','4','','.w-list-type-1_3'),(165599,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-1_3'),(165600,'deals-mobile','.w-list-type-1_3 .button-view a','content','\\e98f','4','','.w-list-type-1_3'),(165601,'deals-mobile','.w-list-type-1_3 .button-wishlist button','content','\\e98e','4','','.w-list-type-1_3'),(165602,'deals-mobile','.w-list-type-1_3 .attributes > .attributes','content','\\_','4','','.w-list-type-1_3'),(165603,'deals-mobile','.w-list-type-1_2 .sale','content','\\e909','3','','.w-list-type-1_2'),(165604,'deals-mobile','.w-list-type-1_3 .add-height','content','\\_','4','','.w-list-type-1_3'),(165605,'deals-mobile','.w-list-type-1_2 .sale','content','SALE','4','','.w-list-type-1_2'),(165606,'deals-mobile','.w-list-type-1_2 .right-area','content','\\_','4','','.w-list-type-1_2'),(165607,'deals-mobile','.w-list-type-1_2 .item','content','\\_','4','','.w-list-type-1_2'),(165608,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-1_2'),(165609,'deals-mobile','.w-list-type-1_2 .button-wishlist button','content','\\e98e','4','','.w-list-type-1_2'),(165610,'deals-mobile','.w-list-type-1_2 .button-view a','content','\\e98f','4','','.w-list-type-1_2'),(165611,'deals-mobile','.b-bottom .pop-up-close','content','\\f00d','3','','.b-bottom'),(165612,'deals-mobile','.w-list-type-1_2 .add-height','content','\\_','4','','.w-list-type-1_2'),(165613,'deals-mobile','.w-list-type-1 .sale','content','SALE','4','','.w-list-type-1'),(165614,'deals-mobile','.w-list-type-1 .sale','content','\\e909','3','','.w-list-type-1'),(165615,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','content','\\e977','3','','.w-list-type-1'),(165616,'deals-mobile','.w-list-type-1 .button-wishlist button','content','\\e98e','4','','.w-list-type-1'),(165617,'deals-mobile','.heading-4 .edit, h4 .edit','content','\\e917','4','',''),(165618,'deals-mobile','.w-filters .open','content','\\f056','3','','.w-filters'),(165619,'deals-mobile','.w-filters .mobileCollapse','content','\\f056','2,4','','.w-filters'),(165620,'deals-mobile','.w-filters .mobileCollapse','content','\\f055','4','','.w-filters'),(165621,'deals-mobile','.w-filters .view_more','content','\\f061','4','','.w-filters'),(165622,'deals-mobile','.w-filters span.close','content','\\f055','3','','.w-filters'),(165623,'deals-mobile','.w-languages .current','content','\\e902','3','','.w-languages'),(165624,'deals-mobile','.w-list-type-1 .add-height','content','\\_','4','','.w-list-type-1'),(165625,'deals-mobile','.w-product-reviews .reviews-list .review','content','\\_','3','','.w-product-reviews'),(165626,'deals-mobile','.w-reviews .heading-3','content','\\e908','3','','.w-reviews'),(165627,'deals-mobile','.w-reviews .review','content','\\_','3','','.w-reviews'),(165628,'deals-mobile','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(165629,'deals-mobile','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(165630,'deals-mobile','.w-search .button-search','content','\\e90a','3','','.w-search'),(165631,'deals-mobile','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(165632,'deals-mobile','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(165633,'deals-mobile','.btn-del','content','\\f1f8','4','',''),(165634,'deals-mobile','.p-account-history-info .historyInfoColumn h2.title-delivery-address, .p-account-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-history-info'),(165635,'deals-mobile','.p-account-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-history-info'),(165636,'deals-mobile','.b-info .info','content','\\e918','3','','.b-info'),(165637,'deals-mobile','.b-products-listing .BlockBox','content','\\_','4','','.b-products-listing'),(165638,'deals-mobile','.b-products-listing .btn-preloader','content','\\f110','3','','.b-products-listing'),(165639,'deals-mobile','.b-products-listing .hover-box-content','content','\\_','3','','.b-products-listing'),(165640,'deals-mobile','.b-products-listing .loader','content','\\f110','4','','.b-products-listing'),(165641,'deals-mobile','.b-products-listing .loader','content','\\_','3','','.b-products-listing'),(165642,'deals-mobile','.b-products-listing .products-listing','content','\\_','4','','.b-products-listing'),(165643,'deals-mobile','.b-products-listing .products-listing .bonus-points-cost','content','\\f219','3','','.b-products-listing'),(165644,'deals-mobile','.b-products-listing .products-listing .bonus-points-price','content','\\f219','3','','.b-products-listing'),(165645,'deals-mobile','.b-products-listing .products-listing .btn-buy','content','\\e977','3','','.b-products-listing'),(165646,'deals-mobile','.b-products-listing .products-listing .mix-attributes','content','\\_','4','','.b-products-listing'),(165647,'deals-mobile','.b-products-listing .products-listing .qty-input.hidden','content','\\_','3','','.b-products-listing'),(165648,'deals-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','content','\\f004','','','.b-products-listing'),(165649,'deals-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','content','\\f08a','','','.b-products-listing'),(165650,'deals-mobile','.b-products-listing .products-listing a.btn.view-button','content','\\e991','3','','.b-products-listing'),(165651,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(165652,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(165653,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(165654,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(165655,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(165656,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(165657,'deals-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','content','\\f0c9','3','','.b-menu-burger_icon'),(165658,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(165659,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(165660,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(165661,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(165662,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(165663,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(165664,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(165665,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(165666,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(165667,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(165668,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','content','\\f107','4','','.b-menu-style-1'),(165669,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > .no-link','content','\\f105','4','','.b-menu-style-1'),(165670,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','content','\\f105 \\f105','4','','.b-menu-style-1'),(165671,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','content','\\f00d','3','','.b-menu-style-2'),(165672,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','content','\\_','3','','.b-menu-style-2'),(165673,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','content','\\f105','3','','.b-menu-style-2'),(165674,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','content','\\_','3','','.b-menu-style-2'),(165675,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','content','\\f104','3','','.b-menu-style-2'),(165676,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > .no-link','content','\\f107','4','','.b-menu-style-3'),(165677,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > .no-link','content','\\f105','3','','.b-menu-style-3'),(165678,'deals-mobile','.b-messages .select2-search-choice-close','content','\\e913','3','','.b-messages'),(165679,'deals-mobile','.b-messages .messBtnMenuDelete','content','\\e913','3','','.b-messages'),(165680,'deals-mobile','.b-messages span.starred::before','content','\\e90e','','','.b-messages'),(165681,'deals-mobile','.b-messages .dataTables_wrapper > .top','content','\\_','4','','.b-messages'),(165682,'deals-mobile','.b-messages .messBtnMenuUnread','content','\\f097','3','','.b-messages'),(165683,'deals-mobile','.b-messages .messBtnMenuStarred','content','\\e90e','3','','.b-messages'),(165684,'deals-mobile','.b-messages .icon-circle-with-cross::before','content','×','','','.b-messages'),(165685,'deals-mobile','.b-messages .dataTables_wrapper > .bottom','content','\\_','4','','.b-messages'),(165686,'deals-mobile','.b-preloader .preloader','content','\\f110','3','','.b-preloader'),(165687,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','content','\\25be','3','','.b-select-suggest'),(165688,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(165689,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(165690,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(165691,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(165692,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(165693,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(165694,'deals-mobile','.b-trade-approval .columns','content','\\_','4','','.b-trade-approval'),(165695,'deals-mobile','.b-upload-file .snapshot','content','\\f030','3','','.b-upload-file'),(165696,'deals-mobile','.b-upload-file .upload-file-wrap .upload-remove','content','\\e913','3','','.b-upload-file'),(165697,'deals-mobile','.b-upload-files .remove-file','content','\\f014','3','','.b-upload-files'),(165698,'deals-mobile','.b-warehouses-popup .warehouses-popup-link','content','\\f041','3','','.b-warehouses-popup'),(165699,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','content','\\f041','3','','.b-warehouses-popup'),(165700,'deals-mobile','.batchPr .btn-batch-remove','content','x','3','','.batchPr'),(165701,'deals-mobile','.batchPr .checkbox input:not(checked) + span:before','content','\\002B','','','.batchPr'),(165702,'deals-mobile','.batchPr .checkbox input:checked + span:before','content','\\f00c','','','.batchPr'),(165703,'deals-mobile','.bell-ico .heading-2','content','\\e9a7','3','','.bell-ico'),(165704,'deals-mobile','.heading-ordered-items .heading-4','content','\\e99b','3','','.heading-ordered-items'),(165705,'deals-mobile','.heading-saved-lists .heading-4','content','\\e99c','3','','.heading-saved-lists'),(165706,'deals-mobile','.heading-settings .heading-4','content','\\e99a','3','','.heading-settings'),(165707,'deals-mobile','.p-account-samples-history .view_link','content','\\e901','4','','.p-account-samples-history'),(165708,'deals-mobile','.p-account-samples-history .view_link','content','\\e901','4','','.p-account-samples-history'),(165709,'deals-mobile','.p-account-samples-history .view_link','content','\\e901','4','','.p-account-samples-history'),(165710,'deals-mobile','.p-account-samples-history .view_link','content','\\e901','4','','.p-account-samples-history'),(165711,'deals-mobile','.p-account-samples-history .view_link','content','\\e901','4','','.p-account-samples-history'),(165712,'deals-mobile','.p-account-samples-history .view_link','content','\\e901','4','','.p-account-samples-history'),(165713,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-samples-history-info'),(165714,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-samples-history-info'),(165715,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-samples-history-info'),(165716,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-samples-history-info'),(165717,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-samples-history-info'),(165718,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-samples-history-info'),(165719,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-samples-history-info'),(165720,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-samples-history-info'),(165721,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-samples-history-info'),(165722,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-samples-history-info'),(165723,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-samples-history-info'),(165724,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-samples-history-info'),(165725,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.p-account-samples-history-info'),(165726,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-samples-history-info'),(165727,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-samples-history-info'),(165728,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-samples-history-info'),(165729,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.p-account-samples-history-info'),(165730,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.p-account-samples-history-info'),(165731,'deals-mobile','.p-catalog-product .prev-product .pn-image','content','\\f053','3','','.p-catalog-product'),(165732,'deals-mobile','.p-catalog-product .next-product .pn-image','content','\\f054','3','','.p-catalog-product'),(165733,'deals-mobile','.p-payer-order-confirmation .ship-ico','content','\\e94e','3','','.p-payer-order-confirmation'),(165734,'deals-mobile','.p-payer-order-confirmation .pay-ico','content','\\e99e','3','','.p-payer-order-confirmation'),(165735,'deals-mobile','.p-payer-order-confirmation .order-ico','content','\\e922','3','','.p-payer-order-confirmation'),(165736,'deals-mobile','.p-payer-order-confirmation .comment-ico','content','\\e99d','3','','.p-payer-order-confirmation'),(165737,'deals-mobile','.p-payer-order-confirmation .discount-ico','content','\\e95e','3','','.p-payer-order-confirmation'),(165738,'deals-mobile','.p-payer-order-pay .ship-ico','content','\\e94e','3','','.p-payer-order-pay'),(165739,'deals-mobile','.p-payer-order-pay .pay-ico','content','\\e99e','3','','.p-payer-order-pay'),(165740,'deals-mobile','.p-payer-order-pay .order-ico','content','\\e922','3','','.p-payer-order-pay'),(165741,'deals-mobile','.p-payer-order-pay .comment-ico','content','\\e99d','3','','.p-payer-order-pay'),(165742,'deals-mobile','.p-payer-order-pay .discount-ico','content','\\e95e','3','','.p-payer-order-pay'),(165743,'deals-mobile','.p-quick-order-index .paginate_button.next','content','\\f105','3','','.p-quick-order-index'),(165744,'deals-mobile','.p-quick-order-index .paginate_button.previous','content','\\f104','3','','.p-quick-order-index'),(165745,'deals-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(165746,'deals-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(165747,'deals-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(165748,'deals-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(165749,'deals-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(165750,'deals-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(165751,'deals-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(165752,'deals-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(165753,'deals-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(165754,'deals-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(165755,'deals-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(165756,'deals-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(165757,'deals-mobile','.p-sample-checkout-success .page-success .text-1','content','\\e916','3','','.p-sample-checkout-success'),(165758,'deals-mobile','.p-sample-checkout-success .page-success','content','\\_','0,3','','.p-sample-checkout-success'),(165759,'deals-mobile','.savings-ico .heading-2','content','\\e95e','3','','.savings-ico'),(165760,'deals-mobile','.shipping-ico .heading-2','content','\\e95e','3','','.shipping-ico'),(165761,'deals-mobile','.shipping-ico .heading-2','content','\\e94e','3','','.shipping-ico'),(165762,'deals-mobile','.shipping-ico .heading-2','content','\\e95e','3','','.shipping-ico'),(165763,'deals-mobile','.w-account-address-book .add_item a','content','\\f067','3','','.w-account-address-book'),(165764,'deals-mobile','.w-blog-widget-categories-list a','content','\\2022','3','','.w-blog-widget-categories-list'),(165765,'deals-mobile','.w-blog-widget-most-popular-posts a','content','\\2022','3','','.w-blog-widget-most-popular-posts'),(165766,'deals-mobile','.w-blog-widget-post-comments-count span','content','\\e645','3','','.w-blog-widget-post-comments-count'),(165767,'deals-mobile','.w-blog-widget-post-listing .post_comment','content','\\e645','3','','.w-blog-widget-post-listing'),(165768,'deals-mobile','.w-blog-widget-post-listing .post_date span + span','content','\\2022','3','','.w-blog-widget-post-listing'),(165769,'deals-mobile','.w-blog-widget-post-listing .products','content','\\_','4','','.w-blog-widget-post-listing'),(165770,'deals-mobile','.w-blog-widget-post-share ','content','\\_','4','','.w-blog-widget-post-share'),(165771,'deals-mobile','.w-blog-widget-post-share .facebook-btn','content','\\f09a','3','','.w-blog-widget-post-share'),(165772,'deals-mobile','.w-blog-widget-post-share .twitter-btn','content','\\f099','3','','.w-blog-widget-post-share'),(165773,'deals-mobile','.w-blog-widget-post-share .pinterest-btn','content','\\f231','3','','.w-blog-widget-post-share'),(165774,'deals-mobile','.w-blog-widget-post-share .mailto','content','\\e75a','3','','.w-blog-widget-post-share'),(165775,'deals-mobile','.w-blog-widget-post-share .printto','content','\\e681','3','','.w-blog-widget-post-share'),(165776,'deals-mobile','.w-cart-bonus-points .btn-remove','content','\\e913','3','','.w-cart-bonus-points'),(165777,'deals-mobile','.w-cart-bonus-points .title','content','\\f219','3','','.w-cart-bonus-points'),(165778,'deals-mobile','.w-cart-compare .product-actions .dropdown-toggle','content','\\f013','3','','.w-cart-compare'),(165779,'deals-mobile','.w-cart-compare .product','content','\\_','4','','.w-cart-compare'),(165780,'deals-mobile','.w-cart-compare .delete-cart','content','\\2573','3','','.w-cart-compare'),(165781,'deals-mobile','.w-cart-compare .atr-col','content','\\f070','3','','.w-cart-compare'),(165782,'deals-mobile','.w-cart-credit-amount .amount-title','content','\\e99f','3','','.w-cart-credit-amount'),(165783,'deals-mobile','.w-cart-credit-amount .btn-remove','content','\\e913','3','','.w-cart-credit-amount'),(165784,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','content','\\e90d','3','','.w-catalog-compare'),(165785,'deals-mobile','.w-catalog-compare td span + span','content','| ','3','','.w-catalog-compare'),(165786,'deals-mobile','.w-catalog-compare .checkbox input:checked + span:before','content','\\f014','','','.w-catalog-compare'),(165787,'deals-mobile','.w-catalog-paging .next','content','\\f105','3','','.w-catalog-paging'),(165788,'deals-mobile','.w-catalog-paging .prev','content','\\f104','3','','.w-catalog-paging'),(165789,'deals-mobile','.w-checkout-billing-address .addresses','content','\\_','4','','.w-checkout-billing-address'),(165790,'deals-mobile','.w-checkout-bonus-points .btn-remove','content','\\e913','3','','.w-checkout-bonus-points'),(165791,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','content','\\f10b','3','','.w-checkout-contact-information'),(165792,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','content','\\f095','3','','.w-checkout-contact-information'),(165793,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','content','\\f003','3','','.w-checkout-contact-information'),(165794,'deals-mobile','.w-checkout-create-account .account-benefits strong','content','\\e918','3','','.w-checkout-create-account'),(165795,'deals-mobile','.w-checkout-credit-amount .btn-remove','content','\\e913','3','','.w-checkout-credit-amount'),(165796,'deals-mobile','.w-checkout-shipping-address .addresses','content','\\_','4','','.w-checkout-shipping-address'),(165797,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','content','\\_','','','.w-checkout-shipping-choice'),(165798,'deals-mobile','.w-coupons-and-vauchers-checkout .btn-remove','content','\\e913','3','','.w-coupons-and-vauchers-checkout'),(165799,'deals-mobile','.w-list-b2b .attributes','content','\\_','4','','.w-list-b2b'),(165800,'deals-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','content','\\f013','3','','.w-multi-cart-actions'),(165801,'deals-mobile','.w-personal-gift-status-bar .inform','content','\\e6a0','4','','.w-personal-gift-status-bar'),(165802,'deals-mobile','.w-personal-gift-status-bar .end-date','content','\\e72b','3','','.w-personal-gift-status-bar'),(165803,'deals-mobile','.w-product-available-in-warehouses .content','content','\\_','4','','.w-product-available-in-warehouses'),(165804,'deals-mobile','.w-product-cross-sell .buy-all-checker','content','\\f14a','3','','.w-product-cross-sell'),(165805,'deals-mobile','.w-product-customers-activity .close','content','\\2715','3','','.w-product-customers-activity'),(165806,'deals-mobile','.w-promotions .prom-multi-discount','content','\\_','4','','.w-promotions'),(165807,'deals-mobile','.w-promotions .nextdiscount .heading','content','\\f07a','3','','.w-promotions'),(165808,'deals-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','content','\\_','3','','.w-promotions'),(165809,'deals-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','content','\\_','3','','.w-promotions'),(165810,'deals-mobile','.w-promotions .prom-multi-discount .promo-range .promo-prod-qty','content',',','4','','.w-promotions'),(165811,'deals-mobile','.w-promotions .prom-multi-discount > .heading','content','\\_','3','','.w-promotions'),(165812,'deals-mobile','.w-reviews-content .review','content','\\_','3','','.w-reviews-content'),(165813,'deals-mobile','.w-social-links .facebook','content','\\f09a','3','','.w-social-links'),(165814,'deals-mobile','.w-social-links .pinterest','content','\\f0d2','3','','.w-social-links'),(165815,'deals-mobile','.w-social-links .stumbleupon','content','\\f1a4','3','','.w-social-links'),(165816,'deals-mobile','.w-social-links .google-plus','content','\\f2b3','3','','.w-social-links'),(165817,'deals-mobile','.w-social-links .linkedin','content','\\f0e1','3','','.w-social-links'),(165818,'deals-mobile','.w-social-links .instagram','content','\\f16d','3','','.w-social-links'),(165819,'deals-mobile','.w-social-links .twitter','content','\\f099','3','','.w-social-links'),(165820,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','content','\\f1f8','3','','.w-upload-customer-id-upload-customer-id-form'),(165821,'deals-mobile','.w-wedding-registry-widgets-delete-link a','content','|','4','','.w-wedding-registry-widgets-delete-link'),(165822,'deals-mobile','.w-wedding-registry-widgets-manage-names .names-separator','content','\\f004','3','','.w-wedding-registry-widgets-manage-names'),(165823,'deals-mobile','.w-wedding-registry-widgets-products .remove-btn','content','\\e913','3','','.w-wedding-registry-widgets-products'),(165824,'deals-mobile','.w-wedding-registry-widgets-search-registry-button a','content','\\f002','3','','.w-wedding-registry-widgets-search-registry-button'),(165825,'deals-mobile','.w-wedding-registry-widgets-share-link a','content','|','4','','.w-wedding-registry-widgets-share-link'),(165826,'deals-mobile','.w-wedding-registry-widgets-share-link a','content','\\f045','3','','.w-wedding-registry-widgets-share-link'),(165827,'deals-mobile','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(165828,'deals-mobile','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(165829,'deals-mobile','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(165830,'deals-mobile','.b-rating .glyphicon-chevron-right','content_important','important','3','','.b-rating'),(165831,'deals-mobile','.b-rating .glyphicon-time','content_important','important','3','','.b-rating'),(165832,'deals-mobile','.b-rating .glyphicon-chevron-down','content_important','important','3','','.b-rating'),(165833,'deals-mobile','.b-rating .glyphicon-chevron-left','content_important','important','3','','.b-rating'),(165834,'deals-mobile','.b-rating .glyphicon-calendar','content_important','important','3','','.b-rating'),(165835,'deals-mobile','.b-rating .glyphicon-chevron-up','content_important','important','3','','.b-rating'),(165836,'deals-mobile','.w-menu-big .show-all','cursor','pointer','','','.w-menu-big'),(165837,'deals-mobile','.w-menu .menu .menu-ico','cursor','pointer','','','.w-menu'),(165838,'deals-mobile','.w-menu-slider .close','cursor','pointer','','','.w-menu-slider'),(165839,'deals-mobile','.b-switch .bootstrap-switch','cursor','pointer','','','.b-switch'),(165840,'deals-mobile','.w-product-images img','cursor','pointer','','','.w-product-images'),(165841,'deals-mobile','.w-filters .filter-box-content ul li.view_items','cursor','pointer','','','.w-filters'),(165842,'deals-mobile','.p-account-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-history-info'),(165843,'deals-mobile','.p-account-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-history-info'),(165844,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','cursor','pointer','','','.b-multi-page-checkout'),(165845,'deals-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','cursor','pointer','','','.b-product-images'),(165846,'deals-mobile','.p-account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-order-pay'),(165847,'deals-mobile','.p-account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-order-pay'),(165848,'deals-mobile','.b-fancybox .fancybox-close','cursor','pointer','','','.b-fancybox'),(165849,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','cursor','pointer','3','','.b-form'),(165850,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor','default','','','.b-switch'),(165851,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor','default','','','.b-switch'),(165852,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor','default','','','.b-switch'),(165853,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','cursor','pointer','','','.b-switch'),(165854,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor','default','','','.b-switch'),(165855,'deals-mobile','.w-tabs .accordion-heading','cursor','pointer','','','.w-tabs'),(165856,'deals-mobile','.w-tabs .accordion-heading','cursor','default','2','','.w-tabs'),(165857,'deals-mobile','.b-slick button.slick-disabled','cursor','default','','','.b-slick'),(165858,'deals-mobile','.b-bottom .footerTitle','cursor','pointer','863','','.b-bottom'),(165859,'deals-mobile','.w-tabs .tab-a','cursor','default','2','','.w-tabs'),(165860,'deals-mobile','.w-tabs .tab-a','cursor','pointer','','','.w-tabs'),(165861,'deals-mobile','.w-filters .mobileCollapse','cursor','pointer','4','','.w-filters'),(165862,'deals-mobile','.p-checkout-index .shipping-method .row','cursor','pointer','','','.p-checkout-index'),(165863,'deals-mobile','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(165864,'deals-mobile','.b-form .item-radio label','cursor','pointer','','','.b-form'),(165865,'deals-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','cursor','pointer','','','.b-product-images'),(165866,'deals-mobile','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(165867,'deals-mobile','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(165868,'deals-mobile','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(165869,'deals-mobile','.b-fancybox .fancybox-nav span','cursor','pointer','','','.b-fancybox'),(165870,'deals-mobile','.b-fancybox .fancybox-nav','cursor','pointer','','','.b-fancybox'),(165871,'deals-mobile','.b-form .item-radio.active label','cursor','default','','','.b-form'),(165872,'deals-mobile','.b-fancybox #fancybox-loading','cursor','pointer','','','.b-fancybox'),(165873,'deals-mobile','.b-autocomplete .ui-autocomplete li','cursor','pointer','','','.b-autocomplete'),(165874,'deals-mobile','.b-bottom .pop-up-close','cursor','pointer','','','.b-bottom'),(165875,'deals-mobile','.w-filters .open, .w-filters .close','cursor','pointer','','','.w-filters'),(165876,'deals-mobile','.w-filters .ui-slider-handle','cursor','pointer','','','.w-filters'),(165877,'deals-mobile','.b-form .addresses .address-item label','cursor','pointer','','','.b-form'),(165878,'deals-mobile','.b-products-listing .products-listing .wishlistButton .checkbox','cursor','pointer','','','.b-products-listing'),(165879,'deals-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','cursor','pointer','','','.b-menu-burger_icon'),(165880,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(165881,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(165882,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(165883,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(165884,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(165885,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','cursor','pointer','','','.b-menu-style-2'),(165886,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','cursor','pointer','','','.b-menu-style-2'),(165887,'deals-mobile','.b-messages .messMenuButton span','cursor','pointer','','','.b-messages'),(165888,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-chosen','cursor','default','','','.b-select-suggest'),(165889,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','1','','.b-select-suggest'),(165890,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','','','.b-select-suggest'),(165891,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','cursor','default','','','.b-select-suggest'),(165892,'deals-mobile','.b-select-suggest .select2-results .select2-disabled','cursor','default','','','.b-select-suggest'),(165893,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','cursor','pointer','','','.b-select-suggest'),(165894,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','cursor','default','','','.b-select-suggest'),(165895,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','cursor','text','','','.b-select-suggest'),(165896,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','cursor','default','','','.b-select-suggest'),(165897,'deals-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','cursor','default','','','.b-select-suggest'),(165898,'deals-mobile','.b-upload-file .snapshot','cursor','pointer','','','.b-upload-file'),(165899,'deals-mobile','.b-upload-files .remove-file','cursor','pointer','','','.b-upload-files'),(165900,'deals-mobile','.batchPr .batchSelect .checkbox','cursor','pointer','','','.batchPr'),(165901,'deals-mobile','.batchPr .btn-batch-remove','cursor','pointer','','','.batchPr'),(165902,'deals-mobile','.batchPr .batchSelect .checkbox','cursor','pointer','','','.batchPr'),(165903,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-samples-history-info'),(165904,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-samples-history-info'),(165905,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-samples-history-info'),(165906,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-samples-history-info'),(165907,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-samples-history-info'),(165908,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-samples-history-info'),(165909,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-samples-history-info'),(165910,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-samples-history-info'),(165911,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-samples-history-info'),(165912,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-samples-history-info'),(165913,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.p-account-samples-history-info'),(165914,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.p-account-samples-history-info'),(165915,'deals-mobile','.p-quick-order-index .filters .clear','cursor','pointer','','','.p-quick-order-index'),(165916,'deals-mobile','.w-account-personal-catalog .list-switcher a','cursor','pointer','','','.w-account-personal-catalog'),(165917,'deals-mobile','.w-account-personal-catalog .list-switcher a','cursor','default','2','','.w-account-personal-catalog'),(165918,'deals-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','cursor','pointer','','','.w-blog-widget-post-share'),(165919,'deals-mobile','.w-cart-bonus-points .btn-remove','cursor','pointer','','','.w-cart-bonus-points'),(165920,'deals-mobile','.w-cart-compare .atr-col','cursor','pointer','','','.w-cart-compare'),(165921,'deals-mobile','.w-cart-credit-amount .btn-remove','cursor','pointer','','','.w-cart-credit-amount'),(165922,'deals-mobile','.w-catalog-compare .compare label','cursor','pointer','','','.w-catalog-compare'),(165923,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','cursor','pointer','','','.w-catalog-compare'),(165924,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','cursor','default','2','','.w-catalog-compare'),(165925,'deals-mobile','.w-catalog-compare .cross-box .return','cursor','pointer','','','.w-catalog-compare'),(165926,'deals-mobile','.w-checkout-bonus-points .btn-remove','cursor','pointer','','','.w-checkout-bonus-points'),(165927,'deals-mobile','.w-checkout-credit-amount .btn-remove','cursor','pointer','','','.w-checkout-credit-amount'),(165928,'deals-mobile','.w-checkout-shipping-choice span','cursor','pointer','','','.w-checkout-shipping-choice'),(165929,'deals-mobile','.w-checkout-shipping-choice input:checked + span','cursor','default','','','.w-checkout-shipping-choice'),(165930,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','cursor','pointer','','','.w-communication-new-topic'),(165931,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','cursor','pointer','','','.w-communication-new-topic'),(165932,'deals-mobile','.w-coupons-and-vauchers-checkout .btn-remove','cursor','pointer','','','.w-coupons-and-vauchers-checkout'),(165933,'deals-mobile','.w-product-customers-activity .close','cursor','pointer','','','.w-product-customers-activity'),(165934,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','cursor','pointer','','','.w-upload-customer-id-upload-customer-id-form'),(165935,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor_important','important','','','.b-switch'),(165936,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor_important','important','','','.b-switch'),(165937,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor_important','important','','','.b-switch'),(165938,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor_important','important','','','.b-switch'),(165939,'deals-mobile','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(165940,'deals-mobile','.b-switch .bootstrap-switch','direction','ltr','','','.b-switch'),(165941,'deals-mobile','.w-menu-big li a, .w-menu-big li .no-link','display','inline-block','','','.w-menu-big'),(165942,'deals-mobile','.w-menu .hided.menu .menu-ico','display','block','','','.w-menu'),(165943,'deals-mobile','.w-menu-big li li li','display','block','','','.w-menu-big'),(165944,'deals-mobile','.w-menu .hided.menu a, .w-menu .hided.menu .no-link','display','block','','','.w-menu'),(165945,'deals-mobile','.w-menu-big li li a, .w-menu-big li li .no-link','display','block','','','.w-menu-big'),(165946,'deals-mobile','.w-menu .hided.menu ul li','display','block','','','.w-menu'),(165947,'deals-mobile','.w-menu .menu .menu-ico','display','none','','','.w-menu'),(165948,'deals-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','display','none','','','.w-menu'),(165949,'deals-mobile','.w-menu div.hided.menu .active + ul, .w-menu div.hided.menu .opened + ul','display','block','','','.w-menu'),(165950,'deals-mobile','.w-menu-big .hide-more.hide-more-disable, .w-menu-big .hide-more.hide-more-disable ~ li:not(.show-all)','display','block','','','.w-menu-big'),(165951,'deals-mobile','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','display','inline-block','','','.w-menu-horizontal'),(165952,'deals-mobile','.w-menu-slider > ul > li > ul > li','display','inline-block','','','.w-menu-slider'),(165953,'deals-mobile','.w-menu-big > ul > li > ul','display','none','','','.w-menu-big'),(165954,'deals-mobile','.w-menu-big > ul > li:hover > ul','display','block','','','.w-menu-big'),(165955,'deals-mobile','.w-menu-big .hide-more, .w-menu-big .hide-more ~ li:not(.show-all)','display','none','','','.w-menu-big'),(165956,'deals-mobile','.w-menu-big li','display','inline-block','','','.w-menu-big'),(165957,'deals-mobile','.w-bestsellers .counter','display','inline-block','','','.w-bestsellers'),(165958,'deals-mobile','.w-menu-slider > ul > li','display','inline-block','','','.w-menu-slider'),(165959,'deals-mobile','.w-menu-slider a, .w-menu-slider .no-link','display','inline-block','','','.w-menu-slider'),(165960,'deals-mobile','.w-account .my-acc-link','display','inline-block','3','','.w-account'),(165961,'deals-mobile','.w-menu-slider > ul > li > ul','display','none','','','.w-menu-slider'),(165962,'deals-mobile','.w-account .no-text','display','none','','','.w-account'),(165963,'deals-mobile','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(165964,'deals-mobile','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(165965,'deals-mobile','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(165966,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(165967,'deals-mobile','.b-form .checkbox-style:checked + .checkbox-span','display','inline-block','','','.b-form'),(165968,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','display','inline-block','','','.b-form'),(165969,'deals-mobile','.w-sale .btn','display','block','','','.w-sale'),(165970,'deals-mobile','.w-login-block .label','display','block','','','.w-login-block'),(165971,'deals-mobile','.w-login-block .cols','display','block','4','','.w-login-block'),(165972,'deals-mobile','.b-product-images .additional-images .item > div, .b-product-images .additional-videos .item > div','display','table-cell','','','.b-product-images'),(165973,'deals-mobile','.w-sale .left-count-days','display','block','','','.w-sale'),(165974,'deals-mobile','.w-sale .left-count','display','block','','','.w-sale'),(165975,'deals-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','display','block','','','.b-product-images'),(165976,'deals-mobile','.w-product-attributes .attributes','display','block','4','','.w-product-attributes'),(165977,'deals-mobile','.w-product-sale-ends .left-count-days','display','block','','','.w-product-sale-ends'),(165978,'deals-mobile','.w-product-sale-ends .left-count','display','block','','','.w-product-sale-ends'),(165979,'deals-mobile','.w-product-sale-ends .left-count-hours','display','block','','','.w-product-sale-ends'),(165980,'deals-mobile','.w-product-sale-ends .left-text-right','display','block','','','.w-product-sale-ends'),(165981,'deals-mobile','.w-product-sale-ends .left-text-left','display','block','','','.w-product-sale-ends'),(165982,'deals-mobile','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(165983,'deals-mobile','.p-account-history .short-date','display','none','','','.p-account-history'),(165984,'deals-mobile','.w-filters .filter-widget-horizontal .filter-box','display','table-cell','','','.w-filters'),(165985,'deals-mobile','.w-filters .filter-widget-horizontal .content-filter-widget','display','table','','','.w-filters'),(165986,'deals-mobile','.w-cart .price','display','block','','','.w-cart'),(165987,'deals-mobile','.w-filters .filter-box-content ul li.view_items','display','block','','','.w-filters'),(165988,'deals-mobile','.w-cart .name','display','block','','','.w-cart'),(165989,'deals-mobile','.w-cart .no-text','display','none','','','.w-cart'),(165990,'deals-mobile','.p-reviews-info .review-info-text','display','block','4','','.p-reviews-info'),(165991,'deals-mobile','.w-product-collection .together','display','block','','','.w-product-collection'),(165992,'deals-mobile','.w-menu-mobile .menu-slider .open','display','block','','','.w-menu-mobile'),(165993,'deals-mobile','.w-menu-mobile .menu-ico','display','block','','','.w-menu-mobile'),(165994,'deals-mobile','.w-menu-mobile .menu-slider','display','none','','','.w-menu-mobile'),(165995,'deals-mobile','.w-categories .categories','display','flex','','','.w-categories'),(165996,'deals-mobile','.b-price-box .price-box .title','display','inline-block','','','.b-price-box'),(165997,'deals-mobile','.w-quote .no-text','display','none','872','','.w-quote'),(165998,'deals-mobile','.p-account-history-info .history_attr div strong, .p-account-history-info .history_attr div span','display','table-cell','','','.p-account-history-info'),(165999,'deals-mobile','.w-categories .item','display','inline-block','','','.w-categories'),(166000,'deals-mobile','.w-categories .categories','display','block','4','','.w-categories'),(166001,'deals-mobile','.w-compare-box-item .checkbox + span','display','inline-block','','','.w-compare-box-item'),(166002,'deals-mobile','.w-categories .name','display','block','','','.w-categories'),(166003,'deals-mobile','.w-categories .image','display','block','','','.w-categories'),(166004,'deals-mobile','.w-catalog-listing-look .listing-look-title','display','inline-block','','','.w-catalog-listing-look'),(166005,'deals-mobile','.b-pagination .pagination','display','block','4','','.b-pagination'),(166006,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','block','','','.b-multi-page-checkout'),(166007,'deals-mobile','.b-pass-strength .pass-strength','display','block','','','.b-pass-strength'),(166008,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','inline-block','4','','.b-multi-page-checkout'),(166009,'deals-mobile','.b-price-box .price-box .price','display','inline-block','','','.b-price-box'),(166010,'deals-mobile','.w-quote .cart-box-link','display','inline-block','3','','.w-quote'),(166011,'deals-mobile','.w-quote .strong','display','block','','','.w-quote'),(166012,'deals-mobile','.w-quote .no-text','display','inline-block','','','.w-quote'),(166013,'deals-mobile','.w-quote .cart-box-link','display','block','','','.w-quote'),(166014,'deals-mobile','.w-product-properties li','display','table-cell','','','.w-product-properties'),(166015,'deals-mobile','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(166016,'deals-mobile','.b-product-images .main-image-box','display','block','4','','.b-product-images'),(166017,'deals-mobile','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(166018,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','display','inline-block','3','','.b-multi-page-checkout'),(166019,'deals-mobile','.b-compare .compare_select_items','display','inline-block','','','.b-compare'),(166020,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .count','display','none','','','.b-multi-page-checkout'),(166021,'deals-mobile','.w-catalog-listing-look .list','display','inline-block','','','.w-catalog-listing-look'),(166022,'deals-mobile','.w-catalog-listing-look .b2b','display','inline-block','','','.w-catalog-listing-look'),(166023,'deals-mobile','.price .old','display','block','','',''),(166024,'deals-mobile','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(166025,'deals-mobile','.w-cart-shipping-estimator .shipping-estimator','display','block','4','','.w-cart-shipping-estimator'),(166026,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .edit','display','none','','','.b-multi-page-checkout'),(166027,'deals-mobile','.p-blog-index .post-title','display','block','','','.p-blog-index'),(166028,'deals-mobile','.p-blog-index .comment-form p label','display','inline-block','','','.p-blog-index'),(166029,'deals-mobile','.p-account-history .orders-table .hidden','display','none','','','.p-account-history'),(166030,'deals-mobile','.p-blog-index .post-list .comments-link','display','none','','','.p-blog-index'),(166031,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','display','inline-block','','','.b-multi-page-checkout'),(166032,'deals-mobile','.b-info-popup .info-popup div','display','none','','','.b-info-popup'),(166033,'deals-mobile','.b-info-popup .info-popup:hover div','display','block','','','.b-info-popup'),(166034,'deals-mobile','.w-filters .content-filter-widget','display','none','890','','.w-filters'),(166035,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','display','block','4','','.b-multi-page-checkout'),(166036,'deals-mobile','.w-promo-code .promo-text-2','display','none','864','','.w-promo-code'),(166037,'deals-mobile','.w-promo-code .holder','display','block','4','','.w-promo-code'),(166038,'deals-mobile','.w-product-bonus-points > div','display','block','4','','.w-product-bonus-points'),(166039,'deals-mobile','.p-wedding-registry-manage a.remove-btn','display','inline-block','','','.p-wedding-registry-manage'),(166040,'deals-mobile','.p-account-history-info .popup-tracking-number-link','display','block','','','.p-account-history-info'),(166041,'deals-mobile','.p-account-history-info .popup-tracking-number a','display','block','','','.p-account-history-info'),(166042,'deals-mobile','.p-account-order-pay .history_attr','display','table','','','.p-account-order-pay'),(166043,'deals-mobile','.p-account-order-pay .history_attr div','display','table-row','','','.p-account-order-pay'),(166044,'deals-mobile','.p-account-order-pay .history_attr div strong, .p-account-order-pay .history_attr div span','display','table-cell','','','.p-account-order-pay'),(166045,'deals-mobile','.w-product-configurator .item-content > div','display','block','863','','.w-product-configurator'),(166046,'deals-mobile','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(166047,'deals-mobile','.w-product-configurator .item-content','display','block','863','','.w-product-configurator'),(166048,'deals-mobile','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(166049,'deals-mobile','.testimonials .review','display','block','3','',''),(166050,'deals-mobile','.b-pagination .pagination .paging','display','inline-block','','','.b-pagination'),(166051,'deals-mobile','.b-pagination .pagination .prev','display','inline-block','','','.b-pagination'),(166052,'deals-mobile','.b-pagination .pagination .prev-pages','display','inline-block','','','.b-pagination'),(166053,'deals-mobile','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(166054,'deals-mobile','.b-pagination .pagination .page-number','display','inline-block','','','.b-pagination'),(166055,'deals-mobile','.b-pagination .pagination .next-pages','display','inline-block','','','.b-pagination'),(166056,'deals-mobile','.b-pagination .pagination .next','display','inline-block','','','.b-pagination'),(166057,'deals-mobile','.b-pagination .pagination span','display','inline-block','2','','.b-pagination'),(166058,'deals-mobile','.p-account-history .orders-table .headings','display','none','890','','.p-account-history'),(166059,'deals-mobile','.p-account-history .view_link','display','inline-block','4','','.p-account-history'),(166060,'deals-mobile','.p-account-history .orders-table .hidden','display','inline-block','890','','.p-account-history'),(166061,'deals-mobile','.p-account-history .orders-table .item','display','block','890','','.p-account-history'),(166062,'deals-mobile','.p-account-index .orders-table .hidden','display','none','','','.p-account-index'),(166063,'deals-mobile','.p-account-history .orders-table .item td','display','block','890','','.p-account-history'),(166064,'deals-mobile','.p-account-index .orders-table .hidden','display','inline-block','890','','.p-account-index'),(166065,'deals-mobile','.p-account-index .orders-table .item','display','block','890','','.p-account-index'),(166066,'deals-mobile','.p-account-index .orders-table .headings','display','none','890','','.p-account-index'),(166067,'deals-mobile','.p-account-history .orders-table td.name','display','none','890','','.p-account-history'),(166068,'deals-mobile','.p-account-history .orders-table, .p-account-history .orders-table tbody','display','block','890','','.p-account-history'),(166069,'deals-mobile','.p-account-index .orders-table .item td','display','block','890','','.p-account-index'),(166070,'deals-mobile','.p-account-index .orders-table, .p-account-index .orders-table tbody','display','block','890','','.p-account-index'),(166071,'deals-mobile','.p-blog-index .entry-content','display','block','4','','.p-blog-index'),(166072,'deals-mobile','.p-account-index .orders-table td.name','display','none','890','','.p-account-index'),(166073,'deals-mobile','.p-blog-index .nav-links .screen-reader-text','display','block','','','.p-blog-index'),(166074,'deals-mobile','.p-blog-index .comment-author .says','display','none','','','.p-blog-index'),(166075,'deals-mobile','.p-blog-index .comment-meta','display','block','4','','.p-blog-index'),(166076,'deals-mobile','.w-list-type-2_2 .qty-input label','display','none','','','.w-list-type-2_2'),(166077,'deals-mobile','.w-list-type-2_2 .price .old','display','block','','','.w-list-type-2_2'),(166078,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','display','block','3','','.w-list-type-2_2'),(166079,'deals-mobile','.w-list-type-2_2 .item','display','block','4','','.w-list-type-2_2'),(166080,'deals-mobile','.w-list-type-2_2 .button-view a','display','block','','','.w-list-type-2_2'),(166081,'deals-mobile','.buttons','display','block','4','',''),(166082,'deals-mobile','.w-list-type-2_2 .add-height','display','block','4','','.w-list-type-2_2'),(166083,'deals-mobile','.w-list-type-2 .qty-input label','display','none','','','.w-list-type-2'),(166084,'deals-mobile','.w-list-type-2 .price .old','display','block','','','.w-list-type-2'),(166085,'deals-mobile','.personal-buttons > div','display','flex','','','.personal-buttons'),(166086,'deals-mobile','.w-account a.my-acc-link','display','inline-block','','','.w-account'),(166087,'deals-mobile','.p-reviews-info .review_by span','display','inline-block','','','.p-reviews-info'),(166088,'deals-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','display','block','','','.b-fancybox'),(166089,'deals-mobile','.w-menu-horizontal ul ul li','display','block','','','.w-menu-horizontal'),(166090,'deals-mobile','.w-menu-horizontal ul li:hover > ul','display','block','','','.w-menu-horizontal'),(166091,'deals-mobile','.w-menu-horizontal ul ul','display','none','','','.w-menu-horizontal'),(166092,'deals-mobile','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(166093,'deals-mobile','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(166094,'deals-mobile','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(166095,'deals-mobile','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(166096,'deals-mobile','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(166097,'deals-mobile','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(166098,'deals-mobile','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(166099,'deals-mobile','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(166100,'deals-mobile','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(166101,'deals-mobile','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(166102,'deals-mobile','.p-wedding-registry-index .search-list label','display','block','','','.p-wedding-registry-index'),(166103,'deals-mobile','.b-form .form-inputs label > span','display','inline-block','','','.b-form'),(166104,'deals-mobile','.p-wedding-registry-manage .links a','display','inline-block','','','.p-wedding-registry-manage'),(166105,'deals-mobile','.p-wedding-registry-search #searchform-status','display','flex','','','.p-wedding-registry-search'),(166106,'deals-mobile','.p-wedding-registry-search .search-form','display','flex','','','.p-wedding-registry-search'),(166107,'deals-mobile','.b-pagination .pagination a','display','inline-block','','','.b-pagination'),(166108,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(166109,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(166110,'deals-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','display','inline-block','','','.b-compare'),(166111,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display','inline-block','','','.b-switch'),(166112,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container','display','inline-block','','','.b-switch'),(166113,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display','inline-block','','','.b-switch'),(166114,'deals-mobile','.b-switch .bootstrap-switch','display','inline-block','','','.b-switch'),(166115,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','display','inline-block','','','.b-fancybox'),(166116,'deals-mobile','.b-form .middle-form .col-gender label','display','inline-block','','','.b-form'),(166117,'deals-mobile','.w-tabs .accordion-heading','display','block','','','.w-tabs'),(166118,'deals-mobile','.w-currencies .select-link','display','block','872','','.w-currencies'),(166119,'deals-mobile','.w-languages .lang-link','display','block','872','','.w-languages'),(166120,'deals-mobile','.b-bottom .footerTitle ~ div','display','none','863','','.b-bottom'),(166121,'deals-mobile','.w-filters .input-checkbox:checked + .checkbox-span','display','inline-block','','','.w-filters'),(166122,'deals-mobile','.w-catalog-listing-look .grid','display','inline-block','','','.w-catalog-listing-look'),(166123,'deals-mobile','.w-list-type-1 .button-view a','display','block','','','.w-list-type-1'),(166124,'deals-mobile','.w-top-categories .categories','display','block','4','','.w-top-categories'),(166125,'deals-mobile','.w-tabs .tab-li','display','table-cell','','','.w-tabs'),(166126,'deals-mobile','.w-top-categories .item','display','inline-block','','','.w-top-categories'),(166127,'deals-mobile','.w-tabs .tab-a','display','block','','','.w-tabs'),(166128,'deals-mobile','.w-search .search','display','block','3','','.w-search'),(166129,'deals-mobile','.w-search .item','display','block','','','.w-search'),(166130,'deals-mobile','.w-search .name','display','block','','','.w-search'),(166131,'deals-mobile','.b-product-images .additional-images .item, .b-product-images .additional-videos .item','display','table','','','.b-product-images'),(166132,'deals-mobile','.w-banner .sliderItems a + a, .w-banner .sliderItems a + img, .w-banner .sliderItems img + a, .w-banner .sliderItems img + img','display','none','','','.w-banner'),(166133,'deals-mobile','.w-list-type-1_3 .price .old','display','block','','','.w-list-type-1_3'),(166134,'deals-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','display','inline-block','','','.w-filters'),(166135,'deals-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','display','table-cell','','','.w-banner'),(166136,'deals-mobile','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','display','table','','','.w-banner'),(166137,'deals-mobile','.p-account-trade-form .wl-td label','display','inline-block','','','.p-account-trade-form'),(166138,'deals-mobile','.p-checkout-index .shipping-method .row','display','block','','','.p-checkout-index'),(166139,'deals-mobile','.p-quote-cart-index .cart-popup .gift-wrap','display','none','','','.p-quote-cart-index'),(166140,'deals-mobile','.p-shopping-cart-index .cart-popup .gift-wrap','display','none','','','.p-shopping-cart-index'),(166141,'deals-mobile','.w-currencies .select','display','none','','','.w-currencies'),(166142,'deals-mobile','.w-currencies .currencies-title','display','block','','','.w-currencies'),(166143,'deals-mobile','.w-currencies .currencies:hover .select','display','block','','','.w-currencies'),(166144,'deals-mobile','.w-currencies .currencies','display','inline-block','','','.w-currencies'),(166145,'deals-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(166146,'deals-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(166147,'deals-mobile','.b-slick .slick-slider','display','block','','','.b-slick'),(166148,'deals-mobile','.b-slick .slick-track','display','block','','','.b-slick'),(166149,'deals-mobile','.b-slick .slick-vertical .slick-slide','display','block','','','.b-slick'),(166150,'deals-mobile','.b-slick .slick-track, .b-slick .slick-track:after','display','table','3','','.b-slick'),(166151,'deals-mobile','.p-account-trade-form .wd-line-row-2','display','block','4','','.p-account-trade-form'),(166152,'deals-mobile','.b-info-popup .info-popup','display','inline-block','3','','.b-info-popup'),(166153,'deals-mobile','.b-info-popup .info-popup','display','inline-block','','','.b-info-popup'),(166154,'deals-mobile','.p-account-index .view_link','display','inline-block','4','','.p-account-index'),(166155,'deals-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','display','inline-block','','','.w-menu-style-1'),(166156,'deals-mobile','.p-account-index .view_history','display','inline-block','3','','.p-account-index'),(166157,'deals-mobile','.w-menu-style-1 li','display','inline-block','','','.w-menu-style-1'),(166158,'deals-mobile','.w-account .account-dropdown','display','none','','','.w-account'),(166159,'deals-mobile','.p-checkout-success .page-success .text-1','display','block','3','','.p-checkout-success'),(166160,'deals-mobile','.p-account-index .topAccount > li > div','display','block','3','','.p-account-index'),(166161,'deals-mobile','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(166162,'deals-mobile','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(166163,'deals-mobile','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(166164,'deals-mobile','.w-product-quantity-discounts .quantity-discounts .count','display','inline-block','','','.w-product-quantity-discounts'),(166165,'deals-mobile','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(166166,'deals-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(166167,'deals-mobile','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(166168,'deals-mobile','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(166169,'deals-mobile','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(166170,'deals-mobile','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(166171,'deals-mobile','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(166172,'deals-mobile','.w-menu-style-1 ul ul li','display','block','','','.w-menu-style-1'),(166173,'deals-mobile','.w-menu-style-1 ul li:hover > ul','display','block','','','.w-menu-style-1'),(166174,'deals-mobile','.w-menu-style-1 ul ul','display','none','','','.w-menu-style-1'),(166175,'deals-mobile','.w-menu-style-1 li li a, .w-menu-style-1 li li .no-link','display','block','','','.w-menu-style-1'),(166176,'deals-mobile','.b-fancybox .fancybox-overlay','display','none','','','.b-fancybox'),(166177,'deals-mobile','.w-sale .left-text-right','display','block','','','.w-sale'),(166178,'deals-mobile','.w-sale .left-count-hours','display','block','','','.w-sale'),(166179,'deals-mobile','.w-sale .left-text-left','display','block','','','.w-sale'),(166180,'deals-mobile','.w-sale .special-price','display','block','','','.w-sale'),(166181,'deals-mobile','.w-sale .text','display','block','','','.w-sale'),(166182,'deals-mobile','.w-sale .special-price-text','display','none','','','.w-sale'),(166183,'deals-mobile','.w-text .customer-service b','display','block','','','.w-text'),(166184,'deals-mobile','.w-top-categories .categories','display','flex','','','.w-top-categories'),(166185,'deals-mobile','.w-banner .carousel-text','display','flex','','','.w-banner'),(166186,'deals-mobile','.b-slick .slick-slide.slick-loading img','display','none','','','.b-slick'),(166187,'deals-mobile','.b-slick .slick-slide','display','none','','','.b-slick'),(166188,'deals-mobile','.b-slick .slick-arrow.slick-hidden','display','none','','','.b-slick'),(166189,'deals-mobile','.b-slick .slick-initialized .slick-slide','display','block','','','.b-slick'),(166190,'deals-mobile','.b-slick .slick-list','display','block','','','.b-slick'),(166191,'deals-mobile','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(166192,'deals-mobile','.b-rating #stars-default .glyphicon','display','inline-block','','','.b-rating'),(166193,'deals-mobile','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(166194,'deals-mobile','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(166195,'deals-mobile','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(166196,'deals-mobile','.w-cart .cart-box.hover-box .cart-content','display','none','','','.w-cart'),(166197,'deals-mobile','.w-cart .cart-box.hover-box:hover .cart-content','display','block','','','.w-cart'),(166198,'deals-mobile','.w-cart .cart-box-link','display','block','','','.w-cart'),(166199,'deals-mobile','.w-cart .strong','display','block','','','.w-cart'),(166200,'deals-mobile','.w-filters .mobileCollapse','display','inline-block','890','','.w-filters'),(166201,'deals-mobile','.w-menu-horizontal li','display','inline-block','','','.w-menu-horizontal'),(166202,'deals-mobile','.w-menu-horizontal li li a, .w-menu-horizontal li li .no-link','display','block','','','.w-menu-horizontal'),(166203,'deals-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','display','inline-block','3','','.w-cart-discount-coupon'),(166204,'deals-mobile','.w-cart .cart-box-link','display','inline-block','3','','.w-cart'),(166205,'deals-mobile','.w-search .search form','display','none','','','.w-search'),(166206,'deals-mobile','.w-list-type-1_3 .qty-input label','display','none','','','.w-list-type-1_3'),(166207,'deals-mobile','.p-account-index .account_info .info','display','none','3','','.p-account-index'),(166208,'deals-mobile','.p-account-history-info .history_attr','display','table','','','.p-account-history-info'),(166209,'deals-mobile','.p-account-history-info .history_attr div','display','table-row','','','.p-account-history-info'),(166210,'deals-mobile','.b-form .columns','display','block','4','','.b-form'),(166211,'deals-mobile','.b-form .addresses','display','block','4','','.b-form'),(166212,'deals-mobile','.p-account-index .date_value, .p-account-index .date_title','display','block','','','.p-account-index'),(166213,'deals-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(166214,'deals-mobile','.w-cart a.item','display','block','','','.w-cart'),(166215,'deals-mobile','.b-datepicker .picker-switch','display','none','','','.b-datepicker'),(166216,'deals-mobile','.w-cart a.item','display','block','4','','.w-cart'),(166217,'deals-mobile','.w-cart-give-away .ga_name','display','block','4','','.w-cart-give-away'),(166218,'deals-mobile','.w-search .search.opened form','display','block','','','.w-search'),(166219,'deals-mobile','.w-list-type-2 .button-view a','display','block','','','.w-list-type-2'),(166220,'deals-mobile','.w-list-type-2 .add-height','display','block','4','','.w-list-type-2'),(166221,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','display','block','3','','.w-list-type-2'),(166222,'deals-mobile','.w-list-type-1_3 .item','display','block','4','','.w-list-type-1_3'),(166223,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','display','block','3','','.w-list-type-1_3'),(166224,'deals-mobile','.w-list-type-1_3 .button-view a','display','block','','','.w-list-type-1_3'),(166225,'deals-mobile','.w-list-type-1_3 .attributes > .attributes','display','block','4','','.w-list-type-1_3'),(166226,'deals-mobile','.w-list-type-1_3 .add-height','display','block','4','','.w-list-type-1_3'),(166227,'deals-mobile','.w-list-type-1_2 .right-area','display','block','4','','.w-list-type-1_2'),(166228,'deals-mobile','.w-list-type-1_2 .qty-input label','display','none','','','.w-list-type-1_2'),(166229,'deals-mobile','.w-list-type-1_2 .item','display','block','4','','.w-list-type-1_2'),(166230,'deals-mobile','.w-list-type-1_2 .price .old','display','block','','','.w-list-type-1_2'),(166231,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','display','block','3','','.w-list-type-1_2'),(166232,'deals-mobile','.w-list-type-1_2 .button-view a','display','block','','','.w-list-type-1_2'),(166233,'deals-mobile','.w-list-type-1_2 .add-height','display','block','4','','.w-list-type-1_2'),(166234,'deals-mobile','.w-list-type-1 .qty-input label','display','none','','','.w-list-type-1'),(166235,'deals-mobile','.w-list-type-1 .price .old','display','block','','','.w-list-type-1'),(166236,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','display','block','3','','.w-list-type-1'),(166237,'deals-mobile','.w-filters .mobileCollapse','display','none','','','.w-filters'),(166238,'deals-mobile','.w-languages .select','display','none','','','.w-languages'),(166239,'deals-mobile','.w-languages .languages:hover .select','display','block','','','.w-languages'),(166240,'deals-mobile','.w-languages .languages','display','inline-block','','','.w-languages'),(166241,'deals-mobile','.w-list-type-1 .add-height','display','block','4','','.w-list-type-1'),(166242,'deals-mobile','.b-form .addresses .address-item span','display','block','','','.b-form'),(166243,'deals-mobile','.w-tabs > .block > .box .heading-2, .w-tabs > .block > .box .heading-3, .w-tabs > .block > .box .heading-4','display','none','','','.w-tabs'),(166244,'deals-mobile','.w-top-categories .name','display','block','','','.w-top-categories'),(166245,'deals-mobile','.w-tabs .tab-navigation','display','table','','','.w-tabs'),(166246,'deals-mobile','.w-product-reviews .reviews-list .review','display','block','3','','.w-product-reviews'),(166247,'deals-mobile','.w-top-categories .image','display','block','','','.w-top-categories'),(166248,'deals-mobile','.w-reviews .review','display','block','3','','.w-reviews'),(166249,'deals-mobile','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(166250,'deals-mobile','.w-search .items-title','display','block','','','.w-search'),(166251,'deals-mobile','.b-form .middle-form label','display','block','','','.b-form'),(166252,'deals-mobile','.b-form .payment-method .item-radio label','display','block','','','.b-form'),(166253,'deals-mobile','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','display','inline-block','','','.b-form'),(166254,'deals-mobile','.b-form .payment-method .item-radio label span','display','block','','','.b-form'),(166255,'deals-mobile','.b-form .payment-method .sub-item span','display','block','','','.b-form'),(166256,'deals-mobile','.b-info .info','display','inline-block','3','','.b-info'),(166257,'deals-mobile','.w-cart .cart-content','display','none','','','.w-cart'),(166258,'deals-mobile','.b-products-listing .BlockBox','display','block','4','','.b-products-listing'),(166259,'deals-mobile','.b-products-listing .btn-preloader','display','inline-block','3','','.b-products-listing'),(166260,'deals-mobile','.b-products-listing .hide','display','none','','','.b-products-listing'),(166261,'deals-mobile','.b-products-listing .hover-box-content','display','none','','','.b-products-listing'),(166262,'deals-mobile','.b-products-listing .hover-box:hover .hover-box-content','display','block','','','.b-products-listing'),(166263,'deals-mobile','.b-products-listing .loader','display','inline-block','4','','.b-products-listing'),(166264,'deals-mobile','.b-products-listing .products-listing','display','block','4','','.b-products-listing'),(166265,'deals-mobile','.b-products-listing .products-listing .attribute-qty-block','display','flex','','','.b-products-listing'),(166266,'deals-mobile','.b-products-listing .products-listing .attribute-qty-blocks','display','flex','','','.b-products-listing'),(166267,'deals-mobile','.b-products-listing .products-listing .bonus-points','display','flex','','','.b-products-listing'),(166268,'deals-mobile','.b-products-listing .products-listing .btn-buy','display','inline-block','3','','.b-products-listing'),(166269,'deals-mobile','.b-products-listing .products-listing .compare','display','block','','','.b-products-listing'),(166270,'deals-mobile','.b-products-listing .products-listing .compare label','display','inline','','','.b-products-listing'),(166271,'deals-mobile','.b-products-listing .products-listing .item','display','inline-block','','','.b-products-listing'),(166272,'deals-mobile','.b-products-listing .products-listing .mix-attributes','display','block','4','','.b-products-listing'),(166273,'deals-mobile','.b-products-listing .products-listing.align-left .item','display','block','','','.b-products-listing'),(166274,'deals-mobile','.b-products-listing .products-listing.align-right .item','display','block','','','.b-products-listing'),(166275,'deals-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','display','block','','','.b-products-listing'),(166276,'deals-mobile','.b-products-listing .promos-info .promo-item','display','flex','','','.b-products-listing'),(166277,'deals-mobile','.b-products-listing .select-attributes','display','flex','','','.b-products-listing'),(166278,'deals-mobile','.b-products-listing .show-ofstock-products .headerStock','display','inline-block','','','.b-products-listing'),(166279,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.b-data-table'),(166280,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.b-data-table'),(166281,'deals-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(166282,'deals-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(166283,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(166284,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(166285,'deals-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(166286,'deals-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(166287,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(166288,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(166289,'deals-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(166290,'deals-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(166291,'deals-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(166292,'deals-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(166293,'deals-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(166294,'deals-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(166295,'deals-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(166296,'deals-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(166297,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(166298,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(166299,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','display','inline','','','.b-h-inline'),(166300,'deals-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .menu-content','display','none','','','.b-menu-burger_icon'),(166301,'deals-mobile','.b-menu-burger_icon .bi-opened .menu-style[data-burger_icon] .menu-content','display','block','','','.b-menu-burger_icon'),(166302,'deals-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','display','block','','','.b-menu-burger_icon'),(166303,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','display','block','','','.b-menu-lev_display-slide'),(166304,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','display','block','','','.b-menu-lev_display-slide'),(166305,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','display','block','','','.b-menu-lev_display-slide'),(166306,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','display','block','','','.b-menu-lev_display-slide'),(166307,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','display','block','','','.b-menu-lev_display-slide'),(166308,'deals-mobile','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(166309,'deals-mobile','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(166310,'deals-mobile','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(166311,'deals-mobile','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(166312,'deals-mobile','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(166313,'deals-mobile','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(166314,'deals-mobile','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(166315,'deals-mobile','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(166316,'deals-mobile','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(166317,'deals-mobile','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(166318,'deals-mobile','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(166319,'deals-mobile','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(166320,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-2','display','none','','','.b-menu-lev_vis'),(166321,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(166322,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-3','display','none','','','.b-menu-lev_vis'),(166323,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(166324,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-4','display','none','','','.b-menu-lev_vis'),(166325,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(166326,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-5','display','none','','','.b-menu-lev_vis'),(166327,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(166328,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-6','display','none','','','.b-menu-lev_vis'),(166329,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(166330,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(166331,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-2','display','none','','','.b-menu-lev_vis'),(166332,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(166333,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-3','display','none','','','.b-menu-lev_vis'),(166334,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(166335,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-4','display','none','','','.b-menu-lev_vis'),(166336,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(166337,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-5','display','none','','','.b-menu-lev_vis'),(166338,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(166339,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-6','display','none','','','.b-menu-lev_vis'),(166340,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(166341,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1','display','none','','','.b-menu-lev_vis-click_icon'),(166342,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(166343,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-3','display','none','','','.b-menu-lev_vis-click_icon'),(166344,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(166345,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-4','display','none','','','.b-menu-lev_vis-click_icon'),(166346,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(166347,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-5','display','none','','','.b-menu-lev_vis-click_icon'),(166348,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(166349,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-6','display','none','','','.b-menu-lev_vis-click_icon'),(166350,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display','block','','','.b-menu-open_from-left'),(166351,'deals-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul','display','flex','','','.b-menu-position'),(166352,'deals-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(166353,'deals-mobile','.b-menu-style picture','display','none','','','.b-menu-style'),(166354,'deals-mobile','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display','none','','','.b-menu-style'),(166355,'deals-mobile','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display','none','','','.b-menu-style'),(166356,'deals-mobile','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display','none','','','.b-menu-style'),(166357,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','display','flex','','','.b-menu-style-1'),(166358,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .component-item','display','none','','','.b-menu-style-1'),(166359,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','display','inline-block','','','.b-menu-style-1'),(166360,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','display','block','','','.b-menu-style-1'),(166361,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','display','block','','','.b-menu-style-2'),(166362,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','display','block','','','.b-menu-style-2'),(166363,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','display','flex','','','.b-menu-style-2'),(166364,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .languages','display','flex','','','.b-menu-style-2'),(166365,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','display','block','','','.b-menu-style-2'),(166366,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies','display','flex','','','.b-menu-style-2'),(166367,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','display','flex','','','.b-menu-style-2'),(166368,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','display','block','','','.b-menu-style-3'),(166369,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .component-item','display','none','','','.b-menu-style-3'),(166370,'deals-mobile','.b-messages .messMenuButton span','display','inline-block','','','.b-messages'),(166371,'deals-mobile','.b-messages .msv_to_cc div span','display','inline-block','','','.b-messages'),(166372,'deals-mobile','.b-messages span.starred::before','display','inline-block','','','.b-messages'),(166373,'deals-mobile','.b-messages .messBtnMenuStarred','display','inline-block','3','','.b-messages'),(166374,'deals-mobile','.b-messages .dataTables_wrapper > .top','display','block','4','','.b-messages'),(166375,'deals-mobile','.b-messages .messBtnMenuDelete','display','inline-block','3','','.b-messages'),(166376,'deals-mobile','.b-messages .messBtnMenuUnread','display','inline-block','3','','.b-messages'),(166377,'deals-mobile','.b-messages .messages-menu li a','display','block','','','.b-messages'),(166378,'deals-mobile','.b-messages .content_management_attach button','display','inline-block','','','.b-messages'),(166379,'deals-mobile','.b-messages .email-line','display','flex','','','.b-messages'),(166380,'deals-mobile','.b-messages .dataTables_wrapper > .bottom','display','block','4','','.b-messages'),(166381,'deals-mobile','.b-preloader .preloader','display','inline-block','3','','.b-preloader'),(166382,'deals-mobile','.b-select-suggest .select2-container .select2-choice','display','block','','','.b-select-suggest'),(166383,'deals-mobile','.b-select-suggest .select2-container.select2-allowclear .select2-choice abbr','display','inline-block','','','.b-select-suggest'),(166384,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','display','none','','','.b-select-suggest'),(166385,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','3','','.b-select-suggest'),(166386,'deals-mobile','.b-select-suggest .select2-results .select2-disabled','display','list-item','','','.b-select-suggest'),(166387,'deals-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','display','block','','','.b-select-suggest'),(166388,'deals-mobile','.b-select-suggest .select2-display-none','display','none','','','.b-select-suggest'),(166389,'deals-mobile','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','display','list-item','','','.b-select-suggest'),(166390,'deals-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice abbr','display','none','','','.b-select-suggest'),(166391,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','display','none','','','.b-select-suggest'),(166392,'deals-mobile','.b-select-suggest .select2-more-results','display','list-item','','','.b-select-suggest'),(166393,'deals-mobile','.b-select-suggest .select2-results li','display','list-item','','','.b-select-suggest'),(166394,'deals-mobile','.b-select-suggest .select2-results .select2-selected','display','none','','','.b-select-suggest'),(166395,'deals-mobile','.b-select-suggest .select2-search','display','inline-block','','','.b-select-suggest'),(166396,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','','','.b-select-suggest'),(166397,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','display','inline-block','','','.b-select-suggest'),(166398,'deals-mobile','.b-select-suggest .select2-container','display','inline-block','','','.b-select-suggest'),(166399,'deals-mobile','.b-select-suggest .select2-search-choice-close','display','block','','','.b-select-suggest'),(166400,'deals-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','display','list-item','','','.b-select-suggest'),(166401,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(166402,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(166403,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(166404,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(166405,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(166406,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(166407,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(166408,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(166409,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(166410,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(166411,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(166412,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(166413,'deals-mobile','.b-trade-approval .steps-bar','display','table','','','.b-trade-approval'),(166414,'deals-mobile','.b-trade-approval .steps-bar li','display','table-cell','','','.b-trade-approval'),(166415,'deals-mobile','.b-trade-approval .steps-bar li a','display','block','','','.b-trade-approval'),(166416,'deals-mobile','.b-trade-approval .middle-form label','display','block','','','.b-trade-approval'),(166417,'deals-mobile','.b-trade-approval .columns','display','block','4','','.b-trade-approval'),(166418,'deals-mobile','.b-upload-file .upload-file-template','display','inline-block','','','.b-upload-file'),(166419,'deals-mobile','.b-upload-files .attach-active-holder','display','block','','','.b-upload-files'),(166420,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','display','inline-block','','','.b-warehouses-popup'),(166421,'deals-mobile','.batchPr .checkbox input:not(checked) + span:before','display','none','','','.batchPr'),(166422,'deals-mobile','.batchPr .checkbox input:checked + span:before','display','inline-block','','','.batchPr'),(166423,'deals-mobile','.batchPr .batchSelect .checkbox','display','inline-block','','','.batchPr'),(166424,'deals-mobile','.batchPr .btn-batch-remove','display','block','3','','.batchPr'),(166425,'deals-mobile','.batchPr .checkbox input + span','display','block','','','.batchPr'),(166426,'deals-mobile','.batchPr .batch-selected-products-list','display','none','','','.batchPr'),(166427,'deals-mobile','.batchPr .checkbox input','display','none','','','.batchPr'),(166428,'deals-mobile','.batchPr .w-batch-selected-products .item:hover .btn-batch-remove','display','block','','','.batchPr'),(166429,'deals-mobile','.batchPr .btn-batch-remove','display','none','','','.batchPr'),(166430,'deals-mobile','.batchPr .w-batch-products .radio-attributes .option-color, .batchPr .w-batch-products .radio-attributes span[itemprop=\"price\"]','display','none','','','.batchPr'),(166431,'deals-mobile','.batchPr .products-listing .radio-attributes label','display','inline-block','','','.batchPr'),(166432,'deals-mobile','.p-account-samples-history .orders-table .hidden','display','inline-block','','','.p-account-samples-history'),(166433,'deals-mobile','.p-account-samples-history .orders-table .item','display','block','','','.p-account-samples-history'),(166434,'deals-mobile','.p-account-samples-history .orders-table td.name','display','none','','','.p-account-samples-history'),(166435,'deals-mobile','.p-account-samples-history .orders-table .headings','display','none','','','.p-account-samples-history'),(166436,'deals-mobile','.p-account-samples-history .orders-table .item td','display','block','','','.p-account-samples-history'),(166437,'deals-mobile','.p-account-samples-history .orders-table, .p-account-samples-history .orders-table tbody','display','block','','','.p-account-samples-history'),(166438,'deals-mobile','.p-account-samples-history .view_link','display','inline-block','4','','.p-account-samples-history'),(166439,'deals-mobile','.p-account-samples-history .orders-table .headings','display','none','','','.p-account-samples-history'),(166440,'deals-mobile','.p-account-samples-history .orders-table .item','display','block','','','.p-account-samples-history'),(166441,'deals-mobile','.p-account-samples-history .orders-table .headings','display','none','','','.p-account-samples-history'),(166442,'deals-mobile','.p-account-samples-history .orders-table .item td','display','block','','','.p-account-samples-history'),(166443,'deals-mobile','.p-account-samples-history .orders-table .item td','display','block','','','.p-account-samples-history'),(166444,'deals-mobile','.p-account-samples-history .orders-table td.name','display','none','','','.p-account-samples-history'),(166445,'deals-mobile','.p-account-samples-history .view_link','display','inline-block','4','','.p-account-samples-history'),(166446,'deals-mobile','.p-account-samples-history .short-date','display','none','','','.p-account-samples-history'),(166447,'deals-mobile','.p-account-samples-history .orders-table, .p-account-samples-history .orders-table tbody','display','block','','','.p-account-samples-history'),(166448,'deals-mobile','.p-account-samples-history .orders-table .hidden','display','inline-block','','','.p-account-samples-history'),(166449,'deals-mobile','.p-account-samples-history .orders-table .hidden','display','none','','','.p-account-samples-history'),(166450,'deals-mobile','.p-account-samples-history .orders-table td.name','display','none','','','.p-account-samples-history'),(166451,'deals-mobile','.p-account-samples-history .orders-table, .p-account-samples-history .orders-table tbody','display','block','','','.p-account-samples-history'),(166452,'deals-mobile','.p-account-samples-history .orders-table .hidden','display','none','','','.p-account-samples-history'),(166453,'deals-mobile','.p-account-samples-history .orders-table .item td','display','block','','','.p-account-samples-history'),(166454,'deals-mobile','.p-account-samples-history .orders-table td.name','display','none','','','.p-account-samples-history'),(166455,'deals-mobile','.p-account-samples-history .view_link','display','inline-block','4','','.p-account-samples-history'),(166456,'deals-mobile','.p-account-samples-history .orders-table .hidden','display','inline-block','','','.p-account-samples-history'),(166457,'deals-mobile','.p-account-samples-history .orders-table .headings','display','none','','','.p-account-samples-history'),(166458,'deals-mobile','.p-account-samples-history .orders-table .headings','display','none','','','.p-account-samples-history'),(166459,'deals-mobile','.p-account-samples-history .orders-table, .p-account-samples-history .orders-table tbody','display','block','','','.p-account-samples-history'),(166460,'deals-mobile','.p-account-samples-history .orders-table .item','display','block','','','.p-account-samples-history'),(166461,'deals-mobile','.p-account-samples-history .short-date','display','none','','','.p-account-samples-history'),(166462,'deals-mobile','.p-account-samples-history .orders-table .headings','display','none','','','.p-account-samples-history'),(166463,'deals-mobile','.p-account-samples-history .short-date','display','none','','','.p-account-samples-history'),(166464,'deals-mobile','.p-account-samples-history .orders-table .hidden','display','inline-block','','','.p-account-samples-history'),(166465,'deals-mobile','.p-account-samples-history .orders-table .hidden','display','none','','','.p-account-samples-history'),(166466,'deals-mobile','.p-account-samples-history .orders-table td.name','display','none','','','.p-account-samples-history'),(166467,'deals-mobile','.p-account-samples-history .view_link','display','inline-block','4','','.p-account-samples-history'),(166468,'deals-mobile','.p-account-samples-history .orders-table td.name','display','none','','','.p-account-samples-history'),(166469,'deals-mobile','.p-account-samples-history .orders-table, .p-account-samples-history .orders-table tbody','display','block','','','.p-account-samples-history'),(166470,'deals-mobile','.p-account-samples-history .orders-table .hidden','display','none','','','.p-account-samples-history'),(166471,'deals-mobile','.p-account-samples-history .orders-table .item td','display','block','','','.p-account-samples-history'),(166472,'deals-mobile','.p-account-samples-history .orders-table .hidden','display','none','','','.p-account-samples-history'),(166473,'deals-mobile','.p-account-samples-history .orders-table .hidden','display','none','','','.p-account-samples-history'),(166474,'deals-mobile','.p-account-samples-history .orders-table .hidden','display','inline-block','','','.p-account-samples-history'),(166475,'deals-mobile','.p-account-samples-history .view_link','display','inline-block','4','','.p-account-samples-history'),(166476,'deals-mobile','.p-account-samples-history .view_link','display','inline-block','4','','.p-account-samples-history'),(166477,'deals-mobile','.p-account-samples-history .orders-table .item','display','block','','','.p-account-samples-history'),(166478,'deals-mobile','.p-account-samples-history .short-date','display','none','','','.p-account-samples-history'),(166479,'deals-mobile','.p-account-samples-history .short-date','display','none','','','.p-account-samples-history'),(166480,'deals-mobile','.p-account-samples-history .short-date','display','none','','','.p-account-samples-history'),(166481,'deals-mobile','.p-account-samples-history .orders-table, .p-account-samples-history .orders-table tbody','display','block','','','.p-account-samples-history'),(166482,'deals-mobile','.p-account-samples-history .orders-table .item','display','block','','','.p-account-samples-history'),(166483,'deals-mobile','.p-account-samples-history .orders-table .hidden','display','inline-block','','','.p-account-samples-history'),(166484,'deals-mobile','.p-account-samples-history .orders-table .item','display','block','','','.p-account-samples-history'),(166485,'deals-mobile','.p-account-samples-history .orders-table .item td','display','block','','','.p-account-samples-history'),(166486,'deals-mobile','.p-account-samples-history-info .history_attr div','display','table-row','','','.p-account-samples-history-info'),(166487,'deals-mobile','.p-account-samples-history-info .popup-tracking-number a','display','block','','','.p-account-samples-history-info'),(166488,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','display','block','','','.p-account-samples-history-info'),(166489,'deals-mobile','.p-account-samples-history-info .popup-tracking-number a','display','block','','','.p-account-samples-history-info'),(166490,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','display','block','','','.p-account-samples-history-info'),(166491,'deals-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','display','table-cell','','','.p-account-samples-history-info'),(166492,'deals-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','display','table-cell','','','.p-account-samples-history-info'),(166493,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','display','block','','','.p-account-samples-history-info'),(166494,'deals-mobile','.p-account-samples-history-info .history_attr','display','table','','','.p-account-samples-history-info'),(166495,'deals-mobile','.p-account-samples-history-info .popup-tracking-number a','display','block','','','.p-account-samples-history-info'),(166496,'deals-mobile','.p-account-samples-history-info .history_attr div','display','table-row','','','.p-account-samples-history-info'),(166497,'deals-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','display','table-cell','','','.p-account-samples-history-info'),(166498,'deals-mobile','.p-account-samples-history-info .popup-tracking-number a','display','block','','','.p-account-samples-history-info'),(166499,'deals-mobile','.p-account-samples-history-info .history_attr div','display','table-row','','','.p-account-samples-history-info'),(166500,'deals-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','display','table-cell','','','.p-account-samples-history-info'),(166501,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','display','block','','','.p-account-samples-history-info'),(166502,'deals-mobile','.p-account-samples-history-info .history_attr','display','table','','','.p-account-samples-history-info'),(166503,'deals-mobile','.p-account-samples-history-info .history_attr div','display','table-row','','','.p-account-samples-history-info'),(166504,'deals-mobile','.p-account-samples-history-info .history_attr div','display','table-row','','','.p-account-samples-history-info'),(166505,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','display','block','','','.p-account-samples-history-info'),(166506,'deals-mobile','.p-account-samples-history-info .popup-tracking-number a','display','block','','','.p-account-samples-history-info'),(166507,'deals-mobile','.p-account-samples-history-info .history_attr','display','table','','','.p-account-samples-history-info'),(166508,'deals-mobile','.p-account-samples-history-info .history_attr div','display','table-row','','','.p-account-samples-history-info'),(166509,'deals-mobile','.p-account-samples-history-info .popup-tracking-number a','display','block','','','.p-account-samples-history-info'),(166510,'deals-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','display','table-cell','','','.p-account-samples-history-info'),(166511,'deals-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','display','table-cell','','','.p-account-samples-history-info'),(166512,'deals-mobile','.p-account-samples-history-info .history_attr','display','table','','','.p-account-samples-history-info'),(166513,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','display','block','','','.p-account-samples-history-info'),(166514,'deals-mobile','.p-account-samples-history-info .history_attr','display','table','','','.p-account-samples-history-info'),(166515,'deals-mobile','.p-account-samples-history-info .history_attr','display','table','','','.p-account-samples-history-info'),(166516,'deals-mobile','.p-catalog-product .prev-next-product > span','display','block','','','.p-catalog-product'),(166517,'deals-mobile','.p-catalog-product .pn-price','display','none','','','.p-catalog-product'),(166518,'deals-mobile','.p-quick-order-index .quick-order-total','display','flex','','','.p-quick-order-index'),(166519,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.p-quick-order-index'),(166520,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.p-quick-order-index'),(166521,'deals-mobile','.p-quick-order-index ul.token-input-list','display','inline-block','','','.p-quick-order-index'),(166522,'deals-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(166523,'deals-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(166524,'deals-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(166525,'deals-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(166526,'deals-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(166527,'deals-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(166528,'deals-mobile','.p-sample-checkout-success .page-success .text-1','display','block','3','','.p-sample-checkout-success'),(166529,'deals-mobile','.w-account-address-book .wrap','display','flex','','','.w-account-address-book'),(166530,'deals-mobile','.w-account-address-book .default-address','display','inline-block','','','.w-account-address-book'),(166531,'deals-mobile','.w-account-address-book .address-book','display','flex','','','.w-account-address-book'),(166532,'deals-mobile','.w-account-address-book .add_item a','display','flex','','','.w-account-address-book'),(166533,'deals-mobile','.w-account-address-book .btn-edit','display','none','3','','.w-account-address-book'),(166534,'deals-mobile','.w-account-address-book .add_item a','display','block','3','','.w-account-address-book'),(166535,'deals-mobile','.w-account-customer-additional-field .field-type-checkbox label','display','inline-block','','','.w-account-customer-additional-field'),(166536,'deals-mobile','.w-account-customer-additional-field .field-type-text','display','flex','','','.w-account-customer-additional-field'),(166537,'deals-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(166538,'deals-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(166539,'deals-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(166540,'deals-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(166541,'deals-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(166542,'deals-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(166543,'deals-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(166544,'deals-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(166545,'deals-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(166546,'deals-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(166547,'deals-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(166548,'deals-mobile','.w-account-personal-catalog .list-switcher','display','flex','','','.w-account-personal-catalog'),(166549,'deals-mobile','.w-account-subscription .send-email','display','block','','','.w-account-subscription'),(166550,'deals-mobile','.w-account-subscription .subscription-variant','display','flex','','','.w-account-subscription'),(166551,'deals-mobile','.w-blog-widget-categories-list a','display','inline-block','3','','.w-blog-widget-categories-list'),(166552,'deals-mobile','.w-blog-widget-categories-list a','display','block','','','.w-blog-widget-categories-list'),(166553,'deals-mobile','.w-blog-widget-most-popular-posts a','display','block','','','.w-blog-widget-most-popular-posts'),(166554,'deals-mobile','.w-blog-widget-most-popular-posts a','display','inline-block','3','','.w-blog-widget-most-popular-posts'),(166555,'deals-mobile','.w-blog-widget-post-comments-count span','display','inline-block','','','.w-blog-widget-post-comments-count'),(166556,'deals-mobile','.w-blog-widget-post-listing .post_comment','display','none','','','.w-blog-widget-post-listing'),(166557,'deals-mobile','.w-blog-widget-post-listing .post_date span + span','display','inline-block','3','','.w-blog-widget-post-listing'),(166558,'deals-mobile','.w-blog-widget-post-listing .products','display','block','4','','.w-blog-widget-post-listing'),(166559,'deals-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','display','inline-block','','','.w-blog-widget-post-share'),(166560,'deals-mobile','.w-blog-widget-post-title h1','display','none','4','','.w-blog-widget-post-title'),(166561,'deals-mobile','.w-blog-widget-post-title h1','display','none','3','','.w-blog-widget-post-title'),(166562,'deals-mobile','.w-blog-widget-related-posts .post_content a','display','block','','','.w-blog-widget-related-posts'),(166563,'deals-mobile','.w-blog-widget-related-posts-by-category .post_content a','display','block','','','.w-blog-widget-related-posts-by-category'),(166564,'deals-mobile','.w-blog-widget-related-posts-by-category .post_img img','display','inline-block','','','.w-blog-widget-related-posts-by-category'),(166565,'deals-mobile','.w-blog-widget-tag-cloud a','display','inline-block','','','.w-blog-widget-tag-cloud'),(166566,'deals-mobile','.w-cart-bonus-points .btn-remove','display','inline-block','','','.w-cart-bonus-points'),(166567,'deals-mobile','.w-cart-compare .product-actions .dropdown-toggle','display','none','4','','.w-cart-compare'),(166568,'deals-mobile','.w-cart-compare .js-cart_totals_container b','display','block','','','.w-cart-compare'),(166569,'deals-mobile','.w-cart-compare .product','display','block','4','','.w-cart-compare'),(166570,'deals-mobile','.w-cart-compare .delete-cart','display','inline-block','','','.w-cart-compare'),(166571,'deals-mobile','.w-cart-credit-amount .btn-remove','display','inline-block','','','.w-cart-credit-amount'),(166572,'deals-mobile','.w-cart-up-sell h3','display','none','','','.w-cart-up-sell'),(166573,'deals-mobile','.w-catalog-additional-images li','display','inline-block','','','.w-catalog-additional-images'),(166574,'deals-mobile','.w-catalog-b2b-add-button ','display','none','','','.w-catalog-b2b-add-button'),(166575,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','display','inline-block','3','','.w-catalog-compare'),(166576,'deals-mobile','.w-catalog-compare td span','display','inline','','','.w-catalog-compare'),(166577,'deals-mobile','.w-catalog-compare .product-listing','display','flex','','','.w-catalog-compare'),(166578,'deals-mobile','.w-catalog-compare .promos-info','display','none','','','.w-catalog-compare'),(166579,'deals-mobile','.w-catalog-compare .item .compare a','display','none','','','.w-catalog-compare'),(166580,'deals-mobile','.w-catalog-compare .cross-box .different-all','display','flex','','','.w-catalog-compare'),(166581,'deals-mobile','.w-catalog-compare .cross-box','display','flex','','','.w-catalog-compare'),(166582,'deals-mobile','.w-catalog-items-on-page .items-on-page','display','flex','','','.w-catalog-items-on-page'),(166583,'deals-mobile','.w-catalog-paging .page-number','display','inline-block','','','.w-catalog-paging'),(166584,'deals-mobile','.w-catalog-paging .next','display','inline-block','','','.w-catalog-paging'),(166585,'deals-mobile','.w-catalog-paging .paging-item','display','inline-block','','','.w-catalog-paging'),(166586,'deals-mobile','.w-catalog-paging ','display','inline-block','2','','.w-catalog-paging'),(166587,'deals-mobile','.w-catalog-paging .paging-holder','display','inline-block','','','.w-catalog-paging'),(166588,'deals-mobile','.w-catalog-paging .prev','display','inline-block','','','.w-catalog-paging'),(166589,'deals-mobile','.w-catalog-paging .next-pages','display','inline-block','','','.w-catalog-paging'),(166590,'deals-mobile','.w-catalog-paging .prev-pages','display','inline-block','','','.w-catalog-paging'),(166591,'deals-mobile','.w-catalog-paging .paging','display','inline-block','','','.w-catalog-paging'),(166592,'deals-mobile','.w-checkout-billing-address .genders-title label','display','inline-block','','','.w-checkout-billing-address'),(166593,'deals-mobile','.w-checkout-billing-address .genders-title > div','display','inline-block','','','.w-checkout-billing-address'),(166594,'deals-mobile','.w-checkout-billing-address .addresses','display','block','4','','.w-checkout-billing-address'),(166595,'deals-mobile','.w-checkout-billing-address .edit-ab','display','inline-block','','','.w-checkout-billing-address'),(166596,'deals-mobile','.w-checkout-billing-address .addresses .address-item label','display','block','','','.w-checkout-billing-address'),(166597,'deals-mobile','.w-checkout-bonus-points .btn-remove','display','inline-block','','','.w-checkout-bonus-points'),(166598,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','display','inline-block','3','','.w-checkout-contact-information'),(166599,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','display','inline-block','3','','.w-checkout-contact-information'),(166600,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','display','inline-block','3','','.w-checkout-contact-information'),(166601,'deals-mobile','.w-checkout-create-account .columns .col-2:nth-child(2n)','display','none','','','.w-checkout-create-account'),(166602,'deals-mobile','.w-checkout-credit-amount .btn-remove','display','inline-block','','','.w-checkout-credit-amount'),(166603,'deals-mobile','.w-checkout-shipping .sub-item','display','block','','','.w-checkout-shipping'),(166604,'deals-mobile','.w-checkout-shipping-address .edit-ab','display','inline-block','','','.w-checkout-shipping-address'),(166605,'deals-mobile','.w-checkout-shipping-address .addresses .address-item label','display','block','','','.w-checkout-shipping-address'),(166606,'deals-mobile','.w-checkout-shipping-address .change-ab','display','inline-block','','','.w-checkout-shipping-address'),(166607,'deals-mobile','.w-checkout-shipping-address .genders-title > div','display','inline-block','','','.w-checkout-shipping-address'),(166608,'deals-mobile','.w-checkout-shipping-address .addresses','display','block','4','','.w-checkout-shipping-address'),(166609,'deals-mobile','.w-checkout-shipping-address .genders-title label','display','inline-block','','','.w-checkout-shipping-address'),(166610,'deals-mobile','.w-checkout-shipping-choice #shippingchoice-choice','display','flex','','','.w-checkout-shipping-choice'),(166611,'deals-mobile','.w-checkout-shipping-choice span','display','flex','','','.w-checkout-shipping-choice'),(166612,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','display','block','','','.w-checkout-shipping-choice'),(166613,'deals-mobile','.w-checkout-shipping-choice input','display','none','','','.w-checkout-shipping-choice'),(166614,'deals-mobile','.w-checkout-terms .required-message-wrap','display','inline-block','','','.w-checkout-terms'),(166615,'deals-mobile','.w-communication-new-topic #communication_group_holder + .columns','display','flex','','','.w-communication-new-topic'),(166616,'deals-mobile','.w-communication-new-topic .middle-form .col-2 label > span','display','block','','','.w-communication-new-topic'),(166617,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','display','inline-block','','','.w-communication-new-topic'),(166618,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','','','.w-communication-new-topic'),(166619,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','3','','.w-communication-new-topic'),(166620,'deals-mobile','.w-communication-post .communication-post-author','display','flex','','','.w-communication-post'),(166621,'deals-mobile','.w-coupons-and-vauchers-checkout .btn-remove','display','inline-block','','','.w-coupons-and-vauchers-checkout'),(166622,'deals-mobile','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(166623,'deals-mobile','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(166624,'deals-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','display','block','','','.w-delivery-day'),(166625,'deals-mobile','.w-delivery-day .time-left','display','flex','','','.w-delivery-day'),(166626,'deals-mobile','.w-delivery-day .left-count','display','block','','','.w-delivery-day'),(166627,'deals-mobile','.w-delivery-day .left-text-left','display','block','','','.w-delivery-day'),(166628,'deals-mobile','.w-delivery-day .left-text-right','display','block','','','.w-delivery-day'),(166629,'deals-mobile','.w-image-maps .categories-items .item .description','display','block','','','.w-image-maps'),(166630,'deals-mobile','.w-image-maps .categories-items .item .title','display','block','','','.w-image-maps'),(166631,'deals-mobile','.w-image-maps .default-links .item','display','block','1','','.w-image-maps'),(166632,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','display','none','','','.w-image-maps'),(166633,'deals-mobile','.w-image-maps .float-items .item .description','display','block','','','.w-image-maps'),(166634,'deals-mobile','.w-image-maps .float-items .item .title','display','block','','','.w-image-maps'),(166635,'deals-mobile','.w-image-maps .products-items .item-holder','display','block','1','','.w-image-maps'),(166636,'deals-mobile','.w-image-maps .svg-wrap','display','inline-block','','','.w-image-maps'),(166637,'deals-mobile','.w-image-maps .categories-items .item','display','block','1','','.w-image-maps'),(166638,'deals-mobile','.w-image-maps .float-items .item','display','block','1','','.w-image-maps'),(166639,'deals-mobile','.w-image-maps .default-links .item .title','display','block','','','.w-image-maps'),(166640,'deals-mobile','.w-image-maps .default-links .item .description','display','block','','','.w-image-maps'),(166641,'deals-mobile','.w-list-b2b .attributes','display','block','4','','.w-list-b2b'),(166642,'deals-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','display','inline-block','','','.w-multi-cart-actions'),(166643,'deals-mobile','.w-multi-cart-actions .cart-actions','display','inline-block','','','.w-multi-cart-actions'),(166644,'deals-mobile','.w-neighbour-checkout .text','display','inline-block','','','.w-neighbour-checkout'),(166645,'deals-mobile','.w-personal-gift-status-bar .timeline','display','flex','','','.w-personal-gift-status-bar'),(166646,'deals-mobile','.w-personal-gift-status-bar .inform','display','inline-block','4','','.w-personal-gift-status-bar'),(166647,'deals-mobile','.w-personal-gift-status-bar .end-date','display','inline-block','3','','.w-personal-gift-status-bar'),(166648,'deals-mobile','.w-product-available-in-warehouses .content','display','block','4','','.w-product-available-in-warehouses'),(166649,'deals-mobile','.w-product-available-in-warehouses .warehouse-item','display','inline-block','','','.w-product-available-in-warehouses'),(166650,'deals-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(166651,'deals-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(166652,'deals-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(166653,'deals-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(166654,'deals-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(166655,'deals-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(166656,'deals-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(166657,'deals-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(166658,'deals-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(166659,'deals-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(166660,'deals-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(166661,'deals-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(166662,'deals-mobile','.w-promotions .prom-multi-discount .products','display','grid','','','.w-promotions'),(166663,'deals-mobile','.w-promotions .prom-multi-discount .list','display','grid','','','.w-promotions'),(166664,'deals-mobile','.w-promotions .nextdiscount .item-holder','display','flex','','','.w-promotions'),(166665,'deals-mobile','.w-promotions .nextdiscount .promo-for-each','display','inline-block','','','.w-promotions'),(166666,'deals-mobile','.w-promotions .promo-cart-discount .item a','display','block','','','.w-promotions'),(166667,'deals-mobile','.w-promotions .promo-cart-discount .content','display','flex','','','.w-promotions'),(166668,'deals-mobile','.w-promotions .promo-cart-discount .slave','display','flex','','','.w-promotions'),(166669,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','display','inline-block','','','.w-promotions'),(166670,'deals-mobile','.w-promotions .promo-cart-discount','display','flex','','','.w-promotions'),(166671,'deals-mobile','.w-promotions .promo-content > .personalgift','display','none','','','.w-promotions'),(166672,'deals-mobile','.w-promotions .promo-date > div','display','inline-block','','','.w-promotions'),(166673,'deals-mobile','.w-promotions .promo-salemaker .discount','display','inline-block','','','.w-promotions'),(166674,'deals-mobile','.w-promotions .promo-salemaker .content','display','flex','','','.w-promotions'),(166675,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','display','inline-block','','','.w-promotions'),(166676,'deals-mobile','.w-promotions .promo-salemaker','display','flex','','','.w-promotions'),(166677,'deals-mobile','.w-promotions .prom-multi-discount .promo-range > div','display','inline-block','','','.w-promotions'),(166678,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','display','inline-block','','','.w-promotions'),(166679,'deals-mobile','.w-promotions .icon','display','inline-block','','','.w-promotions'),(166680,'deals-mobile','.w-promotions .promo-salemaker .content a.name','display','block','','','.w-promotions'),(166681,'deals-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','display','block','','','.w-promotions'),(166682,'deals-mobile','.w-promotions .heading-3','display','inline-block','','','.w-promotions'),(166683,'deals-mobile','.w-promotions .prom-multi-discount','display','block','4','','.w-promotions'),(166684,'deals-mobile','.w-promotions .nextdiscount .content','display','grid','','','.w-promotions'),(166685,'deals-mobile','.w-reviews-content .item','display','grid','','','.w-reviews-content'),(166686,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul','display','flex','','','.w-sitemap-delivery-location'),(166687,'deals-mobile','.w-social-links .name, .w-social-links .image','display','none','','','.w-social-links'),(166688,'deals-mobile','.w-taxable select','display','inline-block','','','.w-taxable'),(166689,'deals-mobile','.w-taxable form','display','flex','','','.w-taxable'),(166690,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','display','flex','','','.w-upload-customer-id-upload-customer-id-form'),(166691,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details ~ div','display','none','','','.w-upload-customer-id-upload-customer-id-form'),(166692,'deals-mobile','.w-wedding-registry-widgets-photos .upload-file-wrap','display','flex','','','.w-wedding-registry-widgets-photos'),(166693,'deals-mobile','.w-wedding-registry-widgets-search-registry-button a','display','inline-block','3','','.w-wedding-registry-widgets-search-registry-button'),(166694,'deals-mobile','.w-wedding-registry-widgets-share-link a','display','inline-block','3','','.w-wedding-registry-widgets-share-link'),(166695,'deals-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(166696,'deals-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(166697,'deals-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(166698,'deals-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(166699,'deals-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(166700,'deals-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(166701,'deals-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(166702,'deals-mobile','.p-catalog-product .pn-image','display','inline-block','3','','.p-catalog-product'),(166703,'deals-mobile','.w-filters .filter-box-content ul li.view_items','display_important','important','','','.w-filters'),(166704,'deals-mobile','.w-menu-mobile .menu-ico','display_important','important','','','.w-menu-mobile'),(166705,'deals-mobile','.w-cart .cart-box.hover-box:hover .cart-content','display_important','important','','','.w-cart'),(166706,'deals-mobile','.w-menu-horizontal ul ul li','display_important','important','','','.w-menu-horizontal'),(166707,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display_important','important','','','.b-switch'),(166708,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display_important','important','','','.b-switch'),(166709,'deals-mobile','.w-menu-style-1 ul ul li','display_important','important','','','.w-menu-style-1'),(166710,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display_important','important','','','.b-menu-open_from-left'),(166711,'deals-mobile','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display_important','important','','','.b-menu-style'),(166712,'deals-mobile','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display_important','important','','','.b-menu-style'),(166713,'deals-mobile','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display_important','important','','','.b-menu-style'),(166714,'deals-mobile','.p-catalog-product .pn-price','display_important','important','','','.p-catalog-product'),(166715,'deals-mobile','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','fill','rgba(255, 255, 255, 0)','','','.w-image-maps'),(166716,'deals-mobile','.w-image-maps rect.no-items, .w-image-maps circle.no-items, .w-image-maps polygon.no-items','fill','rgba(150, 150, 150, 0.7)','','','.w-image-maps'),(166717,'deals-mobile','.w-image-maps polygon:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(166718,'deals-mobile','.w-image-maps rect:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(166719,'deals-mobile','.w-image-maps circle:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(166720,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','filter','alpha(opacity=50)','','','.b-switch'),(166721,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','filter','alpha(opacity=50)','','','.b-switch'),(166722,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','filter','alpha(opacity=50)','','','.b-switch'),(166723,'deals-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','filter','alpha(opacity=0)','','','.b-switch'),(166724,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','filter','progid','','','.b-select-suggest'),(166725,'deals-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','filter','none','','','.b-select-suggest'),(166726,'deals-mobile','.b-select-suggest .select2-dropdown-open .select2-choice','filter','progid','','','.b-select-suggest'),(166727,'deals-mobile','.b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choice, .b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choices','filter','progid','','','.b-select-suggest'),(166728,'deals-mobile','.b-select-suggest .select2-drop-mask','filter','alpha(opacity=0)','','','.b-select-suggest'),(166729,'deals-mobile','.b-select-suggest .select2-container.select2-drop-above .select2-choice','filter','progid','','','.b-select-suggest'),(166730,'deals-mobile','.b-select-suggest .select2-container .select2-choice','filter','progid','','','.b-select-suggest'),(166731,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','filter','progid','','','.b-select-suggest'),(166732,'deals-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-basis','0','','','.b-menu-position'),(166733,'deals-mobile','.w-account-address-book .wrap','flex-direction','column','','','.w-account-address-book'),(166734,'deals-mobile','.w-account-address-book .add_item a','flex-direction','column','','','.w-account-address-book'),(166735,'deals-mobile','.w-catalog-compare .cross-box','flex-direction','column','','','.w-catalog-compare'),(166736,'deals-mobile','.w-promotions .promo-cart-discount .slave','flex-direction','column','','','.w-promotions'),(166737,'deals-mobile','.p-wedding-registry-search .search-form > div','flex-grow','2','','','.p-wedding-registry-search'),(166738,'deals-mobile','.p-wedding-registry-search #searchform-status label','flex-grow','1','','','.p-wedding-registry-search'),(166739,'deals-mobile','.p-wedding-registry-search .button','flex-grow','1','','','.p-wedding-registry-search'),(166740,'deals-mobile','.b-products-listing .products-listing .attribute-qty-block > span','flex-grow','1','','','.b-products-listing'),(166741,'deals-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-grow','1','','','.b-menu-position'),(166742,'deals-mobile','.b-messages .email-line > div','flex-grow','1','','','.b-messages'),(166743,'deals-mobile','.w-account-customer-additional-field .field-type-text label','flex-grow','1','','','.w-account-customer-additional-field'),(166744,'deals-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-grow','1','','','.w-account-customer-additional-field'),(166745,'deals-mobile','.w-account-personal-catalog .list-switcher a','flex-grow','1','','','.w-account-personal-catalog'),(166746,'deals-mobile','.w-account-subscription .title','flex-grow','1','','','.w-account-subscription'),(166747,'deals-mobile','.w-catalog-compare .product-listing > div','flex-grow','1','','','.w-catalog-compare'),(166748,'deals-mobile','.w-delivery-day .time-left > span','flex-grow','1','','','.w-delivery-day'),(166749,'deals-mobile','.w-promotions .prom-multi-discount .promo-product, .w-promotions .prom-multi-discount .promo-category-item','flex-grow','1','','','.w-promotions'),(166750,'deals-mobile','.b-products-listing .select-attributes .item-title','flex-shrink','0','','','.b-products-listing'),(166751,'deals-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-shrink','1','','','.b-menu-position'),(166752,'deals-mobile','.w-account-customer-additional-field .field-type-text label','flex-shrink','0','','','.w-account-customer-additional-field'),(166753,'deals-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-shrink','0','','','.w-account-customer-additional-field'),(166754,'deals-mobile','.w-catalog-compare .cross-box','flex-shrink','0','','','.w-catalog-compare'),(166755,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','flex-shrink','0','','','.w-upload-customer-id-upload-customer-id-form'),(166756,'deals-mobile','.w-categories .categories','flex-wrap','wrap','','','.w-categories'),(166757,'deals-mobile','.personal-buttons > div','flex-wrap','wrap','','','.personal-buttons'),(166758,'deals-mobile','.w-top-categories .categories','flex-wrap','wrap','','','.w-top-categories'),(166759,'deals-mobile','.b-products-listing .products-listing .attribute-qty-blocks','flex-wrap','wrap','','','.b-products-listing'),(166760,'deals-mobile','.w-account-address-book .address-book','flex-wrap','wrap','','','.w-account-address-book'),(166761,'deals-mobile','.w-communication-new-topic #communication_group_holder + .columns','flex-wrap','wrap','','','.w-communication-new-topic'),(166762,'deals-mobile','.w-promotions .promo-cart-discount .content','flex-wrap','wrap','','','.w-promotions'),(166763,'deals-mobile','.w-promotions .promo-salemaker .content','flex-wrap','wrap','','','.w-promotions'),(166764,'deals-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','float','right','3','','.w-menu'),(166765,'deals-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','float','none','','','.w-menu'),(166766,'deals-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','float','right','3','','.w-menu'),(166767,'deals-mobile','.w-menu .hided.menu ul li','float','none','','','.w-menu'),(166768,'deals-mobile','.w-menu-horizontal .box','float','none','','','.w-menu-horizontal'),(166769,'deals-mobile','.w-menu-big li','float','none','','','.w-menu-big'),(166770,'deals-mobile','.w-menu-style-1 .box','float','none','','','.w-menu-style-1'),(166771,'deals-mobile','.b-slick [dir=\'rtl\'] .slick-slide','float','right','','','.b-slick'),(166772,'deals-mobile','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(166773,'deals-mobile','.w-login-block .returning','float','left','','','.w-login-block'),(166774,'deals-mobile','.w-login-block .new','float','right','','','.w-login-block'),(166775,'deals-mobile','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(166776,'deals-mobile','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(166777,'deals-mobile','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(166778,'deals-mobile','.w-login-block .guest','float','right','','','.w-login-block'),(166779,'deals-mobile','.w-sale .holder-1','float','right','','','.w-sale'),(166780,'deals-mobile','.w-sale .image','float','left','','','.w-sale'),(166781,'deals-mobile','.w-sale .holder-2','float','left','','','.w-sale'),(166782,'deals-mobile','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(166783,'deals-mobile','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(166784,'deals-mobile','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(166785,'deals-mobile','.w-product-sale-ends .left-count','float','left','','','.w-product-sale-ends'),(166786,'deals-mobile','.w-product-sale-ends .left-text-right','float','left','','','.w-product-sale-ends'),(166787,'deals-mobile','.w-product-collection .current-product','float','left','','','.w-product-collection'),(166788,'deals-mobile','.w-product-collection .right-area','float','left','','','.w-product-collection'),(166789,'deals-mobile','.w-product-sale-ends .left-text-left','float','left','','','.w-product-sale-ends'),(166790,'deals-mobile','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(166791,'deals-mobile','.w-cart .image','float','left','','','.w-cart'),(166792,'deals-mobile','.w-cart .cart-box','float','right','','','.w-cart'),(166793,'deals-mobile','.w-compare-box-item .cb_title','float','left','','','.w-compare-box-item'),(166794,'deals-mobile','.w-compare-box-item .cb_check','float','right','','','.w-compare-box-item'),(166795,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','float','right','','','.b-multi-page-checkout'),(166796,'deals-mobile','.b-pagination .pagination .left-area','float','left','','','.b-pagination'),(166797,'deals-mobile','.b-pagination .pagination .right-area','float','right','','','.b-pagination'),(166798,'deals-mobile','.w-product-quantity .product-quantity-label','float','left','','','.w-product-quantity'),(166799,'deals-mobile','.w-product-in-bundles .bundle_item','float','left','','','.w-product-in-bundles'),(166800,'deals-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','float','left','','','.p-account-address-book'),(166801,'deals-mobile','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(166802,'deals-mobile','.w-product-bundle .bundle_item','float','left','','','.w-product-bundle'),(166803,'deals-mobile','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(166804,'deals-mobile','.p-account-address-book .topInfo > div','float','none','863','','.p-account-address-book'),(166805,'deals-mobile','.p-account-address-book .address_book_row .column + .column','float','none','863','','.p-account-address-book'),(166806,'deals-mobile','.p-blog-index .wp-widget li','float','left','3','','.p-blog-index'),(166807,'deals-mobile','.p-account-address-book .address_book_row .column','float','none','863','','.p-account-address-book'),(166808,'deals-mobile','.p-account-address-book .topInfo > div + div','float','none','863','','.p-account-address-book'),(166809,'deals-mobile','.p-blog-index .post-thumbnail','float','left','','','.p-blog-index'),(166810,'deals-mobile','.w-list-type-1_2 .right-area .right-area-2','float','left','','','.w-list-type-1_2'),(166811,'deals-mobile','.w-list-type-1_2 .right-area .name','float','left','','','.w-list-type-1_2'),(166812,'deals-mobile','.w-list-type-1_2 .right-area','float','right','864','','.w-list-type-1_2'),(166813,'deals-mobile','.w-list-type-1_2 .right-area .name','float','none','864','','.w-list-type-1_2'),(166814,'deals-mobile','.w-list-type-1_2 .right-area .right-area-2','float','none','864','','.w-list-type-1_2'),(166815,'deals-mobile','.w-list-type-1_2 .image','float','none','864','','.w-list-type-1_2'),(166816,'deals-mobile','.w-list-type-2 .button-wishlist','float','right','','','.w-list-type-2'),(166817,'deals-mobile','.b-info-popup .password-info .info-popup','float','right','','','.b-info-popup'),(166818,'deals-mobile','.w-promo-code .btn','float','right','','','.w-promo-code'),(166819,'deals-mobile','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(166820,'deals-mobile','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(166821,'deals-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','float','right','','','.p-wedding-registry-manage'),(166822,'deals-mobile','.w-product-bonus-points > div > div','float','left','','','.w-product-bonus-points'),(166823,'deals-mobile','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(166824,'deals-mobile','.p-account-order-pay .history_info > div','float','left','','','.p-account-order-pay'),(166825,'deals-mobile','.p-account-order-pay .historyTotal table','float','right','','','.p-account-order-pay'),(166826,'deals-mobile','.w-product-configurator .item-content > div','float','left','863','','.w-product-configurator'),(166827,'deals-mobile','.p-wedding-registry-manage .qty-input','float','left','','','.p-wedding-registry-manage'),(166828,'deals-mobile','.p-wedding-registry-manage a.remove-btn','float','right','','','.p-wedding-registry-manage'),(166829,'deals-mobile','.p-blog-index .nav-previous','float','left','','','.p-blog-index'),(166830,'deals-mobile','.p-blog-index .w-blog-sidebar .wp-widget','float','left','890','','.p-blog-index'),(166831,'deals-mobile','.p-blog-index .nav-previous a','float','left','3','','.p-blog-index'),(166832,'deals-mobile','.p-blog-index .nav-next a','float','right','3','','.p-blog-index'),(166833,'deals-mobile','.p-blog-index .nav-next','float','right','','','.p-blog-index'),(166834,'deals-mobile','.p-blog-index .comment-metadata','float','right','','','.p-blog-index'),(166835,'deals-mobile','.p-blog-index .comment-author','float','left','','','.p-blog-index'),(166836,'deals-mobile','.w-list-type-1_3 .right-area .right-area-2','float','left','','','.w-list-type-1_3'),(166837,'deals-mobile','.w-list-type-2_2 .rating-count','float','right','','','.w-list-type-2_2'),(166838,'deals-mobile','.w-list-type-2_2 .price','float','left','','','.w-list-type-2_2'),(166839,'deals-mobile','.w-list-type-2_2 .rating','float','right','','','.w-list-type-2_2'),(166840,'deals-mobile','.w-list-type-2_2 .qty-input','float','left','','','.w-list-type-2_2'),(166841,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','float','right','','','.w-list-type-2_2'),(166842,'deals-mobile','.w-list-type-2_2 .button-wishlist button','float','right','4','','.w-list-type-2_2'),(166843,'deals-mobile','.w-list-type-2_2 .image','float','left','','','.w-list-type-2_2'),(166844,'deals-mobile','.buttons .left-buttons','float','left','','',''),(166845,'deals-mobile','.w-list-type-2_2 .button-view a','float','right','4','','.w-list-type-2_2'),(166846,'deals-mobile','.w-list-type-2_2 .button-wishlist','float','right','','','.w-list-type-2_2'),(166847,'deals-mobile','.buttons .right-buttons','float','right','','',''),(166848,'deals-mobile','.w-list-type-2 .price','float','left','','','.w-list-type-2'),(166849,'deals-mobile','.w-list-type-2 .rating-count','float','right','','','.w-list-type-2'),(166850,'deals-mobile','.w-brands .brands-listing > div','float','left','','','.w-brands'),(166851,'deals-mobile','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(166852,'deals-mobile','.b-compare .compare-box-btn','float','right','','','.b-compare'),(166853,'deals-mobile','.b-compare .col-two label, .b-compare .col-two select','float','left','','','.b-compare'),(166854,'deals-mobile','.heading-4 .right-text, h4 .right-text','float','right','','',''),(166855,'deals-mobile','.w-socials > li','float','left','','','.w-socials'),(166856,'deals-mobile','.b-product-images .additional-images, .b-product-images .additional-videos','float','right','','','.b-product-images'),(166857,'deals-mobile','.w-socials .post_item_img','float','left','','','.w-socials'),(166858,'deals-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(166859,'deals-mobile','.w-list-type-1 .button-view a','float','right','4','','.w-list-type-1'),(166860,'deals-mobile','.w-list-type-1 .button-wishlist','float','right','','','.w-list-type-1'),(166861,'deals-mobile','.w-filters .handle-to','float','right','','','.w-filters'),(166862,'deals-mobile','.w-filters .handle-from','float','left','','','.w-filters'),(166863,'deals-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(166864,'deals-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(166865,'deals-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(166866,'deals-mobile','.w-menu-style-1 li','float','none','','','.w-menu-style-1'),(166867,'deals-mobile','.p-reviews-info .review-info-image','float','left','','','.p-reviews-info'),(166868,'deals-mobile','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(166869,'deals-mobile','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(166870,'deals-mobile','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(166871,'deals-mobile','.w-list-type-1_3 .rating','float','right','','','.w-list-type-1_3'),(166872,'deals-mobile','.w-list-type-1_3 .rating-count','float','right','','','.w-list-type-1_3'),(166873,'deals-mobile','.w-list-type-1_3 .qty-input','float','left','','','.w-list-type-1_3'),(166874,'deals-mobile','.w-sale .left-text-left','float','left','','','.w-sale'),(166875,'deals-mobile','.w-sale .left-text-right','float','left','','','.w-sale'),(166876,'deals-mobile','.w-sale .left-count','float','left','','','.w-sale'),(166877,'deals-mobile','.b-form .terms-login .bootstrap-switch','float','right','','','.b-form'),(166878,'deals-mobile','.b-slick .slick-slide','float','left','','','.b-slick'),(166879,'deals-mobile','.b-quantity .qty-input label','float','left','','','.b-quantity'),(166880,'deals-mobile','.p-account-index .account_info li','float','none','863','','.p-account-index'),(166881,'deals-mobile','.w-list-type-1_3 .right-area .right-area-2','float','none','864','','.w-list-type-1_3'),(166882,'deals-mobile','.w-list-type-1_3 .right-area .name','float','none','864','','.w-list-type-1_3'),(166883,'deals-mobile','.w-list-type-1_3 .right-area','float','right','864','','.w-list-type-1_3'),(166884,'deals-mobile','.w-menu-horizontal li','float','none','','','.w-menu-horizontal'),(166885,'deals-mobile','.w-cart-order-total.box','float','right','','','.w-cart-order-total'),(166886,'deals-mobile','.w-cart-discount-coupon .gift-code button','float','right','','','.w-cart-discount-coupon'),(166887,'deals-mobile','.p-account-index .topAccount > li','float','none','863','','.p-account-index'),(166888,'deals-mobile','.p-account-index .ai_title, .p-account-index .ai_value','float','left','','','.p-account-index'),(166889,'deals-mobile','.b-form .discount-box button','float','right','','','.b-form'),(166890,'deals-mobile','.p-account-index .account_info li','float','left','','','.p-account-index'),(166891,'deals-mobile','.b-form .col-right','float','right','','','.b-form'),(166892,'deals-mobile','.p-account-history-info .history_info > div','float','left','','','.p-account-history-info'),(166893,'deals-mobile','.b-form .columns .col-2','float','left','','','.b-form'),(166894,'deals-mobile','.p-account-index .topAccount > li','float','left','','','.p-account-index'),(166895,'deals-mobile','.w-cart-gift-certificate .gift-code button','float','right','','','.w-cart-gift-certificate'),(166896,'deals-mobile','.w-cart-give-away .ga_attributes > div','float','left','','','.w-cart-give-away'),(166897,'deals-mobile','.w-cart-give-away .ga_column','float','left','','','.w-cart-give-away'),(166898,'deals-mobile','.w-cart-give-away .ga_price .checkBoxWrap','float','right','','','.w-cart-give-away'),(166899,'deals-mobile','.w-cart-give-away .ga_img','float','left','','','.w-cart-give-away'),(166900,'deals-mobile','.w-list-type-1_3 .right-area','float','right','','','.w-list-type-1_3'),(166901,'deals-mobile','.b-form .addresses .address-item input[type=\"radio\"]','float','left','','','.b-form'),(166902,'deals-mobile','.w-list-type-1_3 .right-area .name','float','left','','','.w-list-type-1_3'),(166903,'deals-mobile','.w-list-type-1_3 .image','float','none','864','','.w-list-type-1_3'),(166904,'deals-mobile','.w-list-type-2 .button-wishlist button','float','right','4','','.w-list-type-2'),(166905,'deals-mobile','.w-list-type-2 .button-view a','float','right','4','','.w-list-type-2'),(166906,'deals-mobile','.w-list-type-2 .rating','float','right','','','.w-list-type-2'),(166907,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','float','right','','','.w-list-type-2'),(166908,'deals-mobile','.w-list-type-2 .qty-input','float','left','','','.w-list-type-2'),(166909,'deals-mobile','.w-list-type-1_3 .price','float','left','','','.w-list-type-1_3'),(166910,'deals-mobile','.w-list-type-1_3 .image','float','left','','','.w-list-type-1_3'),(166911,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','float','right','','','.w-list-type-1_3'),(166912,'deals-mobile','.heading-3 .right-text, h3 .right-text','float','right','','',''),(166913,'deals-mobile','.w-list-type-1_3 .button-wishlist button','float','right','4','','.w-list-type-1_3'),(166914,'deals-mobile','.w-list-type-1_3 .button-view a','float','right','4','','.w-list-type-1_3'),(166915,'deals-mobile','.w-list-type-1_3 .button-wishlist','float','right','','','.w-list-type-1_3'),(166916,'deals-mobile','.w-list-type-1_3 .attributes > .attributes > div','float','left','','','.w-list-type-1_3'),(166917,'deals-mobile','.w-list-type-1_2 .right-area','float','right','','','.w-list-type-1_2'),(166918,'deals-mobile','.w-list-type-1_2 .rating','float','right','','','.w-list-type-1_2'),(166919,'deals-mobile','.w-list-type-1_2 .rating-count','float','right','','','.w-list-type-1_2'),(166920,'deals-mobile','.w-list-type-1_2 .qty-input','float','left','','','.w-list-type-1_2'),(166921,'deals-mobile','.w-list-type-1_2 .price','float','left','','','.w-list-type-1_2'),(166922,'deals-mobile','.w-list-type-1_2 .image','float','left','','','.w-list-type-1_2'),(166923,'deals-mobile','.w-list-type-1_2 .button-wishlist button','float','right','4','','.w-list-type-1_2'),(166924,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','float','right','','','.w-list-type-1_2'),(166925,'deals-mobile','.w-list-type-1_2 .button-view a','float','right','4','','.w-list-type-1_2'),(166926,'deals-mobile','.w-list-type-1_2 .button-view','float','left','','','.w-list-type-1_2'),(166927,'deals-mobile','.w-list-type-1_2 .button-wishlist','float','right','','','.w-list-type-1_2'),(166928,'deals-mobile','.w-list-type-1 .rating-count','float','right','','','.w-list-type-1'),(166929,'deals-mobile','.w-list-type-1 .rating','float','right','','','.w-list-type-1'),(166930,'deals-mobile','.w-list-type-1 .qty-input','float','left','','','.w-list-type-1'),(166931,'deals-mobile','.w-list-type-1 .price','float','left','','','.w-list-type-1'),(166932,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','float','right','','','.w-list-type-1'),(166933,'deals-mobile','.heading-3 .edit, h3 .edit','float','right','','',''),(166934,'deals-mobile','.w-list-type-1 .button-wishlist button','float','right','4','','.w-list-type-1'),(166935,'deals-mobile','.heading-4 .edit, h4 .edit','float','right','','',''),(166936,'deals-mobile','.b-form .col-left','float','left','','','.b-form'),(166937,'deals-mobile','.b-form .addresses .address-item','float','left','','','.b-form'),(166938,'deals-mobile','.w-search .image','float','left','','','.w-search'),(166939,'deals-mobile','.p-account-history-info .historyTotal table','float','right','','','.p-account-history-info'),(166940,'deals-mobile','.b-form .payment-method .item-radio input','float','left','','','.b-form'),(166941,'deals-mobile','.b-form .shipping-method .input','float','right','','','.b-form'),(166942,'deals-mobile','.b-form .shipping-method .cost','float','right','','','.b-form'),(166943,'deals-mobile','.p-account-address-book .address_book h2 strong','float','left','','','.p-account-address-book'),(166944,'deals-mobile','.p-account-address-book .button2','float','left','','','.p-account-address-book'),(166945,'deals-mobile','.p-account-address-book .button1','float','right','','','.p-account-address-book'),(166946,'deals-mobile','.b-info .info','float','left','3','','.b-info'),(166947,'deals-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','float','right','','','.b-products-listing'),(166948,'deals-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','float','right','','','.b-products-listing'),(166949,'deals-mobile','.b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockBox.type-14 > .col, .b-products-listing .BlockBox.type-15 > .col, .b-products-listing .BlockBox.type-16 > .col','float','left','','','.b-products-listing'),(166950,'deals-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','float','right','','','.b-products-listing'),(166951,'deals-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','float','right','','','.b-products-listing'),(166952,'deals-mobile','.b-products-listing .BlockBox.type-2 > .col, .b-products-listing .BlockBox.type-3 > .col, .b-products-listing .BlockBox.type-4 > .col, .b-products-listing .BlockBox.type-5 > .col, .b-products-listing .BlockBox.type-6 > .col','float','left','','','.b-products-listing'),(166953,'deals-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','float','right','','','.b-products-listing'),(166954,'deals-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','float','right','','','.b-products-listing'),(166955,'deals-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','float','right','','','.b-products-listing'),(166956,'deals-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','float','right','','','.b-products-listing'),(166957,'deals-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','float','right','','','.b-products-listing'),(166958,'deals-mobile','.b-products-listing .BlockBox.type-7 > .col, .b-products-listing .BlockBox.type-8 > .col, .b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col','float','left','','','.b-products-listing'),(166959,'deals-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','float','right','','','.b-products-listing'),(166960,'deals-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','float','right','','','.b-products-listing'),(166961,'deals-mobile','.b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col, .b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockB','float','left','','','.b-products-listing'),(166962,'deals-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','float','right','','','.b-products-listing'),(166963,'deals-mobile','.b-products-listing .products-listing .attribute-qty-block > span','float','left','','','.b-products-listing'),(166964,'deals-mobile','.b-products-listing .products-listing .bonus-points-cost','float','left','3','','.b-products-listing'),(166965,'deals-mobile','.b-products-listing .products-listing .bonus-points-price','float','left','3','','.b-products-listing'),(166966,'deals-mobile','.b-products-listing .products-listing .compare input + span','float','right','','','.b-products-listing'),(166967,'deals-mobile','.b-products-listing .products-listing .item','float','none','','','.b-products-listing'),(166968,'deals-mobile','.b-products-listing .products-listing .mult-qty-input','float','right','','','.b-products-listing'),(166969,'deals-mobile','.b-products-listing .products-listing .radio-attributes .item-title','float','left','','','.b-products-listing'),(166970,'deals-mobile','.b-products-listing .products-listing a.btn.view-button','float','right','3','','.b-products-listing'),(166971,'deals-mobile','.b-products-listing .products-listing.align-left .item','float','left','','','.b-products-listing'),(166972,'deals-mobile','.b-products-listing .products-listing.align-right .item','float','right','','','.b-products-listing'),(166973,'deals-mobile','.b-products-listing .wedding-registry-count','float','right','','','.b-products-listing'),(166974,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(166975,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(166976,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(166977,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(166978,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(166979,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > .no-link','float','right','3','','.b-menu-style-3'),(166980,'deals-mobile','.b-messages .msv_btn .btn','float','right','','','.b-messages'),(166981,'deals-mobile','.b-messages .messages-menu li span','float','right','','','.b-messages'),(166982,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices li','float','left','','','.b-select-suggest'),(166983,'deals-mobile','.b-sub-totals .historyTotal table','float','right','','','.b-sub-totals'),(166984,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(166985,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(166986,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(166987,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(166988,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(166989,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(166990,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(166991,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(166992,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(166993,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(166994,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(166995,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(166996,'deals-mobile','.b-trade-approval .col-right','float','right','','','.b-trade-approval'),(166997,'deals-mobile','.b-trade-approval .col-left','float','left','','','.b-trade-approval'),(166998,'deals-mobile','.b-trade-approval .col-3','float','left','','','.b-trade-approval'),(166999,'deals-mobile','.b-upload-files .remove-file','float','right','','','.b-upload-files'),(167000,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','float','left','3','','.b-warehouses-popup'),(167001,'deals-mobile','.batchPr .w-batch-products .products-listing .image','float','left','','','.batchPr'),(167002,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(2)','float','none','','','.batchPr'),(167003,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','float','left','','','.batchPr'),(167004,'deals-mobile','.p-account-samples-history-info .history_info > div','float','left','','','.p-account-samples-history-info'),(167005,'deals-mobile','.p-account-samples-history-info .history_info > div','float','left','','','.p-account-samples-history-info'),(167006,'deals-mobile','.p-account-samples-history-info .history_info > div','float','left','','','.p-account-samples-history-info'),(167007,'deals-mobile','.p-account-samples-history-info .history_info > div','float','left','','','.p-account-samples-history-info'),(167008,'deals-mobile','.p-account-samples-history-info .history_info > div','float','left','','','.p-account-samples-history-info'),(167009,'deals-mobile','.p-account-samples-history-info .history_info > div','float','left','','','.p-account-samples-history-info'),(167010,'deals-mobile','.p-payer-order-confirmation .dob-hide label','float','left','','','.p-payer-order-confirmation'),(167011,'deals-mobile','.p-payer-order-confirmation .dob-hide > div','float','right','','','.p-payer-order-confirmation'),(167012,'deals-mobile','.p-payer-order-pay .dob-hide > div','float','right','','','.p-payer-order-pay'),(167013,'deals-mobile','.p-payer-order-pay .dob-hide label','float','left','','','.p-payer-order-pay'),(167014,'deals-mobile','.w-account-addresses-list .addsess-suggestion-item','float','left','','','.w-account-addresses-list'),(167015,'deals-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','float','left','','','.w-account-addresses-list'),(167016,'deals-mobile','.w-blog-widget-post-date ','float','none','','','.w-blog-widget-post-date'),(167017,'deals-mobile','.w-blog-widget-post-image ','float','none','','','.w-blog-widget-post-image'),(167018,'deals-mobile','.w-blog-widget-post-listing .post','float','left','','','.w-blog-widget-post-listing'),(167019,'deals-mobile','.w-blog-widget-post-share ','float','none','','','.w-blog-widget-post-share'),(167020,'deals-mobile','.w-blog-widget-post-title ','float','none','','','.w-blog-widget-post-title'),(167021,'deals-mobile','.w-blog-widget-related-posts .post','float','left','','','.w-blog-widget-related-posts'),(167022,'deals-mobile','.w-blog-widget-related-posts-by-category .post','float','left','','','.w-blog-widget-related-posts-by-category'),(167023,'deals-mobile','.w-cart-compare .product .image','float','left','','','.w-cart-compare'),(167024,'deals-mobile','.w-cart-compare .product-actions','float','right','','','.w-cart-compare'),(167025,'deals-mobile','.w-cart-compare .buttons','float','right','','','.w-cart-compare'),(167026,'deals-mobile','.w-cart-compare .js-cart_totals_container','float','left','','','.w-cart-compare'),(167027,'deals-mobile','.w-catalog-compare .compare label','float','right','','','.w-catalog-compare'),(167028,'deals-mobile','.w-catalog-compare .buyButton','float','right','','','.w-catalog-compare'),(167029,'deals-mobile','.w-checkout-billing-address .btn-cancel','float','left','','','.w-checkout-billing-address'),(167030,'deals-mobile','.w-checkout-billing-address .addresses .address-item','float','left','','','.w-checkout-billing-address'),(167031,'deals-mobile','.w-checkout-billing-address .add-ab','float','left','','','.w-checkout-billing-address'),(167032,'deals-mobile','.w-checkout-billing-address .bootstrap-switch','float','right','','','.w-checkout-billing-address'),(167033,'deals-mobile','.w-checkout-contact-information .btn-save','float','right','','','.w-checkout-contact-information'),(167034,'deals-mobile','.w-checkout-create-account .newsletter-switcher .bootstrap-switch','float','right','','','.w-checkout-create-account'),(167035,'deals-mobile','.w-checkout-create-account .create-account-switcher','float','right','','','.w-checkout-create-account'),(167036,'deals-mobile','.w-checkout-gdpr .candlestick-wrapper','float','right','','','.w-checkout-gdpr'),(167037,'deals-mobile','.w-checkout-shipping-address .add-ab','float','left','','','.w-checkout-shipping-address'),(167038,'deals-mobile','.w-checkout-shipping-address .btn-cancel','float','left','','','.w-checkout-shipping-address'),(167039,'deals-mobile','.w-checkout-shipping-address .addresses .address-item','float','left','','','.w-checkout-shipping-address'),(167040,'deals-mobile','.w-delivery-day .left-count','float','left','','','.w-delivery-day'),(167041,'deals-mobile','.w-delivery-day .left-text-left','float','left','','','.w-delivery-day'),(167042,'deals-mobile','.w-delivery-day .left-text-right','float','left','','','.w-delivery-day'),(167043,'deals-mobile','.w-list-b2b .select-attributes:nth-child(2n)','float','right','','','.w-list-b2b'),(167044,'deals-mobile','.w-list-b2b .select-attributes','float','left','','','.w-list-b2b'),(167045,'deals-mobile','.w-neighbour-checkout .bootstrap-switch','float','right','','','.w-neighbour-checkout'),(167046,'deals-mobile','.w-product-cross-sell .buy-all-checker','float','left','','','.w-product-cross-sell'),(167047,'deals-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(167048,'deals-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(167049,'deals-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(167050,'deals-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(167051,'deals-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(167052,'deals-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(167053,'deals-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(167054,'deals-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(167055,'deals-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(167056,'deals-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(167057,'deals-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(167058,'deals-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(167059,'deals-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(167060,'deals-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(167061,'deals-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(167062,'deals-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(167063,'deals-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(167064,'deals-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(167065,'deals-mobile','.w-wedding-registry-widgets-products .rating','float','none','','','.w-wedding-registry-widgets-products'),(167066,'deals-mobile','.w-wedding-registry-widgets-products .price','float','left','','','.w-wedding-registry-widgets-products'),(167067,'deals-mobile','.w-wedding-registry-widgets-products .qty-input','float','right','','','.w-wedding-registry-widgets-products'),(167068,'deals-mobile','.w-wedding-registry-widgets-search-form .button','float','right','','','.w-wedding-registry-widgets-search-form'),(167069,'deals-mobile','.p-wedding-registry-manage .qty-input','float_important','important','','','.p-wedding-registry-manage'),(167070,'deals-mobile','.b-slick .slick-slide','float_important','important','','','.b-slick'),(167071,'deals-mobile','.w-blog-widget-post-share ','float_important','important','','','.w-blog-widget-post-share'),(167072,'deals-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','font-family','FontAwesome','3','','.w-menu'),(167073,'deals-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','font-family','FontAwesome','3','','.w-menu'),(167074,'deals-mobile','.w-menu .menu .menu-ico','font-family','\'trueloaded\'','3','','.w-menu'),(167075,'deals-mobile','.w-menu-slider .close','font-family','FontAwesome','3','','.w-menu-slider'),(167076,'deals-mobile','.w-bestsellers .item','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-bestsellers'),(167077,'deals-mobile','.b-social-login .social-login-text-1','font-family','\'Varela Round\'','','','.b-social-login'),(167078,'deals-mobile','.w-bestsellers .heading-3','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-bestsellers'),(167079,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','font-family','FontAwesome','3','','.b-slick'),(167080,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(167081,'deals-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','','','.b-form'),(167082,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','','','.b-form'),(167083,'deals-mobile','.w-html_box .socials','font-family','FontAwesome','','','.w-html_box'),(167084,'deals-mobile','.w-product-wedding-registry-button .btn','font-family','Hind','','','.w-product-wedding-registry-button'),(167085,'deals-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-cart-gift-certificate'),(167086,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','font-family','\'trueloaded\'','3','','.p-account-history-info'),(167087,'deals-mobile','.w-categories .name','font-family','\'Varela Round\', sans-serif','','','.w-categories'),(167088,'deals-mobile','.heading-3 .edit, h3 .edit','font-family','\'Hind\', Verdana, Arial, sans-serif','','',''),(167089,'deals-mobile','.w-catalog-listing-look .list','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-catalog-listing-look'),(167090,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-family','\'trueloaded\'','4','','.b-multi-page-checkout'),(167091,'deals-mobile','.b-pagination .pagination .next','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.b-pagination'),(167092,'deals-mobile','.b-pagination .pagination .prev','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.b-pagination'),(167093,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-family','FontAwesome','3','','.b-multi-page-checkout'),(167094,'deals-mobile','.p-blog-index .nav-previous a','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.p-blog-index'),(167095,'deals-mobile','.p-blog-index .wp-widget li','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.p-blog-index'),(167096,'deals-mobile','.p-blog-index .post-title','font-family','\'Varela Round\'','','','.p-blog-index'),(167097,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-family','\'Varela Round\'','','','.b-multi-page-checkout'),(167098,'deals-mobile','.w-list-type-2 .button-view a','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-2'),(167099,'deals-mobile','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(167100,'deals-mobile','.p-wedding-registry-manage .remove-btn','font-family','trueloaded','3','','.p-wedding-registry-manage'),(167101,'deals-mobile','.p-wedding-registry-view h1','font-family','FontAwesome','4','','.p-wedding-registry-view'),(167102,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','font-family','\'trueloaded\'','3','','.p-account-order-pay'),(167103,'deals-mobile','.js-stock-icon','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','',''),(167104,'deals-mobile','.testimonials .heading-3','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','',''),(167105,'deals-mobile','.p-wedding-registry-manage .wr-search button','font-family','trueloaded','3','','.p-wedding-registry-manage'),(167106,'deals-mobile','.p-account-history .orders-table th','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.p-account-history'),(167107,'deals-mobile','.p-account-history .view_link','font-family','\'trueloaded\',sans-serif','4','','.p-account-history'),(167108,'deals-mobile','.p-account-index .orders-table th','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.p-account-index'),(167109,'deals-mobile','.p-blog-index .nav-next a','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.p-blog-index'),(167110,'deals-mobile','.p-blog-index .author','font-family','\'Varela Round\'','','','.p-blog-index'),(167111,'deals-mobile','.no-found','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','',''),(167112,'deals-mobile','.w-list-type-2_2 .price','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-list-type-2_2'),(167113,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-2_2'),(167114,'deals-mobile','.w-list-type-2_2 .button-wishlist button','font-family','\'Hind\', Verdana, Arial, sans-serif','','','.w-list-type-2_2'),(167115,'deals-mobile','.w-list-type-2_2 .button-view a','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-2_2'),(167116,'deals-mobile','.w-list-type-2 .sale','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-2'),(167117,'deals-mobile','.w-list-type-2 .price','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-list-type-2'),(167118,'deals-mobile','.price','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','',''),(167119,'deals-mobile','.w-product-personal-catalog-button .btn','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-product-personal-catalog-button'),(167120,'deals-mobile','.w-product-wishlist-button .btn','font-family','Hind','','','.w-product-wishlist-button'),(167121,'deals-mobile','.w-list-type-2_2 .button-wishlist button','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-2_2'),(167122,'deals-mobile','.w-product-bonus-points > div > div','font-family','FontAwesome','3','','.w-product-bonus-points'),(167123,'deals-mobile','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(167124,'deals-mobile','.w-product-personal-catalog-button .btn','font-family','\'Hind\', Verdana, Arial, sans-serif','','','.w-product-personal-catalog-button'),(167125,'deals-mobile','.w-chat .w-chat-box a','font-family','FontAwesome','3','','.w-chat'),(167126,'deals-mobile','.w-delivery-location-location-list .deliveryListParrent','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-delivery-location-location-list'),(167127,'deals-mobile','.w-product-promotions .promotion-full-price-discount','font-family','Varela Round','','','.w-product-promotions'),(167128,'deals-mobile','.p-wedding-registry-index .main-button','font-family','FontAwesome','3','','.p-wedding-registry-index'),(167129,'deals-mobile','.p-wedding-registry-index .main-button','font-family','FontAwesome','4','','.p-wedding-registry-index'),(167130,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','font-family','FontAwesome','3','','.b-form'),(167131,'deals-mobile','.p-wedding-registry-index .search-list label','font-family','Varela Round','','','.p-wedding-registry-index'),(167132,'deals-mobile','.p-wedding-registry-manage .links a.share-registry','font-family','FontAwesome','4','','.p-wedding-registry-manage'),(167133,'deals-mobile','.p-wedding-registry-search h1','font-family','FontAwesome','3','','.p-wedding-registry-search'),(167134,'deals-mobile','.p-wedding-registry-search h1','font-family','FontAwesome','4','','.p-wedding-registry-search'),(167135,'deals-mobile','.p-wedding-registry-share h1','font-family','FontAwesome','3','','.p-wedding-registry-share'),(167136,'deals-mobile','.p-wedding-registry-manage h1','font-family','FontAwesome','3','','.p-wedding-registry-manage'),(167137,'deals-mobile','.p-account-address-book .btn-edit','font-family','\'trueloaded\'','4','','.p-account-address-book'),(167138,'deals-mobile','.b-compare .clear_all','font-family','\'FontAwesome\'','4','','.b-compare'),(167139,'deals-mobile','.w-account .my-acc-link','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-account'),(167140,'deals-mobile','.w-tabs .accordion-heading','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-tabs'),(167141,'deals-mobile','.b-bottom .footerTitle','font-family','FontAwesome','863,4','','.b-bottom'),(167142,'deals-mobile','.w-filters .head-filter-widget','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-filters'),(167143,'deals-mobile','.heading-4 .right-text, h4 .right-text','font-family','\'Hind\', Verdana, Arial, sans-serif','','',''),(167144,'deals-mobile','.w-list-type-1 .button-view a','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-1'),(167145,'deals-mobile','.w-search .button-search','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-search'),(167146,'deals-mobile','.w-tabs .tab-a','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-tabs'),(167147,'deals-mobile','.w-socials .post_item > div','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-socials'),(167148,'deals-mobile','.w-search .search','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-search'),(167149,'deals-mobile','.w-list-type-1_3 .price','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-list-type-1_3'),(167150,'deals-mobile','body','font-family','\'Hind\', Verdana, Arial, sans-serif','','',''),(167151,'deals-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','','','.w-filters'),(167152,'deals-mobile','.w-filters .filter-box-head','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-filters'),(167153,'deals-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','\'trueloaded\'','3','','.w-contact-contacts'),(167154,'deals-mobile','.w-currencies .current','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-currencies'),(167155,'deals-mobile','.w-compare-box-item .checkbox:checked + span:before','font-family','\'FontAwesome\'','','','.w-compare-box-item'),(167156,'deals-mobile','.b-info-popup .info-popup','font-family','\'trueloaded\'','3','','.b-info-popup'),(167157,'deals-mobile','.p-account-index .view_link','font-family','\'trueloaded\',sans-serif','4','','.p-account-index'),(167158,'deals-mobile','.p-account-index .view_history','font-family','\'trueloaded\'','3','','.p-account-index'),(167159,'deals-mobile','.p-checkout-success .page-success','font-family','\'trueloaded\'','3','','.p-checkout-success'),(167160,'deals-mobile','.w-menu-mobile .menu-ico','font-family','\'trueloaded\'','3','','.w-menu-mobile'),(167161,'deals-mobile','.p-checkout-success .page-success .text-1','font-family','\'trueloaded\'','3','','.p-checkout-success'),(167162,'deals-mobile','.b-fancybox .fancybox-nav span','font-family','trueloaded','','','.b-fancybox'),(167163,'deals-mobile','.heading-2, h2','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','',''),(167164,'deals-mobile','.p-checkout-success .page-success .text-1, .p-checkout-success .page-success .text-2, .p-checkout-success .page-success .text-3','font-family','\'Varela Round\', sans-serif','','','.p-checkout-success'),(167165,'deals-mobile','.p-wedding-registry-share .invite-remove','font-family','trueloaded','3','','.p-wedding-registry-share'),(167166,'deals-mobile','.w-text .customer-service b','font-family','\'Varela Round\'','','','.w-text'),(167167,'deals-mobile','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(167168,'deals-mobile','.w-categories .categories h2','font-family','inherit','','','.w-categories'),(167169,'deals-mobile','.w-top-categories .categories h2','font-family','inherit','','','.w-top-categories'),(167170,'deals-mobile','.b-rating .glyphicon','font-family','FontAwesome','','','.b-rating'),(167171,'deals-mobile','.b-rating #stars-default .glyphicon','font-family','\'trueloaded\'','','','.b-rating'),(167172,'deals-mobile','.w-cart .cart-box-link','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-cart'),(167173,'deals-mobile','.b-fancybox .fancybox-close','font-family','FontAwesome','3','','.b-fancybox'),(167174,'deals-mobile','.btn-3','font-family','Varela Round','','',''),(167175,'deals-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-cart-discount-coupon'),(167176,'deals-mobile','.btn','font-family','Varela Round','','',''),(167177,'deals-mobile','.w-top-categories .name','font-family','\'Varela Round\', sans-serif','','','.w-top-categories'),(167178,'deals-mobile','.p-account-index .date_value strong','font-family','\'Hind\', sans-serif','','','.p-account-index'),(167179,'deals-mobile','.heading-4, h4','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','',''),(167180,'deals-mobile','h1','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','',''),(167181,'deals-mobile','.w-catalog-listing-look .b2b','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-catalog-listing-look'),(167182,'deals-mobile','.heading-3, h3','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','',''),(167183,'deals-mobile','.p-account-index .account_page h4','font-family','\'trueloaded\'','3','','.p-account-index'),(167184,'deals-mobile','.p-account-index .date_value, .p-account-index .date_title','font-family','\'Varela Round\', sans-serif','','','.p-account-index'),(167185,'deals-mobile','.w-list-type-2_2 .sale','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-2_2'),(167186,'deals-mobile','.p-account-index .topAccount > li > div','font-family','\'trueloaded\'','3','','.p-account-index'),(167187,'deals-mobile','.w-cart-give-away .ga_qty','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-cart-give-away'),(167188,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-2'),(167189,'deals-mobile','.w-list-type-2 .button-wishlist button','font-family','\'Hind\', Verdana, Arial, sans-serif','','','.w-list-type-2'),(167190,'deals-mobile','.w-list-type-1_3 .sale','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-1_3'),(167191,'deals-mobile','.w-list-type-2 .button-wishlist button','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-2'),(167192,'deals-mobile','.w-catalog-listing-look .grid','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-catalog-listing-look'),(167193,'deals-mobile','.view-all .btn','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','4','',''),(167194,'deals-mobile','.p-wedding-registry-share h1','font-family','FontAwesome','4','','.p-wedding-registry-share'),(167195,'deals-mobile','.p-wedding-registry-manage h1','font-family','FontAwesome','4','','.p-wedding-registry-manage'),(167196,'deals-mobile','.btn-2','font-family','Varela Round','','',''),(167197,'deals-mobile','.p-wedding-registry-view h1','font-family','FontAwesome','3','','.p-wedding-registry-view'),(167198,'deals-mobile','.btn-1','font-family','Varela Round','','',''),(167199,'deals-mobile','.heading-3 .edit, h3 .edit','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','',''),(167200,'deals-mobile','.w-list-type-1_3 .button-wishlist button','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-1_3'),(167201,'deals-mobile','.w-list-type-1_3 .button-wishlist button','font-family','\'Hind\', Verdana, Arial, sans-serif','','','.w-list-type-1_3'),(167202,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-1_3'),(167203,'deals-mobile','.w-list-type-1_3 .button-view a','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-1_3'),(167204,'deals-mobile','.w-list-type-1_2 .sale','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-1_2'),(167205,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-1_2'),(167206,'deals-mobile','.w-list-type-1_2 .price','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-list-type-1_2'),(167207,'deals-mobile','.w-list-type-1_2 .button-wishlist button','font-family','\'Hind\', Verdana, Arial, sans-serif','','','.w-list-type-1_2'),(167208,'deals-mobile','.w-list-type-1_2 .button-wishlist button','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-1_2'),(167209,'deals-mobile','.b-bottom .pop-up-close','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.b-bottom'),(167210,'deals-mobile','.w-list-type-1 .sale','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-1'),(167211,'deals-mobile','.w-list-type-1_2 .button-view a','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-1_2'),(167212,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-list-type-1'),(167213,'deals-mobile','.w-filters .mobileCollapse','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','4','','.w-filters'),(167214,'deals-mobile','.w-list-type-1 .button-wishlist button','font-family','\'Hind\', Verdana, Arial, sans-serif','','','.w-list-type-1'),(167215,'deals-mobile','.transit-icon','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','',''),(167216,'deals-mobile','.w-list-type-1 .button-wishlist button','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','','.w-list-type-1'),(167217,'deals-mobile','.in-stock-icon','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','',''),(167218,'deals-mobile','.w-filters .open','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-filters'),(167219,'deals-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','','','.w-filters'),(167220,'deals-mobile','.heading-4 .edit, h4 .edit','font-family','\'trueloaded\', Verdana, Arial, sans-serif','4','',''),(167221,'deals-mobile','.heading-4 .edit, h4 .edit','font-family','\'Hind\', Verdana, Arial, sans-serif','','',''),(167222,'deals-mobile','.w-filters span.close','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-filters'),(167223,'deals-mobile','.w-filters .view_more','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','4','','.w-filters'),(167224,'deals-mobile','.out-stock-icon','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','',''),(167225,'deals-mobile','.w-languages .current','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-languages'),(167226,'deals-mobile','.w-reviews .heading-3','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-reviews'),(167227,'deals-mobile','.w-quote .cart-box-link','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-quote'),(167228,'deals-mobile','.btn-del','font-family','\'FontAwesome\'','4','',''),(167229,'deals-mobile','.p-account-address-book .leftMes div','font-family','\'Varela Round\', sans-serif','','','.p-account-address-book'),(167230,'deals-mobile','.b-info .info','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.b-info'),(167231,'deals-mobile','.b-info .info strong','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.b-info'),(167232,'deals-mobile','.b-products-listing .btn-preloader','font-family','FontAwesome','3','','.b-products-listing'),(167233,'deals-mobile','.b-products-listing .loader','font-family','FontAwesome','4','','.b-products-listing'),(167234,'deals-mobile','.b-products-listing .products-listing .bonus-points-cost','font-family','FontAwesome','3','','.b-products-listing'),(167235,'deals-mobile','.b-products-listing .products-listing .bonus-points-price','font-family','FontAwesome','3','','.b-products-listing'),(167236,'deals-mobile','.b-products-listing .products-listing .btn-buy','font-family','trueloaded','3','','.b-products-listing'),(167237,'deals-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-family','FontAwesome','','','.b-products-listing'),(167238,'deals-mobile','.b-products-listing .products-listing a.btn.view-button','font-family','trueloaded','3','','.b-products-listing'),(167239,'deals-mobile','.b-products-listing .products-listing h2','font-family','inherit','','','.b-products-listing'),(167240,'deals-mobile','.b-data-table table.dataTable thead td','font-family','Varela Round','','','.b-data-table'),(167241,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(167242,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(167243,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(167244,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(167245,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(167246,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(167247,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-family','inherit','','','.b-h-inline'),(167248,'deals-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','font-family','FontAwesome','3','','.b-menu-burger_icon'),(167249,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','font-family','FontAwesome','4','','.b-menu-style-1'),(167250,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > .no-link','font-family','FontAwesome','4','','.b-menu-style-1'),(167251,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','font-family','FontAwesome','4','','.b-menu-style-1'),(167252,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','font-family','FontAwesome','3','','.b-menu-style-2'),(167253,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','font-family','FontAwesome','3','','.b-menu-style-2'),(167254,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-family','FontAwesome','3','','.b-menu-style-2'),(167255,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > .no-link','font-family','FontAwesome','4','','.b-menu-style-3'),(167256,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 .parent > .no-link','font-family','FontAwesome','3','','.b-menu-style-3'),(167257,'deals-mobile','.b-messages .select2-search-choice-close','font-family','trueloaded','3','','.b-messages'),(167258,'deals-mobile','.b-messages .messBtnMenuUnread','font-family','FontAwesome','3','','.b-messages'),(167259,'deals-mobile','.b-messages .messBtnMenuDelete','font-family','trueloaded','3','','.b-messages'),(167260,'deals-mobile','.b-messages span.starred::before','font-family','trueloaded','','','.b-messages'),(167261,'deals-mobile','.b-messages .messBtnMenuStarred','font-family','trueloaded','3','','.b-messages'),(167262,'deals-mobile','.b-messages .content_management_attach span','font-family','Hind','','','.b-messages'),(167263,'deals-mobile','.b-preloader .preloader','font-family','FontAwesome','3','','.b-preloader'),(167264,'deals-mobile','.b-select-suggest .select2-search input','font-family','Hind','','','.b-select-suggest'),(167265,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-family','Hind','','','.b-select-suggest'),(167266,'deals-mobile','.b-table-list .table-list th','font-family','Varela Round','','','.b-table-list'),(167267,'deals-mobile','.b-table-list .table-list th','font-family','Varela Round','','','.b-table-list'),(167268,'deals-mobile','.b-table-list .table-list th','font-family','Varela Round','','','.b-table-list'),(167269,'deals-mobile','.b-table-list .table-list th','font-family','Varela Round','','','.b-table-list'),(167270,'deals-mobile','.b-table-list .table-list th','font-family','Varela Round','','','.b-table-list'),(167271,'deals-mobile','.b-table-list .table-list th','font-family','Varela Round','','','.b-table-list'),(167272,'deals-mobile','.b-upload-file .snapshot','font-family','FontAwesome','3','','.b-upload-file'),(167273,'deals-mobile','.b-upload-file .upload-file-wrap .upload-remove','font-family','trueloaded','3','','.b-upload-file'),(167274,'deals-mobile','.b-upload-files .remove-file','font-family','FontAwesome','3','','.b-upload-files'),(167275,'deals-mobile','.b-warehouses-popup .warehouses-popup-link','font-family','FontAwesome','3','','.b-warehouses-popup'),(167276,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','font-family','FontAwesome','3','','.b-warehouses-popup'),(167277,'deals-mobile','.batchPr .checkbox input:checked + span:before','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','','','.batchPr'),(167278,'deals-mobile','.bell-ico .heading-2','font-family','trueloaded','3','','.bell-ico'),(167279,'deals-mobile','.heading-ordered-items .heading-4','font-family','trueloaded','3','','.heading-ordered-items'),(167280,'deals-mobile','.heading-saved-lists .heading-4','font-family','trueloaded','3','','.heading-saved-lists'),(167281,'deals-mobile','.heading-settings .heading-4','font-family','trueloaded','3','','.heading-settings'),(167282,'deals-mobile','.p-account-samples-history .orders-table th','font-family','Varela Round','','','.p-account-samples-history'),(167283,'deals-mobile','.p-account-samples-history .view_link','font-family','trueloaded','4','','.p-account-samples-history'),(167284,'deals-mobile','.p-account-samples-history .view_link','font-family','trueloaded','4','','.p-account-samples-history'),(167285,'deals-mobile','.p-account-samples-history .orders-table th','font-family','Varela Round','','','.p-account-samples-history'),(167286,'deals-mobile','.p-account-samples-history .orders-table th','font-family','Varela Round','','','.p-account-samples-history'),(167287,'deals-mobile','.p-account-samples-history .orders-table th','font-family','Varela Round','','','.p-account-samples-history'),(167288,'deals-mobile','.p-account-samples-history .orders-table th','font-family','Varela Round','','','.p-account-samples-history'),(167289,'deals-mobile','.p-account-samples-history .view_link','font-family','trueloaded','4','','.p-account-samples-history'),(167290,'deals-mobile','.p-account-samples-history .view_link','font-family','trueloaded','4','','.p-account-samples-history'),(167291,'deals-mobile','.p-account-samples-history .view_link','font-family','trueloaded','4','','.p-account-samples-history'),(167292,'deals-mobile','.p-account-samples-history .view_link','font-family','trueloaded','4','','.p-account-samples-history'),(167293,'deals-mobile','.p-account-samples-history .orders-table th','font-family','Varela Round','','','.p-account-samples-history'),(167294,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-family','trueloaded','3','','.p-account-samples-history-info'),(167295,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-family','trueloaded','3','','.p-account-samples-history-info'),(167296,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-family','trueloaded','3','','.p-account-samples-history-info'),(167297,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-family','trueloaded','3','','.p-account-samples-history-info'),(167298,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-family','trueloaded','3','','.p-account-samples-history-info'),(167299,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-family','trueloaded','3','','.p-account-samples-history-info'),(167300,'deals-mobile','.p-catalog-product .pn-direction','font-family','Varela Round','','','.p-catalog-product'),(167301,'deals-mobile','.p-catalog-product .pn-image','font-family','FontAwesome','3','','.p-catalog-product'),(167302,'deals-mobile','.p-payer-order-confirmation .discount-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(167303,'deals-mobile','.p-payer-order-confirmation .ship-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(167304,'deals-mobile','.p-payer-order-confirmation .comment-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(167305,'deals-mobile','.p-payer-order-confirmation .order-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(167306,'deals-mobile','.p-payer-order-confirmation .pay-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(167307,'deals-mobile','.p-payer-order-pay .order-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(167308,'deals-mobile','.p-payer-order-pay .pay-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(167309,'deals-mobile','.p-payer-order-pay .comment-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(167310,'deals-mobile','.p-payer-order-pay .discount-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(167311,'deals-mobile','.p-payer-order-pay .ship-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(167312,'deals-mobile','.p-quick-order-index .paginate_button.next','font-family','FontAwesome','3','','.p-quick-order-index'),(167313,'deals-mobile','.p-quick-order-index .paginate_button.previous','font-family','FontAwesome','3','','.p-quick-order-index'),(167314,'deals-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-quote-checkout-success'),(167315,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(167316,'deals-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-quote-checkout-success'),(167317,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(167318,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(167319,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(167320,'deals-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-quote-checkout-success'),(167321,'deals-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-quote-checkout-success'),(167322,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(167323,'deals-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-quote-checkout-success'),(167324,'deals-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-quote-checkout-success'),(167325,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(167326,'deals-mobile','.p-sample-checkout-success .page-success .text-1, .p-sample-checkout-success .page-success .text-2, .p-sample-checkout-success .page-success .text-3','font-family','Varela Round','','','.p-sample-checkout-success'),(167327,'deals-mobile','.p-sample-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-sample-checkout-success'),(167328,'deals-mobile','.savings-ico .heading-2','font-family','trueloaded','3','','.savings-ico'),(167329,'deals-mobile','.shipping-ico .heading-2','font-family','trueloaded','3','','.shipping-ico'),(167330,'deals-mobile','.shipping-ico .heading-2','font-family','trueloaded','3','','.shipping-ico'),(167331,'deals-mobile','.shipping-ico .heading-2','font-family','trueloaded','3','','.shipping-ico'),(167332,'deals-mobile','.w-account-address-book .add_item a','font-family','\'FontAwesome\', Verdana, Arial, sans-serif','3','','.w-account-address-book'),(167333,'deals-mobile','.w-account-personal-catalog .list-switcher a','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-account-personal-catalog'),(167334,'deals-mobile','.w-blog-widget-post-listing .post_name','font-family','Varela Round','','','.w-blog-widget-post-listing'),(167335,'deals-mobile','.w-blog-widget-post-share .pinterest-btn','font-family','FontAwesome','3','','.w-blog-widget-post-share'),(167336,'deals-mobile','.w-blog-widget-post-share .facebook-btn','font-family','FontAwesome','3','','.w-blog-widget-post-share'),(167337,'deals-mobile','.w-blog-widget-post-share .twitter-btn','font-family','FontAwesome','3','','.w-blog-widget-post-share'),(167338,'deals-mobile','.w-cart-bonus-points .title','font-family','FontAwesome','3','','.w-cart-bonus-points'),(167339,'deals-mobile','.w-cart-bonus-points .btn-remove','font-family','trueloaded','3','','.w-cart-bonus-points'),(167340,'deals-mobile','.w-cart-compare .price-cell','font-family','Varela Round','','','.w-cart-compare'),(167341,'deals-mobile','.w-cart-compare .cart-name a','font-family','Varela Round','','','.w-cart-compare'),(167342,'deals-mobile','.w-cart-compare .atr-col','font-family','FontAwesome','3','','.w-cart-compare'),(167343,'deals-mobile','.w-cart-compare .product-actions .dropdown-toggle','font-family','FontAwesome','3','','.w-cart-compare'),(167344,'deals-mobile','.w-cart-credit-amount .amount-title','font-family','trueloaded','3','','.w-cart-credit-amount'),(167345,'deals-mobile','.w-cart-credit-amount .btn-remove','font-family','trueloaded','3','','.w-cart-credit-amount'),(167346,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-family','\'trueloaded\', Verdana, Arial, sans-serif','3','','.w-catalog-compare'),(167347,'deals-mobile','.w-catalog-paging .next','font-family','FontAwesome','3','','.w-catalog-paging'),(167348,'deals-mobile','.w-catalog-paging .prev','font-family','FontAwesome','3','','.w-catalog-paging'),(167349,'deals-mobile','.w-checkout-bonus-points .btn-remove','font-family','trueloaded','3','','.w-checkout-bonus-points'),(167350,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','font-family','FontAwesome','3','','.w-checkout-contact-information'),(167351,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','font-family','FontAwesome','3','','.w-checkout-contact-information'),(167352,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','font-family','FontAwesome','3','','.w-checkout-contact-information'),(167353,'deals-mobile','.w-checkout-create-account .account-benefits strong','font-family','trueloaded','3','','.w-checkout-create-account'),(167354,'deals-mobile','.w-checkout-credit-amount .btn-remove','font-family','trueloaded','3','','.w-checkout-credit-amount'),(167355,'deals-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-family','\'Varela Round\', Verdana, Arial, sans-serif','','','.w-communication-new-topic'),(167356,'deals-mobile','.w-coupons-and-vauchers-checkout .btn-remove','font-family','trueloaded','3','','.w-coupons-and-vauchers-checkout'),(167357,'deals-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','font-family','FontAwesome','3','','.w-multi-cart-actions'),(167358,'deals-mobile','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-family','Varela Round','','','.w-multi-cart-cart-switcher'),(167359,'deals-mobile','.w-product-cross-sell .buy-all-checker','font-family','FontAwesome','3','','.w-product-cross-sell'),(167360,'deals-mobile','.w-promotions .nextdiscount .heading','font-family','FontAwesome','3','','.w-promotions'),(167361,'deals-mobile','.w-social-links a','font-family','FontAwesome','','','.w-social-links'),(167362,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-family','FontAwesome','3','','.w-upload-customer-id-upload-customer-id-form'),(167363,'deals-mobile','.w-wedding-registry-widgets-manage-names .names-separator','font-family','FontAwesome','3','','.w-wedding-registry-widgets-manage-names'),(167364,'deals-mobile','.w-wedding-registry-widgets-products .remove-btn','font-family','trueloaded','3','','.w-wedding-registry-widgets-products'),(167365,'deals-mobile','.w-wedding-registry-widgets-search-registry-button a','font-family','FontAwesome','3','','.w-wedding-registry-widgets-search-registry-button'),(167366,'deals-mobile','.w-wedding-registry-widgets-share-link a','font-family','FontAwesome','3','','.w-wedding-registry-widgets-share-link'),(167367,'deals-mobile','.b-rating .glyphicon','font-family_important','important','','','.b-rating'),(167368,'deals-mobile','.b-rating #stars-default .glyphicon','font-family_important','important','','','.b-rating'),(167369,'deals-mobile','.w-bestsellers .item','font-size','32','3','','.w-bestsellers'),(167370,'deals-mobile','.w-bestsellers .heading-3','font-size','50','3','','.w-bestsellers'),(167371,'deals-mobile','.w-account .my-acc-link','font-size','30','3','','.w-account'),(167372,'deals-mobile','.b-switch .bootstrap-switch','font-size','16','','','.b-switch'),(167373,'deals-mobile','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(167374,'deals-mobile','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(167375,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','20','3','','.b-slick'),(167376,'deals-mobile','.w-list-type-1 .rating-count','font-size','14','','','.w-list-type-1'),(167377,'deals-mobile','.w-tabs .accordion-heading','font-size','20','','','.w-tabs'),(167378,'deals-mobile','.w-list-type-1 .price','font-size','20','','','.w-list-type-1'),(167379,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(167380,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-size','18','','','.b-form'),(167381,'deals-mobile','.w-product-sale-ends .ends','font-size','26','','','.w-product-sale-ends'),(167382,'deals-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','font-size','18','','','.b-form'),(167383,'deals-mobile','.w-sale .left-count-days','font-size','40','','','.w-sale'),(167384,'deals-mobile','.w-sale .left-count-hours','font-size','40','','','.w-sale'),(167385,'deals-mobile','.w-menu-slider .menu-ico','font-size','23','','','.w-menu-slider'),(167386,'deals-mobile','.w-menu-horizontal .menu-ico','font-size','23','','','.w-menu-horizontal'),(167387,'deals-mobile','.w-sale .name','font-size','20','','','.w-sale'),(167388,'deals-mobile','.w-list-type-2_2 .title','font-size','16','','','.w-list-type-2_2'),(167389,'deals-mobile','.w-sale .percents','font-size','30','','','.w-sale'),(167390,'deals-mobile','.w-sale .badge','font-size','20','','','.w-sale'),(167391,'deals-mobile','.w-html_box .socials a','font-size','26','','','.w-html_box'),(167392,'deals-mobile','.w-menu-style-1 .menu-ico','font-size','23','','','.w-menu-style-1'),(167393,'deals-mobile','.w-menu-style-1 > ul','font-size','16','','','.w-menu-style-1'),(167394,'deals-mobile','.w-product-sale-ends .left-count-hours','font-size','40','','','.w-product-sale-ends'),(167395,'deals-mobile','.w-product-sale-ends .left-count-days','font-size','40','','','.w-product-sale-ends'),(167396,'deals-mobile','.w-product-sale-ends .left-text-right','font-size','24','','','.w-product-sale-ends'),(167397,'deals-mobile','.w-product-sale-ends .left-text-left','font-size','24','','','.w-product-sale-ends'),(167398,'deals-mobile','.w-cart .cart-box-link','font-size','30','3','','.w-cart'),(167399,'deals-mobile','.p-account-index .date_title','font-size','14','','','.p-account-index'),(167400,'deals-mobile','.w-product-collection .right-area .special','font-size','30','','','.w-product-collection'),(167401,'deals-mobile','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(167402,'deals-mobile','.w-product-personal-catalog-button .btn','font-size','14','','','.w-product-personal-catalog-button'),(167403,'deals-mobile','.w-html_box .socials a','font-size','30','863','','.w-html_box'),(167404,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','font-size','18','','','.p-account-history-info'),(167405,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','font-size','22','3','','.p-account-history-info'),(167406,'deals-mobile','.p-account-history-info .not_fully_paid_td','font-size','30','','','.p-account-history-info'),(167407,'deals-mobile','.p-account-index .not_fully_paid_td','font-size','30','','','.p-account-index'),(167408,'deals-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','font-size','16','','','.p-account-index'),(167409,'deals-mobile','.p-account-trade-form .address-wrapp','font-size','14','','','.p-account-trade-form'),(167410,'deals-mobile','.w-compare-box-item .cb_title','font-size','16','','','.w-compare-box-item'),(167411,'deals-mobile','.w-categories .name','font-size','18','','','.w-categories'),(167412,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-size','0.7','4','','.b-multi-page-checkout'),(167413,'deals-mobile','.w-cart-give-away .ga_qty','font-size','17','863','','.w-cart-give-away'),(167414,'deals-mobile','.b-price-box .price-box .price-row.total','font-size','24','','','.b-price-box'),(167415,'deals-mobile','.b-price-box .price-box','font-size','18','','','.b-price-box'),(167416,'deals-mobile','.w-cart-checkout-btn a','font-size','17','863','','.w-cart-checkout-btn'),(167417,'deals-mobile','.w-product-reviews .reviews-list .date','font-size','14','','','.w-product-reviews'),(167418,'deals-mobile','.w-product-reviews .reviews-list span','font-size','22','','','.w-product-reviews'),(167419,'deals-mobile','.w-reviews .date','font-size','14','','','.w-reviews'),(167420,'deals-mobile','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(167421,'deals-mobile','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(167422,'deals-mobile','.w-product-properties li','font-size','14','','','.w-product-properties'),(167423,'deals-mobile','.w-product-in-bundles .product-link','font-size','16','','','.w-product-in-bundles'),(167424,'deals-mobile','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(167425,'deals-mobile','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(167426,'deals-mobile','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(167427,'deals-mobile','.price .old','font-size','0.8','','',''),(167428,'deals-mobile','.p-checkout-success .page-success .text-1','font-size','40','863','','.p-checkout-success'),(167429,'deals-mobile','.p-checkout-success .page-success .text-2','font-size','30','863','','.p-checkout-success'),(167430,'deals-mobile','.p-blog-index .post-title','font-size','20','','','.p-blog-index'),(167431,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','font-size','14','','','.p-blog-index'),(167432,'deals-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','font-size','16','','','.p-account-history'),(167433,'deals-mobile','.p-blog-index .wp-widget li','font-size','8','3','','.p-blog-index'),(167434,'deals-mobile','.w-filters .head-filter-widget','font-size','21','871','','.w-filters'),(167435,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-size','24','','','.b-multi-page-checkout'),(167436,'deals-mobile','.b-info-popup .info-popup div','font-size','14','','','.b-info-popup'),(167437,'deals-mobile','.w-promo-code .holder','font-size','30','893,3','','.w-promo-code'),(167438,'deals-mobile','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(167439,'deals-mobile','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(167440,'deals-mobile','.p-wedding-registry-manage a.remove-btn','font-size','22','','','.p-wedding-registry-manage'),(167441,'deals-mobile','.p-account-history-info .popup-tracking-number-link','font-size','18','','','.p-account-history-info'),(167442,'deals-mobile','.w-product-bonus-points > div','font-size','14','','','.w-product-bonus-points'),(167443,'deals-mobile','.p-account-history-info .trackings-nambers-label','font-size','20','','','.p-account-history-info'),(167444,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','font-size','18','','','.p-account-order-pay'),(167445,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','font-size','22','3','','.p-account-order-pay'),(167446,'deals-mobile','.p-account-order-pay .history_attr','font-size','14','','','.p-account-order-pay'),(167447,'deals-mobile','.p-account-order-pay .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-order-pay'),(167448,'deals-mobile','.p-account-order-pay .historyTotal table tr:last-child td','font-size','24','','','.p-account-order-pay'),(167449,'deals-mobile','.p-account-order-pay .historyTotal table td','font-size','18','','','.p-account-order-pay'),(167450,'deals-mobile','.testimonials .date','font-size','14','','',''),(167451,'deals-mobile','.p-account-order-pay .not_fully_paid_td','font-size','30','','','.p-account-order-pay'),(167452,'deals-mobile','.testimonials .heading-3','font-size','37','3','',''),(167453,'deals-mobile','.js-stock','font-size','14','','',''),(167454,'deals-mobile','.testimonials .rating','font-size','22','','',''),(167455,'deals-mobile','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(167456,'deals-mobile','.testimonials .reviews-list span','font-size','22','','',''),(167457,'deals-mobile','.testimonials .reviews-list .date','font-size','14','','',''),(167458,'deals-mobile','.b-bottom .confirm-popup .confirm-text','font-size','20','','','.b-bottom'),(167459,'deals-mobile','.b-pagination .pagination .prev','font-size','20','3','','.b-pagination'),(167460,'deals-mobile','.p-wedding-registry-manage .wr-search button','font-size','23','3','','.p-wedding-registry-manage'),(167461,'deals-mobile','.b-pagination .pagination .next','font-size','20','3','','.b-pagination'),(167462,'deals-mobile','.p-account-history .view_link','font-size','18','4','','.p-account-history'),(167463,'deals-mobile','.p-blog-index .nav-previous a','font-size','40','3','','.p-blog-index'),(167464,'deals-mobile','.p-blog-index .nav-next a','font-size','40','3','','.p-blog-index'),(167465,'deals-mobile','.p-blog-index .comment-metadata','font-size','14','','','.p-blog-index'),(167466,'deals-mobile','.p-blog-index .author','font-size','20','','','.p-blog-index'),(167467,'deals-mobile','.no-found','font-size','1.4','','',''),(167468,'deals-mobile','.w-list-type-2_2 .sale','font-size','19','3','','.w-list-type-2_2'),(167469,'deals-mobile','.w-list-type-2_2 .price .old','font-size','18','','','.w-list-type-2_2'),(167470,'deals-mobile','.w-list-type-2_2 .properties','font-size','13','','','.w-list-type-2_2'),(167471,'deals-mobile','.w-list-type-2_2 .price','font-size','24','','','.w-list-type-2_2'),(167472,'deals-mobile','.w-list-type-2_2 .products-model','font-size','13','','','.w-list-type-2_2'),(167473,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','font-size','28','3','','.w-list-type-2_2'),(167474,'deals-mobile','.w-list-type-2 .title','font-size','16','','','.w-list-type-2'),(167475,'deals-mobile','.w-list-type-2_2 .button-view a','font-size','16','','','.w-list-type-2_2'),(167476,'deals-mobile','.w-list-type-2 .price .old','font-size','18','','','.w-list-type-2'),(167477,'deals-mobile','.w-list-type-2 .products-model','font-size','13','','','.w-list-type-2'),(167478,'deals-mobile','.w-list-type-2 .price','font-size','24','','','.w-list-type-2'),(167479,'deals-mobile','.w-product-wedding-registry-button .btn','font-size','14','','','.w-product-wedding-registry-button'),(167480,'deals-mobile','.w-product-personal-catalog-button .btn','font-size','21','3','','.w-product-personal-catalog-button'),(167481,'deals-mobile','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(167482,'deals-mobile','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(167483,'deals-mobile','.w-list-type-2_2 .button-wishlist button','font-size','16','','','.w-list-type-2_2'),(167484,'deals-mobile','.b-fancybox .fancybox-close','font-size','26','','','.b-fancybox'),(167485,'deals-mobile','.p-reviews-info .review_by .rating-1, .p-reviews-info .review_by .rating-2, .p-reviews-info .review_by .rating-3, .p-reviews-info .review_by .rating-4, .p-reviews-info .review_by .rating-5','font-size','20','','','.p-reviews-info'),(167486,'deals-mobile','.p-reviews-info .reviews-info h1','font-size','30','','','.p-reviews-info'),(167487,'deals-mobile','.w-list-type-2_2 .sale','font-size','17','4','','.w-list-type-2_2'),(167488,'deals-mobile','.w-delivery-location-top-location-list .deliveryName a','font-size','21','','','.w-delivery-location-top-location-list'),(167489,'deals-mobile','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(167490,'deals-mobile','.w-chat .w-chat-box a','font-size','20','3','','.w-chat'),(167491,'deals-mobile','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(167492,'deals-mobile','.b-bottom .alert-message','font-size','18','','','.b-bottom'),(167493,'deals-mobile','.p-wedding-registry-index .search-list label','font-size','24','','','.p-wedding-registry-index'),(167494,'deals-mobile','.p-wedding-registry-index .main-button','font-size','20','4','','.p-wedding-registry-index'),(167495,'deals-mobile','.p-wedding-registry-index .main-button','font-size','20','3','','.p-wedding-registry-index'),(167496,'deals-mobile','.p-wedding-registry-manage .links a','font-size','16','','','.p-wedding-registry-manage'),(167497,'deals-mobile','.p-wedding-registry-manage .links','font-size','0','','','.p-wedding-registry-manage'),(167498,'deals-mobile','.p-wedding-registry-manage .links a.share-registry','font-size','20','','','.p-wedding-registry-manage'),(167499,'deals-mobile','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(167500,'deals-mobile','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(167501,'deals-mobile','.p-wedding-registry-manage .wedding-date','font-size','20','','','.p-wedding-registry-manage'),(167502,'deals-mobile','.p-wedding-registry-search h1','font-size','22','4','','.p-wedding-registry-search'),(167503,'deals-mobile','.p-wedding-registry-search h1','font-size','22','3','','.p-wedding-registry-search'),(167504,'deals-mobile','.p-account-history .order_history_table h2','font-size','24','','','.p-account-history'),(167505,'deals-mobile','.p-account-history .order_history_table th','font-size','16','','','.p-account-history'),(167506,'deals-mobile','.p-wedding-registry-manage h1','font-size','22','3','','.p-wedding-registry-manage'),(167507,'deals-mobile','.p-wedding-registry-share h1','font-size','22','3','','.p-wedding-registry-share'),(167508,'deals-mobile','.p-account-address-book .btn-edit','font-size','16','4','','.p-account-address-book'),(167509,'deals-mobile','.b-compare .clear_all','font-size','16','4','','.b-compare'),(167510,'deals-mobile','.b-bottom .popup-heading','font-size','16','','','.b-bottom'),(167511,'deals-mobile','.b-compare .compare-head','font-size','22','','','.b-compare'),(167512,'deals-mobile','.w-chat .w-chat-box a','font-size','30','876,3','','.w-chat'),(167513,'deals-mobile','.w-quote .cart-box-link','font-size','30','872,3','','.w-quote'),(167514,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','0','','','.b-slick'),(167515,'deals-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(167516,'deals-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','font-size','28','','','.w-filters'),(167517,'deals-mobile','.w-list-type-1_3 .price .old','font-size','18','','','.w-list-type-1_3'),(167518,'deals-mobile','.w-list-type-1_3 .properties','font-size','13','','','.w-list-type-1_3'),(167519,'deals-mobile','.w-list-type-1_3 .products-model','font-size','13','','','.w-list-type-1_3'),(167520,'deals-mobile','.p-account-index .date_value strong','font-size','16','','','.p-account-index'),(167521,'deals-mobile','.p-account-index .date_value, .p-account-index .date_title','font-size','18','','','.p-account-index'),(167522,'deals-mobile','.w-tabs .tab-a','font-size','20','','','.w-tabs'),(167523,'deals-mobile','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(167524,'deals-mobile','.w-search .search','font-size','23','3','','.w-search'),(167525,'deals-mobile','.heading-4, h4','font-size','18','','',''),(167526,'deals-mobile','.p-account-trade-form .widget h3','font-size','24','','','.p-account-trade-form'),(167527,'deals-mobile','.p-quote-cart-index .cart-page .empty','font-size','24','','','.p-quote-cart-index'),(167528,'deals-mobile','.p-checkout-index .same-address','font-size','16','','','.p-checkout-index'),(167529,'deals-mobile','.p-shopping-cart-index .cart-page .empty','font-size','24','','','.p-shopping-cart-index'),(167530,'deals-mobile','.b-price-box .price-box .price-row.total','font-size','20','892','','.b-price-box'),(167531,'deals-mobile','.w-filters .head-filter-widget','font-size','24','','','.w-filters'),(167532,'deals-mobile','.p-account-index h1, .p-account-index .reviews-info h1','font-size','21','863','','.p-account-index'),(167533,'deals-mobile','.w-currencies .current','font-size','26','3','','.w-currencies'),(167534,'deals-mobile','.w-filters .filter-box-head','font-size','20','','','.w-filters'),(167535,'deals-mobile','.heading-4 .right-text, h4 .right-text','font-size','16','','',''),(167536,'deals-mobile','.w-compare-box-item .checkbox:checked + span:before','font-size','18','','','.w-compare-box-item'),(167537,'deals-mobile','.heading-3 .edit, h3 .edit','font-size','16','','',''),(167538,'deals-mobile','.p-reviews-info .review-info-reviewed_by, .review-info-date','font-size','14','','','.p-reviews-info'),(167539,'deals-mobile','.p-checkout-success .page-success','font-size','600','3','','.p-checkout-success'),(167540,'deals-mobile','.p-account-subscription-historyinfo .order_history_table th','font-size','16','','','.p-account-subscription-historyinfo'),(167541,'deals-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-size','24','','','.p-account-subscription-historyinfo'),(167542,'deals-mobile','.p-account-index .view_history','font-size','14','3','','.p-account-index'),(167543,'deals-mobile','.p-account-index .view_history','font-size','16','','','.p-account-index'),(167544,'deals-mobile','.p-account-index .view_link','font-size','18','4','','.p-account-index'),(167545,'deals-mobile','.p-checkout-success .page-success .text-1','font-size','80','3','','.p-checkout-success'),(167546,'deals-mobile','.p-checkout-success .page-success .text-1','font-size','60','','','.p-checkout-success'),(167547,'deals-mobile','.p-account-index .topAccount > li > div','font-size','42','3','','.p-account-index'),(167548,'deals-mobile','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(167549,'deals-mobile','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(167550,'deals-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(167551,'deals-mobile','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(167552,'deals-mobile','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(167553,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','font-size','14','','',''),(167554,'deals-mobile','.heading-3, h3','font-size','20','','',''),(167555,'deals-mobile','.p-checkout-success .page-success .text-2','font-size','34','','','.p-checkout-success'),(167556,'deals-mobile','.p-checkout-success .page-success .text-3','font-size','27','','','.p-checkout-success'),(167557,'deals-mobile','.p-account-history-info .historyTotal table tr:last-child td','font-size','24','','','.p-account-history-info'),(167558,'deals-mobile','.p-account-history-info .historyTotal table td','font-size','18','','','.p-account-history-info'),(167559,'deals-mobile','.p-account-history .not_fully_paid_td','font-size','30','','','.p-account-history'),(167560,'deals-mobile','.p-wedding-registry-share .invite-remove','font-size','20','','','.p-wedding-registry-share'),(167561,'deals-mobile','.w-sale .left-text-right','font-size','24','','','.w-sale'),(167562,'deals-mobile','.w-sale .ends','font-size','26','','','.w-sale'),(167563,'deals-mobile','.w-sale .left-text-left','font-size','24','','','.w-sale'),(167564,'deals-mobile','.w-sale .old','font-size','45','','','.w-sale'),(167565,'deals-mobile','.w-sale .special-price','font-size','70','','','.w-sale'),(167566,'deals-mobile','.w-text .customer-service','font-size','21','3','','.w-text'),(167567,'deals-mobile','.w-text .customer-service','font-size','13','','','.w-text'),(167568,'deals-mobile','.b-page-name .page-name','font-size','20','','','.b-page-name'),(167569,'deals-mobile','.w-text .customer-service b','font-size','18','','','.w-text'),(167570,'deals-mobile','.w-top-categories .categories h2','font-size','inherit','','','.w-top-categories'),(167571,'deals-mobile','.w-categories .categories h2','font-size','inherit','','','.w-categories'),(167572,'deals-mobile','.b-form .cart-popup .price','font-size','18','','','.b-form'),(167573,'deals-mobile','.b-quantity .qty-box .smaller','font-size','31','','','.b-quantity'),(167574,'deals-mobile','.b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(167575,'deals-mobile','.w-tabs .tab-a','font-size','16','864','','.w-tabs'),(167576,'deals-mobile','h1','font-size','26','864','',''),(167577,'deals-mobile','.b-fancybox .fancybox-nav span','font-size','34','','','.b-fancybox'),(167578,'deals-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','font-size','22','3','','.w-cart-discount-coupon'),(167579,'deals-mobile','.w-cart-discount-coupon .gift-code p','font-size','13','','','.w-cart-discount-coupon'),(167580,'deals-mobile','.w-filters .head-filter-widget > span','font-size','18','876','','.w-filters'),(167581,'deals-mobile','.w-cart .cart-total','font-size','1.2','','','.w-cart'),(167582,'deals-mobile','.p-account-index .date_value','font-size','18','','','.p-account-index'),(167583,'deals-mobile','.heading-2, h2','font-size','24','','',''),(167584,'deals-mobile','h1','font-size','32','','',''),(167585,'deals-mobile','.p-account-index .account_page h4','font-size','22','3','','.p-account-index'),(167586,'deals-mobile','.p-account-history-info .history_attr','font-size','14','','','.p-account-history-info'),(167587,'deals-mobile','.p-account-index .account_page h1','font-size','30','','','.p-account-index'),(167588,'deals-mobile','.p-account-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-history-info'),(167589,'deals-mobile','.b-form #payment_method .title','font-size','16','','','.b-form'),(167590,'deals-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(167591,'deals-mobile','.w-menu-mobile .menu-ico','font-size','23','','','.w-menu-mobile'),(167592,'deals-mobile','.w-cart .qty','font-size','0.6','4','','.w-cart'),(167593,'deals-mobile','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(167594,'deals-mobile','.w-cart-give-away .ga_qty','font-size','20','','','.w-cart-give-away'),(167595,'deals-mobile','.w-cart-give-away .ga_name','font-size','16','','','.w-cart-give-away'),(167596,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','font-size','28','3','','.w-list-type-2'),(167597,'deals-mobile','.w-list-type-2 .button-view a','font-size','16','','','.w-list-type-2'),(167598,'deals-mobile','.w-list-type-1_3 .title','font-size','16','','','.w-list-type-1_3'),(167599,'deals-mobile','.w-list-type-2 .properties','font-size','13','','','.w-list-type-2'),(167600,'deals-mobile','.w-list-type-2 .button-wishlist button','font-size','16','','','.w-list-type-2'),(167601,'deals-mobile','.p-wedding-registry-manage h1','font-size','22','4','','.p-wedding-registry-manage'),(167602,'deals-mobile','.price','font-size','24','','',''),(167603,'deals-mobile','.w-list-type-1_3 .sale','font-size','17','4','','.w-list-type-1_3'),(167604,'deals-mobile','.view-all .btn','font-size','0.8','4','',''),(167605,'deals-mobile','.w-list-type-1_3 .sale','font-size','19','3','','.w-list-type-1_3'),(167606,'deals-mobile','.w-list-type-2 .sale','font-size','17','4','','.w-list-type-2'),(167607,'deals-mobile','.p-wedding-registry-view h1','font-size','22','3','','.p-wedding-registry-view'),(167608,'deals-mobile','.p-wedding-registry-view h1','font-size','22','4','','.p-wedding-registry-view'),(167609,'deals-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','font-size','14','','','.p-wedding-registry-manage'),(167610,'deals-mobile','.w-list-type-2 .sale','font-size','19','3','','.w-list-type-2'),(167611,'deals-mobile','.p-wedding-registry-share h1','font-size','22','4','','.p-wedding-registry-share'),(167612,'deals-mobile','.btn','font-size','16','','',''),(167613,'deals-mobile','.heading-3 .right-text, h3 .right-text','font-size','16','','',''),(167614,'deals-mobile','.btn-2','font-size','20','','',''),(167615,'deals-mobile','.btn-3','font-size','20','','',''),(167616,'deals-mobile','.btn-1','font-size','16','','',''),(167617,'deals-mobile','.w-list-type-1_3 .price','font-size','24','','','.w-list-type-1_3'),(167618,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','font-size','28','3','','.w-list-type-1_3'),(167619,'deals-mobile','.w-list-type-1_3 .button-wishlist button','font-size','16','','','.w-list-type-1_3'),(167620,'deals-mobile','.w-list-type-1_3 .button-view a','font-size','16','','','.w-list-type-1_3'),(167621,'deals-mobile','.w-list-type-1_2 .sale','font-size','19','3','','.w-list-type-1_2'),(167622,'deals-mobile','.w-list-type-1_2 .sale','font-size','17','4','','.w-list-type-1_2'),(167623,'deals-mobile','.w-list-type-1_2 .title','font-size','16','','','.w-list-type-1_2'),(167624,'deals-mobile','.w-list-type-1_2 .products-model','font-size','13','','','.w-list-type-1_2'),(167625,'deals-mobile','.w-list-type-1_2 .price .old','font-size','18','','','.w-list-type-1_2'),(167626,'deals-mobile','.w-list-type-1_2 .price','font-size','24','','','.w-list-type-1_2'),(167627,'deals-mobile','.w-list-type-1_2 .properties','font-size','13','','','.w-list-type-1_2'),(167628,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','font-size','28','3','','.w-list-type-1_2'),(167629,'deals-mobile','.w-list-type-1 .sale','font-size','17','4','','.w-list-type-1'),(167630,'deals-mobile','.w-list-type-1_2 .button-wishlist button','font-size','16','','','.w-list-type-1_2'),(167631,'deals-mobile','.b-bottom .pop-up-close','font-size','25','','','.b-bottom'),(167632,'deals-mobile','.b-bottom .footerTitle','font-size','24','','','.b-bottom'),(167633,'deals-mobile','.w-list-type-1 .rating','font-size','12','','','.w-list-type-1'),(167634,'deals-mobile','.w-list-type-1 .title','font-size','16','','','.w-list-type-1'),(167635,'deals-mobile','.w-list-type-1 .products-model','font-size','13','','','.w-list-type-1'),(167636,'deals-mobile','.w-list-type-1_2 .button-view a','font-size','16','','','.w-list-type-1_2'),(167637,'deals-mobile','.w-list-type-1 .sale','font-size','19','3','','.w-list-type-1'),(167638,'deals-mobile','.w-list-type-1 .properties','font-size','13','','','.w-list-type-1'),(167639,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','font-size','28','3','','.w-list-type-1'),(167640,'deals-mobile','.heading-3 .edit, h3 .edit','font-size','14','4','',''),(167641,'deals-mobile','.heading-4 .edit, h4 .edit','font-size','16','','',''),(167642,'deals-mobile','.transit','font-size','14','','',''),(167643,'deals-mobile','.out-stock','font-size','14','','',''),(167644,'deals-mobile','.w-list-type-1 .button-wishlist button','font-size','16','','','.w-list-type-1'),(167645,'deals-mobile','.in-stock','font-size','14','','',''),(167646,'deals-mobile','.w-filters .mobileCollapse','font-size','20','4','','.w-filters'),(167647,'deals-mobile','.w-filters .view_more','font-size','16','4','','.w-filters'),(167648,'deals-mobile','.w-list-type-1 .button-view a','font-size','16','','','.w-list-type-1'),(167649,'deals-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-size','28','','','.w-filters'),(167650,'deals-mobile','.w-languages .current','font-size','26','3','','.w-languages'),(167651,'deals-mobile','.w-top-categories .name','font-size','18','','','.w-top-categories'),(167652,'deals-mobile','.w-reviews .heading-3','font-size','37','3','','.w-reviews'),(167653,'deals-mobile','.w-quote .cart-box-link','font-size','1.5','3','','.w-quote'),(167654,'deals-mobile','.w-reviews .rating','font-size','22','','','.w-reviews'),(167655,'deals-mobile','.w-search .button-search','font-size','23','3','','.w-search'),(167656,'deals-mobile','.w-reviews .reviews-list span','font-size','22','','','.w-reviews'),(167657,'deals-mobile','.w-reviews .reviews-list .date','font-size','14','','','.w-reviews'),(167658,'deals-mobile','.w-search .search-input','font-size','14','','','.w-search'),(167659,'deals-mobile','.b-form .middle-form .middle-rating span','font-size','26','','','.b-form'),(167660,'deals-mobile','.b-form .required-message','font-size','14','','','.b-form'),(167661,'deals-mobile','.b-info .info','font-size','30','3','','.b-info'),(167662,'deals-mobile','.p-account-address-book .address_book h2','font-size','18','','','.p-account-address-book'),(167663,'deals-mobile','.p-account-address-book .leftMes div','font-size','18','','','.p-account-address-book'),(167664,'deals-mobile','.p-account-address-book .address_book .btn-edit, .p-account-address-book .address_book .btn-delete','font-size','16','4','','.p-account-address-book'),(167665,'deals-mobile','.b-info .info strong','font-size','18','','','.b-info'),(167666,'deals-mobile','.b-info-popup .info-popup','font-size','30','3','','.b-info-popup'),(167667,'deals-mobile','.b-products-listing .btn-preloader','font-size','24','3','','.b-products-listing'),(167668,'deals-mobile','.b-products-listing .loader','font-size','30','4','','.b-products-listing'),(167669,'deals-mobile','.b-products-listing .products-listing .attribute-qty-block','font-size','14','','','.b-products-listing'),(167670,'deals-mobile','.b-products-listing .products-listing .bonusPoints','font-size','13','','','.b-products-listing'),(167671,'deals-mobile','.b-products-listing .products-listing .btn-buy','font-size','20','3','','.b-products-listing'),(167672,'deals-mobile','.b-products-listing .products-listing .model','font-size','14','','','.b-products-listing'),(167673,'deals-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','font-size','20','','','.b-products-listing'),(167674,'deals-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-size','20','','','.b-products-listing'),(167675,'deals-mobile','.b-products-listing .products-listing h2','font-size','inherit','','','.b-products-listing'),(167676,'deals-mobile','.b-products-listing .promos-info .promo-name','font-size','14','','','.b-products-listing'),(167677,'deals-mobile','.b-products-listing .wedding-registry-count','font-size','14','','','.b-products-listing'),(167678,'deals-mobile','.b-products-listing .products-listing .out-stock','font-size','11','','','.b-products-listing'),(167679,'deals-mobile','.b-products-listing .products-listing .name','font-size','14','','','.b-products-listing'),(167680,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.b-data-table'),(167681,'deals-mobile','.b-data-table table.dataTable thead td','font-size','16','','','.b-data-table'),(167682,'deals-mobile','.b-email .qty','font-size','14','','','.b-email'),(167683,'deals-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(167684,'deals-mobile','.b-email .model','font-size','14','','','.b-email'),(167685,'deals-mobile','.b-email .qty','font-size','14','','','.b-email'),(167686,'deals-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(167687,'deals-mobile','.b-email .model','font-size','14','','','.b-email'),(167688,'deals-mobile','.b-email .name','font-size','14','','','.b-email'),(167689,'deals-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(167690,'deals-mobile','.b-email .name','font-size','14','','','.b-email'),(167691,'deals-mobile','.b-email .model','font-size','14','','','.b-email'),(167692,'deals-mobile','.b-email .model','font-size','14','','','.b-email'),(167693,'deals-mobile','.b-email .name','font-size','14','','','.b-email'),(167694,'deals-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(167695,'deals-mobile','.b-email .qty','font-size','14','','','.b-email'),(167696,'deals-mobile','.b-email .qty','font-size','14','','','.b-email'),(167697,'deals-mobile','.b-email .qty','font-size','14','','','.b-email'),(167698,'deals-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(167699,'deals-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(167700,'deals-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(167701,'deals-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(167702,'deals-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(167703,'deals-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(167704,'deals-mobile','.b-email .price','font-size','14','','','.b-email'),(167705,'deals-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(167706,'deals-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(167707,'deals-mobile','.b-email .name','font-size','14','','','.b-email'),(167708,'deals-mobile','.b-email .price','font-size','14','','','.b-email'),(167709,'deals-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(167710,'deals-mobile','.b-email .qty','font-size','14','','','.b-email'),(167711,'deals-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(167712,'deals-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(167713,'deals-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(167714,'deals-mobile','.b-email .price','font-size','14','','','.b-email'),(167715,'deals-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(167716,'deals-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(167717,'deals-mobile','.b-email .price','font-size','14','','','.b-email'),(167718,'deals-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(167719,'deals-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(167720,'deals-mobile','.b-email .price','font-size','14','','','.b-email'),(167721,'deals-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(167722,'deals-mobile','.b-email .price','font-size','14','','','.b-email'),(167723,'deals-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(167724,'deals-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(167725,'deals-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(167726,'deals-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(167727,'deals-mobile','.b-email .model','font-size','14','','','.b-email'),(167728,'deals-mobile','.b-email .name','font-size','14','','','.b-email'),(167729,'deals-mobile','.b-email .name','font-size','14','','','.b-email'),(167730,'deals-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(167731,'deals-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(167732,'deals-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(167733,'deals-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(167734,'deals-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(167735,'deals-mobile','.b-email .model','font-size','14','','','.b-email'),(167736,'deals-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(167737,'deals-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(167738,'deals-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(167739,'deals-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(167740,'deals-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(167741,'deals-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(167742,'deals-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(167743,'deals-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(167744,'deals-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(167745,'deals-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(167746,'deals-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(167747,'deals-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(167748,'deals-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(167749,'deals-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(167750,'deals-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(167751,'deals-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(167752,'deals-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(167753,'deals-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(167754,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-size','inherit','','','.b-h-inline'),(167755,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(167756,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(167757,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(167758,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(167759,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(167760,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(167761,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(167762,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(167763,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(167764,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev63_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(167765,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','font-size','16','','','.b-menu-style-1'),(167766,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','font-size','18','','','.b-menu-style-1'),(167767,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','font-size','14','','','.b-menu-style-2'),(167768,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','font-size','14','','','.b-menu-style-2'),(167769,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','font-size','26','','','.b-menu-style-2'),(167770,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','font-size','20','3','','.b-menu-style-2'),(167771,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-size','20','3','','.b-menu-style-2'),(167772,'deals-mobile','.b-messages .content-messages .heading-2','font-size','26','','','.b-messages'),(167773,'deals-mobile','.b-messages span.starred::before','font-size','16','','','.b-messages'),(167774,'deals-mobile','.b-messages .messBtnMenuStarred','font-size','22','3','','.b-messages'),(167775,'deals-mobile','.b-messages .messBtnMenuDelete','font-size','22','3','','.b-messages'),(167776,'deals-mobile','.b-messages .messBtnMenuUnread','font-size','22','3','','.b-messages'),(167777,'deals-mobile','.b-messages .messMenuButton span','font-size','14','','','.b-messages'),(167778,'deals-mobile','.b-messages .content_management_attach button','font-size','14','','','.b-messages'),(167779,'deals-mobile','.b-messages .content_management_attach','font-size','14','','','.b-messages'),(167780,'deals-mobile','.b-messages .content_management_attach span','font-size','16','','','.b-messages'),(167781,'deals-mobile','.b-messages .select2-search-choice-close','font-size','11','3','','.b-messages'),(167782,'deals-mobile','.b-preloader .preloader','font-size','40','3','','.b-preloader'),(167783,'deals-mobile','.b-select-suggest .select2-search-choice-close','font-size','1','','','.b-select-suggest'),(167784,'deals-mobile','.b-select-suggest .select2-search input','font-size','1','','','.b-select-suggest'),(167785,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','font-size','1','','','.b-select-suggest'),(167786,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-size','100','','','.b-select-suggest'),(167787,'deals-mobile','.b-sub-totals .historyTotal table td','font-size','18','','','.b-sub-totals'),(167788,'deals-mobile','.b-sub-totals .historyTotal table tr:last-child td','font-size','24','','','.b-sub-totals'),(167789,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(167790,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(167791,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(167792,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(167793,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(167794,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(167795,'deals-mobile','.b-trade-approval .middle-form label','font-size','16','','','.b-trade-approval'),(167796,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','font-size','14','','','.b-trade-approval'),(167797,'deals-mobile','.b-upload-file .snapshot','font-size','18','','','.b-upload-file'),(167798,'deals-mobile','.b-warehouses-popup .warehouses-popup .heading','font-size','18','','','.b-warehouses-popup'),(167799,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','font-size','14','','','.b-warehouses-popup'),(167800,'deals-mobile','.b-warehouses-popup a.warehouses-popup-link','font-size','14','','','.b-warehouses-popup'),(167801,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-name','font-size','16','','','.b-warehouses-popup'),(167802,'deals-mobile','.batchPr .w-batch-products .products-listing .name a','font-size','16','','','.batchPr'),(167803,'deals-mobile','.batchPr .w-batch-products .products-listing .price','font-size','16','','','.batchPr'),(167804,'deals-mobile','.batchPr .btn-batch-remove','font-size','17','3','','.batchPr'),(167805,'deals-mobile','.batchPr .batchSelect .checkbox','font-size','18','','','.batchPr'),(167806,'deals-mobile','.batchPr .batchSelect','font-size','12','','','.batchPr'),(167807,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .name a, .batchPr .w-batch-selected-products .products-listing .price','font-size','14','','','.batchPr'),(167808,'deals-mobile','.batchPr .checkbox input:checked + span:before','font-size','18','','','.batchPr'),(167809,'deals-mobile','.batchPr .batch-selected-products-empty','font-size','20','','','.batchPr'),(167810,'deals-mobile','.batchPr .checkbox input:not(checked) + span:before','font-size','32','','','.batchPr'),(167811,'deals-mobile','.batchPr .batch-selected-products-total','font-size','20','','','.batchPr'),(167812,'deals-mobile','.batchPr .btn-batch-remove','font-size','0','','','.batchPr'),(167813,'deals-mobile','.bell-ico .heading-2','font-size','32','3','','.bell-ico'),(167814,'deals-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(167815,'deals-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(167816,'deals-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(167817,'deals-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(167818,'deals-mobile','.heading-ordered-items .heading-4','font-size','28','3','','.heading-ordered-items'),(167819,'deals-mobile','.heading-saved-lists .heading-4','font-size','28','3','','.heading-saved-lists'),(167820,'deals-mobile','.heading-settings .heading-4','font-size','28','3','','.heading-settings'),(167821,'deals-mobile','.p-account-samples-history .order_history_table th','font-size','16','','','.p-account-samples-history'),(167822,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','font-size','16','','','.p-account-samples-history'),(167823,'deals-mobile','.p-account-samples-history .not_fully_paid_td','font-size','30','','','.p-account-samples-history'),(167824,'deals-mobile','.p-account-samples-history .order_history_table th','font-size','16','','','.p-account-samples-history'),(167825,'deals-mobile','.p-account-samples-history .order_history_table h2','font-size','24','','','.p-account-samples-history'),(167826,'deals-mobile','.p-account-samples-history .view_link','font-size','18','4','','.p-account-samples-history'),(167827,'deals-mobile','.p-account-samples-history .view_link','font-size','18','4','','.p-account-samples-history'),(167828,'deals-mobile','.p-account-samples-history .not_fully_paid_td','font-size','30','','','.p-account-samples-history'),(167829,'deals-mobile','.p-account-samples-history .view_link','font-size','18','4','','.p-account-samples-history'),(167830,'deals-mobile','.p-account-samples-history .view_link','font-size','18','4','','.p-account-samples-history'),(167831,'deals-mobile','.p-account-samples-history .not_fully_paid_td','font-size','30','','','.p-account-samples-history'),(167832,'deals-mobile','.p-account-samples-history .order_history_table th','font-size','16','','','.p-account-samples-history'),(167833,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','font-size','16','','','.p-account-samples-history'),(167834,'deals-mobile','.p-account-samples-history .not_fully_paid_td','font-size','30','','','.p-account-samples-history'),(167835,'deals-mobile','.p-account-samples-history .order_history_table h2','font-size','24','','','.p-account-samples-history'),(167836,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','font-size','16','','','.p-account-samples-history'),(167837,'deals-mobile','.p-account-samples-history .not_fully_paid_td','font-size','30','','','.p-account-samples-history'),(167838,'deals-mobile','.p-account-samples-history .order_history_table h2','font-size','24','','','.p-account-samples-history'),(167839,'deals-mobile','.p-account-samples-history .order_history_table h2','font-size','24','','','.p-account-samples-history'),(167840,'deals-mobile','.p-account-samples-history .view_link','font-size','18','4','','.p-account-samples-history'),(167841,'deals-mobile','.p-account-samples-history .order_history_table th','font-size','16','','','.p-account-samples-history'),(167842,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','font-size','16','','','.p-account-samples-history'),(167843,'deals-mobile','.p-account-samples-history .not_fully_paid_td','font-size','30','','','.p-account-samples-history'),(167844,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','font-size','16','','','.p-account-samples-history'),(167845,'deals-mobile','.p-account-samples-history .order_history_table h2','font-size','24','','','.p-account-samples-history'),(167846,'deals-mobile','.p-account-samples-history .view_link','font-size','18','4','','.p-account-samples-history'),(167847,'deals-mobile','.p-account-samples-history .order_history_table th','font-size','16','','','.p-account-samples-history'),(167848,'deals-mobile','.p-account-samples-history .order_history_table h2','font-size','24','','','.p-account-samples-history'),(167849,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','font-size','16','','','.p-account-samples-history'),(167850,'deals-mobile','.p-account-samples-history .order_history_table th','font-size','16','','','.p-account-samples-history'),(167851,'deals-mobile','.p-account-samples-history-info .history_attr','font-size','14','','','.p-account-samples-history-info'),(167852,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-size','18','','','.p-account-samples-history-info'),(167853,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','22','3','','.p-account-samples-history-info'),(167854,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','font-size','30','','','.p-account-samples-history-info'),(167855,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-samples-history-info'),(167856,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','font-size','30','','','.p-account-samples-history-info'),(167857,'deals-mobile','.p-account-samples-history-info .trackings-nambers-label','font-size','20','','','.p-account-samples-history-info'),(167858,'deals-mobile','.p-account-samples-history-info .history_attr','font-size','14','','','.p-account-samples-history-info'),(167859,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','22','3','','.p-account-samples-history-info'),(167860,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-size','18','','','.p-account-samples-history-info'),(167861,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-samples-history-info'),(167862,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','18','','','.p-account-samples-history-info'),(167863,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','18','','','.p-account-samples-history-info'),(167864,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-size','18','','','.p-account-samples-history-info'),(167865,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','22','3','','.p-account-samples-history-info'),(167866,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','18','','','.p-account-samples-history-info'),(167867,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-samples-history-info'),(167868,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-samples-history-info'),(167869,'deals-mobile','.p-account-samples-history-info .history_attr','font-size','14','','','.p-account-samples-history-info'),(167870,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','18','','','.p-account-samples-history-info'),(167871,'deals-mobile','.p-account-samples-history-info .history_attr','font-size','14','','','.p-account-samples-history-info'),(167872,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','font-size','30','','','.p-account-samples-history-info'),(167873,'deals-mobile','.p-account-samples-history-info .trackings-nambers-label','font-size','20','','','.p-account-samples-history-info'),(167874,'deals-mobile','.p-account-samples-history-info .trackings-nambers-label','font-size','20','','','.p-account-samples-history-info'),(167875,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','font-size','30','','','.p-account-samples-history-info'),(167876,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','22','3','','.p-account-samples-history-info'),(167877,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-samples-history-info'),(167878,'deals-mobile','.p-account-samples-history-info .trackings-nambers-label','font-size','20','','','.p-account-samples-history-info'),(167879,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','font-size','30','','','.p-account-samples-history-info'),(167880,'deals-mobile','.p-account-samples-history-info .history_attr','font-size','14','','','.p-account-samples-history-info'),(167881,'deals-mobile','.p-account-samples-history-info .trackings-nambers-label','font-size','20','','','.p-account-samples-history-info'),(167882,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','font-size','30','','','.p-account-samples-history-info'),(167883,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','18','','','.p-account-samples-history-info'),(167884,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.p-account-samples-history-info'),(167885,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','22','3','','.p-account-samples-history-info'),(167886,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','18','','','.p-account-samples-history-info'),(167887,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-size','18','','','.p-account-samples-history-info'),(167888,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-size','22','3','','.p-account-samples-history-info'),(167889,'deals-mobile','.p-account-samples-history-info .history_attr','font-size','14','','','.p-account-samples-history-info'),(167890,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-size','18','','','.p-account-samples-history-info'),(167891,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-size','18','','','.p-account-samples-history-info'),(167892,'deals-mobile','.p-account-samples-history-info .trackings-nambers-label','font-size','20','','','.p-account-samples-history-info'),(167893,'deals-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(167894,'deals-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(167895,'deals-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(167896,'deals-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(167897,'deals-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(167898,'deals-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(167899,'deals-mobile','.p-catalog-product .pn-direction','font-size','14','','','.p-catalog-product'),(167900,'deals-mobile','.p-catalog-product .pn-image','font-size','14','3','','.p-catalog-product'),(167901,'deals-mobile','.p-catalog-product .pn-name','font-size','14','','','.p-catalog-product'),(167902,'deals-mobile','.p-checkout-login .password-forgotten-link','font-size','14','','','.p-checkout-login'),(167903,'deals-mobile','.p-payer-order-confirmation .ship-ico','font-size','30','3','','.p-payer-order-confirmation'),(167904,'deals-mobile','.p-payer-order-confirmation .comment-ico','font-size','30','3','','.p-payer-order-confirmation'),(167905,'deals-mobile','.p-payer-order-confirmation .order-ico','font-size','36','3','','.p-payer-order-confirmation'),(167906,'deals-mobile','.p-payer-order-confirmation .pay-ico','font-size','30','3','','.p-payer-order-confirmation'),(167907,'deals-mobile','.p-payer-order-confirmation .discount-ico','font-size','30','3','','.p-payer-order-confirmation'),(167908,'deals-mobile','.p-payer-order-pay .ship-ico','font-size','30','3','','.p-payer-order-pay'),(167909,'deals-mobile','.p-payer-order-pay .pay-ico','font-size','30','3','','.p-payer-order-pay'),(167910,'deals-mobile','.p-payer-order-pay .discount-ico','font-size','30','3','','.p-payer-order-pay'),(167911,'deals-mobile','.p-payer-order-pay .comment-ico','font-size','30','3','','.p-payer-order-pay'),(167912,'deals-mobile','.p-payer-order-pay .order-ico','font-size','36','3','','.p-payer-order-pay'),(167913,'deals-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-size','14','','','.p-quick-order-index'),(167914,'deals-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','font-size','13','','','.p-quick-order-index'),(167915,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.next','font-size','0','','','.p-quick-order-index'),(167916,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.previous','font-size','0','','','.p-quick-order-index'),(167917,'deals-mobile','.p-quick-order-index .dataTables_info','font-size','14','','','.p-quick-order-index'),(167918,'deals-mobile','.p-quick-order-index .value','font-size','20','','','.p-quick-order-index'),(167919,'deals-mobile','.p-quick-order-index .in-stock, .p-quick-order-index .out-stock','font-size','12','','','.p-quick-order-index'),(167920,'deals-mobile','.p-quick-order-index .stock','font-size','12','','','.p-quick-order-index'),(167921,'deals-mobile','.p-quick-order-index .paginate_button.previous','font-size','20','3','','.p-quick-order-index'),(167922,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.p-quick-order-index'),(167923,'deals-mobile','.p-quick-order-index .paginate_button.next','font-size','20','3','','.p-quick-order-index'),(167924,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(167925,'deals-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(167926,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(167927,'deals-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(167928,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(167929,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(167930,'deals-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(167931,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(167932,'deals-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(167933,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(167934,'deals-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(167935,'deals-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(167936,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(167937,'deals-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(167938,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(167939,'deals-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(167940,'deals-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(167941,'deals-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(167942,'deals-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(167943,'deals-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(167944,'deals-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(167945,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(167946,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(167947,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(167948,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(167949,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','','','.p-quote-checkout-success'),(167950,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(167951,'deals-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(167952,'deals-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(167953,'deals-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','','','.p-quote-checkout-success'),(167954,'deals-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(167955,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(167956,'deals-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(167957,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(167958,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(167959,'deals-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(167960,'deals-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(167961,'deals-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(167962,'deals-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(167963,'deals-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(167964,'deals-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(167965,'deals-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(167966,'deals-mobile','.p-sample-checkout-success .page-success .text-1','font-size','80','3','','.p-sample-checkout-success'),(167967,'deals-mobile','.p-sample-checkout-success .page-success .text-3','font-size','27','','','.p-sample-checkout-success'),(167968,'deals-mobile','.p-sample-checkout-success .page-success .text-2','font-size','34','','','.p-sample-checkout-success'),(167969,'deals-mobile','.p-sample-checkout-success .page-success .text-2','font-size','30','','','.p-sample-checkout-success'),(167970,'deals-mobile','.p-sample-checkout-success .page-success .text-1','font-size','60','','','.p-sample-checkout-success'),(167971,'deals-mobile','.p-sample-checkout-success .page-success .text-1','font-size','40','','','.p-sample-checkout-success'),(167972,'deals-mobile','.savings-ico .heading-2','font-size','32','3','','.savings-ico'),(167973,'deals-mobile','.shipping-ico .heading-2','font-size','32','3','','.shipping-ico'),(167974,'deals-mobile','.shipping-ico .heading-2','font-size','32','3','','.shipping-ico'),(167975,'deals-mobile','.shipping-ico .heading-2','font-size','32','3','','.shipping-ico'),(167976,'deals-mobile','.w-account-address-book .address-buttons','font-size','14','','','.w-account-address-book'),(167977,'deals-mobile','.w-account-address-book .add_item a','font-size','25','','','.w-account-address-book'),(167978,'deals-mobile','.w-account-addresses-list .addsess-suggestion-item','font-size','14','','','.w-account-addresses-list'),(167979,'deals-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(167980,'deals-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(167981,'deals-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(167982,'deals-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(167983,'deals-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(167984,'deals-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(167985,'deals-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(167986,'deals-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(167987,'deals-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(167988,'deals-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(167989,'deals-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(167990,'deals-mobile','.w-account-personal-catalog .list-switcher a','font-size','20','','','.w-account-personal-catalog'),(167991,'deals-mobile','.w-blog-widget-categories-list a','font-size','14','','','.w-blog-widget-categories-list'),(167992,'deals-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','font-size','15','','','.w-blog-widget-most-popular-posts'),(167993,'deals-mobile','.w-blog-widget-most-popular-posts a','font-size','14','','','.w-blog-widget-most-popular-posts'),(167994,'deals-mobile','.w-blog-widget-post-comments-count span','font-size','14','3','','.w-blog-widget-post-comments-count'),(167995,'deals-mobile','.w-blog-widget-post-date ','font-size','14','','','.w-blog-widget-post-date'),(167996,'deals-mobile','.w-blog-widget-post-linked-products .heading-2','font-size','22','','','.w-blog-widget-post-linked-products'),(167997,'deals-mobile','.w-blog-widget-post-listing .post_date','font-size','14','','','.w-blog-widget-post-listing'),(167998,'deals-mobile','.w-blog-widget-post-listing .post_name a','font-size','22','','','.w-blog-widget-post-listing'),(167999,'deals-mobile','.w-blog-widget-post-share .facebook-btn','font-size','22','3','','.w-blog-widget-post-share'),(168000,'deals-mobile','.w-blog-widget-post-share .mailto','font-size','26','3','','.w-blog-widget-post-share'),(168001,'deals-mobile','.w-blog-widget-post-share .printto','font-size','26','3','','.w-blog-widget-post-share'),(168002,'deals-mobile','.w-blog-widget-post-share .twitter-btn','font-size','22','3','','.w-blog-widget-post-share'),(168003,'deals-mobile','.w-blog-widget-post-share .pinterest-btn','font-size','22','3','','.w-blog-widget-post-share'),(168004,'deals-mobile','.w-blog-widget-post-title h1','font-size','32','','','.w-blog-widget-post-title'),(168005,'deals-mobile','.w-blog-widget-post-title h1','font-size','24','','','.w-blog-widget-post-title'),(168006,'deals-mobile','.w-blog-widget-post-title ','font-size','24','','','.w-blog-widget-post-title'),(168007,'deals-mobile','.w-blog-widget-related-posts .post_content a','font-size','20','','','.w-blog-widget-related-posts'),(168008,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','font-size','18','3','','.w-blog-widget-related-posts'),(168009,'deals-mobile','.w-blog-widget-related-posts-by-category .post_content a','font-size','18','','','.w-blog-widget-related-posts-by-category'),(168010,'deals-mobile','.w-blog-widget-tag-cloud a','font-size','12','','','.w-blog-widget-tag-cloud'),(168011,'deals-mobile','.w-cart-bonus-points .text','font-size','14','','','.w-cart-bonus-points'),(168012,'deals-mobile','.w-cart-bonus-points .title','font-size','14','3','','.w-cart-bonus-points'),(168013,'deals-mobile','.w-cart-bonus-points .btn-remove','font-size','12','','','.w-cart-bonus-points'),(168014,'deals-mobile','.w-cart-cart-tabs .w-tabs .tab-a','font-size','12','','','.w-cart-cart-tabs'),(168015,'deals-mobile','.w-cart-compare .attributes-label','font-size','14','','','.w-cart-compare'),(168016,'deals-mobile','.w-cart-compare .product-actions .dropdown-toggle','font-size','18','3','','.w-cart-compare'),(168017,'deals-mobile','.w-cart-compare .js-cart_totals_container','font-size','14','','','.w-cart-compare'),(168018,'deals-mobile','.w-cart-compare .cart-name a','font-size','17','','','.w-cart-compare'),(168019,'deals-mobile','.w-cart-compare .product-actions','font-size','12','','','.w-cart-compare'),(168020,'deals-mobile','.w-cart-compare .delete-cart','font-size','12','','','.w-cart-compare'),(168021,'deals-mobile','.w-cart-compare .js-cart_totals_container b','font-size','16','','','.w-cart-compare'),(168022,'deals-mobile','.w-cart-compare .atr-col','font-size','20','3','','.w-cart-compare'),(168023,'deals-mobile','.w-cart-compare .attributes-cell','font-size','14','','','.w-cart-compare'),(168024,'deals-mobile','.w-cart-compare .dropdown li','font-size','14','','','.w-cart-compare'),(168025,'deals-mobile','.w-cart-compare .product .name a','font-size','14','','','.w-cart-compare'),(168026,'deals-mobile','.w-cart-compare .price-label','font-size','14','','','.w-cart-compare'),(168027,'deals-mobile','.w-cart-compare .price-cell','font-size','18','','','.w-cart-compare'),(168028,'deals-mobile','.w-cart-credit-amount .text','font-size','14','','','.w-cart-credit-amount'),(168029,'deals-mobile','.w-cart-credit-amount .btn-remove','font-size','12','','','.w-cart-credit-amount'),(168030,'deals-mobile','.w-catalog-compare .checkbox input:checked + span:before','font-size','24','','','.w-catalog-compare'),(168031,'deals-mobile','.w-catalog-compare .model','font-size','14','','','.w-catalog-compare'),(168032,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-size','26','3','','.w-catalog-compare'),(168033,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','font-size','0','','','.w-catalog-compare'),(168034,'deals-mobile','.w-catalog-compare .item .compare','font-size','0','','','.w-catalog-compare'),(168035,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','font-size','15','','','.w-catalog-compare'),(168036,'deals-mobile','.w-catalog-compare .name','font-size','12','','','.w-catalog-compare'),(168037,'deals-mobile','.w-catalog-paging .next','font-size','20','3','','.w-catalog-paging'),(168038,'deals-mobile','.w-catalog-paging .prev','font-size','20','3','','.w-catalog-paging'),(168039,'deals-mobile','.w-checkout-bonus-points .btn-remove','font-size','12','','','.w-checkout-bonus-points'),(168040,'deals-mobile','.w-checkout-create-account .account-benefits','font-size','0.8','','','.w-checkout-create-account'),(168041,'deals-mobile','.w-checkout-create-account .account-benefits strong','font-size','18','3','','.w-checkout-create-account'),(168042,'deals-mobile','.w-checkout-credit-amount .btn-remove','font-size','12','','','.w-checkout-credit-amount'),(168043,'deals-mobile','.w-checkout-shipping-choice span','font-size','14','','','.w-checkout-shipping-choice'),(168044,'deals-mobile','.w-checkout-terms .terms-box','font-size','13','','','.w-checkout-terms'),(168045,'deals-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-size','14','','','.w-communication-new-topic'),(168046,'deals-mobile','.w-communication-new-topic td.date-purchased','font-size','14','','','.w-communication-new-topic'),(168047,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','font-size','31','','','.w-communication-new-topic'),(168048,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','font-size','31','','','.w-communication-new-topic'),(168049,'deals-mobile','.w-communication-post .communication-post-attach','font-size','14','','','.w-communication-post'),(168050,'deals-mobile','.w-communication-post .communication-post-date','font-size','14','','','.w-communication-post'),(168051,'deals-mobile','.w-coupons-and-vauchers-checkout .btn-remove','font-size','12','','','.w-coupons-and-vauchers-checkout'),(168052,'deals-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-size','40','','','.w-delivery-day'),(168053,'deals-mobile','.w-delivery-day .ends','font-size','26','','','.w-delivery-day'),(168054,'deals-mobile','.w-delivery-day .left-text-left','font-size','24','','','.w-delivery-day'),(168055,'deals-mobile','.w-delivery-day .left-text-right','font-size','24','','','.w-delivery-day'),(168056,'deals-mobile','.w-delivery-day .title','font-size','18','','','.w-delivery-day'),(168057,'deals-mobile','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-size','24','','','.w-multi-cart-cart-switcher'),(168058,'deals-mobile','.w-personal-gift-status-bar .end-label','font-size','14','','','.w-personal-gift-status-bar'),(168059,'deals-mobile','.w-personal-gift-status-bar .start-label','font-size','14','','','.w-personal-gift-status-bar'),(168060,'deals-mobile','.w-personal-gift-status-bar .inform','font-size','24','4','','.w-personal-gift-status-bar'),(168061,'deals-mobile','.w-personal-gift-status-bar .end-date','font-size','22','3','','.w-personal-gift-status-bar'),(168062,'deals-mobile','.w-personal-gift-status-bar .inform','font-size','14','','','.w-personal-gift-status-bar'),(168063,'deals-mobile','.w-personal-gift-status-bar .end-date','font-size','14','','','.w-personal-gift-status-bar'),(168064,'deals-mobile','.w-product-available-in-warehouses .heading','font-size','18','','','.w-product-available-in-warehouses'),(168065,'deals-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(168066,'deals-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(168067,'deals-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(168068,'deals-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(168069,'deals-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(168070,'deals-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(168071,'deals-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(168072,'deals-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(168073,'deals-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(168074,'deals-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(168075,'deals-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(168076,'deals-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(168077,'deals-mobile','.w-product-customers-activity .customers-activity','font-size','16','','','.w-product-customers-activity'),(168078,'deals-mobile','.w-promotions .prom-multi-discount .promo-group','font-size','16','','','.w-promotions'),(168079,'deals-mobile','.w-promotions .nextdiscount .item-holder .name','font-size','14','','','.w-promotions'),(168080,'deals-mobile','.w-promotions .prom-multi-discount .heading','font-size','26','','','.w-promotions'),(168081,'deals-mobile','.w-promotions .nextdiscount .heading','font-size','18','3','','.w-promotions'),(168082,'deals-mobile','.w-promotions .nextdiscount .heading','font-size','26','','','.w-promotions'),(168083,'deals-mobile','.w-promotions .promo-cart-discount .item a','font-size','14','','','.w-promotions'),(168084,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','font-size','13','','','.w-promotions'),(168085,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','font-size','16','','','.w-promotions'),(168086,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','font-size','13','','','.w-promotions'),(168087,'deals-mobile','.w-promotions .promo-salemaker .content a','font-size','14','','','.w-promotions'),(168088,'deals-mobile','.w-promotions .promo-item','font-size','24','','','.w-promotions'),(168089,'deals-mobile','.w-promotions .promo-salemaker .discount','font-size','13','','','.w-promotions'),(168090,'deals-mobile','.w-promotions .heading-3','font-size','48','','','.w-promotions'),(168091,'deals-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','font-size','14','','','.w-promotions'),(168092,'deals-mobile','.w-promotions .nextdiscount .promo-for-each','font-size','14','','','.w-promotions'),(168093,'deals-mobile','.w-quote-products .empty','font-size','24','','','.w-quote-products'),(168094,'deals-mobile','.w-reviews-content .rating','font-size','18','','','.w-reviews-content'),(168095,'deals-mobile','.w-reviews-content .date','font-size','13','','','.w-reviews-content'),(168096,'deals-mobile','.w-social-links a','font-size','26','','','.w-social-links'),(168097,'deals-mobile','.w-social-links a','font-size','30','','','.w-social-links'),(168098,'deals-mobile','.w-taxable .bootstrap-switch .bootstrap-switch-label','font-size','0','','','.w-taxable'),(168099,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-size','20','','','.w-upload-customer-id-upload-customer-id-form'),(168100,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-template','font-size','18','','','.w-upload-customer-id-upload-customer-id-form'),(168101,'deals-mobile','.w-wedding-registry-widgets-products .remove','font-size','24','','','.w-wedding-registry-widgets-products'),(168102,'deals-mobile','.b-rating #stars-default .glyphicon','font-style','normal','','','.b-rating'),(168103,'deals-mobile','.b-select-suggest .select2-results li em','font-style','normal','','','.b-select-suggest'),(168104,'deals-mobile','.w-bestsellers .counter','font-weight','600','','','.w-bestsellers'),(168105,'deals-mobile','.w-bestsellers .heading-3','font-weight','400','3','','.w-bestsellers'),(168106,'deals-mobile','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(168107,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(168108,'deals-mobile','.w-sale .left-count-hours','font-weight','600','','','.w-sale'),(168109,'deals-mobile','.w-sale .left-count-days','font-weight','600','','','.w-sale'),(168110,'deals-mobile','.w-sale .left-text-right','font-weight','600','','','.w-sale'),(168111,'deals-mobile','.w-sale .special-price','font-weight','600','','','.w-sale'),(168112,'deals-mobile','.w-list-type-2_2 .sale','font-weight','600','4','','.w-list-type-2_2'),(168113,'deals-mobile','.w-list-type-2_2 .title','font-weight','700','','','.w-list-type-2_2'),(168114,'deals-mobile','.w-sale .name','font-weight','bold','','','.w-sale'),(168115,'deals-mobile','.w-menu-slider > ul > li > ul > li > a','font-weight','700','','','.w-menu-slider'),(168116,'deals-mobile','.w-product-sale-ends .left-count-days','font-weight','600','','','.w-product-sale-ends'),(168117,'deals-mobile','.w-product-sale-ends .ends-date','font-weight','600','','','.w-product-sale-ends'),(168118,'deals-mobile','.w-product-sale-ends .left-count-hours','font-weight','600','','','.w-product-sale-ends'),(168119,'deals-mobile','.w-product-sale-ends .left-text-left','font-weight','600','','','.w-product-sale-ends'),(168120,'deals-mobile','.w-product-sale-ends .left-text-right','font-weight','600','','','.w-product-sale-ends'),(168121,'deals-mobile','.w-product-collection .title','font-weight','bold','','','.w-product-collection'),(168122,'deals-mobile','.w-product-collection .together','font-weight','700','','','.w-product-collection'),(168123,'deals-mobile','.w-cart .cart-total','font-weight','600','','','.w-cart'),(168124,'deals-mobile','.w-cart .price','font-weight','600','','','.w-cart'),(168125,'deals-mobile','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(168126,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','font-weight','normal','3','','.p-account-history-info'),(168127,'deals-mobile','.p-account-history-info .not_fully_paid_td','font-weight','700','','','.p-account-history-info'),(168128,'deals-mobile','.p-account-index .not_fully_paid_td','font-weight','700','','','.p-account-index'),(168129,'deals-mobile','.b-pass-strength .pass-strength span','font-weight','bold','','','.b-pass-strength'),(168130,'deals-mobile','.b-price-box .price-box .price-row.total','font-weight','700','','','.b-price-box'),(168131,'deals-mobile','.w-reviews .name','font-weight','700','','','.w-reviews'),(168132,'deals-mobile','.w-product-reviews .reviews-list span','font-weight','400','','','.w-product-reviews'),(168133,'deals-mobile','.w-quote .strong','font-weight','400','','','.w-quote'),(168134,'deals-mobile','.w-product-reviews .reviews-list .name','font-weight','700','','','.w-product-reviews'),(168135,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-weight','normal','3','','.b-multi-page-checkout'),(168136,'deals-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','font-weight','bold','','','.p-wedding-registry-manage'),(168137,'deals-mobile','.p-account-history-info .trackings-nambers-label','font-weight','600','','','.p-account-history-info'),(168138,'deals-mobile','.w-product-bonus-points > div','font-weight','bold','','','.w-product-bonus-points'),(168139,'deals-mobile','.p-account-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-history-info'),(168140,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','font-weight','normal','3','','.p-account-order-pay'),(168141,'deals-mobile','.p-account-order-pay .not_fully_paid_td','font-weight','700','','','.p-account-order-pay'),(168142,'deals-mobile','.p-account-order-pay .historyTotal table tr:last-child td','font-weight','bold','','','.p-account-order-pay'),(168143,'deals-mobile','.js-stock','font-weight','700','','',''),(168144,'deals-mobile','.testimonials .heading-3','font-weight','400','3','',''),(168145,'deals-mobile','.testimonials .name','font-weight','700','','',''),(168146,'deals-mobile','.testimonials .rating','font-weight','400','','',''),(168147,'deals-mobile','.testimonials .reviews-list .name','font-weight','700','','',''),(168148,'deals-mobile','.testimonials .reviews-list span','font-weight','400','','',''),(168149,'deals-mobile','.b-pagination .pagination span','font-weight','700','2','','.b-pagination'),(168150,'deals-mobile','.p-blog-index .nav-links .screen-reader-text','font-weight','700','','','.p-blog-index'),(168151,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-2_2'),(168152,'deals-mobile','.w-list-type-2 .title','font-weight','700','','','.w-list-type-2'),(168153,'deals-mobile','.w-product-wedding-registry-button .btn','font-weight','700','','','.w-product-wedding-registry-button'),(168154,'deals-mobile','.w-product-personal-catalog-button .btn','font-weight','normal','3','','.w-product-personal-catalog-button'),(168155,'deals-mobile','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(168156,'deals-mobile','.w-product-personal-catalog-button .btn','font-weight','700','','','.w-product-personal-catalog-button'),(168157,'deals-mobile','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(168158,'deals-mobile','.w-list-type-2_2 .button-view a','font-weight','700','','','.w-list-type-2_2'),(168159,'deals-mobile','.w-list-type-2_2 .button-wishlist button','font-weight','700','','','.w-list-type-2_2'),(168160,'deals-mobile','.w-delivery-location-top-location-list .deliveryName a','font-weight','bold','','','.w-delivery-location-top-location-list'),(168161,'deals-mobile','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(168162,'deals-mobile','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(168163,'deals-mobile','.b-bottom .alert-message','font-weight','bold','','','.b-bottom'),(168164,'deals-mobile','.p-wedding-registry-manage .links a.share-registry','font-weight','600','','','.p-wedding-registry-manage'),(168165,'deals-mobile','.p-wedding-registry-manage .wedding-date','font-weight','600','','','.p-wedding-registry-manage'),(168166,'deals-mobile','.b-table .table .headings td','font-weight','600','','','.b-table'),(168167,'deals-mobile','.b-pagination .pagination a','font-weight','700','','','.b-pagination'),(168168,'deals-mobile','.p-account-history .order_history_table h2','font-weight','normal','','','.p-account-history'),(168169,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','font-weight','600','','','.b-switch'),(168170,'deals-mobile','.b-bottom .popup-heading','font-weight','bold','','','.b-bottom'),(168171,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','font-weight','600','','','.b-switch'),(168172,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','font-weight','bold','','','.b-fancybox'),(168173,'deals-mobile','.heading-2, h2','font-weight','400','','',''),(168174,'deals-mobile','.p-account-index .ai_title','font-weight','bold','','','.p-account-index'),(168175,'deals-mobile','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(168176,'deals-mobile','.btn-2','font-weight','600','','',''),(168177,'deals-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','font-weight','normal','','','.p-account-trade-form'),(168178,'deals-mobile','.p-account-trade-form .widget h3','font-weight','normal','','','.p-account-trade-form'),(168179,'deals-mobile','.p-checkout-index .same-address','font-weight','bold','','','.p-checkout-index'),(168180,'deals-mobile','.p-quote-cart-index .cart-page .empty','font-weight','700','','','.p-quote-cart-index'),(168181,'deals-mobile','.p-checkout-index .shipping-method .title','font-weight','bold','','','.p-checkout-index'),(168182,'deals-mobile','.p-shopping-cart-index .cart-page .empty','font-weight','700','','','.p-shopping-cart-index'),(168183,'deals-mobile','.w-currencies .currencies-title','font-weight','700','','','.w-currencies'),(168184,'deals-mobile','.p-account-trade-form .address-wrapp b','font-weight','600','','','.p-account-trade-form'),(168185,'deals-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-weight','normal','','','.p-account-subscription-historyinfo'),(168186,'deals-mobile','.p-reviews-info .review-info-reviewed_by','font-weight','bold','','','.p-reviews-info'),(168187,'deals-mobile','.w-sale .left-text-left','font-weight','600','','','.w-sale'),(168188,'deals-mobile','.w-sale .ends-date','font-weight','600','','','.w-sale'),(168189,'deals-mobile','.p-account-history .not_fully_paid_td','font-weight','700','','','.p-account-history'),(168190,'deals-mobile','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(168191,'deals-mobile','.w-top-categories .categories h2','font-weight','inherit','','','.w-top-categories'),(168192,'deals-mobile','.w-categories .categories h2','font-weight','inherit','','','.w-categories'),(168193,'deals-mobile','.b-rating #stars-default .glyphicon','font-weight','400','','','.b-rating'),(168194,'deals-mobile','.p-account-index .date_value strong','font-weight','normal','','','.p-account-index'),(168195,'deals-mobile','.p-account-index .account_page h4','font-weight','normal','3','','.p-account-index'),(168196,'deals-mobile','.p-account-index .account_info .info .info_span','font-weight','bold','','','.p-account-index'),(168197,'deals-mobile','.b-form #payment_method .title','font-weight','bold','','','.b-form'),(168198,'deals-mobile','.w-cart .strong','font-weight','400','','','.w-cart'),(168199,'deals-mobile','.w-cart-give-away .ga_price','font-weight','700','','','.w-cart-give-away'),(168200,'deals-mobile','.w-list-type-1_3 .sale','font-weight','600','4','','.w-list-type-1_3'),(168201,'deals-mobile','.w-list-type-1_3 .title','font-weight','700','','','.w-list-type-1_3'),(168202,'deals-mobile','.w-list-type-2 .button-view a','font-weight','700','','','.w-list-type-2'),(168203,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-2'),(168204,'deals-mobile','.w-list-type-2 .sale','font-weight','600','4','','.w-list-type-2'),(168205,'deals-mobile','.w-list-type-2 .button-wishlist button','font-weight','700','','','.w-list-type-2'),(168206,'deals-mobile','h1','font-weight','400','','',''),(168207,'deals-mobile','.w-currencies .select-link','font-weight','700','','','.w-currencies'),(168208,'deals-mobile','.btn-1','font-weight','600','','',''),(168209,'deals-mobile','.btn-3','font-weight','600','','',''),(168210,'deals-mobile','.btn','font-weight','600','','',''),(168211,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-1_3'),(168212,'deals-mobile','.w-list-type-1_3 .button-view a','font-weight','700','','','.w-list-type-1_3'),(168213,'deals-mobile','.w-list-type-1_3 .button-wishlist button','font-weight','700','','','.w-list-type-1_3'),(168214,'deals-mobile','.w-list-type-1_2 .title','font-weight','700','','','.w-list-type-1_2'),(168215,'deals-mobile','.w-list-type-1_2 .sale','font-weight','600','4','','.w-list-type-1_2'),(168216,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-1_2'),(168217,'deals-mobile','.b-bottom .footerTitle','font-weight','700','','','.b-bottom'),(168218,'deals-mobile','.w-list-type-1_2 .button-wishlist button','font-weight','700','','','.w-list-type-1_2'),(168219,'deals-mobile','.w-list-type-1_2 .button-view a','font-weight','700','','','.w-list-type-1_2'),(168220,'deals-mobile','.w-list-type-1 .sale','font-weight','600','4','','.w-list-type-1'),(168221,'deals-mobile','.heading-4 .right-text, h4 .right-text','font-weight','400','','',''),(168222,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','font-weight','400','3','','.w-list-type-1'),(168223,'deals-mobile','.heading-4 .edit, h4 .edit','font-weight','400','','',''),(168224,'deals-mobile','.w-list-type-1 .button-wishlist button','font-weight','700','','','.w-list-type-1'),(168225,'deals-mobile','.out-stock','font-weight','700','','',''),(168226,'deals-mobile','.in-stock','font-weight','700','','',''),(168227,'deals-mobile','.transit','font-weight','700','','',''),(168228,'deals-mobile','.w-filters .view_more','font-weight','400','4','','.w-filters'),(168229,'deals-mobile','.w-list-type-1 .button-view a','font-weight','700','','','.w-list-type-1'),(168230,'deals-mobile','.w-reviews .reviews-list .name','font-weight','700','','','.w-reviews'),(168231,'deals-mobile','.w-reviews .heading-3','font-weight','400','3','','.w-reviews'),(168232,'deals-mobile','.w-reviews .rating','font-weight','400','','','.w-reviews'),(168233,'deals-mobile','.w-reviews .reviews-list span','font-weight','400','','','.w-reviews'),(168234,'deals-mobile','.p-account-history-info .historyTotal table tr:last-child td','font-weight','bold','','','.p-account-history-info'),(168235,'deals-mobile','.p-account-address-book .address_book h2','font-weight','normal','','','.p-account-address-book'),(168236,'deals-mobile','.b-info .info strong','font-weight','400','','','.b-info'),(168237,'deals-mobile','.b-products-listing .products-listing .bonus-points span:first-child','font-weight','bold','','','.b-products-listing'),(168238,'deals-mobile','.b-products-listing .products-listing .btn-buy','font-weight','400','3','','.b-products-listing'),(168239,'deals-mobile','.b-products-listing .products-listing .name a','font-weight','bold','','','.b-products-listing'),(168240,'deals-mobile','.b-products-listing .products-listing a.btn.view-button','font-weight','bold','','','.b-products-listing'),(168241,'deals-mobile','.b-products-listing .products-listing h2','font-weight','inherit','','','.b-products-listing'),(168242,'deals-mobile','.b-products-listing .promos-info .promo-name','font-weight','500','','','.b-products-listing'),(168243,'deals-mobile','.b-products-listing .wedding-registry-count','font-weight','bold','','','.b-products-listing'),(168244,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.b-data-table'),(168245,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.b-data-table'),(168246,'deals-mobile','.b-data-table table.dataTable thead td','font-weight','700','','','.b-data-table'),(168247,'deals-mobile','.b-delete-account .delete-box .delete-message','font-weight','normal','','','.b-delete-account'),(168248,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-weight','inherit','','','.b-h-inline'),(168249,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','font-weight','600','','','.b-menu-style-1'),(168250,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','font-weight','600','','','.b-menu-style-1'),(168251,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','font-weight','600','','','.b-menu-style-2'),(168252,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','font-weight','600','','','.b-menu-style-2'),(168253,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-weight','600','','','.b-menu-style-2'),(168254,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-weight','300','3','','.b-menu-style-2'),(168255,'deals-mobile','.b-messages span.starred::before','font-weight','normal','','','.b-messages'),(168256,'deals-mobile','.b-messages .messMenuButton span','font-weight','600','','','.b-messages'),(168257,'deals-mobile','.b-messages .messBtnMenuDelete','font-weight','normal','3','','.b-messages'),(168258,'deals-mobile','.b-messages .messBtnMenuStarred','font-weight','normal','3','','.b-messages'),(168259,'deals-mobile','.b-messages .messBtnMenuUnread','font-weight','normal','3','','.b-messages'),(168260,'deals-mobile','.b-messages .messages-menu li a','font-weight','bold','2','','.b-messages'),(168261,'deals-mobile','.b-messages .content_management_attach','font-weight','600','','','.b-messages'),(168262,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','font-weight','600','','','.b-messages'),(168263,'deals-mobile','.b-personal-catalog-popup #personal_catalog_popup','font-weight','normal','','','.b-personal-catalog-popup'),(168264,'deals-mobile','.b-select-suggest .select2-results li.select2-result-with-children > .select2-result-label','font-weight','bold','','','.b-select-suggest'),(168265,'deals-mobile','.b-sub-totals .historyTotal table tr:last-child td','font-weight','bold','','','.b-sub-totals'),(168266,'deals-mobile','.b-trade-approval .middle-form label','font-weight','600','','','.b-trade-approval'),(168267,'deals-mobile','.b-warehouses-popup .warehouses-popup .heading','font-weight','bold','','','.b-warehouses-popup'),(168268,'deals-mobile','.b-warehouses-popup a.warehouses-popup-link','font-weight','bold','','','.b-warehouses-popup'),(168269,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','font-weight','bold','','','.b-warehouses-popup'),(168270,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','font-weight','bold','','','.b-warehouses-popup'),(168271,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-name','font-weight','bold','','','.b-warehouses-popup'),(168272,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','font-weight','bold','','','.b-warehouses-popup'),(168273,'deals-mobile','.batchPr .batch-selected-products-empty','font-weight','600','','','.batchPr'),(168274,'deals-mobile','.batchPr .batch-selected-products-total','font-weight','600','','','.batchPr'),(168275,'deals-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(168276,'deals-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(168277,'deals-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(168278,'deals-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(168279,'deals-mobile','.p-account-samples-history .not_fully_paid_td','font-weight','700','','','.p-account-samples-history'),(168280,'deals-mobile','.p-account-samples-history .not_fully_paid_td','font-weight','700','','','.p-account-samples-history'),(168281,'deals-mobile','.p-account-samples-history .not_fully_paid_td','font-weight','700','','','.p-account-samples-history'),(168282,'deals-mobile','.p-account-samples-history .order_history_table h2','font-weight','normal','','','.p-account-samples-history'),(168283,'deals-mobile','.p-account-samples-history .order_history_table h2','font-weight','normal','','','.p-account-samples-history'),(168284,'deals-mobile','.p-account-samples-history .not_fully_paid_td','font-weight','700','','','.p-account-samples-history'),(168285,'deals-mobile','.p-account-samples-history .order_history_table h2','font-weight','normal','','','.p-account-samples-history'),(168286,'deals-mobile','.p-account-samples-history .not_fully_paid_td','font-weight','700','','','.p-account-samples-history'),(168287,'deals-mobile','.p-account-samples-history .order_history_table h2','font-weight','normal','','','.p-account-samples-history'),(168288,'deals-mobile','.p-account-samples-history .order_history_table h2','font-weight','normal','','','.p-account-samples-history'),(168289,'deals-mobile','.p-account-samples-history .not_fully_paid_td','font-weight','700','','','.p-account-samples-history'),(168290,'deals-mobile','.p-account-samples-history .order_history_table h2','font-weight','normal','','','.p-account-samples-history'),(168291,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','font-weight','700','','','.p-account-samples-history-info'),(168292,'deals-mobile','.p-account-samples-history-info .trackings-nambers-label','font-weight','600','','','.p-account-samples-history-info'),(168293,'deals-mobile','.p-account-samples-history-info .trackings-nambers-label','font-weight','600','','','.p-account-samples-history-info'),(168294,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','font-weight','700','','','.p-account-samples-history-info'),(168295,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-samples-history-info'),(168296,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-weight','normal','3','','.p-account-samples-history-info'),(168297,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-samples-history-info'),(168298,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-weight','normal','3','','.p-account-samples-history-info'),(168299,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-weight','normal','3','','.p-account-samples-history-info'),(168300,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-weight','normal','3','','.p-account-samples-history-info'),(168301,'deals-mobile','.p-account-samples-history-info .trackings-nambers-label','font-weight','600','','','.p-account-samples-history-info'),(168302,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-samples-history-info'),(168303,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-weight','normal','3','','.p-account-samples-history-info'),(168304,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','font-weight','normal','3','','.p-account-samples-history-info'),(168305,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','font-weight','700','','','.p-account-samples-history-info'),(168306,'deals-mobile','.p-account-samples-history-info .trackings-nambers-label','font-weight','600','','','.p-account-samples-history-info'),(168307,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','font-weight','700','','','.p-account-samples-history-info'),(168308,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','font-weight','700','','','.p-account-samples-history-info'),(168309,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','font-weight','700','','','.p-account-samples-history-info'),(168310,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-samples-history-info'),(168311,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-samples-history-info'),(168312,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','font-weight','600','','','.p-account-samples-history-info'),(168313,'deals-mobile','.p-account-samples-history-info .trackings-nambers-label','font-weight','600','','','.p-account-samples-history-info'),(168314,'deals-mobile','.p-account-samples-history-info .trackings-nambers-label','font-weight','600','','','.p-account-samples-history-info'),(168315,'deals-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(168316,'deals-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(168317,'deals-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(168318,'deals-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(168319,'deals-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(168320,'deals-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(168321,'deals-mobile','.p-catalog-product .pn-direction','font-weight','600','','','.p-catalog-product'),(168322,'deals-mobile','.p-payer-order-confirmation .cardinfo-label','font-weight','bold','','','.p-payer-order-confirmation'),(168323,'deals-mobile','.p-payer-order-pay .cardinfo-label','font-weight','bold','','','.p-payer-order-pay'),(168324,'deals-mobile','.p-quick-order-index .dataTables_info','font-weight','500','','','.p-quick-order-index'),(168325,'deals-mobile','.p-quick-order-index .value','font-weight','bold','','','.p-quick-order-index'),(168326,'deals-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-weight','600','','','.p-quick-order-index'),(168327,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.p-quick-order-index'),(168328,'deals-mobile','.p-quick-order-index .filters label','font-weight','700','','','.p-quick-order-index'),(168329,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.p-quick-order-index'),(168330,'deals-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(168331,'deals-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(168332,'deals-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(168333,'deals-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(168334,'deals-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(168335,'deals-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(168336,'deals-mobile','.w-account-address-book .name','font-weight','bold','','','.w-account-address-book'),(168337,'deals-mobile','.w-account-address-book .address-buttons','font-weight','600','','','.w-account-address-book'),(168338,'deals-mobile','.w-account-address-book .add_item a','font-weight','bold','','','.w-account-address-book'),(168339,'deals-mobile','.w-blog-widget-post-listing .post_name','font-weight','400','','','.w-blog-widget-post-listing'),(168340,'deals-mobile','.w-blog-widget-tag-cloud a','font-weight','700','','','.w-blog-widget-tag-cloud'),(168341,'deals-mobile','.w-cart-bonus-points .title','font-weight','bold','','','.w-cart-bonus-points'),(168342,'deals-mobile','.w-cart-compare .cart-name a','font-weight','600','','','.w-cart-compare'),(168343,'deals-mobile','.w-cart-compare .atr-col','font-weight','normal','3','','.w-cart-compare'),(168344,'deals-mobile','.w-cart-compare .js-cart_totals_container b','font-weight','600','','','.w-cart-compare'),(168345,'deals-mobile','.w-cart-compare .atr-col','font-weight','600','','','.w-cart-compare'),(168346,'deals-mobile','.w-cart-credit-amount .amount-title','font-weight','bold','','','.w-cart-credit-amount'),(168347,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-weight','normal','3','','.w-catalog-compare'),(168348,'deals-mobile','.w-catalog-paging ','font-weight','700','2','','.w-catalog-paging'),(168349,'deals-mobile','.w-checkout-billing-address .genders-title > div','font-weight','bold','','','.w-checkout-billing-address'),(168350,'deals-mobile','.w-checkout-billing-address .btn-cancel','font-weight','500','','','.w-checkout-billing-address'),(168351,'deals-mobile','.w-checkout-billing-address .add-ab','font-weight','500','','','.w-checkout-billing-address'),(168352,'deals-mobile','.w-checkout-billing-address .edit-ab','font-weight','500','','','.w-checkout-billing-address'),(168353,'deals-mobile','.w-checkout-bonus-points .title','font-weight','bold','','','.w-checkout-bonus-points'),(168354,'deals-mobile','.w-checkout-contact-information .contact-info-buttons a','font-weight','500','','','.w-checkout-contact-information'),(168355,'deals-mobile','.w-checkout-create-account .account-benefits strong','font-weight','normal','','','.w-checkout-create-account'),(168356,'deals-mobile','.w-checkout-credit-amount .amount-title','font-weight','bold','','','.w-checkout-credit-amount'),(168357,'deals-mobile','.w-checkout-shipping-address .change-ab','font-weight','500','','','.w-checkout-shipping-address'),(168358,'deals-mobile','.w-checkout-shipping-address .genders-title > div','font-weight','bold','','','.w-checkout-shipping-address'),(168359,'deals-mobile','.w-checkout-shipping-choice span','font-weight','600','','','.w-checkout-shipping-choice'),(168360,'deals-mobile','.w-checkout-totals .ot_code_ot_subtotal','font-weight','bold','','','.w-checkout-totals'),(168361,'deals-mobile','.w-communication-post .communication-post-author-name','font-weight','bold','','','.w-communication-post'),(168362,'deals-mobile','.w-coupons-and-vauchers-checkout .title','font-weight','bold','','','.w-coupons-and-vauchers-checkout'),(168363,'deals-mobile','.w-delayed-despatch-checkout .heading','font-weight','bold','','','.w-delayed-despatch-checkout'),(168364,'deals-mobile','.w-delayed-despatch-checkout-confirm .heading','font-weight','bold','','','.w-delayed-despatch-checkout-confirm'),(168365,'deals-mobile','.w-delayed-despatch-checkout-confirm .heading','font-weight','600','','','.w-delayed-despatch-checkout-confirm'),(168366,'deals-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-weight','600','','','.w-delivery-day'),(168367,'deals-mobile','.w-delivery-day .ends-date','font-weight','600','','','.w-delivery-day'),(168368,'deals-mobile','.w-delivery-day .title','font-weight','bold','','','.w-delivery-day'),(168369,'deals-mobile','.w-delivery-day .left-text-left','font-weight','600','','','.w-delivery-day'),(168370,'deals-mobile','.w-delivery-day .left-text-right','font-weight','600','','','.w-delivery-day'),(168371,'deals-mobile','.w-image-maps .categories-items .item .title','font-weight','700','','','.w-image-maps'),(168372,'deals-mobile','.w-image-maps .float-items .item .title','font-weight','700','','','.w-image-maps'),(168373,'deals-mobile','.w-image-maps .default-links .item .title','font-weight','700','','','.w-image-maps'),(168374,'deals-mobile','.w-multi-cart-actions .cart-actions','font-weight','600','','','.w-multi-cart-actions'),(168375,'deals-mobile','.w-multi-cart-cart-switcher .cart-label','font-weight','600','','','.w-multi-cart-cart-switcher'),(168376,'deals-mobile','.w-multi-cart-cart-switcher .dropdown-menu a','font-weight','bold','','','.w-multi-cart-cart-switcher'),(168377,'deals-mobile','.w-neighbour-checkout .text','font-weight','bold','','','.w-neighbour-checkout'),(168378,'deals-mobile','.w-personal-gift-status-bar .end-date b','font-weight','bold','','','.w-personal-gift-status-bar'),(168379,'deals-mobile','.w-personal-gift-status-bar .start-label','font-weight','bold','','','.w-personal-gift-status-bar'),(168380,'deals-mobile','.w-personal-gift-status-bar .inform b','font-weight','bold','','','.w-personal-gift-status-bar'),(168381,'deals-mobile','.w-personal-gift-status-bar .end-label','font-weight','bold','','','.w-personal-gift-status-bar'),(168382,'deals-mobile','.w-product-available-in-warehouses .warehouse-name','font-weight','bold','','','.w-product-available-in-warehouses'),(168383,'deals-mobile','.w-product-available-in-warehouses .heading','font-weight','bold','','','.w-product-available-in-warehouses'),(168384,'deals-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(168385,'deals-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(168386,'deals-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(168387,'deals-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(168388,'deals-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(168389,'deals-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(168390,'deals-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(168391,'deals-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(168392,'deals-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(168393,'deals-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(168394,'deals-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(168395,'deals-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(168396,'deals-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(168397,'deals-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(168398,'deals-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(168399,'deals-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(168400,'deals-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(168401,'deals-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(168402,'deals-mobile','.w-promotions .prom-multi-discount .heading','font-weight','300','','','.w-promotions'),(168403,'deals-mobile','.w-promotions .promo-cart-discount .master .heading','font-weight','300','','','.w-promotions'),(168404,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder .value','font-weight','bold','','','.w-promotions'),(168405,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty .value','font-weight','bold','','','.w-promotions'),(168406,'deals-mobile','.w-promotions .promo-date','font-weight','500','','','.w-promotions'),(168407,'deals-mobile','.w-promotions .promo-salemaker .promo-conditions','font-weight','300','','','.w-promotions'),(168408,'deals-mobile','.w-promotions .promo-cart-discount .slave .heading','font-weight','300','','','.w-promotions'),(168409,'deals-mobile','.w-promotions .promo-salemaker .discount .value','font-weight','700','','','.w-promotions'),(168410,'deals-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading','font-weight','300','','','.w-promotions'),(168411,'deals-mobile','.w-promotions .prom-multi-discount .promo-range .value','font-weight','bold','','','.w-promotions'),(168412,'deals-mobile','.w-promotions .heading-3','font-weight','bold','','','.w-promotions'),(168413,'deals-mobile','.w-quote-products .empty','font-weight','700','','','.w-quote-products'),(168414,'deals-mobile','.w-reviews-content .author','font-weight','bold','','','.w-reviews-content'),(168415,'deals-mobile','.w-reviews-content .product-name a','font-weight','bold','','','.w-reviews-content'),(168416,'deals-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','font-weight','normal','','','.w-taxable'),(168417,'deals-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','font-weight','normal','','','.w-taxable'),(168418,'deals-mobile','.w-wedding-registry-widgets-delete-link a','font-weight','normal','4','','.w-wedding-registry-widgets-delete-link'),(168419,'deals-mobile','.w-wedding-registry-widgets-products .rating','font-weight','bold','','','.w-wedding-registry-widgets-products'),(168420,'deals-mobile','.w-wedding-registry-widgets-share-link a','font-weight','normal','4','','.w-wedding-registry-widgets-share-link'),(168421,'deals-mobile','.w-cart .qty','font_size_measure','em','4','','.w-cart'),(168422,'deals-mobile','.w-cart .cart-total','font_size_measure','em','','','.w-cart'),(168423,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font_size_measure','em','4','','.b-multi-page-checkout'),(168424,'deals-mobile','.w-quote .cart-box-link','font_size_measure','em','3','','.w-quote'),(168425,'deals-mobile','.no-found','font_size_measure','em','','',''),(168426,'deals-mobile','.view-all .btn','font_size_measure','em','4','',''),(168427,'deals-mobile','.price .old','font_size_measure','em','','',''),(168428,'deals-mobile','.b-select-suggest .select2-search input','font_size_measure','em','','','.b-select-suggest'),(168429,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font_size_measure','%','','','.b-select-suggest'),(168430,'deals-mobile','.w-checkout-create-account .account-benefits','font_size_measure','em','','','.w-checkout-create-account'),(168431,'deals-mobile','.w-promotions .prom-multi-discount .list','grid-auto-flow','dense','','','.w-promotions'),(168432,'deals-mobile','.w-account-personal-catalog div .price','grid-column','4 / 5','','','.w-account-personal-catalog'),(168433,'deals-mobile','.w-promotions .prom-multi-discount .promo-group-2','grid-column','span 2','','','.w-promotions'),(168434,'deals-mobile','.w-promotions .prom-multi-discount .promo-group-3','grid-column','span 3','','','.w-promotions'),(168435,'deals-mobile','.w-promotions .prom-multi-discount .promo-group-4','grid-column','span 4','','','.w-promotions'),(168436,'deals-mobile','.w-reviews-content .product-name','grid-column','2/4','','','.w-reviews-content'),(168437,'deals-mobile','.w-reviews-content .product-image','grid-column','1','','','.w-reviews-content'),(168438,'deals-mobile','.w-reviews-content .review','grid-column','2/4','','','.w-reviews-content'),(168439,'deals-mobile','.w-reviews-content .rating','grid-column','2','','','.w-reviews-content'),(168440,'deals-mobile','.w-reviews-content .author','grid-column','2/4','','','.w-reviews-content'),(168441,'deals-mobile','.w-reviews-content .date','grid-column','3','','','.w-reviews-content'),(168442,'deals-mobile','.w-promotions .content','grid-column-end','3','','','.w-promotions'),(168443,'deals-mobile','.w-promotions .content','grid-column-start','1','','','.w-promotions'),(168444,'deals-mobile','.w-promotions .condition','grid-column-start','2','','','.w-promotions'),(168445,'deals-mobile','.w-promotions .heading','grid-column-start','1','','','.w-promotions'),(168446,'deals-mobile','.w-promotions .prom-multi-discount .products','grid-gap','4px','','','.w-promotions'),(168447,'deals-mobile','.w-promotions .prom-multi-discount .list','grid-gap','20px','','','.w-promotions'),(168448,'deals-mobile','.w-promotions .nextdiscount .content','grid-gap','3px','','','.w-promotions'),(168449,'deals-mobile','.w-account-personal-catalog div .price','grid-row','1 / 2','','','.w-account-personal-catalog'),(168450,'deals-mobile','.w-reviews-content .product-image','grid-row','1/6','','','.w-reviews-content'),(168451,'deals-mobile','.w-reviews-content .product-name','grid-row','2','','','.w-reviews-content'),(168452,'deals-mobile','.w-reviews-content .review','grid-row','3','','','.w-reviews-content'),(168453,'deals-mobile','.w-reviews-content .date','grid-row','1','','','.w-reviews-content'),(168454,'deals-mobile','.w-reviews-content .author','grid-row','4','','','.w-reviews-content'),(168455,'deals-mobile','.w-reviews-content .rating','grid-row','1','','','.w-reviews-content'),(168456,'deals-mobile','.w-promotions .heading','grid-row-start','1','','','.w-promotions'),(168457,'deals-mobile','.w-promotions .condition','grid-row-start','1','','','.w-promotions'),(168458,'deals-mobile','.w-promotions .content','grid-row-start','2','','','.w-promotions'),(168459,'deals-mobile','.w-promotions .nextdiscount .content','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(168460,'deals-mobile','.w-promotions .prom-multi-discount .promo-group-4 .products','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(168461,'deals-mobile','.w-promotions .prom-multi-discount .products','grid-template-columns','1fr','','','.w-promotions'),(168462,'deals-mobile','.w-promotions .prom-multi-discount .promo-group-3 .products','grid-template-columns','1fr 1fr 1fr','','','.w-promotions'),(168463,'deals-mobile','.w-promotions .prom-multi-discount .promo-group-2 .products','grid-template-columns','1fr 1fr','','','.w-promotions'),(168464,'deals-mobile','.w-promotions .prom-multi-discount .list','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(168465,'deals-mobile','.w-reviews-content .item','grid-template-columns','170px 1fr 1fr','','','.w-reviews-content'),(168466,'deals-mobile','.w-bestsellers .item','height','32','3','','.w-bestsellers'),(168467,'deals-mobile','.b-fancybox .fancybox-close','height','36','','','.b-fancybox'),(168468,'deals-mobile','.w-bestsellers .counter','height','32','','','.w-bestsellers'),(168469,'deals-mobile','.b-switch .bootstrap-switch','height','28','','','.b-switch'),(168470,'deals-mobile','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(168471,'deals-mobile','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(168472,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','height','18','','','.b-form'),(168473,'deals-mobile','.b-form .checkbox-style:checked + .checkbox-span','height','18','','','.b-form'),(168474,'deals-mobile','.w-menu-slider .menu-ico','height','54','','','.w-menu-slider'),(168475,'deals-mobile','.w-menu-horizontal .menu-ico','height','54','','','.w-menu-horizontal'),(168476,'deals-mobile','.w-list-type-2_2 .sale','height','19','4','','.w-list-type-2_2'),(168477,'deals-mobile','.w-sale .badge','height','80','','','.w-sale'),(168478,'deals-mobile','.w-menu-style-1 .menu-ico','height','48','','','.w-menu-style-1'),(168479,'deals-mobile','.w-menu-mobile .menu-slider .open','height','100','','','.w-menu-mobile'),(168480,'deals-mobile','.w-product-wedding-registry-button .btn','height','18','3','','.w-product-wedding-registry-button'),(168481,'deals-mobile','.w-product-wedding-registry-button .btn','height','18','4','','.w-product-wedding-registry-button'),(168482,'deals-mobile','.w-compare-box-item .checkbox','height','22','','','.w-compare-box-item'),(168483,'deals-mobile','.w-compare-box-item .checkbox + span','height','24','','','.w-compare-box-item'),(168484,'deals-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','height','auto','','','.b-product-images'),(168485,'deals-mobile','.w-catalog-listing-look .list','height','31','','','.w-catalog-listing-look'),(168486,'deals-mobile','.w-catalog-listing-look .b2b','height','31','','','.w-catalog-listing-look'),(168487,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','height','35','3','','.b-multi-page-checkout'),(168488,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','height','35','','','.p-blog-index'),(168489,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','height','33','','','.b-multi-page-checkout'),(168490,'deals-mobile','.b-pagination .pagination .prev','height','30','','','.b-pagination'),(168491,'deals-mobile','.b-pagination .pagination .prev-pages','height','30','','','.b-pagination'),(168492,'deals-mobile','.p-wedding-registry-manage .wr-search button','height','30','','','.p-wedding-registry-manage'),(168493,'deals-mobile','.b-pagination .pagination .page-number','height','30','','','.b-pagination'),(168494,'deals-mobile','.b-pagination .pagination .next-pages','height','30','','','.b-pagination'),(168495,'deals-mobile','.b-pagination .pagination .next','height','30','','','.b-pagination'),(168496,'deals-mobile','.b-pagination .pagination span','height','30','2','','.b-pagination'),(168497,'deals-mobile','.p-account-history .orders-table .td-alignright','height','45','890','','.p-account-history'),(168498,'deals-mobile','.p-account-index .orders-table .td-alignright','height','45','890','','.p-account-index'),(168499,'deals-mobile','.w-list-type-2_2 .sale','height','19','3','','.w-list-type-2_2'),(168500,'deals-mobile','.w-list-type-2_2 .sale','height','19','','','.w-list-type-2_2'),(168501,'deals-mobile','.w-list-type-2 .sale','height','19','3','','.w-list-type-2'),(168502,'deals-mobile','.w-list-type-2 .sale','height','19','','','.w-list-type-2'),(168503,'deals-mobile','.w-list-type-2 .sale','height','19','4','','.w-list-type-2'),(168504,'deals-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height','100','','','.b-fancybox'),(168505,'deals-mobile','.b-fancybox .fancybox-nav','height','100','','','.b-fancybox'),(168506,'deals-mobile','.w-product-promotions select','height','29','','','.w-product-promotions'),(168507,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','height','30','3','','.b-form'),(168508,'deals-mobile','.b-pagination .pagination a','height','30','','','.b-pagination'),(168509,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','height','20','3','','.b-switch'),(168510,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','height','20','3','','.b-switch'),(168511,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','height','28','','','.b-switch'),(168512,'deals-mobile','.w-list-type-1 .image img','height','auto','','','.w-list-type-1'),(168513,'deals-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','height','40','','','.b-quantity'),(168514,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','height','40','','','.b-slick'),(168515,'deals-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height','100','','','.w-banner'),(168516,'deals-mobile','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height','100','','','.w-banner'),(168517,'deals-mobile','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height','100','','','.w-banner'),(168518,'deals-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','height','24','','','.w-filters'),(168519,'deals-mobile','.w-filters .input-checkbox:checked + .checkbox-span','height','24','','','.w-filters'),(168520,'deals-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','height','22','','','.w-compare-box-item'),(168521,'deals-mobile','.b-slick .slick-vertical .slick-slide','height','auto','','','.b-slick'),(168522,'deals-mobile','.b-info-popup .info-popup','height','2','','','.b-info-popup'),(168523,'deals-mobile','.b-info-popup .info-popup div','height','20','3','','.b-info-popup'),(168524,'deals-mobile','.w-menu-mobile .menu-ico','height','48','','','.w-menu-mobile'),(168525,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','height','50','876','','.b-slick'),(168526,'deals-mobile','.w-banner .carousel-text','height','100','','','.w-banner'),(168527,'deals-mobile','.b-slick .slick-slide','height','100','','','.b-slick'),(168528,'deals-mobile','.b-quantity .qty-box .smaller','height','35','','','.b-quantity'),(168529,'deals-mobile','.b-quantity .qty-box .bigger','height','35','','','.b-quantity'),(168530,'deals-mobile','.b-fancybox #fancybox-loading div','height','44','','','.b-fancybox'),(168531,'deals-mobile','.w-product-images .item-div','height','80','893','','.w-product-images'),(168532,'deals-mobile','.b-fancybox .fancybox-nav span','height','40','','','.b-fancybox'),(168533,'deals-mobile','.w-product-images .item','height','80','893','','.w-product-images'),(168534,'deals-mobile','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','height','25','','','.b-datepicker'),(168535,'deals-mobile','.w-catalog-listing-look .grid','height','31','','','.w-catalog-listing-look'),(168536,'deals-mobile','.w-list-type-1_3 .sale','height','19','4','','.w-list-type-1_3'),(168537,'deals-mobile','.w-list-type-1_3 .sale','height','19','','','.w-list-type-1_3'),(168538,'deals-mobile','.w-list-type-1_3 .sale','height','19','3','','.w-list-type-1_3'),(168539,'deals-mobile','.b-autocomplete .ui-autocomplete','height','300','','','.b-autocomplete'),(168540,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','height','40','','',''),(168541,'deals-mobile','.w-list-type-1_2 .sale','height','19','3','','.w-list-type-1_2'),(168542,'deals-mobile','.w-list-type-1_2 .sale','height','19','4','','.w-list-type-1_2'),(168543,'deals-mobile','.w-list-type-1_2 .sale','height','19','','','.w-list-type-1_2'),(168544,'deals-mobile','.b-bottom .pop-up-close','height','31','','','.b-bottom'),(168545,'deals-mobile','.w-list-type-1 .sale','height','19','4','','.w-list-type-1'),(168546,'deals-mobile','.w-list-type-1 .sale','height','19','','','.w-list-type-1'),(168547,'deals-mobile','.w-list-type-1 .sale','height','19','3','','.w-list-type-1'),(168548,'deals-mobile','.w-filters .ui-slider','height','7','','','.w-filters'),(168549,'deals-mobile','.w-filters .ui-slider-range','height','6','','','.w-filters'),(168550,'deals-mobile','.w-filters .ui-slider-handle','height','18','','','.w-filters'),(168551,'deals-mobile','.w-search .button-search','height','48','','','.w-search'),(168552,'deals-mobile','.w-search .image','height','40','','','.w-search'),(168553,'deals-mobile','.b-form .hide-billing-address','height','100','','','.b-form'),(168554,'deals-mobile','.b-products-listing .btn-preloader','height','24','3','','.b-products-listing'),(168555,'deals-mobile','.b-products-listing .hover-box-content','height','20','3','','.b-products-listing'),(168556,'deals-mobile','.b-products-listing .loader','height','30','4','','.b-products-listing'),(168557,'deals-mobile','.b-products-listing .loader','height','100','3','','.b-products-listing'),(168558,'deals-mobile','.b-products-listing .products-listing .qty-input.hidden','height','100','3','','.b-products-listing'),(168559,'deals-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','height','auto','','','.b-products-listing'),(168560,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.b-data-table'),(168561,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.b-data-table'),(168562,'deals-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(168563,'deals-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(168564,'deals-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(168565,'deals-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(168566,'deals-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(168567,'deals-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(168568,'deals-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','height','30','','','.b-menu-burger_icon'),(168569,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(168570,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(168571,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(168572,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(168573,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(168574,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height','100','','','.b-menu-open_from-left'),(168575,'deals-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(168576,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','height','28','','','.b-menu-style-2'),(168577,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','height','50','','','.b-menu-style-2'),(168578,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','height','24','','','.b-menu-style-2'),(168579,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','height','16','3','','.b-menu-style-2'),(168580,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','height','28','','','.b-menu-style-2'),(168581,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','height','16','3','','.b-menu-style-2'),(168582,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','height','24','','','.b-menu-style-2'),(168583,'deals-mobile','.b-messages .select2-container-multi input.select2-input','height','31','','','.b-messages'),(168584,'deals-mobile','.b-preloader .preloader','height','100','','','.b-preloader'),(168585,'deals-mobile','.b-preloader .preloader','height','40','3','','.b-preloader'),(168586,'deals-mobile','.b-select-suggest .select2-search input','height','auto','','','.b-select-suggest'),(168587,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height','100','','','.b-select-suggest'),(168588,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height','1','','','.b-select-suggest'),(168589,'deals-mobile','.b-select-suggest .select2-drop-mask','height','auto','','','.b-select-suggest'),(168590,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','height','12','','','.b-select-suggest'),(168591,'deals-mobile','.b-select-suggest .select2-measure-scrollbar','height','100','','','.b-select-suggest'),(168592,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','height','100','','','.b-select-suggest'),(168593,'deals-mobile','.b-select-suggest .select2-search-choice-close','height','13','','','.b-select-suggest'),(168594,'deals-mobile','.b-select-suggest .select2-container .select2-choice','height','35','','','.b-select-suggest'),(168595,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','height','35','','','.b-trade-approval'),(168596,'deals-mobile','.b-upload-file .snapshot','height','38','','','.b-upload-file'),(168597,'deals-mobile','.b-upload-file .upload-file-template','height','150','','','.b-upload-file'),(168598,'deals-mobile','.batchPr .checkbox input + span','height','36','','','.batchPr'),(168599,'deals-mobile','.batchPr .batchSelect .checkbox','height','36','','','.batchPr'),(168600,'deals-mobile','.batchPr .checkbox input + span','height','32','','','.batchPr'),(168601,'deals-mobile','.batchPr .batch-selected-products-list','height','304','','','.batchPr'),(168602,'deals-mobile','.batchPr .checkbox input:not(checked) + span:before','height','30','','','.batchPr'),(168603,'deals-mobile','.batchPr .btn-batch-remove','height','20','','','.batchPr'),(168604,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','height','45','','','.p-account-samples-history'),(168605,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','height','45','','','.p-account-samples-history'),(168606,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','height','45','','','.p-account-samples-history'),(168607,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','height','45','','','.p-account-samples-history'),(168608,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','height','45','','','.p-account-samples-history'),(168609,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','height','45','','','.p-account-samples-history'),(168610,'deals-mobile','.p-catalog-product .pn-image','height','24','3','','.p-catalog-product'),(168611,'deals-mobile','.p-payer-order-confirmation .input-wrapper','height','35','','','.p-payer-order-confirmation'),(168612,'deals-mobile','.p-payer-order-pay .input-wrapper','height','35','','','.p-payer-order-pay'),(168613,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.p-quick-order-index'),(168614,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.p-quick-order-index'),(168615,'deals-mobile','.w-account-address-book .wrap','height','100','','','.w-account-address-book'),(168616,'deals-mobile','.w-account-address-book .add_item a','height','100','','','.w-account-address-book'),(168617,'deals-mobile','.w-account-subscription .info-popup','height','15','','','.w-account-subscription'),(168618,'deals-mobile','.w-blog-widget-post-share ','height','26','4','','.w-blog-widget-post-share'),(168619,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','height','35','','','.w-blog-widget-related-posts'),(168620,'deals-mobile','.w-catalog-compare span.btn-preloader','height','24','','','.w-catalog-compare'),(168621,'deals-mobile','.w-catalog-paging .prev','height','30','','','.w-catalog-paging'),(168622,'deals-mobile','.w-catalog-paging .paging-holder','height','30','','','.w-catalog-paging'),(168623,'deals-mobile','.w-catalog-paging ','height','30','2','','.w-catalog-paging'),(168624,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height','30','','','.w-catalog-paging'),(168625,'deals-mobile','.w-catalog-paging .next','height','30','','','.w-catalog-paging'),(168626,'deals-mobile','.w-catalog-paging .page-number','height','30','','','.w-catalog-paging'),(168627,'deals-mobile','.w-catalog-paging .next-pages','height','30','','','.w-catalog-paging'),(168628,'deals-mobile','.w-catalog-paging .prev-pages','height','30','','','.w-catalog-paging'),(168629,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','height','10','','','.w-checkout-shipping-choice'),(168630,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','height','30','','','.w-communication-new-topic'),(168631,'deals-mobile','.w-communication-new-topic #communication_group_holder select','height','35','','','.w-communication-new-topic'),(168632,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','height','36','','','.w-communication-new-topic'),(168633,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','height','36','','','.w-communication-new-topic'),(168634,'deals-mobile','.w-image-maps .svg-wrap svg','height','100','','','.w-image-maps'),(168635,'deals-mobile','.w-personal-gift-status-bar .progress-bar','height','8','','','.w-personal-gift-status-bar'),(168636,'deals-mobile','.w-personal-gift-status-bar .progress-bar-content','height','8','','','.w-personal-gift-status-bar'),(168637,'deals-mobile','.w-product-customers-activity .close','height','30','','','.w-product-customers-activity'),(168638,'deals-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(168639,'deals-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(168640,'deals-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(168641,'deals-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(168642,'deals-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(168643,'deals-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(168644,'deals-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(168645,'deals-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(168646,'deals-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(168647,'deals-mobile','.w-product-images-additional .item','height','80','','','.w-product-images-additional'),(168648,'deals-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(168649,'deals-mobile','.w-product-images-additional .item-div','height','80','','','.w-product-images-additional'),(168650,'deals-mobile','.w-promotions .prom-multi-discount .products','height','calc(100% - 25px)','','','.w-promotions'),(168651,'deals-mobile','.w-promotions .prom-multi-discount .image img','height','auto','','','.w-promotions'),(168652,'deals-mobile','.w-promotions .promo-cart-discount .image img','height','auto','','','.w-promotions'),(168653,'deals-mobile','.w-promotions .promo-salemaker .image img','height','auto','','','.w-promotions'),(168654,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','height','150','','','.w-upload-customer-id-upload-customer-id-form'),(168655,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','height','100','','','.w-upload-customer-id-upload-customer-id-form'),(168656,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','height','144','','','.w-wedding-registry-widgets-photos'),(168657,'deals-mobile','.w-wedding-registry-widgets-photos .upload-file-template','height','144','','','.w-wedding-registry-widgets-photos'),(168658,'deals-mobile','.b-quantity .qty-box input[type=\'text\']','height','40','','','.b-quantity'),(168659,'deals-mobile','.b-select-suggest .select2-search input','height_important','important','','','.b-select-suggest'),(168660,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height_important','important','','','.b-select-suggest'),(168661,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height_important','important','','','.w-catalog-paging'),(168662,'deals-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height_measure','%','','','.b-fancybox'),(168663,'deals-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height_measure','%','','','.w-banner'),(168664,'deals-mobile','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height_measure','%','','','.w-banner'),(168665,'deals-mobile','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height_measure','%','','','.w-banner'),(168666,'deals-mobile','.w-menu-mobile .menu-slider .open','height_measure','vh','','','.w-menu-mobile'),(168667,'deals-mobile','.w-banner .carousel-text','height_measure','%','','','.w-banner'),(168668,'deals-mobile','.b-slick .slick-slide','height_measure','%','','','.b-slick'),(168669,'deals-mobile','.b-fancybox .fancybox-nav','height_measure','%','','','.b-fancybox'),(168670,'deals-mobile','.b-form .hide-billing-address','height_measure','%','','','.b-form'),(168671,'deals-mobile','.b-products-listing .loader','height_measure','%','3','','.b-products-listing'),(168672,'deals-mobile','.b-products-listing .products-listing .qty-input.hidden','height_measure','%','3','','.b-products-listing'),(168673,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height_measure','vh','','','.b-menu-open_from-left'),(168674,'deals-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(168675,'deals-mobile','.b-preloader .preloader','height_measure','%','','','.b-preloader'),(168676,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height_measure','%','','','.b-select-suggest'),(168677,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','height_measure','%','','','.b-select-suggest'),(168678,'deals-mobile','.w-account-address-book .wrap','height_measure','%','','','.w-account-address-book'),(168679,'deals-mobile','.w-account-address-book .add_item a','height_measure','%','','','.w-account-address-book'),(168680,'deals-mobile','.w-image-maps .svg-wrap svg','height_measure','%','','','.w-image-maps'),(168681,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(168682,'deals-mobile','.personal-buttons > div','justify-content','space-around','','','.personal-buttons'),(168683,'deals-mobile','.w-banner .carousel .top-right','justify-content','flex-end','','','.w-banner'),(168684,'deals-mobile','.w-banner .carousel .top-center','justify-content','center','','','.w-banner'),(168685,'deals-mobile','.w-banner .carousel .middle-center','justify-content','center','','','.w-banner'),(168686,'deals-mobile','.w-banner .carousel .bottom-left','justify-content','flex-start','','','.w-banner'),(168687,'deals-mobile','.w-banner .carousel .bottom-center','justify-content','center','','','.w-banner'),(168688,'deals-mobile','.w-banner .carousel .top-left','justify-content','flex-start','','','.w-banner'),(168689,'deals-mobile','.w-banner .carousel .middle-right','justify-content','flex-end','','','.w-banner'),(168690,'deals-mobile','.w-banner .carousel .bottom-right','justify-content','flex-end','','','.w-banner'),(168691,'deals-mobile','.w-banner .carousel .middle-left','justify-content','flex-start','','','.w-banner'),(168692,'deals-mobile','.b-products-listing .products-listing .attribute-qty-blocks','justify-content','space-between','','','.b-products-listing'),(168693,'deals-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(168694,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','justify-content','space-between','','','.b-menu-style-1'),(168695,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(168696,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(168697,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(168698,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(168699,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(168700,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(168701,'deals-mobile','.p-quick-order-index .quick-order-total','justify-content','space-between','','','.p-quick-order-index'),(168702,'deals-mobile','.w-account-address-book .wrap','justify-content','space-between','','','.w-account-address-book'),(168703,'deals-mobile','.w-account-address-book .add_item a','justify-content','center','','','.w-account-address-book'),(168704,'deals-mobile','.w-catalog-compare .cross-box','justify-content','flex-end','','','.w-catalog-compare'),(168705,'deals-mobile','.w-checkout-shipping-choice span','justify-content','center','','','.w-checkout-shipping-choice'),(168706,'deals-mobile','.w-communication-post .communication-post-author','justify-content','space-between','','','.w-communication-post'),(168707,'deals-mobile','.w-personal-gift-status-bar .timeline','justify-content','center','','','.w-personal-gift-status-bar'),(168708,'deals-mobile','.w-promotions .prom-multi-discount .products','justify-content','space-between','','','.w-promotions'),(168709,'deals-mobile','.w-promotions .promo-salemaker .content','justify-content','center','','','.w-promotions'),(168710,'deals-mobile','.w-promotions .promo-cart-discount .content','justify-content','center','','','.w-promotions'),(168711,'deals-mobile','.w-menu-horizontal > ul > li > ul','left','0','','','.w-menu-horizontal'),(168712,'deals-mobile','.w-menu-slider > ul > li > ul','left','0','','','.w-menu-slider'),(168713,'deals-mobile','.w-menu-big > ul > li > ul','left','0','','','.w-menu-big'),(168714,'deals-mobile','.w-bestsellers .heading-3','left','0','3','','.w-bestsellers'),(168715,'deals-mobile','.w-menu-style-1 > ul > li > ul','left','0','','','.w-menu-style-1'),(168716,'deals-mobile','.w-sale .badge','left','10','','','.w-sale'),(168717,'deals-mobile','.w-product-wedding-registry-button .btn','left','0','3','','.w-product-wedding-registry-button'),(168718,'deals-mobile','.w-product-wedding-registry-button .btn','left','13','4','','.w-product-wedding-registry-button'),(168719,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','left','1','3','','.p-account-history-info'),(168720,'deals-mobile','.p-account-index .not_fully_paid_td','left','15','','','.p-account-index'),(168721,'deals-mobile','.p-account-history-info .not_fully_paid_td','left','15','','','.p-account-history-info'),(168722,'deals-mobile','.w-product-reviews .reviews-list .review','left','10','3','','.w-product-reviews'),(168723,'deals-mobile','.p-account-index .topAccount > li > div','left','0','863,3','','.p-account-index'),(168724,'deals-mobile','.b-info-popup .info-popup div','left','40','','','.b-info-popup'),(168725,'deals-mobile','.w-promo-code .holder','left','12','893,3','','.w-promo-code'),(168726,'deals-mobile','.w-menu-mobile .menu-slider .open','left','0','','','.w-menu-mobile'),(168727,'deals-mobile','.b-info-popup .info-popup.top-left div','left','auto','','','.b-info-popup'),(168728,'deals-mobile','.b-info-popup .info-popup.top-left div','left','auto','3','','.b-info-popup'),(168729,'deals-mobile','.w-promo-code .holder','left','20','3','','.w-promo-code'),(168730,'deals-mobile','.p-account-order-pay .historyInfoColumn h2.title-delivery-address, .p-account-order-pay .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-order-pay'),(168731,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','left','1','3','','.p-account-order-pay'),(168732,'deals-mobile','.p-account-order-pay .historyInfoColumn h2.title-payment','left','10','3','','.p-account-order-pay'),(168733,'deals-mobile','.p-account-order-pay .not_fully_paid_td','left','15','','','.p-account-order-pay'),(168734,'deals-mobile','.testimonials .review','left','10','3','',''),(168735,'deals-mobile','.testimonials .heading-3','left','0','3','',''),(168736,'deals-mobile','.p-account-history .orders-table .status-name','left','0','890','','.p-account-history'),(168737,'deals-mobile','.p-account-history .orders-table .td-alignright','left','0','890','','.p-account-history'),(168738,'deals-mobile','.p-account-index .orders-table .status-name','left','0','890','','.p-account-index'),(168739,'deals-mobile','.p-account-index .orders-table .td-alignright','left','0','890','','.p-account-index'),(168740,'deals-mobile','.w-product-personal-catalog-button .btn','left','0','3','','.w-product-personal-catalog-button'),(168741,'deals-mobile','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(168742,'deals-mobile','.p-wedding-registry-index .search-list','left','50','3','','.p-wedding-registry-index'),(168743,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no','left','-100','','','.b-form'),(168744,'deals-mobile','.p-wedding-registry-search h1','left','-10','3','','.p-wedding-registry-search'),(168745,'deals-mobile','.p-wedding-registry-manage h1','left','-10','3','','.p-wedding-registry-manage'),(168746,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','left','2','3','','.b-switch'),(168747,'deals-mobile','.w-filters .ui-slider','left','14','','','.w-filters'),(168748,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','left','2','3','','.b-switch'),(168749,'deals-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','left','0','','','.b-switch'),(168750,'deals-mobile','.b-slick button.slick-next','left','auto','','','.b-slick'),(168751,'deals-mobile','.b-slick button.slick-prev','left','0','','','.b-slick'),(168752,'deals-mobile','.w-search .search form','left','-25','','','.w-search'),(168753,'deals-mobile','.w-search .suggest','left','-25','','','.w-search'),(168754,'deals-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','left','0','','','.w-banner'),(168755,'deals-mobile','.w-banner .image-text-banner.top-left .text-banner','left','0','','','.w-banner'),(168756,'deals-mobile','.w-banner .image-text-banner.bottom-left .text-banner','left','0','','','.w-banner'),(168757,'deals-mobile','.w-banner .banner img + img','left','0','','','.w-banner'),(168758,'deals-mobile','.w-currencies .select','left','0','','','.w-currencies'),(168759,'deals-mobile','.b-slick .slick-track','left','0','','','.b-slick'),(168760,'deals-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left','50','','','.b-slick'),(168761,'deals-mobile','.p-checkout-success .page-success','left','0','3','','.p-checkout-success'),(168762,'deals-mobile','.b-info-popup .info-popup div','left','-11','3','','.b-info-popup'),(168763,'deals-mobile','.b-fancybox .fancybox-title-over-wrap','left','0','','','.b-fancybox'),(168764,'deals-mobile','.b-fancybox .fancybox-tmp','left','-99999','','','.b-fancybox'),(168765,'deals-mobile','.b-fancybox .fancybox-wrap','left','0','','','.b-fancybox'),(168766,'deals-mobile','.b-fancybox .fancybox-prev span','left','10','','','.b-fancybox'),(168767,'deals-mobile','.b-fancybox .fancybox-overlay','left','0','','','.b-fancybox'),(168768,'deals-mobile','.b-fancybox .fancybox-prev','left','0','','','.b-fancybox'),(168769,'deals-mobile','.p-account-history .not_fully_paid_td','left','15','','','.p-account-history'),(168770,'deals-mobile','.w-text .customer-service','left','0','3','','.w-text'),(168771,'deals-mobile','.w-banner .carousel-text','left','0','','','.w-banner'),(168772,'deals-mobile','.p-reviews-info .review-info-text','left','11','4','','.p-reviews-info'),(168773,'deals-mobile','.p-account-index .account_page h4','left','9','3','','.p-account-index'),(168774,'deals-mobile','.b-form .hide-billing-address','left','0','','','.b-form'),(168775,'deals-mobile','.b-fancybox #fancybox-loading','left','50','','','.b-fancybox'),(168776,'deals-mobile','.view-all','left','0','3','',''),(168777,'deals-mobile','.p-wedding-registry-share h1','left','-10','3','','.p-wedding-registry-share'),(168778,'deals-mobile','.p-wedding-registry-view h1','left','-10','3','','.p-wedding-registry-view'),(168779,'deals-mobile','.w-languages .select','left','-1','','','.w-languages'),(168780,'deals-mobile','.w-reviews .review','left','10','3','','.w-reviews'),(168781,'deals-mobile','.w-reviews .heading-3','left','0','3','','.w-reviews'),(168782,'deals-mobile','.p-account-history-info .historyInfoColumn h2.title-delivery-address, .p-account-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-history-info'),(168783,'deals-mobile','.p-account-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-history-info'),(168784,'deals-mobile','.p-account-address-book .buttonBox .info','left','-6','3','','.p-account-address-book'),(168785,'deals-mobile','.b-products-listing .hover-box-content','left','20','3','','.b-products-listing'),(168786,'deals-mobile','.b-products-listing .hover-box-content','left','0','','','.b-products-listing'),(168787,'deals-mobile','.b-products-listing .loader','left','calc(50% - 15px)','4','','.b-products-listing'),(168788,'deals-mobile','.b-products-listing .loader','left','0','3','','.b-products-listing'),(168789,'deals-mobile','.b-products-listing .products-listing .promos-info','left','0','','','.b-products-listing'),(168790,'deals-mobile','.b-products-listing .products-listing .qty-input.hidden','left','0','3','','.b-products-listing'),(168791,'deals-mobile','.b-products-listing .promo','left','0','','','.b-products-listing'),(168792,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(168793,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(168794,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(168795,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(168796,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(168797,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(168798,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','left','0','','','.b-menu-lev_display-down'),(168799,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','left','0','','','.b-menu-lev_display-down'),(168800,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','left','0','','','.b-menu-lev_display-down'),(168801,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','left','0','','','.b-menu-lev_display-down'),(168802,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','left','0','','','.b-menu-lev_display-down'),(168803,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left','100','','','.b-menu-lev_display-lra'),(168804,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left','100','','','.b-menu-lev_display-lra'),(168805,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left','100','','','.b-menu-lev_display-lra'),(168806,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left','100','','','.b-menu-lev_display-lra'),(168807,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left','100','','','.b-menu-lev_display-lra'),(168808,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','left','auto','','','.b-menu-lev_display-lra'),(168809,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','left','auto','','','.b-menu-lev_display-lra'),(168810,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','left','auto','','','.b-menu-lev_display-lra'),(168811,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','left','auto','','','.b-menu-lev_display-lra'),(168812,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','left','auto','','','.b-menu-lev_display-lra'),(168813,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left','100','','','.b-menu-lev_display-right'),(168814,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left','100','','','.b-menu-lev_display-right'),(168815,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left','100','','','.b-menu-lev_display-right'),(168816,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left','100','','','.b-menu-lev_display-right'),(168817,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left','100','','','.b-menu-lev_display-right'),(168818,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left','100','','','.b-menu-lev_display-slide'),(168819,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left','100','','','.b-menu-lev_display-slide'),(168820,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left','100','','','.b-menu-lev_display-slide'),(168821,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left','100','','','.b-menu-lev_display-slide'),(168822,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left','100','','','.b-menu-lev_display-slide'),(168823,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left','-110','','','.b-menu-open_from-left'),(168824,'deals-mobile','.b-menu-open_from-left .bi-opened .menu-style[data-open_from=\"left\"] .menu-content','left','0','','','.b-menu-open_from-left'),(168825,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','left','0','','','.b-menu-style-1'),(168826,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','left','0','','','.b-menu-style-2'),(168827,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','left','0','','','.b-menu-style-2'),(168828,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','left','20','3','','.b-menu-style-2'),(168829,'deals-mobile','.b-preloader .preloader','left','0','','','.b-preloader'),(168830,'deals-mobile','.b-preloader .preloader','left','calc(50% - 20px)','3','','.b-preloader'),(168831,'deals-mobile','.b-select-suggest .select2-container-multi .select2-search-choice-close','left','3','','','.b-select-suggest'),(168832,'deals-mobile','.b-select-suggest .select2-drop-mask','left','0','','','.b-select-suggest'),(168833,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left','0','','','.b-select-suggest'),(168834,'deals-mobile','.b-select-suggest .select2-measure-scrollbar','left','-10000','','','.b-select-suggest'),(168835,'deals-mobile','.batchPr .checkbox input:checked + span:before','left','0','','','.batchPr'),(168836,'deals-mobile','.batchPr .w-batch-products .products-listing .slick-prev','left','-10','','','.batchPr'),(168837,'deals-mobile','.batchPr .checkbox input:not(checked) + span:before','left','1','','','.batchPr'),(168838,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','left','0','','','.p-account-samples-history'),(168839,'deals-mobile','.p-account-samples-history .not_fully_paid_td','left','15','','','.p-account-samples-history'),(168840,'deals-mobile','.p-account-samples-history .not_fully_paid_td','left','15','','','.p-account-samples-history'),(168841,'deals-mobile','.p-account-samples-history .orders-table .status-name','left','0','','','.p-account-samples-history'),(168842,'deals-mobile','.p-account-samples-history .orders-table .status-name','left','0','','','.p-account-samples-history'),(168843,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','left','0','','','.p-account-samples-history'),(168844,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','left','0','','','.p-account-samples-history'),(168845,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','left','0','','','.p-account-samples-history'),(168846,'deals-mobile','.p-account-samples-history .orders-table .status-name','left','0','','','.p-account-samples-history'),(168847,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','left','0','','','.p-account-samples-history'),(168848,'deals-mobile','.p-account-samples-history .not_fully_paid_td','left','15','','','.p-account-samples-history'),(168849,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','left','0','','','.p-account-samples-history'),(168850,'deals-mobile','.p-account-samples-history .not_fully_paid_td','left','15','','','.p-account-samples-history'),(168851,'deals-mobile','.p-account-samples-history .orders-table .status-name','left','0','','','.p-account-samples-history'),(168852,'deals-mobile','.p-account-samples-history .orders-table .status-name','left','0','','','.p-account-samples-history'),(168853,'deals-mobile','.p-account-samples-history .orders-table .status-name','left','0','','','.p-account-samples-history'),(168854,'deals-mobile','.p-account-samples-history .not_fully_paid_td','left','15','','','.p-account-samples-history'),(168855,'deals-mobile','.p-account-samples-history .not_fully_paid_td','left','15','','','.p-account-samples-history'),(168856,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-samples-history-info'),(168857,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-samples-history-info'),(168858,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','left','15','','','.p-account-samples-history-info'),(168859,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','left','15','','','.p-account-samples-history-info'),(168860,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-samples-history-info'),(168861,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-samples-history-info'),(168862,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-samples-history-info'),(168863,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-samples-history-info'),(168864,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','left','15','','','.p-account-samples-history-info'),(168865,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-samples-history-info'),(168866,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-samples-history-info'),(168867,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','left','1','3','','.p-account-samples-history-info'),(168868,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','left','1','3','','.p-account-samples-history-info'),(168869,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-samples-history-info'),(168870,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-samples-history-info'),(168871,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-payment','left','10','3','','.p-account-samples-history-info'),(168872,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','left','15','','','.p-account-samples-history-info'),(168873,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','left','1','3','','.p-account-samples-history-info'),(168874,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','left','15','','','.p-account-samples-history-info'),(168875,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','left','1','3','','.p-account-samples-history-info'),(168876,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','left','1','3','','.p-account-samples-history-info'),(168877,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2.title-delivery-address, .p-account-samples-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.p-account-samples-history-info'),(168878,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','left','1','3','','.p-account-samples-history-info'),(168879,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','left','15','','','.p-account-samples-history-info'),(168880,'deals-mobile','.p-catalog-product .prev-product','left','0','','','.p-catalog-product'),(168881,'deals-mobile','.p-catalog-product .prev-product .pn-image','left','20','3','','.p-catalog-product'),(168882,'deals-mobile','.p-quick-order-index .all-scroll-div','left','0','','','.p-quick-order-index'),(168883,'deals-mobile','.w-blog-widget-categories-list a','left','0','3','','.w-blog-widget-categories-list'),(168884,'deals-mobile','.w-blog-widget-most-popular-posts a','left','0','3','','.w-blog-widget-most-popular-posts'),(168885,'deals-mobile','.w-blog-widget-post-comments-count span','left','0','3','','.w-blog-widget-post-comments-count'),(168886,'deals-mobile','.w-blog-widget-post-linked-products button.slick-prev','left','10','','','.w-blog-widget-post-linked-products'),(168887,'deals-mobile','.w-blog-widget-post-listing .post_comment','left','0','3','','.w-blog-widget-post-listing'),(168888,'deals-mobile','.w-blog-widget-post-share','left','112','0,4','','.w-blog-widget-post-share'),(168889,'deals-mobile','.w-blog-widget-related-posts button.slick-prev','left','13','','','.w-blog-widget-related-posts'),(168890,'deals-mobile','.w-blog-widget-related-posts-by-category button.slick-prev','left','13','','','.w-blog-widget-related-posts-by-category'),(168891,'deals-mobile','.w-cart-compare .dropdown .dropdown-menu','left','auto','','','.w-cart-compare'),(168892,'deals-mobile','.w-catalog-b2b-add-button ','left','0','','','.w-catalog-b2b-add-button'),(168893,'deals-mobile','.w-checkout-billing-address .addresses .address-item label input','left','0','','','.w-checkout-billing-address'),(168894,'deals-mobile','.w-checkout-shipping-address .addresses .address-item label input','left','0','','','.w-checkout-shipping-address'),(168895,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','left','50','','','.w-checkout-shipping-choice'),(168896,'deals-mobile','.w-checkout-terms .required-message','left','0','','','.w-checkout-terms'),(168897,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','left','0','','','.w-image-maps'),(168898,'deals-mobile','.w-image-maps .svg-wrap svg','left','0','','','.w-image-maps'),(168899,'deals-mobile','.w-multi-cart-actions .dropdown .dropdown-menu','left','auto','','','.w-multi-cart-actions'),(168900,'deals-mobile','.w-reviews-content .review','left','15','3','','.w-reviews-content'),(168901,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(168902,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(168903,'deals-mobile','.w-wedding-registry-widgets-delete-link a','left','-3','4','','.w-wedding-registry-widgets-delete-link'),(168904,'deals-mobile','.w-wedding-registry-widgets-share-link a','left','-3','4','','.w-wedding-registry-widgets-share-link'),(168905,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left_important','important','','','.b-select-suggest'),(168906,'deals-mobile','.p-wedding-registry-index .search-list','left_measure','%','3','','.p-wedding-registry-index'),(168907,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no','left_measure','vw','','','.b-form'),(168908,'deals-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left_measure','%','','','.b-slick'),(168909,'deals-mobile','.w-search .search form','left_measure','vw','','','.w-search'),(168910,'deals-mobile','.b-fancybox #fancybox-loading','left_measure','%','','','.b-fancybox'),(168911,'deals-mobile','.w-search .suggest','left_measure','vw','','','.w-search'),(168912,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left_measure','%','','','.b-menu-lev_display-lra'),(168913,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left_measure','%','','','.b-menu-lev_display-lra'),(168914,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left_measure','%','','','.b-menu-lev_display-lra'),(168915,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left_measure','%','','','.b-menu-lev_display-lra'),(168916,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left_measure','%','','','.b-menu-lev_display-lra'),(168917,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left_measure','%','','','.b-menu-lev_display-right'),(168918,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left_measure','%','','','.b-menu-lev_display-right'),(168919,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left_measure','%','','','.b-menu-lev_display-right'),(168920,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left_measure','%','','','.b-menu-lev_display-right'),(168921,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left_measure','%','','','.b-menu-lev_display-right'),(168922,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left_measure','vw','','','.b-menu-lev_display-slide'),(168923,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left_measure','vw','','','.b-menu-lev_display-slide'),(168924,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left_measure','vw','','','.b-menu-lev_display-slide'),(168925,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left_measure','vw','','','.b-menu-lev_display-slide'),(168926,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left_measure','vw','','','.b-menu-lev_display-slide'),(168927,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left_measure','vw','','','.b-menu-open_from-left'),(168928,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','left_measure','%','','','.w-checkout-shipping-choice'),(168929,'deals-mobile','.w-menu-slider .close','line-height','10','','','.w-menu-slider'),(168930,'deals-mobile','.w-bestsellers .counter','line-height','34','','','.w-bestsellers'),(168931,'deals-mobile','.w-bestsellers .item','line-height','33','3','','.w-bestsellers'),(168932,'deals-mobile','.w-bestsellers .heading-3','line-height','1','3','','.w-bestsellers'),(168933,'deals-mobile','.w-account .my-acc-link','line-height','39','3','','.w-account'),(168934,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line-height','18','','','.b-form'),(168935,'deals-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','line-height','18','','','.b-form'),(168936,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','line-height','22','','','.b-form'),(168937,'deals-mobile','.w-product-sale-ends .ends','line-height','1','','','.w-product-sale-ends'),(168938,'deals-mobile','.w-menu-slider .menu-ico','line-height','54','','','.w-menu-slider'),(168939,'deals-mobile','.w-list-type-2_2 .sale','line-height','22','4','','.w-list-type-2_2'),(168940,'deals-mobile','.w-menu-horizontal .menu-ico','line-height','54','','','.w-menu-horizontal'),(168941,'deals-mobile','.w-sale .name','line-height','1.2','','','.w-sale'),(168942,'deals-mobile','.w-sale .badge','line-height','27','','','.w-sale'),(168943,'deals-mobile','.w-menu-style-1 .menu-ico','line-height','48','','','.w-menu-style-1'),(168944,'deals-mobile','.w-cart .cart-box-link','line-height','38','3','','.w-cart'),(168945,'deals-mobile','.b-fancybox .fancybox-nav span','line-height','40','','','.b-fancybox'),(168946,'deals-mobile','.p-account-history .order_history_table th','line-height','16','','','.p-account-history'),(168947,'deals-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','line-height','20','','','.p-account-index'),(168948,'deals-mobile','.w-quote .cart-box-link','line-height','0.75','3','','.w-quote'),(168949,'deals-mobile','.w-reviews .heading-3','line-height','1','3','','.w-reviews'),(168950,'deals-mobile','.w-catalog-listing-look .list','line-height','30','','','.w-catalog-listing-look'),(168951,'deals-mobile','.w-catalog-listing-look .b2b','line-height','30','','','.w-catalog-listing-look'),(168952,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line-height','35','3','','.b-multi-page-checkout'),(168953,'deals-mobile','.w-product-personal-catalog-button .btn','line-height','14','','','.w-product-personal-catalog-button'),(168954,'deals-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','line-height','20','','','.p-account-history'),(168955,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line-height','31','','','.b-multi-page-checkout'),(168956,'deals-mobile','.b-info-popup .info-popup div','line-height','1.7','','','.b-info-popup'),(168957,'deals-mobile','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(168958,'deals-mobile','.testimonials .heading-3','line-height','1','3','',''),(168959,'deals-mobile','.b-pagination .pagination .prev','line-height','26','3','','.b-pagination'),(168960,'deals-mobile','.b-pagination .pagination .prev','line-height','30','','','.b-pagination'),(168961,'deals-mobile','.b-pagination .pagination .prev-pages','line-height','30','','','.b-pagination'),(168962,'deals-mobile','.b-pagination .pagination .page-number','line-height','30','','','.b-pagination'),(168963,'deals-mobile','.p-wedding-registry-manage .wr-search button','line-height','1.3','3','','.p-wedding-registry-manage'),(168964,'deals-mobile','.b-pagination .pagination .next-pages','line-height','30','','','.b-pagination'),(168965,'deals-mobile','.b-pagination .pagination .next','line-height','26','3','','.b-pagination'),(168966,'deals-mobile','.b-pagination .pagination span','line-height','30','2','','.b-pagination'),(168967,'deals-mobile','.b-pagination .pagination .next','line-height','30','','','.b-pagination'),(168968,'deals-mobile','.p-account-history .view_link','line-height','17','4','','.p-account-history'),(168969,'deals-mobile','.p-account-history .orders-table .td-alignright','line-height','35','890','','.p-account-history'),(168970,'deals-mobile','.p-account-index .orders-table .td-alignright','line-height','35','890','','.p-account-index'),(168971,'deals-mobile','.p-blog-index .nav-previous a','line-height','50','3','','.p-blog-index'),(168972,'deals-mobile','.p-blog-index .nav-next a','line-height','50','3','','.p-blog-index'),(168973,'deals-mobile','.w-list-type-2_2 .price','line-height','100','','','.w-list-type-2_2'),(168974,'deals-mobile','.w-list-type-2_2 .sale','line-height','19','3','','.w-list-type-2_2'),(168975,'deals-mobile','.w-list-type-2_2 .description','line-height','120','','','.w-list-type-2_2'),(168976,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','line-height','34','3','','.w-list-type-2_2'),(168977,'deals-mobile','.w-list-type-2_2 .button-wishlist button','line-height','28','','','.w-list-type-2_2'),(168978,'deals-mobile','.w-list-type-2_2 .button-view a','line-height','28','','','.w-list-type-2_2'),(168979,'deals-mobile','.w-list-type-2 .sale','line-height','19','3','','.w-list-type-2'),(168980,'deals-mobile','.w-product-personal-catalog-button .btn','line-height','1','3','','.w-product-personal-catalog-button'),(168981,'deals-mobile','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(168982,'deals-mobile','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(168983,'deals-mobile','.w-product-wedding-registry-button .btn','line-height','14','','','.w-product-wedding-registry-button'),(168984,'deals-mobile','.b-fancybox .fancybox-close','line-height','1','','','.b-fancybox'),(168985,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','line-height','30','3','','.b-form'),(168986,'deals-mobile','.p-wedding-registry-manage .links a.share-registry','line-height','30','','','.p-wedding-registry-manage'),(168987,'deals-mobile','.p-wedding-registry-manage .links a','line-height','20','','','.p-wedding-registry-manage'),(168988,'deals-mobile','.b-pagination .pagination a','line-height','30','','','.b-pagination'),(168989,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line-height','30','','','.b-switch'),(168990,'deals-mobile','.w-quote .cart-box-link','line-height','39','872,3','','.w-quote'),(168991,'deals-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','line-height','40','','','.b-quantity'),(168992,'deals-mobile','.b-switch .bootstrap-switch','line-height','28','','','.b-switch'),(168993,'deals-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line-height','36','','','.b-slick'),(168994,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','38','','','.b-slick'),(168995,'deals-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','line-height','22','','','.w-filters'),(168996,'deals-mobile','.w-search .search','line-height','48','3','','.w-search'),(168997,'deals-mobile','.btn','line-height','20','','',''),(168998,'deals-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','line-height','22','','','.w-filters'),(168999,'deals-mobile','.w-currencies .current','line-height','1','3','','.w-currencies'),(169000,'deals-mobile','.w-currencies .currencies-title','line-height','15','','','.w-currencies'),(169001,'deals-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line-height','24','','','.w-compare-box-item'),(169002,'deals-mobile','.p-account-subscription-historyinfo .order_history_table th','line-height','16','','','.p-account-subscription-historyinfo'),(169003,'deals-mobile','.b-info-popup .info-popup div','line-height','30','3','','.b-info-popup'),(169004,'deals-mobile','.p-account-index .view_link','line-height','17','4','','.p-account-index'),(169005,'deals-mobile','.b-info-popup .info-popup','line-height','2','','','.b-info-popup'),(169006,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','line-height','24','','','.b-fancybox'),(169007,'deals-mobile','.w-menu-mobile .menu-ico','line-height','48','','','.w-menu-mobile'),(169008,'deals-mobile','.w-sale .ends','line-height','1','','','.w-sale'),(169009,'deals-mobile','.w-sale .old','line-height','0.8','','','.w-sale'),(169010,'deals-mobile','.w-sale .special-price','line-height','0.8','','','.w-sale'),(169011,'deals-mobile','.w-text .customer-service b','line-height','18','','','.w-text'),(169012,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','48','876','','.b-slick'),(169013,'deals-mobile','.b-form .cart-popup .price','line-height','35','','','.b-form'),(169014,'deals-mobile','.b-quantity .qty-box .bigger','line-height','35','','','.b-quantity'),(169015,'deals-mobile','.b-quantity .qty-box .smaller','line-height','35','','','.b-quantity'),(169016,'deals-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','line-height','16','3','','.w-cart-discount-coupon'),(169017,'deals-mobile','.p-account-index .account_page h4','line-height','30','3','','.p-account-index'),(169018,'deals-mobile','.b-form .form-inputs div.required-message','line-height','1.3','','','.b-form'),(169019,'deals-mobile','.p-account-index .topAccount > li > div','line-height','40','3','','.p-account-index'),(169020,'deals-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(169021,'deals-mobile','.w-catalog-listing-look .grid','line-height','30','','','.w-catalog-listing-look'),(169022,'deals-mobile','.w-list-type-2 .button-wishlist button','line-height','28','','','.w-list-type-2'),(169023,'deals-mobile','.w-list-type-1_3 .sale','line-height','19','3','','.w-list-type-1_3'),(169024,'deals-mobile','.w-list-type-2 .sale','line-height','22','4','','.w-list-type-2'),(169025,'deals-mobile','.w-list-type-2 .description','line-height','120','','','.w-list-type-2'),(169026,'deals-mobile','.w-list-type-2 .price','line-height','100','','','.w-list-type-2'),(169027,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','line-height','34','3','','.w-list-type-2'),(169028,'deals-mobile','.w-list-type-1_3 .sale','line-height','22','4','','.w-list-type-1_3'),(169029,'deals-mobile','.w-list-type-2 .button-view a','line-height','28','','','.w-list-type-2'),(169030,'deals-mobile','.btn-3','line-height','20','','',''),(169031,'deals-mobile','.w-list-type-1_3 .description','line-height','120','','','.w-list-type-1_3'),(169032,'deals-mobile','.w-list-type-1_3 .price','line-height','100','','','.w-list-type-1_3'),(169033,'deals-mobile','.btn-2','line-height','20','','',''),(169034,'deals-mobile','.btn-1','line-height','24','','',''),(169035,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','line-height','34','3','','.w-list-type-1_3'),(169036,'deals-mobile','.w-list-type-1_3 .button-view a','line-height','28','','','.w-list-type-1_3'),(169037,'deals-mobile','.w-list-type-1_3 .button-wishlist button','line-height','28','','','.w-list-type-1_3'),(169038,'deals-mobile','.w-list-type-1_2 .sale','line-height','19','3','','.w-list-type-1_2'),(169039,'deals-mobile','.w-list-type-1_2 .description','line-height','120','','','.w-list-type-1_2'),(169040,'deals-mobile','.w-list-type-1_2 .sale','line-height','22','4','','.w-list-type-1_2'),(169041,'deals-mobile','.w-list-type-1_2 .price','line-height','100','','','.w-list-type-1_2'),(169042,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','line-height','34','3','','.w-list-type-1_2'),(169043,'deals-mobile','.w-list-type-1_2 .button-wishlist button','line-height','28','','','.w-list-type-1_2'),(169044,'deals-mobile','.b-bottom .pop-up-close','line-height','25','','','.b-bottom'),(169045,'deals-mobile','.w-list-type-1_2 .button-view a','line-height','28','','','.w-list-type-1_2'),(169046,'deals-mobile','.w-list-type-1 .sale','line-height','22','4','','.w-list-type-1'),(169047,'deals-mobile','.w-list-type-1 .sale','line-height','19','3','','.w-list-type-1'),(169048,'deals-mobile','.heading-4 .edit, h4 .edit','line-height','20','','',''),(169049,'deals-mobile','.w-list-type-1 .description','line-height','120','','','.w-list-type-1'),(169050,'deals-mobile','.heading-3 .edit, h3 .edit','line-height','20','','',''),(169051,'deals-mobile','.heading-4 .right-text, h4 .right-text','line-height','20','','',''),(169052,'deals-mobile','.heading-3 .right-text, h3 .right-text','line-height','20','','',''),(169053,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','line-height','34','3','','.w-list-type-1'),(169054,'deals-mobile','.w-list-type-1 .price','line-height','100','','','.w-list-type-1'),(169055,'deals-mobile','.w-list-type-1 .button-wishlist button','line-height','28','','','.w-list-type-1'),(169056,'deals-mobile','.w-list-type-1 .button-view a','line-height','28','','','.w-list-type-1'),(169057,'deals-mobile','.w-languages .current','line-height','1','3','','.w-languages'),(169058,'deals-mobile','.p-account-index .date_value, .p-account-index .date_title','line-height','22','','','.p-account-index'),(169059,'deals-mobile','.w-search .button-search','line-height','1.3','3','','.w-search'),(169060,'deals-mobile','.w-socials .post_item > div','line-height','19','','','.w-socials'),(169061,'deals-mobile','.b-info .info','line-height','1','3','','.b-info'),(169062,'deals-mobile','.b-products-listing .btn-preloader','line-height','24','3','','.b-products-listing'),(169063,'deals-mobile','.b-products-listing .loader','line-height','30','4','','.b-products-listing'),(169064,'deals-mobile','.b-products-listing .products-listing .btn-buy','line-height','10','3','','.b-products-listing'),(169065,'deals-mobile','.b-products-listing .products-listing .btn-preloader','line-height','8','','','.b-products-listing'),(169066,'deals-mobile','.b-products-listing .products-listing .name a','line-height','1.5','','','.b-products-listing'),(169067,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.b-data-table'),(169068,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.b-data-table'),(169069,'deals-mobile','.b-data-table table.dataTable thead td','line-height','1.5','','','.b-data-table'),(169070,'deals-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line-height','30','','','.b-menu-burger_icon'),(169071,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(169072,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(169073,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(169074,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(169075,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(169076,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','line-height','1.2','','','.b-menu-style-1'),(169077,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','line-height','24','','','.b-menu-style-2'),(169078,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','line-height','24','','','.b-menu-style-2'),(169079,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','line-height','50','','','.b-menu-style-2'),(169080,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','line-height','16','3','','.b-menu-style-2'),(169081,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','line-height','16','3','','.b-menu-style-2'),(169082,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','line-height','1.2','','','.b-menu-style-3'),(169083,'deals-mobile','.b-messages span.starred::before','line-height','10','','','.b-messages'),(169084,'deals-mobile','.b-messages .messBtnMenuStarred','line-height','10','3','','.b-messages'),(169085,'deals-mobile','.b-messages .messBtnMenuDelete','line-height','10','3','','.b-messages'),(169086,'deals-mobile','.b-messages .messBtnMenuUnread','line-height','10','3','','.b-messages'),(169087,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line-height','14','','','.b-messages'),(169088,'deals-mobile','.b-preloader .preloader','line-height','40','3','','.b-preloader'),(169089,'deals-mobile','.b-select-suggest .select2-container .select2-choice','line-height','26','','','.b-select-suggest'),(169090,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line-height','13','','','.b-select-suggest'),(169091,'deals-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(169092,'deals-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(169093,'deals-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(169094,'deals-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(169095,'deals-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(169096,'deals-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(169097,'deals-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(169098,'deals-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(169099,'deals-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(169100,'deals-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(169101,'deals-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(169102,'deals-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(169103,'deals-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(169104,'deals-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(169105,'deals-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(169106,'deals-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(169107,'deals-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(169108,'deals-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(169109,'deals-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','line-height','1.3','','','.b-trade-approval'),(169110,'deals-mobile','.b-upload-file .snapshot','line-height','38','','','.b-upload-file'),(169111,'deals-mobile','.batchPr .btn-batch-remove','line-height','1','3','','.batchPr'),(169112,'deals-mobile','.batchPr .batchSelect .checkbox','line-height','36','','','.batchPr'),(169113,'deals-mobile','.batchPr .checkbox input:not(checked) + span:before','line-height','33','','','.batchPr'),(169114,'deals-mobile','.batchPr .btn-batch-remove','line-height','0','','','.batchPr'),(169115,'deals-mobile','.bell-ico .heading-2','line-height','10','3','','.bell-ico'),(169116,'deals-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(169117,'deals-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(169118,'deals-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(169119,'deals-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(169120,'deals-mobile','.p-account-samples-history .order_history_table th','line-height','16','','','.p-account-samples-history'),(169121,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line-height','20','','','.p-account-samples-history'),(169122,'deals-mobile','.p-account-samples-history .order_history_table th','line-height','16','','','.p-account-samples-history'),(169123,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','line-height','35','','','.p-account-samples-history'),(169124,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','line-height','35','','','.p-account-samples-history'),(169125,'deals-mobile','.p-account-samples-history .view_link','line-height','17','4','','.p-account-samples-history'),(169126,'deals-mobile','.p-account-samples-history .view_link','line-height','17','4','','.p-account-samples-history'),(169127,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','line-height','35','','','.p-account-samples-history'),(169128,'deals-mobile','.p-account-samples-history .view_link','line-height','17','4','','.p-account-samples-history'),(169129,'deals-mobile','.p-account-samples-history .order_history_table th','line-height','16','','','.p-account-samples-history'),(169130,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','line-height','35','','','.p-account-samples-history'),(169131,'deals-mobile','.p-account-samples-history .order_history_table th','line-height','16','','','.p-account-samples-history'),(169132,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line-height','20','','','.p-account-samples-history'),(169133,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line-height','20','','','.p-account-samples-history'),(169134,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line-height','20','','','.p-account-samples-history'),(169135,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','line-height','35','','','.p-account-samples-history'),(169136,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line-height','20','','','.p-account-samples-history'),(169137,'deals-mobile','.p-account-samples-history .view_link','line-height','17','4','','.p-account-samples-history'),(169138,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','line-height','35','','','.p-account-samples-history'),(169139,'deals-mobile','.p-account-samples-history .view_link','line-height','17','4','','.p-account-samples-history'),(169140,'deals-mobile','.p-account-samples-history .order_history_table th','line-height','16','','','.p-account-samples-history'),(169141,'deals-mobile','.p-account-samples-history .order_history_table th','line-height','16','','','.p-account-samples-history'),(169142,'deals-mobile','.p-account-samples-history .view_link','line-height','17','4','','.p-account-samples-history'),(169143,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line-height','20','','','.p-account-samples-history'),(169144,'deals-mobile','.p-catalog-product .pn-direction','line-height','1.2','','','.p-catalog-product'),(169145,'deals-mobile','.p-catalog-product .pn-image','line-height','24','3','','.p-catalog-product'),(169146,'deals-mobile','.p-payer-order-confirmation .ship-ico','line-height','20','3','','.p-payer-order-confirmation'),(169147,'deals-mobile','.p-payer-order-confirmation .discount-ico','line-height','20','3','','.p-payer-order-confirmation'),(169148,'deals-mobile','.p-payer-order-confirmation .comment-ico','line-height','20','3','','.p-payer-order-confirmation'),(169149,'deals-mobile','.p-payer-order-confirmation .order-ico','line-height','20','3','','.p-payer-order-confirmation'),(169150,'deals-mobile','.p-payer-order-confirmation .pay-ico','line-height','20','3','','.p-payer-order-confirmation'),(169151,'deals-mobile','.p-payer-order-pay .pay-ico','line-height','20','3','','.p-payer-order-pay'),(169152,'deals-mobile','.p-payer-order-pay .order-ico','line-height','20','3','','.p-payer-order-pay'),(169153,'deals-mobile','.p-payer-order-pay .ship-ico','line-height','20','3','','.p-payer-order-pay'),(169154,'deals-mobile','.p-payer-order-pay .comment-ico','line-height','20','3','','.p-payer-order-pay'),(169155,'deals-mobile','.p-payer-order-pay .discount-ico','line-height','20','3','','.p-payer-order-pay'),(169156,'deals-mobile','.p-quick-order-index .paginate_button.previous','line-height','26','3','','.p-quick-order-index'),(169157,'deals-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','line-height','1.2','','','.p-quick-order-index'),(169158,'deals-mobile','.p-quick-order-index .stock','line-height','1.2','','','.p-quick-order-index'),(169159,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.p-quick-order-index'),(169160,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.p-quick-order-index'),(169161,'deals-mobile','.p-quick-order-index .paginate_button.next','line-height','26','3','','.p-quick-order-index'),(169162,'deals-mobile','.savings-ico .heading-2','line-height','10','3','','.savings-ico'),(169163,'deals-mobile','.shipping-ico .heading-2','line-height','10','3','','.shipping-ico'),(169164,'deals-mobile','.shipping-ico .heading-2','line-height','10','3','','.shipping-ico'),(169165,'deals-mobile','.shipping-ico .heading-2','line-height','10','3','','.shipping-ico'),(169166,'deals-mobile','.w-blog-widget-categories-list a','line-height','1','3','','.w-blog-widget-categories-list'),(169167,'deals-mobile','.w-blog-widget-most-popular-posts a','line-height','1','3','','.w-blog-widget-most-popular-posts'),(169168,'deals-mobile','.w-blog-widget-post-listing .post_date span + span','line-height','1','3','','.w-blog-widget-post-listing'),(169169,'deals-mobile','.w-blog-widget-post-listing .post_name','line-height','1.2','','','.w-blog-widget-post-listing'),(169170,'deals-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','line-height','1','','','.w-blog-widget-post-share'),(169171,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','line-height','35','','','.w-blog-widget-related-posts'),(169172,'deals-mobile','.w-cart-compare .compare-table','line-height','1.3','','','.w-cart-compare'),(169173,'deals-mobile','.w-cart-compare .delete-cart','line-height','1','','','.w-cart-compare'),(169174,'deals-mobile','.w-cart-compare .price-cell','line-height','22','','','.w-cart-compare'),(169175,'deals-mobile','.w-cart-compare .js-cart_totals_container','line-height','1.2','','','.w-cart-compare'),(169176,'deals-mobile','.w-cart-compare .attributes-cell','line-height','22','','','.w-cart-compare'),(169177,'deals-mobile','.w-cart-compare .cart-name a','line-height','1.2','','','.w-cart-compare'),(169178,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line-height','24','3','','.w-catalog-compare'),(169179,'deals-mobile','.w-catalog-compare td','line-height','1.5','','','.w-catalog-compare'),(169180,'deals-mobile','.w-catalog-compare span.btn-preloader','line-height','24','3','','.w-catalog-compare'),(169181,'deals-mobile','.w-catalog-paging .next','line-height','26','3','','.w-catalog-paging'),(169182,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line-height','30','','','.w-catalog-paging'),(169183,'deals-mobile','.w-catalog-paging .next','line-height','30','','','.w-catalog-paging'),(169184,'deals-mobile','.w-catalog-paging ','line-height','30','2','','.w-catalog-paging'),(169185,'deals-mobile','.w-catalog-paging .next-pages','line-height','30','','','.w-catalog-paging'),(169186,'deals-mobile','.w-catalog-paging .page-number','line-height','30','','','.w-catalog-paging'),(169187,'deals-mobile','.w-catalog-paging .prev-pages','line-height','30','','','.w-catalog-paging'),(169188,'deals-mobile','.w-catalog-paging .prev','line-height','30','','','.w-catalog-paging'),(169189,'deals-mobile','.w-catalog-paging .prev','line-height','26','3','','.w-catalog-paging'),(169190,'deals-mobile','.w-checkout-billing-address .addresses .address-item label','line-height','1.3','','','.w-checkout-billing-address'),(169191,'deals-mobile','.w-checkout-create-account .account-benefits strong','line-height','16','3','','.w-checkout-create-account'),(169192,'deals-mobile','.w-checkout-shipping-address .addresses .address-item label','line-height','1.3','','','.w-checkout-shipping-address'),(169193,'deals-mobile','.w-checkout-shipping-choice span','line-height','19','','','.w-checkout-shipping-choice'),(169194,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','35','3','','.w-communication-new-topic'),(169195,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line-height','36','','','.w-communication-new-topic'),(169196,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','40','','','.w-communication-new-topic'),(169197,'deals-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','line-height','1.2','','','.w-communication-new-topic'),(169198,'deals-mobile','.w-delivery-day .ends','line-height','1','','','.w-delivery-day'),(169199,'deals-mobile','.w-multi-cart-cart-switcher .cart-label','line-height','20','','','.w-multi-cart-cart-switcher'),(169200,'deals-mobile','.w-personal-gift-status-bar .end-date','line-height','14','3','','.w-personal-gift-status-bar'),(169201,'deals-mobile','.w-personal-gift-status-bar .inform','line-height','14','4','','.w-personal-gift-status-bar'),(169202,'deals-mobile','.w-product-customers-activity .close','line-height','32','','','.w-product-customers-activity'),(169203,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','line-height','23','','','.w-promotions'),(169204,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','line-height','23','','','.w-promotions'),(169205,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','line-height','23','','','.w-promotions'),(169206,'deals-mobile','.w-promotions .promo-salemaker .discount','line-height','23','','','.w-promotions'),(169207,'deals-mobile','.w-promotions .heading-3','line-height','1','','','.w-promotions'),(169208,'deals-mobile','.w-menu-slider .close','line_height_measure','px','','','.w-menu-slider'),(169209,'deals-mobile','.w-catalog-listing-look .list','line_height_measure','px','','','.w-catalog-listing-look'),(169210,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','line_height_measure','px','','','.b-form'),(169211,'deals-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','line_height_measure','px','','','.b-form'),(169212,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line_height_measure','px','','','.b-form'),(169213,'deals-mobile','.w-sale .badge','line_height_measure','px','','','.w-sale'),(169214,'deals-mobile','.w-product-wedding-registry-button .btn','line_height_measure','px','','','.w-product-wedding-registry-button'),(169215,'deals-mobile','.p-account-history .order_history_table th','line_height_measure','px','','','.p-account-history'),(169216,'deals-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','line_height_measure','px','','','.p-account-index'),(169217,'deals-mobile','.w-bestsellers .item','line_height_measure','px','3','','.w-bestsellers'),(169218,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line_height_measure','px','3','','.b-multi-page-checkout'),(169219,'deals-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-discount-coupon'),(169220,'deals-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(169221,'deals-mobile','.w-catalog-listing-look .b2b','line_height_measure','px','','','.w-catalog-listing-look'),(169222,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line_height_measure','px','','','.b-multi-page-checkout'),(169223,'deals-mobile','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(169224,'deals-mobile','.b-pagination .pagination .prev-pages','line_height_measure','px','','','.b-pagination'),(169225,'deals-mobile','.b-pagination .pagination .prev','line_height_measure','px','3','','.b-pagination'),(169226,'deals-mobile','.b-pagination .pagination .prev','line_height_measure','px','','','.b-pagination'),(169227,'deals-mobile','.b-pagination .pagination .next-pages','line_height_measure','px','','','.b-pagination'),(169228,'deals-mobile','.b-pagination .pagination .page-number','line_height_measure','px','','','.b-pagination'),(169229,'deals-mobile','.b-pagination .pagination .next','line_height_measure','px','3','','.b-pagination'),(169230,'deals-mobile','.b-pagination .pagination .next','line_height_measure','px','','','.b-pagination'),(169231,'deals-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','line_height_measure','px','','','.p-account-history'),(169232,'deals-mobile','.b-pagination .pagination span','line_height_measure','px','2','','.b-pagination'),(169233,'deals-mobile','.p-account-history .view_link','line_height_measure','px','4','','.p-account-history'),(169234,'deals-mobile','.p-account-history .orders-table .td-alignright','line_height_measure','px','890','','.p-account-history'),(169235,'deals-mobile','.p-account-index .orders-table .td-alignright','line_height_measure','px','890','','.p-account-index'),(169236,'deals-mobile','.p-blog-index .nav-previous a','line_height_measure','px','3','','.p-blog-index'),(169237,'deals-mobile','.p-blog-index .nav-next a','line_height_measure','px','3','','.p-blog-index'),(169238,'deals-mobile','.w-list-type-2_2 .price','line_height_measure','%','','','.w-list-type-2_2'),(169239,'deals-mobile','.w-list-type-2_2 .description','line_height_measure','%','','','.w-list-type-2_2'),(169240,'deals-mobile','.w-product-personal-catalog-button .btn','line_height_measure','px','','','.w-product-personal-catalog-button'),(169241,'deals-mobile','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(169242,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','line_height_measure','px','3','','.b-form'),(169243,'deals-mobile','.p-wedding-registry-manage .links a','line_height_measure','px','','','.p-wedding-registry-manage'),(169244,'deals-mobile','.p-wedding-registry-manage .links a.share-registry','line_height_measure','px','','','.p-wedding-registry-manage'),(169245,'deals-mobile','.b-pagination .pagination a','line_height_measure','px','','','.b-pagination'),(169246,'deals-mobile','.b-switch .bootstrap-switch','line_height_measure','px','','','.b-switch'),(169247,'deals-mobile','.w-quote .cart-box-link','line_height_measure','px','872,3','','.w-quote'),(169248,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line_height_measure','px','','','.b-switch'),(169249,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','line_height_measure','px','','','.b-fancybox'),(169250,'deals-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(169251,'deals-mobile','.w-catalog-listing-look .grid','line_height_measure','px','','','.w-catalog-listing-look'),(169252,'deals-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line_height_measure','px','','','.b-slick'),(169253,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','','','.b-slick'),(169254,'deals-mobile','.w-search .search','line_height_measure','px','3','','.w-search'),(169255,'deals-mobile','.p-account-subscription-historyinfo .order_history_table th','line_height_measure','px','','','.p-account-subscription-historyinfo'),(169256,'deals-mobile','.b-info-popup .info-popup','line_height_measure','px','','','.b-info-popup'),(169257,'deals-mobile','.p-account-index .view_link','line_height_measure','px','4','','.p-account-index'),(169258,'deals-mobile','.w-menu-mobile .menu-ico','line_height_measure','px','','','.w-menu-mobile'),(169259,'deals-mobile','.w-list-type-1_3 .price','line_height_measure','%','','','.w-list-type-1_3'),(169260,'deals-mobile','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(169261,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','876','','.b-slick'),(169262,'deals-mobile','.b-form .cart-popup .price','line_height_measure','px','','','.b-form'),(169263,'deals-mobile','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(169264,'deals-mobile','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(169265,'deals-mobile','.w-cart .cart-box-link','line_height_measure','px','3','','.w-cart'),(169266,'deals-mobile','.w-menu-style-1 .menu-ico','line_height_measure','px','','','.w-menu-style-1'),(169267,'deals-mobile','.w-account .my-acc-link','line_height_measure','px','3','','.w-account'),(169268,'deals-mobile','.b-fancybox .fancybox-nav span','line_height_measure','px','','','.b-fancybox'),(169269,'deals-mobile','.btn','line_height_measure','px','','',''),(169270,'deals-mobile','.p-account-index .account_page h4','line_height_measure','px','3','','.p-account-index'),(169271,'deals-mobile','.p-account-index .topAccount > li > div','line_height_measure','px','3','','.p-account-index'),(169272,'deals-mobile','.btn-3','line_height_measure','px','','',''),(169273,'deals-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','line_height_measure','px','','','.w-filters'),(169274,'deals-mobile','.btn-1','line_height_measure','px','','',''),(169275,'deals-mobile','.heading-4 .right-text, h4 .right-text','line_height_measure','px','','',''),(169276,'deals-mobile','.heading-3 .edit, h3 .edit','line_height_measure','px','','',''),(169277,'deals-mobile','.btn-2','line_height_measure','px','','',''),(169278,'deals-mobile','.w-currencies .currencies-title','line_height_measure','px','','','.w-currencies'),(169279,'deals-mobile','.w-list-type-1 .sale','line_height_measure','px','4','','.w-list-type-1'),(169280,'deals-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','line_height_measure','px','','','.w-filters'),(169281,'deals-mobile','.w-list-type-1_2 .button-wishlist button','line_height_measure','px','','','.w-list-type-1_2'),(169282,'deals-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line_height_measure','px','','','.w-compare-box-item'),(169283,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-1_2'),(169284,'deals-mobile','.w-list-type-1 .button-view a','line_height_measure','px','','','.w-list-type-1'),(169285,'deals-mobile','.w-list-type-1 .sale','line_height_measure','px','3','','.w-list-type-1'),(169286,'deals-mobile','.w-list-type-1_3 .button-view a','line_height_measure','px','','','.w-list-type-1_3'),(169287,'deals-mobile','.w-list-type-1 .button-wishlist button','line_height_measure','px','','','.w-list-type-1'),(169288,'deals-mobile','.w-list-type-1_2 .button-view a','line_height_measure','px','','','.w-list-type-1_2'),(169289,'deals-mobile','.w-list-type-1_2 .sale','line_height_measure','px','4','','.w-list-type-1_2'),(169290,'deals-mobile','.w-list-type-1_3 .sale','line_height_measure','px','3','','.w-list-type-1_3'),(169291,'deals-mobile','.w-menu-slider .menu-ico','line_height_measure','px','','','.w-menu-slider'),(169292,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-1'),(169293,'deals-mobile','.w-list-type-2 .button-wishlist button','line_height_measure','px','','','.w-list-type-2'),(169294,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-1_3'),(169295,'deals-mobile','.w-list-type-2 .button-view a','line_height_measure','px','','','.w-list-type-2'),(169296,'deals-mobile','.w-list-type-1_3 .button-wishlist button','line_height_measure','px','','','.w-list-type-1_3'),(169297,'deals-mobile','.w-list-type-1_3 .sale','line_height_measure','px','4','','.w-list-type-1_3'),(169298,'deals-mobile','.w-list-type-1_2 .sale','line_height_measure','px','3','','.w-list-type-1_2'),(169299,'deals-mobile','.w-list-type-2_2 .sale','line_height_measure','px','3','','.w-list-type-2_2'),(169300,'deals-mobile','.w-list-type-2_2 .sale','line_height_measure','px','4','','.w-list-type-2_2'),(169301,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-2'),(169302,'deals-mobile','.w-list-type-2_2 .button-wishlist button','line_height_measure','px','','','.w-list-type-2_2'),(169303,'deals-mobile','.w-menu-horizontal .menu-ico','line_height_measure','px','','','.w-menu-horizontal'),(169304,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','line_height_measure','px','3','','.w-list-type-2_2'),(169305,'deals-mobile','.w-list-type-2 .sale','line_height_measure','px','4','','.w-list-type-2'),(169306,'deals-mobile','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(169307,'deals-mobile','.w-list-type-2 .sale','line_height_measure','px','3','','.w-list-type-2'),(169308,'deals-mobile','.w-list-type-2_2 .button-view a','line_height_measure','px','','','.w-list-type-2_2'),(169309,'deals-mobile','.heading-4 .edit, h4 .edit','line_height_measure','px','','',''),(169310,'deals-mobile','.p-account-index .date_value, .p-account-index .date_title','line_height_measure','px','','','.p-account-index'),(169311,'deals-mobile','.heading-3 .right-text, h3 .right-text','line_height_measure','px','','',''),(169312,'deals-mobile','.w-list-type-2 .description','line_height_measure','%','','','.w-list-type-2'),(169313,'deals-mobile','.w-list-type-2 .price','line_height_measure','%','','','.w-list-type-2'),(169314,'deals-mobile','.w-list-type-1_3 .description','line_height_measure','%','','','.w-list-type-1_3'),(169315,'deals-mobile','.w-list-type-1_2 .price','line_height_measure','%','','','.w-list-type-1_2'),(169316,'deals-mobile','.w-list-type-1_2 .description','line_height_measure','%','','','.w-list-type-1_2'),(169317,'deals-mobile','.b-bottom .pop-up-close','line_height_measure','px','','','.b-bottom'),(169318,'deals-mobile','.w-list-type-1 .price','line_height_measure','%','','','.w-list-type-1'),(169319,'deals-mobile','.w-list-type-1 .description','line_height_measure','%','','','.w-list-type-1'),(169320,'deals-mobile','.w-bestsellers .counter','line_height_measure','px','','','.w-bestsellers'),(169321,'deals-mobile','.b-info-popup .info-popup div','line_height_measure','px','3','','.b-info-popup'),(169322,'deals-mobile','.b-products-listing .btn-preloader','line_height_measure','px','3','','.b-products-listing'),(169323,'deals-mobile','.b-products-listing .loader','line_height_measure','px','4','','.b-products-listing'),(169324,'deals-mobile','.b-products-listing .products-listing .btn-buy','line_height_measure','px','3','','.b-products-listing'),(169325,'deals-mobile','.b-products-listing .products-listing .btn-preloader','line_height_measure','px','','','.b-products-listing'),(169326,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.b-data-table'),(169327,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.b-data-table'),(169328,'deals-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line_height_measure','px','','','.b-menu-burger_icon'),(169329,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(169330,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(169331,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(169332,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(169333,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(169334,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','line_height_measure','px','','','.b-menu-style-2'),(169335,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','line_height_measure','px','','','.b-menu-style-2'),(169336,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','line_height_measure','px','','','.b-menu-style-2'),(169337,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','line_height_measure','px','3','','.b-menu-style-2'),(169338,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','line_height_measure','px','3','','.b-menu-style-2'),(169339,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-messages'),(169340,'deals-mobile','.b-messages span.starred::before','line_height_measure','px','','','.b-messages'),(169341,'deals-mobile','.b-messages .messBtnMenuStarred','line_height_measure','px','3','','.b-messages'),(169342,'deals-mobile','.b-messages .messBtnMenuDelete','line_height_measure','px','3','','.b-messages'),(169343,'deals-mobile','.b-messages .messBtnMenuUnread','line_height_measure','px','3','','.b-messages'),(169344,'deals-mobile','.b-preloader .preloader','line_height_measure','px','3','','.b-preloader'),(169345,'deals-mobile','.b-select-suggest .select2-container .select2-choice','line_height_measure','px','','','.b-select-suggest'),(169346,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-select-suggest'),(169347,'deals-mobile','.b-upload-file .snapshot','line_height_measure','px','','','.b-upload-file'),(169348,'deals-mobile','.batchPr .batchSelect .checkbox','line_height_measure','px','','','.batchPr'),(169349,'deals-mobile','.batchPr .checkbox input:not(checked) + span:before','line_height_measure','px','','','.batchPr'),(169350,'deals-mobile','.bell-ico .heading-2','line_height_measure','px','3','','.bell-ico'),(169351,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','line_height_measure','px','','','.p-account-samples-history'),(169352,'deals-mobile','.p-account-samples-history .view_link','line_height_measure','px','4','','.p-account-samples-history'),(169353,'deals-mobile','.p-account-samples-history .view_link','line_height_measure','px','4','','.p-account-samples-history'),(169354,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','line_height_measure','px','','','.p-account-samples-history'),(169355,'deals-mobile','.p-account-samples-history .view_link','line_height_measure','px','4','','.p-account-samples-history'),(169356,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','line_height_measure','px','','','.p-account-samples-history'),(169357,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line_height_measure','px','','','.p-account-samples-history'),(169358,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line_height_measure','px','','','.p-account-samples-history'),(169359,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line_height_measure','px','','','.p-account-samples-history'),(169360,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','line_height_measure','px','','','.p-account-samples-history'),(169361,'deals-mobile','.p-account-samples-history .view_link','line_height_measure','px','4','','.p-account-samples-history'),(169362,'deals-mobile','.p-account-samples-history .order_history_table th','line_height_measure','px','','','.p-account-samples-history'),(169363,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line_height_measure','px','','','.p-account-samples-history'),(169364,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line_height_measure','px','','','.p-account-samples-history'),(169365,'deals-mobile','.p-account-samples-history .view_link','line_height_measure','px','4','','.p-account-samples-history'),(169366,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','line_height_measure','px','','','.p-account-samples-history'),(169367,'deals-mobile','.p-account-samples-history .order_history_table th','line_height_measure','px','','','.p-account-samples-history'),(169368,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','line_height_measure','px','','','.p-account-samples-history'),(169369,'deals-mobile','.p-account-samples-history .order_history_table th','line_height_measure','px','','','.p-account-samples-history'),(169370,'deals-mobile','.p-account-samples-history .order_history_table th','line_height_measure','px','','','.p-account-samples-history'),(169371,'deals-mobile','.p-account-samples-history .order_history_table th','line_height_measure','px','','','.p-account-samples-history'),(169372,'deals-mobile','.p-account-samples-history .view_link','line_height_measure','px','4','','.p-account-samples-history'),(169373,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','line_height_measure','px','','','.p-account-samples-history'),(169374,'deals-mobile','.p-account-samples-history .order_history_table th','line_height_measure','px','','','.p-account-samples-history'),(169375,'deals-mobile','.p-catalog-product .pn-image','line_height_measure','px','3','','.p-catalog-product'),(169376,'deals-mobile','.p-payer-order-confirmation .discount-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(169377,'deals-mobile','.p-payer-order-confirmation .comment-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(169378,'deals-mobile','.p-payer-order-confirmation .pay-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(169379,'deals-mobile','.p-payer-order-confirmation .ship-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(169380,'deals-mobile','.p-payer-order-confirmation .order-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(169381,'deals-mobile','.p-payer-order-pay .ship-ico','line_height_measure','px','3','','.p-payer-order-pay'),(169382,'deals-mobile','.p-payer-order-pay .pay-ico','line_height_measure','px','3','','.p-payer-order-pay'),(169383,'deals-mobile','.p-payer-order-pay .order-ico','line_height_measure','px','3','','.p-payer-order-pay'),(169384,'deals-mobile','.p-payer-order-pay .comment-ico','line_height_measure','px','3','','.p-payer-order-pay'),(169385,'deals-mobile','.p-payer-order-pay .discount-ico','line_height_measure','px','3','','.p-payer-order-pay'),(169386,'deals-mobile','.p-quick-order-index .paginate_button.next','line_height_measure','px','3','','.p-quick-order-index'),(169387,'deals-mobile','.p-quick-order-index .paginate_button.previous','line_height_measure','px','3','','.p-quick-order-index'),(169388,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.p-quick-order-index'),(169389,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.p-quick-order-index'),(169390,'deals-mobile','.savings-ico .heading-2','line_height_measure','px','3','','.savings-ico'),(169391,'deals-mobile','.shipping-ico .heading-2','line_height_measure','px','3','','.shipping-ico'),(169392,'deals-mobile','.shipping-ico .heading-2','line_height_measure','px','3','','.shipping-ico'),(169393,'deals-mobile','.shipping-ico .heading-2','line_height_measure','px','3','','.shipping-ico'),(169394,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','line_height_measure','px','','','.w-blog-widget-related-posts'),(169395,'deals-mobile','.w-cart-compare .attributes-cell','line_height_measure','px','','','.w-cart-compare'),(169396,'deals-mobile','.w-cart-compare .price-cell','line_height_measure','px','','','.w-cart-compare'),(169397,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line_height_measure','px','3','','.w-catalog-compare'),(169398,'deals-mobile','.w-catalog-compare span.btn-preloader','line_height_measure','px','3','','.w-catalog-compare'),(169399,'deals-mobile','.w-catalog-paging ','line_height_measure','px','2','','.w-catalog-paging'),(169400,'deals-mobile','.w-catalog-paging .next','line_height_measure','px','','','.w-catalog-paging'),(169401,'deals-mobile','.w-catalog-paging .prev','line_height_measure','px','','','.w-catalog-paging'),(169402,'deals-mobile','.w-catalog-paging .next','line_height_measure','px','3','','.w-catalog-paging'),(169403,'deals-mobile','.w-catalog-paging .next-pages','line_height_measure','px','','','.w-catalog-paging'),(169404,'deals-mobile','.w-catalog-paging .prev-pages','line_height_measure','px','','','.w-catalog-paging'),(169405,'deals-mobile','.w-catalog-paging .page-number','line_height_measure','px','','','.w-catalog-paging'),(169406,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line_height_measure','px','','','.w-catalog-paging'),(169407,'deals-mobile','.w-catalog-paging .prev','line_height_measure','px','3','','.w-catalog-paging'),(169408,'deals-mobile','.w-checkout-create-account .account-benefits strong','line_height_measure','px','3','','.w-checkout-create-account'),(169409,'deals-mobile','.w-checkout-shipping-choice span','line_height_measure','px','','','.w-checkout-shipping-choice'),(169410,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line_height_measure','px','','','.w-communication-new-topic'),(169411,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','3','','.w-communication-new-topic'),(169412,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','','','.w-communication-new-topic'),(169413,'deals-mobile','.w-multi-cart-cart-switcher .cart-label','line_height_measure','px','','','.w-multi-cart-cart-switcher'),(169414,'deals-mobile','.w-personal-gift-status-bar .end-date','line_height_measure','px','3','','.w-personal-gift-status-bar'),(169415,'deals-mobile','.w-personal-gift-status-bar .inform','line_height_measure','px','4','','.w-personal-gift-status-bar'),(169416,'deals-mobile','.w-product-customers-activity .close','line_height_measure','px','','','.w-product-customers-activity'),(169417,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','line_height_measure','px','','','.w-promotions'),(169418,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','line_height_measure','px','','','.w-promotions'),(169419,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','line_height_measure','px','','','.w-promotions'),(169420,'deals-mobile','.w-promotions .promo-salemaker .discount','line_height_measure','px','','','.w-promotions'),(169421,'deals-mobile','.w-menu-big ul','list-style','none','','','.w-menu-big'),(169422,'deals-mobile','.w-menu-slider ul, .w-menu-slider li','list-style','none','','','.w-menu-slider'),(169423,'deals-mobile','.w-menu-horizontal ul','list-style','none','','','.w-menu-horizontal'),(169424,'deals-mobile','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(169425,'deals-mobile','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(169426,'deals-mobile','.p-blog-index .wp-widget ul','list-style','none','','','.p-blog-index'),(169427,'deals-mobile','.p-blog-index .wp-widget li','list-style','none','','','.p-blog-index'),(169428,'deals-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','list-style','none','','','.p-blog-index'),(169429,'deals-mobile','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(169430,'deals-mobile','.w-account ul, .w-account li','list-style','none','','','.w-account'),(169431,'deals-mobile','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(169432,'deals-mobile','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(169433,'deals-mobile','.w-tabs .tab-navigation','list-style','none','','','.w-tabs'),(169434,'deals-mobile','.w-filters .filter-ul-content','list-style','none','','','.w-filters'),(169435,'deals-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(169436,'deals-mobile','.w-menu-style-1 ul','list-style','none','','','.w-menu-style-1'),(169437,'deals-mobile','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(169438,'deals-mobile','.p-account-index .topAccount','list-style','none','','','.p-account-index'),(169439,'deals-mobile','.b-autocomplete .ui-autocomplete','list-style','none','','','.b-autocomplete'),(169440,'deals-mobile','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(169441,'deals-mobile','.p-account-index .account_info','list-style','none','','','.p-account-index'),(169442,'deals-mobile','.p-account-address-book .leftMes ul','list-style','disc inside','','','.p-account-address-book'),(169443,'deals-mobile','.p-account-address-book .rightMes ul','list-style','disc inside','','','.p-account-address-book'),(169444,'deals-mobile','.b-info .info ul','list-style','disc inside','','','.b-info'),(169445,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(169446,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(169447,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(169448,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(169449,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(169450,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(169451,'deals-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','list-style','none','','','.b-menu-style'),(169452,'deals-mobile','.b-messages .messages-menu ul','list-style','none','','','.b-messages'),(169453,'deals-mobile','.b-select-suggest .select2-results li','list-style','none','','','.b-select-suggest'),(169454,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices li','list-style','none','','','.b-select-suggest'),(169455,'deals-mobile','.p-quick-order-index ul.token-input-list','list-style','none','','','.p-quick-order-index'),(169456,'deals-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','list-style','none','','','.w-catalog-additional-images'),(169457,'deals-mobile','.w-sitemap-delivery-location > ul','list-style','none','','','.w-sitemap-delivery-location'),(169458,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul','list-style','none','','','.w-sitemap-delivery-location'),(169459,'deals-mobile','.b-product-images .additional-horizontal .additional-images .item, .b-product-images .additional-horizontal .additional-videos .item','margin','0 auto','','','.b-product-images'),(169460,'deals-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','margin','0 auto','','','.b-product-images'),(169461,'deals-mobile','.w-delivery-location-top-location-list .deliveryName','margin','5px auto','','','.w-delivery-location-top-location-list'),(169462,'deals-mobile','.p-wedding-registry-manage .wr-search','margin','0 auto 20px','','','.p-wedding-registry-manage'),(169463,'deals-mobile','.p-wedding-registry-index .middle-box','margin','0 auto','','','.p-wedding-registry-index'),(169464,'deals-mobile','.b-form .middle-form','margin','0 auto','','','.b-form'),(169465,'deals-mobile','.b-messages .msv_btn .btn','margin','0px auto 0px','','','.b-messages'),(169466,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','margin','3px auto 3px','','','.b-select-suggest'),(169467,'deals-mobile','.b-select-suggest .select2-results','margin','4px auto 4px','','','.b-select-suggest'),(169468,'deals-mobile','.b-trade-approval .middle-form','margin','0 auto','','','.b-trade-approval'),(169469,'deals-mobile','.w-blog-widget-tag-cloud a','margin','0px auto 4px','','','.w-blog-widget-tag-cloud'),(169470,'deals-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','margin','0 auto','','','.w-catalog-b2b-add-button'),(169471,'deals-mobile','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(169472,'deals-mobile','.w-menu-big li','margin-bottom','0','','','.w-menu-big'),(169473,'deals-mobile','.w-menu .hided.menu ul li','margin-bottom','0','','','.w-menu'),(169474,'deals-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-bottom','0','','','.w-menu'),(169475,'deals-mobile','.w-menu-big ul','margin-bottom','0','','','.w-menu-big'),(169476,'deals-mobile','.w-bestsellers .heading-3','margin-bottom','10','','','.w-bestsellers'),(169477,'deals-mobile','.w-menu-slider ul, .w-menu-slider li','margin-bottom','0','','','.w-menu-slider'),(169478,'deals-mobile','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(169479,'deals-mobile','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(169480,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(169481,'deals-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-bottom','0','','','.b-cookie-notice'),(169482,'deals-mobile','.b-form .bootstrap-switch','margin-bottom','15','','','.b-form'),(169483,'deals-mobile','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','margin-bottom','15','','','.b-form'),(169484,'deals-mobile','.b-form .checkbox-style','margin-bottom','0','','','.b-form'),(169485,'deals-mobile','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(169486,'deals-mobile','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(169487,'deals-mobile','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(169488,'deals-mobile','.w-product-sale-ends .ends','margin-bottom','20','','','.w-product-sale-ends'),(169489,'deals-mobile','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(169490,'deals-mobile','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(169491,'deals-mobile','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(169492,'deals-mobile','.w-product-sale-ends .left','margin-bottom','30','','','.w-product-sale-ends'),(169493,'deals-mobile','.w-list-type-2_2 .title','margin-bottom','10','','','.w-list-type-2_2'),(169494,'deals-mobile','.w-sale .name','margin-bottom','20','','','.w-sale'),(169495,'deals-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','margin-bottom','0','','','.b-product-images'),(169496,'deals-mobile','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(169497,'deals-mobile','.w-filters .filter-ul-content','margin-bottom','0','','','.w-filters'),(169498,'deals-mobile','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(169499,'deals-mobile','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(169500,'deals-mobile','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(169501,'deals-mobile','.p-account-index .account_info','margin-bottom','0','','','.p-account-index'),(169502,'deals-mobile','.p-account-history-info .history_info','margin-bottom','20','','','.p-account-history-info'),(169503,'deals-mobile','.p-account-index .account_page h1','margin-bottom','10','','','.p-account-index'),(169504,'deals-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','margin-bottom','10','','','.p-account-trade-form'),(169505,'deals-mobile','.b-price-box .checkout-index .price-box, .b-price-box .checkout-confirmation .price-box','margin-bottom','20','','','.b-price-box'),(169506,'deals-mobile','.w-product-attributes .select-box:nth-child(2n+1)','margin-bottom','20','','','.w-product-attributes'),(169507,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','margin-bottom','5','','','.b-multi-page-checkout'),(169508,'deals-mobile','.p-blog-index .wp-widget','margin-bottom','20','','','.p-blog-index'),(169509,'deals-mobile','.p-blog-index .nav-previous','margin-bottom','20','888','','.p-blog-index'),(169510,'deals-mobile','.p-blog-index .post_body','margin-bottom','30','','','.p-blog-index'),(169511,'deals-mobile','.p-blog-index .autor_name_data','margin-bottom','10','','','.p-blog-index'),(169512,'deals-mobile','.w-list-type-1_2 .image','margin-bottom','10','864','','.w-list-type-1_2'),(169513,'deals-mobile','.w-socials .post_item_img','margin-bottom','0','','','.w-socials'),(169514,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-bottom','0','','','.b-multi-page-checkout'),(169515,'deals-mobile','.w-search .search-input','margin-bottom','0','','','.w-search'),(169516,'deals-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(169517,'deals-mobile','.w-delivery-location-top-location-list .deliveryList','margin-bottom','0','','','.w-delivery-location-top-location-list'),(169518,'deals-mobile','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(169519,'deals-mobile','.w-delivery-location-top-location-list','margin-bottom','25','','','.w-delivery-location-top-location-list'),(169520,'deals-mobile','.p-account-order-pay .buttons','margin-bottom','20','','','.p-account-order-pay'),(169521,'deals-mobile','.p-account-order-pay .history_info','margin-bottom','20','','','.p-account-order-pay'),(169522,'deals-mobile','.p-account-order-pay .history_info > div','margin-bottom','12','864','','.p-account-order-pay'),(169523,'deals-mobile','.p-sample-checkout-index .price-box','margin-bottom','20','','','.p-sample-checkout-index'),(169524,'deals-mobile','.testimonials .name','margin-bottom','20','','',''),(169525,'deals-mobile','.p-sample-checkout-index .buttons','margin-bottom','20','','','.p-sample-checkout-index'),(169526,'deals-mobile','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(169527,'deals-mobile','.b-pagination .pagination','margin-bottom','20','','','.b-pagination'),(169528,'deals-mobile','.testimonials .heading-3','margin-bottom','10','','',''),(169529,'deals-mobile','.testimonials .reviews-list .name','margin-bottom','20','','',''),(169530,'deals-mobile','.b-bottom .confirm-popup .buttons .btn','margin-bottom','0','','','.b-bottom'),(169531,'deals-mobile','.p-account-history-info .buttons','margin-bottom','20','','','.p-account-history-info'),(169532,'deals-mobile','.p-account-history .orders-table .item','margin-bottom','10','890','','.p-account-history'),(169533,'deals-mobile','.p-account-index .orders-table .item','margin-bottom','10','890','','.p-account-index'),(169534,'deals-mobile','.p-blog-index .comment-form p','margin-bottom','20','','','.p-blog-index'),(169535,'deals-mobile','.p-blog-index .comments-area article','margin-bottom','10','','','.p-blog-index'),(169536,'deals-mobile','.pop-up-content .buttons .left-buttons','margin-bottom','15','864','',''),(169537,'deals-mobile','.w-list-type-2_2 .price','margin-bottom','10','','','.w-list-type-2_2'),(169538,'deals-mobile','.w-list-type-2_2 .qty-input','margin-bottom','10','','','.w-list-type-2_2'),(169539,'deals-mobile','.w-list-type-2_2 .properties','margin-bottom','5','','','.w-list-type-2_2'),(169540,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-2_2'),(169541,'deals-mobile','.w-list-type-2_2 .description','margin-bottom','5','','','.w-list-type-2_2'),(169542,'deals-mobile','.w-list-type-2 .title','margin-bottom','10','','','.w-list-type-2'),(169543,'deals-mobile','.w-list-type-2 .qty-input','margin-bottom','10','','','.w-list-type-2'),(169544,'deals-mobile','.w-list-type-2 .properties','margin-bottom','5','','','.w-list-type-2'),(169545,'deals-mobile','.w-list-type-2 .price','margin-bottom','10','','','.w-list-type-2'),(169546,'deals-mobile','.personal-buttons > div > div','margin-bottom','20','','','.personal-buttons'),(169547,'deals-mobile','.w-bestsellers .item','margin-bottom','12','','','.w-bestsellers'),(169548,'deals-mobile','.b-fancybox .fancybox-error','margin-bottom','0','','','.b-fancybox'),(169549,'deals-mobile','.w-account ul, .w-account li','margin-bottom','0','','','.w-account'),(169550,'deals-mobile','.w-menu-horizontal ul','margin-bottom','0','','','.w-menu-horizontal'),(169551,'deals-mobile','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(169552,'deals-mobile','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(169553,'deals-mobile','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(169554,'deals-mobile','.w-delivery-location-top-location-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-top-location-list'),(169555,'deals-mobile','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(169556,'deals-mobile','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(169557,'deals-mobile','.b-form #shipping-address .radio-buttons','margin-bottom','10','','','.b-form'),(169558,'deals-mobile','.b-form .radio-buttons','margin-bottom','20','','','.b-form'),(169559,'deals-mobile','.p-quote-cart-index .w-quote-checkout-btn','margin-bottom','20','','','.p-quote-cart-index'),(169560,'deals-mobile','.p-wedding-registry-index .main-content','margin-bottom','20','','','.p-wedding-registry-index'),(169561,'deals-mobile','.p-wedding-registry-index .search-list','margin-bottom','10','','','.p-wedding-registry-index'),(169562,'deals-mobile','.b-form .form-inputs label > span','margin-bottom','3','','','.b-form'),(169563,'deals-mobile','.p-wedding-registry-index .search-list label','margin-bottom','10','','','.p-wedding-registry-index'),(169564,'deals-mobile','.b-form .addresses','margin-bottom','20','','','.b-form'),(169565,'deals-mobile','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(169566,'deals-mobile','.p-wedding-registry-manage .wedding-date','margin-bottom','30','','','.p-wedding-registry-manage'),(169567,'deals-mobile','.p-wedding-registry-search .result-table','margin-bottom','50','','','.p-wedding-registry-search'),(169568,'deals-mobile','.p-wedding-registry-search .search-form','margin-bottom','30','','','.p-wedding-registry-search'),(169569,'deals-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','margin-bottom','10','','','.p-account-address-book'),(169570,'deals-mobile','.p-account-history .order_history_table h2','margin-bottom','8','','','.p-account-history'),(169571,'deals-mobile','.p-account-address-book .address_book_row .column + .column, .p-account-address-book .topInfo > div + div','margin-bottom','15','','','.p-account-address-book'),(169572,'deals-mobile','.p-account-history .buttonBox','margin-bottom','15','','','.p-account-history'),(169573,'deals-mobile','.p-account-address-book .buttonBox .info','margin-bottom','0','','','.p-account-address-book'),(169574,'deals-mobile','.p-account-address-book .address_book_row h2 a','margin-bottom','0','','','.p-account-address-book'),(169575,'deals-mobile','.p-account-address-book .address_book h2','margin-bottom','15','','','.p-account-address-book'),(169576,'deals-mobile','.p-account-address-book .address_book h1','margin-bottom','18','','','.p-account-address-book'),(169577,'deals-mobile','.p-account-address-book .address_book .row-buttons a','margin-bottom','0','','','.p-account-address-book'),(169578,'deals-mobile','.b-compare .clear_all','margin-bottom','0','4','','.b-compare'),(169579,'deals-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin-bottom','0','','','.b-compare'),(169580,'deals-mobile','.b-compare .col-two','margin-bottom','15','','','.b-compare'),(169581,'deals-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-bottom','0','','','.b-switch'),(169582,'deals-mobile','.p-account-edit .buttons','margin-bottom','20','','','.p-account-edit'),(169583,'deals-mobile','.p-account-address-book .address_book_row .column','margin-bottom','12','863','','.p-account-address-book'),(169584,'deals-mobile','.p-account-address-book .topInfo > div','margin-bottom','12','863','','.p-account-address-book'),(169585,'deals-mobile','.p-account-history-info .history_info > div','margin-bottom','12','864','','.p-account-history-info'),(169586,'deals-mobile','.w-top-categories .categories','margin-bottom','0','865','','.w-top-categories'),(169587,'deals-mobile','.p-account-index .account_info','margin-bottom','20','876','','.p-account-index'),(169588,'deals-mobile','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(169589,'deals-mobile','.w-breadcrumb .breadcrumb-li','margin-bottom','0','','','.w-breadcrumb'),(169590,'deals-mobile','.w-list-type-1_3 .qty-input','margin-bottom','10','','','.w-list-type-1_3'),(169591,'deals-mobile','.heading-3, h3','margin-bottom','10','','',''),(169592,'deals-mobile','.heading-2, h2','margin-bottom','15','','',''),(169593,'deals-mobile','h1','margin-bottom','18','','',''),(169594,'deals-mobile','.heading-4, h4','margin-bottom','5','','',''),(169595,'deals-mobile','.w-list-type-1_3 .properties','margin-bottom','5','','','.w-list-type-1_3'),(169596,'deals-mobile','.w-tabs .tab-li','margin-bottom','0','','','.w-tabs'),(169597,'deals-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-bottom','0','','','.b-form'),(169598,'deals-mobile','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(169599,'deals-mobile','.w-top-categories .categories','margin-bottom','0','','','.w-top-categories'),(169600,'deals-mobile','.w-tabs .tab-navigation','margin-bottom','0','','','.w-tabs'),(169601,'deals-mobile','.p-account-trade-form .widget h3','margin-bottom','10','','','.p-account-trade-form'),(169602,'deals-mobile','.p-account-trade-form .widget','margin-bottom','20','','','.p-account-trade-form'),(169603,'deals-mobile','.p-blog-index .nav-previous a','margin-bottom','0','3','','.p-blog-index'),(169604,'deals-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-bottom','0','','','.p-blog-index'),(169605,'deals-mobile','.p-blog-index .wp-widget li','margin-bottom','0','3','','.p-blog-index'),(169606,'deals-mobile','.p-account-trade-form .wl-td','margin-bottom','10','','','.p-account-trade-form'),(169607,'deals-mobile','.p-blog-index .post-thumbnail','margin-bottom','20','','','.p-blog-index'),(169608,'deals-mobile','.p-checkout-index .shipping-address, .p-checkout-index .billing-address','margin-bottom','30','','','.p-checkout-index'),(169609,'deals-mobile','.p-blog-index .wp-widget ul','margin-bottom','0','','','.p-blog-index'),(169610,'deals-mobile','.p-blog-index .wp-widget li','margin-bottom','0','','','.p-blog-index'),(169611,'deals-mobile','.p-blog-index .nav-next a','margin-bottom','0','3','','.p-blog-index'),(169612,'deals-mobile','.p-checkout-index .buttons','margin-bottom','20','','','.p-checkout-index'),(169613,'deals-mobile','.p-checkout-index .shipping-estimator .info','margin-bottom','20','','','.p-checkout-index'),(169614,'deals-mobile','.p-reviews-info .review-info-content','margin-bottom','20','','','.p-reviews-info'),(169615,'deals-mobile','.p-reviews-info .review-info-reviewed_by','margin-bottom','0','','','.p-reviews-info'),(169616,'deals-mobile','.p-reviews-info .review-info-text','margin-bottom','20','','','.p-reviews-info'),(169617,'deals-mobile','.p-reviews-info .review-info-image','margin-bottom','0','','','.p-reviews-info'),(169618,'deals-mobile','.p-reviews-info .reviews-info h1','margin-bottom','10','','','.p-reviews-info'),(169619,'deals-mobile','.p-account-address-book .address_book_row .column + .column','margin-bottom','12','863','','.p-account-address-book'),(169620,'deals-mobile','.p-account-address-book .topInfo > div + div','margin-bottom','12','863','','.p-account-address-book'),(169621,'deals-mobile','.p-checkout-confirmation .confirm-info','margin-bottom','20','','','.p-checkout-confirmation'),(169622,'deals-mobile','.w-filters .filter-box-head','margin-bottom','15','','','.w-filters'),(169623,'deals-mobile','.p-account-address-book-process .buttons','margin-bottom','20','','','.p-account-address-book-process'),(169624,'deals-mobile','.b-fancybox .fancybox-title-float-wrap','margin-bottom','-35','','','.b-fancybox'),(169625,'deals-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','margin-bottom','10','','','.p-account-trade-form'),(169626,'deals-mobile','.p-account-trade-form .trade-form-area','margin-bottom','20','','','.p-account-trade-form'),(169627,'deals-mobile','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(169628,'deals-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-bottom','8','','','.p-account-subscription-historyinfo'),(169629,'deals-mobile','.p-account-index .account_info li','margin-bottom','20','','','.p-account-index'),(169630,'deals-mobile','.p-account-password .buttonedit','margin-bottom','0','','','.p-account-password'),(169631,'deals-mobile','.p-account-index .view_history','margin-bottom','0','3','','.p-account-index'),(169632,'deals-mobile','.p-account-index .topAccount','margin-bottom','30','','','.p-account-index'),(169633,'deals-mobile','.w-html_box .socials a','margin-bottom','0','','','.w-html_box'),(169634,'deals-mobile','.w-info-content p','margin-bottom','10','','','.w-info-content'),(169635,'deals-mobile','.w-filters .input-checkbox','margin-bottom','0','','','.w-filters'),(169636,'deals-mobile','.p-checkout-confirmation .buttons','margin-bottom','20','','','.p-checkout-confirmation'),(169637,'deals-mobile','.p-account-password .buttons','margin-bottom','20','','','.p-account-password'),(169638,'deals-mobile','.p-checkout-index .discount-box','margin-bottom','20','','','.p-checkout-index'),(169639,'deals-mobile','.w-categories .categories','margin-bottom','0','','','.w-categories'),(169640,'deals-mobile','.w-cart-discount-coupon .gift-code p','margin-bottom','0','','','.w-cart-discount-coupon'),(169641,'deals-mobile','.w-cart-give-away .ga_attributes > div','margin-bottom','1','','','.w-cart-give-away'),(169642,'deals-mobile','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(169643,'deals-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(169644,'deals-mobile','.w-product-in-bundles .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(169645,'deals-mobile','.w-product-quantity .qty_packs .price_1','margin-bottom','0','4','','.w-product-quantity'),(169646,'deals-mobile','.w-product-configurator .pc_row','margin-bottom','20','','','.w-product-configurator'),(169647,'deals-mobile','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(169648,'deals-mobile','.w-product-bundle .bundle_item','margin-bottom','0','','','.w-product-bundle'),(169649,'deals-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(169650,'deals-mobile','.w-product-bundle .bundle_item + .bundle_item','margin-bottom','0','','','.w-product-bundle'),(169651,'deals-mobile','.w-menu-style-1 ul','margin-bottom','0','','','.w-menu-style-1'),(169652,'deals-mobile','.w-menu-style-1 li','margin-bottom','0','','','.w-menu-style-1'),(169653,'deals-mobile','.w-sale .ends','margin-bottom','20','','','.w-sale'),(169654,'deals-mobile','.w-sale .left','margin-bottom','30','','','.w-sale'),(169655,'deals-mobile','.w-product-reviews .reviews-list','margin-bottom','10','','','.w-product-reviews'),(169656,'deals-mobile','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(169657,'deals-mobile','.w-categories .categories h2','margin-bottom','0','','','.w-categories'),(169658,'deals-mobile','.w-top-categories .categories h2','margin-bottom','0','','','.w-top-categories'),(169659,'deals-mobile','.b-form .col-full-padding','margin-bottom','10','','','.b-form'),(169660,'deals-mobile','.b-form .terms-login .bootstrap-switch','margin-bottom','0','','','.b-form'),(169661,'deals-mobile','.b-form .col-full-margin','margin-bottom','10','','','.b-form'),(169662,'deals-mobile','.b-slick .slick-list','margin-bottom','0','','','.b-slick'),(169663,'deals-mobile','.w-socials > li','margin-bottom','10','','','.w-socials'),(169664,'deals-mobile','.w-list-type-1_3 .image','margin-bottom','10','864','','.w-list-type-1_3'),(169665,'deals-mobile','.w-menu-horizontal li','margin-bottom','0','','','.w-menu-horizontal'),(169666,'deals-mobile','.w-list-type-1_3 .price','margin-bottom','10','','','.w-list-type-1_3'),(169667,'deals-mobile','.b-form #frmCheckout','margin-bottom','20','','','.b-form'),(169668,'deals-mobile','.w-categories .categories','margin-bottom','0','863','','.w-categories'),(169669,'deals-mobile','.w-categories .categories','margin-bottom','0','865','','.w-categories'),(169670,'deals-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-bottom','0','','','.b-fancybox'),(169671,'deals-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-bottom','0','','','.b-fancybox'),(169672,'deals-mobile','.w-cart-give-away .ga_wrapper','margin-bottom','25','','','.w-cart-give-away'),(169673,'deals-mobile','.w-top-categories .categories','margin-bottom','0','863','','.w-top-categories'),(169674,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-2'),(169675,'deals-mobile','.w-list-type-1_3 .title','margin-bottom','10','','','.w-list-type-1_3'),(169676,'deals-mobile','.w-list-type-2 .image','margin-bottom','20','','','.w-list-type-2'),(169677,'deals-mobile','.w-list-type-2 .description','margin-bottom','5','','','.w-list-type-2'),(169678,'deals-mobile','.w-list-type-1_3 .description','margin-bottom','5','','','.w-list-type-1_3'),(169679,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-1_3'),(169680,'deals-mobile','.w-list-type-1_3 .attributes > .attributes > div','margin-bottom','5','','','.w-list-type-1_3'),(169681,'deals-mobile','.w-list-type-1_2 .title','margin-bottom','10','','','.w-list-type-1_2'),(169682,'deals-mobile','.w-list-type-1_2 .qty-input','margin-bottom','10','','','.w-list-type-1_2'),(169683,'deals-mobile','.w-list-type-1_2 .price','margin-bottom','10','','','.w-list-type-1_2'),(169684,'deals-mobile','.w-list-type-1_2 .properties','margin-bottom','5','','','.w-list-type-1_2'),(169685,'deals-mobile','.w-list-type-1_2 .description','margin-bottom','5','','','.w-list-type-1_2'),(169686,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-1_2'),(169687,'deals-mobile','.b-bottom .content-item','margin-bottom','20','','','.b-bottom'),(169688,'deals-mobile','.b-bottom .pop-up-content .buttons','margin-bottom','0','','','.b-bottom'),(169689,'deals-mobile','.w-list-type-1 .title','margin-bottom','10','','','.w-list-type-1'),(169690,'deals-mobile','.w-list-type-1 .description','margin-bottom','5','','','.w-list-type-1'),(169691,'deals-mobile','.w-list-type-1 .price','margin-bottom','10','','','.w-list-type-1'),(169692,'deals-mobile','.w-list-type-1 .qty-input','margin-bottom','10','','','.w-list-type-1'),(169693,'deals-mobile','.w-list-type-1 .properties','margin-bottom','5','','','.w-list-type-1'),(169694,'deals-mobile','.w-list-type-1 .image','margin-bottom','20','','','.w-list-type-1'),(169695,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','margin-bottom','12','','','.w-list-type-1'),(169696,'deals-mobile','.w-filters .ui-slider','margin-bottom','0','','','.w-filters'),(169697,'deals-mobile','.w-reviews .heading-3','margin-bottom','10','','','.w-reviews'),(169698,'deals-mobile','.w-reviews .name','margin-bottom','20','','','.w-reviews'),(169699,'deals-mobile','.w-product-reviews .reviews-list .name','margin-bottom','20','','','.w-product-reviews'),(169700,'deals-mobile','.w-reviews .reviews-list .name','margin-bottom','20','','','.w-reviews'),(169701,'deals-mobile','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(169702,'deals-mobile','.b-form .payment-method .item-radio','margin-bottom','5','','','.b-form'),(169703,'deals-mobile','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','margin-bottom','15','','','.b-form'),(169704,'deals-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin-bottom','10','','','.b-form'),(169705,'deals-mobile','.b-form .required-message-wrap','margin-bottom','0','','','.b-form'),(169706,'deals-mobile','.b-form .required-message','margin-bottom','0','','','.b-form'),(169707,'deals-mobile','.b-info .info li','margin-bottom','0','','','.b-info'),(169708,'deals-mobile','.b-info .info ul','margin-bottom','0','','','.b-info'),(169709,'deals-mobile','.b-products-listing .products-listing .bonusPoints','margin-bottom','7','','','.b-products-listing'),(169710,'deals-mobile','.b-products-listing .products-listing .description','margin-bottom','5','','','.b-products-listing'),(169711,'deals-mobile','.b-products-listing .products-listing .description ul','margin-bottom','0','','','.b-products-listing'),(169712,'deals-mobile','.b-products-listing .products-listing .model','margin-bottom','5','','','.b-products-listing'),(169713,'deals-mobile','.b-products-listing .products-listing .mult-qty-input','margin-bottom','3','','','.b-products-listing'),(169714,'deals-mobile','.b-products-listing .products-listing .name','margin-bottom','5','','','.b-products-listing'),(169715,'deals-mobile','.b-products-listing .products-listing h2','margin-bottom','0','','','.b-products-listing'),(169716,'deals-mobile','.b-products-listing .promos-info','margin-bottom','-30','','','.b-products-listing'),(169717,'deals-mobile','.b-products-listing .select-attributes','margin-bottom','10','','','.b-products-listing'),(169718,'deals-mobile','.b-products-listing .select-attributes select','margin-bottom','0','','','.b-products-listing'),(169719,'deals-mobile','.b-products-listing .wedding-registry-count','margin-bottom','10','','','.b-products-listing'),(169720,'deals-mobile','.b-delete-account .delete-box > div','margin-bottom','10','','','.b-delete-account'),(169721,'deals-mobile','.b-delete-account .delete-box span','margin-bottom','0','','','.b-delete-account'),(169722,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(169723,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(169724,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(169725,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(169726,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(169727,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(169728,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-bottom','0','','','.b-h-inline'),(169729,'deals-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-bottom','0','','','.b-menu-style'),(169730,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','margin-bottom','5','','','.b-menu-style-1'),(169731,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages','margin-bottom','10','','','.b-menu-style-2'),(169732,'deals-mobile','.b-messages .messMenuButtonTop','margin-bottom','-39','','','.b-messages'),(169733,'deals-mobile','.b-messages .dataTables_wrapper > .top','margin-bottom','8','','','.b-messages'),(169734,'deals-mobile','.b-messages .messages-menu ul','margin-bottom','0','','','.b-messages'),(169735,'deals-mobile','.b-messages .messages-sidebar .heading-2','margin-bottom','20','','','.b-messages'),(169736,'deals-mobile','.b-messages .messages-sidebar .btn-2','margin-bottom','20','','','.b-messages'),(169737,'deals-mobile','.b-messages .messages-menu li','margin-bottom','0','','','.b-messages'),(169738,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-bottom','5','','','.b-messages'),(169739,'deals-mobile','.b-personal-catalog-popup #personal_catalog_popup .lists-message-box','margin-bottom','20','','','.b-personal-catalog-popup'),(169740,'deals-mobile','.b-select-suggest .select2-search input','margin-bottom','0','','','.b-select-suggest'),(169741,'deals-mobile','.b-select-suggest .select2-search','margin-bottom','0','','','.b-select-suggest'),(169742,'deals-mobile','.b-select-suggest .select2-drop-mask','margin-bottom','0','','','.b-select-suggest'),(169743,'deals-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-bottom','0','','','.b-select-suggest'),(169744,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-bottom','0','','','.b-select-suggest'),(169745,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-bottom','0','','','.b-select-suggest'),(169746,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-bottom','0','','','.b-select-suggest'),(169747,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-bottom','1','','','.b-select-suggest'),(169748,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','margin-bottom','0','','','.b-select-suggest'),(169749,'deals-mobile','.b-select-suggest .select2-container','margin-bottom','0','','','.b-select-suggest'),(169750,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(169751,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(169752,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(169753,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(169754,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(169755,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(169756,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(169757,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(169758,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(169759,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(169760,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(169761,'deals-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(169762,'deals-mobile','.b-trade-approval .steps-bar','margin-bottom','25','','','.b-trade-approval'),(169763,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','margin-bottom','15','','','.b-trade-approval'),(169764,'deals-mobile','.b-trade-approval .middle-form textarea','margin-bottom','15','','','.b-trade-approval'),(169765,'deals-mobile','.b-upload-files .upload-files','margin-bottom','20','','','.b-upload-files'),(169766,'deals-mobile','.b-warehouses-popup .warehouses-popup .heading','margin-bottom','20','','','.b-warehouses-popup'),(169767,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-bottom','20','','','.b-warehouses-popup'),(169768,'deals-mobile','.batchPr .w-batch-selected-products .products-listing','margin-bottom','0','','','.batchPr'),(169769,'deals-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(169770,'deals-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(169771,'deals-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(169772,'deals-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(169773,'deals-mobile','.p-account-samples-history .buttonBox','margin-bottom','15','','','.p-account-samples-history'),(169774,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-bottom','8','','','.p-account-samples-history'),(169775,'deals-mobile','.p-account-samples-history .buttonBox','margin-bottom','15','','','.p-account-samples-history'),(169776,'deals-mobile','.p-account-samples-history .orders-table .item','margin-bottom','10','','','.p-account-samples-history'),(169777,'deals-mobile','.p-account-samples-history .orders-table .item','margin-bottom','10','','','.p-account-samples-history'),(169778,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-bottom','8','','','.p-account-samples-history'),(169779,'deals-mobile','.p-account-samples-history .orders-table .item','margin-bottom','10','','','.p-account-samples-history'),(169780,'deals-mobile','.p-account-samples-history .buttonBox','margin-bottom','15','','','.p-account-samples-history'),(169781,'deals-mobile','.p-account-samples-history .buttonBox','margin-bottom','15','','','.p-account-samples-history'),(169782,'deals-mobile','.p-account-samples-history .buttonBox','margin-bottom','15','','','.p-account-samples-history'),(169783,'deals-mobile','.p-account-samples-history .orders-table .item','margin-bottom','10','','','.p-account-samples-history'),(169784,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-bottom','8','','','.p-account-samples-history'),(169785,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-bottom','8','','','.p-account-samples-history'),(169786,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-bottom','8','','','.p-account-samples-history'),(169787,'deals-mobile','.p-account-samples-history .buttonBox','margin-bottom','15','','','.p-account-samples-history'),(169788,'deals-mobile','.p-account-samples-history .orders-table .item','margin-bottom','10','','','.p-account-samples-history'),(169789,'deals-mobile','.p-account-samples-history .orders-table .item','margin-bottom','10','','','.p-account-samples-history'),(169790,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-bottom','8','','','.p-account-samples-history'),(169791,'deals-mobile','.p-account-samples-history-info .history_info','margin-bottom','20','','','.p-account-samples-history-info'),(169792,'deals-mobile','.p-account-samples-history-info .buttons','margin-bottom','20','','','.p-account-samples-history-info'),(169793,'deals-mobile','.p-account-samples-history-info .buttons','margin-bottom','20','','','.p-account-samples-history-info'),(169794,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-bottom','12','','','.p-account-samples-history-info'),(169795,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-bottom','12','','','.p-account-samples-history-info'),(169796,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-bottom','12','','','.p-account-samples-history-info'),(169797,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-bottom','12','','','.p-account-samples-history-info'),(169798,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-bottom','12','','','.p-account-samples-history-info'),(169799,'deals-mobile','.p-account-samples-history-info .history_info','margin-bottom','20','','','.p-account-samples-history-info'),(169800,'deals-mobile','.p-account-samples-history-info .history_info','margin-bottom','20','','','.p-account-samples-history-info'),(169801,'deals-mobile','.p-account-samples-history-info .buttons','margin-bottom','20','','','.p-account-samples-history-info'),(169802,'deals-mobile','.p-account-samples-history-info .buttons','margin-bottom','20','','','.p-account-samples-history-info'),(169803,'deals-mobile','.p-account-samples-history-info .history_info','margin-bottom','20','','','.p-account-samples-history-info'),(169804,'deals-mobile','.p-account-samples-history-info .buttons','margin-bottom','20','','','.p-account-samples-history-info'),(169805,'deals-mobile','.p-account-samples-history-info .buttons','margin-bottom','20','','','.p-account-samples-history-info'),(169806,'deals-mobile','.p-account-samples-history-info .history_info','margin-bottom','20','','','.p-account-samples-history-info'),(169807,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-bottom','12','','','.p-account-samples-history-info'),(169808,'deals-mobile','.p-account-samples-history-info .history_info','margin-bottom','20','','','.p-account-samples-history-info'),(169809,'deals-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(169810,'deals-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(169811,'deals-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(169812,'deals-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(169813,'deals-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(169814,'deals-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(169815,'deals-mobile','.p-catalog-product .pn-direction','margin-bottom','15','','','.p-catalog-product'),(169816,'deals-mobile','.p-payer-order-confirmation .input-wrapper','margin-bottom','10','','','.p-payer-order-confirmation'),(169817,'deals-mobile','.p-payer-order-confirmation .dob-hide','margin-bottom','-10','','','.p-payer-order-confirmation'),(169818,'deals-mobile','.p-payer-order-pay .input-wrapper','margin-bottom','10','','','.p-payer-order-pay'),(169819,'deals-mobile','.p-payer-order-pay .dob-hide','margin-bottom','-10','','','.p-payer-order-pay'),(169820,'deals-mobile','.p-quick-order-index ul.token-input-list','margin-bottom','0','','','.p-quick-order-index'),(169821,'deals-mobile','.p-quick-order-index .filters','margin-bottom','20','','','.p-quick-order-index'),(169822,'deals-mobile','.w-account-address-book .name','margin-bottom','5','','','.w-account-address-book'),(169823,'deals-mobile','.w-account-address-book .address-wrapper','margin-bottom','20','','','.w-account-address-book'),(169824,'deals-mobile','.w-account-address-book .address-book','margin-bottom','0','','','.w-account-address-book'),(169825,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(169826,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(169827,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(169828,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(169829,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(169830,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(169831,'deals-mobile','.w-account-customer-additional-field .field-type-text','margin-bottom','10','','','.w-account-customer-additional-field'),(169832,'deals-mobile','.w-account-customer-additional-field .field-type-checkbox','margin-bottom','10','','','.w-account-customer-additional-field'),(169833,'deals-mobile','.w-account-personal-catalog .list-switcher','margin-bottom','20','','','.w-account-personal-catalog'),(169834,'deals-mobile','.w-account-subscription .send-email','margin-bottom','20','','','.w-account-subscription'),(169835,'deals-mobile','.w-account-subscription .subscription-list','margin-bottom','20','','','.w-account-subscription'),(169836,'deals-mobile','.w-blog-widget-post-image ','margin-bottom','20','','','.w-blog-widget-post-image'),(169837,'deals-mobile','.w-blog-widget-post-linked-products .heading-2','margin-bottom','25','','','.w-blog-widget-post-linked-products'),(169838,'deals-mobile','.w-blog-widget-post-listing .post_content','margin-bottom','40','','','.w-blog-widget-post-listing'),(169839,'deals-mobile','.w-blog-widget-post-listing .post_date span + span','margin-bottom','0','3','','.w-blog-widget-post-listing'),(169840,'deals-mobile','.w-blog-widget-post-listing .post_name','margin-bottom','10','','','.w-blog-widget-post-listing'),(169841,'deals-mobile','.w-blog-widget-post-listing ','margin-bottom','0','','','.w-blog-widget-post-listing'),(169842,'deals-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-bottom','0','','','.w-blog-widget-post-share'),(169843,'deals-mobile','.w-blog-widget-post-title ','margin-bottom','20','','','.w-blog-widget-post-title'),(169844,'deals-mobile','.w-blog-widget-post-title h1','margin-bottom','0','','','.w-blog-widget-post-title'),(169845,'deals-mobile','.w-cart-cart-tabs .w-tabs .tab-navigation','margin-bottom','25','','','.w-cart-cart-tabs'),(169846,'deals-mobile','.w-cart-compare .product .image','margin-bottom','10','','','.w-cart-compare'),(169847,'deals-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(169848,'deals-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(169849,'deals-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(169850,'deals-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(169851,'deals-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(169852,'deals-mobile','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(169853,'deals-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-bottom','0','','','.w-catalog-additional-images'),(169854,'deals-mobile','.w-catalog-compare .cross-box .return','margin-bottom','30','','','.w-catalog-compare'),(169855,'deals-mobile','.w-catalog-items-on-page select','margin-bottom','0','','','.w-catalog-items-on-page'),(169856,'deals-mobile','.w-checkout-billing-address .addresses .address-item','margin-bottom','10','','','.w-checkout-billing-address'),(169857,'deals-mobile','.w-checkout-billing-address .same-address','margin-bottom','10','','','.w-checkout-billing-address'),(169858,'deals-mobile','.w-checkout-billing-address .genders-title','margin-bottom','5','','','.w-checkout-billing-address'),(169859,'deals-mobile','.w-checkout-create-account .heading-2','margin-bottom','0','','','.w-checkout-create-account'),(169860,'deals-mobile','.w-checkout-gdpr .privacy-row','margin-bottom','0','','','.w-checkout-gdpr'),(169861,'deals-mobile','.w-checkout-gdpr .col-left','margin-bottom','20','','','.w-checkout-gdpr'),(169862,'deals-mobile','.w-checkout-shipping-address #shippingchoice-choice','margin-bottom','10','','','.w-checkout-shipping-address'),(169863,'deals-mobile','.w-checkout-shipping-address .genders-title','margin-bottom','5','','','.w-checkout-shipping-address'),(169864,'deals-mobile','.w-checkout-shipping-address .addresses .address-item','margin-bottom','10','','','.w-checkout-shipping-address'),(169865,'deals-mobile','.w-communication-new-topic #communication_group_holder input, .w-communication-new-topic select','margin-bottom','0','','','.w-communication-new-topic'),(169866,'deals-mobile','.w-communication-new-topic #rmaProductReturnButtonFilterHolder','margin-bottom','30','','','.w-communication-new-topic'),(169867,'deals-mobile','.w-communication-new-topic .privacy-row','margin-bottom','10','','','.w-communication-new-topic'),(169868,'deals-mobile','.w-communication-new-topic .text-container','margin-bottom','20','','','.w-communication-new-topic'),(169869,'deals-mobile','.w-communication-post .communication-post','margin-bottom','5','','','.w-communication-post'),(169870,'deals-mobile','.w-communication-post .communication-post-message','margin-bottom','20','','','.w-communication-post'),(169871,'deals-mobile','.w-communication-post .text-container','margin-bottom','20','','','.w-communication-post'),(169872,'deals-mobile','.w-delivery-day .time-left','margin-bottom','30','','','.w-delivery-day'),(169873,'deals-mobile','.w-delivery-day .ends','margin-bottom','20','','','.w-delivery-day'),(169874,'deals-mobile','.w-image-maps .categories-items .item .title','margin-bottom','10','','','.w-image-maps'),(169875,'deals-mobile','.w-image-maps .float-items .item .title','margin-bottom','10','','','.w-image-maps'),(169876,'deals-mobile','.w-image-maps .default-links .item .title','margin-bottom','10','','','.w-image-maps'),(169877,'deals-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(169878,'deals-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(169879,'deals-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(169880,'deals-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(169881,'deals-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(169882,'deals-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(169883,'deals-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(169884,'deals-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(169885,'deals-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(169886,'deals-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(169887,'deals-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(169888,'deals-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(169889,'deals-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(169890,'deals-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(169891,'deals-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(169892,'deals-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(169893,'deals-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(169894,'deals-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(169895,'deals-mobile','.w-promotions .prom-multi-discount .heading','margin-bottom','10','','','.w-promotions'),(169896,'deals-mobile','.w-promotions .nextdiscount .promo-for-each','margin-bottom','10','','','.w-promotions'),(169897,'deals-mobile','.w-promotions .nextdiscount .heading','margin-bottom','20','','','.w-promotions'),(169898,'deals-mobile','.w-promotions .promo-cart-discount .master .heading','margin-bottom','10','','','.w-promotions'),(169899,'deals-mobile','.w-promotions .promo-cart-discount .master .item','margin-bottom','12','','','.w-promotions'),(169900,'deals-mobile','.w-promotions .promo-date','margin-bottom','10','','','.w-promotions'),(169901,'deals-mobile','.w-promotions .promo-item','margin-bottom','30','','','.w-promotions'),(169902,'deals-mobile','.w-promotions .promo-salemaker .item','margin-bottom','2','','','.w-promotions'),(169903,'deals-mobile','.w-promotions .promo-cart-discount .slave .item','margin-bottom','2','','','.w-promotions'),(169904,'deals-mobile','.w-promotions .heading-3','margin-bottom','20','','','.w-promotions'),(169905,'deals-mobile','.w-reviews-content .reviews-list','margin-bottom','20','','','.w-reviews-content'),(169906,'deals-mobile','.w-sitemap-delivery-location > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(169907,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(169908,'deals-mobile','.w-social-links a','margin-bottom','0','','','.w-social-links'),(169909,'deals-mobile','.w-taxable select','margin-bottom','0','','','.w-taxable'),(169910,'deals-mobile','.w-taxable label','margin-bottom','0','','','.w-taxable'),(169911,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','margin-bottom','20','','','.w-upload-customer-id-upload-customer-id-form'),(169912,'deals-mobile','.w-wedding-registry-widgets-products .select-box, .w-wedding-registry-widgets-products .name','margin-bottom','10','','','.w-wedding-registry-widgets-products'),(169913,'deals-mobile','.w-list-type-1_3 .rating-count','margin-left','5','','','.w-list-type-1_3'),(169914,'deals-mobile','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(169915,'deals-mobile','.w-menu .hided.menu ul li','margin-left','0','','','.w-menu'),(169916,'deals-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-left','0','','','.w-menu'),(169917,'deals-mobile','.w-catalog-listing-look .list','margin-left','5','','','.w-catalog-listing-look'),(169918,'deals-mobile','.w-menu-big li','margin-left','0','','','.w-menu-big'),(169919,'deals-mobile','.w-menu-big ul','margin-left','0','','','.w-menu-big'),(169920,'deals-mobile','.w-menu-slider ul, .w-menu-slider li','margin-left','0','','','.w-menu-slider'),(169921,'deals-mobile','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(169922,'deals-mobile','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(169923,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(169924,'deals-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-left','0','','','.b-cookie-notice'),(169925,'deals-mobile','.b-form .checkbox-style','margin-left','0','','','.b-form'),(169926,'deals-mobile','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(169927,'deals-mobile','.w-product-sale-ends .left-count','margin-left','2','','','.w-product-sale-ends'),(169928,'deals-mobile','.w-product-sale-ends .left-text-right','margin-left','2','','','.w-product-sale-ends'),(169929,'deals-mobile','.w-filters .input-checkbox','margin-left','0','','','.w-filters'),(169930,'deals-mobile','.w-filters .filter-ul-content','margin-left','0','','','.w-filters'),(169931,'deals-mobile','.w-categories .categories','margin-left','-20','','','.w-categories'),(169932,'deals-mobile','.w-cart .image','margin-left','-90','','','.w-cart'),(169933,'deals-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','margin-left','0','','','.p-account-address-book'),(169934,'deals-mobile','.p-account-history .order_history_table h2','margin-left','0','','','.p-account-history'),(169935,'deals-mobile','.p-account-history-info .history_info','margin-left','0','','','.p-account-history-info'),(169936,'deals-mobile','.p-account-index .account_page h1','margin-left','0','','','.p-account-index'),(169937,'deals-mobile','.p-account-index .account_info','margin-left','0','','','.p-account-index'),(169938,'deals-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-left','0','','','.p-account-subscription-historyinfo'),(169939,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','margin-left','15','4','','.b-multi-page-checkout'),(169940,'deals-mobile','.w-cart-give-away .ga_column','margin-left','0','863','','.w-cart-give-away'),(169941,'deals-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','margin-left','1','','','.b-product-images'),(169942,'deals-mobile','.w-list-type-1_2 .right-area .right-area-2','margin-left','2','','','.w-list-type-1_2'),(169943,'deals-mobile','.w-list-type-1_2 .right-area .right-area-2','margin-left','0','864','','.w-list-type-1_2'),(169944,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-left','0','','','.b-multi-page-checkout'),(169945,'deals-mobile','.w-search .search-input','margin-left','0','','','.w-search'),(169946,'deals-mobile','.w-socials .post_item_img','margin-left','0','','','.w-socials'),(169947,'deals-mobile','.w-delivery-location-top-location-list','margin-left','0','','','.w-delivery-location-top-location-list'),(169948,'deals-mobile','.w-delivery-location-top-location-list .deliveryList','margin-left','-1','','','.w-delivery-location-top-location-list'),(169949,'deals-mobile','.b-form .columns .col-2:nth-child(2n)','margin-left','0','893','','.b-form'),(169950,'deals-mobile','.p-account-order-pay .buttons','margin-left','0','','','.p-account-order-pay'),(169951,'deals-mobile','.p-account-order-pay .history_info','margin-left','0','','','.p-account-order-pay'),(169952,'deals-mobile','.p-account-order-pay .history_info > div','margin-left','0','864','','.p-account-order-pay'),(169953,'deals-mobile','.b-pagination .pagination span','margin-left','5','2','','.b-pagination'),(169954,'deals-mobile','.b-pagination .pagination .prev-pages','margin-left','5','','','.b-pagination'),(169955,'deals-mobile','.b-pagination .pagination .page-number','margin-left','5','','','.b-pagination'),(169956,'deals-mobile','.b-pagination .pagination .prev','margin-left','5','','','.b-pagination'),(169957,'deals-mobile','.b-bottom .confirm-popup .buttons .btn','margin-left','20','','','.b-bottom'),(169958,'deals-mobile','.b-pagination .pagination .next-pages','margin-left','5','','','.b-pagination'),(169959,'deals-mobile','.b-pagination .pagination .next','margin-left','5','','','.b-pagination'),(169960,'deals-mobile','.p-account-history-info .buttons','margin-left','0','','','.p-account-history-info'),(169961,'deals-mobile','.w-list-type-1_3 .right-area .right-area-2','margin-left','2','','','.w-list-type-1_3'),(169962,'deals-mobile','.w-list-type-2_2 .rating-count','margin-left','5','','','.w-list-type-2_2'),(169963,'deals-mobile','.w-list-type-2 .rating-count','margin-left','5','','','.w-list-type-2'),(169964,'deals-mobile','.buttons .right-buttons .btn','margin-left','10','','',''),(169965,'deals-mobile','.w-account ul, .w-account li','margin-left','0','','','.w-account'),(169966,'deals-mobile','.b-fancybox .fancybox-error','margin-left','0','','','.b-fancybox'),(169967,'deals-mobile','.w-menu-horizontal ul','margin-left','0','','','.w-menu-horizontal'),(169968,'deals-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(169969,'deals-mobile','.w-delivery-location-top-location-list .deliveryList ul','margin-left','0','','','.w-delivery-location-top-location-list'),(169970,'deals-mobile','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(169971,'deals-mobile','.w-chat .w-chat-box','margin-left','5','','','.w-chat'),(169972,'deals-mobile','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(169973,'deals-mobile','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(169974,'deals-mobile','.p-quote-cart-index .w-quote-checkout-btn','margin-left','0','','','.p-quote-cart-index'),(169975,'deals-mobile','.p-wedding-registry-index .search-list','margin-left','-75','3','','.p-wedding-registry-index'),(169976,'deals-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-left','0','','','.b-form'),(169977,'deals-mobile','.p-wedding-registry-manage .links a.share-registry','margin-left','10','4','','.p-wedding-registry-manage'),(169978,'deals-mobile','.p-wedding-registry-manage .links a.share-registry','margin-left','30','','','.p-wedding-registry-manage'),(169979,'deals-mobile','.b-pagination .pagination a','margin-left','5','','','.b-pagination'),(169980,'deals-mobile','.p-account-address-book .buttonBox .info','margin-left','0','','','.p-account-address-book'),(169981,'deals-mobile','.p-account-history .buttonBox','margin-left','0','','','.p-account-history'),(169982,'deals-mobile','.p-account-address-book .address_book_row h2 a','margin-left','15','','','.p-account-address-book'),(169983,'deals-mobile','.p-account-address-book .address_book h2','margin-left','0','','','.p-account-address-book'),(169984,'deals-mobile','.p-account-address-book .address_book_row .column + .column, .p-account-address-book .topInfo > div + div','margin-left','2','','','.p-account-address-book'),(169985,'deals-mobile','.p-account-address-book .address_book h1','margin-left','0','','','.p-account-address-book'),(169986,'deals-mobile','.p-account-address-book .address_book .row-buttons a','margin-left','0','','','.p-account-address-book'),(169987,'deals-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin-left','0','','','.b-compare'),(169988,'deals-mobile','.b-compare .clear_all','margin-left','7','4','','.b-compare'),(169989,'deals-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-left','0','','','.b-switch'),(169990,'deals-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-left','-20','','','.b-slick'),(169991,'deals-mobile','.p-account-history-info .history_info > div','margin-left','0','864','','.p-account-history-info'),(169992,'deals-mobile','.p-account-index .account_info','margin-left','0','876','','.p-account-index'),(169993,'deals-mobile','.w-top-categories .categories','margin-left','-10','865','','.w-top-categories'),(169994,'deals-mobile','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(169995,'deals-mobile','.p-account-address-book .address_book_row .column + .column','margin-left','0','863','','.p-account-address-book'),(169996,'deals-mobile','.w-tabs .tab-navigation','margin-left','0','','','.w-tabs'),(169997,'deals-mobile','.w-top-categories .categories','margin-left','-20','','','.w-top-categories'),(169998,'deals-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-left','0','','','.p-blog-index'),(169999,'deals-mobile','.p-blog-index .nav-next a','margin-left','0','3','','.p-blog-index'),(170000,'deals-mobile','.p-blog-index .wp-widget li','margin-left','-15','3','','.p-blog-index'),(170001,'deals-mobile','.p-blog-index .post-thumbnail','margin-left','0','','','.p-blog-index'),(170002,'deals-mobile','.p-blog-index .nav-previous a','margin-left','-50','3','','.p-blog-index'),(170003,'deals-mobile','.p-blog-index .wp-widget ul','margin-left','0','','','.p-blog-index'),(170004,'deals-mobile','.p-checkout-index .same-address div.bootstrap-switch','margin-left','30','','','.p-checkout-index'),(170005,'deals-mobile','.p-blog-index .wp-widget li','margin-left','0','','','.p-blog-index'),(170006,'deals-mobile','.p-reviews-info .review-info-content','margin-left','0','','','.p-reviews-info'),(170007,'deals-mobile','.p-reviews-info .review-info-text','margin-left','0','','','.p-reviews-info'),(170008,'deals-mobile','.p-reviews-info .review-info-reviewed_by','margin-left','0','','','.p-reviews-info'),(170009,'deals-mobile','.p-reviews-info .reviews-info h1','margin-left','0','','','.p-reviews-info'),(170010,'deals-mobile','.p-reviews-info .review-info-image','margin-left','0','','','.p-reviews-info'),(170011,'deals-mobile','.p-account-address-book .address_book_row .column','margin-left','0','863','','.p-account-address-book'),(170012,'deals-mobile','.p-account-address-book .topInfo > div','margin-left','0','863','','.p-account-address-book'),(170013,'deals-mobile','.p-account-address-book .topInfo > div + div','margin-left','0','863','','.p-account-address-book'),(170014,'deals-mobile','.w-top-categories .categories','margin-left','0','863','','.w-top-categories'),(170015,'deals-mobile','.heading-3 .edit, h3 .edit','margin-left','10','4','',''),(170016,'deals-mobile','.b-slick .slick-track','margin-left','auto','','','.b-slick'),(170017,'deals-mobile','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(170018,'deals-mobile','.p-account-trade-form .trade-form-area .btn','margin-left','30','','','.p-account-trade-form'),(170019,'deals-mobile','.p-account-index .account_info li:nth-child(3n+1)','margin-left','0','','','.p-account-index'),(170020,'deals-mobile','.p-account-password .buttonedit','margin-left','0','','','.p-account-password'),(170021,'deals-mobile','.p-account-index .account_info li','margin-left','4.5','','','.p-account-index'),(170022,'deals-mobile','.p-account-index .view_history','margin-left','0','3','','.p-account-index'),(170023,'deals-mobile','.w-html_box .socials a','margin-left','5','','','.w-html_box'),(170024,'deals-mobile','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(170025,'deals-mobile','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(170026,'deals-mobile','.w-cart-discount-coupon .gift-code p','margin-left','0','','','.w-cart-discount-coupon'),(170027,'deals-mobile','.w-breadcrumb .breadcrumb-li','margin-left','0','','','.w-breadcrumb'),(170028,'deals-mobile','.w-cart-give-away .ga_attributes > div','margin-left','1','','','.w-cart-give-away'),(170029,'deals-mobile','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(170030,'deals-mobile','.w-product-quantity .qty_packs .price_1','margin-left','15','4','','.w-product-quantity'),(170031,'deals-mobile','.w-product-in-bundles .bundle_item','margin-left','0','','','.w-product-in-bundles'),(170032,'deals-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin-left','2','','','.w-product-in-bundles'),(170033,'deals-mobile','.w-product-bundle .bundle_item + .bundle_item','margin-left','2','','','.w-product-bundle'),(170034,'deals-mobile','.w-product-bundle .bundle_item','margin-left','0','','','.w-product-bundle'),(170035,'deals-mobile','.w-menu-style-1 ul','margin-left','0','','','.w-menu-style-1'),(170036,'deals-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(170037,'deals-mobile','.w-menu-style-1 li','margin-left','0','','','.w-menu-style-1'),(170038,'deals-mobile','.w-sale .left-count','margin-left','2','','','.w-sale'),(170039,'deals-mobile','.w-sale .left-text-right','margin-left','2','','','.w-sale'),(170040,'deals-mobile','.w-product-reviews .reviews-list','margin-left','0','','','.w-product-reviews'),(170041,'deals-mobile','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(170042,'deals-mobile','.w-top-categories .categories h2','margin-left','0','','','.w-top-categories'),(170043,'deals-mobile','.w-categories .categories h2','margin-left','0','','','.w-categories'),(170044,'deals-mobile','.b-form .terms-login .bootstrap-switch','margin-left','0','','','.b-form'),(170045,'deals-mobile','.b-slick .slick-list','margin-left','0','','','.b-slick'),(170046,'deals-mobile','.w-socials > li','margin-left','10','','','.w-socials'),(170047,'deals-mobile','.w-list-type-1_3 .right-area .right-area-2','margin-left','0','864','','.w-list-type-1_3'),(170048,'deals-mobile','.b-fancybox #fancybox-loading','margin-left','-22','','','.b-fancybox'),(170049,'deals-mobile','.w-menu-horizontal li','margin-left','0','','','.w-menu-horizontal'),(170050,'deals-mobile','.w-cart-discount-coupon .gift-code button','margin-left','15','','','.w-cart-discount-coupon'),(170051,'deals-mobile','.b-form .addresses .address-item:nth-child(2n)','margin-left','4','','','.b-form'),(170052,'deals-mobile','.b-form .discount-box button','margin-left','15','','','.b-form'),(170053,'deals-mobile','.w-catalog-listing-look .b2b','margin-left','5','','','.w-catalog-listing-look'),(170054,'deals-mobile','.w-categories .categories','margin-left','-10','865','','.w-categories'),(170055,'deals-mobile','.b-form #frmCheckout','margin-left','0','','','.b-form'),(170056,'deals-mobile','.w-categories .categories','margin-left','0','863','','.w-categories'),(170057,'deals-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-left','0','','','.b-fancybox'),(170058,'deals-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-left','0','','','.b-fancybox'),(170059,'deals-mobile','.w-cart-gift-certificate .gift-code button','margin-left','15','','','.w-cart-gift-certificate'),(170060,'deals-mobile','.w-cart-give-away .ga_column','margin-left','2','','','.w-cart-give-away'),(170061,'deals-mobile','.view-all .btn','margin-left','10','4','',''),(170062,'deals-mobile','.w-list-type-1_2 .rating-count','margin-left','5','','','.w-list-type-1_2'),(170063,'deals-mobile','.b-bottom .pop-up-content .buttons','margin-left','0','','','.b-bottom'),(170064,'deals-mobile','.heading-3 .right-text, h3 .right-text','margin-left','10','','',''),(170065,'deals-mobile','.heading-4 .right-text, h4 .right-text','margin-left','10','','',''),(170066,'deals-mobile','.w-list-type-1 .rating-count','margin-left','5','','','.w-list-type-1'),(170067,'deals-mobile','.heading-4 .edit, h4 .edit','margin-left','10','4','',''),(170068,'deals-mobile','.w-filters .view_more','margin-left','5','4','','.w-filters'),(170069,'deals-mobile','.b-form .columns .col-2:nth-child(2n)','margin-left','4','','','.b-form'),(170070,'deals-mobile','.w-tabs .tab-li','margin-left','0','','','.w-tabs'),(170071,'deals-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin-left','0','','','.b-form'),(170072,'deals-mobile','.b-form .required-message-wrap','margin-left','0','','','.b-form'),(170073,'deals-mobile','.b-form .required-message','margin-left','0','','','.b-form'),(170074,'deals-mobile','.b-info .info','margin-left','-40','3','','.b-info'),(170075,'deals-mobile','.b-info .info ul','margin-left','0','','','.b-info'),(170076,'deals-mobile','.b-info .info li','margin-left','0','','','.b-info'),(170077,'deals-mobile','.p-account-index .topAccount','margin-left','0','','','.p-account-index'),(170078,'deals-mobile','.b-products-listing .products-listing .bonus-points-cost','margin-left','-20','3','','.b-products-listing'),(170079,'deals-mobile','.b-products-listing .products-listing .bonus-points-price','margin-left','-20','3','','.b-products-listing'),(170080,'deals-mobile','.b-products-listing .products-listing .description ul','margin-left','0','','','.b-products-listing'),(170081,'deals-mobile','.b-products-listing .products-listing h2','margin-left','0','','','.b-products-listing'),(170082,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.b-data-table'),(170083,'deals-mobile','.b-delete-account .delete-box span','margin-left','10','','','.b-delete-account'),(170084,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(170085,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(170086,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(170087,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(170088,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(170089,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(170090,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(170091,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(170092,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(170093,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(170094,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(170095,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(170096,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-left','0','','','.b-h-inline'),(170097,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(170098,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(170099,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(170100,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(170101,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(170102,'deals-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-left','0','','','.b-menu-style'),(170103,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','margin-left','5','4','','.b-menu-style-1'),(170104,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','margin-left','10','4','','.b-menu-style-1'),(170105,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > .parent > .no-link','margin-left','5','4','','.b-menu-style-3'),(170106,'deals-mobile','.b-messages .msv_content','margin-left','0','','','.b-messages'),(170107,'deals-mobile','.b-messages .msv_history','margin-left','0','','','.b-messages'),(170108,'deals-mobile','.b-messages .messages-menu ul','margin-left','0','','','.b-messages'),(170109,'deals-mobile','.b-messages .messages-menu li','margin-left','0','','','.b-messages'),(170110,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-left','5','','','.b-messages'),(170111,'deals-mobile','.b-select-suggest .select2-drop-mask','margin-left','0','','','.b-select-suggest'),(170112,'deals-mobile','.b-select-suggest .select2-search','margin-left','0','','','.b-select-suggest'),(170113,'deals-mobile','.b-select-suggest .select2-search input','margin-left','0','','','.b-select-suggest'),(170114,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-left','0','','','.b-select-suggest'),(170115,'deals-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-left','0','','','.b-select-suggest'),(170116,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-left','0','','','.b-select-suggest'),(170117,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-left','0','','','.b-select-suggest'),(170118,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-left','0','','','.b-select-suggest'),(170119,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','margin-left','0','','','.b-select-suggest'),(170120,'deals-mobile','.b-select-suggest .select2-container','margin-left','0','','','.b-select-suggest'),(170121,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(170122,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(170123,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(170124,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(170125,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(170126,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(170127,'deals-mobile','.b-trade-approval .steps-bar','margin-left','0','','','.b-trade-approval'),(170128,'deals-mobile','.b-trade-approval .col-3 + .col-3','margin-left','3','','','.b-trade-approval'),(170129,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','0','','','.b-warehouses-popup'),(170130,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','-17','3','','.b-warehouses-popup'),(170131,'deals-mobile','.batchPr .w-batch-selected-products .products-listing','margin-left','0','','','.batchPr'),(170132,'deals-mobile','.p-account-samples-history .buttonBox','margin-left','0','','','.p-account-samples-history'),(170133,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-left','0','','','.p-account-samples-history'),(170134,'deals-mobile','.p-account-samples-history .buttonBox','margin-left','0','','','.p-account-samples-history'),(170135,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-left','0','','','.p-account-samples-history'),(170136,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-left','0','','','.p-account-samples-history'),(170137,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-left','0','','','.p-account-samples-history'),(170138,'deals-mobile','.p-account-samples-history .buttonBox','margin-left','0','','','.p-account-samples-history'),(170139,'deals-mobile','.p-account-samples-history .buttonBox','margin-left','0','','','.p-account-samples-history'),(170140,'deals-mobile','.p-account-samples-history .buttonBox','margin-left','0','','','.p-account-samples-history'),(170141,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-left','0','','','.p-account-samples-history'),(170142,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-left','0','','','.p-account-samples-history'),(170143,'deals-mobile','.p-account-samples-history .buttonBox','margin-left','0','','','.p-account-samples-history'),(170144,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-left','0','','','.p-account-samples-history-info'),(170145,'deals-mobile','.p-account-samples-history-info .buttons','margin-left','0','','','.p-account-samples-history-info'),(170146,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-left','0','','','.p-account-samples-history-info'),(170147,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-left','0','','','.p-account-samples-history-info'),(170148,'deals-mobile','.p-account-samples-history-info .buttons','margin-left','0','','','.p-account-samples-history-info'),(170149,'deals-mobile','.p-account-samples-history-info .history_info','margin-left','0','','','.p-account-samples-history-info'),(170150,'deals-mobile','.p-account-samples-history-info .buttons','margin-left','0','','','.p-account-samples-history-info'),(170151,'deals-mobile','.p-account-samples-history-info .buttons','margin-left','0','','','.p-account-samples-history-info'),(170152,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-left','0','','','.p-account-samples-history-info'),(170153,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-left','0','','','.p-account-samples-history-info'),(170154,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-left','0','','','.p-account-samples-history-info'),(170155,'deals-mobile','.p-account-samples-history-info .history_info','margin-left','0','','','.p-account-samples-history-info'),(170156,'deals-mobile','.p-account-samples-history-info .history_info','margin-left','0','','','.p-account-samples-history-info'),(170157,'deals-mobile','.p-account-samples-history-info .history_info','margin-left','0','','','.p-account-samples-history-info'),(170158,'deals-mobile','.p-account-samples-history-info .history_info','margin-left','0','','','.p-account-samples-history-info'),(170159,'deals-mobile','.p-account-samples-history-info .buttons','margin-left','0','','','.p-account-samples-history-info'),(170160,'deals-mobile','.p-account-samples-history-info .buttons','margin-left','0','','','.p-account-samples-history-info'),(170161,'deals-mobile','.p-account-samples-history-info .history_info','margin-left','0','','','.p-account-samples-history-info'),(170162,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','margin-left','5','','','.p-quick-order-index'),(170163,'deals-mobile','.p-quick-order-index ul.token-input-list','margin-left','5','','','.p-quick-order-index'),(170164,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.p-quick-order-index');
INSERT INTO `themes_styles` VALUES (170165,'deals-mobile','.p-quick-order-index .filters .clear','margin-left','15','','','.p-quick-order-index'),(170166,'deals-mobile','.w-account-address-book .address-book','margin-left','-10','','','.w-account-address-book'),(170167,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(170168,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(170169,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(170170,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(170171,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(170172,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(170173,'deals-mobile','.w-account-personal-catalog .list-switcher','margin-left','0','','','.w-account-personal-catalog'),(170174,'deals-mobile','.w-blog-widget-post-listing .post_date span + span','margin-left','10','3','','.w-blog-widget-post-listing'),(170175,'deals-mobile','.w-blog-widget-post-listing ','margin-left','0','','','.w-blog-widget-post-listing'),(170176,'deals-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-left','8','','','.w-blog-widget-post-share'),(170177,'deals-mobile','.w-blog-widget-post-share a.mailto','margin-left','32','','','.w-blog-widget-post-share'),(170178,'deals-mobile','.w-blog-widget-post-title h1','margin-left','0','','','.w-blog-widget-post-title'),(170179,'deals-mobile','.w-blog-widget-related-posts .products','margin-left','-15','','','.w-blog-widget-related-posts'),(170180,'deals-mobile','.w-blog-widget-related-posts-by-category .products','margin-left','-15','','','.w-blog-widget-related-posts-by-category'),(170181,'deals-mobile','.w-cart-bonus-points .btn-remove','margin-left','-30','','','.w-cart-bonus-points'),(170182,'deals-mobile','.w-cart-compare .product .image','margin-left','0','','','.w-cart-compare'),(170183,'deals-mobile','.w-cart-credit-amount .btn-remove','margin-left','-30','','','.w-cart-credit-amount'),(170184,'deals-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(170185,'deals-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(170186,'deals-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(170187,'deals-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(170188,'deals-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(170189,'deals-mobile','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(170190,'deals-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-left','0','','','.w-catalog-additional-images'),(170191,'deals-mobile','.w-catalog-b2b-add-button .add-b2b-products','margin-left','50','','','.w-catalog-b2b-add-button'),(170192,'deals-mobile','.w-catalog-items-on-page select','margin-left','10','','','.w-catalog-items-on-page'),(170193,'deals-mobile','.w-catalog-paging .next','margin-left','2','','','.w-catalog-paging'),(170194,'deals-mobile','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-billing-address'),(170195,'deals-mobile','.w-checkout-bonus-points .btn-remove','margin-left','-30','','','.w-checkout-bonus-points'),(170196,'deals-mobile','.w-checkout-credit-amount .btn-remove','margin-left','-30','','','.w-checkout-credit-amount'),(170197,'deals-mobile','.w-checkout-gdpr .bootstrap-switch','margin-left','25','','','.w-checkout-gdpr'),(170198,'deals-mobile','.w-checkout-gdpr .privacy-row','margin-left','0','','','.w-checkout-gdpr'),(170199,'deals-mobile','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-shipping-address'),(170200,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','margin-left','-5','','','.w-checkout-shipping-choice'),(170201,'deals-mobile','.w-coupons-and-vauchers-checkout .btn-remove','margin-left','-30','','','.w-coupons-and-vauchers-checkout'),(170202,'deals-mobile','.w-delivery-day .left-count','margin-left','2','','','.w-delivery-day'),(170203,'deals-mobile','.w-delivery-day .left-text-right','margin-left','2','','','.w-delivery-day'),(170204,'deals-mobile','.w-promotions .promo-cart-discount .master .item','margin-left','12','','','.w-promotions'),(170205,'deals-mobile','.w-promotions .promo-salemaker .item','margin-left','2','','','.w-promotions'),(170206,'deals-mobile','.w-promotions .promo-cart-discount .slave .item','margin-left','2','','','.w-promotions'),(170207,'deals-mobile','.w-sitemap-delivery-location > ul','margin-left','0','','','.w-sitemap-delivery-location'),(170208,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-left','0','','','.w-sitemap-delivery-location'),(170209,'deals-mobile','.w-social-links a','margin-left','5','','','.w-social-links'),(170210,'deals-mobile','.w-taxable select','margin-left','5','','','.w-taxable'),(170211,'deals-mobile','.w-taxable label','margin-left','5','','','.w-taxable'),(170212,'deals-mobile','.b-quantity .qty-box input[type=\'text\']','margin-left','3','','','.b-quantity'),(170213,'deals-mobile','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(170214,'deals-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-right','0','','','.w-menu'),(170215,'deals-mobile','.w-menu .hided.menu ul li','margin-right','0','','','.w-menu'),(170216,'deals-mobile','.w-menu-big li','margin-right','0','','','.w-menu-big'),(170217,'deals-mobile','.w-menu-big ul','margin-right','0','','','.w-menu-big'),(170218,'deals-mobile','.w-menu-slider ul, .w-menu-slider li','margin-right','0','','','.w-menu-slider'),(170219,'deals-mobile','.w-bestsellers .counter','margin-right','15','','','.w-bestsellers'),(170220,'deals-mobile','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(170221,'deals-mobile','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(170222,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(170223,'deals-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-right','0','','','.b-cookie-notice'),(170224,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','margin-right','5','','','.b-form'),(170225,'deals-mobile','.b-form .checkbox-style:checked + .checkbox-span','margin-right','5','','','.b-form'),(170226,'deals-mobile','.b-form .checkbox-style','margin-right','0','','','.b-form'),(170227,'deals-mobile','.w-filters .filter-ul-content','margin-right','0','','','.w-filters'),(170228,'deals-mobile','.p-account-history-info .history_info','margin-right','0','','','.p-account-history-info'),(170229,'deals-mobile','.p-account-index .account_info','margin-right','0','','','.p-account-index'),(170230,'deals-mobile','.p-account-index .account_page h1','margin-right','0','','','.p-account-index'),(170231,'deals-mobile','.w-catalog-listing-look .listing-look-title','margin-right','10','','','.w-catalog-listing-look'),(170232,'deals-mobile','.w-cart-give-away .ga_column','margin-right','0','863','','.w-cart-give-away'),(170233,'deals-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','margin-right','1','','','.b-product-images'),(170234,'deals-mobile','.w-list-type-1_2 .image','margin-right','0','864','','.w-list-type-1_2'),(170235,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-right','0','','','.b-multi-page-checkout'),(170236,'deals-mobile','.w-search .search-input','margin-right','0','','','.w-search'),(170237,'deals-mobile','.w-socials .post_item_img','margin-right','10','','','.w-socials'),(170238,'deals-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(170239,'deals-mobile','.w-delivery-location-top-location-list .deliveryList','margin-right','-1','','','.w-delivery-location-top-location-list'),(170240,'deals-mobile','.w-delivery-location-top-location-list','margin-right','0','','','.w-delivery-location-top-location-list'),(170241,'deals-mobile','.p-account-order-pay .buttons','margin-right','0','','','.p-account-order-pay'),(170242,'deals-mobile','.p-account-order-pay .history_info','margin-right','0','','','.p-account-order-pay'),(170243,'deals-mobile','.p-account-order-pay .history_info > div','margin-right','0','864','','.p-account-order-pay'),(170244,'deals-mobile','.js-stock-icon','margin-right','3','3','',''),(170245,'deals-mobile','.b-bottom .confirm-popup .buttons .btn','margin-right','20','','','.b-bottom'),(170246,'deals-mobile','.p-account-history-info .buttons','margin-right','0','','','.p-account-history-info'),(170247,'deals-mobile','.p-blog-index .avatar','margin-right','10','','','.p-blog-index'),(170248,'deals-mobile','.p-blog-index .author','margin-right','20','','','.p-blog-index'),(170249,'deals-mobile','.w-list-type-2_2 .image','margin-right','20','','','.w-list-type-2_2'),(170250,'deals-mobile','.buttons .left-buttons .btn','margin-right','10','','',''),(170251,'deals-mobile','.w-product-bonus-points > div > div','margin-right','5','3','','.w-product-bonus-points'),(170252,'deals-mobile','.w-account ul, .w-account li','margin-right','0','','','.w-account'),(170253,'deals-mobile','.b-fancybox .fancybox-error','margin-right','0','','','.b-fancybox'),(170254,'deals-mobile','.w-delivery-location-top-location-list .deliveryList ul','margin-right','0','','','.w-delivery-location-top-location-list'),(170255,'deals-mobile','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(170256,'deals-mobile','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(170257,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','margin-right','5','3','','.b-form'),(170258,'deals-mobile','.p-quote-cart-index .w-quote-checkout-btn','margin-right','0','','','.p-quote-cart-index'),(170259,'deals-mobile','.b-form .radio-buttons .radio-button','margin-right','30','','','.b-form'),(170260,'deals-mobile','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(170261,'deals-mobile','.p-account-address-book .address_book_row .column + .column, .p-account-address-book .topInfo > div + div','margin-right','0','','','.p-account-address-book'),(170262,'deals-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','margin-right','2','','','.p-account-address-book'),(170263,'deals-mobile','.p-account-history .buttonBox','margin-right','0','','','.p-account-history'),(170264,'deals-mobile','.p-account-address-book .address_book h1','margin-right','0','','','.p-account-address-book'),(170265,'deals-mobile','.p-account-address-book .buttonBox .info','margin-right','25','','','.p-account-address-book'),(170266,'deals-mobile','.p-account-address-book .address_book_row h2 a','margin-right','0','','','.p-account-address-book'),(170267,'deals-mobile','.p-account-address-book .address_book h2','margin-right','0','','','.p-account-address-book'),(170268,'deals-mobile','.p-account-history .order_history_table h2','margin-right','0','','','.p-account-history'),(170269,'deals-mobile','.p-account-address-book .address_book .row-buttons a','margin-right','10','','','.p-account-address-book'),(170270,'deals-mobile','.b-compare .clear_all','margin-right','0','4','','.b-compare'),(170271,'deals-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin-right','5','','','.b-compare'),(170272,'deals-mobile','.b-compare .compare-box-btn','margin-right','20','','','.b-compare'),(170273,'deals-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-right','0','','','.b-switch'),(170274,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','margin-right','-100','','','.b-fancybox'),(170275,'deals-mobile','.p-account-address-book .address_book_row .column','margin-right','0','863','','.p-account-address-book'),(170276,'deals-mobile','.w-filters .input-checkbox:checked + .checkbox-span','margin-right','10','','','.w-filters'),(170277,'deals-mobile','.p-account-history-info .history_info > div','margin-right','0','864','','.p-account-history-info'),(170278,'deals-mobile','.p-account-index .account_info','margin-right','0','876','','.p-account-index'),(170279,'deals-mobile','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(170280,'deals-mobile','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(170281,'deals-mobile','.w-breadcrumb .breadcrumb-li','margin-right','0','','','.w-breadcrumb'),(170282,'deals-mobile','.p-account-address-book .topInfo > div','margin-right','0','863','','.p-account-address-book'),(170283,'deals-mobile','.p-account-address-book .topInfo > div + div','margin-right','0','863','','.p-account-address-book'),(170284,'deals-mobile','.w-top-categories .categories','margin-right','-20','','','.w-top-categories'),(170285,'deals-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-right','0','','','.p-blog-index'),(170286,'deals-mobile','.p-blog-index .nav-previous a','margin-right','0','3','','.p-blog-index'),(170287,'deals-mobile','.p-blog-index .post-thumbnail','margin-right','40','','','.p-blog-index'),(170288,'deals-mobile','.p-blog-index .wp-widget li','margin-right','0','','','.p-blog-index'),(170289,'deals-mobile','.p-blog-index .nav-next a','margin-right','-50','3','','.p-blog-index'),(170290,'deals-mobile','.p-blog-index .wp-widget li','margin-right','0','3','','.p-blog-index'),(170291,'deals-mobile','.p-blog-index .wp-widget ul','margin-right','0','','','.p-blog-index'),(170292,'deals-mobile','.p-reviews-info .review-info-text','margin-right','0','','','.p-reviews-info'),(170293,'deals-mobile','.p-reviews-info .review-info-content','margin-right','0','','','.p-reviews-info'),(170294,'deals-mobile','.p-reviews-info .review-info-image','margin-right','20','','','.p-reviews-info'),(170295,'deals-mobile','.p-reviews-info .review-info-reviewed_by','margin-right','6','','','.p-reviews-info'),(170296,'deals-mobile','.p-reviews-info .reviews-info h1','margin-right','0','','','.p-reviews-info'),(170297,'deals-mobile','.p-account-address-book .address_book_row .column + .column','margin-right','0','863','','.p-account-address-book'),(170298,'deals-mobile','.w-top-categories .categories','margin-right','0','863','','.w-top-categories'),(170299,'deals-mobile','.b-slick .slick-track','margin-right','auto','','','.b-slick'),(170300,'deals-mobile','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(170301,'deals-mobile','.p-account-index .account_info li','margin-right','0','','','.p-account-index'),(170302,'deals-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-right','0','','','.p-account-subscription-historyinfo'),(170303,'deals-mobile','.p-account-password .buttonedit','margin-right','0','','','.p-account-password'),(170304,'deals-mobile','.p-account-index .view_history','margin-right','7','3','','.p-account-index'),(170305,'deals-mobile','.w-filters .input-checkbox','margin-right','0','','','.w-filters'),(170306,'deals-mobile','.w-html_box .socials a','margin-right','5','','','.w-html_box'),(170307,'deals-mobile','.w-categories .categories','margin-right','-20','','','.w-categories'),(170308,'deals-mobile','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(170309,'deals-mobile','.w-cart-discount-coupon .gift-code p','margin-right','0','','','.w-cart-discount-coupon'),(170310,'deals-mobile','.w-cart-give-away .ga_attributes > div','margin-right','1','','','.w-cart-give-away'),(170311,'deals-mobile','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(170312,'deals-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin-right','0','','','.w-product-in-bundles'),(170313,'deals-mobile','.w-product-quantity .qty_packs .price_1','margin-right','25','4','','.w-product-quantity'),(170314,'deals-mobile','.w-product-in-bundles .bundle_item','margin-right','2','','','.w-product-in-bundles'),(170315,'deals-mobile','.w-product-bundle .bundle_item','margin-right','2','','','.w-product-bundle'),(170316,'deals-mobile','.w-product-bundle .bundle_item + .bundle_item','margin-right','0','','','.w-product-bundle'),(170317,'deals-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(170318,'deals-mobile','.w-menu-style-1 ul','margin-right','0','','','.w-menu-style-1'),(170319,'deals-mobile','.w-menu-style-1 li','margin-right','0','','','.w-menu-style-1'),(170320,'deals-mobile','.w-product-reviews .reviews-list','margin-right','0','','','.w-product-reviews'),(170321,'deals-mobile','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(170322,'deals-mobile','.w-top-categories .categories h2','margin-right','0','','','.w-top-categories'),(170323,'deals-mobile','.w-categories .categories h2','margin-right','0','','','.w-categories'),(170324,'deals-mobile','.b-form .terms-login .bootstrap-switch','margin-right','-80','','','.b-form'),(170325,'deals-mobile','.b-slick .slick-list','margin-right','0','','','.b-slick'),(170326,'deals-mobile','.w-socials > li','margin-right','10','','','.w-socials'),(170327,'deals-mobile','.w-list-type-1_3 .image','margin-right','0','864','','.w-list-type-1_3'),(170328,'deals-mobile','.w-menu-horizontal li','margin-right','0','','','.w-menu-horizontal'),(170329,'deals-mobile','.w-menu-horizontal ul','margin-right','0','','','.w-menu-horizontal'),(170330,'deals-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','margin-right','10','3','','.w-cart-discount-coupon'),(170331,'deals-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-right','0','','','.b-form'),(170332,'deals-mobile','.w-categories .categories','margin-right','0','863','','.w-categories'),(170333,'deals-mobile','.w-categories .categories','margin-right','-10','865','','.w-categories'),(170334,'deals-mobile','.b-form #frmCheckout','margin-right','0','','','.b-form'),(170335,'deals-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-right','0','','','.b-fancybox'),(170336,'deals-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-right','0','','','.b-fancybox'),(170337,'deals-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(170338,'deals-mobile','.w-cart-give-away .ga_column','margin-right','2','','','.w-cart-give-away'),(170339,'deals-mobile','.w-cart-give-away .ga_img','margin-right','2','','','.w-cart-give-away'),(170340,'deals-mobile','.out-stock-icon','margin-right','3','3','',''),(170341,'deals-mobile','.w-list-type-1_3 .image','margin-right','20','','','.w-list-type-1_3'),(170342,'deals-mobile','.w-list-type-1_3 .attributes > .attributes > div','margin-right','5','','','.w-list-type-1_3'),(170343,'deals-mobile','.w-list-type-1_2 .image','margin-right','20','','','.w-list-type-1_2'),(170344,'deals-mobile','.b-bottom .pop-up-content .buttons','margin-right','0','','','.b-bottom'),(170345,'deals-mobile','.w-filters .open','margin-right','10','3','','.w-filters'),(170346,'deals-mobile','.transit-icon','margin-right','3','3','',''),(170347,'deals-mobile','.in-stock-icon','margin-right','3','3','',''),(170348,'deals-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','margin-right','10','','','.w-filters'),(170349,'deals-mobile','.w-tabs .tab-li','margin-right','0','','','.w-tabs'),(170350,'deals-mobile','.w-tabs .tab-navigation','margin-right','0','','','.w-tabs'),(170351,'deals-mobile','.w-top-categories .categories','margin-right','-10','865','','.w-top-categories'),(170352,'deals-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin-right','10','','','.b-form'),(170353,'deals-mobile','.b-form .required-message','margin-right','0','','','.b-form'),(170354,'deals-mobile','.b-form .required-message-wrap','margin-right','0','','','.b-form'),(170355,'deals-mobile','.b-info .info ul','margin-right','0','','','.b-info'),(170356,'deals-mobile','.b-info .info li','margin-right','0','','','.b-info'),(170357,'deals-mobile','.p-account-index .topAccount','margin-right','0','','','.p-account-index'),(170358,'deals-mobile','.b-products-listing .products-listing .bonus-points-cost','margin-right','5','3','','.b-products-listing'),(170359,'deals-mobile','.b-products-listing .products-listing .bonus-points-cost','margin-right','10','','','.b-products-listing'),(170360,'deals-mobile','.b-products-listing .products-listing .bonus-points-price','margin-right','10','','','.b-products-listing'),(170361,'deals-mobile','.b-products-listing .products-listing .btn-buy','margin-right','10','3','','.b-products-listing'),(170362,'deals-mobile','.b-products-listing .products-listing .description ul','margin-right','0','','','.b-products-listing'),(170363,'deals-mobile','.b-products-listing .products-listing .radio-attributes label','margin-right','10','','','.b-products-listing'),(170364,'deals-mobile','.b-products-listing .products-listing h2','margin-right','0','','','.b-products-listing'),(170365,'deals-mobile','.b-delete-account .delete-box span','margin-right','10','','','.b-delete-account'),(170366,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(170367,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(170368,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(170369,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(170370,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(170371,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(170372,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-right','0','','','.b-h-inline'),(170373,'deals-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-right','0','','','.b-menu-style'),(170374,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','margin-right','10','','','.b-menu-style-2'),(170375,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','margin-right','10','','','.b-menu-style-2'),(170376,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','margin-right','10','3','','.b-menu-style-2'),(170377,'deals-mobile','.b-messages span.starred::before','margin-right','8','','','.b-messages'),(170378,'deals-mobile','.b-messages .msv_content','margin-right','0','','','.b-messages'),(170379,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-right','5','','','.b-messages'),(170380,'deals-mobile','.b-messages .msv_history','margin-right','0','','','.b-messages'),(170381,'deals-mobile','.b-messages .messBtnMenuUnread','margin-right','8','3','','.b-messages'),(170382,'deals-mobile','.b-messages .messBtnMenuDelete','margin-right','8','3','','.b-messages'),(170383,'deals-mobile','.b-messages .messBtnMenuStarred','margin-right','8','3','','.b-messages'),(170384,'deals-mobile','.b-messages .messages-menu ul','margin-right','0','','','.b-messages'),(170385,'deals-mobile','.b-messages .messages-menu li','margin-right','0','','','.b-messages'),(170386,'deals-mobile','.b-messages .content_management_attach span::before','margin-right','5','','','.b-messages'),(170387,'deals-mobile','.b-messages .content_management_attach span','margin-right','10','','','.b-messages'),(170388,'deals-mobile','.b-select-suggest .select2-search','margin-right','0','','','.b-select-suggest'),(170389,'deals-mobile','.b-select-suggest .select2-drop-mask','margin-right','0','','','.b-select-suggest'),(170390,'deals-mobile','.b-select-suggest .select2-search input','margin-right','0','','','.b-select-suggest'),(170391,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-right','0','','','.b-select-suggest'),(170392,'deals-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-right','0','','','.b-select-suggest'),(170393,'deals-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','margin-right','26','','','.b-select-suggest'),(170394,'deals-mobile','.b-select-suggest .select2-container.select2-allowclear .select2-choice .select2-chosen','margin-right','42','','','.b-select-suggest'),(170395,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-right','0','','','.b-select-suggest'),(170396,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-right','0','','','.b-select-suggest'),(170397,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-right','0','','','.b-select-suggest'),(170398,'deals-mobile','.b-select-suggest .select2-container','margin-right','0','','','.b-select-suggest'),(170399,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','margin-right','0','','','.b-select-suggest'),(170400,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(170401,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(170402,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(170403,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(170404,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(170405,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(170406,'deals-mobile','.b-trade-approval .steps-bar','margin-right','0','','','.b-trade-approval'),(170407,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-right','20','','','.b-warehouses-popup'),(170408,'deals-mobile','.b-warehouses-popup .warehouses-popup-link','margin-right','5','3','','.b-warehouses-popup'),(170409,'deals-mobile','.batchPr .w-batch-selected-products .products-listing','margin-right','0','','','.batchPr'),(170410,'deals-mobile','.bell-ico .heading-2','margin-right','10','3','','.bell-ico'),(170411,'deals-mobile','.heading-ordered-items .heading-4','margin-right','5','3','','.heading-ordered-items'),(170412,'deals-mobile','.heading-saved-lists .heading-4','margin-right','5','3','','.heading-saved-lists'),(170413,'deals-mobile','.heading-settings .heading-4','margin-right','5','3','','.heading-settings'),(170414,'deals-mobile','.p-account-samples-history .buttonBox','margin-right','0','','','.p-account-samples-history'),(170415,'deals-mobile','.p-account-samples-history .buttonBox','margin-right','0','','','.p-account-samples-history'),(170416,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-right','0','','','.p-account-samples-history'),(170417,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-right','0','','','.p-account-samples-history'),(170418,'deals-mobile','.p-account-samples-history .buttonBox','margin-right','0','','','.p-account-samples-history'),(170419,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-right','0','','','.p-account-samples-history'),(170420,'deals-mobile','.p-account-samples-history .buttonBox','margin-right','0','','','.p-account-samples-history'),(170421,'deals-mobile','.p-account-samples-history .buttonBox','margin-right','0','','','.p-account-samples-history'),(170422,'deals-mobile','.p-account-samples-history .buttonBox','margin-right','0','','','.p-account-samples-history'),(170423,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-right','0','','','.p-account-samples-history'),(170424,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-right','0','','','.p-account-samples-history'),(170425,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-right','0','','','.p-account-samples-history'),(170426,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-right','0','','','.p-account-samples-history-info'),(170427,'deals-mobile','.p-account-samples-history-info .history_info','margin-right','0','','','.p-account-samples-history-info'),(170428,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-right','0','','','.p-account-samples-history-info'),(170429,'deals-mobile','.p-account-samples-history-info .history_info','margin-right','0','','','.p-account-samples-history-info'),(170430,'deals-mobile','.p-account-samples-history-info .history_info','margin-right','0','','','.p-account-samples-history-info'),(170431,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-right','0','','','.p-account-samples-history-info'),(170432,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-right','0','','','.p-account-samples-history-info'),(170433,'deals-mobile','.p-account-samples-history-info .history_info','margin-right','0','','','.p-account-samples-history-info'),(170434,'deals-mobile','.p-account-samples-history-info .history_info','margin-right','0','','','.p-account-samples-history-info'),(170435,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-right','0','','','.p-account-samples-history-info'),(170436,'deals-mobile','.p-account-samples-history-info .buttons','margin-right','0','','','.p-account-samples-history-info'),(170437,'deals-mobile','.p-account-samples-history-info .history_info','margin-right','0','','','.p-account-samples-history-info'),(170438,'deals-mobile','.p-account-samples-history-info .buttons','margin-right','0','','','.p-account-samples-history-info'),(170439,'deals-mobile','.p-account-samples-history-info .buttons','margin-right','0','','','.p-account-samples-history-info'),(170440,'deals-mobile','.p-account-samples-history-info .buttons','margin-right','0','','','.p-account-samples-history-info'),(170441,'deals-mobile','.p-account-samples-history-info .buttons','margin-right','0','','','.p-account-samples-history-info'),(170442,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-right','0','','','.p-account-samples-history-info'),(170443,'deals-mobile','.p-account-samples-history-info .buttons','margin-right','0','','','.p-account-samples-history-info'),(170444,'deals-mobile','.p-payer-order-confirmation .ship-ico','margin-right','10','3','','.p-payer-order-confirmation'),(170445,'deals-mobile','.p-payer-order-confirmation .discount-ico','margin-right','10','3','','.p-payer-order-confirmation'),(170446,'deals-mobile','.p-payer-order-confirmation .comment-ico','margin-right','10','3','','.p-payer-order-confirmation'),(170447,'deals-mobile','.p-payer-order-confirmation .pay-ico','margin-right','10','3','','.p-payer-order-confirmation'),(170448,'deals-mobile','.p-payer-order-confirmation .order-ico','margin-right','10','3','','.p-payer-order-confirmation'),(170449,'deals-mobile','.p-payer-order-pay .ship-ico','margin-right','10','3','','.p-payer-order-pay'),(170450,'deals-mobile','.p-payer-order-pay .order-ico','margin-right','10','3','','.p-payer-order-pay'),(170451,'deals-mobile','.p-payer-order-pay .pay-ico','margin-right','10','3','','.p-payer-order-pay'),(170452,'deals-mobile','.p-payer-order-pay .comment-ico','margin-right','10','3','','.p-payer-order-pay'),(170453,'deals-mobile','.p-payer-order-pay .discount-ico','margin-right','10','3','','.p-payer-order-pay'),(170454,'deals-mobile','.p-quick-order-index ul.token-input-list','margin-right','30','','','.p-quick-order-index'),(170455,'deals-mobile','.savings-ico .heading-2','margin-right','10','3','','.savings-ico'),(170456,'deals-mobile','.shipping-ico .heading-2','margin-right','10','3','','.shipping-ico'),(170457,'deals-mobile','.shipping-ico .heading-2','margin-right','10','3','','.shipping-ico'),(170458,'deals-mobile','.shipping-ico .heading-2','margin-right','10','3','','.shipping-ico'),(170459,'deals-mobile','.w-account-address-book .address-book','margin-right','-10','','','.w-account-address-book'),(170460,'deals-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','margin-right','10','','','.w-account-addresses-list'),(170461,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(170462,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(170463,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(170464,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(170465,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(170466,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(170467,'deals-mobile','.w-account-personal-catalog .list-switcher','margin-right','0','','','.w-account-personal-catalog'),(170468,'deals-mobile','.w-account-subscription .info-popup','margin-right','20','','','.w-account-subscription'),(170469,'deals-mobile','.w-blog-widget-post-image ','margin-right','0','','','.w-blog-widget-post-image'),(170470,'deals-mobile','.w-blog-widget-post-listing .post_date span + span','margin-right','10','3','','.w-blog-widget-post-listing'),(170471,'deals-mobile','.w-blog-widget-post-listing .post_view','margin-right','15','','','.w-blog-widget-post-listing'),(170472,'deals-mobile','.w-blog-widget-post-listing ','margin-right','0','','','.w-blog-widget-post-listing'),(170473,'deals-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-right','8','','','.w-blog-widget-post-share'),(170474,'deals-mobile','.w-blog-widget-post-title h1','margin-right','0','','','.w-blog-widget-post-title'),(170475,'deals-mobile','.w-blog-widget-related-posts .products','margin-right','-15','','','.w-blog-widget-related-posts'),(170476,'deals-mobile','.w-blog-widget-related-posts-by-category .products','margin-right','-15','','','.w-blog-widget-related-posts-by-category'),(170477,'deals-mobile','.w-cart-compare .product .image','margin-right','10','','','.w-cart-compare'),(170478,'deals-mobile','.w-cart-compare .product-actions .dropdown-toggle','margin-right','8','3','','.w-cart-compare'),(170479,'deals-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(170480,'deals-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(170481,'deals-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(170482,'deals-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(170483,'deals-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(170484,'deals-mobile','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(170485,'deals-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-right','0','','','.w-catalog-additional-images'),(170486,'deals-mobile','.w-catalog-items-on-page select','margin-right','10','','','.w-catalog-items-on-page'),(170487,'deals-mobile','.w-catalog-paging .prev','margin-right','5','','','.w-catalog-paging'),(170488,'deals-mobile','.w-checkout-billing-address .genders-title label','margin-right','20','','','.w-checkout-billing-address'),(170489,'deals-mobile','.w-checkout-billing-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-billing-address'),(170490,'deals-mobile','.w-checkout-billing-address .btn-cancel','margin-right','20','','','.w-checkout-billing-address'),(170491,'deals-mobile','.w-checkout-create-account .account-benefits strong','margin-right','5','3','','.w-checkout-create-account'),(170492,'deals-mobile','.w-checkout-gdpr .privacy-row','margin-right','0','','','.w-checkout-gdpr'),(170493,'deals-mobile','.w-checkout-shipping-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-shipping-address'),(170494,'deals-mobile','.w-checkout-shipping-address .genders-title label','margin-right','20','','','.w-checkout-shipping-address'),(170495,'deals-mobile','.w-checkout-shipping-address .btn-cancel','margin-right','20','','','.w-checkout-shipping-address'),(170496,'deals-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','margin-right','10','3','','.w-multi-cart-actions'),(170497,'deals-mobile','.w-product-cross-sell .buy-all-checker','margin-right','5','','','.w-product-cross-sell'),(170498,'deals-mobile','.w-promotions .nextdiscount .heading','margin-right','10','3','','.w-promotions'),(170499,'deals-mobile','.w-promotions .promo-cart-discount .master .item','margin-right','12','','','.w-promotions'),(170500,'deals-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','margin-right','5','3','','.w-promotions'),(170501,'deals-mobile','.w-promotions .promo-cart-discount .slave .item','margin-right','2','','','.w-promotions'),(170502,'deals-mobile','.w-promotions .promo-salemaker .item','margin-right','2','','','.w-promotions'),(170503,'deals-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','margin-right','5','3','','.w-promotions'),(170504,'deals-mobile','.w-promotions .prom-multi-discount > .heading','margin-right','5','3','','.w-promotions'),(170505,'deals-mobile','.w-promotions .icon','margin-right','15','','','.w-promotions'),(170506,'deals-mobile','.w-sitemap-delivery-location > ul','margin-right','0','','','.w-sitemap-delivery-location'),(170507,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-right','0','','','.w-sitemap-delivery-location'),(170508,'deals-mobile','.w-social-links a','margin-right','5','','','.w-social-links'),(170509,'deals-mobile','.w-taxable input[type=\"checkbox\"]','margin-right','5','','','.w-taxable'),(170510,'deals-mobile','.w-taxable label','margin-right','5','','','.w-taxable'),(170511,'deals-mobile','.w-taxable select','margin-right','0','','','.w-taxable'),(170512,'deals-mobile','.w-wedding-registry-widgets-photos .upload-file-template','margin-right','20','','','.w-wedding-registry-widgets-photos'),(170513,'deals-mobile','.w-wedding-registry-widgets-search-registry-button a','margin-right','10','3','','.w-wedding-registry-widgets-search-registry-button'),(170514,'deals-mobile','.w-wedding-registry-widgets-share-link a','margin-right','5','3','','.w-wedding-registry-widgets-share-link'),(170515,'deals-mobile','.b-quantity .qty-box input[type=\'text\']','margin-right','3','','','.b-quantity'),(170516,'deals-mobile','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(170517,'deals-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-top','0','','','.w-menu'),(170518,'deals-mobile','.w-menu .hided.menu ul li','margin-top','0','','','.w-menu'),(170519,'deals-mobile','.w-menu-big ul','margin-top','0','','','.w-menu-big'),(170520,'deals-mobile','.w-menu-big li','margin-top','0','','','.w-menu-big'),(170521,'deals-mobile','.w-menu-slider ul, .w-menu-slider li','margin-top','0','','','.w-menu-slider'),(170522,'deals-mobile','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(170523,'deals-mobile','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(170524,'deals-mobile','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(170525,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(170526,'deals-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-top','0','','','.b-cookie-notice'),(170527,'deals-mobile','.b-form .checkbox-style','margin-top','0','','','.b-form'),(170528,'deals-mobile','.b-product-images .additional-images .item a, .b-product-images .additional-videos .item a','margin-top','0','','','.b-product-images'),(170529,'deals-mobile','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(170530,'deals-mobile','.w-filters .filter-ul-content','margin-top','0','','','.w-filters'),(170531,'deals-mobile','.w-menu-horizontal li','margin-top','0','','','.w-menu-horizontal'),(170532,'deals-mobile','.p-account-history .order_history_table h2','margin-top','0','','','.p-account-history'),(170533,'deals-mobile','.p-account-history-info .history_info','margin-top','0','','','.p-account-history-info'),(170534,'deals-mobile','.p-account-index .account_info','margin-top','0','','','.p-account-index'),(170535,'deals-mobile','.p-account-index .account_page h1','margin-top','0','','','.p-account-index'),(170536,'deals-mobile','.w-list-type-1_2 .right-area .right-area-2','margin-top','15','864','','.w-list-type-1_2'),(170537,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-top','0','','','.b-multi-page-checkout'),(170538,'deals-mobile','.w-socials > li','margin-top','10','','','.w-socials'),(170539,'deals-mobile','.w-socials .post_item_img','margin-top','0','','','.w-socials'),(170540,'deals-mobile','.w-search .search-input','margin-top','0','','','.w-search'),(170541,'deals-mobile','.p-account-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-history-info'),(170542,'deals-mobile','.w-delivery-location-top-location-list','margin-top','25','','','.w-delivery-location-top-location-list'),(170543,'deals-mobile','.w-delivery-location-top-location-list .deliveryList','margin-top','0','','','.w-delivery-location-top-location-list'),(170544,'deals-mobile','.p-account-order-pay .buttons','margin-top','20','','','.p-account-order-pay'),(170545,'deals-mobile','.p-account-order-pay .history_info','margin-top','0','','','.p-account-order-pay'),(170546,'deals-mobile','.p-account-order-pay .history_info > div','margin-top','0','864','','.p-account-order-pay'),(170547,'deals-mobile','.b-bottom .confirm-popup .buttons .btn','margin-top','0','','','.b-bottom'),(170548,'deals-mobile','.p-account-history-info .buttons','margin-top','20','','','.p-account-history-info'),(170549,'deals-mobile','.w-account ul, .w-account li','margin-top','0','','','.w-account'),(170550,'deals-mobile','.b-fancybox .fancybox-error','margin-top','0','','','.b-fancybox'),(170551,'deals-mobile','.w-menu-horizontal ul','margin-top','0','','','.w-menu-horizontal'),(170552,'deals-mobile','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(170553,'deals-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(170554,'deals-mobile','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(170555,'deals-mobile','.w-delivery-location-top-location-list .deliveryList ul','margin-top','0','','','.w-delivery-location-top-location-list'),(170556,'deals-mobile','.b-form .wedding-form .heading-2','margin-top','10','','','.b-form'),(170557,'deals-mobile','.p-quote-cart-index .w-quote-checkout-btn','margin-top','20','','','.p-quote-cart-index'),(170558,'deals-mobile','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(170559,'deals-mobile','.p-account-address-book .address_book_row h2 a','margin-top','0','','','.p-account-address-book'),(170560,'deals-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','margin-top','0','','','.p-account-address-book'),(170561,'deals-mobile','.p-account-address-book .buttonBox .info','margin-top','0','','','.p-account-address-book'),(170562,'deals-mobile','.p-account-history .buttonBox','margin-top','15','','','.p-account-history'),(170563,'deals-mobile','.p-account-address-book .address_book h1','margin-top','0','','','.p-account-address-book'),(170564,'deals-mobile','.p-account-address-book .address_book_row .column + .column, .p-account-address-book .topInfo > div + div','margin-top','0','','','.p-account-address-book'),(170565,'deals-mobile','.p-account-address-book .address_book h2','margin-top','0','','','.p-account-address-book'),(170566,'deals-mobile','.p-account-address-book .address_book .row-buttons a','margin-top','0','','','.p-account-address-book'),(170567,'deals-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin-top','0','','','.b-compare'),(170568,'deals-mobile','.b-compare .clear_all','margin-top','0','4','','.b-compare'),(170569,'deals-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-top','0','','','.b-switch'),(170570,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','margin-top','-20','','','.b-slick'),(170571,'deals-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-top','0','','','.b-slick'),(170572,'deals-mobile','.p-account-edit .buttons','margin-top','-70','','','.p-account-edit'),(170573,'deals-mobile','.p-account-address-book .address_book_row .column + .column','margin-top','0','863','','.p-account-address-book'),(170574,'deals-mobile','.p-account-address-book .topInfo > div + div','margin-top','0','863','','.p-account-address-book'),(170575,'deals-mobile','.p-account-history-info .history_info > div','margin-top','0','864','','.p-account-history-info'),(170576,'deals-mobile','.w-cart-discount-coupon .gift-code p','margin-top','0','','','.w-cart-discount-coupon'),(170577,'deals-mobile','.w-breadcrumb .breadcrumb-li','margin-top','0','','','.w-breadcrumb'),(170578,'deals-mobile','.w-tabs .tab-li','margin-top','0','','','.w-tabs'),(170579,'deals-mobile','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(170580,'deals-mobile','.p-account-address-book .topInfo > div','margin-top','0','863','','.p-account-address-book'),(170581,'deals-mobile','.w-tabs .tab-navigation','margin-top','0','','','.w-tabs'),(170582,'deals-mobile','.w-top-categories .categories','margin-top','0','865','','.w-top-categories'),(170583,'deals-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-top','0','','','.p-blog-index'),(170584,'deals-mobile','.p-blog-index .wp-widget ul','margin-top','0','','','.p-blog-index'),(170585,'deals-mobile','.p-blog-index .wp-widget li','margin-top','5','3','','.p-blog-index'),(170586,'deals-mobile','.p-blog-index .nav-previous a','margin-top','0','3','','.p-blog-index'),(170587,'deals-mobile','.p-blog-index .wp-widget li','margin-top','0','','','.p-blog-index'),(170588,'deals-mobile','.p-blog-index .post-thumbnail','margin-top','0','','','.p-blog-index'),(170589,'deals-mobile','.p-blog-index .nav-next a','margin-top','0','3','','.p-blog-index'),(170590,'deals-mobile','.p-reviews-info .reviews-info h1','margin-top','0','','','.p-reviews-info'),(170591,'deals-mobile','.p-reviews-info .review-info-image','margin-top','0','','','.p-reviews-info'),(170592,'deals-mobile','.p-reviews-info .review-info-content','margin-top','0','','','.p-reviews-info'),(170593,'deals-mobile','.p-reviews-info .review-info-reviewed_by','margin-top','0','','','.p-reviews-info'),(170594,'deals-mobile','.p-reviews-info .review-info-text','margin-top','0','','','.p-reviews-info'),(170595,'deals-mobile','.p-account-address-book .address_book_row .column','margin-top','0','863','','.p-account-address-book'),(170596,'deals-mobile','.w-top-categories .categories','margin-top','0','863','','.w-top-categories'),(170597,'deals-mobile','.p-account-password .buttons','margin-top','-70','','','.p-account-password'),(170598,'deals-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-top','0','','','.p-account-subscription-historyinfo'),(170599,'deals-mobile','.p-account-index .account_info li','margin-top','0','','','.p-account-index'),(170600,'deals-mobile','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(170601,'deals-mobile','.p-account-password .buttonedit','margin-top','-40','','','.p-account-password'),(170602,'deals-mobile','.p-account-index .view_history','margin-top','0','3','','.p-account-index'),(170603,'deals-mobile','.p-account-index .topAccount','margin-top','0','','','.p-account-index'),(170604,'deals-mobile','.w-filters .input-checkbox','margin-top','0','','','.w-filters'),(170605,'deals-mobile','.w-html_box .socials a','margin-top','0','','','.w-html_box'),(170606,'deals-mobile','.b-fancybox .fancybox-title-outside-wrap','margin-top','10','','','.b-fancybox'),(170607,'deals-mobile','.p-account-address-book-process .buttons','margin-top','-70','','','.p-account-address-book-process'),(170608,'deals-mobile','.b-fancybox .fancybox-nav span','margin-top','-18','','','.b-fancybox'),(170609,'deals-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-top','0','','','.b-fancybox'),(170610,'deals-mobile','.w-categories .categories','margin-top','0','','','.w-categories'),(170611,'deals-mobile','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(170612,'deals-mobile','.w-cart-give-away .ga_attributes > div','margin-top','1','','','.w-cart-give-away'),(170613,'deals-mobile','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(170614,'deals-mobile','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(170615,'deals-mobile','.w-product-quantity .qty_packs .price_1','margin-top','0','4','','.w-product-quantity'),(170616,'deals-mobile','.w-product-in-bundles .bundle_item','margin-top','0','','','.w-product-in-bundles'),(170617,'deals-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin-top','0','','','.w-product-in-bundles'),(170618,'deals-mobile','.w-product-bundle .bundle_item','margin-top','0','','','.w-product-bundle'),(170619,'deals-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(170620,'deals-mobile','.w-product-bundle .bundle_item + .bundle_item','margin-top','0','','','.w-product-bundle'),(170621,'deals-mobile','.w-menu-style-1 ul','margin-top','0','','','.w-menu-style-1'),(170622,'deals-mobile','.w-menu-style-1 li','margin-top','0','','','.w-menu-style-1'),(170623,'deals-mobile','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(170624,'deals-mobile','.w-product-reviews .reviews-list','margin-top','10','','','.w-product-reviews'),(170625,'deals-mobile','.w-top-categories .categories h2','margin-top','0','','','.w-top-categories'),(170626,'deals-mobile','.w-categories .categories h2','margin-top','0','','','.w-categories'),(170627,'deals-mobile','.b-form .terms-login .bootstrap-switch','margin-top','0','','','.b-form'),(170628,'deals-mobile','.b-slick .slick-list','margin-top','0','','','.b-slick'),(170629,'deals-mobile','.b-fancybox #fancybox-loading','margin-top','-22','','','.b-fancybox'),(170630,'deals-mobile','.w-list-type-1_3 .right-area .right-area-2','margin-top','15','864','','.w-list-type-1_3'),(170631,'deals-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-top','0','','','.b-form'),(170632,'deals-mobile','.w-categories .categories','margin-top','0','863','','.w-categories'),(170633,'deals-mobile','.w-categories .categories','margin-top','0','865','','.w-categories'),(170634,'deals-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-top','0','','','.b-fancybox'),(170635,'deals-mobile','.b-form #frmCheckout','margin-top','20','','','.b-form'),(170636,'deals-mobile','.b-bottom .pop-up-content .buttons','margin-top','15','','','.b-bottom'),(170637,'deals-mobile','.w-filters .ui-slider','margin-top','5','','','.w-filters'),(170638,'deals-mobile','.p-account-index .account_info','margin-top','0','876','','.p-account-index'),(170639,'deals-mobile','.w-top-categories .categories','margin-top','0','','','.w-top-categories'),(170640,'deals-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin-top','0','','','.b-form'),(170641,'deals-mobile','.b-form .required-message','margin-top','0','','','.b-form'),(170642,'deals-mobile','.b-form .required-message-wrap','margin-top','0','','','.b-form'),(170643,'deals-mobile','.b-info .info','margin-top','-8','3','','.b-info'),(170644,'deals-mobile','.b-info .info ul','margin-top','0','','','.b-info'),(170645,'deals-mobile','.b-info .info li','margin-top','0','','','.b-info'),(170646,'deals-mobile','.b-products-listing .products-listing .description ul','margin-top','0','','','.b-products-listing'),(170647,'deals-mobile','.b-products-listing .products-listing h2','margin-top','0','','','.b-products-listing'),(170648,'deals-mobile','.b-delete-account .delete-box span','margin-top','10','','','.b-delete-account'),(170649,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(170650,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(170651,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(170652,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(170653,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(170654,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(170655,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-top','0','','','.b-h-inline'),(170656,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(170657,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(170658,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(170659,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(170660,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(170661,'deals-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-top','0','','','.b-menu-style'),(170662,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','margin-top','-8','3','','.b-menu-style-2'),(170663,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','margin-top','-10','3','','.b-menu-style-2'),(170664,'deals-mobile','.b-messages .msv_content','margin-top','15','','','.b-messages'),(170665,'deals-mobile','.b-messages .msv_btn','margin-top','10','','','.b-messages'),(170666,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-top','0','','','.b-messages'),(170667,'deals-mobile','.b-messages .msv_history','margin-top','15','','','.b-messages'),(170668,'deals-mobile','.b-messages .messages-menu ul','margin-top','0','','','.b-messages'),(170669,'deals-mobile','.b-messages .messages-menu li','margin-top','0','','','.b-messages'),(170670,'deals-mobile','.b-select-suggest .select2-search input','margin-top','0','','','.b-select-suggest'),(170671,'deals-mobile','.b-select-suggest .select2-drop-mask','margin-top','0','','','.b-select-suggest'),(170672,'deals-mobile','.b-select-suggest .select2-drop.select2-drop-above .select2-search input','margin-top','4','','','.b-select-suggest'),(170673,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-top','0','','','.b-select-suggest'),(170674,'deals-mobile','.b-select-suggest .select2-drop','margin-top','-1','','','.b-select-suggest'),(170675,'deals-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-top','0','','','.b-select-suggest'),(170676,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-top','0','','','.b-select-suggest'),(170677,'deals-mobile','.b-select-suggest .select2-drop.select2-drop-above','margin-top','1','','','.b-select-suggest'),(170678,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-top','1','','','.b-select-suggest'),(170679,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-top','0','','','.b-select-suggest'),(170680,'deals-mobile','.b-select-suggest .select2-search','margin-top','0','','','.b-select-suggest'),(170681,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','margin-top','0','','','.b-select-suggest'),(170682,'deals-mobile','.b-select-suggest .select2-container','margin-top','0','','','.b-select-suggest'),(170683,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(170684,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(170685,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(170686,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(170687,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(170688,'deals-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(170689,'deals-mobile','.b-trade-approval .steps-bar','margin-top','0','','','.b-trade-approval'),(170690,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-top','0','','','.b-warehouses-popup'),(170691,'deals-mobile','.batchPr .w-batch-selected-products .products-listing','margin-top','0','','','.batchPr'),(170692,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-top','0','','','.p-account-samples-history'),(170693,'deals-mobile','.p-account-samples-history .buttonBox','margin-top','15','','','.p-account-samples-history'),(170694,'deals-mobile','.p-account-samples-history .buttonBox','margin-top','15','','','.p-account-samples-history'),(170695,'deals-mobile','.p-account-samples-history .buttonBox','margin-top','15','','','.p-account-samples-history'),(170696,'deals-mobile','.p-account-samples-history .buttonBox','margin-top','15','','','.p-account-samples-history'),(170697,'deals-mobile','.p-account-samples-history .buttonBox','margin-top','15','','','.p-account-samples-history'),(170698,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-top','0','','','.p-account-samples-history'),(170699,'deals-mobile','.p-account-samples-history .buttonBox','margin-top','15','','','.p-account-samples-history'),(170700,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-top','0','','','.p-account-samples-history'),(170701,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-top','0','','','.p-account-samples-history'),(170702,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-top','0','','','.p-account-samples-history'),(170703,'deals-mobile','.p-account-samples-history .order_history_table h2','margin-top','0','','','.p-account-samples-history'),(170704,'deals-mobile','.p-account-samples-history-info .buttons','margin-top','20','','','.p-account-samples-history-info'),(170705,'deals-mobile','.p-account-samples-history-info .history_info','margin-top','0','','','.p-account-samples-history-info'),(170706,'deals-mobile','.p-account-samples-history-info .buttons','margin-top','20','','','.p-account-samples-history-info'),(170707,'deals-mobile','.p-account-samples-history-info .buttons','margin-top','20','','','.p-account-samples-history-info'),(170708,'deals-mobile','.p-account-samples-history-info .buttons','margin-top','20','','','.p-account-samples-history-info'),(170709,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-top','0','','','.p-account-samples-history-info'),(170710,'deals-mobile','.p-account-samples-history-info .history_info','margin-top','0','','','.p-account-samples-history-info'),(170711,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-samples-history-info'),(170712,'deals-mobile','.p-account-samples-history-info .buttons','margin-top','20','','','.p-account-samples-history-info'),(170713,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-top','0','','','.p-account-samples-history-info'),(170714,'deals-mobile','.p-account-samples-history-info .history_info','margin-top','0','','','.p-account-samples-history-info'),(170715,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-top','0','','','.p-account-samples-history-info'),(170716,'deals-mobile','.p-account-samples-history-info .history_info','margin-top','0','','','.p-account-samples-history-info'),(170717,'deals-mobile','.p-account-samples-history-info .history_info','margin-top','0','','','.p-account-samples-history-info'),(170718,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-top','0','','','.p-account-samples-history-info'),(170719,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-samples-history-info'),(170720,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-top','0','','','.p-account-samples-history-info'),(170721,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-samples-history-info'),(170722,'deals-mobile','.p-account-samples-history-info .history_info','margin-top','0','','','.p-account-samples-history-info'),(170723,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-samples-history-info'),(170724,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-samples-history-info'),(170725,'deals-mobile','.p-account-samples-history-info .popup-tracking-number-link','margin-top','10','','','.p-account-samples-history-info'),(170726,'deals-mobile','.p-account-samples-history-info .history_info > div','margin-top','0','','','.p-account-samples-history-info'),(170727,'deals-mobile','.p-account-samples-history-info .buttons','margin-top','20','','','.p-account-samples-history-info'),(170728,'deals-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(170729,'deals-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(170730,'deals-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(170731,'deals-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(170732,'deals-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(170733,'deals-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(170734,'deals-mobile','.p-payer-order-confirmation .dob-hide','margin-top','20','','','.p-payer-order-confirmation'),(170735,'deals-mobile','.p-payer-order-pay .dob-hide','margin-top','20','','','.p-payer-order-pay'),(170736,'deals-mobile','.p-quick-order-index .dataTables_info','margin-top','5','','','.p-quick-order-index'),(170737,'deals-mobile','.p-quick-order-index ul.token-input-list','margin-top','0','','','.p-quick-order-index'),(170738,'deals-mobile','.w-account-address-book .address-book','margin-top','0','','','.w-account-address-book'),(170739,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(170740,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(170741,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(170742,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(170743,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(170744,'deals-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(170745,'deals-mobile','.w-account-personal-catalog .list-switcher','margin-top','0','','','.w-account-personal-catalog'),(170746,'deals-mobile','.w-blog-widget-categories-list div ~ div','margin-top','10','','','.w-blog-widget-categories-list'),(170747,'deals-mobile','.w-blog-widget-post-listing .post_date span + span','margin-top','0','3','','.w-blog-widget-post-listing'),(170748,'deals-mobile','.w-blog-widget-post-listing ','margin-top','0','','','.w-blog-widget-post-listing'),(170749,'deals-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-top','0','','','.w-blog-widget-post-share'),(170750,'deals-mobile','.w-blog-widget-post-title h1','margin-top','0','','','.w-blog-widget-post-title'),(170751,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','margin-top','-17','','','.w-blog-widget-related-posts'),(170752,'deals-mobile','.w-cart-compare .product .image','margin-top','0','','','.w-cart-compare'),(170753,'deals-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(170754,'deals-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(170755,'deals-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(170756,'deals-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(170757,'deals-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(170758,'deals-mobile','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(170759,'deals-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-top','0','','','.w-catalog-additional-images'),(170760,'deals-mobile','.w-catalog-items-on-page select','margin-top','0','','','.w-catalog-items-on-page'),(170761,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top','0','','','.w-catalog-paging'),(170762,'deals-mobile','.w-checkout-billing-address .bootstrap-switch','margin-top','-2','','','.w-checkout-billing-address'),(170763,'deals-mobile','.w-checkout-contact-information .contact-info-buttons','margin-top','5','','','.w-checkout-contact-information'),(170764,'deals-mobile','.w-checkout-gdpr .privacy-row','margin-top','0','','','.w-checkout-gdpr'),(170765,'deals-mobile','.w-checkout-gdpr .bootstrap-switch','margin-top','0','','','.w-checkout-gdpr'),(170766,'deals-mobile','.w-checkout-shipping-address .change-ab','margin-top','5','','','.w-checkout-shipping-address'),(170767,'deals-mobile','.w-communication-new-topic .files-box','margin-top','50','','','.w-communication-new-topic'),(170768,'deals-mobile','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(170769,'deals-mobile','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(170770,'deals-mobile','.w-multi-cart-cart-switcher .cart-label','margin-top','-20','','','.w-multi-cart-cart-switcher'),(170771,'deals-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(170772,'deals-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(170773,'deals-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(170774,'deals-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(170775,'deals-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(170776,'deals-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(170777,'deals-mobile','.w-product-customers-activity .buttons','margin-top','10','','','.w-product-customers-activity'),(170778,'deals-mobile','.w-promotions .promo-cart-discount .master .image','margin-top','-16','','','.w-promotions'),(170779,'deals-mobile','.w-promotions .promo-cart-discount .master .item','margin-top','12','','','.w-promotions'),(170780,'deals-mobile','.w-promotions .promo-cart-discount .slave .item','margin-top','2','','','.w-promotions'),(170781,'deals-mobile','.w-promotions .promo-salemaker .content','margin-top','-18','','','.w-promotions'),(170782,'deals-mobile','.w-promotions .promo-salemaker .item','margin-top','2','','','.w-promotions'),(170783,'deals-mobile','.w-sitemap-delivery-location > ul','margin-top','0','','','.w-sitemap-delivery-location'),(170784,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-top','0','','','.w-sitemap-delivery-location'),(170785,'deals-mobile','.w-social-links a','margin-top','0','','','.w-social-links'),(170786,'deals-mobile','.w-taxable select','margin-top','0','','','.w-taxable'),(170787,'deals-mobile','.w-taxable label','margin-top','0','','','.w-taxable'),(170788,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-template .btn','margin-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(170789,'deals-mobile','.w-wedding-registry-widgets-products .rating','margin-top','15','','','.w-wedding-registry-widgets-products'),(170790,'deals-mobile','.w-wedding-registry-widgets-search-form .button','margin-top','-46','','','.w-wedding-registry-widgets-search-form'),(170791,'deals-mobile','.w-multi-cart-save-cart .copy-cart','margin-top','10','','','.w-multi-cart-save-cart'),(170792,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top_important','important','','','.w-catalog-paging'),(170793,'deals-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(170794,'deals-mobile','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(170795,'deals-mobile','.w-cart-give-away .ga_attributes > div','margin_bottom_measure','%','','','.w-cart-give-away'),(170796,'deals-mobile','.p-quick-order-index ul.token-input-list','margin_bottom_measure','pt','','','.p-quick-order-index'),(170797,'deals-mobile','.w-sale .left-count','margin_left_measure','%','','','.w-sale'),(170798,'deals-mobile','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(170799,'deals-mobile','.w-product-sale-ends .left-count','margin_left_measure','%','','','.w-product-sale-ends'),(170800,'deals-mobile','.w-product-sale-ends .left-text-right','margin_left_measure','%','','','.w-product-sale-ends'),(170801,'deals-mobile','.w-list-type-1_2 .right-area .right-area-2','margin_left_measure','%','','','.w-list-type-1_2'),(170802,'deals-mobile','.w-delivery-location-top-location-list .deliveryList','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(170803,'deals-mobile','.w-list-type-1_3 .right-area .right-area-2','margin_left_measure','%','','','.w-list-type-1_3'),(170804,'deals-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(170805,'deals-mobile','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(170806,'deals-mobile','.p-account-address-book .address_book_row .column + .column, .p-account-address-book .topInfo > div + div','margin_left_measure','%','','','.p-account-address-book'),(170807,'deals-mobile','.p-account-index .account_info li','margin_left_measure','%','','','.p-account-index'),(170808,'deals-mobile','.w-cart-give-away .ga_attributes > div','margin_left_measure','%','','','.w-cart-give-away'),(170809,'deals-mobile','.w-product-in-bundles .bundle_item + .bundle_item','margin_left_measure','%','','','.w-product-in-bundles'),(170810,'deals-mobile','.w-product-bundle .bundle_item + .bundle_item','margin_left_measure','%','','','.w-product-bundle'),(170811,'deals-mobile','.w-sale .left-text-right','margin_left_measure','%','','','.w-sale'),(170812,'deals-mobile','.w-cart-give-away .ga_column','margin_left_measure','%','','','.w-cart-give-away'),(170813,'deals-mobile','.b-form .columns .col-2:nth-child(2n)','margin_left_measure','%','','','.b-form'),(170814,'deals-mobile','.b-form .addresses .address-item:nth-child(2n)','margin_left_measure','%','','','.b-form'),(170815,'deals-mobile','.b-trade-approval .col-3 + .col-3','margin_left_measure','%','','','.b-trade-approval'),(170816,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_left_measure','pt','','','.b-warehouses-popup'),(170817,'deals-mobile','.p-quick-order-index ul.token-input-list','margin_left_measure','pt','','','.p-quick-order-index'),(170818,'deals-mobile','.w-delivery-day .left-count','margin_left_measure','%','','','.w-delivery-day'),(170819,'deals-mobile','.w-delivery-day .left-text-right','margin_left_measure','%','','','.w-delivery-day'),(170820,'deals-mobile','.w-taxable select','margin_left_measure','pt','','','.w-taxable'),(170821,'deals-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(170822,'deals-mobile','.w-delivery-location-top-location-list .deliveryList','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(170823,'deals-mobile','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(170824,'deals-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','margin_right_measure','%','','','.p-account-address-book'),(170825,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','margin_right_measure','%','','','.b-fancybox'),(170826,'deals-mobile','.w-cart-give-away .ga_attributes > div','margin_right_measure','%','','','.w-cart-give-away'),(170827,'deals-mobile','.w-product-in-bundles .bundle_item','margin_right_measure','%','','','.w-product-in-bundles'),(170828,'deals-mobile','.w-product-bundle .bundle_item','margin_right_measure','%','','','.w-product-bundle'),(170829,'deals-mobile','.w-cart-give-away .ga_column','margin_right_measure','%','','','.w-cart-give-away'),(170830,'deals-mobile','.w-cart-give-away .ga_img','margin_right_measure','%','','','.w-cart-give-away'),(170831,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_right_measure','pt','','','.b-warehouses-popup'),(170832,'deals-mobile','.p-quick-order-index ul.token-input-list','margin_right_measure','pt','','','.p-quick-order-index'),(170833,'deals-mobile','.w-taxable select','margin_right_measure','pt','','','.w-taxable'),(170834,'deals-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(170835,'deals-mobile','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(170836,'deals-mobile','.w-cart-give-away .ga_attributes > div','margin_top_measure','%','','','.w-cart-give-away'),(170837,'deals-mobile','.p-quick-order-index ul.token-input-list','margin_top_measure','pt','','','.p-quick-order-index'),(170838,'deals-mobile','.w-sale .image img','max-height','300','','','.w-sale'),(170839,'deals-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','max-height','130','','','.b-product-images'),(170840,'deals-mobile','.w-product-images img','max-height','450','','','.w-product-images'),(170841,'deals-mobile','.b-fancybox .fancybox-image','max-height','100','','','.b-fancybox'),(170842,'deals-mobile','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(170843,'deals-mobile','.w-list-type-1 .image img','max-height','150','','','.w-list-type-1'),(170844,'deals-mobile','.w-search .suggest','max-height','400','','','.w-search'),(170845,'deals-mobile','.b-fancybox .fancybox-tmp','max-height','99999','','','.b-fancybox'),(170846,'deals-mobile','.w-product-images .item-img','max-height','70','893','','.w-product-images'),(170847,'deals-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-height','100','','','.b-products-listing'),(170848,'deals-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(170849,'deals-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(170850,'deals-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(170851,'deals-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(170852,'deals-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(170853,'deals-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(170854,'deals-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','max-height','0','','','.b-menu-burger_icon'),(170855,'deals-mobile','.b-menu-burger_icon .bi-opened .menu-style[data-open_from=\"top\"] .menu-content','max-height','2000','','','.b-menu-burger_icon'),(170856,'deals-mobile','.b-select-suggest .select2-results','max-height','200','','','.b-select-suggest'),(170857,'deals-mobile','.batchPr .w-batch-products .products-listing .image img','max-height','80','','','.batchPr'),(170858,'deals-mobile','.batchPr .w-batch-selected-products .image img','max-height','40','','','.batchPr'),(170859,'deals-mobile','.batchPr .w-batch-products .image img','max-height','160','','','.batchPr'),(170860,'deals-mobile','.w-blog-widget-post-listing .post_image img','max-height','232','','','.w-blog-widget-post-listing'),(170861,'deals-mobile','.w-blog-widget-related-posts-by-category .post_img img','max-height','167','','','.w-blog-widget-related-posts-by-category'),(170862,'deals-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(170863,'deals-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(170864,'deals-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(170865,'deals-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(170866,'deals-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(170867,'deals-mobile','.w-product-images-additional .item-img','max-height','70','','','.w-product-images-additional'),(170868,'deals-mobile','.w-promotions .prom-multi-discount .image img','max-height','80','','','.w-promotions'),(170869,'deals-mobile','.w-promotions .promo-cart-discount .image img','max-height','80','','','.w-promotions'),(170870,'deals-mobile','.w-promotions .promo-salemaker .image img','max-height','80','','','.w-promotions'),(170871,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-height','100','','','.w-upload-customer-id-upload-customer-id-form'),(170872,'deals-mobile','.w-menu .hided.menu ul ul','max-width','none','','','.w-menu'),(170873,'deals-mobile','.w-product-images img','max-width','100','','','.w-product-images'),(170874,'deals-mobile','.p-blog-index .post-thumbnail','max-width','40','','','.p-blog-index'),(170875,'deals-mobile','.w-list-type-1_2 .image','max-width','100','864','','.w-list-type-1_2'),(170876,'deals-mobile','.p-wedding-registry-manage .wr-search','max-width','100','','','.p-wedding-registry-manage'),(170877,'deals-mobile','.p-blog-index .avatar','max-width','28','','','.p-blog-index'),(170878,'deals-mobile','.b-fancybox .fancybox-image','max-width','100','','','.b-fancybox'),(170879,'deals-mobile','.p-wedding-registry-index .middle-box','max-width','600','','','.p-wedding-registry-index'),(170880,'deals-mobile','.p-wedding-registry-index .main-content','max-width','none','','','.p-wedding-registry-index'),(170881,'deals-mobile','.b-bottom .popup-credit-amount .popup-box','max-width','960','','','.b-bottom'),(170882,'deals-mobile','textarea','max-width','100','','',''),(170883,'deals-mobile','.b-fancybox .fancybox-tmp','max-width','99999','','','.b-fancybox'),(170884,'deals-mobile','.w-product-video .frame-video iframe','max-width','100','','','.w-product-video'),(170885,'deals-mobile','.w-product-images .item-img','max-width','70','893','','.w-product-images'),(170886,'deals-mobile','.main-width, .type-1 > .block','max-width','1250','','',''),(170887,'deals-mobile','.w-list-type-1_3 .image','max-width','100','864','','.w-list-type-1_3'),(170888,'deals-mobile','.w-list-type-1_2 .image','max-width','170','','','.w-list-type-1_2'),(170889,'deals-mobile','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(170890,'deals-mobile','.b-form .middle-form','max-width','560','','','.b-form'),(170891,'deals-mobile','div.cart-popup','max-width','95','','',''),(170892,'deals-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-width','100','','','.b-products-listing'),(170893,'deals-mobile','.b-products-listing .promo','max-width','30','','','.b-products-listing'),(170894,'deals-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(170895,'deals-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(170896,'deals-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(170897,'deals-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(170898,'deals-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(170899,'deals-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(170900,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max-width','100','','','.b-menu-lev_display-slide'),(170901,'deals-mobile','.b-trade-approval .middle-form','max-width','560','','','.b-trade-approval'),(170902,'deals-mobile','.b-upload-files .attached-block','max-width','300','','','.b-upload-files'),(170903,'deals-mobile','.batchPr .w-batch-products .products-listing .image','max-width','100','','','.batchPr'),(170904,'deals-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','max-width','1250','','','.w-catalog-b2b-add-button'),(170905,'deals-mobile','.w-checkout-create-btn .btn-2','max-width','100','','','.w-checkout-create-btn'),(170906,'deals-mobile','.w-checkout-guest-btn .btn-2','max-width','100','','','.w-checkout-guest-btn'),(170907,'deals-mobile','.w-login-register .middle-form','max-width','100','','','.w-login-register'),(170908,'deals-mobile','.w-login-returning .middle-form','max-width','100','','','.w-login-returning'),(170909,'deals-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(170910,'deals-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(170911,'deals-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(170912,'deals-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(170913,'deals-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(170914,'deals-mobile','.w-product-images-additional .item-img','max-width','70','','','.w-product-images-additional'),(170915,'deals-mobile','.w-promotions .heading-3','max-width','calc(100% - 100px)','','','.w-promotions'),(170916,'deals-mobile','.w-promotions .promo-cart-discount .master .item','max-width','calc(50% - 24px)','','','.w-promotions'),(170917,'deals-mobile','.w-promotions .promo-cart-discount .slave .item','max-width','calc(50% - 4px)','','','.w-promotions'),(170918,'deals-mobile','.w-promotions .promo-salemaker .item','max-width','calc(50% - 4px)','','','.w-promotions'),(170919,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-width','100','','','.w-upload-customer-id-upload-customer-id-form'),(170920,'deals-mobile','.b-fancybox .fancybox-image','max_height_measure','%','','','.b-fancybox'),(170921,'deals-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_height_measure','%','','','.b-products-listing'),(170922,'deals-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(170923,'deals-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(170924,'deals-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(170925,'deals-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(170926,'deals-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(170927,'deals-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(170928,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(170929,'deals-mobile','.w-product-video .frame-video iframe','max_width_measure','%','','','.w-product-video'),(170930,'deals-mobile','.w-product-images img','max_width_measure','%','','','.w-product-images'),(170931,'deals-mobile','.p-blog-index .post-thumbnail','max_width_measure','%','','','.p-blog-index'),(170932,'deals-mobile','.w-list-type-1_2 .image','max_width_measure','%','864','','.w-list-type-1_2'),(170933,'deals-mobile','.p-wedding-registry-manage .wr-search','max_width_measure','%','','','.p-wedding-registry-manage'),(170934,'deals-mobile','.b-fancybox .fancybox-image','max_width_measure','%','','','.b-fancybox'),(170935,'deals-mobile','.w-list-type-1_3 .image','max_width_measure','%','864','','.w-list-type-1_3'),(170936,'deals-mobile','textarea','max_width_measure','%','','',''),(170937,'deals-mobile','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(170938,'deals-mobile','div.cart-popup','max_width_measure','%','','',''),(170939,'deals-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_width_measure','%','','','.b-products-listing'),(170940,'deals-mobile','.b-products-listing .promo','max_width_measure','%','','','.b-products-listing'),(170941,'deals-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(170942,'deals-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(170943,'deals-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(170944,'deals-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(170945,'deals-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(170946,'deals-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(170947,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max_width_measure','vw','','','.b-menu-lev_display-slide'),(170948,'deals-mobile','.w-checkout-create-btn .btn-2','max_width_measure','%','','','.w-checkout-create-btn'),(170949,'deals-mobile','.w-checkout-guest-btn .btn-2','max_width_measure','%','','','.w-checkout-guest-btn'),(170950,'deals-mobile','.w-login-register .middle-form','max_width_measure','%','','','.w-login-register'),(170951,'deals-mobile','.w-login-returning .middle-form','max_width_measure','%','','','.w-login-returning'),(170952,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(170953,'deals-mobile','.w-search .search-input','min-height','35','','','.w-search'),(170954,'deals-mobile','.w-currencies .current','min-height','31','','','.w-currencies'),(170955,'deals-mobile','.b-slick .slick-slide','min-height','1','','','.b-slick'),(170956,'deals-mobile','.w-cart-discount-coupon .gift-code p','min-height','45','','','.w-cart-discount-coupon'),(170957,'deals-mobile','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(170958,'deals-mobile','.w-languages .current','min-height','31','','','.w-languages'),(170959,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','min-height','40','','','.b-menu-style-1'),(170960,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1','min-height','35','','','.b-menu-style-1'),(170961,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1','min-height','35','','','.b-menu-style-3'),(170962,'deals-mobile','.b-select-suggest .select2-search input','min-height','26','','','.b-select-suggest'),(170963,'deals-mobile','.b-select-suggest .select2-drop-mask','min-height','100','','','.b-select-suggest'),(170964,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','min-height','26','','','.b-select-suggest'),(170965,'deals-mobile','.b-select-suggest .select2-search','min-height','26','','','.b-select-suggest'),(170966,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','min-height','1','','','.b-select-suggest'),(170967,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','min-height','0','','','.batchPr'),(170968,'deals-mobile','.batchPr .w-batch-selected-products','min-height','0','','','.batchPr'),(170969,'deals-mobile','.batchPr .w-batch-products .products-listing .product-holder','min-height_important','important','','','.batchPr'),(170970,'deals-mobile','.batchPr .w-batch-selected-products','min-height_important','important','','','.batchPr'),(170971,'deals-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','min-width','150','','','.w-menu-horizontal'),(170972,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','min-width','150','','','.w-menu-style-1'),(170973,'deals-mobile','.w-menu-style-1 > ul > li > ul > li ul','min-width','150','','','.w-menu-style-1'),(170974,'deals-mobile','.b-pagination .pagination .prev','min-width','30','','','.b-pagination'),(170975,'deals-mobile','.b-bottom .confirm-popup .buttons .btn','min-width','120','','','.b-bottom'),(170976,'deals-mobile','.b-pagination .pagination .prev-pages','min-width','30','','','.b-pagination'),(170977,'deals-mobile','.b-pagination .pagination .page-number','min-width','30','','','.b-pagination'),(170978,'deals-mobile','.b-pagination .pagination .next-pages','min-width','30','','','.b-pagination'),(170979,'deals-mobile','.b-pagination .pagination span','min-width','30','2','','.b-pagination'),(170980,'deals-mobile','.b-pagination .pagination .next','min-width','30','','','.b-pagination'),(170981,'deals-mobile','.b-pagination .pagination a','min-width','30','','','.b-pagination'),(170982,'deals-mobile','.b-bottom .popup-box.popupCompare','min-width','800','','','.b-bottom'),(170983,'deals-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(170984,'deals-mobile','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(170985,'deals-mobile','.w-menu-horizontal > ul > li > ul > li','min-width','150','','','.w-menu-horizontal'),(170986,'deals-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','min-width','70','','','.b-form'),(170987,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.b-data-table'),(170988,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.b-data-table'),(170989,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','min-width','200','','','.b-menu-lev_display-down'),(170990,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','min-width','200','','','.b-menu-lev_display-down'),(170991,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','min-width','200','','','.b-menu-lev_display-down'),(170992,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','min-width','200','','','.b-menu-lev_display-down'),(170993,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','min-width','200','','','.b-menu-lev_display-down'),(170994,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','min-width','200','','','.b-menu-lev_display-left'),(170995,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','min-width','200','','','.b-menu-lev_display-left'),(170996,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','min-width','200','','','.b-menu-lev_display-left'),(170997,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','min-width','200','','','.b-menu-lev_display-left'),(170998,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','min-width','200','','','.b-menu-lev_display-left'),(170999,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','min-width','200','','','.b-menu-lev_display-lra'),(171000,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','min-width','200','','','.b-menu-lev_display-lra'),(171001,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','min-width','200','','','.b-menu-lev_display-lra'),(171002,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','min-width','200','','','.b-menu-lev_display-lra'),(171003,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','min-width','200','','','.b-menu-lev_display-lra'),(171004,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','min-width','200','','','.b-menu-lev_display-right'),(171005,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','min-width','200','','','.b-menu-lev_display-right'),(171006,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','min-width','200','','','.b-menu-lev_display-right'),(171007,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','min-width','200','','','.b-menu-lev_display-right'),(171008,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','min-width','200','','','.b-menu-lev_display-right'),(171009,'deals-mobile','.b-select-suggest .select2-drop-mask','min-width','100','','','.b-select-suggest'),(171010,'deals-mobile','.p-quick-order-index .al_incart, .p-quick-order-index .al-incart','min-width','60','','','.p-quick-order-index'),(171011,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.p-quick-order-index'),(171012,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.p-quick-order-index'),(171013,'deals-mobile','.w-catalog-paging .prev','min-width','30','','','.w-catalog-paging'),(171014,'deals-mobile','.w-catalog-paging ','min-width','30','2','','.w-catalog-paging'),(171015,'deals-mobile','.w-catalog-paging .next','min-width','30','','','.w-catalog-paging'),(171016,'deals-mobile','.w-catalog-paging .page-number','min-width','30','','','.w-catalog-paging'),(171017,'deals-mobile','.w-catalog-paging .next-pages','min-width','30','','','.w-catalog-paging'),(171018,'deals-mobile','.w-catalog-paging .prev-pages','min-width','30','','','.w-catalog-paging'),(171019,'deals-mobile','.w-communication-new-topic #communication_group_holder table table','min-width','0','','','.w-communication-new-topic'),(171020,'deals-mobile','.w-communication-new-topic .quantity','min-width','70','','','.w-communication-new-topic'),(171021,'deals-mobile','.w-communication-new-topic #communication_group_holder table','min-width','800','','','.w-communication-new-topic'),(171022,'deals-mobile','.w-communication-post .btn-submit','min-width','200','','','.w-communication-post'),(171023,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','min_height_measure','em','','','.b-select-suggest'),(171024,'deals-mobile','.b-select-suggest .select2-drop-mask','min_height_measure','%','','','.b-select-suggest'),(171025,'deals-mobile','.b-select-suggest .select2-drop-mask','min_width_measure','%','','','.b-select-suggest'),(171026,'deals-mobile','.w-filters .input-checkbox','opacity','0','','','.w-filters'),(171027,'deals-mobile','.p-account-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-history-info'),(171028,'deals-mobile','.p-account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-order-pay'),(171029,'deals-mobile','.b-pagination .pagination .paging span.prev, .b-pagination .pagination .paging span.next','opacity','0.3','','','.b-pagination'),(171030,'deals-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','opacity','0','','','.b-switch'),(171031,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','opacity','0.5','','','.b-switch'),(171032,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','opacity','0.5','','','.b-switch'),(171033,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','opacity','0.5','','','.b-switch'),(171034,'deals-mobile','.b-slick button.slick-disabled','opacity','0.3','','','.b-slick'),(171035,'deals-mobile','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(171036,'deals-mobile','.b-form .checkbox-style','opacity','0','','','.b-form'),(171037,'deals-mobile','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(171038,'deals-mobile','.b-form .hide-billing-address','opacity','0.7','','','.b-form'),(171039,'deals-mobile','.b-fancybox #fancybox-loading','opacity','0.8','','','.b-fancybox'),(171040,'deals-mobile','.b-products-listing .products-listing .qty-input.hidden','opacity','0.7','3','','.b-products-listing'),(171041,'deals-mobile','.b-select-suggest .select2-drop-mask','opacity','0','','','.b-select-suggest'),(171042,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-samples-history-info'),(171043,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-samples-history-info'),(171044,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-samples-history-info'),(171045,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-samples-history-info'),(171046,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-samples-history-info'),(171047,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.p-account-samples-history-info'),(171048,'deals-mobile','.p-quick-order-index .paginate_button.next.disabled','opacity','0.3','3','','.p-quick-order-index'),(171049,'deals-mobile','.p-quick-order-index .paginate_button.previous.disabled','opacity','0.3','3','','.p-quick-order-index'),(171050,'deals-mobile','.w-catalog-paging .paging span.prev, .w-catalog-paging .paging span.next','opacity','0.3','','','.w-catalog-paging'),(171051,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition','order','2','','','.w-promotions'),(171052,'deals-mobile','.w-promotions .promo-cart-discount .slave .content','order','3','','','.w-promotions'),(171053,'deals-mobile','.w-promotions .promo-cart-discount .slave .heading','order','1','','','.w-promotions'),(171054,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-focused','outline','0','','','.b-switch'),(171055,'deals-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','outline','none','','','.b-fancybox'),(171056,'deals-mobile','.b-slick .slick-list:focus','outline','none','','','.b-slick'),(171057,'deals-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','outline','none','','','.b-fancybox'),(171058,'deals-mobile','.b-product-images .additional-images div:focus, .b-product-images .additional-videos div:focus','outline','none','','','.b-product-images'),(171059,'deals-mobile','.b-select-suggest .select2-search-choice-close','outline','none','','','.b-select-suggest'),(171060,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','outline','0','','','.b-select-suggest'),(171061,'deals-mobile','.b-select-suggest .select2-container-active .select2-choice, .b-select-suggest .select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(171062,'deals-mobile','.b-select-suggest .select2-search input','outline','0','','','.b-select-suggest'),(171063,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline','0','','','.b-select-suggest'),(171064,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(171065,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','outline','0','','','.b-select-suggest'),(171066,'deals-mobile','.batchPr .products-listing .item','outline','none','','','.batchPr'),(171067,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline_important','important','','','.b-select-suggest'),(171068,'deals-mobile','.w-list-type-2_2 .compare-box-item','overflow','hidden','','','.w-list-type-2_2'),(171069,'deals-mobile','.b-switch .bootstrap-switch','overflow','hidden','','','.b-switch'),(171070,'deals-mobile','.w-product-sale-ends .left','overflow','hidden','','','.w-product-sale-ends'),(171071,'deals-mobile','.w-sale .sale-holder','overflow','hidden','','','.w-sale'),(171072,'deals-mobile','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(171073,'deals-mobile','.w-cart .no-text','overflow','hidden','','','.w-cart'),(171074,'deals-mobile','.p-account-index .topAccount','overflow','hidden','','','.p-account-index'),(171075,'deals-mobile','.w-quote .no-text','overflow','hidden','','','.w-quote'),(171076,'deals-mobile','.w-product-images .img-holder','overflow','hidden','','','.w-product-images'),(171077,'deals-mobile','.p-account-order-pay .history_info','overflow','hidden','','','.p-account-order-pay'),(171078,'deals-mobile','.p-blog-index .nav-links','overflow','hidden','','','.p-blog-index'),(171079,'deals-mobile','.w-list-type-2_2 .buttons','overflow','hidden','','','.w-list-type-2_2'),(171080,'deals-mobile','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(171081,'deals-mobile','.b-fancybox .fancybox-inner','overflow','hidden','','','.b-fancybox'),(171082,'deals-mobile','.b-fancybox .fancybox-lock','overflow','hidden','','','.b-fancybox'),(171083,'deals-mobile','.b-fancybox .fancybox-lock .fancybox-overlay','overflow','auto','','','.b-fancybox'),(171084,'deals-mobile','.b-fancybox .fancybox-lock body','overflow','hidden','','','.b-fancybox'),(171085,'deals-mobile','.b-compare .col-two','overflow','hidden','','','.b-compare'),(171086,'deals-mobile','.b-compare .compare-box-item','overflow','hidden','','','.b-compare'),(171087,'deals-mobile','.w-search .suggest','overflow','auto','','','.w-search'),(171088,'deals-mobile','.w-search .item','overflow','hidden','','','.w-search'),(171089,'deals-mobile','.w-list-type-1_2 .compare-box-item','overflow','hidden','','','.w-list-type-1_2'),(171090,'deals-mobile','.w-banner .banner .image-box','overflow','hidden','','','.w-banner'),(171091,'deals-mobile','.p-account-trade-form .widget','overflow','hidden','','','.p-account-trade-form'),(171092,'deals-mobile','.p-checkout-index .sel_pr_values','overflow','hidden','','','.p-checkout-index'),(171093,'deals-mobile','.w-list-type-2 .compare-box-item','overflow','hidden','','','.w-list-type-2'),(171094,'deals-mobile','.w-list-type-1_3 .compare-box-item','overflow','hidden','','','.w-list-type-1_3'),(171095,'deals-mobile','.w-list-type-1 .compare-box-item','overflow','hidden','','','.w-list-type-1'),(171096,'deals-mobile','.b-fancybox .fancybox-tmp','overflow','visible','','','.b-fancybox'),(171097,'deals-mobile','.w-menu-mobile .menu-slider .open','overflow','auto','','','.w-menu-mobile'),(171098,'deals-mobile','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(171099,'deals-mobile','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(171100,'deals-mobile','.p-reviews-info .review-info-head','overflow','hidden','','','.p-reviews-info'),(171101,'deals-mobile','.b-fancybox .fancybox-overlay','overflow','hidden','','','.b-fancybox'),(171102,'deals-mobile','.w-sale .left','overflow','hidden','','','.w-sale'),(171103,'deals-mobile','.b-slick .slick-list','overflow','hidden','','','.b-slick'),(171104,'deals-mobile','.w-cart-discount-coupon .gift-code .input-apple > div','overflow','hidden','','','.w-cart-discount-coupon'),(171105,'deals-mobile','.p-account-history-info .history_info','overflow','hidden','','','.p-account-history-info'),(171106,'deals-mobile','.p-account-index .acount_row','overflow','hidden','','','.p-account-index'),(171107,'deals-mobile','.p-account-index .account_page','overflow','hidden','','','.p-account-index'),(171108,'deals-mobile','.w-cart-give-away .ga_ovr','overflow','hidden','','','.w-cart-give-away'),(171109,'deals-mobile','.w-cart-give-away .ga_wrapper','overflow','hidden','','','.w-cart-give-away'),(171110,'deals-mobile','.w-list-type-2 .buttons','overflow','hidden','','','.w-list-type-2'),(171111,'deals-mobile','.b-autocomplete .ui-autocomplete','overflow','auto','','','.b-autocomplete'),(171112,'deals-mobile','.w-list-type-1_3 .buttons','overflow','hidden','','','.w-list-type-1_3'),(171113,'deals-mobile','.w-list-type-1_3 .attributes > .attributes','overflow','hidden','','','.w-list-type-1_3'),(171114,'deals-mobile','.w-list-type-1_2 .buttons','overflow','hidden','','','.w-list-type-1_2'),(171115,'deals-mobile','.w-list-type-1 .buttons','overflow','hidden','','','.w-list-type-1'),(171116,'deals-mobile','.b-form .addresses .address-item span','overflow','hidden','','','.b-form'),(171117,'deals-mobile','.b-form .discount-box .inp','overflow','hidden','','','.b-form'),(171118,'deals-mobile','.b-form .payment-method .item-radio label span','overflow','hidden','','','.b-form'),(171119,'deals-mobile','.p-account-address-book .buttonBox','overflow','hidden','','','.p-account-address-book'),(171120,'deals-mobile','.b-products-listing .btn-preloader','overflow','hidden','3','','.b-products-listing'),(171121,'deals-mobile','.b-products-listing .loader','overflow','hidden','4','','.b-products-listing'),(171122,'deals-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','overflow','hidden','','','.b-menu-burger_icon'),(171123,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','overflow','auto','','','.b-menu-lev_display-width'),(171124,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','overflow','auto','','','.b-menu-lev_display-width'),(171125,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','overflow','auto','','','.b-menu-lev_display-width'),(171126,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','overflow','auto','','','.b-menu-lev_display-width'),(171127,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','overflow','auto','','','.b-menu-lev_display-width'),(171128,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','overflow','auto','','','.b-menu-lev_display-width_cont'),(171129,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','overflow','auto','','','.b-menu-lev_display-width_cont'),(171130,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','overflow','auto','','','.b-menu-lev_display-width_cont'),(171131,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','overflow','auto','','','.b-menu-lev_display-width_cont'),(171132,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','overflow','auto','','','.b-menu-lev_display-width_cont'),(171133,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','overflow','auto','','','.b-menu-open_from-left'),(171134,'deals-mobile','.b-preloader .preloader','overflow','hidden','3','','.b-preloader'),(171135,'deals-mobile','.b-select-suggest .select2-container .select2-choice','overflow','hidden','','','.b-select-suggest'),(171136,'deals-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','overflow','hidden','','','.b-select-suggest'),(171137,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow','hidden','','','.b-select-suggest'),(171138,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','overflow','hidden','','','.b-select-suggest'),(171139,'deals-mobile','.b-select-suggest .select2-measure-scrollbar','overflow','scroll','','','.b-select-suggest'),(171140,'deals-mobile','.b-trade-approval .steps-bar','overflow','hidden','','','.b-trade-approval'),(171141,'deals-mobile','.b-upload-files .attach-active-holder','overflow','hidden','','','.b-upload-files'),(171142,'deals-mobile','.b-upload-files .attached-block','overflow','hidden','','','.b-upload-files'),(171143,'deals-mobile','.b-upload-files .attach-block','overflow','hidden','','','.b-upload-files'),(171144,'deals-mobile','.b-upload-files .added-file','overflow','hidden','','','.b-upload-files'),(171145,'deals-mobile','.batchPr .w-batch-products .products-listing .image + .type-1','overflow','hidden','','','.batchPr'),(171146,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','overflow','hidden','','','.batchPr'),(171147,'deals-mobile','.batchPr .batch-selected-products-list','overflow','auto','','','.batchPr'),(171148,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(2)','overflow','hidden','','','.batchPr'),(171149,'deals-mobile','.p-account-samples-history-info .history_info','overflow','hidden','','','.p-account-samples-history-info'),(171150,'deals-mobile','.p-account-samples-history-info .history_info','overflow','hidden','','','.p-account-samples-history-info'),(171151,'deals-mobile','.p-account-samples-history-info .history_info','overflow','hidden','','','.p-account-samples-history-info'),(171152,'deals-mobile','.p-account-samples-history-info .history_info','overflow','hidden','','','.p-account-samples-history-info'),(171153,'deals-mobile','.p-account-samples-history-info .history_info','overflow','hidden','','','.p-account-samples-history-info'),(171154,'deals-mobile','.p-account-samples-history-info .history_info','overflow','hidden','','','.p-account-samples-history-info'),(171155,'deals-mobile','.p-quick-order-index .top','overflow','hidden','','','.p-quick-order-index'),(171156,'deals-mobile','.p-quick-order-index .bottom','overflow','hidden','','','.p-quick-order-index'),(171157,'deals-mobile','.w-account-addresses-list ','overflow','hidden','','','.w-account-addresses-list'),(171158,'deals-mobile','.w-blog-widget-post-linked-products .heading-2','overflow','hidden','','','.w-blog-widget-post-linked-products'),(171159,'deals-mobile','.w-blog-widget-related-posts ','overflow','hidden','','','.w-blog-widget-related-posts'),(171160,'deals-mobile','.w-blog-widget-related-posts-by-category ','overflow','hidden','','','.w-blog-widget-related-posts-by-category'),(171161,'deals-mobile','.w-cart-compare .product .name','overflow','hidden','','','.w-cart-compare'),(171162,'deals-mobile','.w-catalog-compare .compare','overflow','hidden','','','.w-catalog-compare'),(171163,'deals-mobile','.w-catalog-paging .paging-holder','overflow','hidden','','','.w-catalog-paging'),(171164,'deals-mobile','.w-catalog-paging .paging-holder.slick-slider','overflow','visible','','','.w-catalog-paging'),(171165,'deals-mobile','.w-checkout-shipping-choice #shippingchoice-choice','overflow','hidden','','','.w-checkout-shipping-choice'),(171166,'deals-mobile','.w-checkout-shipping-choice input','overflow','hidden','','','.w-checkout-shipping-choice'),(171167,'deals-mobile','.w-communication-new-topic #communication_group_holder','overflow','auto','','','.w-communication-new-topic'),(171168,'deals-mobile','.w-delivery-day .time-left','overflow','hidden','','','.w-delivery-day'),(171169,'deals-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','overflow','hidden','','','.w-promotions'),(171170,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','overflow','hidden','','','.w-wedding-registry-widgets-photos'),(171171,'deals-mobile','.b-compare .compare_list','overflow-x','hidden','','','.b-compare'),(171172,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-x','hidden','','','.b-menu-lev_display-slide'),(171173,'deals-mobile','.b-select-suggest .select2-results','overflow-x','hidden','','','.b-select-suggest'),(171174,'deals-mobile','.b-compare .compare_list','overflow-y','auto','','','.b-compare'),(171175,'deals-mobile','.b-fancybox .fancybox-lock-test','overflow-y','hidden','','','.b-fancybox'),(171176,'deals-mobile','.b-fancybox .fancybox-lock .fancybox-overlay','overflow-y','scroll','','','.b-fancybox'),(171177,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-y','auto','','','.b-menu-lev_display-slide'),(171178,'deals-mobile','.b-select-suggest .select2-results','overflow-y','auto','','','.b-select-suggest'),(171179,'deals-mobile','.b-fancybox .fancybox-lock-test','overflow-y_important','important','','','.b-fancybox'),(171180,'deals-mobile','.b-fancybox .fancybox-lock','overflow_important','important','','','.b-fancybox'),(171181,'deals-mobile','.b-fancybox .fancybox-lock body','overflow_important','important','','','.b-fancybox'),(171182,'deals-mobile','.b-fancybox .fancybox-tmp','overflow_important','important','','','.b-fancybox'),(171183,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow_important','important','','','.b-select-suggest'),(171184,'deals-mobile','.w-list-type-1_3 .compare-box-item','padding-bottom','7','','','.w-list-type-1_3'),(171185,'deals-mobile','.w-list-type-2 .compare-box-item','padding-bottom','7','','','.w-list-type-2'),(171186,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-2'),(171187,'deals-mobile','.w-list-type-2_2.products-listing','padding-bottom','20','','','.w-list-type-2_2'),(171188,'deals-mobile','.w-list-type-1_3 .item','padding-bottom','20','','','.w-list-type-1_3'),(171189,'deals-mobile','.w-list-type-2_2 .compare-box-item','padding-bottom','7','','','.w-list-type-2_2'),(171190,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-2_2'),(171191,'deals-mobile','.w-list-type-2.products-listing','padding-bottom','20','','','.w-list-type-2'),(171192,'deals-mobile','.w-list-type-2 .item','padding-bottom','21','','','.w-list-type-2'),(171193,'deals-mobile','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(171194,'deals-mobile','.w-list-type-3.products-listing','padding-bottom','20','','','.w-list-type-3'),(171195,'deals-mobile','.w-menu .hided.menu ul li','padding-bottom','0','','','.w-menu'),(171196,'deals-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-bottom','0','','','.w-menu'),(171197,'deals-mobile','.w-menu-slider > ul > li > a','padding-bottom','5','','','.w-menu-slider'),(171198,'deals-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-bottom','2','','','.w-menu-horizontal'),(171199,'deals-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','6','','','.w-menu-horizontal'),(171200,'deals-mobile','.w-menu-big ul','padding-bottom','0','','','.w-menu-big'),(171201,'deals-mobile','.w-menu-horizontal > ul > li > ul > li','padding-bottom','2','','','.w-menu-horizontal'),(171202,'deals-mobile','.w-menu-slider > ul > li > ul > li','padding-bottom','10','','','.w-menu-slider'),(171203,'deals-mobile','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(171204,'deals-mobile','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(171205,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-bottom','0','','','.b-slick'),(171206,'deals-mobile','.w-top-categories .item','padding-bottom','30','863','','.w-top-categories'),(171207,'deals-mobile','.w-menu-slider ul, .w-menu-slider li','padding-bottom','0','','','.w-menu-slider'),(171208,'deals-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','5','','','.w-menu-style-1'),(171209,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(171210,'deals-mobile','.b-bottom .popup-simple','padding-bottom','20','','','.b-bottom'),(171211,'deals-mobile','.b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .buttons','padding-bottom','10','','','.b-cookie-notice'),(171212,'deals-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.bottom .text','padding-bottom','5','','','.b-cookie-notice'),(171213,'deals-mobile','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(171214,'deals-mobile','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(171215,'deals-mobile','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(171216,'deals-mobile','.w-product-wedding-registry-button .btn','padding-bottom','0','','','.w-product-wedding-registry-button'),(171217,'deals-mobile','.w-search .items-title','padding-bottom','5','','','.w-search'),(171218,'deals-mobile','.w-sale .holder-2','padding-bottom','20','','','.w-sale'),(171219,'deals-mobile','.w-sale .left-count','padding-bottom','0','','','.w-sale'),(171220,'deals-mobile','.w-list-type-1_2 .button-wishlist button','padding-bottom','10','','','.w-list-type-1_2'),(171221,'deals-mobile','.w-product-sale-ends .left-text-left','padding-bottom','24','','','.w-product-sale-ends'),(171222,'deals-mobile','.w-product-sale-ends .left-text-right','padding-bottom','24','','','.w-product-sale-ends'),(171223,'deals-mobile','.w-currencies .select-link','padding-bottom','5','','','.w-currencies'),(171224,'deals-mobile','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(171225,'deals-mobile','.w-currencies .current','padding-bottom','3','','','.w-currencies'),(171226,'deals-mobile','.w-categories .name','padding-bottom','3','','','.w-categories'),(171227,'deals-mobile','.w-categories .item','padding-bottom','30','','','.w-categories'),(171228,'deals-mobile','.w-filters .filter-ul-content','padding-bottom','0','','','.w-filters'),(171229,'deals-mobile','.p-account-address-book .buttonBox','padding-bottom','15','','','.p-account-address-book'),(171230,'deals-mobile','.p-account-history .order_history_table th','padding-bottom','10','','','.p-account-history'),(171231,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','padding-bottom','5','','','.p-account-history-info'),(171232,'deals-mobile','.p-account-history-info .contentColumn','padding-bottom','10','','','.p-account-history-info'),(171233,'deals-mobile','.p-account-history-info .historyTotal td','padding-bottom','2','','','.p-account-history-info'),(171234,'deals-mobile','.p-account-history-info .history_info > div + div','padding-bottom','0','','','.p-account-history-info'),(171235,'deals-mobile','.p-account-index .account_info','padding-bottom','0','','','.p-account-index'),(171236,'deals-mobile','.p-account-index .account_info li','padding-bottom','0','','','.p-account-index'),(171237,'deals-mobile','.p-account-index .account_block','padding-bottom','20','','','.p-account-index'),(171238,'deals-mobile','.p-account-index .account_page','padding-bottom','0','','','.p-account-index'),(171239,'deals-mobile','.p-account-index .date_title','padding-bottom','0','','','.p-account-index'),(171240,'deals-mobile','.p-account-index .badc_bottom','padding-bottom','58','','','.p-account-index'),(171241,'deals-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','padding-bottom','10','','','.p-account-index'),(171242,'deals-mobile','.p-account-index .orders-table th','padding-bottom','2','','','.p-account-index'),(171243,'deals-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-bottom','10','','','.p-account-subscription-historyinfo'),(171244,'deals-mobile','.b-bottom .popup-buttons','padding-bottom','15','','','.b-bottom'),(171245,'deals-mobile','.w-product-images .img-holder','padding-bottom','20','','','.w-product-images'),(171246,'deals-mobile','.b-bottom .popup-content','padding-bottom','15','','','.b-bottom'),(171247,'deals-mobile','.b-compare .compare_pagination','padding-bottom','10','','','.b-compare'),(171248,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-bottom','20','','','.b-multi-page-checkout'),(171249,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-bottom','6','','','.b-multi-page-checkout'),(171250,'deals-mobile','.w-sale .holder-1','padding-bottom','20','','','.w-sale'),(171251,'deals-mobile','.w-search .suggest','padding-bottom','0','','','.w-search'),(171252,'deals-mobile','.b-info-popup .info-popup div','padding-bottom','10','','','.b-info-popup'),(171253,'deals-mobile','.w-search .name','padding-bottom','0','','','.w-search'),(171254,'deals-mobile','.w-search .item','padding-bottom','10','','','.w-search'),(171255,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-bottom','0','','','.b-multi-page-checkout'),(171256,'deals-mobile','.w-search .search-input','padding-bottom','5','','','.w-search'),(171257,'deals-mobile','.w-socials > li','padding-bottom','15','','','.w-socials'),(171258,'deals-mobile','.w-promo-code .holder','padding-bottom','20','893','','.w-promo-code'),(171259,'deals-mobile','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(171260,'deals-mobile','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(171261,'deals-mobile','.p-wedding-registry-manage a.remove-btn','padding-bottom','5','','','.p-wedding-registry-manage'),(171262,'deals-mobile','.p-account-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-history-info'),(171263,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','padding-bottom','5','','','.p-account-order-pay'),(171264,'deals-mobile','.p-account-order-pay .contentColumn','padding-bottom','10','','','.p-account-order-pay'),(171265,'deals-mobile','.p-account-order-pay .historyTotal td','padding-bottom','2','','','.p-account-order-pay'),(171266,'deals-mobile','.p-account-order-pay .history_info > div + div','padding-bottom','0','','','.p-account-order-pay'),(171267,'deals-mobile','.p-account-order-pay .history_info > div','padding-bottom','0','864','','.p-account-order-pay'),(171268,'deals-mobile','.w-filters .head-filter-widget','padding-bottom','0','890','','.w-filters'),(171269,'deals-mobile','.w-product-configurator .pc_attr','padding-bottom','5','863','','.w-product-configurator'),(171270,'deals-mobile','.w-product-configurator .pc_item','padding-bottom','10','872','','.w-product-configurator'),(171271,'deals-mobile','.testimonials .name','padding-bottom','5','','',''),(171272,'deals-mobile','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(171273,'deals-mobile','.p-account-order-pay .history_info > div + div','padding-bottom','0','864','','.p-account-order-pay'),(171274,'deals-mobile','.testimonials .heading-3','padding-bottom','10','','',''),(171275,'deals-mobile','.testimonials .review','padding-bottom','10','','',''),(171276,'deals-mobile','.testimonials .reviews-list .name','padding-bottom','5','','',''),(171277,'deals-mobile','.b-bottom .confirm-popup .buttons','padding-bottom','30','','','.b-bottom'),(171278,'deals-mobile','.b-bottom .confirm-popup .confirm-text','padding-bottom','30','','','.b-bottom'),(171279,'deals-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','padding-bottom','10','','','.p-account-history'),(171280,'deals-mobile','.p-account-history .orders-table th','padding-bottom','2','','','.p-account-history'),(171281,'deals-mobile','.p-account-history .view_link','padding-bottom','0','','','.p-account-history'),(171282,'deals-mobile','.p-account-history .orders-table .item','padding-bottom','60','890','','.p-account-history'),(171283,'deals-mobile','.p-account-history .orders-table td','padding-bottom','5','890','','.p-account-history'),(171284,'deals-mobile','.p-account-history .orders-table .td-alignright','padding-bottom','5','890','','.p-account-history'),(171285,'deals-mobile','.p-account-index .orders-table td','padding-bottom','5','890','','.p-account-index'),(171286,'deals-mobile','.p-account-index .orders-table .td-alignright','padding-bottom','5','890','','.p-account-index'),(171287,'deals-mobile','.p-account-index .orders-table .item','padding-bottom','45','890','','.p-account-index'),(171288,'deals-mobile','.btn-1','padding-bottom','4','','',''),(171289,'deals-mobile','.btn','padding-bottom','8','','',''),(171290,'deals-mobile','.btn-2','padding-bottom','12','','',''),(171291,'deals-mobile','.p-blog-index .comment-list','padding-bottom','30','','','.p-blog-index'),(171292,'deals-mobile','.p-blog-index .comments-area article','padding-bottom','10','','','.p-blog-index'),(171293,'deals-mobile','.btn-3','padding-bottom','10','','',''),(171294,'deals-mobile','.w-list-type-2_2 .buttons','padding-bottom','3','','','.w-list-type-2_2'),(171295,'deals-mobile','.no-found','padding-bottom','20','','',''),(171296,'deals-mobile','.w-list-type-2_2 .item','padding-bottom','20','','','.w-list-type-2_2'),(171297,'deals-mobile','.w-list-type-2_2 .button-wishlist button','padding-bottom','10','','','.w-list-type-2_2'),(171298,'deals-mobile','.w-product-personal-catalog-button .btn','padding-bottom','0','','','.w-product-personal-catalog-button'),(171299,'deals-mobile','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(171300,'deals-mobile','.w-account ul, .w-account li','padding-bottom','0','','','.w-account'),(171301,'deals-mobile','.b-fancybox .fancybox-error','padding-bottom','15','','','.b-fancybox'),(171302,'deals-mobile','.w-menu-horizontal ul','padding-bottom','0','','','.w-menu-horizontal'),(171303,'deals-mobile','.w-chat .w-chat-box','padding-bottom','2','','','.w-chat'),(171304,'deals-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-bottom','0','','','.w-delivery-location-top-location-list'),(171305,'deals-mobile','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(171306,'deals-mobile','.p-wedding-registry-index .middle-box','padding-bottom','30','','','.p-wedding-registry-index'),(171307,'deals-mobile','.p-wedding-registry-index .main-content','padding-bottom','70','','','.p-wedding-registry-index'),(171308,'deals-mobile','.p-wedding-registry-index .main-button','padding-bottom','0','4','','.p-wedding-registry-index'),(171309,'deals-mobile','.p-wedding-registry-index .main-button','padding-bottom','40','','','.p-wedding-registry-index'),(171310,'deals-mobile','.p-wedding-registry-index .main-button','padding-bottom','0','3','','.p-wedding-registry-index'),(171311,'deals-mobile','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(171312,'deals-mobile','.b-form .form-buttons','padding-bottom','50','','','.b-form'),(171313,'deals-mobile','.p-wedding-registry-manage .links a','padding-bottom','0','','','.p-wedding-registry-manage'),(171314,'deals-mobile','.b-bottom .alert-message','padding-bottom','20','','','.b-bottom'),(171315,'deals-mobile','.p-wedding-registry-manage .links','padding-bottom','10','','','.p-wedding-registry-manage'),(171316,'deals-mobile','.p-wedding-registry-share .middle-form > input','padding-bottom','0','','','.p-wedding-registry-share'),(171317,'deals-mobile','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(171318,'deals-mobile','.b-table .table td','padding-bottom','15','','','.b-table'),(171319,'deals-mobile','.header2 .ccc','padding-bottom','10','','',''),(171320,'deals-mobile','.p-account-address-book .btn-edit','padding-bottom','0','4','','.p-account-address-book'),(171321,'deals-mobile','.p-account-address-book .topButtons','padding-bottom','15','','','.p-account-address-book'),(171322,'deals-mobile','.p-account-address-book .rightMes ul','padding-bottom','0','','','.p-account-address-book'),(171323,'deals-mobile','.p-account-address-book .address_book h1','padding-bottom','5','','','.p-account-address-book'),(171324,'deals-mobile','.p-account-address-book .address_book, .p-account-address-book .account_history_info','padding-bottom','10','','','.p-account-address-book'),(171325,'deals-mobile','.p-account-address-book .address_book','padding-bottom','30','','','.p-account-address-book'),(171326,'deals-mobile','.p-account-address-book .address_book h2','padding-bottom','10','','','.p-account-address-book'),(171327,'deals-mobile','.b-bottom .popup-heading','padding-bottom','12','','','.b-bottom'),(171328,'deals-mobile','.b-compare .col-gender','padding-bottom','10','','','.b-compare'),(171329,'deals-mobile','.b-compare .col-two label','padding-bottom','5','','','.b-compare'),(171330,'deals-mobile','.b-compare .compare-head','padding-bottom','0','','','.b-compare'),(171331,'deals-mobile','.b-compare .compare-box-item','padding-bottom','10','','','.b-compare'),(171332,'deals-mobile','.b-compare .column_wrapper','padding-bottom','10','','','.b-compare'),(171333,'deals-mobile','.w-quote .cart-box-link','padding-bottom','5','872','','.w-quote'),(171334,'deals-mobile','.w-tabs .accordion-heading','padding-bottom','6','2','','.w-tabs'),(171335,'deals-mobile','.w-languages .current','padding-bottom','13','872','','.w-languages'),(171336,'deals-mobile','.w-currencies .select-link','padding-bottom','12','872','','.w-currencies'),(171337,'deals-mobile','.w-tabs .accordion-heading','padding-bottom','8','','','.w-tabs'),(171338,'deals-mobile','.w-languages .lang-link','padding-bottom','13','872','','.w-languages'),(171339,'deals-mobile','.w-currencies .current','padding-bottom','14','872','','.w-currencies'),(171340,'deals-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','12','872','','.w-menu-horizontal'),(171341,'deals-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','12','876','','.w-menu-style-1'),(171342,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-bottom','8','876','','.w-list-type-1'),(171343,'deals-mobile','.w-search .button-search','padding-bottom','6','','','.w-search'),(171344,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-bottom','12','876','','.w-menu-style-1'),(171345,'deals-mobile','.b-bottom .footerTitle','padding-bottom','9','863','','.b-bottom'),(171346,'deals-mobile','.p-account-history-info .history_info > div','padding-bottom','0','864','','.p-account-history-info'),(171347,'deals-mobile','.p-account-history-info .history_info > div + div','padding-bottom','0','864','','.p-account-history-info'),(171348,'deals-mobile','.w-cart .cart-total','padding-bottom','10','','','.w-cart'),(171349,'deals-mobile','.w-cart .cart-content','padding-bottom','5','','','.w-cart'),(171350,'deals-mobile','.w-cart .cart-box-link','padding-bottom','5','','','.w-cart'),(171351,'deals-mobile','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(171352,'deals-mobile','.w-product-reviews .reviews-list .name','padding-bottom','5','','','.w-product-reviews'),(171353,'deals-mobile','.w-reviews .name','padding-bottom','5','','','.w-reviews'),(171354,'deals-mobile','.w-tabs .tab-a','padding-bottom','6','2','','.w-tabs'),(171355,'deals-mobile','.w-bestsellers .heading-3','padding-bottom','15','','','.w-bestsellers'),(171356,'deals-mobile','.w-account a.my-acc-link','padding-bottom','5','','','.w-account'),(171357,'deals-mobile','.w-list-type-1_3 .item','padding-bottom','20','1','','.w-list-type-1_3'),(171358,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-1_2'),(171359,'deals-mobile','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(171360,'deals-mobile','.w-tabs .tab-navigation','padding-bottom','0','','','.w-tabs'),(171361,'deals-mobile','.p-account-trade-form .widget','padding-bottom','20','','','.p-account-trade-form'),(171362,'deals-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-bottom','0','','','.p-blog-index'),(171363,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-bottom','5','','','.p-blog-index'),(171364,'deals-mobile','.p-blog-index .nav-links','padding-bottom','20','','','.p-blog-index'),(171365,'deals-mobile','.p-checkout-index .same-address','padding-bottom','15','','','.p-checkout-index'),(171366,'deals-mobile','.p-blog-index .wp-widget li','padding-bottom','10','','','.p-blog-index'),(171367,'deals-mobile','.p-blog-index .wp-widget ul','padding-bottom','0','','','.p-blog-index'),(171368,'deals-mobile','.p-checkout-index .shipping-method .item','padding-bottom','10','','','.p-checkout-index'),(171369,'deals-mobile','.p-checkout-index .shipping-method .title','padding-bottom','0','','','.p-checkout-index'),(171370,'deals-mobile','.p-checkout-index .shipping-method .row','padding-bottom','5','','','.p-checkout-index'),(171371,'deals-mobile','.p-quote-cart-index .cart-page .empty','padding-bottom','100','','','.p-quote-cart-index'),(171372,'deals-mobile','.p-reviews-info .review-info-image','padding-bottom','20','','','.p-reviews-info'),(171373,'deals-mobile','.p-reviews-info .review-info-content','padding-bottom','20','','','.p-reviews-info'),(171374,'deals-mobile','.p-quote-cart-index .cart-popup .cart-page, .p-quote-cart-index .cart-popup .wishlist-page','padding-bottom','10','','','.p-quote-cart-index'),(171375,'deals-mobile','.p-reviews-info .review-info-text','padding-bottom','10','','','.p-reviews-info'),(171376,'deals-mobile','.p-reviews-info .reviews-info .buttons','padding-bottom','20','','','.p-reviews-info'),(171377,'deals-mobile','.p-shopping-cart-index .cart-popup .cart-page, .p-shopping-cart-index .cart-popup .wishlist-page','padding-bottom','10','','','.p-shopping-cart-index'),(171378,'deals-mobile','.p-shopping-cart-index .cart-page .empty','padding-bottom','100','','','.p-shopping-cart-index'),(171379,'deals-mobile','.p-account-index .account_info li','padding-bottom','10','863','','.p-account-index'),(171380,'deals-mobile','.p-account-index .topAccount > li > div','padding-bottom','0','863','','.p-account-index'),(171381,'deals-mobile','.w-filters .filter-box-content','padding-bottom','20','','','.w-filters'),(171382,'deals-mobile','.w-filters .filter-box-head','padding-bottom','5','','','.w-filters'),(171383,'deals-mobile','.w-filters .filter-li-content','padding-bottom','15','','','.w-filters'),(171384,'deals-mobile','.b-slick .slick-vertical button.slick-next','padding-bottom','0','3','','.b-slick'),(171385,'deals-mobile','.b-slick .slick-vertical button.slick-prev','padding-bottom','0','3','','.b-slick'),(171386,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-bottom','2','','','.b-fancybox'),(171387,'deals-mobile','.p-account-trade-form .trade-form-area','padding-bottom','20','','','.p-account-trade-form'),(171388,'deals-mobile','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(171389,'deals-mobile','.b-info .info ul','padding-bottom','0','','','.b-info'),(171390,'deals-mobile','.w-product-configurator .pc_item','padding-bottom','10','','','.w-product-configurator'),(171391,'deals-mobile','.p-account-index th','padding-bottom','10','','','.p-account-index'),(171392,'deals-mobile','.p-account-index .view_link','padding-bottom','0','','','.p-account-index'),(171393,'deals-mobile','.p-account-index .topAccount','padding-bottom','17','','','.p-account-index'),(171394,'deals-mobile','.p-account-index .topAccount > li','padding-bottom','0','','','.p-account-index'),(171395,'deals-mobile','.w-list-type-2 .item','padding-bottom','20','1','','.w-list-type-2'),(171396,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-1_3'),(171397,'deals-mobile','.w-list-type-1_2 .compare-box-item','padding-bottom','7','','','.w-list-type-1_2'),(171398,'deals-mobile','.w-list-type-1 .item','padding-bottom','20','','','.w-list-type-1'),(171399,'deals-mobile','.w-list-type-1 .compare-box-item','padding-bottom','7','','','.w-list-type-1'),(171400,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-bottom','0','','','.w-list-type-1'),(171401,'deals-mobile','.w-list-type-1 ','padding-bottom','20','','','.w-list-type-1'),(171402,'deals-mobile','.w-list-type-1_2.products-listing','padding-bottom','20','','','.w-list-type-1_2'),(171403,'deals-mobile','.w-filters .head-filter-widget','padding-bottom','10','','','.w-filters'),(171404,'deals-mobile','.w-languages .lang-link','padding-bottom','5','','','.w-languages'),(171405,'deals-mobile','.w-languages .current','padding-bottom','3','','','.w-languages'),(171406,'deals-mobile','.w-filters .ui-slider-range','padding-bottom','0','','','.w-filters'),(171407,'deals-mobile','.w-filters .fsl_handle','padding-bottom','15','','','.w-filters'),(171408,'deals-mobile','.b-fancybox .fancybox-title-over-wrap','padding-bottom','10','','','.b-fancybox'),(171409,'deals-mobile','.w-currencies .currencies-title','padding-bottom','0','','','.w-currencies'),(171410,'deals-mobile','.w-categories .image','padding-bottom','75','','','.w-categories'),(171411,'deals-mobile','.w-cart a.item','padding-bottom','5','','','.w-cart'),(171412,'deals-mobile','.w-breadcrumb .breadcrumb-li','padding-bottom','0','','','.w-breadcrumb'),(171413,'deals-mobile','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(171414,'deals-mobile','.b-compare .popupCompare .pop-up-content','padding-bottom','10','','','.b-compare'),(171415,'deals-mobile','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(171416,'deals-mobile','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(171417,'deals-mobile','.w-reviews .heading-3','padding-bottom','10','','','.w-reviews'),(171418,'deals-mobile','.w-product-sale-ends .left-count','padding-bottom','0','','','.w-product-sale-ends'),(171419,'deals-mobile','.w-product-reviews .reviews-list .review','padding-bottom','10','','','.w-product-reviews'),(171420,'deals-mobile','.w-quote .cart-box-link','padding-bottom','5','','','.w-quote'),(171421,'deals-mobile','.w-reviews .review','padding-bottom','10','','','.w-reviews'),(171422,'deals-mobile','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(171423,'deals-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(171424,'deals-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(171425,'deals-mobile','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(171426,'deals-mobile','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(171427,'deals-mobile','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(171428,'deals-mobile','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(171429,'deals-mobile','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(171430,'deals-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(171431,'deals-mobile','.w-menu-style-1 ul','padding-bottom','0','','','.w-menu-style-1'),(171432,'deals-mobile','.w-sale .left-text-right','padding-bottom','24','','','.w-sale'),(171433,'deals-mobile','.w-sale .left-text-left','padding-bottom','24','','','.w-sale'),(171434,'deals-mobile','.w-tabs .accordion-heading','padding-bottom','9','863','','.w-tabs'),(171435,'deals-mobile','.w-top-categories .categories h2','padding-bottom','0','','','.w-top-categories'),(171436,'deals-mobile','.w-categories .categories h2','padding-bottom','0','','','.w-categories'),(171437,'deals-mobile','.w-banner .carousel-text > span','padding-bottom','20','','','.w-banner'),(171438,'deals-mobile','.b-form .col-full-padding','padding-bottom','30','','','.b-form'),(171439,'deals-mobile','.b-slick .slick-list','padding-bottom','0','','','.b-slick'),(171440,'deals-mobile','.w-tabs .tab-li','padding-bottom','0','','','.w-tabs'),(171441,'deals-mobile','.w-tabs .tab-a','padding-bottom','8','','','.w-tabs'),(171442,'deals-mobile','.p-account-index .account_info .info','padding-bottom','25','','','.p-account-index'),(171443,'deals-mobile','.w-categories .item','padding-bottom','30','863','','.w-categories'),(171444,'deals-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-bottom','0','','','.b-fancybox'),(171445,'deals-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-bottom','0','','','.b-fancybox'),(171446,'deals-mobile','.w-cart-give-away .ga_column','padding-bottom','15','','','.w-cart-give-away'),(171447,'deals-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-bottom','4','','','.b-compare'),(171448,'deals-mobile','.w-product-images .images','padding-bottom','20','893','','.w-product-images'),(171449,'deals-mobile','.p-account-index .topAccount > li','padding-bottom','10','863','','.p-account-index'),(171450,'deals-mobile','.w-search .search form','padding-bottom','5','','','.w-search'),(171451,'deals-mobile','.w-list-type-2 .buttons','padding-bottom','3','','','.w-list-type-2'),(171452,'deals-mobile','.w-list-type-2 .button-wishlist button','padding-bottom','10','','','.w-list-type-2'),(171453,'deals-mobile','.b-autocomplete .ui-autocomplete','padding-bottom','0','','','.b-autocomplete'),(171454,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','padding-bottom','5','','',''),(171455,'deals-mobile','textarea','padding-bottom','5','','',''),(171456,'deals-mobile','.w-list-type-1_3 .buttons','padding-bottom','3','','','.w-list-type-1_3'),(171457,'deals-mobile','.w-list-type-1_3 .button-wishlist button','padding-bottom','10','','','.w-list-type-1_3'),(171458,'deals-mobile','.b-autocomplete .ui-autocomplete li','padding-bottom','3','','','.b-autocomplete'),(171459,'deals-mobile','.w-list-type-1_2 .item','padding-bottom','20','','','.w-list-type-1_2'),(171460,'deals-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-bottom','10','','','.b-bottom'),(171461,'deals-mobile','.w-list-type-1_2 .buttons','padding-bottom','3','','','.w-list-type-1_2'),(171462,'deals-mobile','.b-bottom .pop-up-close','padding-bottom','1','','','.b-bottom'),(171463,'deals-mobile','.b-bottom .pop-up-info','padding-bottom','20','','','.b-bottom'),(171464,'deals-mobile','.heading-4, h4','padding-bottom','3','','',''),(171465,'deals-mobile','.w-list-type-1 .buttons','padding-bottom','3','','','.w-list-type-1'),(171466,'deals-mobile','.w-list-type-1 .button-wishlist button','padding-bottom','10','','','.w-list-type-1'),(171467,'deals-mobile','.b-bottom .popup-box-wrap','padding-bottom','10','','','.b-bottom'),(171468,'deals-mobile','.b-form .center-buttons','padding-bottom','20','','','.b-form'),(171469,'deals-mobile','.w-reviews .reviews-list .name','padding-bottom','5','','','.w-reviews'),(171470,'deals-mobile','.w-top-categories .name','padding-bottom','3','','','.w-top-categories'),(171471,'deals-mobile','.p-account-index .account_info','padding-bottom','0','876','','.p-account-index'),(171472,'deals-mobile','.w-top-categories .image','padding-bottom','75','','','.w-top-categories'),(171473,'deals-mobile','.w-tabs > .block','padding-bottom','20','','','.w-tabs'),(171474,'deals-mobile','.w-top-categories .item','padding-bottom','30','','','.w-top-categories'),(171475,'deals-mobile','.b-form .middle-form','padding-bottom','20','','','.b-form'),(171476,'deals-mobile','.b-form .payment-method .item-radio label','padding-bottom','5','','','.b-form'),(171477,'deals-mobile','.b-form .required-message','padding-bottom','0','','','.b-form'),(171478,'deals-mobile','.b-form .shipping-method .input','padding-bottom','0','','','.b-form'),(171479,'deals-mobile','.b-form .required-message-wrap','padding-bottom','0','','','.b-form'),(171480,'deals-mobile','.b-info .info','padding-bottom','15','','','.b-info'),(171481,'deals-mobile','.b-info .info li','padding-bottom','0','','','.b-info'),(171482,'deals-mobile','.b-products-listing .in-cart','padding-bottom','4','','','.b-products-listing'),(171483,'deals-mobile','.b-products-listing .products-listing .btn-buy','padding-bottom','4','','','.b-products-listing'),(171484,'deals-mobile','.b-products-listing .products-listing .buyButton .btn','padding-bottom','4','','','.b-products-listing'),(171485,'deals-mobile','.b-products-listing .products-listing .compare','padding-bottom','6','','','.b-products-listing'),(171486,'deals-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-bottom','6','','','.b-products-listing'),(171487,'deals-mobile','.b-products-listing .products-listing a.btn.view-button','padding-bottom','6','','','.b-products-listing'),(171488,'deals-mobile','.b-products-listing .products-listing h2','padding-bottom','0','','','.b-products-listing'),(171489,'deals-mobile','.b-products-listing .promos-info .promo-item','padding-bottom','3','','','.b-products-listing'),(171490,'deals-mobile','.b-products-listing .promos-info .promo-name','padding-bottom','3','','','.b-products-listing'),(171491,'deals-mobile','.b-products-listing .list-productlisting div.BlockBox.item-holder','padding-bottom','25','','','.b-products-listing'),(171492,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.b-data-table'),(171493,'deals-mobile','.b-data-table table.dataTable thead td','padding-bottom','10','','','.b-data-table'),(171494,'deals-mobile','.b-data-table table.dataTable tbody td','padding-bottom','10','','','.b-data-table'),(171495,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom','0','','','.b-data-table'),(171496,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(171497,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(171498,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(171499,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(171500,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(171501,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(171502,'deals-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(171503,'deals-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(171504,'deals-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(171505,'deals-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(171506,'deals-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(171507,'deals-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(171508,'deals-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(171509,'deals-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(171510,'deals-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(171511,'deals-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(171512,'deals-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(171513,'deals-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(171514,'deals-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(171515,'deals-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(171516,'deals-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(171517,'deals-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(171518,'deals-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(171519,'deals-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(171520,'deals-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(171521,'deals-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(171522,'deals-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(171523,'deals-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(171524,'deals-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(171525,'deals-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(171526,'deals-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(171527,'deals-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(171528,'deals-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(171529,'deals-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(171530,'deals-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(171531,'deals-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(171532,'deals-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(171533,'deals-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(171534,'deals-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(171535,'deals-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(171536,'deals-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(171537,'deals-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(171538,'deals-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(171539,'deals-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(171540,'deals-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(171541,'deals-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(171542,'deals-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(171543,'deals-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(171544,'deals-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(171545,'deals-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(171546,'deals-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(171547,'deals-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(171548,'deals-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(171549,'deals-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(171550,'deals-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(171551,'deals-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(171552,'deals-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(171553,'deals-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(171554,'deals-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(171555,'deals-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(171556,'deals-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(171557,'deals-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(171558,'deals-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(171559,'deals-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(171560,'deals-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(171561,'deals-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(171562,'deals-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(171563,'deals-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(171564,'deals-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(171565,'deals-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(171566,'deals-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(171567,'deals-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(171568,'deals-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(171569,'deals-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(171570,'deals-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(171571,'deals-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(171572,'deals-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(171573,'deals-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(171574,'deals-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(171575,'deals-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(171576,'deals-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(171577,'deals-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(171578,'deals-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(171579,'deals-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(171580,'deals-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(171581,'deals-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(171582,'deals-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(171583,'deals-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(171584,'deals-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(171585,'deals-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(171586,'deals-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(171587,'deals-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(171588,'deals-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(171589,'deals-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(171590,'deals-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(171591,'deals-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(171592,'deals-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(171593,'deals-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(171594,'deals-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(171595,'deals-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(171596,'deals-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(171597,'deals-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(171598,'deals-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(171599,'deals-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(171600,'deals-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(171601,'deals-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(171602,'deals-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(171603,'deals-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(171604,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-bottom','0','','','.b-h-inline'),(171605,'deals-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-bottom','0','','','.b-menu-style'),(171606,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-bottom','5','','','.b-menu-style-1'),(171607,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-bottom','5','','','.b-menu-style-1'),(171608,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-bottom','20','','','.b-menu-style-1'),(171609,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-bottom','0','','','.b-menu-style-1'),(171610,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-bottom','5','','','.b-menu-style-2'),(171611,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-bottom','5','','','.b-menu-style-2'),(171612,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-bottom','0','','','.b-menu-style-2'),(171613,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-bottom','0','','','.b-menu-style-2'),(171614,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-bottom','10','','','.b-menu-style-2'),(171615,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-bottom','0','','','.b-menu-style-2'),(171616,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-bottom','5','','','.b-menu-style-2'),(171617,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-bottom','10','','','.b-menu-style-2'),(171618,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-bottom','5','','','.b-menu-style-2'),(171619,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-bottom','10','','','.b-menu-style-2'),(171620,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-bottom','5','','','.b-menu-style-3'),(171621,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','padding-bottom','5','','','.b-menu-style-3'),(171622,'deals-mobile','.b-messages .msv_btn','padding-bottom','12','','','.b-messages'),(171623,'deals-mobile','.b-messages .msv_content','padding-bottom','10','','','.b-messages'),(171624,'deals-mobile','.b-messages .msv_history','padding-bottom','10','','','.b-messages'),(171625,'deals-mobile','.b-messages .messMenuButton span','padding-bottom','10','','','.b-messages'),(171626,'deals-mobile','.b-messages .messages-menu ul','padding-bottom','0','','','.b-messages'),(171627,'deals-mobile','.b-messages .messages-menu li a','padding-bottom','8','','','.b-messages'),(171628,'deals-mobile','.b-messages .messages-menu li','padding-bottom','0','','','.b-messages'),(171629,'deals-mobile','.b-messages .content_management_attach button','padding-bottom','1','','','.b-messages'),(171630,'deals-mobile','.b-messages .email-heading','padding-bottom','15','','','.b-messages'),(171631,'deals-mobile','.b-messages .content_management_attach','padding-bottom','8','','','.b-messages'),(171632,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-bottom','5','','','.b-messages'),(171633,'deals-mobile','.b-messages .emailBtn','padding-bottom','10','','','.b-messages'),(171634,'deals-mobile','.b-messages .msv_to_cc','padding-bottom','10','','','.b-messages'),(171635,'deals-mobile','.b-messages .dataTables_wrapper > .bottom','padding-bottom','4','','','.b-messages'),(171636,'deals-mobile','.b-messages .emailLineTextArea textarea','padding-bottom','30','','','.b-messages'),(171637,'deals-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-bottom','20','','','.b-personal-catalog-popup'),(171638,'deals-mobile','.b-select-suggest .select2-container .select2-choice','padding-bottom','0','','','.b-select-suggest'),(171639,'deals-mobile','.b-select-suggest .select2-search input','padding-bottom','4','','','.b-select-suggest'),(171640,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(171641,'deals-mobile','.b-select-suggest .select2-drop-mask','padding-bottom','0','','','.b-select-suggest'),(171642,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-bottom','0','','','.b-select-suggest'),(171643,'deals-mobile','.b-select-suggest .select2-results','padding-bottom','0','','','.b-select-suggest'),(171644,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-bottom','0','','','.b-select-suggest'),(171645,'deals-mobile','.b-select-suggest .select2-locked','padding-bottom','3','','','.b-select-suggest'),(171646,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-bottom','0','','','.b-select-suggest'),(171647,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-bottom','5','','','.b-select-suggest'),(171648,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(171649,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','padding-bottom','4','','','.b-select-suggest'),(171650,'deals-mobile','.b-sub-totals .historyTotal td','padding-bottom','2','','','.b-sub-totals'),(171651,'deals-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(171652,'deals-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(171653,'deals-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(171654,'deals-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(171655,'deals-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(171656,'deals-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(171657,'deals-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(171658,'deals-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(171659,'deals-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(171660,'deals-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(171661,'deals-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(171662,'deals-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(171663,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(171664,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(171665,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(171666,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(171667,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(171668,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(171669,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(171670,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(171671,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(171672,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(171673,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(171674,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(171675,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(171676,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(171677,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(171678,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(171679,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(171680,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(171681,'deals-mobile','.b-trade-approval .steps-bar li a','padding-bottom','7','','','.b-trade-approval'),(171682,'deals-mobile','.b-trade-approval .middle-form','padding-bottom','20','','','.b-trade-approval'),(171683,'deals-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-bottom','5','','','.b-trade-approval'),(171684,'deals-mobile','.b-trade-approval .steps-bar','padding-bottom','0','','','.b-trade-approval'),(171685,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-bottom','6','','','.b-trade-approval'),(171686,'deals-mobile','.b-trade-approval .center-buttons','padding-bottom','20','','','.b-trade-approval'),(171687,'deals-mobile','.b-upload-file .upload-file-template','padding-bottom','25','','','.b-upload-file'),(171688,'deals-mobile','.b-upload-files .added-file','padding-bottom','5','','','.b-upload-files'),(171689,'deals-mobile','.b-upload-files .upload-files','padding-bottom','10','','','.b-upload-files'),(171690,'deals-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-bottom','20','','','.b-warehouses-popup'),(171691,'deals-mobile','.batchPr .w-batch-products .products-listing .image','padding-bottom','0','','','.batchPr'),(171692,'deals-mobile','.batchPr .w-batch-products','padding-bottom','0','','','.batchPr'),(171693,'deals-mobile','.batchPr > .block:nth-child(2)','padding-bottom','12','','','.batchPr'),(171694,'deals-mobile','.batchPr .w-batch-selected-products','padding-bottom','15','','','.batchPr'),(171695,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-bottom','0','','','.batchPr'),(171696,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-bottom','10','','','.batchPr'),(171697,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-bottom','0','','','.batchPr'),(171698,'deals-mobile','.batchPr ','padding-bottom','0','','','.batchPr'),(171699,'deals-mobile','.batchPr .batch-selected-products-empty','padding-bottom','10','','','.batchPr'),(171700,'deals-mobile','.batchPr .batch-selected-products-total','padding-bottom','10','','','.batchPr'),(171701,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-bottom','0','','','.batchPr'),(171702,'deals-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-bottom','15','','','.batchPr'),(171703,'deals-mobile','.batchPr .w-batch-products .products-listing .image','padding-bottom','10','','','.batchPr'),(171704,'deals-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(171705,'deals-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(171706,'deals-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(171707,'deals-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(171708,'deals-mobile','.p-account-samples-history .view_link','padding-bottom','0','','','.p-account-samples-history'),(171709,'deals-mobile','.p-account-samples-history .order_history_table th','padding-bottom','10','','','.p-account-samples-history'),(171710,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-bottom','10','','','.p-account-samples-history'),(171711,'deals-mobile','.p-account-samples-history .orders-table td','padding-bottom','5','','','.p-account-samples-history'),(171712,'deals-mobile','.p-account-samples-history .orders-table th','padding-bottom','2','','','.p-account-samples-history'),(171713,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-bottom','5','','','.p-account-samples-history'),(171714,'deals-mobile','.p-account-samples-history .orders-table td','padding-bottom','5','','','.p-account-samples-history'),(171715,'deals-mobile','.p-account-samples-history .orders-table .item','padding-bottom','60','','','.p-account-samples-history'),(171716,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-bottom','5','','','.p-account-samples-history'),(171717,'deals-mobile','.p-account-samples-history .orders-table td','padding-bottom','5','','','.p-account-samples-history'),(171718,'deals-mobile','.p-account-samples-history .order_history_table th','padding-bottom','10','','','.p-account-samples-history'),(171719,'deals-mobile','.p-account-samples-history .view_link','padding-bottom','0','','','.p-account-samples-history'),(171720,'deals-mobile','.p-account-samples-history .orders-table .item','padding-bottom','60','','','.p-account-samples-history'),(171721,'deals-mobile','.p-account-samples-history .order_history_table th','padding-bottom','10','','','.p-account-samples-history'),(171722,'deals-mobile','.p-account-samples-history .view_link','padding-bottom','0','','','.p-account-samples-history'),(171723,'deals-mobile','.p-account-samples-history .order_history_table th','padding-bottom','10','','','.p-account-samples-history'),(171724,'deals-mobile','.p-account-samples-history .orders-table th','padding-bottom','2','','','.p-account-samples-history'),(171725,'deals-mobile','.p-account-samples-history .orders-table .item','padding-bottom','60','','','.p-account-samples-history'),(171726,'deals-mobile','.p-account-samples-history .orders-table .item','padding-bottom','60','','','.p-account-samples-history'),(171727,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-bottom','5','','','.p-account-samples-history'),(171728,'deals-mobile','.p-account-samples-history .view_link','padding-bottom','0','','','.p-account-samples-history'),(171729,'deals-mobile','.p-account-samples-history .orders-table th','padding-bottom','2','','','.p-account-samples-history'),(171730,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-bottom','5','','','.p-account-samples-history'),(171731,'deals-mobile','.p-account-samples-history .orders-table .item','padding-bottom','60','','','.p-account-samples-history'),(171732,'deals-mobile','.p-account-samples-history .order_history_table th','padding-bottom','10','','','.p-account-samples-history'),(171733,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-bottom','10','','','.p-account-samples-history'),(171734,'deals-mobile','.p-account-samples-history .orders-table td','padding-bottom','5','','','.p-account-samples-history'),(171735,'deals-mobile','.p-account-samples-history .orders-table th','padding-bottom','2','','','.p-account-samples-history'),(171736,'deals-mobile','.p-account-samples-history .orders-table th','padding-bottom','2','','','.p-account-samples-history'),(171737,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-bottom','10','','','.p-account-samples-history'),(171738,'deals-mobile','.p-account-samples-history .view_link','padding-bottom','0','','','.p-account-samples-history'),(171739,'deals-mobile','.p-account-samples-history .orders-table td','padding-bottom','5','','','.p-account-samples-history'),(171740,'deals-mobile','.p-account-samples-history .orders-table th','padding-bottom','2','','','.p-account-samples-history'),(171741,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-bottom','5','','','.p-account-samples-history'),(171742,'deals-mobile','.p-account-samples-history .view_link','padding-bottom','0','','','.p-account-samples-history'),(171743,'deals-mobile','.p-account-samples-history .orders-table .item','padding-bottom','60','','','.p-account-samples-history'),(171744,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-bottom','10','','','.p-account-samples-history'),(171745,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-bottom','10','','','.p-account-samples-history'),(171746,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-bottom','10','','','.p-account-samples-history'),(171747,'deals-mobile','.p-account-samples-history .order_history_table th','padding-bottom','10','','','.p-account-samples-history'),(171748,'deals-mobile','.p-account-samples-history .orders-table td','padding-bottom','5','','','.p-account-samples-history'),(171749,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-bottom','5','','','.p-account-samples-history'),(171750,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-bottom','10','','','.p-account-samples-history-info'),(171751,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-samples-history-info'),(171752,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(171753,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(171754,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-samples-history-info'),(171755,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-bottom','10','','','.p-account-samples-history-info'),(171756,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(171757,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(171758,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-samples-history-info'),(171759,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-bottom','10','','','.p-account-samples-history-info'),(171760,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-bottom','10','','','.p-account-samples-history-info'),(171761,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-bottom','0','','','.p-account-samples-history-info'),(171762,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-bottom','10','','','.p-account-samples-history-info'),(171763,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-bottom','0','','','.p-account-samples-history-info'),(171764,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-bottom','5','','','.p-account-samples-history-info'),(171765,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-bottom','0','','','.p-account-samples-history-info'),(171766,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(171767,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-bottom','5','','','.p-account-samples-history-info'),(171768,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-bottom','5','','','.p-account-samples-history-info'),(171769,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-bottom','0','','','.p-account-samples-history-info'),(171770,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-samples-history-info'),(171771,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-bottom','0','','','.p-account-samples-history-info'),(171772,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(171773,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(171774,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(171775,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-bottom','10','','','.p-account-samples-history-info'),(171776,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-bottom','5','','','.p-account-samples-history-info'),(171777,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(171778,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-bottom','5','','','.p-account-samples-history-info'),(171779,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-bottom','5','','','.p-account-samples-history-info'),(171780,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(171781,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-bottom','0','','','.p-account-samples-history-info'),(171782,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-samples-history-info'),(171783,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-bottom','10','','','.p-account-samples-history-info'),(171784,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(171785,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-bottom','0','','','.p-account-samples-history-info'),(171786,'deals-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(171787,'deals-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(171788,'deals-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(171789,'deals-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(171790,'deals-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(171791,'deals-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(171792,'deals-mobile','.p-catalog-product .prev-product','padding-bottom','20','','','.p-catalog-product'),(171793,'deals-mobile','.p-catalog-product .next-product','padding-bottom','20','','','.p-catalog-product'),(171794,'deals-mobile','.p-catalog-product .pn-image','padding-bottom','20','','','.p-catalog-product'),(171795,'deals-mobile','.p-catalog-product .pn-direction','padding-bottom','0','','','.p-catalog-product'),(171796,'deals-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-bottom','8','','','.p-quick-order-index'),(171797,'deals-mobile','.p-quick-order-index .bottom','padding-bottom','10','','','.p-quick-order-index'),(171798,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.p-quick-order-index'),(171799,'deals-mobile','.p-quick-order-index ul.token-input-list','padding-bottom','0','','','.p-quick-order-index'),(171800,'deals-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-bottom','7','','','.p-quick-order-index'),(171801,'deals-mobile','.p-quick-order-index .all-scroll-div','padding-bottom','10','','','.p-quick-order-index'),(171802,'deals-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(171803,'deals-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(171804,'deals-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(171805,'deals-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(171806,'deals-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(171807,'deals-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(171808,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(171809,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(171810,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(171811,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(171812,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(171813,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(171814,'deals-mobile','.w-account-address-book .item','padding-bottom','20','','','.w-account-address-book'),(171815,'deals-mobile','.w-account-address-book .wrap','padding-bottom','15','','','.w-account-address-book'),(171816,'deals-mobile','.w-account-address-book .btn-del','padding-bottom','0','','','.w-account-address-book'),(171817,'deals-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-bottom','20','','','.w-account-addresses-list'),(171818,'deals-mobile','.w-account-personal-catalog .list-switcher','padding-bottom','0','','','.w-account-personal-catalog'),(171819,'deals-mobile','.w-account-personal-catalog .list-switcher a','padding-bottom','12','','','.w-account-personal-catalog'),(171820,'deals-mobile','.w-account-subscription .subscription-variant','padding-bottom','10','','','.w-account-subscription'),(171821,'deals-mobile','.w-blog-widget-categories-list ','padding-bottom','25','','','.w-blog-widget-categories-list'),(171822,'deals-mobile','.w-blog-widget-most-popular-posts ','padding-bottom','20','','','.w-blog-widget-most-popular-posts'),(171823,'deals-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-bottom','10','','','.w-blog-widget-most-popular-posts'),(171824,'deals-mobile','.w-blog-widget-post-listing .post','padding-bottom','0','','','.w-blog-widget-post-listing'),(171825,'deals-mobile','.w-blog-widget-post-listing .post_content','padding-bottom','20','','','.w-blog-widget-post-listing'),(171826,'deals-mobile','.w-blog-widget-post-listing .post_date','padding-bottom','10','','','.w-blog-widget-post-listing'),(171827,'deals-mobile','.w-blog-widget-post-listing .post_name','padding-bottom','10','','','.w-blog-widget-post-listing'),(171828,'deals-mobile','.w-blog-widget-post-listing .post','padding-bottom','0','','','.w-blog-widget-post-listing'),(171829,'deals-mobile','.w-blog-widget-post-title h1','padding-bottom','0','','','.w-blog-widget-post-title'),(171830,'deals-mobile','.w-blog-widget-post-title ','padding-bottom','20','','','.w-blog-widget-post-title'),(171831,'deals-mobile','.w-blog-widget-related-posts .post','padding-bottom','0','','','.w-blog-widget-related-posts'),(171832,'deals-mobile','.w-blog-widget-related-posts .post_content a','padding-bottom','20','','','.w-blog-widget-related-posts'),(171833,'deals-mobile','.w-blog-widget-related-posts ','padding-bottom','20','','','.w-blog-widget-related-posts'),(171834,'deals-mobile','.w-blog-widget-related-posts-by-category .post','padding-bottom','0','','','.w-blog-widget-related-posts-by-category'),(171835,'deals-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-bottom','20','','','.w-blog-widget-related-posts-by-category'),(171836,'deals-mobile','.w-blog-widget-tag-cloud ','padding-bottom','25','','','.w-blog-widget-tag-cloud'),(171837,'deals-mobile','.w-blog-widget-tag-cloud a','padding-bottom','10','','','.w-blog-widget-tag-cloud'),(171838,'deals-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-bottom','0','','','.w-cart-cart-tabs'),(171839,'deals-mobile','.w-cart-compare .attributes-label','padding-bottom','10','','','.w-cart-compare'),(171840,'deals-mobile','.w-cart-compare .cart-cell','padding-bottom','20','','','.w-cart-compare'),(171841,'deals-mobile','.w-cart-compare .price-cell','padding-bottom','8','','','.w-cart-compare'),(171842,'deals-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-bottom','5','','','.w-cart-compare'),(171843,'deals-mobile','.w-cart-compare .price-label','padding-bottom','10','','','.w-cart-compare'),(171844,'deals-mobile','.w-cart-compare .delete-cart','padding-bottom','10','','','.w-cart-compare'),(171845,'deals-mobile','.w-cart-compare .attributes-cell','padding-bottom','8','','','.w-cart-compare'),(171846,'deals-mobile','.w-cart-compare .product-actions','padding-bottom','0','','','.w-cart-compare'),(171847,'deals-mobile','.w-cart-compare .product','padding-bottom','10','','','.w-cart-compare'),(171848,'deals-mobile','.w-cart-compare .product-label','padding-bottom','15','','','.w-cart-compare'),(171849,'deals-mobile','.w-cart-compare .dropdown li','padding-bottom','5','','','.w-cart-compare'),(171850,'deals-mobile','.w-cart-up-sell .w-list-type-1','padding-bottom','0','','','.w-cart-up-sell'),(171851,'deals-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','0','1','','.w-cart-up-sell'),(171852,'deals-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','1','','','.w-cart-up-sell'),(171853,'deals-mobile','.w-catalog-additional-images li','padding-bottom','10','','','.w-catalog-additional-images'),(171854,'deals-mobile','.w-catalog-additional-images ul','padding-bottom','0','','','.w-catalog-additional-images'),(171855,'deals-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-bottom','5','','','.w-catalog-b2b-add-button'),(171856,'deals-mobile','.w-catalog-compare td','padding-bottom','10','','','.w-catalog-compare'),(171857,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-bottom','0','','','.w-catalog-compare'),(171858,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','padding-bottom','11','2','','.w-catalog-compare'),(171859,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','padding-bottom','10','','','.w-catalog-compare'),(171860,'deals-mobile','.w-catalog-paging .paging-item','padding-bottom','0','','','.w-catalog-paging'),(171861,'deals-mobile','.w-checkout-billing-address .same-address','padding-bottom','10','','','.w-checkout-billing-address'),(171862,'deals-mobile','.w-checkout-billing-address .edit-ab','padding-bottom','0','','','.w-checkout-billing-address'),(171863,'deals-mobile','.w-checkout-create-account .create-account','padding-bottom','10','','','.w-checkout-create-account'),(171864,'deals-mobile','.w-checkout-gdpr .privacy-row','padding-bottom','0','','','.w-checkout-gdpr'),(171865,'deals-mobile','.w-checkout-gdpr .terms-login','padding-bottom','0','','','.w-checkout-gdpr'),(171866,'deals-mobile','.w-checkout-shipping .sub-item','padding-bottom','5','','','.w-checkout-shipping'),(171867,'deals-mobile','.w-checkout-shipping-address .edit-ab','padding-bottom','0','','','.w-checkout-shipping-address'),(171868,'deals-mobile','.w-checkout-shipping-choice #shippingchoice-choice','padding-bottom','7','','','.w-checkout-shipping-choice'),(171869,'deals-mobile','.w-checkout-shipping-choice span','padding-bottom','4','','','.w-checkout-shipping-choice'),(171870,'deals-mobile','.w-checkout-shipping-choice span','padding-bottom','4','','','.w-checkout-shipping-choice'),(171871,'deals-mobile','.w-checkout-terms .required-message','padding-bottom','5','','','.w-checkout-terms'),(171872,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-bottom','5','','','.w-communication-new-topic'),(171873,'deals-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-bottom','0','','','.w-communication-new-topic'),(171874,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-bottom','5','','','.w-communication-new-topic'),(171875,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-bottom','0','','','.w-communication-new-topic'),(171876,'deals-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-bottom','10','','','.w-communication-new-topic'),(171877,'deals-mobile','.w-communication-post .communication-post','padding-bottom','5','','','.w-communication-post'),(171878,'deals-mobile','.w-communication-post .communication-post-author','padding-bottom','10','','','.w-communication-post'),(171879,'deals-mobile','.w-delivery-day .left-count','padding-bottom','0','','','.w-delivery-day'),(171880,'deals-mobile','.w-delivery-day .left-text-left','padding-bottom','24','','','.w-delivery-day'),(171881,'deals-mobile','.w-delivery-day .left-text-right','padding-bottom','24','','','.w-delivery-day'),(171882,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-bottom','10','','','.w-image-maps'),(171883,'deals-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-bottom','3','','','.w-multi-cart-actions'),(171884,'deals-mobile','.w-personal-gift-status-bar .inform','padding-bottom','0','4','','.w-personal-gift-status-bar'),(171885,'deals-mobile','.w-personal-gift-status-bar .end-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(171886,'deals-mobile','.w-personal-gift-status-bar .end-date','padding-bottom','0','3','','.w-personal-gift-status-bar'),(171887,'deals-mobile','.w-personal-gift-status-bar .start-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(171888,'deals-mobile','.w-personal-gift-status-bar .timeline','padding-bottom','16','','','.w-personal-gift-status-bar'),(171889,'deals-mobile','.w-product-available-in-warehouses .warehouse-item','padding-bottom','20','','','.w-product-available-in-warehouses'),(171890,'deals-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(171891,'deals-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(171892,'deals-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(171893,'deals-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(171894,'deals-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(171895,'deals-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(171896,'deals-mobile','.w-product-customers-activity .customers-activity','padding-bottom','20','','','.w-product-customers-activity'),(171897,'deals-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(171898,'deals-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(171899,'deals-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(171900,'deals-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(171901,'deals-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(171902,'deals-mobile','.w-product-images-additional .images','padding-bottom','20','','','.w-product-images-additional'),(171903,'deals-mobile','.w-promotions .nextdiscount .promo-for-each','padding-bottom','2','','','.w-promotions'),(171904,'deals-mobile','.w-promotions .nextdiscount .content > div','padding-bottom','10','','','.w-promotions'),(171905,'deals-mobile','.w-promotions .promo-cart-discount .master .item','padding-bottom','20','','','.w-promotions'),(171906,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-bottom','0','','','.w-promotions'),(171907,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-bottom','0','','','.w-promotions'),(171908,'deals-mobile','.w-promotions .promo-cart-discount .slave .item','padding-bottom','20','','','.w-promotions'),(171909,'deals-mobile','.w-promotions .promo-cart-discount .slave .heading','padding-bottom','1','','','.w-promotions'),(171910,'deals-mobile','.w-promotions .promo-salemaker .discount','padding-bottom','0','','','.w-promotions'),(171911,'deals-mobile','.w-promotions .promo-item','padding-bottom','20','','','.w-promotions'),(171912,'deals-mobile','.w-promotions .promo-salemaker .item','padding-bottom','20','','','.w-promotions'),(171913,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','padding-bottom','0','','','.w-promotions'),(171914,'deals-mobile','.w-promotions .prom-multi-discount .promo-product','padding-bottom','20','','','.w-promotions'),(171915,'deals-mobile','.w-quote-products .empty','padding-bottom','100','','','.w-quote-products'),(171916,'deals-mobile','.w-reviews-content .review','padding-bottom','10','','','.w-reviews-content'),(171917,'deals-mobile','.w-reviews-content .product-name','padding-bottom','20','','','.w-reviews-content'),(171918,'deals-mobile','.w-reviews-content .item','padding-bottom','25','','','.w-reviews-content'),(171919,'deals-mobile','.w-reviews-content .author','padding-bottom','20','','','.w-reviews-content'),(171920,'deals-mobile','.w-reviews-content .rating','padding-bottom','10','','','.w-reviews-content'),(171921,'deals-mobile','.w-sitemap-delivery-location > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(171922,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(171923,'deals-mobile','.w-top-text .top-text','padding-bottom','5','','','.w-top-text'),(171924,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-bottom','17','','','.w-wedding-registry-widgets-photos'),(171925,'deals-mobile','.b-quantity .qty-box input[type=\'text\']','padding-bottom','5','','','.b-quantity'),(171926,'deals-mobile','.p-blog-index .comment-list','padding-bottom_important','important','','','.p-blog-index'),(171927,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom_important','important','','','.b-data-table'),(171928,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom_important','important','','','.b-data-table'),(171929,'deals-mobile','.b-data-table table.dataTable thead td','padding-bottom_important','important','','','.b-data-table'),(171930,'deals-mobile','.b-data-table table.dataTable tbody td','padding-bottom_important','important','','','.b-data-table'),(171931,'deals-mobile','.batchPr .w-batch-products','padding-bottom_important','important','','','.batchPr'),(171932,'deals-mobile','.w-list-type-1_3 .item','padding-left','0','','','.w-list-type-1_3'),(171933,'deals-mobile','.w-list-type-1_3 .compare-box-item','padding-left','7','','','.w-list-type-1_3'),(171934,'deals-mobile','.w-list-type-1_3 .item','padding-left','0','1','','.w-list-type-1_3'),(171935,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','padding-left','15','','','.w-list-type-2'),(171936,'deals-mobile','.w-list-type-1_2.products-listing','padding-left','20','','','.w-list-type-1_2'),(171937,'deals-mobile','.w-list-type-2 .compare-box-item','padding-left','7','','','.w-list-type-2'),(171938,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','padding-left','15','','','.w-list-type-1_3'),(171939,'deals-mobile','.w-list-type-2_2.products-listing','padding-left','20','','','.w-list-type-2_2'),(171940,'deals-mobile','.w-list-type-2 .item','padding-left','21','','','.w-list-type-2'),(171941,'deals-mobile','.w-list-type-2.products-listing','padding-left','20','','','.w-list-type-2'),(171942,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','padding-left','15','','','.w-list-type-2_2'),(171943,'deals-mobile','.w-list-type-2 .item','padding-left','20','1','','.w-list-type-2'),(171944,'deals-mobile','.w-list-type-2_2 .compare-box-item','padding-left','7','','','.w-list-type-2_2'),(171945,'deals-mobile','.w-list-type-3.products-listing','padding-left','20','','','.w-list-type-3'),(171946,'deals-mobile','.w-menu .hided.menu ul li','padding-left','0','','','.w-menu'),(171947,'deals-mobile','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(171948,'deals-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-left','0','','','.w-menu'),(171949,'deals-mobile','.w-menu-slider > ul > li > a','padding-left','10','','','.w-menu-slider'),(171950,'deals-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','','','.w-menu-horizontal'),(171951,'deals-mobile','.w-menu-big ul','padding-left','0','','','.w-menu-big'),(171952,'deals-mobile','.w-menu-horizontal > ul > li > ul > li','padding-left','10','','','.w-menu-horizontal'),(171953,'deals-mobile','.w-menu-slider > ul > li > ul > li','padding-left','10','','','.w-menu-slider'),(171954,'deals-mobile','.w-menu-slider ul, .w-menu-slider li','padding-left','0','','','.w-menu-slider'),(171955,'deals-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','','','.w-menu-style-1'),(171956,'deals-mobile','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(171957,'deals-mobile','.w-top-categories .item','padding-left','10','863','','.w-top-categories'),(171958,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(171959,'deals-mobile','.b-bottom .popup-simple','padding-left','20','','','.b-bottom'),(171960,'deals-mobile','.b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .buttons','padding-left','10','','','.b-cookie-notice'),(171961,'deals-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.bottom .text','padding-left','10','','','.b-cookie-notice'),(171962,'deals-mobile','.w-login-block .new','padding-left','40','','','.w-login-block'),(171963,'deals-mobile','.w-login-block .guest','padding-left','40','','','.w-login-block'),(171964,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-left','20','','','.w-menu-style-1'),(171965,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','','','.w-menu-style-1'),(171966,'deals-mobile','.w-sale .holder-2','padding-left','20','','','.w-sale'),(171967,'deals-mobile','.w-product-wedding-registry-button .btn','padding-left','40','','','.w-product-wedding-registry-button'),(171968,'deals-mobile','.w-reviews .review','padding-left','10','','','.w-reviews'),(171969,'deals-mobile','.w-sale .left-count','padding-left','5','','','.w-sale'),(171970,'deals-mobile','.w-filters .head-filter-widget','padding-left','0','','','.w-filters'),(171971,'deals-mobile','.w-currencies .select-link','padding-left','10','','','.w-currencies'),(171972,'deals-mobile','.w-filters .filter-ul-content','padding-left','0','','','.w-filters'),(171973,'deals-mobile','.w-categories .name','padding-left','3','','','.w-categories'),(171974,'deals-mobile','.w-currencies .current','padding-left','10','','','.w-currencies'),(171975,'deals-mobile','.w-categories .image','padding-left','0','','','.w-categories'),(171976,'deals-mobile','.w-currencies .currencies-title','padding-left','4','','','.w-currencies'),(171977,'deals-mobile','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(171978,'deals-mobile','.w-cart .no-text','padding-left','10','','','.w-cart'),(171979,'deals-mobile','.w-cart .qty','padding-left','5','4','','.w-cart'),(171980,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','padding-left','40','','','.p-account-history-info'),(171981,'deals-mobile','.p-account-history-info .historyTotal td','padding-left','5','','','.p-account-history-info'),(171982,'deals-mobile','.p-account-history-info .contentColumn','padding-left','40','','','.p-account-history-info'),(171983,'deals-mobile','.p-account-history-info .history_info > div + div','padding-left','2','','','.p-account-history-info'),(171984,'deals-mobile','.p-account-index .account_page','padding-left','0','','','.p-account-index'),(171985,'deals-mobile','.p-account-index .account_block','padding-left','40','','','.p-account-index'),(171986,'deals-mobile','.p-account-index .badc_bottom','padding-left','0','','','.p-account-index'),(171987,'deals-mobile','.p-account-index .account_info li','padding-left','0','','','.p-account-index'),(171988,'deals-mobile','.p-account-index .account_info','padding-left','0','','','.p-account-index'),(171989,'deals-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','padding-left','10','','','.p-account-index'),(171990,'deals-mobile','.p-account-index .date_title','padding-left','0','','','.p-account-index'),(171991,'deals-mobile','.p-account-index .orders-table th','padding-left','10','','','.p-account-index'),(171992,'deals-mobile','.b-bottom .popup-buttons','padding-left','15','','','.b-bottom'),(171993,'deals-mobile','.w-cart-checkout-btn a','padding-left','12','863','','.w-cart-checkout-btn'),(171994,'deals-mobile','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(171995,'deals-mobile','.w-quote .no-text','padding-left','10','','','.w-quote'),(171996,'deals-mobile','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(171997,'deals-mobile','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(171998,'deals-mobile','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(171999,'deals-mobile','.w-product-images .img-holder','padding-left','20','','','.w-product-images'),(172000,'deals-mobile','.b-compare .compare_pagination','padding-left','0','','','.b-compare'),(172001,'deals-mobile','.p-blog-index .comments-area ol ol','padding-left','20','888','','.p-blog-index'),(172002,'deals-mobile','.header2 .ccc','padding-left','10','','',''),(172003,'deals-mobile','.w-promo-code .holder','padding-left','20','893','','.w-promo-code'),(172004,'deals-mobile','.w-sale .holder-1','padding-left','20','','','.w-sale'),(172005,'deals-mobile','.w-search .item','padding-left','0','','','.w-search'),(172006,'deals-mobile','.w-search .suggest','padding-left','20','','','.w-search'),(172007,'deals-mobile','.w-search .search-input','padding-left','10','','','.w-search'),(172008,'deals-mobile','.w-search .items-title','padding-left','0','','','.w-search'),(172009,'deals-mobile','.w-socials > li','padding-left','15','','','.w-socials'),(172010,'deals-mobile','.b-info-popup .info-popup div','padding-left','15','','','.b-info-popup'),(172011,'deals-mobile','.w-menu .hided.menu li li a','padding-left','40','890','','.w-menu'),(172012,'deals-mobile','.w-menu .hided.menu li li li a','padding-left','60','890','','.w-menu'),(172013,'deals-mobile','.w-menu .hided.menu li a','padding-left','20','890','','.w-menu'),(172014,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-left','0','','','.b-multi-page-checkout'),(172015,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-left','10','','','.b-multi-page-checkout'),(172016,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-left','10','','','.b-multi-page-checkout'),(172017,'deals-mobile','.w-search .name','padding-left','50','','','.w-search'),(172018,'deals-mobile','.w-promo-code .heading-4','padding-left','30','893','','.w-promo-code'),(172019,'deals-mobile','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(172020,'deals-mobile','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(172021,'deals-mobile','.p-wedding-registry-manage a.remove-btn','padding-left','5','','','.p-wedding-registry-manage'),(172022,'deals-mobile','.p-account-history-info .popup-tracking-number','padding-left','10','','','.p-account-history-info'),(172023,'deals-mobile','.p-account-order-pay .contentColumn','padding-left','40','','','.p-account-order-pay'),(172024,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','padding-left','40','','','.p-account-order-pay'),(172025,'deals-mobile','.p-account-order-pay .historyTotal td','padding-left','5','','','.p-account-order-pay'),(172026,'deals-mobile','.p-account-order-pay .history_info > div + div','padding-left','2','','','.p-account-order-pay'),(172027,'deals-mobile','.p-account-order-pay .history_info > div','padding-left','0','864','','.p-account-order-pay'),(172028,'deals-mobile','.testimonials .answer','padding-left','30','','',''),(172029,'deals-mobile','.w-product-configurator .pc_item','padding-left','0','872','','.w-product-configurator'),(172030,'deals-mobile','.p-account-order-pay .history_info > div + div','padding-left','0','864','','.p-account-order-pay'),(172031,'deals-mobile','.w-product-configurator .pc_attr','padding-left','0','863','','.w-product-configurator'),(172032,'deals-mobile','.w-filters .head-filter-widget','padding-left','10','890','','.w-filters'),(172033,'deals-mobile','.testimonials .heading-3','padding-left','55','','',''),(172034,'deals-mobile','.b-pagination .pagination span','padding-left','5','2','','.b-pagination'),(172035,'deals-mobile','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(172036,'deals-mobile','.testimonials .review','padding-left','10','','',''),(172037,'deals-mobile','.b-pagination .pagination .page-number','padding-left','5','','','.b-pagination'),(172038,'deals-mobile','.b-pagination .pagination .prev-pages','padding-left','5','','','.b-pagination'),(172039,'deals-mobile','.b-pagination .pagination .prev','padding-left','5','','','.b-pagination'),(172040,'deals-mobile','.b-bottom .confirm-popup .confirm-text','padding-left','0','','','.b-bottom'),(172041,'deals-mobile','.b-pagination .pagination .next-pages','padding-left','5','','','.b-pagination'),(172042,'deals-mobile','.b-pagination .pagination .next','padding-left','5','','','.b-pagination'),(172043,'deals-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','padding-left','10','','','.p-account-history'),(172044,'deals-mobile','.p-account-history .orders-table th','padding-left','10','','','.p-account-history'),(172045,'deals-mobile','.p-account-history .view_link','padding-left','0','','','.p-account-history'),(172046,'deals-mobile','.p-account-history .orders-table .td-alignright','padding-left','10','890','','.p-account-history'),(172047,'deals-mobile','.btn-2','padding-left','25','','',''),(172048,'deals-mobile','.p-account-history .orders-table td','padding-left','10','890','','.p-account-history'),(172049,'deals-mobile','.p-account-index .orders-table td','padding-left','10','890','','.p-account-index'),(172050,'deals-mobile','.p-blog-index .nav-previous','padding-left','50','','','.p-blog-index'),(172051,'deals-mobile','.p-account-index .orders-table .td-alignright','padding-left','10','890','','.p-account-index'),(172052,'deals-mobile','.btn','padding-left','12','','',''),(172053,'deals-mobile','.btn-1','padding-left','25','','',''),(172054,'deals-mobile','.p-blog-index .comments-area ol ol','padding-left','50','','','.p-blog-index'),(172055,'deals-mobile','.btn-3','padding-left','25','','',''),(172056,'deals-mobile','.w-product-personal-catalog-button .btn','padding-left','25','','','.w-product-personal-catalog-button'),(172057,'deals-mobile','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(172058,'deals-mobile','.w-account ul, .w-account li','padding-left','0','','','.w-account'),(172059,'deals-mobile','.b-fancybox .fancybox-error','padding-left','15','','','.b-fancybox'),(172060,'deals-mobile','.w-menu-horizontal ul','padding-left','0','','','.w-menu-horizontal'),(172061,'deals-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(172062,'deals-mobile','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(172063,'deals-mobile','.w-chat .w-chat-box','padding-left','12','','','.w-chat'),(172064,'deals-mobile','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(172065,'deals-mobile','.p-wedding-registry-index .main-button','padding-left','20','4','','.p-wedding-registry-index'),(172066,'deals-mobile','.p-wedding-registry-index .main-content','padding-left','0','','','.p-wedding-registry-index'),(172067,'deals-mobile','.p-wedding-registry-index .middle-box','padding-left','10','','','.p-wedding-registry-index'),(172068,'deals-mobile','.p-wedding-registry-index .main-button','padding-left','20','3','','.p-wedding-registry-index'),(172069,'deals-mobile','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(172070,'deals-mobile','.b-form .form-buttons','padding-left','0','','','.b-form'),(172071,'deals-mobile','.b-bottom .alert-message','padding-left','20','','','.b-bottom'),(172072,'deals-mobile','.p-wedding-registry-manage .links','padding-left','10','','','.p-wedding-registry-manage'),(172073,'deals-mobile','.p-wedding-registry-share .middle-form > input','padding-left','0','','','.p-wedding-registry-share'),(172074,'deals-mobile','.p-wedding-registry-manage .links a','padding-left','10','','','.p-wedding-registry-manage'),(172075,'deals-mobile','.p-wedding-registry-manage .links a.share-registry','padding-left','40','','','.p-wedding-registry-manage'),(172076,'deals-mobile','.b-table .table td','padding-left','15','','','.b-table'),(172077,'deals-mobile','.b-table .table .headings td','padding-left','10','','','.b-table'),(172078,'deals-mobile','.b-pagination .pagination a','padding-left','5','','','.b-pagination'),(172079,'deals-mobile','.p-account-history .order_history_table th','padding-left','10','','','.p-account-history'),(172080,'deals-mobile','.p-account-address-book .topButtons','padding-left','0','','','.p-account-address-book'),(172081,'deals-mobile','.p-account-address-book .buttonBox','padding-left','0','','','.p-account-address-book'),(172082,'deals-mobile','.p-account-address-book .btn-edit','padding-left','10','4','','.p-account-address-book'),(172083,'deals-mobile','.p-account-address-book .rightMes ul','padding-left','19','','','.p-account-address-book'),(172084,'deals-mobile','.p-account-address-book .address_book h2','padding-left','10','','','.p-account-address-book'),(172085,'deals-mobile','.p-account-address-book .address_book, .p-account-address-book .account_history_info','padding-left','0','','','.p-account-address-book'),(172086,'deals-mobile','.p-account-address-book .address_book h1','padding-left','0','','','.p-account-address-book'),(172087,'deals-mobile','.p-account-address-book .address_book','padding-left','0','','','.p-account-address-book'),(172088,'deals-mobile','.b-compare .col-gender','padding-left','0','','','.b-compare'),(172089,'deals-mobile','.b-bottom .popup-heading','padding-left','15','','','.b-bottom'),(172090,'deals-mobile','.b-bottom .popup-content','padding-left','15','','','.b-bottom'),(172091,'deals-mobile','.b-compare .col-two label','padding-left','0','','','.b-compare'),(172092,'deals-mobile','.b-compare .compare-head','padding-left','10','','','.b-compare'),(172093,'deals-mobile','.b-compare .compare-box-item','padding-left','10','','','.b-compare'),(172094,'deals-mobile','.b-compare .column_wrapper','padding-left','10','','','.b-compare'),(172095,'deals-mobile','.w-languages .current','padding-left','10','872','','.w-languages'),(172096,'deals-mobile','.w-quote .cart-box-link','padding-left','14','872','','.w-quote'),(172097,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','padding-left','5','','','.b-switch'),(172098,'deals-mobile','.w-languages .lang-link','padding-left','10','872','','.w-languages'),(172099,'deals-mobile','.w-tabs .accordion-heading','padding-left','6','','','.w-tabs'),(172100,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-left','0','','','.b-slick'),(172101,'deals-mobile','.w-search .button-search','padding-left','0','','','.w-search'),(172102,'deals-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','876','','.w-menu-style-1'),(172103,'deals-mobile','.w-currencies .select-link','padding-left','10','872','','.w-currencies'),(172104,'deals-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','872','','.w-menu-horizontal'),(172105,'deals-mobile','.w-currencies .current','padding-left','10','872','','.w-currencies'),(172106,'deals-mobile','.b-slick button.slick-next','padding-left','4','3','','.b-slick'),(172107,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-left','18','876','','.w-list-type-1'),(172108,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','876','','.w-menu-style-1'),(172109,'deals-mobile','.b-bottom .footerTitle','padding-left','0','863','','.b-bottom'),(172110,'deals-mobile','.p-account-history-info .history_info > div + div','padding-left','0','864','','.p-account-history-info'),(172111,'deals-mobile','.p-account-history-info .history_info > div','padding-left','0','864','','.p-account-history-info'),(172112,'deals-mobile','.p-account-index .account_info','padding-left','0','876','','.p-account-index'),(172113,'deals-mobile','.w-top-categories .name','padding-left','3','','','.w-top-categories'),(172114,'deals-mobile','.w-cart .cart-total','padding-left','0','','','.w-cart'),(172115,'deals-mobile','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(172116,'deals-mobile','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(172117,'deals-mobile','.w-breadcrumb .breadcrumb-li','padding-left','0','','','.w-breadcrumb'),(172118,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','padding-left','15','','','.w-list-type-1_2'),(172119,'deals-mobile','.w-bestsellers .heading-3','padding-left','55','','','.w-bestsellers'),(172120,'deals-mobile','.w-account a.my-acc-link','padding-left','17','','','.w-account'),(172121,'deals-mobile','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(172122,'deals-mobile','.w-tabs .tab-navigation','padding-left','0','','','.w-tabs'),(172123,'deals-mobile','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block','padding-left','10','865','',''),(172124,'deals-mobile','.w-top-categories .image','padding-left','0','','','.w-top-categories'),(172125,'deals-mobile','.p-account-trade-form .trade-form-area','padding-left','20','','','.p-account-trade-form'),(172126,'deals-mobile','.p-account-trade-form .widget','padding-left','0','','','.p-account-trade-form'),(172127,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-left','10','','','.p-blog-index'),(172128,'deals-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-left','0','','','.p-blog-index'),(172129,'deals-mobile','.p-blog-index .wp-widget li','padding-left','15','','','.p-blog-index'),(172130,'deals-mobile','.p-checkout-index .shipping-method .item','padding-left','0','','','.p-checkout-index'),(172131,'deals-mobile','.p-blog-index .nav-links','padding-left','0','','','.p-blog-index'),(172132,'deals-mobile','.p-checkout-index .shipping-method .title','padding-left','5','','','.p-checkout-index'),(172133,'deals-mobile','.p-quote-cart-index .cart-popup .cart-page, .p-quote-cart-index .cart-popup .wishlist-page','padding-left','20','','','.p-quote-cart-index'),(172134,'deals-mobile','.p-blog-index .wp-widget ul','padding-left','0','','','.p-blog-index'),(172135,'deals-mobile','.p-checkout-index .shipping-method .row','padding-left','5','','','.p-checkout-index'),(172136,'deals-mobile','.p-reviews-info .review-info-image','padding-left','20','','','.p-reviews-info'),(172137,'deals-mobile','.p-reviews-info .review-info-content','padding-left','20','','','.p-reviews-info'),(172138,'deals-mobile','.p-reviews-info .review-info-text','padding-left','10','','','.p-reviews-info'),(172139,'deals-mobile','.p-reviews-info .reviews-info .buttons','padding-left','0','','','.p-reviews-info'),(172140,'deals-mobile','.p-shopping-cart-index .cart-popup .cart-page, .p-shopping-cart-index .cart-popup .wishlist-page','padding-left','20','','','.p-shopping-cart-index'),(172141,'deals-mobile','.p-account-index .account_info li','padding-left','0','863','','.p-account-index'),(172142,'deals-mobile','.p-account-index .topAccount > li','padding-left','0','863','','.p-account-index'),(172143,'deals-mobile','.p-account-index .topAccount > li > div','padding-left','55','863','','.p-account-index'),(172144,'deals-mobile','.w-product-images .images','padding-left','0','893','','.w-product-images'),(172145,'deals-mobile','.b-bottom .popup-box-wrap','padding-left','10','','','.b-bottom'),(172146,'deals-mobile','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(172147,'deals-mobile','.b-slick .slick-vertical button.slick-prev','padding-left','0','3','','.b-slick'),(172148,'deals-mobile','.b-slick .slick-vertical button.slick-next','padding-left','0','3','','.b-slick'),(172149,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-left','20','','','.b-fancybox'),(172150,'deals-mobile','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(172151,'deals-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-left','10','','','.p-account-subscription-historyinfo'),(172152,'deals-mobile','.w-product-configurator .pc_item','padding-left','0','','','.w-product-configurator'),(172153,'deals-mobile','.p-account-index .view_link','padding-left','0','','','.p-account-index'),(172154,'deals-mobile','.p-account-index th','padding-left','15','','','.p-account-index'),(172155,'deals-mobile','.p-account-index .topAccount > li','padding-left','2','','','.p-account-index'),(172156,'deals-mobile','.w-list-type-1 .item','padding-left','5','','','.w-list-type-1'),(172157,'deals-mobile','.w-list-type-1 .compare-box-item','padding-left','7','','','.w-list-type-1'),(172158,'deals-mobile','.w-list-type-1_2 .compare-box-item','padding-left','7','','','.w-list-type-1_2'),(172159,'deals-mobile','.w-languages .lang-link','padding-left','10','','','.w-languages'),(172160,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-left','15','','','.w-list-type-1'),(172161,'deals-mobile','.w-filters .fsl_handle','padding-left','0','','','.w-filters'),(172162,'deals-mobile','.w-filters .ui-slider-range','padding-left','0','','','.w-filters'),(172163,'deals-mobile','.w-languages .current','padding-left','10','','','.w-languages'),(172164,'deals-mobile','.b-fancybox .fancybox-title-over-wrap','padding-left','10','','','.b-fancybox'),(172165,'deals-mobile','.b-fancybox .fancybox-next span','padding-left','4','3','','.b-fancybox'),(172166,'deals-mobile','.w-categories .item','padding-left','20','','','.w-categories'),(172167,'deals-mobile','.w-cart a.item','padding-left','90','','','.w-cart'),(172168,'deals-mobile','.w-cart .cart-content','padding-left','15','','','.w-cart'),(172169,'deals-mobile','.w-cart .cart-box-link','padding-left','14','','','.w-cart'),(172170,'deals-mobile','.b-compare .popupCompare .pop-up-content','padding-left','10','','','.b-compare'),(172171,'deals-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(172172,'deals-mobile','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(172173,'deals-mobile','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(172174,'deals-mobile','.w-quote .cart-box-link','padding-left','10','','','.w-quote'),(172175,'deals-mobile','.w-product-reviews .reviews-list .review','padding-left','10','','','.w-product-reviews'),(172176,'deals-mobile','.w-product-sale-ends .left-count','padding-left','5','','','.w-product-sale-ends'),(172177,'deals-mobile','.w-reviews .heading-3','padding-left','55','','','.w-reviews'),(172178,'deals-mobile','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(172179,'deals-mobile','.w-product-properties li','padding-left','0','','','.w-product-properties'),(172180,'deals-mobile','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(172181,'deals-mobile','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(172182,'deals-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(172183,'deals-mobile','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(172184,'deals-mobile','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(172185,'deals-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(172186,'deals-mobile','.w-menu-style-1 ul','padding-left','0','','','.w-menu-style-1'),(172187,'deals-mobile','.w-tabs .accordion-heading','padding-left','8','863','','.w-tabs'),(172188,'deals-mobile','.w-text .customer-service','padding-left','30','','','.w-text'),(172189,'deals-mobile','.w-categories .categories h2','padding-left','0','','','.w-categories'),(172190,'deals-mobile','.w-top-categories .categories h2','padding-left','0','','','.w-top-categories'),(172191,'deals-mobile','.w-banner .carousel-text > span','padding-left','20','','','.w-banner'),(172192,'deals-mobile','.b-slick .slick-list','padding-left','0','','','.b-slick'),(172193,'deals-mobile','.w-tabs .tab-li','padding-left','0','','','.w-tabs'),(172194,'deals-mobile','.w-tabs .tab-a','padding-left','6','','','.w-tabs'),(172195,'deals-mobile','.w-list-type-1 ','padding-left','0','','','.w-list-type-1'),(172196,'deals-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-left','10','','','.w-menu-horizontal'),(172197,'deals-mobile','.p-account-index .account_page h2.order-table-title','padding-left','30','','','.p-account-index'),(172198,'deals-mobile','.p-account-index .account_page h4','padding-left','40','','','.p-account-index'),(172199,'deals-mobile','.w-categories .item','padding-left','10','863','','.w-categories'),(172200,'deals-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-left','0','','','.b-fancybox'),(172201,'deals-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-left','0','','','.b-fancybox'),(172202,'deals-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-left','6','','','.b-compare'),(172203,'deals-mobile','.b-compare .popupCompare td.level-3:first-child','padding-left','18','','','.b-compare'),(172204,'deals-mobile','.b-compare .popupCompare td.level-2:first-child','padding-left','12','','','.b-compare'),(172205,'deals-mobile','.w-cart-give-away .ga_img','padding-left','1','','','.w-cart-give-away'),(172206,'deals-mobile','.w-search .search form','padding-left','5','','','.w-search'),(172207,'deals-mobile','.b-autocomplete .ui-autocomplete','padding-left','0','','','.b-autocomplete'),(172208,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','padding-left','10','','',''),(172209,'deals-mobile','textarea','padding-left','10','','',''),(172210,'deals-mobile','.b-autocomplete .ui-autocomplete li','padding-left','10','','','.b-autocomplete'),(172211,'deals-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-left','20','','','.b-bottom'),(172212,'deals-mobile','.b-bottom .pop-up-close','padding-left','1','','','.b-bottom'),(172213,'deals-mobile','.b-bottom .pop-up-info','padding-left','20','','','.b-bottom'),(172214,'deals-mobile','.b-form .addresses .address-item span','padding-left','5','','','.b-form'),(172215,'deals-mobile','.b-form .center-buttons','padding-left','0','','','.b-form'),(172216,'deals-mobile','.w-reviews .reviews','padding-left','10','','','.w-reviews'),(172217,'deals-mobile','.w-top-categories .item','padding-left','20','','','.w-top-categories'),(172218,'deals-mobile','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-left','10','865','',''),(172219,'deals-mobile','.b-form .payment-method .item-radio label span','padding-left','5','','','.b-form'),(172220,'deals-mobile','.b-form .payment-method .item-radio label','padding-left','5','','','.b-form'),(172221,'deals-mobile','.b-form .middle-form','padding-left','0','','','.b-form'),(172222,'deals-mobile','.b-form .required-message-wrap','padding-left','0','','','.b-form'),(172223,'deals-mobile','.b-form .required-message','padding-left','3','','','.b-form'),(172224,'deals-mobile','.p-account-address-book .leftMes ul','padding-left','0','','','.p-account-address-book'),(172225,'deals-mobile','.b-form .shipping-method .input','padding-left','10','','','.b-form'),(172226,'deals-mobile','.b-info .info','padding-left','40','','','.b-info'),(172227,'deals-mobile','.b-info .info ul','padding-left','0','','','.b-info'),(172228,'deals-mobile','.b-info .info li','padding-left','0','','','.b-info'),(172229,'deals-mobile','.p-account-index .topAccount','padding-left','19','','','.p-account-index'),(172230,'deals-mobile','.b-products-listing .in-cart','padding-left','10','','','.b-products-listing'),(172231,'deals-mobile','.b-products-listing .products-listing .bonus-points-cost','padding-left','20','','','.b-products-listing'),(172232,'deals-mobile','.b-products-listing .products-listing .bonus-points-price','padding-left','20','','','.b-products-listing'),(172233,'deals-mobile','.b-products-listing .products-listing .btn-buy','padding-left','10','','','.b-products-listing'),(172234,'deals-mobile','.b-products-listing .products-listing .buyButton .btn','padding-left','10','','','.b-products-listing'),(172235,'deals-mobile','.b-products-listing .products-listing .compare','padding-left','6','','','.b-products-listing'),(172236,'deals-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-left','2','','','.b-products-listing'),(172237,'deals-mobile','.b-products-listing .products-listing a.btn.view-button','padding-left','0','','','.b-products-listing'),(172238,'deals-mobile','.b-products-listing .products-listing h2','padding-left','0','','','.b-products-listing'),(172239,'deals-mobile','.b-products-listing .promos-info .promo-item','padding-left','0','','','.b-products-listing'),(172240,'deals-mobile','.b-products-listing .promos-info .promo-name','padding-left','15','','','.b-products-listing'),(172241,'deals-mobile','.b-products-listing .list-productlisting div.BlockBox.item-holder','padding-left','10','','','.b-products-listing'),(172242,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.b-data-table'),(172243,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.b-data-table'),(172244,'deals-mobile','.b-data-table table.dataTable thead td','padding-left','20','','','.b-data-table'),(172245,'deals-mobile','.b-data-table table.dataTable tbody td','padding-left','20','','','.b-data-table'),(172246,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(172247,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(172248,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(172249,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(172250,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(172251,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(172252,'deals-mobile','.b-email .model','padding-left','10','','','.b-email'),(172253,'deals-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(172254,'deals-mobile','.b-email .price','padding-left','10','','','.b-email'),(172255,'deals-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(172256,'deals-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(172257,'deals-mobile','.b-email .image','padding-left','10','','','.b-email'),(172258,'deals-mobile','.b-email .price','padding-left','10','','','.b-email'),(172259,'deals-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(172260,'deals-mobile','.b-email .model','padding-left','10','','','.b-email'),(172261,'deals-mobile','.b-email .qty','padding-left','10','','','.b-email'),(172262,'deals-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(172263,'deals-mobile','.b-email .image','padding-left','10','','','.b-email'),(172264,'deals-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(172265,'deals-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(172266,'deals-mobile','.b-email .price','padding-left','10','','','.b-email'),(172267,'deals-mobile','.b-email .image','padding-left','10','','','.b-email'),(172268,'deals-mobile','.b-email .model','padding-left','10','','','.b-email'),(172269,'deals-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(172270,'deals-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(172271,'deals-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(172272,'deals-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(172273,'deals-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(172274,'deals-mobile','.b-email .model','padding-left','10','','','.b-email'),(172275,'deals-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(172276,'deals-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(172277,'deals-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(172278,'deals-mobile','.b-email .name','padding-left','10','','','.b-email'),(172279,'deals-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(172280,'deals-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(172281,'deals-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(172282,'deals-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(172283,'deals-mobile','.b-email .name','padding-left','10','','','.b-email'),(172284,'deals-mobile','.b-email .model','padding-left','10','','','.b-email'),(172285,'deals-mobile','.b-email .name','padding-left','10','','','.b-email'),(172286,'deals-mobile','.b-email .qty','padding-left','10','','','.b-email'),(172287,'deals-mobile','.b-email .image','padding-left','10','','','.b-email'),(172288,'deals-mobile','.b-email .name','padding-left','10','','','.b-email'),(172289,'deals-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(172290,'deals-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(172291,'deals-mobile','.b-email .qty','padding-left','10','','','.b-email'),(172292,'deals-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(172293,'deals-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(172294,'deals-mobile','.b-email .name','padding-left','10','','','.b-email'),(172295,'deals-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(172296,'deals-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(172297,'deals-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(172298,'deals-mobile','.b-email .model','padding-left','10','','','.b-email'),(172299,'deals-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(172300,'deals-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(172301,'deals-mobile','.b-email .name','padding-left','10','','','.b-email'),(172302,'deals-mobile','.b-email .qty','padding-left','10','','','.b-email'),(172303,'deals-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(172304,'deals-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(172305,'deals-mobile','.b-email .image','padding-left','10','','','.b-email'),(172306,'deals-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(172307,'deals-mobile','.b-email .image','padding-left','10','','','.b-email'),(172308,'deals-mobile','.b-email .price','padding-left','10','','','.b-email'),(172309,'deals-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(172310,'deals-mobile','.b-email .qty','padding-left','10','','','.b-email'),(172311,'deals-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(172312,'deals-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(172313,'deals-mobile','.b-email .price','padding-left','10','','','.b-email'),(172314,'deals-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(172315,'deals-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(172316,'deals-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(172317,'deals-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(172318,'deals-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(172319,'deals-mobile','.b-email .price','padding-left','10','','','.b-email'),(172320,'deals-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(172321,'deals-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(172322,'deals-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(172323,'deals-mobile','.b-email .qty','padding-left','10','','','.b-email'),(172324,'deals-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(172325,'deals-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(172326,'deals-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(172327,'deals-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(172328,'deals-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(172329,'deals-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(172330,'deals-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(172331,'deals-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(172332,'deals-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(172333,'deals-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(172334,'deals-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(172335,'deals-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(172336,'deals-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(172337,'deals-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(172338,'deals-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(172339,'deals-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(172340,'deals-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(172341,'deals-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(172342,'deals-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(172343,'deals-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(172344,'deals-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(172345,'deals-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(172346,'deals-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(172347,'deals-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(172348,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-left','0','','','.b-h-inline'),(172349,'deals-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-left','0','','','.b-menu-style'),(172350,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-left','5','','','.b-menu-style-1'),(172351,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-left','20','','','.b-menu-style-1'),(172352,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-left','20','','','.b-menu-style-1'),(172353,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-left','20','','','.b-menu-style-1'),(172354,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-left','0','','','.b-menu-style-2'),(172355,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-left','0','','','.b-menu-style-2'),(172356,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-left','0','','','.b-menu-style-2'),(172357,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-left','0','','','.b-menu-style-2'),(172358,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-left','20','','','.b-menu-style-2'),(172359,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-left','0','','','.b-menu-style-2'),(172360,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-left','20','','','.b-menu-style-2'),(172361,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-left','20','','','.b-menu-style-2'),(172362,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-left','20','','','.b-menu-style-2'),(172363,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-left','50','','','.b-menu-style-2'),(172364,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-left','5','','','.b-menu-style-3'),(172365,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','padding-left','20','','','.b-menu-style-3'),(172366,'deals-mobile','.b-messages .msv_btn','padding-left','0','','','.b-messages'),(172367,'deals-mobile','.b-messages .msv_content','padding-left','20','','','.b-messages'),(172368,'deals-mobile','.b-messages .msv_history','padding-left','20','','','.b-messages'),(172369,'deals-mobile','.b-messages .messMenuButton span','padding-left','15','','','.b-messages'),(172370,'deals-mobile','.b-messages .messages-menu ul','padding-left','0','','','.b-messages'),(172371,'deals-mobile','.b-messages .development-content .type-6 .content','padding-left','0','','','.b-messages'),(172372,'deals-mobile','.b-messages .messages-menu li a','padding-left','0','','','.b-messages'),(172373,'deals-mobile','.b-messages .content_management_attach button','padding-left','27','','','.b-messages'),(172374,'deals-mobile','.b-messages .messages-menu li','padding-left','0','','','.b-messages'),(172375,'deals-mobile','.b-messages .content_management_attach','padding-left','8','','','.b-messages'),(172376,'deals-mobile','.b-messages .email-heading','padding-left','15','','','.b-messages'),(172377,'deals-mobile','.b-messages .msv_to_cc','padding-left','15','','','.b-messages'),(172378,'deals-mobile','.b-messages .emailLineTextArea textarea','padding-left','10','','','.b-messages'),(172379,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-left','10','','','.b-messages'),(172380,'deals-mobile','.b-messages .emailBtn','padding-left','10','','','.b-messages'),(172381,'deals-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-left','0','','','.b-personal-catalog-popup'),(172382,'deals-mobile','.b-select-suggest .select2-container .select2-choice','padding-left','8','','','.b-select-suggest'),(172383,'deals-mobile','.b-select-suggest .select2-search input','padding-left','5','','','.b-select-suggest'),(172384,'deals-mobile','.b-select-suggest .select2-drop-mask','padding-left','0','','','.b-select-suggest'),(172385,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-left','5','','','.b-select-suggest'),(172386,'deals-mobile','.b-select-suggest .select2-results ul.select2-result-sub > li .select2-result-label','padding-left','20','','','.b-select-suggest'),(172387,'deals-mobile','.b-select-suggest .select2-results','padding-left','4','','','.b-select-suggest'),(172388,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-left','0','','','.b-select-suggest'),(172389,'deals-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','40','','','.b-select-suggest'),(172390,'deals-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','100','','','.b-select-suggest'),(172391,'deals-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','80','','','.b-select-suggest'),(172392,'deals-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','110','','','.b-select-suggest'),(172393,'deals-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','120','','','.b-select-suggest'),(172394,'deals-mobile','.b-select-suggest .select2-results ul.select2-result-sub','padding-left','0','','','.b-select-suggest'),(172395,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-left','0','','','.b-select-suggest'),(172396,'deals-mobile','.b-select-suggest .select2-locked','padding-left','5','','','.b-select-suggest'),(172397,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-left','0','','','.b-select-suggest'),(172398,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-left','18','','','.b-select-suggest'),(172399,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-left','5','','','.b-select-suggest'),(172400,'deals-mobile','.b-select-suggest .select2-search','padding-left','4','','','.b-select-suggest'),(172401,'deals-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','60','','','.b-select-suggest'),(172402,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','padding-left','7','','','.b-select-suggest'),(172403,'deals-mobile','.b-sub-totals .historyTotal td','padding-left','5','','','.b-sub-totals'),(172404,'deals-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(172405,'deals-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(172406,'deals-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(172407,'deals-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(172408,'deals-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(172409,'deals-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(172410,'deals-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(172411,'deals-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(172412,'deals-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(172413,'deals-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(172414,'deals-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(172415,'deals-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(172416,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(172417,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(172418,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(172419,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(172420,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(172421,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(172422,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(172423,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(172424,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(172425,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(172426,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(172427,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(172428,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(172429,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(172430,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(172431,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(172432,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(172433,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(172434,'deals-mobile','.b-trade-approval .steps-bar li a','padding-left','0','','','.b-trade-approval'),(172435,'deals-mobile','.b-trade-approval .middle-form','padding-left','0','','','.b-trade-approval'),(172436,'deals-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-left','5','','','.b-trade-approval'),(172437,'deals-mobile','.b-trade-approval .steps-bar','padding-left','12','','','.b-trade-approval'),(172438,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-left','10','','','.b-trade-approval'),(172439,'deals-mobile','.b-trade-approval .center-buttons','padding-left','0','','','.b-trade-approval'),(172440,'deals-mobile','.b-upload-file .upload-file-template','padding-left','1','','','.b-upload-file'),(172441,'deals-mobile','.b-upload-files .added-file','padding-left','0','','','.b-upload-files'),(172442,'deals-mobile','.b-upload-files .upload-files','padding-left','10','','','.b-upload-files'),(172443,'deals-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-left','20','','','.b-warehouses-popup'),(172444,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','padding-left','17','','','.b-warehouses-popup'),(172445,'deals-mobile','.batchPr .w-batch-products .products-listing .image','padding-left','0','','','.batchPr'),(172446,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-left','0','','','.batchPr'),(172447,'deals-mobile','.batchPr .w-batch-products','padding-left','0','','','.batchPr'),(172448,'deals-mobile','.batchPr > .block:nth-child(2)','padding-left','20','','','.batchPr'),(172449,'deals-mobile','.batchPr .w-batch-selected-products','padding-left','15','','','.batchPr'),(172450,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-left','0','','','.batchPr'),(172451,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-left','0','','','.batchPr'),(172452,'deals-mobile','.batchPr ','padding-left','0','','','.batchPr'),(172453,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-left','0','','','.batchPr'),(172454,'deals-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-left','0','','','.batchPr'),(172455,'deals-mobile','.batchPr .w-batch-products .products-listing .image','padding-left','0','','','.batchPr'),(172456,'deals-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(172457,'deals-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(172458,'deals-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(172459,'deals-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(172460,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-left','10','','','.p-account-samples-history'),(172461,'deals-mobile','.p-account-samples-history .orders-table td','padding-left','10','','','.p-account-samples-history'),(172462,'deals-mobile','.p-account-samples-history .view_link','padding-left','0','','','.p-account-samples-history'),(172463,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-left','10','','','.p-account-samples-history'),(172464,'deals-mobile','.p-account-samples-history .view_link','padding-left','0','','','.p-account-samples-history'),(172465,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-left','10','','','.p-account-samples-history'),(172466,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-left','10','','','.p-account-samples-history'),(172467,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-left','10','','','.p-account-samples-history'),(172468,'deals-mobile','.p-account-samples-history .orders-table td','padding-left','10','','','.p-account-samples-history'),(172469,'deals-mobile','.p-account-samples-history .order_history_table th','padding-left','10','','','.p-account-samples-history'),(172470,'deals-mobile','.p-account-samples-history .orders-table td','padding-left','10','','','.p-account-samples-history'),(172471,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-left','10','','','.p-account-samples-history'),(172472,'deals-mobile','.p-account-samples-history .view_link','padding-left','0','','','.p-account-samples-history'),(172473,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-left','10','','','.p-account-samples-history'),(172474,'deals-mobile','.p-account-samples-history .orders-table th','padding-left','10','','','.p-account-samples-history'),(172475,'deals-mobile','.p-account-samples-history .order_history_table th','padding-left','10','','','.p-account-samples-history'),(172476,'deals-mobile','.p-account-samples-history .view_link','padding-left','0','','','.p-account-samples-history'),(172477,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-left','10','','','.p-account-samples-history'),(172478,'deals-mobile','.p-account-samples-history .orders-table th','padding-left','10','','','.p-account-samples-history'),(172479,'deals-mobile','.p-account-samples-history .orders-table th','padding-left','10','','','.p-account-samples-history'),(172480,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-left','10','','','.p-account-samples-history'),(172481,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-left','10','','','.p-account-samples-history'),(172482,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-left','10','','','.p-account-samples-history'),(172483,'deals-mobile','.p-account-samples-history .orders-table th','padding-left','10','','','.p-account-samples-history'),(172484,'deals-mobile','.p-account-samples-history .orders-table td','padding-left','10','','','.p-account-samples-history'),(172485,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-left','10','','','.p-account-samples-history'),(172486,'deals-mobile','.p-account-samples-history .order_history_table th','padding-left','10','','','.p-account-samples-history'),(172487,'deals-mobile','.p-account-samples-history .order_history_table th','padding-left','10','','','.p-account-samples-history'),(172488,'deals-mobile','.p-account-samples-history .view_link','padding-left','0','','','.p-account-samples-history'),(172489,'deals-mobile','.p-account-samples-history .orders-table td','padding-left','10','','','.p-account-samples-history'),(172490,'deals-mobile','.p-account-samples-history .orders-table th','padding-left','10','','','.p-account-samples-history'),(172491,'deals-mobile','.p-account-samples-history .orders-table td','padding-left','10','','','.p-account-samples-history'),(172492,'deals-mobile','.p-account-samples-history .order_history_table th','padding-left','10','','','.p-account-samples-history'),(172493,'deals-mobile','.p-account-samples-history .order_history_table th','padding-left','10','','','.p-account-samples-history'),(172494,'deals-mobile','.p-account-samples-history .view_link','padding-left','0','','','.p-account-samples-history'),(172495,'deals-mobile','.p-account-samples-history .orders-table th','padding-left','10','','','.p-account-samples-history'),(172496,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','0','','','.p-account-samples-history-info'),(172497,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','0','','','.p-account-samples-history-info'),(172498,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-left','10','','','.p-account-samples-history-info'),(172499,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-left','0','','','.p-account-samples-history-info'),(172500,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-left','40','','','.p-account-samples-history-info'),(172501,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-left','0','','','.p-account-samples-history-info'),(172502,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','0','','','.p-account-samples-history-info'),(172503,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-left','40','','','.p-account-samples-history-info'),(172504,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','2','','','.p-account-samples-history-info'),(172505,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-left','10','','','.p-account-samples-history-info'),(172506,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-left','40','','','.p-account-samples-history-info'),(172507,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','2','','','.p-account-samples-history-info'),(172508,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-left','0','','','.p-account-samples-history-info'),(172509,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-left','0','','','.p-account-samples-history-info'),(172510,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-left','0','','','.p-account-samples-history-info'),(172511,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','0','','','.p-account-samples-history-info'),(172512,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-left','40','','','.p-account-samples-history-info'),(172513,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','0','','','.p-account-samples-history-info'),(172514,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','2','','','.p-account-samples-history-info'),(172515,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-left','40','','','.p-account-samples-history-info'),(172516,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','2','','','.p-account-samples-history-info'),(172517,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-left','40','','','.p-account-samples-history-info'),(172518,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-left','0','','','.p-account-samples-history-info'),(172519,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-left','10','','','.p-account-samples-history-info'),(172520,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','2','','','.p-account-samples-history-info'),(172521,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-left','10','','','.p-account-samples-history-info'),(172522,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','0','','','.p-account-samples-history-info'),(172523,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-left','40','','','.p-account-samples-history-info'),(172524,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-left','2','','','.p-account-samples-history-info'),(172525,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-left','40','','','.p-account-samples-history-info'),(172526,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-left','40','','','.p-account-samples-history-info'),(172527,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-left','10','','','.p-account-samples-history-info'),(172528,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-left','10','','','.p-account-samples-history-info'),(172529,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-left','40','','','.p-account-samples-history-info'),(172530,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-left','40','','','.p-account-samples-history-info'),(172531,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-left','40','','','.p-account-samples-history-info'),(172532,'deals-mobile','.p-catalog-product .prev-product','padding-left','50','','','.p-catalog-product'),(172533,'deals-mobile','.p-catalog-product .next-product','padding-left','20','','','.p-catalog-product'),(172534,'deals-mobile','.p-catalog-product .pn-image','padding-left','5','','','.p-catalog-product'),(172535,'deals-mobile','.p-catalog-product .next-product .pn-image','padding-left','2','3','','.p-catalog-product'),(172536,'deals-mobile','.p-catalog-product .pn-direction','padding-left','4','','','.p-catalog-product'),(172537,'deals-mobile','.p-quick-order-index .bottom','padding-left','0','','','.p-quick-order-index'),(172538,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.p-quick-order-index'),(172539,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.p-quick-order-index'),(172540,'deals-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-left','10','','','.p-quick-order-index'),(172541,'deals-mobile','.p-quick-order-index .all-scroll-div','padding-left','0','','','.p-quick-order-index'),(172542,'deals-mobile','.p-quick-order-index ul.token-input-list','padding-left','0','','','.p-quick-order-index'),(172543,'deals-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-left','10','','','.p-quick-order-index'),(172544,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(172545,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(172546,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(172547,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(172548,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(172549,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(172550,'deals-mobile','.w-account-address-book .item','padding-left','10','','','.w-account-address-book'),(172551,'deals-mobile','.w-account-address-book .wrap','padding-left','15','','','.w-account-address-book'),(172552,'deals-mobile','.w-account-address-book .btn-del','padding-left','7','','','.w-account-address-book'),(172553,'deals-mobile','.w-account-address-book .default-address','padding-left','7','','','.w-account-address-book'),(172554,'deals-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-left','0','','','.w-account-addresses-list'),(172555,'deals-mobile','.w-account-personal-catalog .list-switcher','padding-left','0','','','.w-account-personal-catalog'),(172556,'deals-mobile','.w-account-personal-catalog .list-switcher a','padding-left','6','','','.w-account-personal-catalog'),(172557,'deals-mobile','.w-account-subscription .subscription-variant','padding-left','10','','','.w-account-subscription'),(172558,'deals-mobile','.w-blog-widget-categories-list a','padding-left','15','','','.w-blog-widget-categories-list'),(172559,'deals-mobile','.w-blog-widget-most-popular-posts a','padding-left','15','','','.w-blog-widget-most-popular-posts'),(172560,'deals-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-left','0','','','.w-blog-widget-most-popular-posts'),(172561,'deals-mobile','.w-blog-widget-post-comments-count span','padding-left','22','','','.w-blog-widget-post-comments-count'),(172562,'deals-mobile','.w-blog-widget-post-listing .post','padding-left','33','','','.w-blog-widget-post-listing'),(172563,'deals-mobile','.w-blog-widget-post-listing .post_comment','padding-left','22','','','.w-blog-widget-post-listing'),(172564,'deals-mobile','.w-blog-widget-post-listing .post_name','padding-left','0','','','.w-blog-widget-post-listing'),(172565,'deals-mobile','.w-blog-widget-post-listing .post','padding-left','15','','','.w-blog-widget-post-listing'),(172566,'deals-mobile','.w-blog-widget-post-title ','padding-left','0','','','.w-blog-widget-post-title'),(172567,'deals-mobile','.w-blog-widget-post-title h1','padding-left','0','','','.w-blog-widget-post-title'),(172568,'deals-mobile','.w-blog-widget-related-posts .post','padding-left','15','','','.w-blog-widget-related-posts'),(172569,'deals-mobile','.w-blog-widget-related-posts .post_content a','padding-left','20','','','.w-blog-widget-related-posts'),(172570,'deals-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-left','20','','','.w-blog-widget-related-posts-by-category'),(172571,'deals-mobile','.w-blog-widget-related-posts-by-category .post','padding-left','15','','','.w-blog-widget-related-posts-by-category'),(172572,'deals-mobile','.w-blog-widget-related-posts-by-category ','padding-left','0','','','.w-blog-widget-related-posts-by-category'),(172573,'deals-mobile','.w-blog-widget-related-posts-by-category ','padding-left','15','','','.w-blog-widget-related-posts-by-category'),(172574,'deals-mobile','.w-blog-widget-tag-cloud a','padding-left','13','','','.w-blog-widget-tag-cloud'),(172575,'deals-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-left','0','','','.w-cart-cart-tabs'),(172576,'deals-mobile','.w-cart-compare .attributes-label','padding-left','10','','','.w-cart-compare'),(172577,'deals-mobile','.w-cart-compare .product .stock','padding-left','3','','','.w-cart-compare'),(172578,'deals-mobile','.w-cart-compare .product','padding-left','15','','','.w-cart-compare'),(172579,'deals-mobile','.w-cart-compare .cart-cell','padding-left','7','','','.w-cart-compare'),(172580,'deals-mobile','.w-cart-compare .price-cell','padding-left','20','','','.w-cart-compare'),(172581,'deals-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-left','0','','','.w-cart-compare'),(172582,'deals-mobile','.w-cart-compare .delete-cart','padding-left','10','','','.w-cart-compare'),(172583,'deals-mobile','.w-cart-compare .dropdown li','padding-left','10','','','.w-cart-compare'),(172584,'deals-mobile','.w-cart-compare .attributes-cell','padding-left','20','','','.w-cart-compare'),(172585,'deals-mobile','.w-cart-compare .price-label','padding-left','10','','','.w-cart-compare'),(172586,'deals-mobile','.w-cart-compare .product-label','padding-left','10','','','.w-cart-compare'),(172587,'deals-mobile','.w-cart-up-sell .w-list-type-1','padding-left','0','','','.w-cart-up-sell'),(172588,'deals-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-left','20','1','','.w-cart-up-sell'),(172589,'deals-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-left','21','','','.w-cart-up-sell'),(172590,'deals-mobile','.w-catalog-additional-images li','padding-left','10','','','.w-catalog-additional-images'),(172591,'deals-mobile','.w-catalog-additional-images ul','padding-left','0','','','.w-catalog-additional-images'),(172592,'deals-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-left','5','','','.w-catalog-b2b-add-button'),(172593,'deals-mobile','.w-catalog-compare td','padding-left','20','','','.w-catalog-compare'),(172594,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-left','0','','','.w-catalog-compare'),(172595,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','padding-left','5','2','','.w-catalog-compare'),(172596,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','padding-left','5','','','.w-catalog-compare'),(172597,'deals-mobile','.w-catalog-compare .cross-box .return','padding-left','20','','','.w-catalog-compare'),(172598,'deals-mobile','.w-catalog-paging .prev','padding-left','5','','','.w-catalog-paging'),(172599,'deals-mobile','.w-catalog-paging .next','padding-left','5','','','.w-catalog-paging'),(172600,'deals-mobile','.w-catalog-paging ','padding-left','5','2','','.w-catalog-paging'),(172601,'deals-mobile','.w-catalog-paging .paging-item','padding-left','2','','','.w-catalog-paging'),(172602,'deals-mobile','.w-catalog-paging .next-pages','padding-left','5','','','.w-catalog-paging'),(172603,'deals-mobile','.w-catalog-paging .prev-pages','padding-left','5','','','.w-catalog-paging'),(172604,'deals-mobile','.w-catalog-paging .page-number','padding-left','5','','','.w-catalog-paging'),(172605,'deals-mobile','.w-checkout-billing-address .same-address','padding-left','10','','','.w-checkout-billing-address'),(172606,'deals-mobile','.w-checkout-billing-address .edit-ab','padding-left','15','','','.w-checkout-billing-address'),(172607,'deals-mobile','.w-checkout-billing-address .addresses.address-main label','padding-left','0','','','.w-checkout-billing-address'),(172608,'deals-mobile','.w-checkout-billing-address .addresses .address-item label','padding-left','15','','','.w-checkout-billing-address'),(172609,'deals-mobile','.w-checkout-create-account .create-account','padding-left','0','','','.w-checkout-create-account'),(172610,'deals-mobile','.w-checkout-create-account .account-benefits ul','padding-left','20','','','.w-checkout-create-account'),(172611,'deals-mobile','.w-checkout-gdpr .terms-login','padding-left','0','','','.w-checkout-gdpr'),(172612,'deals-mobile','.w-checkout-gdpr .privacy-row','padding-left','0','','','.w-checkout-gdpr'),(172613,'deals-mobile','.w-checkout-shipping .sub-item','padding-left','0','','','.w-checkout-shipping'),(172614,'deals-mobile','.w-checkout-shipping-address .addresses.address-main label','padding-left','0','','','.w-checkout-shipping-address'),(172615,'deals-mobile','.w-checkout-shipping-address .addresses .address-item label','padding-left','15','','','.w-checkout-shipping-address'),(172616,'deals-mobile','.w-checkout-shipping-address .edit-ab','padding-left','15','','','.w-checkout-shipping-address'),(172617,'deals-mobile','.w-checkout-shipping-choice span','padding-left','0','','','.w-checkout-shipping-choice'),(172618,'deals-mobile','.w-checkout-shipping-choice span','padding-left','10','','','.w-checkout-shipping-choice'),(172619,'deals-mobile','.w-checkout-terms .required-message','padding-left','10','','','.w-checkout-terms'),(172620,'deals-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-left','10','','','.w-communication-new-topic'),(172621,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-left','5','','','.w-communication-new-topic'),(172622,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-left','5','','','.w-communication-new-topic'),(172623,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-left','10','','','.w-communication-new-topic'),(172624,'deals-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-left','0','','','.w-communication-new-topic'),(172625,'deals-mobile','.w-communication-post .communication-post-author','padding-left','0','','','.w-communication-post'),(172626,'deals-mobile','.w-delivery-day .left-count','padding-left','5','','','.w-delivery-day'),(172627,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-left','10','','','.w-image-maps'),(172628,'deals-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-left','0','','','.w-multi-cart-actions'),(172629,'deals-mobile','.w-personal-gift-status-bar .timeline','padding-left','10','','','.w-personal-gift-status-bar'),(172630,'deals-mobile','.w-personal-gift-status-bar .start-label','padding-left','30','','','.w-personal-gift-status-bar'),(172631,'deals-mobile','.w-personal-gift-status-bar .end-date','padding-left','5','3','','.w-personal-gift-status-bar'),(172632,'deals-mobile','.w-personal-gift-status-bar .end-label','padding-left','5','','','.w-personal-gift-status-bar'),(172633,'deals-mobile','.w-personal-gift-status-bar .inform','padding-left','5','4','','.w-personal-gift-status-bar'),(172634,'deals-mobile','.w-product-available-in-warehouses .warehouse-item','padding-left','0','','','.w-product-available-in-warehouses'),(172635,'deals-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(172636,'deals-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(172637,'deals-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(172638,'deals-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(172639,'deals-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(172640,'deals-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(172641,'deals-mobile','.w-product-customers-activity .customers-activity','padding-left','20','','','.w-product-customers-activity'),(172642,'deals-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(172643,'deals-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(172644,'deals-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(172645,'deals-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(172646,'deals-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(172647,'deals-mobile','.w-product-images-additional .images','padding-left','0','','','.w-product-images-additional'),(172648,'deals-mobile','.w-promotions .nextdiscount .promo-for-each','padding-left','10','','','.w-promotions'),(172649,'deals-mobile','.w-promotions .promo-cart-discount .master .item','padding-left','20','','','.w-promotions'),(172650,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-left','20','','','.w-promotions'),(172651,'deals-mobile','.w-promotions .promo-cart-discount .slave','padding-left','15','','','.w-promotions'),(172652,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-left','20','','','.w-promotions'),(172653,'deals-mobile','.w-promotions .promo-salemaker .item','padding-left','20','','','.w-promotions'),(172654,'deals-mobile','.w-promotions .promo-salemaker .promo-manufacturers','padding-left','12','','','.w-promotions'),(172655,'deals-mobile','.w-promotions .promo-item','padding-left','40','','','.w-promotions'),(172656,'deals-mobile','.w-promotions .promo-salemaker .discount','padding-left','20','','','.w-promotions'),(172657,'deals-mobile','.w-promotions .promo-cart-discount .slave .item','padding-left','20','','','.w-promotions'),(172658,'deals-mobile','.w-promotions .prom-multi-discount .promo-product','padding-left','20','','','.w-promotions'),(172659,'deals-mobile','.w-promotions .nextdiscount .content > div','padding-left','10','','','.w-promotions'),(172660,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','padding-left','20','','','.w-promotions'),(172661,'deals-mobile','.w-reviews-content .author','padding-left','20','','','.w-reviews-content'),(172662,'deals-mobile','.w-reviews-content .item','padding-left','0','','','.w-reviews-content'),(172663,'deals-mobile','.w-reviews-content .review','padding-left','20','','','.w-reviews-content'),(172664,'deals-mobile','.w-sitemap-delivery-location > ul','padding-left','0','','','.w-sitemap-delivery-location'),(172665,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul ul','padding-left','20','','','.w-sitemap-delivery-location'),(172666,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-left','0','','','.w-sitemap-delivery-location'),(172667,'deals-mobile','.w-top-text .top-text','padding-left','10','','','.w-top-text'),(172668,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(172669,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-preview','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(172670,'deals-mobile','.w-wedding-registry-widgets-delete-link a','padding-left','12','','','.w-wedding-registry-widgets-delete-link'),(172671,'deals-mobile','.w-wedding-registry-widgets-photos ','padding-left','20','','','.w-wedding-registry-widgets-photos'),(172672,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-left','17','','','.w-wedding-registry-widgets-photos'),(172673,'deals-mobile','.w-wedding-registry-widgets-share-link a','padding-left','12','','','.w-wedding-registry-widgets-share-link'),(172674,'deals-mobile','.b-quantity .qty-box input[type=\'text\']','padding-left','3','','','.b-quantity'),(172675,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left_important','important','','','.b-data-table'),(172676,'deals-mobile','.b-data-table table.dataTable thead td','padding-left_important','important','','','.b-data-table'),(172677,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left_important','important','','','.b-data-table'),(172678,'deals-mobile','.b-data-table table.dataTable tbody td','padding-left_important','important','','','.b-data-table'),(172679,'deals-mobile','.batchPr .w-batch-products','padding-left_important','important','','','.batchPr'),(172680,'deals-mobile','.w-list-type-2 .item','padding-right','21','','','.w-list-type-2'),(172681,'deals-mobile','.w-list-type-2 .compare-box-item','padding-right','7','','','.w-list-type-2'),(172682,'deals-mobile','.w-list-type-1_3 .item','padding-right','0','1','','.w-list-type-1_3'),(172683,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','padding-right','15','','','.w-list-type-2'),(172684,'deals-mobile','.w-list-type-1_3 .item','padding-right','0','','','.w-list-type-1_3'),(172685,'deals-mobile','.w-list-type-1_3 .compare-box-item','padding-right','7','','','.w-list-type-1_3'),(172686,'deals-mobile','.w-list-type-2_2 .compare-box-item','padding-right','7','','','.w-list-type-2_2'),(172687,'deals-mobile','.w-list-type-2.products-listing','padding-right','20','','','.w-list-type-2'),(172688,'deals-mobile','.w-list-type-2 .item','padding-right','20','1','','.w-list-type-2'),(172689,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','padding-right','15','','','.w-list-type-2_2'),(172690,'deals-mobile','.w-list-type-2_2.products-listing','padding-right','20','','','.w-list-type-2_2'),(172691,'deals-mobile','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(172692,'deals-mobile','.w-list-type-3.products-listing','padding-right','20','','','.w-list-type-3'),(172693,'deals-mobile','.w-menu .hided.menu ul li','padding-right','0','','','.w-menu'),(172694,'deals-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-right','0','','','.w-menu'),(172695,'deals-mobile','.w-menu-big ul','padding-right','0','','','.w-menu-big'),(172696,'deals-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','','','.w-menu-horizontal'),(172697,'deals-mobile','.w-menu-horizontal > ul > li > ul > li','padding-right','10','','','.w-menu-horizontal'),(172698,'deals-mobile','.w-menu-slider ul, .w-menu-slider li','padding-right','0','','','.w-menu-slider'),(172699,'deals-mobile','.w-menu-slider > ul > li > a','padding-right','10','','','.w-menu-slider'),(172700,'deals-mobile','.w-menu-slider > ul > li > ul > li','padding-right','50','','','.w-menu-slider'),(172701,'deals-mobile','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(172702,'deals-mobile','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(172703,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-right','0','','','.b-slick'),(172704,'deals-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','','','.w-menu-style-1'),(172705,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(172706,'deals-mobile','.b-bottom .popup-simple','padding-right','20','','','.b-bottom'),(172707,'deals-mobile','.b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .buttons','padding-right','10','','','.b-cookie-notice'),(172708,'deals-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.bottom .text','padding-right','10','','','.b-cookie-notice'),(172709,'deals-mobile','.w-login-block .returning','padding-right','40','','','.w-login-block'),(172710,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','','','.w-menu-style-1'),(172711,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-right','20','','','.w-menu-style-1'),(172712,'deals-mobile','.w-product-wedding-registry-button .btn','padding-right','0','','','.w-product-wedding-registry-button'),(172713,'deals-mobile','.w-sale .holder-2','padding-right','20','','','.w-sale'),(172714,'deals-mobile','.w-quote .cart-box-link','padding-right','10','','','.w-quote'),(172715,'deals-mobile','.w-filters .filter-widget-horizontal .filter-box','padding-right','20','','','.w-filters'),(172716,'deals-mobile','.w-categories .name','padding-right','3','','','.w-categories'),(172717,'deals-mobile','.w-filters .filter-ul-content','padding-right','0','','','.w-filters'),(172718,'deals-mobile','.w-currencies .currencies-title','padding-right','4','','','.w-currencies'),(172719,'deals-mobile','.w-currencies .current','padding-right','27','','','.w-currencies'),(172720,'deals-mobile','.w-currencies .select-link','padding-right','10','','','.w-currencies'),(172721,'deals-mobile','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(172722,'deals-mobile','.w-filters .ui-slider-range','padding-right','0','','','.w-filters'),(172723,'deals-mobile','.w-filters .fsl_handle','padding-right','0','','','.w-filters'),(172724,'deals-mobile','.w-top-categories .item','padding-right','10','863','','.w-top-categories'),(172725,'deals-mobile','.p-account-history-info .contentColumn','padding-right','10','','','.p-account-history-info'),(172726,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','padding-right','0','','','.p-account-history-info'),(172727,'deals-mobile','.p-account-history-info .historyTotal td','padding-right','5','','','.p-account-history-info'),(172728,'deals-mobile','.p-account-history-info .history_attr div strong, .p-account-history-info .history_attr div span','padding-right','10','','','.p-account-history-info'),(172729,'deals-mobile','.p-account-history-info .history_info > div + div','padding-right','0','','','.p-account-history-info'),(172730,'deals-mobile','.p-account-index .account_block','padding-right','0','','','.p-account-index'),(172731,'deals-mobile','.p-account-index .account_info','padding-right','0','','','.p-account-index'),(172732,'deals-mobile','.p-account-index .date_title','padding-right','0','','','.p-account-index'),(172733,'deals-mobile','.p-account-index .account_info li','padding-right','0','','','.p-account-index'),(172734,'deals-mobile','.p-account-index .account_page','padding-right','0','','','.p-account-index'),(172735,'deals-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','padding-right','10','','','.p-account-index'),(172736,'deals-mobile','.p-account-index .badc_bottom','padding-right','0','','','.p-account-index'),(172737,'deals-mobile','.p-account-index .orders-table th','padding-right','10','','','.p-account-index'),(172738,'deals-mobile','.b-bottom .popup-buttons','padding-right','15','','','.b-bottom'),(172739,'deals-mobile','.w-cart-checkout-btn a','padding-right','12','863','','.w-cart-checkout-btn'),(172740,'deals-mobile','.w-product-reviews .reviews-list .name','padding-right','10','','','.w-product-reviews'),(172741,'deals-mobile','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(172742,'deals-mobile','.w-product-images .img-holder','padding-right','20','','','.w-product-images'),(172743,'deals-mobile','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(172744,'deals-mobile','.b-bottom .popup-content','padding-right','15','','','.b-bottom'),(172745,'deals-mobile','.b-compare .compare_pagination','padding-right','0','','','.b-compare'),(172746,'deals-mobile','.w-search .button-search','padding-right','0','','','.w-search'),(172747,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-right','10','','','.b-multi-page-checkout'),(172748,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-right','10','','','.b-multi-page-checkout'),(172749,'deals-mobile','.w-search .name','padding-right','0','','','.w-search'),(172750,'deals-mobile','.w-search .items-title','padding-right','0','','','.w-search'),(172751,'deals-mobile','.w-sale .holder-1','padding-right','20','','','.w-sale'),(172752,'deals-mobile','.w-search .item','padding-right','0','','','.w-search'),(172753,'deals-mobile','.w-socials > li','padding-right','15','','','.w-socials'),(172754,'deals-mobile','.b-info-popup .info-popup div','padding-right','15','','','.b-info-popup'),(172755,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-right','0','','','.b-multi-page-checkout'),(172756,'deals-mobile','.w-search .search-input','padding-right','40','','','.w-search'),(172757,'deals-mobile','.w-promo-code .holder','padding-right','20','893','','.w-promo-code'),(172758,'deals-mobile','.w-search .suggest','padding-right','20','','','.w-search'),(172759,'deals-mobile','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(172760,'deals-mobile','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(172761,'deals-mobile','.p-wedding-registry-manage a.remove-btn','padding-right','5','','','.p-wedding-registry-manage'),(172762,'deals-mobile','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(172763,'deals-mobile','.p-account-history-info .popup-tracking-number','padding-right','10','','','.p-account-history-info'),(172764,'deals-mobile','.p-account-order-pay .contentColumn','padding-right','10','','','.p-account-order-pay'),(172765,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','padding-right','0','','','.p-account-order-pay'),(172766,'deals-mobile','.p-account-order-pay .historyTotal td','padding-right','5','','','.p-account-order-pay'),(172767,'deals-mobile','.p-account-order-pay .history_info > div + div','padding-right','0','864','','.p-account-order-pay'),(172768,'deals-mobile','.p-account-order-pay .history_attr div strong, .p-account-order-pay .history_attr div span','padding-right','10','','','.p-account-order-pay'),(172769,'deals-mobile','.p-account-order-pay .history_info > div','padding-right','0','864','','.p-account-order-pay'),(172770,'deals-mobile','.p-account-order-pay .history_info > div + div','padding-right','0','','','.p-account-order-pay'),(172771,'deals-mobile','.w-filters .head-filter-widget','padding-right','10','890','','.w-filters'),(172772,'deals-mobile','.w-product-configurator .pc_attr','padding-right','0','863','','.w-product-configurator'),(172773,'deals-mobile','.w-product-configurator .pc_item','padding-right','0','872','','.w-product-configurator'),(172774,'deals-mobile','.testimonials .name','padding-right','10','','',''),(172775,'deals-mobile','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(172776,'deals-mobile','.b-pagination .pagination span','padding-right','5','2','','.b-pagination'),(172777,'deals-mobile','.testimonials .heading-3','padding-right','0','','',''),(172778,'deals-mobile','.testimonials .review','padding-right','10','','',''),(172779,'deals-mobile','.b-pagination .pagination .prev-pages','padding-right','5','','','.b-pagination'),(172780,'deals-mobile','.testimonials .reviews-list .name','padding-right','10','','',''),(172781,'deals-mobile','.b-pagination .pagination .prev','padding-right','5','','','.b-pagination'),(172782,'deals-mobile','.b-bottom .confirm-popup .confirm-text','padding-right','0','','','.b-bottom'),(172783,'deals-mobile','.b-pagination .pagination .page-number','padding-right','5','','','.b-pagination'),(172784,'deals-mobile','.b-pagination .pagination .next-pages','padding-right','5','','','.b-pagination'),(172785,'deals-mobile','.b-pagination .pagination .next','padding-right','5','','','.b-pagination'),(172786,'deals-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','padding-right','10','','','.p-account-history'),(172787,'deals-mobile','.p-account-history .orders-table th','padding-right','10','','','.p-account-history'),(172788,'deals-mobile','.p-account-history .view_link','padding-right','20','','','.p-account-history'),(172789,'deals-mobile','.p-account-history .orders-table .td-alignright','padding-right','10','890','','.p-account-history'),(172790,'deals-mobile','.p-account-history .orders-table td','padding-right','10','890','','.p-account-history'),(172791,'deals-mobile','.p-account-index .orders-table td','padding-right','10','890','','.p-account-index'),(172792,'deals-mobile','.p-account-index .orders-table .td-alignright','padding-right','10','890','','.p-account-index'),(172793,'deals-mobile','.btn','padding-right','12','','',''),(172794,'deals-mobile','.btn-1','padding-right','25','','',''),(172795,'deals-mobile','.btn-2','padding-right','25','','',''),(172796,'deals-mobile','.p-blog-index .nav-next','padding-right','50','','','.p-blog-index'),(172797,'deals-mobile','.btn-3','padding-right','25','','',''),(172798,'deals-mobile','.w-list-type-2_2 .button-view a','padding-right','10','','','.w-list-type-2_2'),(172799,'deals-mobile','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(172800,'deals-mobile','.w-product-personal-catalog-button .btn','padding-right','0','','','.w-product-personal-catalog-button'),(172801,'deals-mobile','.b-fancybox .fancybox-error','padding-right','15','','','.b-fancybox'),(172802,'deals-mobile','.w-menu-horizontal ul','padding-right','0','','','.w-menu-horizontal'),(172803,'deals-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-right','0','','','.w-delivery-location-top-location-list'),(172804,'deals-mobile','.w-chat .w-chat-box','padding-right','12','','','.w-chat'),(172805,'deals-mobile','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(172806,'deals-mobile','.b-bottom .alert-message','padding-right','20','','','.b-bottom'),(172807,'deals-mobile','.p-wedding-registry-index .middle-box','padding-right','10','','','.p-wedding-registry-index'),(172808,'deals-mobile','.p-wedding-registry-index .main-content','padding-right','0','','','.p-wedding-registry-index'),(172809,'deals-mobile','.p-wedding-registry-index .main-button','padding-right','20','3','','.p-wedding-registry-index'),(172810,'deals-mobile','.p-wedding-registry-index .main-button','padding-right','20','4','','.p-wedding-registry-index'),(172811,'deals-mobile','.b-form .form-buttons','padding-right','0','','','.b-form'),(172812,'deals-mobile','.p-wedding-registry-manage .links','padding-right','10','','','.p-wedding-registry-manage'),(172813,'deals-mobile','.p-wedding-registry-manage .links a','padding-right','10','','','.p-wedding-registry-manage'),(172814,'deals-mobile','.p-wedding-registry-search .search-list','padding-right','20','','','.p-wedding-registry-search'),(172815,'deals-mobile','.b-table .table td','padding-right','15','','','.b-table'),(172816,'deals-mobile','.b-table .table .headings td','padding-right','10','','','.b-table'),(172817,'deals-mobile','.p-wedding-registry-share .middle-form > input','padding-right','0','','','.p-wedding-registry-share'),(172818,'deals-mobile','.b-pagination .pagination a','padding-right','5','','','.b-pagination'),(172819,'deals-mobile','.p-account-address-book .topButtons','padding-right','0','','','.p-account-address-book'),(172820,'deals-mobile','.header2 .ccc','padding-right','10','','',''),(172821,'deals-mobile','.p-account-history .order_history_table th','padding-right','10','','','.p-account-history'),(172822,'deals-mobile','.p-account-address-book .buttonBox','padding-right','0','','','.p-account-address-book'),(172823,'deals-mobile','.p-account-address-book .rightMes ul','padding-right','0','','','.p-account-address-book'),(172824,'deals-mobile','.p-account-address-book .btn-edit','padding-right','0','4','','.p-account-address-book'),(172825,'deals-mobile','.p-account-address-book .address_book h2','padding-right','10','','','.p-account-address-book'),(172826,'deals-mobile','.p-account-address-book .address_book','padding-right','0','','','.p-account-address-book'),(172827,'deals-mobile','.p-account-address-book .address_book h1','padding-right','0','','','.p-account-address-book'),(172828,'deals-mobile','.p-account-address-book .address_book, .p-account-address-book .account_history_info','padding-right','0','','','.p-account-address-book'),(172829,'deals-mobile','.b-compare .col-gender','padding-right','0','','','.b-compare'),(172830,'deals-mobile','.b-bottom .popup-heading','padding-right','15','','','.b-bottom'),(172831,'deals-mobile','.b-compare .column_wrapper','padding-right','10','','','.b-compare'),(172832,'deals-mobile','.b-compare .compare-box-item','padding-right','10','','','.b-compare'),(172833,'deals-mobile','.b-compare .col-two label','padding-right','0','','','.b-compare'),(172834,'deals-mobile','.b-compare .compare-head','padding-right','10','','','.b-compare'),(172835,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','padding-right','5','','','.b-switch'),(172836,'deals-mobile','.w-languages .lang-link','padding-right','10','872','','.w-languages'),(172837,'deals-mobile','.w-tabs .accordion-heading','padding-right','6','','','.w-tabs'),(172838,'deals-mobile','.w-quote .cart-box-link','padding-right','14','872','','.w-quote'),(172839,'deals-mobile','.w-currencies .select-link','padding-right','10','872','','.w-currencies'),(172840,'deals-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','872','','.w-menu-horizontal'),(172841,'deals-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','876','','.w-menu-style-1'),(172842,'deals-mobile','.w-languages .current','padding-right','27','872','','.w-languages'),(172843,'deals-mobile','.w-currencies .current','padding-right','27','872','','.w-currencies'),(172844,'deals-mobile','.b-slick button.slick-prev','padding-right','4','3','','.b-slick'),(172845,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-right','18','876','','.w-list-type-1'),(172846,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','876','','.w-menu-style-1'),(172847,'deals-mobile','.b-bottom .footerTitle','padding-right','0','863','','.b-bottom'),(172848,'deals-mobile','.p-account-history-info .history_info > div + div','padding-right','0','864','','.p-account-history-info'),(172849,'deals-mobile','.p-account-history-info .history_info > div','padding-right','0','864','','.p-account-history-info'),(172850,'deals-mobile','.w-cart .cart-content','padding-right','15','','','.w-cart'),(172851,'deals-mobile','.w-cart .cart-total','padding-right','0','','','.w-cart'),(172852,'deals-mobile','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(172853,'deals-mobile','.b-product-images .additional-vertical','padding-right','150','','','.b-product-images'),(172854,'deals-mobile','.w-bestsellers .heading-3','padding-right','0','','','.w-bestsellers'),(172855,'deals-mobile','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(172856,'deals-mobile','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(172857,'deals-mobile','.w-breadcrumb .breadcrumb-li','padding-right','0','','','.w-breadcrumb'),(172858,'deals-mobile','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-right','10','865','',''),(172859,'deals-mobile','.w-top-categories .image','padding-right','0','','','.w-top-categories'),(172860,'deals-mobile','.w-account a.my-acc-link','padding-right','17','','','.w-account'),(172861,'deals-mobile','.p-account-index .topAccount > li > div','padding-right','0','863','','.p-account-index'),(172862,'deals-mobile','.p-account-trade-form .trade-form-area','padding-right','20','','','.p-account-trade-form'),(172863,'deals-mobile','.p-account-trade-form .widget','padding-right','0','','','.p-account-trade-form'),(172864,'deals-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-right','0','','','.p-blog-index'),(172865,'deals-mobile','.p-blog-index .nav-links','padding-right','0','','','.p-blog-index'),(172866,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-right','10','','','.p-blog-index'),(172867,'deals-mobile','.p-blog-index .wp-widget ul','padding-right','0','','','.p-blog-index'),(172868,'deals-mobile','.p-blog-index .wp-widget li','padding-right','0','','','.p-blog-index'),(172869,'deals-mobile','.p-checkout-index .shipping-method .item','padding-right','0','','','.p-checkout-index'),(172870,'deals-mobile','.p-checkout-index .shipping-method .title','padding-right','5','','','.p-checkout-index'),(172871,'deals-mobile','.p-reviews-info .review-info-content','padding-right','20','','','.p-reviews-info'),(172872,'deals-mobile','.p-checkout-index .shipping-method .row','padding-right','5','','','.p-checkout-index'),(172873,'deals-mobile','.p-reviews-info .review-info-text','padding-right','10','','','.p-reviews-info'),(172874,'deals-mobile','.p-reviews-info .review-info-image','padding-right','20','','','.p-reviews-info'),(172875,'deals-mobile','.p-reviews-info .reviews-info .buttons','padding-right','0','','','.p-reviews-info'),(172876,'deals-mobile','.p-shopping-cart-index .cart-popup .cart-page, .p-shopping-cart-index .cart-popup .wishlist-page','padding-right','20','','','.p-shopping-cart-index'),(172877,'deals-mobile','.p-account-index .account_info li','padding-right','0','863','','.p-account-index'),(172878,'deals-mobile','.p-account-index .topAccount > li','padding-right','0','863','','.p-account-index'),(172879,'deals-mobile','.w-product-images .images','padding-right','0','893','','.w-product-images'),(172880,'deals-mobile','.w-filters .handle_tit','padding-right','5','','','.w-filters'),(172881,'deals-mobile','.b-slick .slick-vertical button.slick-next','padding-right','0','3','','.b-slick'),(172882,'deals-mobile','.b-slick .slick-vertical button.slick-prev','padding-right','0','3','','.b-slick'),(172883,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-right','20','','','.b-fancybox'),(172884,'deals-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-right','10','','','.p-account-subscription-historyinfo'),(172885,'deals-mobile','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(172886,'deals-mobile','.p-account-index th','padding-right','15','','','.p-account-index'),(172887,'deals-mobile','.p-account-index .view_link','padding-right','20','','','.p-account-index'),(172888,'deals-mobile','.p-account-index .topAccount','padding-right','19','','','.p-account-index'),(172889,'deals-mobile','.w-list-type-1 ','padding-right','0','','','.w-list-type-1'),(172890,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','padding-right','15','','','.w-list-type-1_3'),(172891,'deals-mobile','.w-list-type-1 .item','padding-right','5','','','.w-list-type-1'),(172892,'deals-mobile','.w-list-type-1_2.products-listing','padding-right','20','','','.w-list-type-1_2'),(172893,'deals-mobile','.w-list-type-1 .compare-box-item','padding-right','7','','','.w-list-type-1'),(172894,'deals-mobile','.w-list-type-1_2 .compare-box-item','padding-right','7','','','.w-list-type-1_2'),(172895,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-right','15','','','.w-list-type-1'),(172896,'deals-mobile','.w-languages .lang-link','padding-right','10','','','.w-languages'),(172897,'deals-mobile','.w-languages .current','padding-right','27','','','.w-languages'),(172898,'deals-mobile','.w-filters .head-filter-widget','padding-right','0','','','.w-filters'),(172899,'deals-mobile','.b-fancybox .fancybox-title-over-wrap','padding-right','10','','','.b-fancybox'),(172900,'deals-mobile','.p-quote-cart-index .cart-popup .cart-page, .p-quote-cart-index .cart-popup .wishlist-page','padding-right','20','','','.p-quote-cart-index'),(172901,'deals-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-right','0','','','.b-fancybox'),(172902,'deals-mobile','.w-categories .image','padding-right','0','','','.w-categories'),(172903,'deals-mobile','.w-categories .item','padding-right','20','','','.w-categories'),(172904,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','padding-right','15','','','.w-list-type-1_2'),(172905,'deals-mobile','.w-cart a.item','padding-right','0','','','.w-cart'),(172906,'deals-mobile','.w-cart .cart-box-link','padding-right','14','','','.w-cart'),(172907,'deals-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(172908,'deals-mobile','.b-compare .popupCompare .pop-up-content','padding-right','10','','','.b-compare'),(172909,'deals-mobile','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(172910,'deals-mobile','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(172911,'deals-mobile','.w-product-reviews .reviews-list .review','padding-right','10','','','.w-product-reviews'),(172912,'deals-mobile','.w-product-sale-ends .left-count','padding-right','5','','','.w-product-sale-ends'),(172913,'deals-mobile','.w-reviews .heading-3','padding-right','0','','','.w-reviews'),(172914,'deals-mobile','.w-reviews .review','padding-right','10','','','.w-reviews'),(172915,'deals-mobile','.w-sale .left-count','padding-right','5','','','.w-sale'),(172916,'deals-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(172917,'deals-mobile','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(172918,'deals-mobile','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(172919,'deals-mobile','.w-product-properties li','padding-right','5','','','.w-product-properties'),(172920,'deals-mobile','.w-product-configurator .pc_item','padding-right','20','','','.w-product-configurator'),(172921,'deals-mobile','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(172922,'deals-mobile','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(172923,'deals-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(172924,'deals-mobile','.w-menu-style-1 ul','padding-right','0','','','.w-menu-style-1'),(172925,'deals-mobile','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(172926,'deals-mobile','.b-fancybox .fancybox-prev span','padding-right','4','3','','.b-fancybox'),(172927,'deals-mobile','.p-wedding-registry-share .add-row','padding-right','40','','','.p-wedding-registry-share'),(172928,'deals-mobile','.p-wedding-registry-share .address-row','padding-right','40','','','.p-wedding-registry-share'),(172929,'deals-mobile','.w-tabs .accordion-heading','padding-right','8','863','','.w-tabs'),(172930,'deals-mobile','.w-top-categories .categories h2','padding-right','0','','','.w-top-categories'),(172931,'deals-mobile','.w-categories .categories h2','padding-right','0','','','.w-categories'),(172932,'deals-mobile','.w-banner .carousel-text > span','padding-right','20','','','.w-banner'),(172933,'deals-mobile','.b-form .terms-login','padding-right','80','','','.b-form'),(172934,'deals-mobile','.b-slick .slick-list','padding-right','0','','','.b-slick'),(172935,'deals-mobile','.w-tabs .tab-li','padding-right','0','','','.w-tabs'),(172936,'deals-mobile','.w-tabs .tab-a','padding-right','6','','','.w-tabs'),(172937,'deals-mobile','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(172938,'deals-mobile','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(172939,'deals-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-right','10','','','.w-menu-horizontal'),(172940,'deals-mobile','.w-cart .qty','padding-right','5','4','','.w-cart'),(172941,'deals-mobile','.w-account ul, .w-account li','padding-right','0','','','.w-account'),(172942,'deals-mobile','.p-account-index .account_info .info .info_span','padding-right','5','','','.p-account-index'),(172943,'deals-mobile','.w-categories .item','padding-right','10','863','','.w-categories'),(172944,'deals-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-right','0','','','.b-fancybox'),(172945,'deals-mobile','.w-cart-give-away .ga_img','padding-right','1','','','.w-cart-give-away'),(172946,'deals-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-right','6','','','.b-compare'),(172947,'deals-mobile','.w-search .search form','padding-right','5','','','.w-search'),(172948,'deals-mobile','.w-list-type-2 .button-view a','padding-right','10','','','.w-list-type-2'),(172949,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','padding-right','10','','',''),(172950,'deals-mobile','.b-autocomplete .ui-autocomplete','padding-right','0','','','.b-autocomplete'),(172951,'deals-mobile','textarea','padding-right','10','','',''),(172952,'deals-mobile','.b-autocomplete .ui-autocomplete li','padding-right','10','','','.b-autocomplete'),(172953,'deals-mobile','.w-list-type-1_3 .button-view a','padding-right','10','','','.w-list-type-1_3'),(172954,'deals-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-right','20','','','.b-bottom'),(172955,'deals-mobile','.w-list-type-1_2 .button-view a','padding-right','10','','','.w-list-type-1_2'),(172956,'deals-mobile','.b-bottom .pop-up-close','padding-right','1','','','.b-bottom'),(172957,'deals-mobile','.b-bottom .pop-up-info','padding-right','20','','','.b-bottom'),(172958,'deals-mobile','.b-bottom .popup-box-wrap','padding-right','10','','','.b-bottom'),(172959,'deals-mobile','.w-list-type-1 .button-view a','padding-right','10','','','.w-list-type-1'),(172960,'deals-mobile','.b-form .center-buttons','padding-right','0','','','.b-form'),(172961,'deals-mobile','.w-reviews .name','padding-right','10','','','.w-reviews'),(172962,'deals-mobile','.w-reviews .reviews','padding-right','10','','','.w-reviews'),(172963,'deals-mobile','.w-reviews .reviews-list .name','padding-right','10','','','.w-reviews'),(172964,'deals-mobile','.w-top-categories .item','padding-right','20','','','.w-top-categories'),(172965,'deals-mobile','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block','padding-right','10','865','',''),(172966,'deals-mobile','.p-account-index .account_info','padding-right','0','876','','.p-account-index'),(172967,'deals-mobile','.w-tabs .tab-navigation','padding-right','0','','','.w-tabs'),(172968,'deals-mobile','.w-top-categories .name','padding-right','3','','','.w-top-categories'),(172969,'deals-mobile','.b-form .middle-form','padding-right','0','','','.b-form'),(172970,'deals-mobile','.b-form .payment-method .item-radio label','padding-right','5','','','.b-form'),(172971,'deals-mobile','.b-form .shipping-method .input','padding-right','10','','','.b-form'),(172972,'deals-mobile','.b-form .required-message','padding-right','3','','','.b-form'),(172973,'deals-mobile','.b-form .required-message-wrap','padding-right','0','','','.b-form'),(172974,'deals-mobile','.b-info .info','padding-right','0','','','.b-info'),(172975,'deals-mobile','.b-info .info li','padding-right','0','','','.b-info'),(172976,'deals-mobile','.b-info .info ul','padding-right','0','','','.b-info'),(172977,'deals-mobile','.p-account-index .topAccount > li','padding-right','2','','','.p-account-index'),(172978,'deals-mobile','.b-products-listing .in-cart','padding-right','10','','','.b-products-listing'),(172979,'deals-mobile','.b-products-listing .products-listing .btn-buy','padding-right','10','','','.b-products-listing'),(172980,'deals-mobile','.b-products-listing .products-listing .buyButton .btn','padding-right','10','','','.b-products-listing'),(172981,'deals-mobile','.b-products-listing .products-listing .compare','padding-right','6','','','.b-products-listing'),(172982,'deals-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-right','2','','','.b-products-listing'),(172983,'deals-mobile','.b-products-listing .products-listing a.btn.view-button','padding-right','0','','','.b-products-listing'),(172984,'deals-mobile','.b-products-listing .products-listing h2','padding-right','0','','','.b-products-listing'),(172985,'deals-mobile','.b-products-listing .promos-info .promo-item','padding-right','10','','','.b-products-listing'),(172986,'deals-mobile','.b-products-listing .promos-info .promo-name','padding-right','15','','','.b-products-listing'),(172987,'deals-mobile','.b-products-listing .list-productlisting div.BlockBox.item-holder','padding-right','10','','','.b-products-listing'),(172988,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.b-data-table'),(172989,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.b-data-table'),(172990,'deals-mobile','.b-data-table table.dataTable thead td','padding-right','20','','','.b-data-table'),(172991,'deals-mobile','.b-data-table table.dataTable tbody td','padding-right','20','','','.b-data-table'),(172992,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(172993,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(172994,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(172995,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(172996,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(172997,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(172998,'deals-mobile','.b-email .qty','padding-right','10','','','.b-email'),(172999,'deals-mobile','.b-email .price','padding-right','10','','','.b-email'),(173000,'deals-mobile','.b-email .price','padding-right','10','','','.b-email'),(173001,'deals-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(173002,'deals-mobile','.b-email .model','padding-right','10','','','.b-email'),(173003,'deals-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(173004,'deals-mobile','.b-email .model','padding-right','10','','','.b-email'),(173005,'deals-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(173006,'deals-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(173007,'deals-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(173008,'deals-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(173009,'deals-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(173010,'deals-mobile','.b-email .image','padding-right','10','','','.b-email'),(173011,'deals-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(173012,'deals-mobile','.b-email .price','padding-right','10','','','.b-email'),(173013,'deals-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(173014,'deals-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(173015,'deals-mobile','.b-email .qty','padding-right','10','','','.b-email'),(173016,'deals-mobile','.b-email .name','padding-right','10','','','.b-email'),(173017,'deals-mobile','.b-email .name','padding-right','10','','','.b-email'),(173018,'deals-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(173019,'deals-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(173020,'deals-mobile','.b-email .price','padding-right','10','','','.b-email'),(173021,'deals-mobile','.b-email .model','padding-right','10','','','.b-email'),(173022,'deals-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(173023,'deals-mobile','.b-email .model','padding-right','10','','','.b-email'),(173024,'deals-mobile','.b-email .price','padding-right','10','','','.b-email'),(173025,'deals-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(173026,'deals-mobile','.b-email .image','padding-right','10','','','.b-email'),(173027,'deals-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(173028,'deals-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(173029,'deals-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(173030,'deals-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(173031,'deals-mobile','.b-email .image','padding-right','10','','','.b-email'),(173032,'deals-mobile','.b-email .name','padding-right','10','','','.b-email'),(173033,'deals-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(173034,'deals-mobile','.b-email .image','padding-right','10','','','.b-email'),(173035,'deals-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(173036,'deals-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(173037,'deals-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(173038,'deals-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(173039,'deals-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(173040,'deals-mobile','.b-email .name','padding-right','10','','','.b-email'),(173041,'deals-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(173042,'deals-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(173043,'deals-mobile','.b-email .image','padding-right','10','','','.b-email'),(173044,'deals-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(173045,'deals-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(173046,'deals-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(173047,'deals-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(173048,'deals-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(173049,'deals-mobile','.b-email .qty','padding-right','10','','','.b-email'),(173050,'deals-mobile','.b-email .name','padding-right','10','','','.b-email'),(173051,'deals-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(173052,'deals-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(173053,'deals-mobile','.b-email .model','padding-right','10','','','.b-email'),(173054,'deals-mobile','.b-email .price','padding-right','10','','','.b-email'),(173055,'deals-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(173056,'deals-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(173057,'deals-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(173058,'deals-mobile','.b-email .qty','padding-right','10','','','.b-email'),(173059,'deals-mobile','.b-email .image','padding-right','10','','','.b-email'),(173060,'deals-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(173061,'deals-mobile','.b-email .name','padding-right','10','','','.b-email'),(173062,'deals-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(173063,'deals-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(173064,'deals-mobile','.b-email .qty','padding-right','10','','','.b-email'),(173065,'deals-mobile','.b-email .model','padding-right','10','','','.b-email'),(173066,'deals-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(173067,'deals-mobile','.b-email .qty','padding-right','10','','','.b-email'),(173068,'deals-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(173069,'deals-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(173070,'deals-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(173071,'deals-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(173072,'deals-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(173073,'deals-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(173074,'deals-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(173075,'deals-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(173076,'deals-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(173077,'deals-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(173078,'deals-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(173079,'deals-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(173080,'deals-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(173081,'deals-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(173082,'deals-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(173083,'deals-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(173084,'deals-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(173085,'deals-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(173086,'deals-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(173087,'deals-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(173088,'deals-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(173089,'deals-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(173090,'deals-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(173091,'deals-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(173092,'deals-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(173093,'deals-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(173094,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-right','0','','','.b-h-inline'),(173095,'deals-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-right','0','','','.b-menu-style'),(173096,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-right','5','','','.b-menu-style-1'),(173097,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-right','20','','','.b-menu-style-1'),(173098,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-right','20','','','.b-menu-style-1'),(173099,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-right','20','','','.b-menu-style-1'),(173100,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-right','20','','','.b-menu-style-2'),(173101,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-right','20','','','.b-menu-style-2'),(173102,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-right','0','','','.b-menu-style-2'),(173103,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-right','0','','','.b-menu-style-2'),(173104,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-right','20','','','.b-menu-style-2'),(173105,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-right','0','','','.b-menu-style-2'),(173106,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-right','20','','','.b-menu-style-2'),(173107,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-right','20','','','.b-menu-style-2'),(173108,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-right','50','','','.b-menu-style-2'),(173109,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-right','30','','','.b-menu-style-2'),(173110,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-right','5','','','.b-menu-style-3'),(173111,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','padding-right','20','','','.b-menu-style-3'),(173112,'deals-mobile','.b-messages .emailLineTextArea textarea','padding-right','10','','','.b-messages'),(173113,'deals-mobile','.b-messages .msv_btn','padding-right','0','','','.b-messages'),(173114,'deals-mobile','.b-messages .msv_content','padding-right','20','','','.b-messages'),(173115,'deals-mobile','.b-messages .development-content .type-6 .content','padding-right','40','','','.b-messages'),(173116,'deals-mobile','.b-messages .msv_history','padding-right','20','','','.b-messages'),(173117,'deals-mobile','.b-messages .messMenuButton span','padding-right','15','','','.b-messages'),(173118,'deals-mobile','.b-messages .messages-menu ul','padding-right','0','','','.b-messages'),(173119,'deals-mobile','.b-messages .messages-menu li a','padding-right','0','','','.b-messages'),(173120,'deals-mobile','.b-messages .messages-menu li','padding-right','0','','','.b-messages'),(173121,'deals-mobile','.b-messages .content_management_attach button','padding-right','27','','','.b-messages'),(173122,'deals-mobile','.b-messages .email-heading','padding-right','15','','','.b-messages'),(173123,'deals-mobile','.b-messages .content_management_attach','padding-right','8','','','.b-messages'),(173124,'deals-mobile','.b-messages .emailBtn','padding-right','10','','','.b-messages'),(173125,'deals-mobile','.b-messages .msv_to_cc','padding-right','15','','','.b-messages'),(173126,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-right','10','','','.b-messages'),(173127,'deals-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-right','0','','','.b-personal-catalog-popup'),(173128,'deals-mobile','.b-select-suggest .select2-search input','padding-right','20','','','.b-select-suggest'),(173129,'deals-mobile','.b-select-suggest .select2-search','padding-right','4','','','.b-select-suggest'),(173130,'deals-mobile','.b-select-suggest .select2-container .select2-choice','padding-right','0','','','.b-select-suggest'),(173131,'deals-mobile','.b-select-suggest .select2-drop-mask','padding-right','0','','','.b-select-suggest'),(173132,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-right','0','','','.b-select-suggest'),(173133,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(173134,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(173135,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-right','0','','','.b-select-suggest'),(173136,'deals-mobile','.b-select-suggest .select2-locked','padding-right','5','','','.b-select-suggest'),(173137,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-right','0','','','.b-select-suggest'),(173138,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-right','5','','','.b-select-suggest'),(173139,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','padding-right','7','','','.b-select-suggest'),(173140,'deals-mobile','.b-select-suggest .select2-results','padding-right','4','','','.b-select-suggest'),(173141,'deals-mobile','.b-sub-totals .historyTotal td','padding-right','5','','','.b-sub-totals'),(173142,'deals-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(173143,'deals-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(173144,'deals-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(173145,'deals-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(173146,'deals-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(173147,'deals-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(173148,'deals-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(173149,'deals-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(173150,'deals-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(173151,'deals-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(173152,'deals-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(173153,'deals-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(173154,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(173155,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(173156,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(173157,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(173158,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(173159,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(173160,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(173161,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(173162,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(173163,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(173164,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(173165,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(173166,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(173167,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(173168,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(173169,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(173170,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(173171,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(173172,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(173173,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(173174,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(173175,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(173176,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(173177,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(173178,'deals-mobile','.b-trade-approval .steps-bar li a','padding-right','0','','','.b-trade-approval'),(173179,'deals-mobile','.b-trade-approval .middle-form','padding-right','0','','','.b-trade-approval'),(173180,'deals-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-right','5','','','.b-trade-approval'),(173181,'deals-mobile','.b-trade-approval .steps-bar','padding-right','0','','','.b-trade-approval'),(173182,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-right','10','','','.b-trade-approval'),(173183,'deals-mobile','.b-trade-approval .center-buttons','padding-right','0','','','.b-trade-approval'),(173184,'deals-mobile','.b-upload-file .upload-file-template','padding-right','1','','','.b-upload-file'),(173185,'deals-mobile','.b-upload-files .added-file','padding-right','0','','','.b-upload-files'),(173186,'deals-mobile','.b-upload-files .upload-files','padding-right','10','','','.b-upload-files'),(173187,'deals-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-right','20','','','.b-warehouses-popup'),(173188,'deals-mobile','.batchPr .w-batch-products .products-listing .image','padding-right','15','','','.batchPr'),(173189,'deals-mobile','.batchPr .w-batch-products','padding-right','0','','','.batchPr'),(173190,'deals-mobile','.batchPr > .block:nth-child(2)','padding-right','0','','','.batchPr'),(173191,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-right','0','','','.batchPr'),(173192,'deals-mobile','.batchPr .w-batch-selected-products','padding-right','15','','','.batchPr'),(173193,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-right','0','','','.batchPr'),(173194,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-right','15','','','.batchPr'),(173195,'deals-mobile','.batchPr .w-batch-selected-products .item','padding-right','40','','','.batchPr'),(173196,'deals-mobile','.batchPr ','padding-right','0','','','.batchPr'),(173197,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-right','0','','','.batchPr'),(173198,'deals-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-right','0','','','.batchPr'),(173199,'deals-mobile','.batchPr .w-batch-products .products-listing .image','padding-right','0','','','.batchPr'),(173200,'deals-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(173201,'deals-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(173202,'deals-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(173203,'deals-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(173204,'deals-mobile','.p-account-samples-history .view_link','padding-right','20','','','.p-account-samples-history'),(173205,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-right','10','','','.p-account-samples-history'),(173206,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-right','10','','','.p-account-samples-history'),(173207,'deals-mobile','.p-account-samples-history .view_link','padding-right','20','','','.p-account-samples-history'),(173208,'deals-mobile','.p-account-samples-history .order_history_table th','padding-right','10','','','.p-account-samples-history'),(173209,'deals-mobile','.p-account-samples-history .order_history_table th','padding-right','10','','','.p-account-samples-history'),(173210,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-right','10','','','.p-account-samples-history'),(173211,'deals-mobile','.p-account-samples-history .orders-table td','padding-right','10','','','.p-account-samples-history'),(173212,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-right','10','','','.p-account-samples-history'),(173213,'deals-mobile','.p-account-samples-history .orders-table th','padding-right','10','','','.p-account-samples-history'),(173214,'deals-mobile','.p-account-samples-history .orders-table td','padding-right','10','','','.p-account-samples-history'),(173215,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-right','10','','','.p-account-samples-history'),(173216,'deals-mobile','.p-account-samples-history .order_history_table th','padding-right','10','','','.p-account-samples-history'),(173217,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-right','10','','','.p-account-samples-history'),(173218,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-right','10','','','.p-account-samples-history'),(173219,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-right','10','','','.p-account-samples-history'),(173220,'deals-mobile','.p-account-samples-history .orders-table td','padding-right','10','','','.p-account-samples-history'),(173221,'deals-mobile','.p-account-samples-history .view_link','padding-right','20','','','.p-account-samples-history'),(173222,'deals-mobile','.p-account-samples-history .orders-table td','padding-right','10','','','.p-account-samples-history'),(173223,'deals-mobile','.p-account-samples-history .orders-table th','padding-right','10','','','.p-account-samples-history'),(173224,'deals-mobile','.p-account-samples-history .order_history_table th','padding-right','10','','','.p-account-samples-history'),(173225,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-right','10','','','.p-account-samples-history'),(173226,'deals-mobile','.p-account-samples-history .view_link','padding-right','20','','','.p-account-samples-history'),(173227,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-right','10','','','.p-account-samples-history'),(173228,'deals-mobile','.p-account-samples-history .orders-table th','padding-right','10','','','.p-account-samples-history'),(173229,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-right','10','','','.p-account-samples-history'),(173230,'deals-mobile','.p-account-samples-history .order_history_table th','padding-right','10','','','.p-account-samples-history'),(173231,'deals-mobile','.p-account-samples-history .orders-table th','padding-right','10','','','.p-account-samples-history'),(173232,'deals-mobile','.p-account-samples-history .view_link','padding-right','20','','','.p-account-samples-history'),(173233,'deals-mobile','.p-account-samples-history .orders-table td','padding-right','10','','','.p-account-samples-history'),(173234,'deals-mobile','.p-account-samples-history .orders-table th','padding-right','10','','','.p-account-samples-history'),(173235,'deals-mobile','.p-account-samples-history .order_history_table th','padding-right','10','','','.p-account-samples-history'),(173236,'deals-mobile','.p-account-samples-history .view_link','padding-right','20','','','.p-account-samples-history'),(173237,'deals-mobile','.p-account-samples-history .orders-table th','padding-right','10','','','.p-account-samples-history'),(173238,'deals-mobile','.p-account-samples-history .orders-table td','padding-right','10','','','.p-account-samples-history'),(173239,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-right','10','','','.p-account-samples-history'),(173240,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(173241,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-right','0','','','.p-account-samples-history-info'),(173242,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-right','0','','','.p-account-samples-history-info'),(173243,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(173244,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-right','0','','','.p-account-samples-history-info'),(173245,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(173246,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-right','0','','','.p-account-samples-history-info'),(173247,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(173248,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(173249,'deals-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','padding-right','10','','','.p-account-samples-history-info'),(173250,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-right','0','','','.p-account-samples-history-info'),(173251,'deals-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','padding-right','10','','','.p-account-samples-history-info'),(173252,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(173253,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-right','0','','','.p-account-samples-history-info'),(173254,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(173255,'deals-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','padding-right','10','','','.p-account-samples-history-info'),(173256,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-right','10','','','.p-account-samples-history-info'),(173257,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-right','10','','','.p-account-samples-history-info'),(173258,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(173259,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-right','0','','','.p-account-samples-history-info'),(173260,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(173261,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-right','10','','','.p-account-samples-history-info'),(173262,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-right','10','','','.p-account-samples-history-info'),(173263,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-right','0','','','.p-account-samples-history-info'),(173264,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(173265,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-right','10','','','.p-account-samples-history-info'),(173266,'deals-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','padding-right','10','','','.p-account-samples-history-info'),(173267,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-right','10','','','.p-account-samples-history-info'),(173268,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-right','10','','','.p-account-samples-history-info'),(173269,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(173270,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-right','0','','','.p-account-samples-history-info'),(173271,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-right','0','','','.p-account-samples-history-info'),(173272,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-right','0','','','.p-account-samples-history-info'),(173273,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-right','10','','','.p-account-samples-history-info'),(173274,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-right','10','','','.p-account-samples-history-info'),(173275,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-right','10','','','.p-account-samples-history-info'),(173276,'deals-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','padding-right','10','','','.p-account-samples-history-info'),(173277,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-right','0','','','.p-account-samples-history-info'),(173278,'deals-mobile','.p-account-samples-history-info .history_attr div strong, .p-account-samples-history-info .history_attr div span','padding-right','10','','','.p-account-samples-history-info'),(173279,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-right','10','','','.p-account-samples-history-info'),(173280,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-right','0','','','.p-account-samples-history-info'),(173281,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-right','10','','','.p-account-samples-history-info'),(173282,'deals-mobile','.p-catalog-product .prev-product','padding-right','20','','','.p-catalog-product'),(173283,'deals-mobile','.p-catalog-product .next-product','padding-right','50','','','.p-catalog-product'),(173284,'deals-mobile','.p-catalog-product .pn-image','padding-right','5','','','.p-catalog-product'),(173285,'deals-mobile','.p-catalog-product .prev-product .pn-image','padding-right','2','3','','.p-catalog-product'),(173286,'deals-mobile','.p-catalog-product .pn-direction','padding-right','4','','','.p-catalog-product'),(173287,'deals-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-right','10','','','.p-quick-order-index'),(173288,'deals-mobile','.p-quick-order-index .all-scroll-div','padding-right','0','','','.p-quick-order-index'),(173289,'deals-mobile','.p-quick-order-index .bottom','padding-right','0','','','.p-quick-order-index'),(173290,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.p-quick-order-index'),(173291,'deals-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-right','10','','','.p-quick-order-index'),(173292,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.p-quick-order-index'),(173293,'deals-mobile','.p-quick-order-index ul.token-input-list','padding-right','0','','','.p-quick-order-index'),(173294,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(173295,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(173296,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(173297,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(173298,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(173299,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(173300,'deals-mobile','.w-account-address-book .item','padding-right','10','','','.w-account-address-book'),(173301,'deals-mobile','.w-account-address-book .btn-del','padding-right','7','','','.w-account-address-book'),(173302,'deals-mobile','.w-account-address-book .wrap','padding-right','15','','','.w-account-address-book'),(173303,'deals-mobile','.w-account-address-book .btn-edit','padding-right','7','','','.w-account-address-book'),(173304,'deals-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-right','20','','','.w-account-addresses-list'),(173305,'deals-mobile','.w-account-personal-catalog .list-switcher','padding-right','0','','','.w-account-personal-catalog'),(173306,'deals-mobile','.w-account-personal-catalog .list-switcher a','padding-right','6','','','.w-account-personal-catalog'),(173307,'deals-mobile','.w-account-subscription .subscription-variant','padding-right','10','','','.w-account-subscription'),(173308,'deals-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-right','0','','','.w-blog-widget-most-popular-posts'),(173309,'deals-mobile','.w-blog-widget-post-listing .post','padding-right','33','','','.w-blog-widget-post-listing'),(173310,'deals-mobile','.w-blog-widget-post-listing .post_name','padding-right','0','','','.w-blog-widget-post-listing'),(173311,'deals-mobile','.w-blog-widget-post-listing .post_view','padding-right','15','','','.w-blog-widget-post-listing'),(173312,'deals-mobile','.w-blog-widget-post-listing .post','padding-right','15','','','.w-blog-widget-post-listing'),(173313,'deals-mobile','.w-blog-widget-post-title h1','padding-right','0','','','.w-blog-widget-post-title'),(173314,'deals-mobile','.w-blog-widget-post-title ','padding-right','0','','','.w-blog-widget-post-title'),(173315,'deals-mobile','.w-blog-widget-related-posts ','padding-right','15','','','.w-blog-widget-related-posts'),(173316,'deals-mobile','.w-blog-widget-related-posts .post','padding-right','15','','','.w-blog-widget-related-posts'),(173317,'deals-mobile','.w-blog-widget-related-posts .post_content a','padding-right','20','','','.w-blog-widget-related-posts'),(173318,'deals-mobile','.w-blog-widget-related-posts ','padding-right','0','','','.w-blog-widget-related-posts'),(173319,'deals-mobile','.w-blog-widget-related-posts-by-category .post','padding-right','15','','','.w-blog-widget-related-posts-by-category'),(173320,'deals-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-right','20','','','.w-blog-widget-related-posts-by-category'),(173321,'deals-mobile','.w-blog-widget-tag-cloud a','padding-right','13','','','.w-blog-widget-tag-cloud'),(173322,'deals-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-right','0','','','.w-cart-cart-tabs'),(173323,'deals-mobile','.w-cart-compare .attributes-label','padding-right','10','','','.w-cart-compare'),(173324,'deals-mobile','.w-cart-compare .price-label','padding-right','10','','','.w-cart-compare'),(173325,'deals-mobile','.w-cart-compare .price-cell','padding-right','20','','','.w-cart-compare'),(173326,'deals-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-right','0','','','.w-cart-compare'),(173327,'deals-mobile','.w-cart-compare .delete-cart','padding-right','10','','','.w-cart-compare'),(173328,'deals-mobile','.w-cart-compare .attributes-cell','padding-right','20','','','.w-cart-compare'),(173329,'deals-mobile','.w-cart-compare .cart-cell','padding-right','7','','','.w-cart-compare'),(173330,'deals-mobile','.w-cart-compare .dropdown li','padding-right','10','','','.w-cart-compare'),(173331,'deals-mobile','.w-cart-compare .product-label','padding-right','10','','','.w-cart-compare'),(173332,'deals-mobile','.w-cart-compare .product','padding-right','15','','','.w-cart-compare'),(173333,'deals-mobile','.w-cart-compare .atr-col','padding-right','30','','','.w-cart-compare'),(173334,'deals-mobile','.w-cart-up-sell .w-list-type-1','padding-right','0','','','.w-cart-up-sell'),(173335,'deals-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-right','21','','','.w-cart-up-sell'),(173336,'deals-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-right','20','1','','.w-cart-up-sell'),(173337,'deals-mobile','.w-catalog-additional-images li','padding-right','10','','','.w-catalog-additional-images'),(173338,'deals-mobile','.w-catalog-additional-images ul','padding-right','0','','','.w-catalog-additional-images'),(173339,'deals-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-right','5','','','.w-catalog-b2b-add-button'),(173340,'deals-mobile','.w-catalog-compare td','padding-right','20','','','.w-catalog-compare'),(173341,'deals-mobile','.w-catalog-compare .image','padding-right','10','','','.w-catalog-compare'),(173342,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','padding-right','5','2','','.w-catalog-compare'),(173343,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','padding-right','5','','','.w-catalog-compare'),(173344,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-right','0','','','.w-catalog-compare'),(173345,'deals-mobile','.w-catalog-paging .paging-item','padding-right','2','','','.w-catalog-paging'),(173346,'deals-mobile','.w-catalog-paging .next','padding-right','5','','','.w-catalog-paging'),(173347,'deals-mobile','.w-catalog-paging .prev','padding-right','5','','','.w-catalog-paging'),(173348,'deals-mobile','.w-catalog-paging ','padding-right','5','2','','.w-catalog-paging'),(173349,'deals-mobile','.w-catalog-paging .next-pages','padding-right','5','','','.w-catalog-paging'),(173350,'deals-mobile','.w-catalog-paging .prev-pages','padding-right','5','','','.w-catalog-paging'),(173351,'deals-mobile','.w-catalog-paging .page-number','padding-right','5','','','.w-catalog-paging'),(173352,'deals-mobile','.w-checkout-billing-address .same-address','padding-right','10','','','.w-checkout-billing-address'),(173353,'deals-mobile','.w-checkout-billing-address .edit-ab','padding-right','0','','','.w-checkout-billing-address'),(173354,'deals-mobile','.w-checkout-billing-address .addresses .address-item label','padding-right','10','','','.w-checkout-billing-address'),(173355,'deals-mobile','.w-checkout-create-account .create-account','padding-right','0','','','.w-checkout-create-account'),(173356,'deals-mobile','.w-checkout-gdpr .privacy-row','padding-right','0','','','.w-checkout-gdpr'),(173357,'deals-mobile','.w-checkout-gdpr .terms-login','padding-right','0','','','.w-checkout-gdpr'),(173358,'deals-mobile','.w-checkout-shipping .sub-item','padding-right','0','','','.w-checkout-shipping'),(173359,'deals-mobile','.w-checkout-shipping-address .edit-ab','padding-right','0','','','.w-checkout-shipping-address'),(173360,'deals-mobile','.w-checkout-shipping-address .addresses .address-item label','padding-right','10','','','.w-checkout-shipping-address'),(173361,'deals-mobile','.w-checkout-shipping-choice span','padding-right','0','','','.w-checkout-shipping-choice'),(173362,'deals-mobile','.w-checkout-shipping-choice span','padding-right','10','','','.w-checkout-shipping-choice'),(173363,'deals-mobile','.w-checkout-terms .required-message','padding-right','10','','','.w-checkout-terms'),(173364,'deals-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-right','0','','','.w-communication-new-topic'),(173365,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-right','5','','','.w-communication-new-topic'),(173366,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-right','10','','','.w-communication-new-topic'),(173367,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-right','0','','','.w-communication-new-topic'),(173368,'deals-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-right','10','','','.w-communication-new-topic'),(173369,'deals-mobile','.w-communication-post .communication-post-author','padding-right','0','','','.w-communication-post'),(173370,'deals-mobile','.w-delivery-day .left-count','padding-right','5','','','.w-delivery-day'),(173371,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-right','10','','','.w-image-maps'),(173372,'deals-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-right','0','','','.w-multi-cart-actions'),(173373,'deals-mobile','.w-personal-gift-status-bar .end-label','padding-right','30','','','.w-personal-gift-status-bar'),(173374,'deals-mobile','.w-personal-gift-status-bar .start-label','padding-right','5','','','.w-personal-gift-status-bar'),(173375,'deals-mobile','.w-personal-gift-status-bar .timeline','padding-right','10','','','.w-personal-gift-status-bar'),(173376,'deals-mobile','.w-personal-gift-status-bar .end-date','padding-right','5','3','','.w-personal-gift-status-bar'),(173377,'deals-mobile','.w-personal-gift-status-bar .inform','padding-right','5','4','','.w-personal-gift-status-bar'),(173378,'deals-mobile','.w-product-available-in-warehouses .warehouse-item','padding-right','20','','','.w-product-available-in-warehouses'),(173379,'deals-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(173380,'deals-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(173381,'deals-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(173382,'deals-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(173383,'deals-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(173384,'deals-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(173385,'deals-mobile','.w-product-customers-activity .customers-activity','padding-right','20','','','.w-product-customers-activity'),(173386,'deals-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(173387,'deals-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(173388,'deals-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(173389,'deals-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(173390,'deals-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(173391,'deals-mobile','.w-product-images-additional .images','padding-right','0','','','.w-product-images-additional'),(173392,'deals-mobile','.w-promotions .promo-cart-discount .master .item','padding-right','20','','','.w-promotions'),(173393,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-right','20','','','.w-promotions'),(173394,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-right','20','','','.w-promotions'),(173395,'deals-mobile','.w-promotions .promo-item','padding-right','40','','','.w-promotions'),(173396,'deals-mobile','.w-promotions .promo-date > div','padding-right','50','','','.w-promotions'),(173397,'deals-mobile','.w-promotions .promo-cart-discount .slave .item','padding-right','20','','','.w-promotions'),(173398,'deals-mobile','.w-promotions .promo-salemaker .discount','padding-right','20','','','.w-promotions'),(173399,'deals-mobile','.w-promotions .promo-salemaker .item','padding-right','20','','','.w-promotions'),(173400,'deals-mobile','.w-promotions .promo-salemaker .promo-categories','padding-right','12','','','.w-promotions'),(173401,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','padding-right','20','','','.w-promotions'),(173402,'deals-mobile','.w-promotions .heading','padding-right','10','','','.w-promotions'),(173403,'deals-mobile','.w-promotions .nextdiscount .promo-for-each','padding-right','20','','','.w-promotions'),(173404,'deals-mobile','.w-promotions .prom-multi-discount .promo-product','padding-right','20','','','.w-promotions'),(173405,'deals-mobile','.w-promotions .nextdiscount .content > div','padding-right','10','','','.w-promotions'),(173406,'deals-mobile','.w-promotions .nextdiscount .item-holder .image','padding-right','10','','','.w-promotions'),(173407,'deals-mobile','.w-promotions .master','padding-right','15','','','.w-promotions'),(173408,'deals-mobile','.w-reviews-content .item','padding-right','0','','','.w-reviews-content'),(173409,'deals-mobile','.w-reviews-content .author','padding-right','20','','','.w-reviews-content'),(173410,'deals-mobile','.w-reviews-content .review','padding-right','20','','','.w-reviews-content'),(173411,'deals-mobile','.w-reviews-content .product-image','padding-right','10','','','.w-reviews-content'),(173412,'deals-mobile','.w-sitemap-delivery-location > ul','padding-right','0','','','.w-sitemap-delivery-location'),(173413,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-right','0','','','.w-sitemap-delivery-location'),(173414,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul > li','padding-right','20','','','.w-sitemap-delivery-location'),(173415,'deals-mobile','.w-top-text .top-text','padding-right','10','','','.w-top-text'),(173416,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-right','17','','','.w-wedding-registry-widgets-photos'),(173417,'deals-mobile','.b-quantity .qty-box input[type=\'text\']','padding-right','3','','','.b-quantity'),(173418,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right_important','important','','','.b-data-table'),(173419,'deals-mobile','.b-data-table table.dataTable thead td','padding-right_important','important','','','.b-data-table'),(173420,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right_important','important','','','.b-data-table'),(173421,'deals-mobile','.b-data-table table.dataTable tbody td','padding-right_important','important','','','.b-data-table'),(173422,'deals-mobile','.batchPr .w-batch-products','padding-right_important','important','','','.batchPr'),(173423,'deals-mobile','.w-list-type-2 .compare-box-item','padding-top','7','','','.w-list-type-2'),(173424,'deals-mobile','.w-list-type-1_3 .compare-box-item','padding-top','7','','','.w-list-type-1_3'),(173425,'deals-mobile','.w-list-type-1_3 .item','padding-top','20','1','','.w-list-type-1_3'),(173426,'deals-mobile','.w-list-type-1_3 .item','padding-top','20','','','.w-list-type-1_3'),(173427,'deals-mobile','.w-list-type-2 .item','padding-top','21','','','.w-list-type-2'),(173428,'deals-mobile','.w-list-type-3.products-listing','padding-top','20','','','.w-list-type-3'),(173429,'deals-mobile','.w-list-type-2.products-listing','padding-top','20','','','.w-list-type-2'),(173430,'deals-mobile','.w-list-type-2_2 .compare-box-item','padding-top','7','','','.w-list-type-2_2'),(173431,'deals-mobile','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(173432,'deals-mobile','.w-list-type-2_2.products-listing','padding-top','20','','','.w-list-type-2_2'),(173433,'deals-mobile','.w-list-type-1_3 .buy-button .btn-buy, .w-list-type-1_3 .buy-button .btn-cart','padding-top','0','','','.w-list-type-1_3'),(173434,'deals-mobile','.w-menu .hided.menu ul li','padding-top','0','','','.w-menu'),(173435,'deals-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-top','0','','','.w-menu'),(173436,'deals-mobile','.w-catalog-listing-look .listing-look-title','padding-top','4','','','.w-catalog-listing-look'),(173437,'deals-mobile','.w-menu-horizontal > ul > li > ul > li','padding-top','2','','','.w-menu-horizontal'),(173438,'deals-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','6','','','.w-menu-horizontal'),(173439,'deals-mobile','.w-menu-big ul','padding-top','0','','','.w-menu-big'),(173440,'deals-mobile','.w-menu-slider ul, .w-menu-slider li','padding-top','0','','','.w-menu-slider'),(173441,'deals-mobile','.w-menu-slider > ul > li > ul > li','padding-top','5','','','.w-menu-slider'),(173442,'deals-mobile','.w-menu-slider > ul > li > a','padding-top','5','','','.w-menu-slider'),(173443,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-top','0','','','.b-slick'),(173444,'deals-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','6','','','.w-menu-style-1'),(173445,'deals-mobile','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(173446,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(173447,'deals-mobile','.b-bottom .popup-simple','padding-top','20','','','.b-bottom'),(173448,'deals-mobile','.b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .buttons','padding-top','5','','','.b-cookie-notice'),(173449,'deals-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.bottom .text','padding-top','10','','','.b-cookie-notice'),(173450,'deals-mobile','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(173451,'deals-mobile','.w-product-wedding-registry-button .btn','padding-top','0','','','.w-product-wedding-registry-button'),(173452,'deals-mobile','.w-product-sale-ends .left-text-right','padding-top','24','','','.w-product-sale-ends'),(173453,'deals-mobile','.w-product-sale-ends .left-text-left','padding-top','24','','','.w-product-sale-ends'),(173454,'deals-mobile','.w-filters .ui-slider-range','padding-top','0','','','.w-filters'),(173455,'deals-mobile','.w-currencies .select-link','padding-top','5','','','.w-currencies'),(173456,'deals-mobile','.w-filters .fsl_handle','padding-top','20','','','.w-filters'),(173457,'deals-mobile','.w-categories .name','padding-top','3','','','.w-categories'),(173458,'deals-mobile','.w-currencies .current','padding-top','4','','','.w-currencies'),(173459,'deals-mobile','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(173460,'deals-mobile','.w-currencies .currencies-title','padding-top','3','','','.w-currencies'),(173461,'deals-mobile','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(173462,'deals-mobile','.w-top-categories .item','padding-top','5','863','','.w-top-categories'),(173463,'deals-mobile','.p-account-history-info .contentColumn','padding-top','10','','','.p-account-history-info'),(173464,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','padding-top','5','','','.p-account-history-info'),(173465,'deals-mobile','.p-account-history-info .historyTotal td','padding-top','2','','','.p-account-history-info'),(173466,'deals-mobile','.p-account-index .account_info li','padding-top','0','','','.p-account-index'),(173467,'deals-mobile','.p-account-history-info .history_info > div + div','padding-top','0','','','.p-account-history-info'),(173468,'deals-mobile','.p-account-index .account_info','padding-top','0','','','.p-account-index'),(173469,'deals-mobile','.p-account-index .account_block','padding-top','10','','','.p-account-index'),(173470,'deals-mobile','.p-account-index .account_page','padding-top','10','','','.p-account-index'),(173471,'deals-mobile','.p-account-index .orders-table th','padding-top','2','','','.p-account-index'),(173472,'deals-mobile','.p-account-index .date_title','padding-top','5','','','.p-account-index'),(173473,'deals-mobile','.p-account-index .badc_bottom','padding-top','0','','','.p-account-index'),(173474,'deals-mobile','.p-account-index .orders-table td, .p-account-index .order-info td, .p-account-index .order_history_table td','padding-top','10','','','.p-account-index'),(173475,'deals-mobile','.p-account-index .topAccount','padding-top','24','','','.p-account-index'),(173476,'deals-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-top','10','','','.p-account-subscription-historyinfo'),(173477,'deals-mobile','.b-bottom .popup-buttons','padding-top','15','','','.b-bottom'),(173478,'deals-mobile','.b-price-box .checkout-index .price-box, .b-price-box .checkout-confirmation .price-box','padding-top','10','','','.b-price-box'),(173479,'deals-mobile','.w-tabs .accordion-heading','padding-top','9','863','','.w-tabs'),(173480,'deals-mobile','.w-product-quantity .product-quantity-label','padding-top','4','','','.w-product-quantity'),(173481,'deals-mobile','.b-compare .compare_pagination','padding-top','10','','','.b-compare'),(173482,'deals-mobile','.p-checkout-success .page-success .text-1','padding-top','5','863','','.p-checkout-success'),(173483,'deals-mobile','.w-search .button-search','padding-top','6','','','.w-search'),(173484,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-top','20','','','.b-multi-page-checkout'),(173485,'deals-mobile','.w-search .name','padding-top','0','','','.w-search'),(173486,'deals-mobile','.w-sale .holder-2','padding-top','20','','','.w-sale'),(173487,'deals-mobile','.w-search .items-title','padding-top','10','','','.w-search'),(173488,'deals-mobile','.w-socials > li','padding-top','15','','','.w-socials'),(173489,'deals-mobile','.w-search .item','padding-top','10','','','.w-search'),(173490,'deals-mobile','.b-info-popup .info-popup div','padding-top','10','','','.b-info-popup'),(173491,'deals-mobile','.b-multi-page-checkout .multi-page-checkout','padding-top','20','','','.b-multi-page-checkout'),(173492,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-top','0','','','.b-multi-page-checkout'),(173493,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-top','8','','','.b-multi-page-checkout'),(173494,'deals-mobile','.w-search .suggest','padding-top','0','','','.w-search'),(173495,'deals-mobile','.w-promo-code .holder','padding-top','20','893','','.w-promo-code'),(173496,'deals-mobile','.w-search .search-input','padding-top','5','','','.w-search'),(173497,'deals-mobile','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(173498,'deals-mobile','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(173499,'deals-mobile','.p-wedding-registry-manage .w-list-type-1 .qty-input','padding-top','5','','','.p-wedding-registry-manage'),(173500,'deals-mobile','.p-wedding-registry-manage a.remove-btn','padding-top','5','','','.p-wedding-registry-manage'),(173501,'deals-mobile','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(173502,'deals-mobile','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(173503,'deals-mobile','.p-account-history-info .popup-tracking-number','padding-top','10','','','.p-account-history-info'),(173504,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','padding-top','5','','','.p-account-order-pay'),(173505,'deals-mobile','.p-account-order-pay .contentColumn','padding-top','10','','','.p-account-order-pay'),(173506,'deals-mobile','.p-account-order-pay .historyTotal td','padding-top','2','','','.p-account-order-pay'),(173507,'deals-mobile','.p-account-order-pay .history_attr','padding-top','5','','','.p-account-order-pay'),(173508,'deals-mobile','.p-account-order-pay .history_info > div + div','padding-top','0','','','.p-account-order-pay'),(173509,'deals-mobile','.w-filters .head-filter-widget','padding-top','0','890','','.w-filters'),(173510,'deals-mobile','.p-account-order-pay .history_info > div','padding-top','0','864','','.p-account-order-pay'),(173511,'deals-mobile','.w-product-configurator .pc_item','padding-top','10','872','','.w-product-configurator'),(173512,'deals-mobile','.p-account-order-pay .history_info > div + div','padding-top','0','864','','.p-account-order-pay'),(173513,'deals-mobile','.w-product-configurator .pc_attr','padding-top','5','863','','.w-product-configurator'),(173514,'deals-mobile','.testimonials .heading-3','padding-top','7','','',''),(173515,'deals-mobile','.testimonials .reviews-list .name','padding-top','5','','',''),(173516,'deals-mobile','.testimonials .reviews-list .answer .name','padding-top','10','','',''),(173517,'deals-mobile','.testimonials .name','padding-top','5','','',''),(173518,'deals-mobile','.testimonials .review','padding-top','10','','',''),(173519,'deals-mobile','.p-account-history .orders-table td, .p-account-history .order-info td, .p-account-history .order_history_table td','padding-top','10','','','.p-account-history'),(173520,'deals-mobile','.b-bottom .confirm-popup .confirm-text','padding-top','40','','','.b-bottom'),(173521,'deals-mobile','.p-account-history .orders-table th','padding-top','2','','','.p-account-history'),(173522,'deals-mobile','.p-account-history .view_link','padding-top','0','','','.p-account-history'),(173523,'deals-mobile','.p-account-history .orders-table .td-alignright','padding-top','5','890','','.p-account-history'),(173524,'deals-mobile','.p-account-history .orders-table td','padding-top','5','890','','.p-account-history'),(173525,'deals-mobile','.btn','padding-top','8','','',''),(173526,'deals-mobile','.p-account-index .orders-table .td-alignright','padding-top','5','890','','.p-account-index'),(173527,'deals-mobile','.p-account-index .orders-table td','padding-top','5','890','','.p-account-index'),(173528,'deals-mobile','.btn-1','padding-top','5','','',''),(173529,'deals-mobile','.btn-2','padding-top','14','','',''),(173530,'deals-mobile','.p-blog-index .comment-metadata','padding-top','4','','','.p-blog-index'),(173531,'deals-mobile','.btn-3','padding-top','12','','',''),(173532,'deals-mobile','.no-found','padding-top','20','','',''),(173533,'deals-mobile','.w-list-type-2_2 .buttons','padding-top','3','','','.w-list-type-2_2'),(173534,'deals-mobile','.w-list-type-2_2 .item','padding-top','20','','','.w-list-type-2_2'),(173535,'deals-mobile','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(173536,'deals-mobile','.w-product-personal-catalog-button .btn','padding-top','0','','','.w-product-personal-catalog-button'),(173537,'deals-mobile','.b-fancybox .fancybox-error','padding-top','15','','','.b-fancybox'),(173538,'deals-mobile','.w-menu-horizontal ul','padding-top','0','','','.w-menu-horizontal'),(173539,'deals-mobile','.w-chat .w-chat-box','padding-top','2','','','.w-chat'),(173540,'deals-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-top','0','','','.w-delivery-location-top-location-list'),(173541,'deals-mobile','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(173542,'deals-mobile','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(173543,'deals-mobile','.b-bottom .alert-message','padding-top','20','','','.b-bottom'),(173544,'deals-mobile','.p-wedding-registry-index .main-content','padding-top','70','','','.p-wedding-registry-index'),(173545,'deals-mobile','.p-wedding-registry-index .search-list','padding-top','20','','','.p-wedding-registry-index'),(173546,'deals-mobile','.p-wedding-registry-index .middle-box','padding-top','30','','','.p-wedding-registry-index'),(173547,'deals-mobile','.p-wedding-registry-index .main-button','padding-top','0','4','','.p-wedding-registry-index'),(173548,'deals-mobile','.p-wedding-registry-index .main-button','padding-top','0','3','','.p-wedding-registry-index'),(173549,'deals-mobile','.b-form .form-buttons','padding-top','17','','','.b-form'),(173550,'deals-mobile','.p-wedding-registry-manage .wedding-image','padding-top','15','','','.p-wedding-registry-manage'),(173551,'deals-mobile','.p-wedding-registry-manage .links','padding-top','10','','','.p-wedding-registry-manage'),(173552,'deals-mobile','.p-wedding-registry-manage .links a','padding-top','0','','','.p-wedding-registry-manage'),(173553,'deals-mobile','.p-wedding-registry-share .middle-form > input','padding-top','0','','','.p-wedding-registry-share'),(173554,'deals-mobile','.p-wedding-registry-share .wedding-image','padding-top','15','','','.p-wedding-registry-share'),(173555,'deals-mobile','.b-table .table td','padding-top','15','','','.b-table'),(173556,'deals-mobile','.b-table .table .headings td','padding-top','5','','','.b-table'),(173557,'deals-mobile','.p-account-address-book .address_book, .p-account-address-book .account_history_info','padding-top','10','','','.p-account-address-book'),(173558,'deals-mobile','.p-account-history .order_history_table th','padding-top','10','','','.p-account-history'),(173559,'deals-mobile','.header2 .ccc','padding-top','10','','',''),(173560,'deals-mobile','.p-account-address-book .topButtons','padding-top','0','','','.p-account-address-book'),(173561,'deals-mobile','.p-account-address-book .btn-edit','padding-top','0','4','','.p-account-address-book'),(173562,'deals-mobile','.p-account-address-book .buttonBox','padding-top','15','','','.p-account-address-book'),(173563,'deals-mobile','.p-account-address-book .rightMes ul','padding-top','22','','','.p-account-address-book'),(173564,'deals-mobile','.p-account-address-book .address_book h1','padding-top','0','','','.p-account-address-book'),(173565,'deals-mobile','.p-account-address-book .address_book','padding-top','0','','','.p-account-address-book'),(173566,'deals-mobile','.p-account-address-book .address_book h2','padding-top','15','','','.p-account-address-book'),(173567,'deals-mobile','.b-bottom .popup-heading','padding-top','10','','','.b-bottom'),(173568,'deals-mobile','.b-compare .col-gender','padding-top','0','','','.b-compare'),(173569,'deals-mobile','.b-compare .col-two label','padding-top','5','','','.b-compare'),(173570,'deals-mobile','.b-compare .column_wrapper','padding-top','0','','','.b-compare'),(173571,'deals-mobile','.b-compare .compare-box-item','padding-top','10','','','.b-compare'),(173572,'deals-mobile','.b-compare .compare-head','padding-top','10','','','.b-compare'),(173573,'deals-mobile','.w-quote .cart-box-link','padding-top','5','872','','.w-quote'),(173574,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-top','8','876','','.w-list-type-1'),(173575,'deals-mobile','.w-tabs .accordion-heading','padding-top','6','','','.w-tabs'),(173576,'deals-mobile','.w-languages .current','padding-top','12','872','','.w-languages'),(173577,'deals-mobile','.w-languages .lang-link','padding-top','13','872','','.w-languages'),(173578,'deals-mobile','.w-currencies .current','padding-top','13','872','','.w-currencies'),(173579,'deals-mobile','.w-currencies .select-link','padding-top','12','872','','.w-currencies'),(173580,'deals-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','12','872','','.w-menu-horizontal'),(173581,'deals-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','12','876','','.w-menu-style-1'),(173582,'deals-mobile','.b-fancybox .fancybox-title-inside-wrap','padding-top','10','','','.b-fancybox'),(173583,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-top','12','876','','.w-menu-style-1'),(173584,'deals-mobile','.b-bottom .footerTitle','padding-top','9','863','','.b-bottom'),(173585,'deals-mobile','.p-account-history-info .history_info > div + div','padding-top','0','864','','.p-account-history-info'),(173586,'deals-mobile','.p-account-history-info .history_info > div','padding-top','0','864','','.p-account-history-info'),(173587,'deals-mobile','.w-top-categories .name','padding-top','3','','','.w-top-categories'),(173588,'deals-mobile','.w-cart .cart-total','padding-top','10','','','.w-cart'),(173589,'deals-mobile','.w-breadcrumb .breadcrumb-li','padding-top','0','','','.w-breadcrumb'),(173590,'deals-mobile','.w-cart .cart-content','padding-top','15','','','.w-cart'),(173591,'deals-mobile','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(173592,'deals-mobile','.w-list-type-1_2 .compare-box-item','padding-top','7','','','.w-list-type-1_2'),(173593,'deals-mobile','.w-product-reviews .reviews-list .name','padding-top','5','','','.w-product-reviews'),(173594,'deals-mobile','.b-form .center-buttons','padding-top','20','','','.b-form'),(173595,'deals-mobile','.w-bestsellers .heading-3','padding-top','7','','','.w-bestsellers'),(173596,'deals-mobile','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(173597,'deals-mobile','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(173598,'deals-mobile','.w-top-categories .image','padding-top','0','','','.w-top-categories'),(173599,'deals-mobile','.w-account a.my-acc-link','padding-top','5','','','.w-account'),(173600,'deals-mobile','.p-shopping-cart-index .cart-popup .cart-page, .p-shopping-cart-index .cart-popup .wishlist-page','padding-top','0','','','.p-shopping-cart-index'),(173601,'deals-mobile','.p-account-trade-form .widget','padding-top','10','','','.p-account-trade-form'),(173602,'deals-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-top','0','','','.p-blog-index'),(173603,'deals-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-top','5','','','.p-blog-index'),(173604,'deals-mobile','.p-blog-index .nav-links','padding-top','20','','','.p-blog-index'),(173605,'deals-mobile','.p-blog-index .wp-widget li','padding-top','0','','','.p-blog-index'),(173606,'deals-mobile','.p-checkout-index .shipping-method .row','padding-top','5','','','.p-checkout-index'),(173607,'deals-mobile','.p-checkout-index .shipping-method .item','padding-top','10','','','.p-checkout-index'),(173608,'deals-mobile','.p-blog-index .wp-widget ul','padding-top','0','','','.p-blog-index'),(173609,'deals-mobile','.p-quote-cart-index .cart-page .empty','padding-top','100','','','.p-quote-cart-index'),(173610,'deals-mobile','.p-quote-cart-index .cart-popup .cart-page, .p-quote-cart-index .cart-popup .wishlist-page','padding-top','0','','','.p-quote-cart-index'),(173611,'deals-mobile','.p-reviews-info .review-info-text','padding-top','10','','','.p-reviews-info'),(173612,'deals-mobile','.p-reviews-info .review-info-content','padding-top','20','','','.p-reviews-info'),(173613,'deals-mobile','.p-reviews-info .review-info-image','padding-top','20','','','.p-reviews-info'),(173614,'deals-mobile','.p-checkout-index .shipping-method .title','padding-top','0','','','.p-checkout-index'),(173615,'deals-mobile','.p-reviews-info .reviews-info .buttons','padding-top','0','','','.p-reviews-info'),(173616,'deals-mobile','.p-shopping-cart-index .cart-page .empty','padding-top','100','','','.p-shopping-cart-index'),(173617,'deals-mobile','.p-account-index .topAccount > li > div','padding-top','0','863','','.p-account-index'),(173618,'deals-mobile','.w-product-images .images','padding-top','10','893','','.w-product-images'),(173619,'deals-mobile','.p-account-index .topAccount > li','padding-top','0','863','','.p-account-index'),(173620,'deals-mobile','.p-account-index .account_info li','padding-top','0','863','','.p-account-index'),(173621,'deals-mobile','.b-slick .slick-vertical button.slick-next','padding-top','0','3','','.b-slick'),(173622,'deals-mobile','.b-slick .slick-vertical button.slick-prev','padding-top','0','3','','.b-slick'),(173623,'deals-mobile','.p-account-trade-form .trade-form-area','padding-top','20','','','.p-account-trade-form'),(173624,'deals-mobile','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(173625,'deals-mobile','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(173626,'deals-mobile','.b-info .info ul','padding-top','0','','','.b-info'),(173627,'deals-mobile','.p-account-index .topAccount > li','padding-top','0','','','.p-account-index'),(173628,'deals-mobile','.p-account-index th','padding-top','10','','','.p-account-index'),(173629,'deals-mobile','.p-account-index .view_link','padding-top','0','','','.p-account-index'),(173630,'deals-mobile','.w-list-type-2 .buy-button .btn-buy, .w-list-type-2 .buy-button .btn-cart','padding-top','0','','','.w-list-type-2'),(173631,'deals-mobile','.w-list-type-2_2 .buy-button .btn-buy, .w-list-type-2_2 .buy-button .btn-cart','padding-top','0','','','.w-list-type-2_2'),(173632,'deals-mobile','.w-list-type-1 ','padding-top','20','','','.w-list-type-1'),(173633,'deals-mobile','.w-list-type-1 .item','padding-top','0','','','.w-list-type-1'),(173634,'deals-mobile','.w-list-type-1_2.products-listing','padding-top','20','','','.w-list-type-1_2'),(173635,'deals-mobile','.w-list-type-2 .item','padding-top','20','1','','.w-list-type-2'),(173636,'deals-mobile','.w-list-type-1 .compare-box-item','padding-top','7','','','.w-list-type-1'),(173637,'deals-mobile','.w-list-type-1 .buy-button .btn-buy, .w-list-type-1 .buy-button .btn-cart','padding-top','0','','','.w-list-type-1'),(173638,'deals-mobile','.w-languages .lang-link','padding-top','5','','','.w-languages'),(173639,'deals-mobile','.w-languages .current','padding-top','3','','','.w-languages'),(173640,'deals-mobile','.w-filters .head-filter-widget','padding-top','0','','','.w-filters'),(173641,'deals-mobile','.w-filters .filter-ul-content','padding-top','0','','','.w-filters'),(173642,'deals-mobile','.b-fancybox .fancybox-title-over-wrap','padding-top','10','','','.b-fancybox'),(173643,'deals-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-top','0','','','.b-fancybox'),(173644,'deals-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-top','0','','','.b-fancybox'),(173645,'deals-mobile','.w-categories .image','padding-top','0','','','.w-categories'),(173646,'deals-mobile','.w-categories .item','padding-top','5','','','.w-categories'),(173647,'deals-mobile','.w-list-type-1_2 .buy-button .btn-buy, .w-list-type-1_2 .buy-button .btn-cart','padding-top','0','','','.w-list-type-1_2'),(173648,'deals-mobile','.w-cart .cart-box-link','padding-top','5','','','.w-cart'),(173649,'deals-mobile','.w-cart a.item','padding-top','5','','','.w-cart'),(173650,'deals-mobile','.b-compare .popupCompare .pop-up-content','padding-top','0','','','.b-compare'),(173651,'deals-mobile','.b-bottom .popup-content','padding-top','15','','','.b-bottom'),(173652,'deals-mobile','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(173653,'deals-mobile','.w-product-sale-ends .left-count','padding-top','5','','','.w-product-sale-ends'),(173654,'deals-mobile','.w-sale .holder-1','padding-top','20','','','.w-sale'),(173655,'deals-mobile','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(173656,'deals-mobile','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(173657,'deals-mobile','.w-product-reviews .reviews-list .review','padding-top','10','','','.w-product-reviews'),(173658,'deals-mobile','.w-quote .cart-box-link','padding-top','5','','','.w-quote'),(173659,'deals-mobile','.w-sale .left-count','padding-top','5','','','.w-sale'),(173660,'deals-mobile','.w-reviews .review','padding-top','10','','','.w-reviews'),(173661,'deals-mobile','.w-reviews .heading-3','padding-top','7','','','.w-reviews'),(173662,'deals-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(173663,'deals-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(173664,'deals-mobile','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(173665,'deals-mobile','.w-product-properties li','padding-top','5','','','.w-product-properties'),(173666,'deals-mobile','.w-product-configurator .pc_item','padding-top','10','','','.w-product-configurator'),(173667,'deals-mobile','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(173668,'deals-mobile','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(173669,'deals-mobile','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(173670,'deals-mobile','.w-menu-style-1 ul','padding-top','0','','','.w-menu-style-1'),(173671,'deals-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(173672,'deals-mobile','.p-checkout-success .page-success .text-1','padding-top','120','','','.p-checkout-success'),(173673,'deals-mobile','.w-sale .left-text-left','padding-top','24','','','.w-sale'),(173674,'deals-mobile','.w-sale .left-text-right','padding-top','24','','','.w-sale'),(173675,'deals-mobile','.w-sale .text','padding-top','10','','','.w-sale'),(173676,'deals-mobile','.w-categories .categories h2','padding-top','0','','','.w-categories'),(173677,'deals-mobile','.w-top-categories .categories h2','padding-top','0','','','.w-top-categories'),(173678,'deals-mobile','.w-banner .carousel-text > span','padding-top','20','','','.w-banner'),(173679,'deals-mobile','.b-slick .slick-list','padding-top','0','','','.b-slick'),(173680,'deals-mobile','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(173681,'deals-mobile','.w-tabs .tab-li','padding-top','0','','','.w-tabs'),(173682,'deals-mobile','.w-tabs .tab-a','padding-top','6','','','.w-tabs'),(173683,'deals-mobile','.w-cart .buttons','padding-top','15','','','.w-cart'),(173684,'deals-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-top','2','','','.w-menu-horizontal'),(173685,'deals-mobile','.w-account ul, .w-account li','padding-top','0','','','.w-account'),(173686,'deals-mobile','h1','padding-top','20','','',''),(173687,'deals-mobile','.p-account-history-info .history_attr','padding-top','5','','','.p-account-history-info'),(173688,'deals-mobile','.b-form .middle-form','padding-top','20','','','.b-form'),(173689,'deals-mobile','.w-categories .item','padding-top','5','863','','.w-categories'),(173690,'deals-mobile','.w-cart-give-away .ga_column','padding-top','15','','','.w-cart-give-away'),(173691,'deals-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-top','4','','','.b-compare'),(173692,'deals-mobile','.w-search .search form','padding-top','5','','','.w-search'),(173693,'deals-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], select','padding-top','5','','',''),(173694,'deals-mobile','.w-list-type-2 .buttons','padding-top','3','','','.w-list-type-2'),(173695,'deals-mobile','.b-autocomplete .ui-autocomplete','padding-top','0','','','.b-autocomplete'),(173696,'deals-mobile','textarea','padding-top','5','','',''),(173697,'deals-mobile','.heading-3 .right-text, h3 .right-text','padding-top','3','','',''),(173698,'deals-mobile','.b-autocomplete .ui-autocomplete li','padding-top','3','','','.b-autocomplete'),(173699,'deals-mobile','.w-list-type-1_3 .buttons','padding-top','3','','','.w-list-type-1_3'),(173700,'deals-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-top','0','','','.b-bottom'),(173701,'deals-mobile','.w-list-type-1_2 .item','padding-top','20','','','.w-list-type-1_2'),(173702,'deals-mobile','.w-list-type-1_2 .buttons','padding-top','3','','','.w-list-type-1_2'),(173703,'deals-mobile','.b-bottom .pop-up-close','padding-top','1','','','.b-bottom'),(173704,'deals-mobile','.w-list-type-1_2 .button-view','padding-top','1','','','.w-list-type-1_2'),(173705,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-top','2','','','.b-fancybox'),(173706,'deals-mobile','.b-bottom .pop-up-info','padding-top','20','','','.b-bottom'),(173707,'deals-mobile','.heading-3 .edit, h3 .edit','padding-top','2','','',''),(173708,'deals-mobile','.w-list-type-1 .buttons','padding-top','3','','','.w-list-type-1'),(173709,'deals-mobile','.heading-4 .edit, h4 .edit','padding-top','2','','',''),(173710,'deals-mobile','.heading-4 .right-text, h4 .right-text','padding-top','4','','',''),(173711,'deals-mobile','.b-bottom .popup-box-wrap','padding-top','10','','','.b-bottom'),(173712,'deals-mobile','.w-reviews .name','padding-top','5','','','.w-reviews'),(173713,'deals-mobile','.w-reviews .reviews-list .name','padding-top','5','','','.w-reviews'),(173714,'deals-mobile','.p-account-index .account_info','padding-top','0','876','','.p-account-index'),(173715,'deals-mobile','.w-top-categories .item','padding-top','5','','','.w-top-categories'),(173716,'deals-mobile','.w-tabs > .block','padding-top','20','','','.w-tabs'),(173717,'deals-mobile','.w-tabs .tab-navigation','padding-top','0','','','.w-tabs'),(173718,'deals-mobile','.b-form .payment-method .item-radio label','padding-top','5','','','.b-form'),(173719,'deals-mobile','.b-form .required-message-wrap','padding-top','0','','','.b-form'),(173720,'deals-mobile','.b-form .shipping-method .input','padding-top','0','','','.b-form'),(173721,'deals-mobile','.b-form .required-message','padding-top','0','','','.b-form'),(173722,'deals-mobile','.b-info .info','padding-top','20','','','.b-info'),(173723,'deals-mobile','.b-info .info li','padding-top','0','','','.b-info'),(173724,'deals-mobile','.b-products-listing .in-cart','padding-top','5','','','.b-products-listing'),(173725,'deals-mobile','.b-products-listing .products-listing .btn-buy','padding-top','5','','','.b-products-listing'),(173726,'deals-mobile','.b-products-listing .products-listing .buyButton .btn','padding-top','5','','','.b-products-listing'),(173727,'deals-mobile','.b-products-listing .products-listing .compare','padding-top','6','','','.b-products-listing'),(173728,'deals-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-top','4','','','.b-products-listing'),(173729,'deals-mobile','.b-products-listing .products-listing a.btn.view-button','padding-top','6','','','.b-products-listing'),(173730,'deals-mobile','.b-products-listing .products-listing h2','padding-top','0','','','.b-products-listing'),(173731,'deals-mobile','.b-products-listing .promos-info .promo-item','padding-top','3','','','.b-products-listing'),(173732,'deals-mobile','.b-products-listing .promos-info .promo-name','padding-top','3','','','.b-products-listing'),(173733,'deals-mobile','.b-products-listing .select-attributes .item-title','padding-top','2','','','.b-products-listing'),(173734,'deals-mobile','.b-products-listing .list-productlisting div.BlockBox.item-holder','padding-top','25','','','.b-products-listing'),(173735,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.b-data-table'),(173736,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top','0','','','.b-data-table'),(173737,'deals-mobile','.b-data-table table.dataTable thead td','padding-top','10','','','.b-data-table'),(173738,'deals-mobile','.b-data-table table.dataTable tbody td','padding-top','10','','','.b-data-table'),(173739,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(173740,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(173741,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(173742,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(173743,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(173744,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(173745,'deals-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(173746,'deals-mobile','.b-email .image','padding-top','5','','','.b-email'),(173747,'deals-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(173748,'deals-mobile','.b-email .qty','padding-top','5','','','.b-email'),(173749,'deals-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(173750,'deals-mobile','.b-email .image','padding-top','5','','','.b-email'),(173751,'deals-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(173752,'deals-mobile','.b-email .model','padding-top','5','','','.b-email'),(173753,'deals-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(173754,'deals-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(173755,'deals-mobile','.b-email .image','padding-top','5','','','.b-email'),(173756,'deals-mobile','.b-email .name','padding-top','5','','','.b-email'),(173757,'deals-mobile','.b-email .qty','padding-top','5','','','.b-email'),(173758,'deals-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(173759,'deals-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(173760,'deals-mobile','.b-email .model','padding-top','5','','','.b-email'),(173761,'deals-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(173762,'deals-mobile','.b-email .model','padding-top','5','','','.b-email'),(173763,'deals-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(173764,'deals-mobile','.b-email .qty','padding-top','5','','','.b-email'),(173765,'deals-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(173766,'deals-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(173767,'deals-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(173768,'deals-mobile','.b-email .model','padding-top','5','','','.b-email'),(173769,'deals-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(173770,'deals-mobile','.b-email .name','padding-top','5','','','.b-email'),(173771,'deals-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(173772,'deals-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(173773,'deals-mobile','.b-email .image','padding-top','5','','','.b-email'),(173774,'deals-mobile','.b-email .price','padding-top','5','','','.b-email'),(173775,'deals-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(173776,'deals-mobile','.b-email .name','padding-top','5','','','.b-email'),(173777,'deals-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(173778,'deals-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(173779,'deals-mobile','.b-email .model','padding-top','5','','','.b-email'),(173780,'deals-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(173781,'deals-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(173782,'deals-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(173783,'deals-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(173784,'deals-mobile','.b-email .name','padding-top','5','','','.b-email'),(173785,'deals-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(173786,'deals-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(173787,'deals-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(173788,'deals-mobile','.b-email .price','padding-top','5','','','.b-email'),(173789,'deals-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(173790,'deals-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(173791,'deals-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(173792,'deals-mobile','.b-email .price','padding-top','5','','','.b-email'),(173793,'deals-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(173794,'deals-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(173795,'deals-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(173796,'deals-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(173797,'deals-mobile','.b-email .price','padding-top','5','','','.b-email'),(173798,'deals-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(173799,'deals-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(173800,'deals-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(173801,'deals-mobile','.b-email .qty','padding-top','5','','','.b-email'),(173802,'deals-mobile','.b-email .model','padding-top','5','','','.b-email'),(173803,'deals-mobile','.b-email .price','padding-top','5','','','.b-email'),(173804,'deals-mobile','.b-email .image','padding-top','5','','','.b-email'),(173805,'deals-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(173806,'deals-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(173807,'deals-mobile','.b-email .name','padding-top','5','','','.b-email'),(173808,'deals-mobile','.b-email .image','padding-top','5','','','.b-email'),(173809,'deals-mobile','.b-email .name','padding-top','5','','','.b-email'),(173810,'deals-mobile','.b-email .qty','padding-top','5','','','.b-email'),(173811,'deals-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(173812,'deals-mobile','.b-email .price','padding-top','5','','','.b-email'),(173813,'deals-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(173814,'deals-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(173815,'deals-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(173816,'deals-mobile','.b-email .qty','padding-top','5','','','.b-email'),(173817,'deals-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(173818,'deals-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(173819,'deals-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(173820,'deals-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(173821,'deals-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(173822,'deals-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(173823,'deals-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(173824,'deals-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(173825,'deals-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(173826,'deals-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(173827,'deals-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(173828,'deals-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(173829,'deals-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(173830,'deals-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(173831,'deals-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(173832,'deals-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(173833,'deals-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(173834,'deals-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(173835,'deals-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(173836,'deals-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(173837,'deals-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(173838,'deals-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(173839,'deals-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(173840,'deals-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(173841,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-top','0','','','.b-h-inline'),(173842,'deals-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-top','0','','','.b-menu-style'),(173843,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-top','5','','','.b-menu-style-1'),(173844,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-top','5','','','.b-menu-style-1'),(173845,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-top','20','','','.b-menu-style-1'),(173846,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','padding-top','40','','','.b-menu-style-1'),(173847,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-top','0','','','.b-menu-style-1'),(173848,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-top','5','','','.b-menu-style-2'),(173849,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-top','5','','','.b-menu-style-2'),(173850,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-top','0','','','.b-menu-style-2'),(173851,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-top','0','','','.b-menu-style-2'),(173852,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-top','10','','','.b-menu-style-2'),(173853,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-top','0','','','.b-menu-style-2'),(173854,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-top','5','','','.b-menu-style-2'),(173855,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-top','10','','','.b-menu-style-2'),(173856,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-top','5','','','.b-menu-style-2'),(173857,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-html_box','padding-top','7','','','.b-menu-style-2'),(173858,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-top','10','','','.b-menu-style-2'),(173859,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-top','5','','','.b-menu-style-3'),(173860,'deals-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 a','padding-top','5','','','.b-menu-style-3'),(173861,'deals-mobile','.b-messages .msv_content','padding-top','10','','','.b-messages'),(173862,'deals-mobile','.b-messages .msv_btn','padding-top','12','','','.b-messages'),(173863,'deals-mobile','.b-messages .emailLineTextArea textarea','padding-top','30','','','.b-messages'),(173864,'deals-mobile','.b-messages .msv_history','padding-top','10','','','.b-messages'),(173865,'deals-mobile','.b-messages .messages-menu li','padding-top','0','','','.b-messages'),(173866,'deals-mobile','.b-messages .messages-menu ul','padding-top','0','','','.b-messages'),(173867,'deals-mobile','.b-messages .messMenuButton span','padding-top','10','','','.b-messages'),(173868,'deals-mobile','.b-messages .messages-menu li a','padding-top','10','','','.b-messages'),(173869,'deals-mobile','.b-messages .content_management_attach','padding-top','8','','','.b-messages'),(173870,'deals-mobile','.b-messages .content_management_attach button','padding-top','1','','','.b-messages'),(173871,'deals-mobile','.b-messages .email-heading','padding-top','15','','','.b-messages'),(173872,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-top','5','','','.b-messages'),(173873,'deals-mobile','.b-messages .messMenuButtonTop','padding-top','5','','','.b-messages'),(173874,'deals-mobile','.b-messages .msv_to_cc','padding-top','10','','','.b-messages'),(173875,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','padding-top','4','','','.b-messages'),(173876,'deals-mobile','.b-messages .emailBtn','padding-top','10','','','.b-messages'),(173877,'deals-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-top','20','','','.b-personal-catalog-popup'),(173878,'deals-mobile','.b-select-suggest .select2-container .select2-choice','padding-top','0','','','.b-select-suggest'),(173879,'deals-mobile','.b-select-suggest .select2-drop-mask','padding-top','0','','','.b-select-suggest'),(173880,'deals-mobile','.b-select-suggest .select2-search input','padding-top','4','','','.b-select-suggest'),(173881,'deals-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(173882,'deals-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','padding-top','4','','','.b-select-suggest'),(173883,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-top','0','','','.b-select-suggest'),(173884,'deals-mobile','.b-select-suggest .select2-results','padding-top','0','','','.b-select-suggest'),(173885,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','padding-top','3','3','','.b-select-suggest'),(173886,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','padding-top','3','','','.b-select-suggest'),(173887,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-top','0','','','.b-select-suggest'),(173888,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-top','5','','','.b-select-suggest'),(173889,'deals-mobile','.b-select-suggest .select2-locked','padding-top','3','','','.b-select-suggest'),(173890,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-top','0','','','.b-select-suggest'),(173891,'deals-mobile','.b-select-suggest .select2-drop-auto-width .select2-search','padding-top','4','','','.b-select-suggest'),(173892,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(173893,'deals-mobile','.b-sub-totals .historyTotal td','padding-top','2','','','.b-sub-totals'),(173894,'deals-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(173895,'deals-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(173896,'deals-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(173897,'deals-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(173898,'deals-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(173899,'deals-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(173900,'deals-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(173901,'deals-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(173902,'deals-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(173903,'deals-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(173904,'deals-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(173905,'deals-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(173906,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(173907,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(173908,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(173909,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(173910,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(173911,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(173912,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(173913,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(173914,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(173915,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(173916,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(173917,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(173918,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(173919,'deals-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(173920,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(173921,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(173922,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(173923,'deals-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(173924,'deals-mobile','.b-trade-approval .steps-bar li a','padding-top','7','','','.b-trade-approval'),(173925,'deals-mobile','.b-trade-approval .middle-form','padding-top','20','','','.b-trade-approval'),(173926,'deals-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-top','5','','','.b-trade-approval'),(173927,'deals-mobile','.b-trade-approval .steps-bar','padding-top','0','','','.b-trade-approval'),(173928,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-top','4','','','.b-trade-approval'),(173929,'deals-mobile','.b-trade-approval .center-buttons','padding-top','20','','','.b-trade-approval'),(173930,'deals-mobile','.b-upload-file .upload-file-template','padding-top','25','','','.b-upload-file'),(173931,'deals-mobile','.b-upload-files .upload-files','padding-top','0','','','.b-upload-files'),(173932,'deals-mobile','.b-upload-files .attached-block','padding-top','10','','','.b-upload-files'),(173933,'deals-mobile','.b-upload-files .added-file','padding-top','5','','','.b-upload-files'),(173934,'deals-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-top','20','','','.b-warehouses-popup'),(173935,'deals-mobile','.batchPr .w-batch-products .products-listing .image','padding-top','0','','','.batchPr'),(173936,'deals-mobile','.batchPr .w-batch-products .products-listing .image + .type-1','padding-top','5','','','.batchPr'),(173937,'deals-mobile','.batchPr .w-batch-products','padding-top','0','','','.batchPr'),(173938,'deals-mobile','.batchPr > .block:nth-child(2)','padding-top','12','','','.batchPr'),(173939,'deals-mobile','.batchPr .w-batch-selected-products','padding-top','15','','','.batchPr'),(173940,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-top','0','','','.batchPr'),(173941,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .item + .item','padding-top','10','','','.batchPr'),(173942,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-top','0','','','.batchPr'),(173943,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-top','0','','','.batchPr'),(173944,'deals-mobile','.batchPr ','padding-top','20','','','.batchPr'),(173945,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-top','0','','','.batchPr'),(173946,'deals-mobile','.batchPr .w-batch-products .products-listing .image','padding-top','0','','','.batchPr'),(173947,'deals-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-top','0','','','.batchPr'),(173948,'deals-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(173949,'deals-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(173950,'deals-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(173951,'deals-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(173952,'deals-mobile','.p-account-samples-history .orders-table th','padding-top','2','','','.p-account-samples-history'),(173953,'deals-mobile','.p-account-samples-history .order_history_table th','padding-top','10','','','.p-account-samples-history'),(173954,'deals-mobile','.p-account-samples-history .view_link','padding-top','0','','','.p-account-samples-history'),(173955,'deals-mobile','.p-account-samples-history .view_link','padding-top','0','','','.p-account-samples-history'),(173956,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-top','10','','','.p-account-samples-history'),(173957,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-top','5','','','.p-account-samples-history'),(173958,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-top','10','','','.p-account-samples-history'),(173959,'deals-mobile','.p-account-samples-history .orders-table th','padding-top','2','','','.p-account-samples-history'),(173960,'deals-mobile','.p-account-samples-history .order_history_table th','padding-top','10','','','.p-account-samples-history'),(173961,'deals-mobile','.p-account-samples-history .orders-table th','padding-top','2','','','.p-account-samples-history'),(173962,'deals-mobile','.p-account-samples-history .view_link','padding-top','0','','','.p-account-samples-history'),(173963,'deals-mobile','.p-account-samples-history .orders-table td','padding-top','5','','','.p-account-samples-history'),(173964,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-top','5','','','.p-account-samples-history'),(173965,'deals-mobile','.p-account-samples-history .order_history_table th','padding-top','10','','','.p-account-samples-history'),(173966,'deals-mobile','.p-account-samples-history .orders-table th','padding-top','2','','','.p-account-samples-history'),(173967,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-top','10','','','.p-account-samples-history'),(173968,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-top','5','','','.p-account-samples-history'),(173969,'deals-mobile','.p-account-samples-history .view_link','padding-top','0','','','.p-account-samples-history'),(173970,'deals-mobile','.p-account-samples-history .order_history_table th','padding-top','10','','','.p-account-samples-history'),(173971,'deals-mobile','.p-account-samples-history .orders-table th','padding-top','2','','','.p-account-samples-history'),(173972,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-top','10','','','.p-account-samples-history'),(173973,'deals-mobile','.p-account-samples-history .orders-table td','padding-top','5','','','.p-account-samples-history'),(173974,'deals-mobile','.p-account-samples-history .orders-table th','padding-top','2','','','.p-account-samples-history'),(173975,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-top','10','','','.p-account-samples-history'),(173976,'deals-mobile','.p-account-samples-history .view_link','padding-top','0','','','.p-account-samples-history'),(173977,'deals-mobile','.p-account-samples-history .order_history_table th','padding-top','10','','','.p-account-samples-history'),(173978,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-top','5','','','.p-account-samples-history'),(173979,'deals-mobile','.p-account-samples-history .orders-table td, .p-account-samples-history .order-info td, .p-account-samples-history .order_history_table td','padding-top','10','','','.p-account-samples-history'),(173980,'deals-mobile','.p-account-samples-history .orders-table td','padding-top','5','','','.p-account-samples-history'),(173981,'deals-mobile','.p-account-samples-history .view_link','padding-top','0','','','.p-account-samples-history'),(173982,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-top','5','','','.p-account-samples-history'),(173983,'deals-mobile','.p-account-samples-history .orders-table td','padding-top','5','','','.p-account-samples-history'),(173984,'deals-mobile','.p-account-samples-history .order_history_table th','padding-top','10','','','.p-account-samples-history'),(173985,'deals-mobile','.p-account-samples-history .orders-table td','padding-top','5','','','.p-account-samples-history'),(173986,'deals-mobile','.p-account-samples-history .orders-table td','padding-top','5','','','.p-account-samples-history'),(173987,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','padding-top','5','','','.p-account-samples-history'),(173988,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-top','10','','','.p-account-samples-history-info'),(173989,'deals-mobile','.p-account-samples-history-info .history_attr','padding-top','5','','','.p-account-samples-history-info'),(173990,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(173991,'deals-mobile','.p-account-samples-history-info .history_attr','padding-top','5','','','.p-account-samples-history-info'),(173992,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(173993,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-top','10','','','.p-account-samples-history-info'),(173994,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(173995,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-top','0','','','.p-account-samples-history-info'),(173996,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-top','10','','','.p-account-samples-history-info'),(173997,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(173998,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-top','5','','','.p-account-samples-history-info'),(173999,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-top','10','','','.p-account-samples-history-info'),(174000,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-top','10','','','.p-account-samples-history-info'),(174001,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(174002,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-top','0','','','.p-account-samples-history-info'),(174003,'deals-mobile','.p-account-samples-history-info .history_attr','padding-top','5','','','.p-account-samples-history-info'),(174004,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-top','5','','','.p-account-samples-history-info'),(174005,'deals-mobile','.p-account-samples-history-info .history_attr','padding-top','5','','','.p-account-samples-history-info'),(174006,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-top','5','','','.p-account-samples-history-info'),(174007,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-top','0','','','.p-account-samples-history-info'),(174008,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-top','10','','','.p-account-samples-history-info'),(174009,'deals-mobile','.p-account-samples-history-info .history_attr','padding-top','5','','','.p-account-samples-history-info'),(174010,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-top','0','','','.p-account-samples-history-info'),(174011,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(174012,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-top','10','','','.p-account-samples-history-info'),(174013,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(174014,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(174015,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(174016,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-top','10','','','.p-account-samples-history-info'),(174017,'deals-mobile','.p-account-samples-history-info .history_attr','padding-top','5','','','.p-account-samples-history-info'),(174018,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-top','5','','','.p-account-samples-history-info'),(174019,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-top','5','','','.p-account-samples-history-info'),(174020,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(174021,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(174022,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-top','10','','','.p-account-samples-history-info'),(174023,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','padding-top','5','','','.p-account-samples-history-info'),(174024,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding-top','0','','','.p-account-samples-history-info'),(174025,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-top','10','','','.p-account-samples-history-info'),(174026,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','padding-top','10','','','.p-account-samples-history-info'),(174027,'deals-mobile','.p-account-samples-history-info .contentColumn','padding-top','10','','','.p-account-samples-history-info'),(174028,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-top','0','','','.p-account-samples-history-info'),(174029,'deals-mobile','.p-account-samples-history-info .history_info > div','padding-top','0','','','.p-account-samples-history-info'),(174030,'deals-mobile','.p-catalog-product .prev-product','padding-top','20','','','.p-catalog-product'),(174031,'deals-mobile','.p-catalog-product .next-product','padding-top','20','','','.p-catalog-product'),(174032,'deals-mobile','.p-catalog-product .pn-image','padding-top','20','','','.p-catalog-product'),(174033,'deals-mobile','.p-catalog-product .pn-name','padding-top','15','','','.p-catalog-product'),(174034,'deals-mobile','.p-catalog-product .pn-direction','padding-top','0','','','.p-catalog-product'),(174035,'deals-mobile','.p-checkout-login .password-forgotten-link','padding-top','0','','','.p-checkout-login'),(174036,'deals-mobile','.p-payer-order-confirmation .dob-hide label','padding-top','5','','','.p-payer-order-confirmation'),(174037,'deals-mobile','.p-payer-order-pay .dob-hide label','padding-top','5','','','.p-payer-order-pay'),(174038,'deals-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-top','8','','','.p-quick-order-index'),(174039,'deals-mobile','.p-quick-order-index .bottom','padding-top','10','','','.p-quick-order-index'),(174040,'deals-mobile','.p-quick-order-index .all-scroll-div','padding-top','10','','','.p-quick-order-index'),(174041,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.p-quick-order-index'),(174042,'deals-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-top','7','','','.p-quick-order-index'),(174043,'deals-mobile','.p-quick-order-index ul.token-input-list','padding-top','0','','','.p-quick-order-index'),(174044,'deals-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(174045,'deals-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(174046,'deals-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(174047,'deals-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(174048,'deals-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(174049,'deals-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(174050,'deals-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(174051,'deals-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(174052,'deals-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(174053,'deals-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','','','.p-quote-checkout-success'),(174054,'deals-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(174055,'deals-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(174056,'deals-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(174057,'deals-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(174058,'deals-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(174059,'deals-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(174060,'deals-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(174061,'deals-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(174062,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(174063,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(174064,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(174065,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(174066,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(174067,'deals-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(174068,'deals-mobile','.p-sample-checkout-success .page-success .text-1','padding-top','120','','','.p-sample-checkout-success'),(174069,'deals-mobile','.p-sample-checkout-success .page-success .text-1','padding-top','5','','','.p-sample-checkout-success'),(174070,'deals-mobile','.w-account-address-book .wrap','padding-top','15','','','.w-account-address-book'),(174071,'deals-mobile','.w-account-address-book .item','padding-top','0','','','.w-account-address-book'),(174072,'deals-mobile','.w-account-address-book .btn-del','padding-top','0','','','.w-account-address-book'),(174073,'deals-mobile','.w-account-address-book .name','padding-top','4','','','.w-account-address-book'),(174074,'deals-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-top','0','','','.w-account-addresses-list'),(174075,'deals-mobile','.w-account-personal-catalog .list-switcher','padding-top','0','','','.w-account-personal-catalog'),(174076,'deals-mobile','.w-account-personal-catalog .list-switcher a','padding-top','14','','','.w-account-personal-catalog'),(174077,'deals-mobile','.w-account-personal-catalog .list-switcher a','padding-top','12','2','','.w-account-personal-catalog'),(174078,'deals-mobile','.w-account-subscription .subscription-variant','padding-top','10','','','.w-account-subscription'),(174079,'deals-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-top','0','','','.w-blog-widget-most-popular-posts'),(174080,'deals-mobile','.w-blog-widget-post-listing .post','padding-top','0','','','.w-blog-widget-post-listing'),(174081,'deals-mobile','.w-blog-widget-post-listing .post_name','padding-top','10','','','.w-blog-widget-post-listing'),(174082,'deals-mobile','.w-blog-widget-post-listing .post','padding-top','0','','','.w-blog-widget-post-listing'),(174083,'deals-mobile','.w-blog-widget-post-share ','padding-top','15','','','.w-blog-widget-post-share'),(174084,'deals-mobile','.w-blog-widget-post-title ','padding-top','0','','','.w-blog-widget-post-title'),(174085,'deals-mobile','.w-blog-widget-post-title h1','padding-top','0','','','.w-blog-widget-post-title'),(174086,'deals-mobile','.w-blog-widget-related-posts .post','padding-top','0','','','.w-blog-widget-related-posts'),(174087,'deals-mobile','.w-blog-widget-related-posts .post_content a','padding-top','20','','','.w-blog-widget-related-posts'),(174088,'deals-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-top','20','','','.w-blog-widget-related-posts-by-category'),(174089,'deals-mobile','.w-blog-widget-related-posts-by-category .post','padding-top','0','','','.w-blog-widget-related-posts-by-category'),(174090,'deals-mobile','.w-blog-widget-tag-cloud a','padding-top','10','','','.w-blog-widget-tag-cloud'),(174091,'deals-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-top','0','','','.w-cart-cart-tabs'),(174092,'deals-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-top','5','','','.w-cart-compare'),(174093,'deals-mobile','.w-cart-compare .attributes-label','padding-top','10','','','.w-cart-compare'),(174094,'deals-mobile','.w-cart-compare .dropdown li','padding-top','5','','','.w-cart-compare'),(174095,'deals-mobile','.w-cart-compare .delete-cart','padding-top','10','','','.w-cart-compare'),(174096,'deals-mobile','.w-cart-compare .product','padding-top','10','','','.w-cart-compare'),(174097,'deals-mobile','.w-cart-compare .cart-cell','padding-top','0','','','.w-cart-compare'),(174098,'deals-mobile','.w-cart-compare .attributes-cell','padding-top','8','','','.w-cart-compare'),(174099,'deals-mobile','.w-cart-compare .price-label','padding-top','10','','','.w-cart-compare'),(174100,'deals-mobile','.w-cart-compare .price-cell','padding-top','8','','','.w-cart-compare'),(174101,'deals-mobile','.w-cart-compare .product-label','padding-top','15','','','.w-cart-compare'),(174102,'deals-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-top','1','','','.w-cart-up-sell'),(174103,'deals-mobile','.w-cart-up-sell .w-list-type-1','padding-top','0','','','.w-cart-up-sell'),(174104,'deals-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-top','0','1','','.w-cart-up-sell'),(174105,'deals-mobile','.w-catalog-additional-images li','padding-top','10','','','.w-catalog-additional-images'),(174106,'deals-mobile','.w-catalog-additional-images ul','padding-top','0','','','.w-catalog-additional-images'),(174107,'deals-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-top','5','','','.w-catalog-b2b-add-button'),(174108,'deals-mobile','.w-catalog-compare td','padding-top','10','','','.w-catalog-compare'),(174109,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','padding-top','12','','','.w-catalog-compare'),(174110,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','padding-top','10','2','','.w-catalog-compare'),(174111,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-top','0','','','.w-catalog-compare'),(174112,'deals-mobile','.w-catalog-items-on-page .before, .w-catalog-items-on-page .after','padding-top','5','','','.w-catalog-items-on-page'),(174113,'deals-mobile','.w-catalog-paging .paging-item','padding-top','0','','','.w-catalog-paging'),(174114,'deals-mobile','.w-checkout-billing-address .same-address','padding-top','10','','','.w-checkout-billing-address'),(174115,'deals-mobile','.w-checkout-billing-address .edit-ab','padding-top','5','','','.w-checkout-billing-address'),(174116,'deals-mobile','.w-checkout-create-account .create-account-switcher','padding-top','3','','','.w-checkout-create-account'),(174117,'deals-mobile','.w-checkout-create-account .create-account','padding-top','10','','','.w-checkout-create-account'),(174118,'deals-mobile','.w-checkout-gdpr .privacy-row','padding-top','0','','','.w-checkout-gdpr'),(174119,'deals-mobile','.w-checkout-gdpr .terms-login','padding-top','0','','','.w-checkout-gdpr'),(174120,'deals-mobile','.w-checkout-shipping .sub-item','padding-top','5','','','.w-checkout-shipping'),(174121,'deals-mobile','.w-checkout-shipping-address .buttons-under-drop .add-ab','padding-top','5','','','.w-checkout-shipping-address'),(174122,'deals-mobile','.w-checkout-shipping-address .edit-ab','padding-top','5','','','.w-checkout-shipping-address'),(174123,'deals-mobile','.w-checkout-shipping-choice span','padding-top','7','','','.w-checkout-shipping-choice'),(174124,'deals-mobile','.w-checkout-shipping-choice span','padding-top','7','','','.w-checkout-shipping-choice'),(174125,'deals-mobile','.w-checkout-terms .required-message','padding-top','5','','','.w-checkout-terms'),(174126,'deals-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-top','20','','','.w-communication-new-topic'),(174127,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-top','5','','','.w-communication-new-topic'),(174128,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-top','0','','','.w-communication-new-topic'),(174129,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-top','5','','','.w-communication-new-topic'),(174130,'deals-mobile','.w-communication-new-topic .topick-left-col','padding-top','24','','','.w-communication-new-topic'),(174131,'deals-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-top','10','','','.w-communication-new-topic'),(174132,'deals-mobile','.w-communication-post .communication-post-author','padding-top','10','','','.w-communication-post'),(174133,'deals-mobile','.w-delivery-day .left-count','padding-top','5','','','.w-delivery-day'),(174134,'deals-mobile','.w-delivery-day .left-text-left','padding-top','24','','','.w-delivery-day'),(174135,'deals-mobile','.w-delivery-day .left-text-right','padding-top','24','','','.w-delivery-day'),(174136,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-top','10','','','.w-image-maps'),(174137,'deals-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-top','3','','','.w-multi-cart-actions'),(174138,'deals-mobile','.w-multi-cart-cart-switcher .carts-switcher','padding-top','20','','','.w-multi-cart-cart-switcher'),(174139,'deals-mobile','.w-neighbour-checkout .neighbour-comment-box','padding-top','10','','','.w-neighbour-checkout'),(174140,'deals-mobile','.w-personal-gift-status-bar .start-label','padding-top','0','','','.w-personal-gift-status-bar'),(174141,'deals-mobile','.w-personal-gift-status-bar .end-label','padding-top','0','','','.w-personal-gift-status-bar'),(174142,'deals-mobile','.w-personal-gift-status-bar .timeline','padding-top','16','','','.w-personal-gift-status-bar'),(174143,'deals-mobile','.w-personal-gift-status-bar .inform','padding-top','0','4','','.w-personal-gift-status-bar'),(174144,'deals-mobile','.w-personal-gift-status-bar .end-date','padding-top','0','3','','.w-personal-gift-status-bar'),(174145,'deals-mobile','.w-product-available-in-warehouses .warehouse-item','padding-top','0','','','.w-product-available-in-warehouses'),(174146,'deals-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(174147,'deals-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(174148,'deals-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(174149,'deals-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(174150,'deals-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(174151,'deals-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(174152,'deals-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(174153,'deals-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(174154,'deals-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(174155,'deals-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(174156,'deals-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(174157,'deals-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(174158,'deals-mobile','.w-product-customers-activity .customers-activity','padding-top','35','','','.w-product-customers-activity'),(174159,'deals-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(174160,'deals-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(174161,'deals-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(174162,'deals-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(174163,'deals-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(174164,'deals-mobile','.w-product-images-additional .images','padding-top','10','','','.w-product-images-additional'),(174165,'deals-mobile','.w-promotions .nextdiscount .content > div','padding-top','10','','','.w-promotions'),(174166,'deals-mobile','.w-promotions .promo-cart-discount .master .item','padding-top','0','','','.w-promotions'),(174167,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-top','0','','','.w-promotions'),(174168,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-top','0','','','.w-promotions'),(174169,'deals-mobile','.w-promotions .promo-salemaker .item','padding-top','20','','','.w-promotions'),(174170,'deals-mobile','.w-promotions .promo-salemaker .discount','padding-top','0','','','.w-promotions'),(174171,'deals-mobile','.w-promotions .promo-cart-discount .slave .item','padding-top','20','','','.w-promotions'),(174172,'deals-mobile','.w-promotions .promo-item','padding-top','30','','','.w-promotions'),(174173,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','padding-top','0','','','.w-promotions'),(174174,'deals-mobile','.w-promotions .prom-multi-discount .promo-product','padding-top','20','','','.w-promotions'),(174175,'deals-mobile','.w-promotions .nextdiscount .promo-for-each','padding-top','3','','','.w-promotions'),(174176,'deals-mobile','.w-quote-products .empty','padding-top','100','','','.w-quote-products'),(174177,'deals-mobile','.w-reviews-content .author','padding-top','0','','','.w-reviews-content'),(174178,'deals-mobile','.w-reviews-content .item','padding-top','20','','','.w-reviews-content'),(174179,'deals-mobile','.w-reviews-content .review','padding-top','20','','','.w-reviews-content'),(174180,'deals-mobile','.w-sitemap-delivery-location > ul','padding-top','0','','','.w-sitemap-delivery-location'),(174181,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-top','0','','','.w-sitemap-delivery-location'),(174182,'deals-mobile','.w-top-text .top-text','padding-top','5','','','.w-top-text'),(174183,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-template','padding-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(174184,'deals-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding-top','25','','','.w-wedding-registry-widgets-manage-banner'),(174185,'deals-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding-top','15','','','.w-wedding-registry-widgets-manage-banner'),(174186,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-top','17','','','.w-wedding-registry-widgets-photos'),(174187,'deals-mobile','.w-wedding-registry-widgets-products .price','padding-top','5','','','.w-wedding-registry-widgets-products'),(174188,'deals-mobile','.w-wedding-registry-widgets-products .rating','padding-top','10','','','.w-wedding-registry-widgets-products'),(174189,'deals-mobile','.w-wedding-registry-widgets-search-registry-button ','padding-top','5','','','.w-wedding-registry-widgets-search-registry-button'),(174190,'deals-mobile','.b-quantity .qty-box input[type=\'text\']','padding-top','5','','','.b-quantity'),(174191,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top_important','important','','','.b-data-table'),(174192,'deals-mobile','.b-data-table table.dataTable thead td','padding-top_important','important','','','.b-data-table'),(174193,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top_important','important','','','.b-data-table'),(174194,'deals-mobile','.b-data-table table.dataTable tbody td','padding-top_important','important','','','.b-data-table'),(174195,'deals-mobile','.batchPr .w-batch-products','padding-top_important','important','','','.batchPr'),(174196,'deals-mobile','.w-categories .image','padding_bottom_measure','%','','','.w-categories'),(174197,'deals-mobile','.w-top-categories .image','padding_bottom_measure','%','','','.w-top-categories'),(174198,'deals-mobile','.p-account-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-history-info'),(174199,'deals-mobile','.p-account-order-pay .history_info > div + div','padding_left_measure','%','','','.p-account-order-pay'),(174200,'deals-mobile','.p-account-index .topAccount > li','padding_left_measure','%','','','.p-account-index'),(174201,'deals-mobile','.w-cart-give-away .ga_img','padding_left_measure','%','','','.w-cart-give-away'),(174202,'deals-mobile','.b-upload-file .upload-file-template','padding_left_measure','%','','','.b-upload-file'),(174203,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-samples-history-info'),(174204,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-samples-history-info'),(174205,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-samples-history-info'),(174206,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-samples-history-info'),(174207,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-samples-history-info'),(174208,'deals-mobile','.p-account-samples-history-info .history_info > div + div','padding_left_measure','%','','','.p-account-samples-history-info'),(174209,'deals-mobile','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(174210,'deals-mobile','.p-account-index .topAccount > li','padding_right_measure','%','','','.p-account-index'),(174211,'deals-mobile','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(174212,'deals-mobile','.w-cart-give-away .ga_img','padding_right_measure','%','','','.w-cart-give-away'),(174213,'deals-mobile','.b-upload-file .upload-file-template','padding_right_measure','%','','','.b-upload-file'),(174214,'deals-mobile','.p-wedding-registry-manage .wedding-image','padding_top_measure','%','','','.p-wedding-registry-manage'),(174215,'deals-mobile','.p-wedding-registry-share .wedding-image','padding_top_measure','%','','','.p-wedding-registry-share'),(174216,'deals-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding_top_measure','%','','','.w-wedding-registry-widgets-manage-banner'),(174217,'deals-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding_top_measure','%','','','.w-wedding-registry-widgets-manage-banner'),(174218,'deals-mobile','.b-slick .slick-slide.dragging img','pointer-events','none','','','.b-slick'),(174219,'deals-mobile','.w-list-type-1_3 #add_all','position','fixed','','','.w-list-type-1_3'),(174220,'deals-mobile','.w-menu .hided.menu > ul','position','absolute','','','.w-menu'),(174221,'deals-mobile','.w-menu .hided.menu','position','relative','','','.w-menu'),(174222,'deals-mobile','.w-menu .hided.menu ul li','position','static','','','.w-menu'),(174223,'deals-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','position','static','','','.w-menu'),(174224,'deals-mobile','.w-menu .menu .menu-ico','position','relative','','','.w-menu'),(174225,'deals-mobile','.w-menu-big','position','relative','','','.w-menu-big'),(174226,'deals-mobile','.w-menu-slider > ul','position','relative','','','.w-menu-slider'),(174227,'deals-mobile','.w-menu-big > ul > li > ul','position','absolute','','','.w-menu-big'),(174228,'deals-mobile','.w-menu-big li','position','static','','','.w-menu-big'),(174229,'deals-mobile','.w-menu-slider > ul > li > ul','position','absolute','','','.w-menu-slider'),(174230,'deals-mobile','.w-menu-slider .close','position','absolute','','','.w-menu-slider'),(174231,'deals-mobile','.w-bestsellers .counter','position','relative','','','.w-bestsellers'),(174232,'deals-mobile','.w-bestsellers .heading-3','position','relative','','','.w-bestsellers'),(174233,'deals-mobile','.w-bestsellers .item','position','relative','','','.w-bestsellers'),(174234,'deals-mobile','.w-bestsellers .item','position','absolute','3','','.w-bestsellers'),(174235,'deals-mobile','.w-banner .banner','position','relative','','','.w-banner'),(174236,'deals-mobile','.b-switch .bootstrap-switch','position','relative','','','.b-switch'),(174237,'deals-mobile','.w-list-type-1 .rating-count','position','relative','','','.w-list-type-1'),(174238,'deals-mobile','.w-bestsellers .heading-3','position','absolute','3','','.w-bestsellers'),(174239,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(174240,'deals-mobile','.w-filters .input-checkbox','position','absolute','','','.w-filters'),(174241,'deals-mobile','.w-list-type-2_2 .sale','position','absolute','4','','.w-list-type-2_2'),(174242,'deals-mobile','.w-sale .sale-holder','position','relative','','','.w-sale'),(174243,'deals-mobile','.w-sale .badge','position','absolute','','','.w-sale'),(174244,'deals-mobile','.w-product-wedding-registry-button .btn','position','absolute','3','','.w-product-wedding-registry-button'),(174245,'deals-mobile','.b-fancybox #fancybox-loading','position','fixed','','','.b-fancybox'),(174246,'deals-mobile','.w-menu-horizontal li','position','relative','','','.w-menu-horizontal'),(174247,'deals-mobile','.b-fancybox .fancybox-nav span','position','absolute','','','.b-fancybox'),(174248,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','position','relative','','','.p-account-history-info'),(174249,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','position','absolute','3','','.p-account-history-info'),(174250,'deals-mobile','.p-account-history-info .not_fully_paid_td','position','absolute','','','.p-account-history-info'),(174251,'deals-mobile','.p-account-index .not_fully_paid_td','position','absolute','','','.p-account-index'),(174252,'deals-mobile','.p-account-index .moduleRowDue td','position','relative','','','.p-account-index'),(174253,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','position','relative','4','','.b-multi-page-checkout'),(174254,'deals-mobile','.b-pass-strength .pass-strength','position','relative','','','.b-pass-strength'),(174255,'deals-mobile','.b-pass-strength .pass-strength span','position','absolute','','','.b-pass-strength'),(174256,'deals-mobile','.w-reviews .heading-3','position','absolute','3','','.w-reviews'),(174257,'deals-mobile','.w-product-reviews .reviews-list .review','position','absolute','3','','.w-product-reviews'),(174258,'deals-mobile','.w-product-reviews .reviews-list .review','position','relative','','','.w-product-reviews'),(174259,'deals-mobile','.w-quote .cart-box','position','relative','','','.w-quote'),(174260,'deals-mobile','.w-product-reviews .reviews-list span','position','relative','','','.w-product-reviews'),(174261,'deals-mobile','.p-blog-index .author .avatar','position','relative','','','.p-blog-index'),(174262,'deals-mobile','.w-product-personal-catalog-button .btn','position','relative','','','.w-product-personal-catalog-button'),(174263,'deals-mobile','.b-info-popup .info-popup div','position','absolute','','','.b-info-popup'),(174264,'deals-mobile','.w-menu-mobile .menu-slider .open','position','fixed','','','.w-menu-mobile'),(174265,'deals-mobile','.w-promo-code .holder','position','relative','','','.w-promo-code'),(174266,'deals-mobile','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(174267,'deals-mobile','.p-wedding-registry-view h1','position','relative','3','','.p-wedding-registry-view'),(174268,'deals-mobile','.p-account-order-pay .account_history_info.account_history_info_due','position','relative','','','.p-account-order-pay'),(174269,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','position','relative','','','.p-account-order-pay'),(174270,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','position','absolute','3','','.p-account-order-pay'),(174271,'deals-mobile','.p-account-order-pay .not_fully_paid_td','position','absolute','','','.p-account-order-pay'),(174272,'deals-mobile','.testimonials .heading-3','position','absolute','3','',''),(174273,'deals-mobile','.testimonials .heading-3','position','relative','','',''),(174274,'deals-mobile','.testimonials .rating','position','relative','','',''),(174275,'deals-mobile','.testimonials .review','position','relative','','',''),(174276,'deals-mobile','.testimonials .review','position','absolute','3','',''),(174277,'deals-mobile','.testimonials .reviews-list span','position','relative','','',''),(174278,'deals-mobile','.p-wedding-registry-manage .wr-search','position','relative','','','.p-wedding-registry-manage'),(174279,'deals-mobile','.p-wedding-registry-manage .wr-search button','position','absolute','','','.p-wedding-registry-manage'),(174280,'deals-mobile','.p-account-history .view_link','position','relative','','','.p-account-history'),(174281,'deals-mobile','.p-account-history .view_link','position','absolute','4','','.p-account-history'),(174282,'deals-mobile','.p-account-history .orders-table .item','position','relative','890','','.p-account-history'),(174283,'deals-mobile','.p-account-history .orders-table .status-name','position','absolute','890','','.p-account-history'),(174284,'deals-mobile','.p-account-history .orders-table .td-alignright','position','absolute','890','','.p-account-history'),(174285,'deals-mobile','.p-account-index .orders-table .item','position','relative','890','','.p-account-index'),(174286,'deals-mobile','.p-account-history .orders-table .order-total','position','absolute','890','','.p-account-history'),(174287,'deals-mobile','.p-account-index .orders-table .order-total','position','absolute','890','','.p-account-index'),(174288,'deals-mobile','.p-account-index .orders-table .td-alignright','position','absolute','890','','.p-account-index'),(174289,'deals-mobile','.p-account-index .orders-table .status-name','position','absolute','890','','.p-account-index'),(174290,'deals-mobile','.w-list-type-2_2 .sale','position','absolute','','','.w-list-type-2_2'),(174291,'deals-mobile','.w-list-type-2_2 .sale','position','absolute','3','','.w-list-type-2_2'),(174292,'deals-mobile','.w-list-type-2_2 .image','position','relative','','','.w-list-type-2_2'),(174293,'deals-mobile','.w-list-type-2 .sale','position','absolute','','','.w-list-type-2'),(174294,'deals-mobile','.w-list-type-2 .sale','position','absolute','3','','.w-list-type-2'),(174295,'deals-mobile','.w-product-wedding-registry-button .btn','position','absolute','4','','.w-product-wedding-registry-button'),(174296,'deals-mobile','.w-list-type-2 .sale','position','absolute','4','','.w-list-type-2'),(174297,'deals-mobile','.w-product-wedding-registry-button .btn','position','relative','','','.w-product-wedding-registry-button'),(174298,'deals-mobile','.w-product-personal-catalog-button .btn','position','absolute','3','','.w-product-personal-catalog-button'),(174299,'deals-mobile','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(174300,'deals-mobile','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(174301,'deals-mobile','.w-account a.my-acc-link','position','relative','','','.w-account'),(174302,'deals-mobile','.b-fancybox .fancybox-close','position','absolute','','','.b-fancybox'),(174303,'deals-mobile','.w-menu-horizontal ul ul','position','absolute','','','.w-menu-horizontal'),(174304,'deals-mobile','.b-fancybox .fancybox-nav','position','absolute','','','.b-fancybox'),(174305,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','position','relative','3','','.b-form'),(174306,'deals-mobile','.b-form .radio-button input[type=\"radio\"]','position','relative','','','.b-form'),(174307,'deals-mobile','.p-wedding-registry-index .search-list','position','absolute','3','','.p-wedding-registry-index'),(174308,'deals-mobile','.p-wedding-registry-index .search-list','position','relative','','','.p-wedding-registry-index'),(174309,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no','position','absolute','','','.b-form'),(174310,'deals-mobile','.b-form .radio-buttons .radio-button','position','relative','','','.b-form'),(174311,'deals-mobile','.b-form .form-buttons','position','relative','','','.b-form'),(174312,'deals-mobile','.p-wedding-registry-search h1','position','relative','4','','.p-wedding-registry-search'),(174313,'deals-mobile','.p-account-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-history-info'),(174314,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','position','relative','3','','.b-switch'),(174315,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','position','relative','3','','.b-switch'),(174316,'deals-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position','absolute','','','.b-switch'),(174317,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','position','absolute','','','.b-slick'),(174318,'deals-mobile','.b-bottom .footerTitle','position','absolute','863,4','','.b-bottom'),(174319,'deals-mobile','.b-bottom .footerTitle','position','relative','863','','.b-bottom'),(174320,'deals-mobile','.w-search .search','position','relative','','','.w-search'),(174321,'deals-mobile','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(174322,'deals-mobile','.w-search .suggest','position','absolute','','','.w-search'),(174323,'deals-mobile','.w-banner .image-text-banner','position','relative','','','.w-banner'),(174324,'deals-mobile','.w-banner .banner img + img','position','absolute','','','.w-banner'),(174325,'deals-mobile','.w-banner .image-text-banner .text-banner','position','absolute','','','.w-banner'),(174326,'deals-mobile','.w-currencies .current','position','relative','','','.w-currencies'),(174327,'deals-mobile','.w-currencies .select','position','absolute','','','.w-currencies'),(174328,'deals-mobile','.w-filters .head-filter-widget','position','relative','','','.w-filters'),(174329,'deals-mobile','.w-currencies .current','position','absolute','3','','.w-currencies'),(174330,'deals-mobile','.w-currencies .currencies','position','relative','','','.w-currencies'),(174331,'deals-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(174332,'deals-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','position','absolute','','','.w-compare-box-item'),(174333,'deals-mobile','.w-compare-box-item .checkbox:not(checked) + span','position','relative','','','.w-compare-box-item'),(174334,'deals-mobile','.w-compare-box-item .checkbox:not(checked)','position','absolute','','','.w-compare-box-item'),(174335,'deals-mobile','.b-slick .slick-slider','position','relative','','','.b-slick'),(174336,'deals-mobile','.b-slick .slick-track','position','relative','','','.b-slick'),(174337,'deals-mobile','.p-checkout-success .page-success','position','relative','','','.p-checkout-success'),(174338,'deals-mobile','.p-checkout-success .page-success','position','absolute','3','','.p-checkout-success'),(174339,'deals-mobile','.b-fancybox .fancybox-title-outside-wrap','position','relative','','','.b-fancybox'),(174340,'deals-mobile','.b-fancybox .fancybox-title','position','relative','','','.b-fancybox'),(174341,'deals-mobile','.b-fancybox .fancybox-title-float-wrap','position','absolute','','','.b-fancybox'),(174342,'deals-mobile','.b-info-popup .info-popup','position','relative','','','.b-info-popup'),(174343,'deals-mobile','.p-account-index .view_link','position','absolute','4','','.p-account-index'),(174344,'deals-mobile','.p-account-index .view_link','position','relative','','','.p-account-index'),(174345,'deals-mobile','.b-info-popup .info-popup div','position','absolute','3','','.b-info-popup'),(174346,'deals-mobile','.b-fancybox .fancybox-tmp','position','absolute','','','.b-fancybox'),(174347,'deals-mobile','.b-fancybox .fancybox-skin','position','relative','','','.b-fancybox'),(174348,'deals-mobile','.b-fancybox .fancybox-title-over-wrap','position','absolute','','','.b-fancybox'),(174349,'deals-mobile','.b-fancybox .fancybox-wrap','position','absolute','','','.b-fancybox'),(174350,'deals-mobile','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(174351,'deals-mobile','.w-menu-style-1 li','position','relative','','','.w-menu-style-1'),(174352,'deals-mobile','.w-menu-style-1 ul ul','position','absolute','','','.w-menu-style-1'),(174353,'deals-mobile','.p-checkout-success .page-success > div','position','relative','','','.p-checkout-success'),(174354,'deals-mobile','.b-fancybox .fancybox-overlay-fixed','position','fixed','','','.b-fancybox'),(174355,'deals-mobile','.b-fancybox .fancybox-overlay','position','absolute','','','.b-fancybox'),(174356,'deals-mobile','.b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner','position','relative','','','.b-fancybox'),(174357,'deals-mobile','.p-account-history .not_fully_paid_td','position','absolute','','','.p-account-history'),(174358,'deals-mobile','.p-wedding-registry-share .invite-remove','position','absolute','','','.p-wedding-registry-share'),(174359,'deals-mobile','.p-wedding-registry-share .address-row','position','relative','','','.p-wedding-registry-share'),(174360,'deals-mobile','.w-text .customer-service','position','absolute','3','','.w-text'),(174361,'deals-mobile','.w-text .customer-service','position','relative','','','.w-text'),(174362,'deals-mobile','.p-account-history .moduleRowDue td','position','relative','','','.p-account-history'),(174363,'deals-mobile','.w-banner .carousel-text','position','absolute','','','.w-banner'),(174364,'deals-mobile','.b-form .checkbox-style','position','absolute','','','.b-form'),(174365,'deals-mobile','.w-banner .carousel .item','position','relative','','','.w-banner'),(174366,'deals-mobile','.b-slick .slick-list','position','relative','','','.b-slick'),(174367,'deals-mobile','.b-rating #stars-default .glyphicon','position','relative','','','.b-rating'),(174368,'deals-mobile','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(174369,'deals-mobile','.w-cart .cart-box','position','relative','','','.w-cart'),(174370,'deals-mobile','.w-cart .cart-box.hover-box .cart-content','position','absolute','','','.w-cart'),(174371,'deals-mobile','.p-reviews-info .review-info-text','position','absolute','4','','.p-reviews-info'),(174372,'deals-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','position','relative','3','','.w-cart-discount-coupon'),(174373,'deals-mobile','.w-cart .cart-box-link','position','relative','','','.w-cart'),(174374,'deals-mobile','.p-account-index .topAccount > li > div','position','absolute','863,3','','.p-account-index'),(174375,'deals-mobile','.p-account-index .topAccount > li > div','position','relative','863','','.p-account-index'),(174376,'deals-mobile','.b-form .addresses .address-item input[type=\"radio\"]','position','relative','','','.b-form'),(174377,'deals-mobile','.p-account-index .account_page h4','position','relative','','','.p-account-index'),(174378,'deals-mobile','.b-form .hide-billing-address','position','absolute','','','.b-form'),(174379,'deals-mobile','.p-account-index .account_page h4','position','absolute','3','','.p-account-index'),(174380,'deals-mobile','.b-form .discount-box input[type=\"text\"]','position','relative','','','.b-form'),(174381,'deals-mobile','.b-fancybox .filter-listing-preloader','position','absolute','','','.b-fancybox'),(174382,'deals-mobile','.b-fancybox .filter-listing-loader','position','absolute','','','.b-fancybox'),(174383,'deals-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(174384,'deals-mobile','.b-datepicker .datepicker-dropdown','position','absolute','','','.b-datepicker'),(174385,'deals-mobile','.b-form .columns .col-2','position','relative','','','.b-form'),(174386,'deals-mobile','.view-all','position','absolute','3','',''),(174387,'deals-mobile','.view-all','position','relative','','',''),(174388,'deals-mobile','.w-list-type-1_3 .sale','position','absolute','4','','.w-list-type-1_3'),(174389,'deals-mobile','.w-list-type-1_3 .sale','position','absolute','','','.w-list-type-1_3'),(174390,'deals-mobile','.w-list-type-1_3 .sale','position','absolute','3','','.w-list-type-1_3'),(174391,'deals-mobile','.w-list-type-2 .image','position','relative','','','.w-list-type-2'),(174392,'deals-mobile','.p-wedding-registry-manage h1','position','relative','3','','.p-wedding-registry-manage'),(174393,'deals-mobile','.p-wedding-registry-search h1','position','relative','3','','.p-wedding-registry-search'),(174394,'deals-mobile','.view-all .btn','position','relative','','',''),(174395,'deals-mobile','.b-autocomplete .ui-autocomplete','position','absolute','','','.b-autocomplete'),(174396,'deals-mobile','.p-wedding-registry-manage h1','position','relative','4','','.p-wedding-registry-manage'),(174397,'deals-mobile','.p-wedding-registry-view h1','position','relative','4','','.p-wedding-registry-view'),(174398,'deals-mobile','.p-wedding-registry-share h1','position','relative','4','','.p-wedding-registry-share'),(174399,'deals-mobile','.p-wedding-registry-share h1','position','relative','3','','.p-wedding-registry-share'),(174400,'deals-mobile','.w-list-type-1_3 .image','position','relative','','','.w-list-type-1_3'),(174401,'deals-mobile','.w-list-type-1_2 .sale','position','absolute','3','','.w-list-type-1_2'),(174402,'deals-mobile','.w-list-type-1_2 .sale','position','absolute','4','','.w-list-type-1_2'),(174403,'deals-mobile','.w-list-type-1_2 .sale','position','absolute','','','.w-list-type-1_2'),(174404,'deals-mobile','.w-list-type-1_2 .image','position','relative','','','.w-list-type-1_2'),(174405,'deals-mobile','.b-bottom .pop-up-close','position','absolute','','','.b-bottom'),(174406,'deals-mobile','.p-reviews-info .review-info-text','position','relative','','','.p-reviews-info'),(174407,'deals-mobile','.w-list-type-1 .sale','position','absolute','4','','.w-list-type-1'),(174408,'deals-mobile','.w-list-type-1 .sale','position','absolute','3','','.w-list-type-1'),(174409,'deals-mobile','.w-list-type-1 .sale','position','absolute','','','.w-list-type-1'),(174410,'deals-mobile','.w-list-type-1 .image','position','relative','','','.w-list-type-1'),(174411,'deals-mobile','.w-filters .mobileCollapse','position','absolute','','','.w-filters'),(174412,'deals-mobile','.w-languages .current','position','absolute','3','','.w-languages'),(174413,'deals-mobile','.w-languages .languages','position','relative','','','.w-languages'),(174414,'deals-mobile','.w-languages .select','position','absolute','','','.w-languages'),(174415,'deals-mobile','.w-languages .current','position','relative','','','.w-languages'),(174416,'deals-mobile','.b-form .billing-address','position','relative','','','.b-form'),(174417,'deals-mobile','.w-reviews .review','position','absolute','3','','.w-reviews'),(174418,'deals-mobile','.w-quote .cart-box-link','position','relative','','','.w-quote'),(174419,'deals-mobile','.w-reviews .heading-3','position','relative','','','.w-reviews'),(174420,'deals-mobile','.w-reviews .review','position','relative','','','.w-reviews'),(174421,'deals-mobile','.w-reviews .rating','position','relative','','','.w-reviews'),(174422,'deals-mobile','.w-search .button-search','position','absolute','','','.w-search'),(174423,'deals-mobile','.w-reviews .reviews-list span','position','relative','','','.w-reviews'),(174424,'deals-mobile','.w-search .search form','position','absolute','','','.w-search'),(174425,'deals-mobile','.b-form .payment-method .item-radio input','position','relative','','','.b-form'),(174426,'deals-mobile','.b-form .required-message','position','absolute','','','.b-form'),(174427,'deals-mobile','.b-info .info','position','relative','','','.b-info'),(174428,'deals-mobile','.b-form .required-message-wrap','position','relative','','','.b-form'),(174429,'deals-mobile','.b-form .shipping-method .input input','position','relative','','','.b-form'),(174430,'deals-mobile','.b-form .same-address','position','relative','','','.b-form'),(174431,'deals-mobile','.b-info .info','position','relative','3','','.b-info'),(174432,'deals-mobile','.b-info-popup .info-popup','position','relative','3','','.b-info-popup'),(174433,'deals-mobile','.b-products-listing .hover-box','position','relative','','','.b-products-listing'),(174434,'deals-mobile','.b-products-listing .hover-box-content','position','absolute','3','','.b-products-listing'),(174435,'deals-mobile','.b-products-listing .hover-box-content','position','absolute','','','.b-products-listing'),(174436,'deals-mobile','.b-products-listing .loader','position','absolute','4','','.b-products-listing'),(174437,'deals-mobile','.b-products-listing .loader','position','absolute','3','','.b-products-listing'),(174438,'deals-mobile','.b-products-listing .loader','position','relative','','','.b-products-listing'),(174439,'deals-mobile','.b-products-listing .products-listing .btn-buy','position','relative','3','','.b-products-listing'),(174440,'deals-mobile','.b-products-listing .products-listing .image','position','relative','','','.b-products-listing'),(174441,'deals-mobile','.b-products-listing .products-listing .promos-info','position','absolute','','','.b-products-listing'),(174442,'deals-mobile','.b-products-listing .products-listing .qty-input.hidden','position','absolute','3','','.b-products-listing'),(174443,'deals-mobile','.b-products-listing .products-listing .radio-attributes input','position','relative','','','.b-products-listing'),(174444,'deals-mobile','.b-products-listing .promo','position','absolute','','','.b-products-listing'),(174445,'deals-mobile','.b-products-listing .promo-icon','position','relative','','','.b-products-listing'),(174446,'deals-mobile','.b-products-listing .promos-info','position','relative','','','.b-products-listing'),(174447,'deals-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(174448,'deals-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(174449,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(174450,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(174451,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(174452,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(174453,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(174454,'deals-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(174455,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(174456,'deals-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(174457,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(174458,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(174459,'deals-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(174460,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(174461,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(174462,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(174463,'deals-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(174464,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(174465,'deals-mobile','.b-menu-burger_icon .menu-style[data-burger_icon]','position','relative','','','.b-menu-burger_icon'),(174466,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-1 > li','position','relative','','','.b-menu-lev_display-down'),(174467,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','position','absolute','','','.b-menu-lev_display-down'),(174468,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-2 > li','position','relative','','','.b-menu-lev_display-down'),(174469,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','position','absolute','','','.b-menu-lev_display-down'),(174470,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-3 > li','position','relative','','','.b-menu-lev_display-down'),(174471,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','position','absolute','','','.b-menu-lev_display-down'),(174472,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-4 > li','position','relative','','','.b-menu-lev_display-down'),(174473,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','position','absolute','','','.b-menu-lev_display-down'),(174474,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-5 > li','position','relative','','','.b-menu-lev_display-down'),(174475,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','position','absolute','','','.b-menu-lev_display-down'),(174476,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-1 > li','position','relative','','','.b-menu-lev_display-left'),(174477,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','position','absolute','','','.b-menu-lev_display-left'),(174478,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-2 > li','position','relative','','','.b-menu-lev_display-left'),(174479,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','position','absolute','','','.b-menu-lev_display-left'),(174480,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-3 > li','position','relative','','','.b-menu-lev_display-left'),(174481,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','position','absolute','','','.b-menu-lev_display-left'),(174482,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-4 > li','position','relative','','','.b-menu-lev_display-left'),(174483,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','position','absolute','','','.b-menu-lev_display-left'),(174484,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-5 > li','position','relative','','','.b-menu-lev_display-left'),(174485,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','position','absolute','','','.b-menu-lev_display-left'),(174486,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-1 > li','position','relative','','','.b-menu-lev_display-lra'),(174487,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','position','absolute','','','.b-menu-lev_display-lra'),(174488,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-2 > li','position','relative','','','.b-menu-lev_display-lra'),(174489,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','position','absolute','','','.b-menu-lev_display-lra'),(174490,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-3 > li','position','relative','','','.b-menu-lev_display-lra'),(174491,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','position','absolute','','','.b-menu-lev_display-lra'),(174492,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-4 > li','position','relative','','','.b-menu-lev_display-lra'),(174493,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','position','absolute','','','.b-menu-lev_display-lra'),(174494,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-5 > li','position','relative','','','.b-menu-lev_display-lra'),(174495,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','position','absolute','','','.b-menu-lev_display-lra'),(174496,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right'),(174497,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','position','absolute','','','.b-menu-lev_display-right'),(174498,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right'),(174499,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','position','absolute','','','.b-menu-lev_display-right'),(174500,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right'),(174501,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','position','absolute','','','.b-menu-lev_display-right'),(174502,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right'),(174503,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','position','absolute','','','.b-menu-lev_display-right'),(174504,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right'),(174505,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','position','absolute','','','.b-menu-lev_display-right'),(174506,'deals-mobile','.b-menu-lev_display-right_top .menu-style[data-lev2_display=\"right_top\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right_top'),(174507,'deals-mobile','.b-menu-lev_display-right_top .menu-style[data-lev3_display=\"right_top\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right_top'),(174508,'deals-mobile','.b-menu-lev_display-right_top .menu-style[data-lev4_display=\"right_top\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right_top'),(174509,'deals-mobile','.b-menu-lev_display-right_top .menu-style[data-lev5_display=\"right_top\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right_top'),(174510,'deals-mobile','.b-menu-lev_display-right_top .menu-style[data-lev6_display=\"right_top\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right_top'),(174511,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .level-1','position','relative','','','.b-menu-lev_display-slide'),(174512,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] .level-2','position','relative','','','.b-menu-lev_display-slide'),(174513,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','position','absolute','','','.b-menu-lev_display-slide'),(174514,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] .level-3','position','relative','','','.b-menu-lev_display-slide'),(174515,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','position','absolute','','','.b-menu-lev_display-slide'),(174516,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] .level-4','position','relative','','','.b-menu-lev_display-slide'),(174517,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','position','absolute','','','.b-menu-lev_display-slide'),(174518,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] .level-5','position','relative','','','.b-menu-lev_display-slide'),(174519,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','position','absolute','','','.b-menu-lev_display-slide'),(174520,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','position','absolute','','','.b-menu-lev_display-slide'),(174521,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width'),(174522,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','position','absolute','','','.b-menu-lev_display-width'),(174523,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width'),(174524,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','position','absolute','','','.b-menu-lev_display-width'),(174525,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width'),(174526,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','position','absolute','','','.b-menu-lev_display-width'),(174527,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width'),(174528,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','position','absolute','','','.b-menu-lev_display-width'),(174529,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width'),(174530,'deals-mobile','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','position','absolute','','','.b-menu-lev_display-width'),(174531,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width_cont'),(174532,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','position','absolute','','','.b-menu-lev_display-width_cont'),(174533,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width_cont'),(174534,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','position','absolute','','','.b-menu-lev_display-width_cont'),(174535,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width_cont'),(174536,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','position','absolute','','','.b-menu-lev_display-width_cont'),(174537,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width_cont'),(174538,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','position','absolute','','','.b-menu-lev_display-width_cont'),(174539,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width_cont'),(174540,'deals-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','position','absolute','','','.b-menu-lev_display-width_cont'),(174541,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(174542,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(174543,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(174544,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(174545,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(174546,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','position','fixed','','','.b-menu-open_from-left'),(174547,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','position','absolute','','','.b-menu-style-1'),(174548,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','position','static','','','.b-menu-style-2'),(174549,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','position','relative','','','.b-menu-style-2'),(174550,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','position','absolute','3','','.b-menu-style-2'),(174551,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','position','static','','','.b-menu-style-2'),(174552,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','position','relative','','','.b-menu-style-2'),(174553,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','position','absolute','3','','.b-menu-style-2'),(174554,'deals-mobile','.b-messages .messMenuButton span','position','relative','','','.b-messages'),(174555,'deals-mobile','.b-messages .messBtnMenuDelete','position','relative','3','','.b-messages'),(174556,'deals-mobile','.b-messages .messBtnMenuStarred','position','relative','3','','.b-messages'),(174557,'deals-mobile','.b-messages span.starred::before','position','relative','','','.b-messages'),(174558,'deals-mobile','.b-messages .messBtnMenuUnread','position','relative','3','','.b-messages'),(174559,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-messages'),(174560,'deals-mobile','.b-preloader .preloader','position','absolute','','','.b-preloader'),(174561,'deals-mobile','.b-preloader .preloader','position','absolute','3','','.b-preloader'),(174562,'deals-mobile','.b-select-suggest .select2-search','position','relative','','','.b-select-suggest'),(174563,'deals-mobile','.b-select-suggest .select2-container .select2-choice','position','relative','','','.b-select-suggest'),(174564,'deals-mobile','.b-select-suggest .select2-search-choice-close','position','absolute','','','.b-select-suggest'),(174565,'deals-mobile','.b-select-suggest .select2-drop-mask','position','fixed','','','.b-select-suggest'),(174566,'deals-mobile','.b-select-suggest .select2-drop','position','absolute','','','.b-select-suggest'),(174567,'deals-mobile','.b-select-suggest .select2-results','position','relative','','','.b-select-suggest'),(174568,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position','absolute','','','.b-select-suggest'),(174569,'deals-mobile','.b-select-suggest .select2-measure-scrollbar','position','absolute','','','.b-select-suggest'),(174570,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices','position','relative','','','.b-select-suggest'),(174571,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','position','absolute','','','.b-select-suggest'),(174572,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-select-suggest'),(174573,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','position','absolute','','','.b-select-suggest'),(174574,'deals-mobile','.b-select-suggest .select2-container','position','relative','','','.b-select-suggest'),(174575,'deals-mobile','.b-upload-file .snapshot','position','absolute','','','.b-upload-file'),(174576,'deals-mobile','.b-upload-file .upload-remove','position','absolute','','','.b-upload-file'),(174577,'deals-mobile','.b-upload-files .attach-active-holder .attach-file','position','absolute','','','.b-upload-files'),(174578,'deals-mobile','.batchPr .w-batch-products .item-holder','position','relative','','','.batchPr'),(174579,'deals-mobile','.batchPr .checkbox input:checked + span:before','position','static','','','.batchPr'),(174580,'deals-mobile','.batchPr .checkbox input + span','position','absolute','','','.batchPr'),(174581,'deals-mobile','.batchPr .batchSelect .checkbox','position','relative','','','.batchPr'),(174582,'deals-mobile','.batchPr .batchSelect','position','static','','','.batchPr'),(174583,'deals-mobile','.batchPr .w-batch-selected-products .item','position','relative','','','.batchPr'),(174584,'deals-mobile','.batchPr .checkbox input:not(checked) + span:before','position','absolute','','','.batchPr'),(174585,'deals-mobile','.batchPr .batchSelect','position','absolute','','','.batchPr'),(174586,'deals-mobile','.batchPr .btn-batch-remove','position','absolute','','','.batchPr'),(174587,'deals-mobile','.bell-ico .heading-2','position','relative','3','','.bell-ico'),(174588,'deals-mobile','.heading-ordered-items .heading-4','position','relative','3','','.heading-ordered-items'),(174589,'deals-mobile','.heading-saved-lists .heading-4','position','relative','3','','.heading-saved-lists'),(174590,'deals-mobile','.heading-settings .heading-4','position','relative','3','','.heading-settings'),(174591,'deals-mobile','.p-account-samples-history .view_link','position','absolute','4','','.p-account-samples-history'),(174592,'deals-mobile','.p-account-samples-history .not_fully_paid_td','position','absolute','','','.p-account-samples-history'),(174593,'deals-mobile','.p-account-samples-history .moduleRowDue td','position','relative','','','.p-account-samples-history'),(174594,'deals-mobile','.p-account-samples-history .orders-table .item','position','relative','','','.p-account-samples-history'),(174595,'deals-mobile','.p-account-samples-history .orders-table .item','position','relative','','','.p-account-samples-history'),(174596,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','position','absolute','','','.p-account-samples-history'),(174597,'deals-mobile','.p-account-samples-history .view_link','position','absolute','4','','.p-account-samples-history'),(174598,'deals-mobile','.p-account-samples-history .moduleRowDue td','position','relative','','','.p-account-samples-history'),(174599,'deals-mobile','.p-account-samples-history .orders-table .order-total','position','absolute','','','.p-account-samples-history'),(174600,'deals-mobile','.p-account-samples-history .not_fully_paid_td','position','absolute','','','.p-account-samples-history'),(174601,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','position','absolute','','','.p-account-samples-history'),(174602,'deals-mobile','.p-account-samples-history .moduleRowDue td','position','relative','','','.p-account-samples-history'),(174603,'deals-mobile','.p-account-samples-history .moduleRowDue td','position','relative','','','.p-account-samples-history'),(174604,'deals-mobile','.p-account-samples-history .orders-table .status-name','position','absolute','','','.p-account-samples-history'),(174605,'deals-mobile','.p-account-samples-history .orders-table .status-name','position','absolute','','','.p-account-samples-history'),(174606,'deals-mobile','.p-account-samples-history .orders-table .order-total','position','absolute','','','.p-account-samples-history'),(174607,'deals-mobile','.p-account-samples-history .view_link','position','relative','','','.p-account-samples-history'),(174608,'deals-mobile','.p-account-samples-history .orders-table .item','position','relative','','','.p-account-samples-history'),(174609,'deals-mobile','.p-account-samples-history .orders-table .item','position','relative','','','.p-account-samples-history'),(174610,'deals-mobile','.p-account-samples-history .orders-table .status-name','position','absolute','','','.p-account-samples-history'),(174611,'deals-mobile','.p-account-samples-history .view_link','position','absolute','4','','.p-account-samples-history'),(174612,'deals-mobile','.p-account-samples-history .orders-table .item','position','relative','','','.p-account-samples-history'),(174613,'deals-mobile','.p-account-samples-history .orders-table .status-name','position','absolute','','','.p-account-samples-history'),(174614,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','position','absolute','','','.p-account-samples-history'),(174615,'deals-mobile','.p-account-samples-history .orders-table .item','position','relative','','','.p-account-samples-history'),(174616,'deals-mobile','.p-account-samples-history .orders-table .status-name','position','absolute','','','.p-account-samples-history'),(174617,'deals-mobile','.p-account-samples-history .view_link','position','absolute','4','','.p-account-samples-history'),(174618,'deals-mobile','.p-account-samples-history .orders-table .order-total','position','absolute','','','.p-account-samples-history'),(174619,'deals-mobile','.p-account-samples-history .orders-table .order-total','position','absolute','','','.p-account-samples-history'),(174620,'deals-mobile','.p-account-samples-history .orders-table .order-total','position','absolute','','','.p-account-samples-history'),(174621,'deals-mobile','.p-account-samples-history .orders-table .status-name','position','absolute','','','.p-account-samples-history'),(174622,'deals-mobile','.p-account-samples-history .view_link','position','relative','','','.p-account-samples-history'),(174623,'deals-mobile','.p-account-samples-history .orders-table .order-total','position','absolute','','','.p-account-samples-history'),(174624,'deals-mobile','.p-account-samples-history .moduleRowDue td','position','relative','','','.p-account-samples-history'),(174625,'deals-mobile','.p-account-samples-history .view_link','position','relative','','','.p-account-samples-history'),(174626,'deals-mobile','.p-account-samples-history .view_link','position','relative','','','.p-account-samples-history'),(174627,'deals-mobile','.p-account-samples-history .view_link','position','absolute','4','','.p-account-samples-history'),(174628,'deals-mobile','.p-account-samples-history .moduleRowDue td','position','relative','','','.p-account-samples-history'),(174629,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','position','absolute','','','.p-account-samples-history'),(174630,'deals-mobile','.p-account-samples-history .not_fully_paid_td','position','absolute','','','.p-account-samples-history'),(174631,'deals-mobile','.p-account-samples-history .not_fully_paid_td','position','absolute','','','.p-account-samples-history'),(174632,'deals-mobile','.p-account-samples-history .not_fully_paid_td','position','absolute','','','.p-account-samples-history'),(174633,'deals-mobile','.p-account-samples-history .not_fully_paid_td','position','absolute','','','.p-account-samples-history'),(174634,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','position','absolute','','','.p-account-samples-history'),(174635,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','position','absolute','','','.p-account-samples-history'),(174636,'deals-mobile','.p-account-samples-history .view_link','position','relative','','','.p-account-samples-history'),(174637,'deals-mobile','.p-account-samples-history .view_link','position','relative','','','.p-account-samples-history'),(174638,'deals-mobile','.p-account-samples-history .view_link','position','absolute','4','','.p-account-samples-history'),(174639,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-samples-history-info'),(174640,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','absolute','3','','.p-account-samples-history-info'),(174641,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-samples-history-info'),(174642,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','position','absolute','','','.p-account-samples-history-info'),(174643,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','absolute','3','','.p-account-samples-history-info'),(174644,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','position','absolute','','','.p-account-samples-history-info'),(174645,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','relative','','','.p-account-samples-history-info'),(174646,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-samples-history-info'),(174647,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-samples-history-info'),(174648,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','absolute','3','','.p-account-samples-history-info'),(174649,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','relative','','','.p-account-samples-history-info'),(174650,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','position','absolute','','','.p-account-samples-history-info'),(174651,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','absolute','3','','.p-account-samples-history-info'),(174652,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','position','absolute','','','.p-account-samples-history-info'),(174653,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-samples-history-info'),(174654,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','relative','','','.p-account-samples-history-info'),(174655,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','absolute','3','','.p-account-samples-history-info'),(174656,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','relative','','','.p-account-samples-history-info'),(174657,'deals-mobile','.p-account-samples-history-info .account_history_info.account_history_info_due','position','relative','','','.p-account-samples-history-info'),(174658,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','relative','','','.p-account-samples-history-info'),(174659,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','absolute','3','','.p-account-samples-history-info'),(174660,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','position','absolute','','','.p-account-samples-history-info'),(174661,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','position','absolute','','','.p-account-samples-history-info'),(174662,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','position','relative','','','.p-account-samples-history-info'),(174663,'deals-mobile','.p-catalog-product .prev-next-product','position','fixed','','','.p-catalog-product'),(174664,'deals-mobile','.p-catalog-product .pn-image','position','absolute','3','','.p-catalog-product'),(174665,'deals-mobile','.p-payer-order-confirmation .discount-ico','position','relative','3','','.p-payer-order-confirmation'),(174666,'deals-mobile','.p-payer-order-confirmation .comment-ico','position','relative','3','','.p-payer-order-confirmation'),(174667,'deals-mobile','.p-payer-order-confirmation .order-ico','position','relative','3','','.p-payer-order-confirmation'),(174668,'deals-mobile','.p-payer-order-pay .order-ico','position','relative','3','','.p-payer-order-pay'),(174669,'deals-mobile','.p-payer-order-pay .comment-ico','position','relative','3','','.p-payer-order-pay'),(174670,'deals-mobile','.p-payer-order-pay .discount-ico','position','relative','3','','.p-payer-order-pay'),(174671,'deals-mobile','.p-quick-order-index .all-scroll-div','position','fixed','','','.p-quick-order-index'),(174672,'deals-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(174673,'deals-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(174674,'deals-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(174675,'deals-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(174676,'deals-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(174677,'deals-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(174678,'deals-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(174679,'deals-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(174680,'deals-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(174681,'deals-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(174682,'deals-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(174683,'deals-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(174684,'deals-mobile','.p-sample-checkout-success .page-success > div','position','relative','','','.p-sample-checkout-success'),(174685,'deals-mobile','.p-sample-checkout-success .page-success','position','relative','','','.p-sample-checkout-success'),(174686,'deals-mobile','.savings-ico .heading-2','position','relative','3','','.savings-ico'),(174687,'deals-mobile','.shipping-ico .heading-2','position','relative','3','','.shipping-ico'),(174688,'deals-mobile','.shipping-ico .heading-2','position','relative','3','','.shipping-ico'),(174689,'deals-mobile','.shipping-ico .heading-2','position','relative','3','','.shipping-ico'),(174690,'deals-mobile','.w-account-address-book .heading-4','position','relative','','','.w-account-address-book'),(174691,'deals-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','position','relative','','','.w-account-addresses-list'),(174692,'deals-mobile','.w-blog-widget-categories-list a','position','relative','','','.w-blog-widget-categories-list'),(174693,'deals-mobile','.w-blog-widget-categories-list a','position','absolute','3','','.w-blog-widget-categories-list'),(174694,'deals-mobile','.w-blog-widget-most-popular-posts a','position','absolute','3','','.w-blog-widget-most-popular-posts'),(174695,'deals-mobile','.w-blog-widget-most-popular-posts a','position','relative','','','.w-blog-widget-most-popular-posts'),(174696,'deals-mobile','.w-blog-widget-post-comments-count span','position','relative','','','.w-blog-widget-post-comments-count'),(174697,'deals-mobile','.w-blog-widget-post-comments-count span','position','absolute','3','','.w-blog-widget-post-comments-count'),(174698,'deals-mobile','.w-blog-widget-post-linked-products .heading-2','position','relative','','','.w-blog-widget-post-linked-products'),(174699,'deals-mobile','.w-blog-widget-post-listing .post_comment','position','relative','','','.w-blog-widget-post-listing'),(174700,'deals-mobile','.w-blog-widget-post-listing .post_comment','position','absolute','3','','.w-blog-widget-post-listing'),(174701,'deals-mobile','.w-blog-widget-post-share ','position','absolute','4','','.w-blog-widget-post-share'),(174702,'deals-mobile','.w-blog-widget-post-share ','position','relative','','','.w-blog-widget-post-share'),(174703,'deals-mobile','.w-cart-bonus-points .btn-remove','position','relative','','','.w-cart-bonus-points'),(174704,'deals-mobile','.w-cart-bonus-points .title','position','relative','3','','.w-cart-bonus-points'),(174705,'deals-mobile','.w-cart-compare .remove-cart','position','absolute','','','.w-cart-compare'),(174706,'deals-mobile','.w-cart-compare .cart-cell > div','position','relative','','','.w-cart-compare'),(174707,'deals-mobile','.w-cart-compare .atr-col','position','absolute','3','','.w-cart-compare'),(174708,'deals-mobile','.w-cart-compare .atr-col','position','relative','','','.w-cart-compare'),(174709,'deals-mobile','.w-cart-credit-amount .btn-remove','position','relative','','','.w-cart-credit-amount'),(174710,'deals-mobile','.w-catalog-b2b-add-button ','position','fixed','','','.w-catalog-b2b-add-button'),(174711,'deals-mobile','.w-catalog-compare .compare .checkbox span','position','relative','','','.w-catalog-compare'),(174712,'deals-mobile','.w-catalog-paging .paging-holder','position','relative','','','.w-catalog-paging'),(174713,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','position','static','','','.w-catalog-paging'),(174714,'deals-mobile','.w-checkout-billing-address .addresses .address-item label','position','relative','','','.w-checkout-billing-address'),(174715,'deals-mobile','.w-checkout-billing-address .addresses .address-item label input','position','absolute','','','.w-checkout-billing-address'),(174716,'deals-mobile','.w-checkout-billing-address .genders-title input','position','relative','','','.w-checkout-billing-address'),(174717,'deals-mobile','.w-checkout-bonus-points .btn-remove','position','relative','','','.w-checkout-bonus-points'),(174718,'deals-mobile','.w-checkout-create-account .account-benefits strong','position','relative','3','','.w-checkout-create-account'),(174719,'deals-mobile','.w-checkout-credit-amount .btn-remove','position','relative','','','.w-checkout-credit-amount'),(174720,'deals-mobile','.w-checkout-shipping-address .addresses .address-item label input','position','absolute','','','.w-checkout-shipping-address'),(174721,'deals-mobile','.w-checkout-shipping-address .genders-title input','position','relative','','','.w-checkout-shipping-address'),(174722,'deals-mobile','.w-checkout-shipping-address .addresses .address-item label','position','relative','','','.w-checkout-shipping-address'),(174723,'deals-mobile','.w-checkout-shipping-choice input:checked + span','position','relative','','','.w-checkout-shipping-choice'),(174724,'deals-mobile','.w-checkout-shipping-choice input','position','absolute','','','.w-checkout-shipping-choice'),(174725,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','position','absolute','','','.w-checkout-shipping-choice'),(174726,'deals-mobile','.w-checkout-terms input[type=\"checkbox\"]','position','relative','','','.w-checkout-terms'),(174727,'deals-mobile','.w-checkout-terms .required-message-wrap','position','static','','','.w-checkout-terms'),(174728,'deals-mobile','.w-checkout-terms .terms-box','position','relative','','','.w-checkout-terms'),(174729,'deals-mobile','.w-coupons-and-vauchers-checkout .btn-remove','position','relative','','','.w-coupons-and-vauchers-checkout'),(174730,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','position','fixed','','','.w-image-maps'),(174731,'deals-mobile','.w-image-maps .svg-wrap svg','position','absolute','','','.w-image-maps'),(174732,'deals-mobile','.w-image-maps .svg-wrap','position','relative','','','.w-image-maps'),(174733,'deals-mobile','.w-multi-cart-actions .cart-actions','position','relative','','','.w-multi-cart-actions'),(174734,'deals-mobile','.w-neighbour-checkout .bootstrap-switch','position','relative','','','.w-neighbour-checkout'),(174735,'deals-mobile','.w-personal-gift-status-bar .inform','position','relative','4','','.w-personal-gift-status-bar'),(174736,'deals-mobile','.w-personal-gift-status-bar .end-date','position','relative','3','','.w-personal-gift-status-bar'),(174737,'deals-mobile','.w-product-customers-activity .customers-activity','position','fixed','','','.w-product-customers-activity'),(174738,'deals-mobile','.w-product-customers-activity .close','position','absolute','','','.w-product-customers-activity'),(174739,'deals-mobile','.w-promotions .prom-multi-discount .products','position','relative','','','.w-promotions'),(174740,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition','position','relative','','','.w-promotions'),(174741,'deals-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','position','relative','3','','.w-promotions'),(174742,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','position','relative','','','.w-promotions'),(174743,'deals-mobile','.w-promotions .promo-date','position','relative','','','.w-promotions'),(174744,'deals-mobile','.w-promotions .promo-cart-discount .slave .content','position','relative','','','.w-promotions'),(174745,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','position','relative','','','.w-promotions'),(174746,'deals-mobile','.w-promotions .promo-salemaker .discount','position','relative','','','.w-promotions'),(174747,'deals-mobile','.w-promotions .prom-multi-discount > .heading','position','relative','3','','.w-promotions'),(174748,'deals-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','position','relative','3','','.w-promotions'),(174749,'deals-mobile','.w-promotions .icon','position','relative','','','.w-promotions'),(174750,'deals-mobile','.w-reviews-content .review','position','absolute','3','','.w-reviews-content'),(174751,'deals-mobile','.w-reviews-content .review','position','relative','','','.w-reviews-content'),(174752,'deals-mobile','.w-taxable input[type=\"radio\"]','position','relative','','','.w-taxable'),(174753,'deals-mobile','.w-taxable input[type=\"checkbox\"]','position','relative','','','.w-taxable'),(174754,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(174755,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(174756,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(174757,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(174758,'deals-mobile','.w-wedding-registry-widgets-delete-link a','position','absolute','4','','.w-wedding-registry-widgets-delete-link'),(174759,'deals-mobile','.w-wedding-registry-widgets-delete-link a','position','relative','','','.w-wedding-registry-widgets-delete-link'),(174760,'deals-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','position','relative','','','.w-wedding-registry-widgets-manage-banner'),(174761,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','position','relative','','','.w-wedding-registry-widgets-photos'),(174762,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','position','relative','','','.w-wedding-registry-widgets-photos'),(174763,'deals-mobile','.w-wedding-registry-widgets-products .remove','position','absolute','','','.w-wedding-registry-widgets-products'),(174764,'deals-mobile','.w-wedding-registry-widgets-share-link a','position','relative','','','.w-wedding-registry-widgets-share-link'),(174765,'deals-mobile','.w-wedding-registry-widgets-share-link a','position','absolute','4','','.w-wedding-registry-widgets-share-link'),(174766,'deals-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position_important','important','','','.b-switch'),(174767,'deals-mobile','.w-menu .hided.menu > ul','position_important','important','','','.w-menu'),(174768,'deals-mobile','.b-autocomplete .ui-autocomplete','position_important','important','','','.b-autocomplete'),(174769,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position_important','important','','','.b-select-suggest'),(174770,'deals-mobile','.w-checkout-billing-address .addresses .address-item label input','position_important','important','','','.w-checkout-billing-address'),(174771,'deals-mobile','.w-checkout-shipping-address .addresses .address-item label input','position_important','important','','','.w-checkout-shipping-address'),(174772,'deals-mobile','.w-menu-slider .close','right','10','','','.w-menu-slider'),(174773,'deals-mobile','.w-menu-big > ul > li > ul','right','0','','','.w-menu-big'),(174774,'deals-mobile','.w-list-type-2_2 .sale','right','0','4','','.w-list-type-2_2'),(174775,'deals-mobile','.b-fancybox .fancybox-next span','right','10','','','.b-fancybox'),(174776,'deals-mobile','.b-pass-strength .pass-strength span','right','10','','','.b-pass-strength'),(174777,'deals-mobile','.b-info-popup .info-popup.top-left div','right','13','3','','.b-info-popup'),(174778,'deals-mobile','.b-info-popup .info-popup.top-left div','right','-10','','','.b-info-popup'),(174779,'deals-mobile','.p-wedding-registry-view h1','right','-10','4','','.p-wedding-registry-view'),(174780,'deals-mobile','.p-wedding-registry-manage .wr-search button','right','5','','','.p-wedding-registry-manage'),(174781,'deals-mobile','.p-account-history .orders-table .order-total','right','0','890','','.p-account-history'),(174782,'deals-mobile','.p-account-index .orders-table .order-total','right','0','890','','.p-account-index'),(174783,'deals-mobile','.w-list-type-2_2 .sale','right','0','3','','.w-list-type-2_2'),(174784,'deals-mobile','.w-list-type-2_2 .sale','right','0','','','.w-list-type-2_2'),(174785,'deals-mobile','.w-list-type-2 .sale','right','0','','','.w-list-type-2'),(174786,'deals-mobile','.w-list-type-2 .sale','right','0','4','','.w-list-type-2'),(174787,'deals-mobile','.b-fancybox .fancybox-close','right','0','','','.b-fancybox'),(174788,'deals-mobile','.b-fancybox .fancybox-next','right','0','','','.b-fancybox'),(174789,'deals-mobile','.p-wedding-registry-search h1','right','-10','4','','.p-wedding-registry-search'),(174790,'deals-mobile','.b-bottom .footerTitle','right','0','863,4','','.b-bottom'),(174791,'deals-mobile','.b-slick button.slick-prev','right','auto','','','.b-slick'),(174792,'deals-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','right','auto','','','.b-slick'),(174793,'deals-mobile','.b-slick button.slick-next','right','0','','','.b-slick'),(174794,'deals-mobile','.w-socials .post_item > div','right','10','3','','.w-socials'),(174795,'deals-mobile','.w-banner .image-text-banner.top-right .text-banner','right','0','','','.w-banner'),(174796,'deals-mobile','.w-banner .image-text-banner.middle-right .text-banner','right','0','','','.w-banner'),(174797,'deals-mobile','.w-banner .image-text-banner.bottom-right .text-banner','right','0','','','.w-banner'),(174798,'deals-mobile','.w-currencies .current','right','0','3','','.w-currencies'),(174799,'deals-mobile','.b-fancybox .fancybox-title-float-wrap','right','50','','','.b-fancybox'),(174800,'deals-mobile','.w-list-type-1_3 #add_all','right','20','','','.w-list-type-1_3'),(174801,'deals-mobile','.b-fancybox .fancybox-overlay-fixed','right','0','','','.b-fancybox'),(174802,'deals-mobile','.p-wedding-registry-share .invite-remove','right','0','','','.p-wedding-registry-share'),(174803,'deals-mobile','.w-list-type-1_3 .sale','right','0','4','','.w-list-type-1_3'),(174804,'deals-mobile','.w-list-type-1_3 .sale','right','0','','','.w-list-type-1_3'),(174805,'deals-mobile','.p-wedding-registry-manage h1','right','-10','4','','.p-wedding-registry-manage'),(174806,'deals-mobile','.w-list-type-1_3 .sale','right','0','3','','.w-list-type-1_3'),(174807,'deals-mobile','.p-wedding-registry-share h1','right','-10','4','','.p-wedding-registry-share'),(174808,'deals-mobile','.w-list-type-2 .sale','right','0','3','','.w-list-type-2'),(174809,'deals-mobile','.w-list-type-1_2 .sale','right','0','3','','.w-list-type-1_2'),(174810,'deals-mobile','.w-list-type-1_2 .sale','right','0','4','','.w-list-type-1_2'),(174811,'deals-mobile','.w-list-type-1_2 .sale','right','0','','','.w-list-type-1_2'),(174812,'deals-mobile','.b-bottom .pop-up-close','right','6','','','.b-bottom'),(174813,'deals-mobile','.w-list-type-1 .sale','right','0','4','','.w-list-type-1'),(174814,'deals-mobile','.w-list-type-1 .sale','right','0','3','','.w-list-type-1'),(174815,'deals-mobile','.w-list-type-1 .sale','right','0','','','.w-list-type-1'),(174816,'deals-mobile','.w-filters .mobileCollapse','right','12','','','.w-filters'),(174817,'deals-mobile','.w-languages .current','right','0','3','','.w-languages'),(174818,'deals-mobile','.w-search .button-search','right','0','','','.w-search'),(174819,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right','100','','','.b-menu-lev_display-left'),(174820,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right','100','','','.b-menu-lev_display-left'),(174821,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right','100','','','.b-menu-lev_display-left'),(174822,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right','100','','','.b-menu-lev_display-left'),(174823,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right','100','','','.b-menu-lev_display-left'),(174824,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right','100','','','.b-menu-lev_display-lra'),(174825,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right','100','','','.b-menu-lev_display-lra'),(174826,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right','100','','','.b-menu-lev_display-lra'),(174827,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right','100','','','.b-menu-lev_display-lra'),(174828,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right','100','','','.b-menu-lev_display-lra'),(174829,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','right','10','3','','.b-menu-style-2'),(174830,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .parent > .no-link','right','40','3','','.b-menu-style-2'),(174831,'deals-mobile','.b-select-suggest .select2-search-choice-close','right','3','','','.b-select-suggest'),(174832,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','right','0','','','.b-select-suggest'),(174833,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','right','24','','','.b-select-suggest'),(174834,'deals-mobile','.b-upload-file .snapshot','right','5','','','.b-upload-file'),(174835,'deals-mobile','.b-upload-file .upload-remove','right','10','','','.b-upload-file'),(174836,'deals-mobile','.batchPr .w-batch-products .products-listing .slick-next','right','-10','','','.batchPr'),(174837,'deals-mobile','.batchPr .batchSelect','right','20','','','.batchPr'),(174838,'deals-mobile','.batchPr .btn-batch-remove','right','0','','','.batchPr'),(174839,'deals-mobile','.p-account-samples-history .orders-table .order-total','right','0','','','.p-account-samples-history'),(174840,'deals-mobile','.p-account-samples-history .orders-table .order-total','right','0','','','.p-account-samples-history'),(174841,'deals-mobile','.p-account-samples-history .orders-table .order-total','right','0','','','.p-account-samples-history'),(174842,'deals-mobile','.p-account-samples-history .orders-table .order-total','right','0','','','.p-account-samples-history'),(174843,'deals-mobile','.p-account-samples-history .orders-table .order-total','right','0','','','.p-account-samples-history'),(174844,'deals-mobile','.p-account-samples-history .orders-table .order-total','right','0','','','.p-account-samples-history'),(174845,'deals-mobile','.p-catalog-product .next-product','right','0','','','.p-catalog-product'),(174846,'deals-mobile','.p-catalog-product .next-product .pn-image','right','20','3','','.p-catalog-product'),(174847,'deals-mobile','.w-account-address-book .btn-del','right','0','','','.w-account-address-book'),(174848,'deals-mobile','.w-blog-widget-post-linked-products button.slick-next','right','10','','','.w-blog-widget-post-linked-products'),(174849,'deals-mobile','.w-blog-widget-post-share ','right','100','4','','.w-blog-widget-post-share'),(174850,'deals-mobile','.w-blog-widget-post-share','right','auto','0,4','','.w-blog-widget-post-share'),(174851,'deals-mobile','.w-blog-widget-related-posts button.slick-next','right','10','','','.w-blog-widget-related-posts'),(174852,'deals-mobile','.w-blog-widget-related-posts-by-category button.slick-next','right','10','','','.w-blog-widget-related-posts-by-category'),(174853,'deals-mobile','.w-cart-compare .dropdown .dropdown-menu','right','0','','','.w-cart-compare'),(174854,'deals-mobile','.w-cart-compare .atr-col','right','0','3','','.w-cart-compare'),(174855,'deals-mobile','.w-cart-compare .remove-cart','right','0','','','.w-cart-compare'),(174856,'deals-mobile','.w-multi-cart-actions .dropdown .dropdown-menu','right','0','','','.w-multi-cart-actions'),(174857,'deals-mobile','.w-product-customers-activity .customers-activity','right','20','','','.w-product-customers-activity'),(174858,'deals-mobile','.w-product-customers-activity .close','right','5','','','.w-product-customers-activity'),(174859,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','right','5','','','.w-upload-customer-id-upload-customer-id-form'),(174860,'deals-mobile','.w-wedding-registry-widgets-products .remove','right','0','','','.w-wedding-registry-widgets-products'),(174861,'deals-mobile','.b-fancybox .fancybox-title-float-wrap','right_measure','%','','','.b-fancybox'),(174862,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right_measure','%','','','.b-menu-lev_display-left'),(174863,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right_measure','%','','','.b-menu-lev_display-left'),(174864,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right_measure','%','','','.b-menu-lev_display-left'),(174865,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right_measure','%','','','.b-menu-lev_display-left'),(174866,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right_measure','%','','','.b-menu-lev_display-left'),(174867,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right_measure','%','','','.b-menu-lev_display-lra'),(174868,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right_measure','%','','','.b-menu-lev_display-lra'),(174869,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right_measure','%','','','.b-menu-lev_display-lra'),(174870,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right_measure','%','','','.b-menu-lev_display-lra'),(174871,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right_measure','%','','','.b-menu-lev_display-lra'),(174872,'deals-mobile','.b-info-popup .info-popup.top-left div','rotate','-135','3','','.b-info-popup'),(174873,'deals-mobile','.b-info-popup .info-popup div','rotate','-45','3','','.b-info-popup'),(174874,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','rotate','45','','','.w-checkout-shipping-choice'),(174875,'deals-mobile','.w-image-maps circle:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(174876,'deals-mobile','.w-image-maps rect:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(174877,'deals-mobile','.w-image-maps polygon:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(174878,'deals-mobile','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','stroke-width','0','','','.w-image-maps'),(174879,'deals-mobile','.w-tabs .tab-navigation','table-layout','fixed','','','.w-tabs'),(174880,'deals-mobile','.w-menu-big li a, .w-menu-big li .no-link','text-align','left','','','.w-menu-big'),(174881,'deals-mobile','.w-menu-big li li li','text-align','left','','','.w-menu-big'),(174882,'deals-mobile','.w-menu-slider > ul','text-align','center','','','.w-menu-slider'),(174883,'deals-mobile','.w-menu-slider .close','text-align','center','','','.w-menu-slider'),(174884,'deals-mobile','.w-menu-horizontal .box','text-align','center','','','.w-menu-horizontal'),(174885,'deals-mobile','.w-menu-slider > ul > li > ul','text-align','center','','','.w-menu-slider'),(174886,'deals-mobile','.w-bestsellers .item','text-align','center','3','','.w-bestsellers'),(174887,'deals-mobile','.w-menu-slider > ul > li > ul li','text-align','left','','','.w-menu-slider'),(174888,'deals-mobile','.w-bestsellers .counter','text-align','center','','','.w-bestsellers'),(174889,'deals-mobile','.b-social-login .social-login','text-align','center','','','.b-social-login'),(174890,'deals-mobile','.w-tabs .accordion-heading','text-align','center','','','.w-tabs'),(174891,'deals-mobile','.w-menu-style-1 .box','text-align','center','','','.w-menu-style-1'),(174892,'deals-mobile','.w-product-sale-ends .left','text-align','center','','','.w-product-sale-ends'),(174893,'deals-mobile','.w-sale .btn','text-align','center','','','.w-sale'),(174894,'deals-mobile','.w-login-block .buttons','text-align','right','','','.w-login-block'),(174895,'deals-mobile','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(174896,'deals-mobile','.w-menu-horizontal .menu-ico','text-align','center','','','.w-menu-horizontal'),(174897,'deals-mobile','.w-list-type-2_2 .sale','text-align','center','4','','.w-list-type-2_2'),(174898,'deals-mobile','.w-sale .image','text-align','center','','','.w-sale'),(174899,'deals-mobile','.w-sale .badge','text-align','center','','','.w-sale'),(174900,'deals-mobile','.w-menu-style-1 .menu-ico','text-align','center','','','.w-menu-style-1'),(174901,'deals-mobile','.w-menu-style-1 > ul','text-align','center','','','.w-menu-style-1'),(174902,'deals-mobile','.w-menu-slider .menu-ico','text-align','center','','','.w-menu-slider'),(174903,'deals-mobile','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(174904,'deals-mobile','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(174905,'deals-mobile','.w-product-collection .item','text-align','center','','','.w-product-collection'),(174906,'deals-mobile','.w-cart .price','text-align','right','','','.w-cart'),(174907,'deals-mobile','.b-fancybox .fancybox-nav span','text-align','center','','','.b-fancybox'),(174908,'deals-mobile','.p-reviews-info .review-info-image','text-align','center','','','.p-reviews-info'),(174909,'deals-mobile','.b-product-images .additional-images .item > div, .b-product-images .additional-videos .item > div','text-align','center','','','.b-product-images'),(174910,'deals-mobile','.w-product-buttons .btn, .w-product-buttons .btn-2, .w-product-buttons .btn-3, .w-product-buttons .btn-4','text-align','center','','','.w-product-buttons'),(174911,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','text-align','left','','','.p-account-history-info'),(174912,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','text-align','left','3','','.p-account-history-info'),(174913,'deals-mobile','.p-account-index .badc_bottom','text-align','center','','','.p-account-index'),(174914,'deals-mobile','.w-categories .categories','text-align','center','','','.w-categories'),(174915,'deals-mobile','.w-categories .item','text-align','center','','','.w-categories'),(174916,'deals-mobile','.w-cart-checkout-btn a','text-align','center','863','','.w-cart-checkout-btn'),(174917,'deals-mobile','.b-price-box .price-box','text-align','right','','','.b-price-box'),(174918,'deals-mobile','.w-product-images .images','text-align','center','','','.w-product-images'),(174919,'deals-mobile','.w-success-continue-btn','text-align','center','864','','.w-success-continue-btn'),(174920,'deals-mobile','.p-account-index .topAccount > li > div','text-align','left','863','','.p-account-index'),(174921,'deals-mobile','.w-catalog-listing-look .b2b','text-align','center','','','.w-catalog-listing-look'),(174922,'deals-mobile','.view-all','text-align','center','','',''),(174923,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','text-align','center','3','','.b-multi-page-checkout'),(174924,'deals-mobile','.w-list-type-1_2 .image','text-align','center','864','','.w-list-type-1_2'),(174925,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','text-align','center','','','.b-multi-page-checkout'),(174926,'deals-mobile','.b-multi-page-checkout .messageBox .info','text-align','left','','','.b-multi-page-checkout'),(174927,'deals-mobile','.p-wedding-registry-manage .remove','text-align','right','','','.p-wedding-registry-manage'),(174928,'deals-mobile','.w-delivery-location-top-location-list .deliveryName','text-align','center','','','.w-delivery-location-top-location-list'),(174929,'deals-mobile','.p-account-history-info .trackings-nambers','text-align','center','','','.p-account-history-info'),(174930,'deals-mobile','.p-account-history-info .popup-tracking-number','text-align','center','','','.p-account-history-info'),(174931,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','text-align','left','','','.p-account-order-pay'),(174932,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','text-align','left','3','','.p-account-order-pay'),(174933,'deals-mobile','.p-account-order-pay .historyTotal table td','text-align','right','','','.p-account-order-pay'),(174934,'deals-mobile','.p-account-order-pay .tableForm th','text-align','left','','','.p-account-order-pay'),(174935,'deals-mobile','.w-product-configurator .pc_qty','text-align','left','863','','.w-product-configurator'),(174936,'deals-mobile','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(174937,'deals-mobile','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(174938,'deals-mobile','.b-pagination .pagination .prev-pages','text-align','center','','','.b-pagination'),(174939,'deals-mobile','.b-bottom .confirm-popup .confirm-text','text-align','center','','','.b-bottom'),(174940,'deals-mobile','.b-bottom .confirm-popup .buttons','text-align','center','','','.b-bottom'),(174941,'deals-mobile','.b-pagination .pagination .prev','text-align','center','','','.b-pagination'),(174942,'deals-mobile','.b-pagination .pagination .page-number','text-align','center','','','.b-pagination'),(174943,'deals-mobile','.b-pagination .pagination .p-blog-index','text-align','right','','','.b-pagination'),(174944,'deals-mobile','.b-pagination .pagination .next','text-align','center','','','.b-pagination'),(174945,'deals-mobile','.b-pagination .pagination .next-pages','text-align','center','','','.b-pagination'),(174946,'deals-mobile','.b-pagination .pagination span','text-align','center','2','','.b-pagination'),(174947,'deals-mobile','.p-account-history .orders-table td.td-alignright','text-align','right','','','.p-account-history'),(174948,'deals-mobile','.p-account-history .orders-table th','text-align','left','','','.p-account-history'),(174949,'deals-mobile','.p-account-history-info .tableForm th','text-align','left','','','.p-account-history-info'),(174950,'deals-mobile','.p-blog-index .nav-next','text-align','right','','','.p-blog-index'),(174951,'deals-mobile','.p-blog-index .form-submit','text-align','right','','','.p-blog-index'),(174952,'deals-mobile','.pop-up-content .buttons .btn-2','text-align','center','864','',''),(174953,'deals-mobile','.pop-up-content .buttons .btn','text-align','center','864','',''),(174954,'deals-mobile','.no-found','text-align','center','','',''),(174955,'deals-mobile','.w-list-type-2_2 .item','text-align','left','','','.w-list-type-2_2'),(174956,'deals-mobile','.w-list-type-2_2 .image','text-align','center','','','.w-list-type-2_2'),(174957,'deals-mobile','.w-list-type-2_2 .button-wishlist button','text-align','left','','','.w-list-type-2_2'),(174958,'deals-mobile','.w-list-type-2_2 .button-view a','text-align','left','','','.w-list-type-2_2'),(174959,'deals-mobile','.w-product-bonus-points > div > div','text-align','center','','','.w-product-bonus-points'),(174960,'deals-mobile','.w-account .account-title','text-align','center','','','.w-account'),(174961,'deals-mobile','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(174962,'deals-mobile','.b-fancybox .fancybox-close','text-align','center','','','.b-fancybox'),(174963,'deals-mobile','.w-menu-horizontal ul ul li','text-align','left','','','.w-menu-horizontal'),(174964,'deals-mobile','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(174965,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','text-align','center','3','','.b-form'),(174966,'deals-mobile','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(174967,'deals-mobile','.b-form .wedding-form .heading-2','text-align','left','','','.b-form'),(174968,'deals-mobile','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(174969,'deals-mobile','.p-quote-cart-index .w-quote-checkout-btn','text-align','right','','','.p-quote-cart-index'),(174970,'deals-mobile','.p-wedding-registry-index .middle-box','text-align','center','','','.p-wedding-registry-index'),(174971,'deals-mobile','.p-wedding-registry-manage .links','text-align','center','','','.p-wedding-registry-manage'),(174972,'deals-mobile','.b-bottom .alert-message','text-align','center','','','.b-bottom'),(174973,'deals-mobile','.p-wedding-registry-manage .wedding-date','text-align','center','','','.p-wedding-registry-manage'),(174974,'deals-mobile','.p-wedding-registry-share .heading-3','text-align','center','','','.p-wedding-registry-share'),(174975,'deals-mobile','.p-wedding-registry-search .result-table td:nth-child(4)','text-align','right','','','.p-wedding-registry-search'),(174976,'deals-mobile','.p-wedding-registry-search #searchform-status label','text-align','right','','','.p-wedding-registry-search'),(174977,'deals-mobile','.p-wedding-registry-search .button','text-align','right','','','.p-wedding-registry-search'),(174978,'deals-mobile','.b-pagination .pagination a','text-align','center','','','.b-pagination'),(174979,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','text-align','center','3','','.b-switch'),(174980,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','text-align','center','3','','.b-switch'),(174981,'deals-mobile','.b-compare .compare-head','text-align','left','','','.b-compare'),(174982,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-align','left','','','.b-switch'),(174983,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-label','text-align','center','','','.b-switch'),(174984,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-align','right','','','.b-switch'),(174985,'deals-mobile','.b-switch .bootstrap-switch','text-align','left','','','.b-switch'),(174986,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','text-align','center','','','.b-slick'),(174987,'deals-mobile','.b-form .center-buttons','text-align','center','','','.b-form'),(174988,'deals-mobile','.w-top-categories .item','text-align','center','','','.w-top-categories'),(174989,'deals-mobile','.w-top-categories .categories','text-align','center','','','.w-top-categories'),(174990,'deals-mobile','.w-search .suggest','text-align','left','','','.w-search'),(174991,'deals-mobile','.w-tabs .tab-a','text-align','center','','','.w-tabs'),(174992,'deals-mobile','.w-search .search','text-align','center','3','','.w-search'),(174993,'deals-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','text-align','center','','','.w-banner'),(174994,'deals-mobile','.p-account-trade-form .widget h3','text-align','center','','','.p-account-trade-form'),(174995,'deals-mobile','.p-checkout-index .shipping-estimator .info','text-align','center','','','.p-checkout-index'),(174996,'deals-mobile','.p-quote-cart-index .cart-page .empty','text-align','center','','','.p-quote-cart-index'),(174997,'deals-mobile','.p-shopping-cart-index .cart-page .empty','text-align','center','','','.p-shopping-cart-index'),(174998,'deals-mobile','.w-filters .handle-to','text-align','right','','','.w-filters'),(174999,'deals-mobile','.w-compare-box-item .checkbox:checked + span:before','text-align','center','','','.w-compare-box-item'),(175000,'deals-mobile','.b-fancybox .fancybox-title-float-wrap','text-align','center','','','.b-fancybox'),(175001,'deals-mobile','.p-account-trade-form .trade-form-area','text-align','center','','','.p-account-trade-form'),(175002,'deals-mobile','.w-menu .hided.menu ul li','text-align','left','890','','.w-menu'),(175003,'deals-mobile','.p-account-index th.wish_remove_title, .p-account-index td.acc_wish_remove','text-align','center','','','.p-account-index'),(175004,'deals-mobile','.p-account-index th, .p-account-index td','text-align','left','','','.p-account-index'),(175005,'deals-mobile','.p-account-index td.td-alignright','text-align','right','','','.p-account-index'),(175006,'deals-mobile','.p-checkout-success .page-success','text-align','center','','','.p-checkout-success'),(175007,'deals-mobile','.w-menu-mobile .menu-ico','text-align','center','','','.w-menu-mobile'),(175008,'deals-mobile','.p-account-index .topAccount > li > div','text-align','center','','','.p-account-index'),(175009,'deals-mobile','.p-account-index .topAccount > li > div','text-align','center','3','','.p-account-index'),(175010,'deals-mobile','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(175011,'deals-mobile','.w-catalog-listing-look .list','text-align','center','','','.w-catalog-listing-look'),(175012,'deals-mobile','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(175013,'deals-mobile','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(175014,'deals-mobile','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(175015,'deals-mobile','.w-menu-style-1 ul ul li','text-align','left','','','.w-menu-style-1'),(175016,'deals-mobile','.p-account-history-info .historyTotal table td','text-align','right','','','.p-account-history-info'),(175017,'deals-mobile','.p-wedding-registry-share .add-row','text-align','right','','','.p-wedding-registry-share'),(175018,'deals-mobile','.w-sale .left','text-align','center','','','.w-sale'),(175019,'deals-mobile','.b-page-name .page-name','text-align','center','','','.b-page-name'),(175020,'deals-mobile','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(175021,'deals-mobile','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(175022,'deals-mobile','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(175023,'deals-mobile','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(175024,'deals-mobile','.w-list-type-1_3 .image','text-align','center','864','','.w-list-type-1_3'),(175025,'deals-mobile','.w-catalog-listing-look .grid','text-align','center','','','.w-catalog-listing-look'),(175026,'deals-mobile','.p-account-index .orders-table th','text-align','left','','','.p-account-index'),(175027,'deals-mobile','.w-cart-give-away .ga_img','text-align','center','','','.w-cart-give-away'),(175028,'deals-mobile','.heading-2, h2','text-align','center','','',''),(175029,'deals-mobile','h1','text-align','center','','',''),(175030,'deals-mobile','.w-list-type-1_3 .sale','text-align','center','4','','.w-list-type-1_3'),(175031,'deals-mobile','.w-list-type-2 .button-view a','text-align','left','','','.w-list-type-2'),(175032,'deals-mobile','.w-list-type-2 .sale','text-align','center','4','','.w-list-type-2'),(175033,'deals-mobile','.w-list-type-2 .item','text-align','left','','','.w-list-type-2'),(175034,'deals-mobile','.w-list-type-2 .button-wishlist button','text-align','left','','','.w-list-type-2'),(175035,'deals-mobile','.w-list-type-1_3 .image','text-align','center','','','.w-list-type-1_3'),(175036,'deals-mobile','.w-list-type-1_3 .item','text-align','left','','','.w-list-type-1_3'),(175037,'deals-mobile','.w-list-type-1_3 .button-wishlist button','text-align','left','','','.w-list-type-1_3'),(175038,'deals-mobile','.w-list-type-1_3 .button-view a','text-align','left','','','.w-list-type-1_3'),(175039,'deals-mobile','.w-list-type-1_2 .sale','text-align','center','4','','.w-list-type-1_2'),(175040,'deals-mobile','.w-list-type-1_2 .item','text-align','left','','','.w-list-type-1_2'),(175041,'deals-mobile','.w-list-type-1_2 .image','text-align','center','','','.w-list-type-1_2'),(175042,'deals-mobile','.w-list-type-1_2 .button-wishlist button','text-align','left','','','.w-list-type-1_2'),(175043,'deals-mobile','.w-list-type-1_2 .button-view a','text-align','left','','','.w-list-type-1_2'),(175044,'deals-mobile','.b-bottom .pop-up-close','text-align','center','','','.b-bottom'),(175045,'deals-mobile','.w-list-type-1 .sale','text-align','center','4','','.w-list-type-1'),(175046,'deals-mobile','.w-list-type-1 .image a','text-align','center','','','.w-list-type-1'),(175047,'deals-mobile','.w-list-type-1 .image','text-align','center','','','.w-list-type-1'),(175048,'deals-mobile','.w-list-type-1 .item','text-align','left','','','.w-list-type-1'),(175049,'deals-mobile','.w-list-type-1 .button-wishlist button','text-align','left','','','.w-list-type-1'),(175050,'deals-mobile','.w-list-type-1 .button-view a','text-align','left','','','.w-list-type-1'),(175051,'deals-mobile','.p-account-address-book .address_book h2','text-align','right','','','.p-account-address-book'),(175052,'deals-mobile','.b-products-listing .btn-choose-options','text-align','center','','','.b-products-listing'),(175053,'deals-mobile','.b-products-listing .products-listing','text-align','center','','','.b-products-listing'),(175054,'deals-mobile','.b-products-listing .products-listing .btn-buy','text-align','center','','','.b-products-listing'),(175055,'deals-mobile','.b-products-listing .products-listing .btn-preloader','text-align','center','','','.b-products-listing'),(175056,'deals-mobile','.b-products-listing .products-listing .buyButton .btn','text-align','center','','','.b-products-listing'),(175057,'deals-mobile','.b-products-listing .products-listing .image','text-align','center','','','.b-products-listing'),(175058,'deals-mobile','.b-products-listing .products-listing .in-cart','text-align','center','','','.b-products-listing'),(175059,'deals-mobile','.b-products-listing .products-listing .mult-qty-input','text-align','right','','','.b-products-listing'),(175060,'deals-mobile','.b-products-listing .products-listing .properties','text-align','left','','','.b-products-listing'),(175061,'deals-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','text-align','left','','','.b-products-listing'),(175062,'deals-mobile','.b-products-listing .show-ofstock-products','text-align','center','','','.b-products-listing'),(175063,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.b-data-table'),(175064,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.b-data-table'),(175065,'deals-mobile','.b-data-table .dt-body-center','text-align','center','','','.b-data-table'),(175066,'deals-mobile','.b-data-table table.dataTable tbody td:last-child','text-align','right','','','.b-data-table'),(175067,'deals-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(175068,'deals-mobile','.b-email .qty','text-align','center','','','.b-email'),(175069,'deals-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(175070,'deals-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(175071,'deals-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(175072,'deals-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(175073,'deals-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(175074,'deals-mobile','.b-email .price','text-align','right','','','.b-email'),(175075,'deals-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(175076,'deals-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(175077,'deals-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(175078,'deals-mobile','.b-email .price','text-align','right','','','.b-email'),(175079,'deals-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(175080,'deals-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(175081,'deals-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(175082,'deals-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(175083,'deals-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(175084,'deals-mobile','.b-email .price','text-align','right','','','.b-email'),(175085,'deals-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(175086,'deals-mobile','.b-email .price','text-align','right','','','.b-email'),(175087,'deals-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(175088,'deals-mobile','.b-email .price','text-align','right','','','.b-email'),(175089,'deals-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(175090,'deals-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(175091,'deals-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(175092,'deals-mobile','.b-email .model','text-align','center','','','.b-email'),(175093,'deals-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(175094,'deals-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(175095,'deals-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(175096,'deals-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(175097,'deals-mobile','.b-email .model','text-align','center','','','.b-email'),(175098,'deals-mobile','.b-email .model','text-align','center','','','.b-email'),(175099,'deals-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(175100,'deals-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(175101,'deals-mobile','.b-email .model','text-align','center','','','.b-email'),(175102,'deals-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(175103,'deals-mobile','.b-email .price','text-align','right','','','.b-email'),(175104,'deals-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(175105,'deals-mobile','.b-email .model','text-align','center','','','.b-email'),(175106,'deals-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(175107,'deals-mobile','.b-email .qty','text-align','center','','','.b-email'),(175108,'deals-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(175109,'deals-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(175110,'deals-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(175111,'deals-mobile','.b-email .qty','text-align','center','','','.b-email'),(175112,'deals-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(175113,'deals-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(175114,'deals-mobile','.b-email .qty','text-align','center','','','.b-email'),(175115,'deals-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(175116,'deals-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(175117,'deals-mobile','.b-email .model','text-align','center','','','.b-email'),(175118,'deals-mobile','.b-email .qty','text-align','center','','','.b-email'),(175119,'deals-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(175120,'deals-mobile','.b-email .qty','text-align','center','','','.b-email'),(175121,'deals-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(175122,'deals-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(175123,'deals-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(175124,'deals-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(175125,'deals-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(175126,'deals-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(175127,'deals-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(175128,'deals-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(175129,'deals-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(175130,'deals-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(175131,'deals-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(175132,'deals-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(175133,'deals-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(175134,'deals-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(175135,'deals-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(175136,'deals-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(175137,'deals-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(175138,'deals-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(175139,'deals-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(175140,'deals-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(175141,'deals-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(175142,'deals-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(175143,'deals-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(175144,'deals-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(175145,'deals-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','text-align','center','','','.b-menu-burger_icon'),(175146,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(175147,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(175148,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(175149,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(175150,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(175151,'deals-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(175152,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','text-align','center','','','.b-menu-style-2'),(175153,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','text-align','center','','','.b-menu-style-2'),(175154,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','text-align','right','','','.b-menu-style-2'),(175155,'deals-mobile','.b-messages .msv_to_cc, .b-messages .msv_btn','text-align','left','','','.b-messages'),(175156,'deals-mobile','.b-messages .msv_content','text-align','left','','','.b-messages'),(175157,'deals-mobile','.b-messages .attach-view','text-align','left','','','.b-messages'),(175158,'deals-mobile','.b-messages .msv_history','text-align','left','','','.b-messages'),(175159,'deals-mobile','.b-messages .development-content','text-align','left','','','.b-messages'),(175160,'deals-mobile','.b-messages .messages-sidebar .heading-2','text-align','center','','','.b-messages'),(175161,'deals-mobile','.b-messages .messages-sidebar .btn-2','text-align','center','','','.b-messages'),(175162,'deals-mobile','.b-messages .emailBtn','text-align','right','','','.b-messages'),(175163,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','text-align','left','','','.b-messages'),(175164,'deals-mobile','.b-personal-catalog-popup #personal_catalog_popup','text-align','left','','','.b-personal-catalog-popup'),(175165,'deals-mobile','.b-sub-totals .historyTotal table td','text-align','right','','','.b-sub-totals'),(175166,'deals-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(175167,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(175168,'deals-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(175169,'deals-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(175170,'deals-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(175171,'deals-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(175172,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(175173,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(175174,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(175175,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(175176,'deals-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(175177,'deals-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(175178,'deals-mobile','.b-trade-approval .steps-bar li','text-align','center','','','.b-trade-approval'),(175179,'deals-mobile','.b-trade-approval .steps-bar li a','text-align','center','','','.b-trade-approval'),(175180,'deals-mobile','.b-trade-approval .orders-table td:nth-child(1), .b-trade-approval .orders-table th:nth-child(1)','text-align','left','','','.b-trade-approval'),(175181,'deals-mobile','.b-trade-approval .orders-table td:nth-child(2)','text-align','right','','','.b-trade-approval'),(175182,'deals-mobile','.b-trade-approval .w-login-block label','text-align','left','','','.b-trade-approval'),(175183,'deals-mobile','.b-trade-approval .steps-bar','text-align','left','','','.b-trade-approval'),(175184,'deals-mobile','.b-trade-approval .center-buttons','text-align','center','','','.b-trade-approval'),(175185,'deals-mobile','.b-trade-approval .comments','text-align','left','','','.b-trade-approval'),(175186,'deals-mobile','.b-upload-file .upload-file-template','text-align','center','','','.b-upload-file'),(175187,'deals-mobile','.b-upload-file .snapshot','text-align','center','','','.b-upload-file'),(175188,'deals-mobile','.batchPr .w-batch-products .products-listing .image + .type-1','text-align','left','','','.batchPr'),(175189,'deals-mobile','.batchPr .checkbox input:not(checked) + span:before','text-align','center','','','.batchPr'),(175190,'deals-mobile','.batchPr .checkbox input + span','text-align','center','','','.batchPr'),(175191,'deals-mobile','.batchPr .btn-batch-remove','text-align','center','3','','.batchPr'),(175192,'deals-mobile','.batchPr .buttons','text-align','center','','','.batchPr'),(175193,'deals-mobile','.batchPr .batchSelect .checkbox','text-align','center','','','.batchPr'),(175194,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','text-align','left','','','.batchPr'),(175195,'deals-mobile','.batchPr .checkbox input:checked + span:before','text-align','center','','','.batchPr'),(175196,'deals-mobile','.batchPr .batch-selected-products-empty','text-align','center','','','.batchPr'),(175197,'deals-mobile','.batchPr .batch-selected-products-total','text-align','center','','','.batchPr'),(175198,'deals-mobile','.p-account-samples-history .orders-table th','text-align','left','','','.p-account-samples-history'),(175199,'deals-mobile','.p-account-samples-history .orders-table th','text-align','left','','','.p-account-samples-history'),(175200,'deals-mobile','.p-account-samples-history .orders-table td.td-alignright','text-align','right','','','.p-account-samples-history'),(175201,'deals-mobile','.p-account-samples-history .orders-table th','text-align','left','','','.p-account-samples-history'),(175202,'deals-mobile','.p-account-samples-history .orders-table td.td-alignright','text-align','right','','','.p-account-samples-history'),(175203,'deals-mobile','.p-account-samples-history .orders-table th','text-align','left','','','.p-account-samples-history'),(175204,'deals-mobile','.p-account-samples-history .orders-table td.td-alignright','text-align','right','','','.p-account-samples-history'),(175205,'deals-mobile','.p-account-samples-history .orders-table th','text-align','left','','','.p-account-samples-history'),(175206,'deals-mobile','.p-account-samples-history .orders-table td.td-alignright','text-align','right','','','.p-account-samples-history'),(175207,'deals-mobile','.p-account-samples-history .orders-table td.td-alignright','text-align','right','','','.p-account-samples-history'),(175208,'deals-mobile','.p-account-samples-history .orders-table th','text-align','left','','','.p-account-samples-history'),(175209,'deals-mobile','.p-account-samples-history .orders-table td.td-alignright','text-align','right','','','.p-account-samples-history'),(175210,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','','','.p-account-samples-history-info'),(175211,'deals-mobile','.p-account-samples-history-info .trackings-nambers','text-align','center','','','.p-account-samples-history-info'),(175212,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','text-align','center','','','.p-account-samples-history-info'),(175213,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','3','','.p-account-samples-history-info'),(175214,'deals-mobile','.p-account-samples-history-info .tableForm th','text-align','left','','','.p-account-samples-history-info'),(175215,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','text-align','center','','','.p-account-samples-history-info'),(175216,'deals-mobile','.p-account-samples-history-info .tableForm th','text-align','left','','','.p-account-samples-history-info'),(175217,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','3','','.p-account-samples-history-info'),(175218,'deals-mobile','.p-account-samples-history-info .tableForm th','text-align','left','','','.p-account-samples-history-info'),(175219,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','','','.p-account-samples-history-info'),(175220,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','','','.p-account-samples-history-info'),(175221,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','text-align','center','','','.p-account-samples-history-info'),(175222,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','3','','.p-account-samples-history-info'),(175223,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','text-align','center','','','.p-account-samples-history-info'),(175224,'deals-mobile','.p-account-samples-history-info .trackings-nambers','text-align','center','','','.p-account-samples-history-info'),(175225,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','text-align','center','','','.p-account-samples-history-info'),(175226,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','','','.p-account-samples-history-info'),(175227,'deals-mobile','.p-account-samples-history-info .popup-tracking-number','text-align','center','','','.p-account-samples-history-info'),(175228,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','3','','.p-account-samples-history-info'),(175229,'deals-mobile','.p-account-samples-history-info .trackings-nambers','text-align','center','','','.p-account-samples-history-info'),(175230,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','3','','.p-account-samples-history-info'),(175231,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','','','.p-account-samples-history-info'),(175232,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','','','.p-account-samples-history-info'),(175233,'deals-mobile','.p-account-samples-history-info .trackings-nambers','text-align','center','','','.p-account-samples-history-info'),(175234,'deals-mobile','.p-account-samples-history-info .tableForm th','text-align','left','','','.p-account-samples-history-info'),(175235,'deals-mobile','.p-account-samples-history-info .trackings-nambers','text-align','center','','','.p-account-samples-history-info'),(175236,'deals-mobile','.p-account-samples-history-info .tableForm th','text-align','left','','','.p-account-samples-history-info'),(175237,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-align','left','3','','.p-account-samples-history-info'),(175238,'deals-mobile','.p-account-samples-history-info .trackings-nambers','text-align','center','','','.p-account-samples-history-info'),(175239,'deals-mobile','.p-account-samples-history-info .tableForm th','text-align','left','','','.p-account-samples-history-info'),(175240,'deals-mobile','.p-catalog-product .prev-next-product','text-align','center','','','.p-catalog-product'),(175241,'deals-mobile','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align','left','','','.p-quick-order-index'),(175242,'deals-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','text-align','center','','','.p-quick-order-index'),(175243,'deals-mobile','.p-quick-order-index .all-scroll-div td + td','text-align','right','','','.p-quick-order-index'),(175244,'deals-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','text-align','center','','','.p-quick-order-index'),(175245,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.p-quick-order-index'),(175246,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.p-quick-order-index'),(175247,'deals-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(175248,'deals-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(175249,'deals-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(175250,'deals-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(175251,'deals-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(175252,'deals-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(175253,'deals-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(175254,'deals-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(175255,'deals-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(175256,'deals-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(175257,'deals-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(175258,'deals-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(175259,'deals-mobile','.p-sample-checkout-success .page-success','text-align','center','','','.p-sample-checkout-success'),(175260,'deals-mobile','.w-account-address-book .button-add','text-align','right','','','.w-account-address-book'),(175261,'deals-mobile','.w-account-address-book .add_item a','text-align','center','','','.w-account-address-book'),(175262,'deals-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(175263,'deals-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(175264,'deals-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(175265,'deals-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(175266,'deals-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(175267,'deals-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(175268,'deals-mobile','.w-account-personal-catalog .list-switcher a','text-align','center','','','.w-account-personal-catalog'),(175269,'deals-mobile','.w-blog-widget-post-date ','text-align','center','','','.w-blog-widget-post-date'),(175270,'deals-mobile','.w-blog-widget-post-linked-products .heading-2','text-align','center','','','.w-blog-widget-post-linked-products'),(175271,'deals-mobile','.w-blog-widget-post-listing .post_date','text-align','center','','','.w-blog-widget-post-listing'),(175272,'deals-mobile','.w-blog-widget-post-listing .post_image','text-align','center','','','.w-blog-widget-post-listing'),(175273,'deals-mobile','.w-blog-widget-post-listing .post_name','text-align','center','','','.w-blog-widget-post-listing'),(175274,'deals-mobile','.w-blog-widget-post-title h1','text-align','center','','','.w-blog-widget-post-title'),(175275,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','text-align','center','','','.w-blog-widget-related-posts'),(175276,'deals-mobile','.w-blog-widget-related-posts-by-category .post_content a','text-align','center','','','.w-blog-widget-related-posts-by-category'),(175277,'deals-mobile','.w-blog-widget-related-posts-by-category .post_img','text-align','center','','','.w-blog-widget-related-posts-by-category'),(175278,'deals-mobile','.w-cart-bonus-points .btn-remove','text-align','center','','','.w-cart-bonus-points'),(175279,'deals-mobile','.w-cart-bonus-points .bonus_points_amount','text-align','center','','','.w-cart-bonus-points'),(175280,'deals-mobile','.w-cart-credit-amount input','text-align','center','','','.w-cart-credit-amount'),(175281,'deals-mobile','.w-cart-credit-amount .btn-remove','text-align','center','','','.w-cart-credit-amount'),(175282,'deals-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','text-align','center','','','.w-catalog-additional-images'),(175283,'deals-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','text-align','right','','','.w-catalog-b2b-add-button'),(175284,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','text-align','center','','','.w-catalog-compare'),(175285,'deals-mobile','.w-catalog-paging .prev','text-align','center','','','.w-catalog-paging'),(175286,'deals-mobile','.w-catalog-paging ','text-align','center','2','','.w-catalog-paging'),(175287,'deals-mobile','.w-catalog-paging .next','text-align','center','','','.w-catalog-paging'),(175288,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align','center','','','.w-catalog-paging'),(175289,'deals-mobile','.w-catalog-paging .p-blog-index','text-align','right','','','.w-catalog-paging'),(175290,'deals-mobile','.w-catalog-paging .page-number','text-align','center','','','.w-catalog-paging'),(175291,'deals-mobile','.w-catalog-paging .next-pages','text-align','center','','','.w-catalog-paging'),(175292,'deals-mobile','.w-catalog-paging .prev-pages','text-align','center','','','.w-catalog-paging'),(175293,'deals-mobile','.w-checkout-bonus-points .bonus_points_amount','text-align','center','','','.w-checkout-bonus-points'),(175294,'deals-mobile','.w-checkout-bonus-points .btn-remove','text-align','center','','','.w-checkout-bonus-points'),(175295,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','text-align','center','3','','.w-checkout-contact-information'),(175296,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','text-align','center','3','','.w-checkout-contact-information'),(175297,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','text-align','center','3','','.w-checkout-contact-information'),(175298,'deals-mobile','.w-checkout-credit-amount .btn-remove','text-align','center','','','.w-checkout-credit-amount'),(175299,'deals-mobile','.w-checkout-credit-amount .cot_gv_amount','text-align','center','','','.w-checkout-credit-amount'),(175300,'deals-mobile','.w-checkout-terms .required-message','text-align','left','','','.w-checkout-terms'),(175301,'deals-mobile','.w-checkout-terms .terms-box','text-align','left','','','.w-checkout-terms'),(175302,'deals-mobile','.w-communication-new-topic .quantity','text-align','center','','','.w-communication-new-topic'),(175303,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(5), .w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(7)','text-align','center','','','.w-communication-new-topic'),(175304,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','text-align','center','','','.w-communication-new-topic'),(175305,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','text-align','center','','','.w-communication-new-topic'),(175306,'deals-mobile','.w-communication-new-topic .orders-id','text-align','center','','','.w-communication-new-topic'),(175307,'deals-mobile','.w-communication-new-topic .model','text-align','center','','','.w-communication-new-topic'),(175308,'deals-mobile','.w-communication-new-topic .date-purchased','text-align','right','','','.w-communication-new-topic'),(175309,'deals-mobile','.w-communication-post .communication-post-attach','text-align','right','','','.w-communication-post'),(175310,'deals-mobile','.w-coupons-and-vauchers-checkout .btn-remove','text-align','center','','','.w-coupons-and-vauchers-checkout'),(175311,'deals-mobile','.w-delivery-day .time-left','text-align','center','','','.w-delivery-day'),(175312,'deals-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(175313,'deals-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(175314,'deals-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(175315,'deals-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(175316,'deals-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(175317,'deals-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(175318,'deals-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(175319,'deals-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(175320,'deals-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(175321,'deals-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(175322,'deals-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(175323,'deals-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(175324,'deals-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(175325,'deals-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(175326,'deals-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(175327,'deals-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(175328,'deals-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(175329,'deals-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(175330,'deals-mobile','.w-product-customers-activity .customers-activity','text-align','center','','','.w-product-customers-activity'),(175331,'deals-mobile','.w-product-customers-activity .close','text-align','center','','','.w-product-customers-activity'),(175332,'deals-mobile','.w-promotions .prom-multi-discount .heading','text-align','center','','','.w-promotions'),(175333,'deals-mobile','.w-promotions .promo-item','text-align','center','','','.w-promotions'),(175334,'deals-mobile','.w-promotions .promo-date','text-align','center','','','.w-promotions'),(175335,'deals-mobile','.w-quote-products .empty','text-align','center','','','.w-quote-products'),(175336,'deals-mobile','.w-reviews-content .date','text-align','right','','','.w-reviews-content'),(175337,'deals-mobile','.w-reviews-content .product-image','text-align','center','','','.w-reviews-content'),(175338,'deals-mobile','.w-top-text .top-text','text-align','center','','','.w-top-text'),(175339,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','text-align','center','','','.w-upload-customer-id-upload-customer-id-form'),(175340,'deals-mobile','.w-wedding-registry-widgets-products .rating','text-align','right','','','.w-wedding-registry-widgets-products'),(175341,'deals-mobile','.b-quantity .qty-box input[type=\'text\']','text-align','center','','','.b-quantity'),(175342,'deals-mobile','.w-success-continue-btn','text-align_important','important','864','','.w-success-continue-btn'),(175343,'deals-mobile','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align_important','important','','','.p-quick-order-index'),(175344,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align_important','important','','','.w-catalog-paging'),(175345,'deals-mobile','.w-tabs .accordion-heading','text-decoration','none','','','.w-tabs'),(175346,'deals-mobile','.w-html_box .socials a','text-decoration','none','1','','.w-html_box'),(175347,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(175348,'deals-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(175349,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','text-decoration','none','1','','.w-menu-style-1'),(175350,'deals-mobile','.p-account-index .orders-table a, .p-account-index .order-info a','text-decoration','none','1','','.p-account-index'),(175351,'deals-mobile','.p-blog-index a','text-decoration','none','1','','.p-blog-index'),(175352,'deals-mobile','.p-account-history .orders-table a, .p-account-history .order-info a','text-decoration','none','1','','.p-account-history'),(175353,'deals-mobile','.p-wedding-registry-manage a.remove-btn','text-decoration','none','1','','.p-wedding-registry-manage'),(175354,'deals-mobile','.b-pagination .pagination span','text-decoration','none','1','','.b-pagination'),(175355,'deals-mobile','.b-pagination .pagination a','text-decoration','none','1','','.b-pagination'),(175356,'deals-mobile','.p-account-history .view_link','text-decoration','underline','','','.p-account-history'),(175357,'deals-mobile','.w-list-type-2_2 .price .old','text-decoration','line-through','','','.w-list-type-2_2'),(175358,'deals-mobile','.w-chat .w-chat-box a','text-decoration','none','1','','.w-chat'),(175359,'deals-mobile','.w-chat .w-chat-box a','text-decoration','none','','','.w-chat'),(175360,'deals-mobile','.w-socials > li a','text-decoration','none','','','.w-socials'),(175361,'deals-mobile','.w-tabs .tab-a','text-decoration','none','','','.w-tabs'),(175362,'deals-mobile','.p-account-index .view_link','text-decoration','underline','','','.p-account-index'),(175363,'deals-mobile','.p-account-index .view_history','text-decoration','underline','','','.p-account-index'),(175364,'deals-mobile','.w-list-type-1_3 .price .old','text-decoration','line-through','','','.w-list-type-1_3'),(175365,'deals-mobile','.w-sale .old','text-decoration','line-through','','','.w-sale'),(175366,'deals-mobile','.b-fancybox .fancybox-nav','text-decoration','none','','','.b-fancybox'),(175367,'deals-mobile','.b-fancybox a.fancybox-close','text-decoration','none','1','','.b-fancybox'),(175368,'deals-mobile','.w-cart a.item','text-decoration','none','1','','.w-cart'),(175369,'deals-mobile','.price .old','text-decoration','line-through','','',''),(175370,'deals-mobile','.w-list-type-2 .price .old','text-decoration','line-through','','','.w-list-type-2'),(175371,'deals-mobile','.heading-3 .right-text, h3 .right-text','text-decoration','none','','',''),(175372,'deals-mobile','.w-list-type-1_2 .price .old','text-decoration','line-through','','','.w-list-type-1_2'),(175373,'deals-mobile','.w-filters .mobileCollapse','text-decoration','none','1','','.w-filters'),(175374,'deals-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(175375,'deals-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(175376,'deals-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(175377,'deals-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(175378,'deals-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(175379,'deals-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(175380,'deals-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(175381,'deals-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(175382,'deals-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(175383,'deals-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(175384,'deals-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(175385,'deals-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(175386,'deals-mobile','.b-select-suggest .select2-container .select2-choice','text-decoration','none','','','.b-select-suggest'),(175387,'deals-mobile','.b-select-suggest .select2-result-selectable .select2-match, .b-select-suggest .select2-result-unselectable .select2-match','text-decoration','underline','','','.b-select-suggest'),(175388,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','text-decoration','none','','','.b-select-suggest'),(175389,'deals-mobile','.p-account-samples-history .view_link','text-decoration','underline','','','.p-account-samples-history'),(175390,'deals-mobile','.p-account-samples-history .orders-table a, .p-account-samples-history .order-info a','text-decoration','none','1','','.p-account-samples-history'),(175391,'deals-mobile','.p-account-samples-history .orders-table a, .p-account-samples-history .order-info a','text-decoration','none','1','','.p-account-samples-history'),(175392,'deals-mobile','.p-account-samples-history .orders-table a, .p-account-samples-history .order-info a','text-decoration','none','1','','.p-account-samples-history'),(175393,'deals-mobile','.p-account-samples-history .view_link','text-decoration','underline','','','.p-account-samples-history'),(175394,'deals-mobile','.p-account-samples-history .view_link','text-decoration','underline','','','.p-account-samples-history'),(175395,'deals-mobile','.p-account-samples-history .view_link','text-decoration','underline','','','.p-account-samples-history'),(175396,'deals-mobile','.p-account-samples-history .orders-table a, .p-account-samples-history .order-info a','text-decoration','none','1','','.p-account-samples-history'),(175397,'deals-mobile','.p-account-samples-history .orders-table a, .p-account-samples-history .order-info a','text-decoration','none','1','','.p-account-samples-history'),(175398,'deals-mobile','.p-account-samples-history .orders-table a, .p-account-samples-history .order-info a','text-decoration','none','1','','.p-account-samples-history'),(175399,'deals-mobile','.p-account-samples-history .view_link','text-decoration','underline','','','.p-account-samples-history'),(175400,'deals-mobile','.p-account-samples-history .view_link','text-decoration','underline','','','.p-account-samples-history'),(175401,'deals-mobile','.p-catalog-product a.prev-next-product','text-decoration','none','1','','.p-catalog-product'),(175402,'deals-mobile','.w-account-address-book .add_item a.disabled-link','text-decoration','none','1','','.w-account-address-book'),(175403,'deals-mobile','.w-account-personal-catalog .list-switcher a','text-decoration','none','','','.w-account-personal-catalog'),(175404,'deals-mobile','.w-blog-widget-post-share a','text-decoration','none','1','','.w-blog-widget-post-share'),(175405,'deals-mobile','.w-catalog-paging span','text-decoration','none','1','','.w-catalog-paging'),(175406,'deals-mobile','.w-catalog-paging a','text-decoration','none','1','','.w-catalog-paging'),(175407,'deals-mobile','.w-image-maps .categories-items .item a','text-decoration','none','1','','.w-image-maps'),(175408,'deals-mobile','.w-image-maps .float-items .item a','text-decoration','none','1','','.w-image-maps'),(175409,'deals-mobile','.w-social-links a','text-decoration','none','1','','.w-social-links'),(175410,'deals-mobile','.batchPr .btn-batch-remove','text-indent','-33333em','','','.batchPr'),(175411,'deals-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','text-overflow','ellipsis','','','.b-select-suggest'),(175412,'deals-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(175413,'deals-mobile','.p-wedding-registry-index .main-button','text-shadow','0 0','3','','.p-wedding-registry-index'),(175414,'deals-mobile','.b-fancybox .fancybox-skin','text-shadow','none','','','.b-fancybox'),(175415,'deals-mobile','.b-fancybox .fancybox-title','text-shadow','none','','','.b-fancybox'),(175416,'deals-mobile','.p-account-history .order_history_table h2','text-transform','uppercase','','','.p-account-history'),(175417,'deals-mobile','.p-account-history .order_history_table th','text-transform','none','','','.p-account-history'),(175418,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-history-info'),(175419,'deals-mobile','.p-account-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-history-info'),(175420,'deals-mobile','.p-account-index .not_fully_paid_td','text-transform','uppercase','','','.p-account-index'),(175421,'deals-mobile','.w-categories .name','text-transform','uppercase','','','.w-categories'),(175422,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','text-transform','none','','','.b-multi-page-checkout'),(175423,'deals-mobile','.w-product-personal-catalog-button .btn','text-transform','none','','','.w-product-personal-catalog-button'),(175424,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','text-transform','uppercase','','','.b-multi-page-checkout'),(175425,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','text-transform','uppercase','','','.p-account-order-pay'),(175426,'deals-mobile','.p-account-order-pay .not_fully_paid_td','text-transform','uppercase','','','.p-account-order-pay'),(175427,'deals-mobile','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(175428,'deals-mobile','.w-product-wedding-registry-button .btn','text-transform','none','','','.w-product-wedding-registry-button'),(175429,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-transform','uppercase','','','.b-switch'),(175430,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-transform','uppercase','','','.b-switch'),(175431,'deals-mobile','.w-tabs .accordion-heading','text-transform','uppercase','','','.w-tabs'),(175432,'deals-mobile','.heading-4 .edit, h4 .edit','text-transform','none','','',''),(175433,'deals-mobile','.w-tabs .tab-a','text-transform','uppercase','','','.w-tabs'),(175434,'deals-mobile','.heading-4, h4','text-transform','uppercase','','',''),(175435,'deals-mobile','.heading-2, h2','text-transform','uppercase','','',''),(175436,'deals-mobile','.p-account-trade-form .widget h3','text-transform','uppercase','','','.p-account-trade-form'),(175437,'deals-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','text-transform','uppercase','','','.p-account-trade-form'),(175438,'deals-mobile','.w-filters .filter-box-head','text-transform','uppercase','','','.w-filters'),(175439,'deals-mobile','.w-filters .head-filter-widget','text-transform','uppercase','','','.w-filters'),(175440,'deals-mobile','.heading-3 .edit, h3 .edit','text-transform','none','','',''),(175441,'deals-mobile','.p-account-subscription-historyinfo .order_history_table th','text-transform','none','','','.p-account-subscription-historyinfo'),(175442,'deals-mobile','.p-account-subscription-historyinfo .order_history_table h2','text-transform','uppercase','','','.p-account-subscription-historyinfo'),(175443,'deals-mobile','.p-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-checkout-success'),(175444,'deals-mobile','.heading-3, h3','text-transform','uppercase','','',''),(175445,'deals-mobile','.p-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-checkout-success'),(175446,'deals-mobile','.p-account-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-history'),(175447,'deals-mobile','.w-top-categories .categories h2','text-transform','inherit','','','.w-top-categories'),(175448,'deals-mobile','.w-categories .categories h2','text-transform','inherit','','','.w-categories'),(175449,'deals-mobile','.w-top-categories .name','text-transform','uppercase','','','.w-top-categories'),(175450,'deals-mobile','.p-account-index .date_title','text-transform','uppercase','','','.p-account-index'),(175451,'deals-mobile','h1','text-transform','uppercase','','',''),(175452,'deals-mobile','.btn-2','text-transform','uppercase','','',''),(175453,'deals-mobile','.btn','text-transform','uppercase','','',''),(175454,'deals-mobile','.btn-1','text-transform','uppercase','','',''),(175455,'deals-mobile','.btn-3','text-transform','uppercase','','',''),(175456,'deals-mobile','.heading-4 .right-text, h4 .right-text','text-transform','none','','',''),(175457,'deals-mobile','.p-account-address-book .leftMes div','text-transform','uppercase','','','.p-account-address-book'),(175458,'deals-mobile','.p-account-address-book .address_book_row h2 a','text-transform','none','','','.p-account-address-book'),(175459,'deals-mobile','.p-account-address-book .address_book h2','text-transform','uppercase','','','.p-account-address-book'),(175460,'deals-mobile','.b-info .info strong','text-transform','uppercase','','','.b-info'),(175461,'deals-mobile','.b-products-listing .products-listing a.btn.view-button','text-transform','none','','','.b-products-listing'),(175462,'deals-mobile','.b-products-listing .products-listing h2','text-transform','inherit','','','.b-products-listing'),(175463,'deals-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','text-transform','inherit','','','.b-h-inline'),(175464,'deals-mobile','.b-messages .content-messages .heading-2','text-transform','none','','','.b-messages'),(175465,'deals-mobile','.batchPr .batchSelect .checkbox','text-transform','uppercase','','','.batchPr'),(175466,'deals-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(175467,'deals-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(175468,'deals-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(175469,'deals-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(175470,'deals-mobile','.p-account-samples-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history'),(175471,'deals-mobile','.p-account-samples-history .order_history_table h2','text-transform','uppercase','','','.p-account-samples-history'),(175472,'deals-mobile','.p-account-samples-history .order_history_table th','text-transform','none','','','.p-account-samples-history'),(175473,'deals-mobile','.p-account-samples-history .order_history_table th','text-transform','none','','','.p-account-samples-history'),(175474,'deals-mobile','.p-account-samples-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history'),(175475,'deals-mobile','.p-account-samples-history .order_history_table th','text-transform','none','','','.p-account-samples-history'),(175476,'deals-mobile','.p-account-samples-history .order_history_table th','text-transform','none','','','.p-account-samples-history'),(175477,'deals-mobile','.p-account-samples-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history'),(175478,'deals-mobile','.p-account-samples-history .order_history_table h2','text-transform','uppercase','','','.p-account-samples-history'),(175479,'deals-mobile','.p-account-samples-history .order_history_table h2','text-transform','uppercase','','','.p-account-samples-history'),(175480,'deals-mobile','.p-account-samples-history .order_history_table h2','text-transform','uppercase','','','.p-account-samples-history'),(175481,'deals-mobile','.p-account-samples-history .order_history_table h2','text-transform','uppercase','','','.p-account-samples-history'),(175482,'deals-mobile','.p-account-samples-history .order_history_table th','text-transform','none','','','.p-account-samples-history'),(175483,'deals-mobile','.p-account-samples-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history'),(175484,'deals-mobile','.p-account-samples-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history'),(175485,'deals-mobile','.p-account-samples-history .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history'),(175486,'deals-mobile','.p-account-samples-history .order_history_table h2','text-transform','uppercase','','','.p-account-samples-history'),(175487,'deals-mobile','.p-account-samples-history .order_history_table th','text-transform','none','','','.p-account-samples-history'),(175488,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history-info'),(175489,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-samples-history-info'),(175490,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-samples-history-info'),(175491,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history-info'),(175492,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-samples-history-info'),(175493,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-samples-history-info'),(175494,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history-info'),(175495,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history-info'),(175496,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history-info'),(175497,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','text-transform','uppercase','','','.p-account-samples-history-info'),(175498,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-samples-history-info'),(175499,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','text-transform','uppercase','','','.p-account-samples-history-info'),(175500,'deals-mobile','.p-catalog-product .pn-direction','text-transform','uppercase','','','.p-catalog-product'),(175501,'deals-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(175502,'deals-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(175503,'deals-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(175504,'deals-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(175505,'deals-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(175506,'deals-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(175507,'deals-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(175508,'deals-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(175509,'deals-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(175510,'deals-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(175511,'deals-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(175512,'deals-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(175513,'deals-mobile','.p-sample-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-sample-checkout-success'),(175514,'deals-mobile','.p-sample-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-sample-checkout-success'),(175515,'deals-mobile','.w-account-address-book .btn-edit','text-transform','none','','','.w-account-address-book'),(175516,'deals-mobile','.w-account-personal-catalog .list-switcher a','text-transform','uppercase','','','.w-account-personal-catalog'),(175517,'deals-mobile','.w-blog-widget-post-listing .post_name a','text-transform','uppercase','','','.w-blog-widget-post-listing'),(175518,'deals-mobile','.w-blog-widget-post-title h1','text-transform','none','','','.w-blog-widget-post-title'),(175519,'deals-mobile','.w-blog-widget-related-posts-by-category .post_content a','text-transform','uppercase','','','.w-blog-widget-related-posts-by-category'),(175520,'deals-mobile','.w-blog-widget-tag-cloud a','text-transform','uppercase','','','.w-blog-widget-tag-cloud'),(175521,'deals-mobile','.w-cart-compare .cart-name a','text-transform','uppercase','','','.w-cart-compare'),(175522,'deals-mobile','.w-checkout-shipping-choice span','text-transform','uppercase','','','.w-checkout-shipping-choice'),(175523,'deals-mobile','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','text-transform','uppercase','','','.w-multi-cart-cart-switcher'),(175524,'deals-mobile','.w-personal-gift-status-bar .end-date','text-transform','uppercase','','','.w-personal-gift-status-bar'),(175525,'deals-mobile','.w-personal-gift-status-bar .inform','text-transform','uppercase','','','.w-personal-gift-status-bar'),(175526,'deals-mobile','.w-promotions .heading-3','text-transform','uppercase','','','.w-promotions'),(175527,'deals-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','text-transform','none','','','.w-taxable'),(175528,'deals-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','text-transform','none','','','.w-taxable'),(175529,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_color','#222','','','.b-fancybox'),(175530,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left','0','','','.b-fancybox'),(175531,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left_measure','','','','.b-fancybox'),(175532,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size','2','','','.b-fancybox'),(175533,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size_measure','px','','','.b-fancybox'),(175534,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top','1','','','.b-fancybox'),(175535,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top_measure','px','','','.b-fancybox'),(175536,'deals-mobile','.w-menu-slider > ul > li > ul','top','100','','','.w-menu-slider'),(175537,'deals-mobile','.w-menu-slider .close','top','10','','','.w-menu-slider'),(175538,'deals-mobile','.w-menu-big > ul > li > ul','top','100','','','.w-menu-big'),(175539,'deals-mobile','.w-menu-horizontal > ul > li > ul','top','100','','','.w-menu-horizontal'),(175540,'deals-mobile','.w-bestsellers .heading-3','top','0','3','','.w-bestsellers'),(175541,'deals-mobile','.w-list-type-1 .rating-count','top','-1','','','.w-list-type-1'),(175542,'deals-mobile','.w-menu-style-1 > ul > li > ul','top','100','','','.w-menu-style-1'),(175543,'deals-mobile','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(175544,'deals-mobile','.w-sale .badge','top','10','','','.w-sale'),(175545,'deals-mobile','.w-product-wedding-registry-button .btn','top','1','3','','.w-product-wedding-registry-button'),(175546,'deals-mobile','.w-product-wedding-registry-button .btn','top','1','4','','.w-product-wedding-registry-button'),(175547,'deals-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(175548,'deals-mobile','.b-fancybox #fancybox-loading','top','50','','','.b-fancybox'),(175549,'deals-mobile','.b-fancybox .fancybox-nav','top','0','','','.b-fancybox'),(175550,'deals-mobile','.p-account-history-info .historyInfoColumn h2, .p-account-history-info h2.product_details, .p-account-history-info h2.o_history_info','top','2','3','','.p-account-history-info'),(175551,'deals-mobile','.p-account-history-info .not_fully_paid_td','top','19','','','.p-account-history-info'),(175552,'deals-mobile','.p-account-index .not_fully_paid_td','top','19','','','.p-account-index'),(175553,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','top','-2','4','','.b-multi-page-checkout'),(175554,'deals-mobile','.b-pass-strength .pass-strength span','top','6','','','.b-pass-strength'),(175555,'deals-mobile','.p-account-index .topAccount > li > div','top','4','863,3','','.p-account-index'),(175556,'deals-mobile','.p-blog-index .author .avatar','top','-2','','','.p-blog-index'),(175557,'deals-mobile','.w-menu-mobile .menu-slider .open','top','0','','','.w-menu-mobile'),(175558,'deals-mobile','.b-info-popup .info-popup.top-left div','top','auto','3','','.b-info-popup'),(175559,'deals-mobile','.b-info-popup .info-popup.top-left div','top','auto','','','.b-info-popup'),(175560,'deals-mobile','.w-promo-code .holder','top','2','893,3','','.w-promo-code'),(175561,'deals-mobile','.b-info-popup .info-popup div','top','-12','','','.b-info-popup'),(175562,'deals-mobile','.w-promo-code .holder','top','19','3','','.w-promo-code'),(175563,'deals-mobile','.p-wedding-registry-view h1','top','-4','4','','.p-wedding-registry-view'),(175564,'deals-mobile','.p-account-order-pay .historyInfoColumn h2, .p-account-order-pay h2.product_details, .p-account-order-pay h2.o_history_info','top','2','3','','.p-account-order-pay'),(175565,'deals-mobile','.p-account-order-pay .not_fully_paid_td','top','19','','','.p-account-order-pay'),(175566,'deals-mobile','.testimonials .heading-3','top','0','3','',''),(175567,'deals-mobile','.testimonials .rating','top','2','','',''),(175568,'deals-mobile','.testimonials .reviews-list span','top','2','','',''),(175569,'deals-mobile','.p-wedding-registry-manage .wr-search button','top','1','','','.p-wedding-registry-manage'),(175570,'deals-mobile','.p-account-history .view_link','top','4','4','','.p-account-history'),(175571,'deals-mobile','.w-product-personal-catalog-button .btn','top','1','3','','.w-product-personal-catalog-button'),(175572,'deals-mobile','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(175573,'deals-mobile','.b-fancybox .fancybox-close','top','0','','','.b-fancybox'),(175574,'deals-mobile','.w-menu-horizontal ul ul ul','top','0','','','.w-menu-horizontal'),(175575,'deals-mobile','.b-form .radio-button input[type=\"radio\"]','top','2','','','.b-form'),(175576,'deals-mobile','.p-wedding-registry-index .search-list','top','0','3','','.p-wedding-registry-index'),(175577,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','top','1','3','','.b-form'),(175578,'deals-mobile','.b-form .form-buttons','top','10','','','.b-form'),(175579,'deals-mobile','.p-wedding-registry-search h1','top','-4','3','','.p-wedding-registry-search'),(175580,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','top','4','3','','.b-switch'),(175581,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','top','4','3','','.b-switch'),(175582,'deals-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','top','0','','','.b-switch'),(175583,'deals-mobile','.w-currencies .select','top','46','872','','.w-currencies'),(175584,'deals-mobile','.w-languages .select','top','46','872','','.w-languages'),(175585,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container','top','0','','','.b-switch'),(175586,'deals-mobile','.w-currencies .w-currencies .current','top','10','872,3','','.w-currencies'),(175587,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','top','50','','','.b-slick'),(175588,'deals-mobile','.b-bottom .footerTitle','top','8','863,4','','.b-bottom'),(175589,'deals-mobile','.w-search .suggest','top','220','','','.w-search'),(175590,'deals-mobile','.w-socials .post_item > div','top','10','3','','.w-socials'),(175591,'deals-mobile','.w-banner .image-text-banner.top-right .text-banner','top','0','','','.w-banner'),(175592,'deals-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','top','0','','','.w-banner'),(175593,'deals-mobile','.w-banner .image-text-banner.top-left .text-banner','top','0','','','.w-banner'),(175594,'deals-mobile','.w-banner .banner img + img','top','0','','','.w-banner'),(175595,'deals-mobile','.w-banner .image-text-banner.bottom-center .text-banner','top','auto','','','.w-banner'),(175596,'deals-mobile','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','top','0','','','.w-banner'),(175597,'deals-mobile','.w-currencies .current','top','1','3','','.w-currencies'),(175598,'deals-mobile','.w-currencies .select','top','31','','','.w-currencies'),(175599,'deals-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(175600,'deals-mobile','.b-slick .slick-vertical button.slick-prev','top','0','','','.b-slick'),(175601,'deals-mobile','.b-slick .slick-track','top','0','','','.b-slick'),(175602,'deals-mobile','.b-slick .slick-vertical button.slick-next','top','auto','','','.b-slick'),(175603,'deals-mobile','.p-checkout-success .page-success','top','-126','3','','.p-checkout-success'),(175604,'deals-mobile','.p-account-index .view_link','top','4','4','','.p-account-index'),(175605,'deals-mobile','.b-info-popup .info-popup div','top','15','3','','.b-info-popup'),(175606,'deals-mobile','.b-fancybox .fancybox-tmp','top','-99999','','','.b-fancybox'),(175607,'deals-mobile','.w-search .search form','top','100','','','.w-search'),(175608,'deals-mobile','.b-fancybox .fancybox-wrap','top','0','','','.b-fancybox'),(175609,'deals-mobile','.w-menu-style-1 ul ul ul','top','0','','','.w-menu-style-1'),(175610,'deals-mobile','.b-fancybox .fancybox-overlay','top','0','','','.b-fancybox'),(175611,'deals-mobile','.p-account-history .not_fully_paid_td','top','19','','','.p-account-history'),(175612,'deals-mobile','.p-wedding-registry-share .invite-remove','top','27','','','.p-wedding-registry-share'),(175613,'deals-mobile','.w-text .customer-service','top','5','3','','.w-text'),(175614,'deals-mobile','.w-languages .current','top','10','872,3','','.w-languages'),(175615,'deals-mobile','.w-banner .carousel-text','top','0','','','.w-banner'),(175616,'deals-mobile','.b-rating #stars-default .glyphicon','top','1','','','.b-rating'),(175617,'deals-mobile','.b-fancybox .fancybox-nav span','top','50','','','.b-fancybox'),(175618,'deals-mobile','.w-cart-discount-coupon .gift-certificate .heading-4','top','3','3','','.w-cart-discount-coupon'),(175619,'deals-mobile','.p-account-index .account_page h4','top','-4','3','','.p-account-index'),(175620,'deals-mobile','.b-form .hide-billing-address','top','0','','','.b-form'),(175621,'deals-mobile','.b-form .form-inputs div.required-message','top','-15','','','.b-form'),(175622,'deals-mobile','.p-wedding-registry-manage h1','top','-4','4','','.p-wedding-registry-manage'),(175623,'deals-mobile','.p-wedding-registry-search h1','top','-4','4','','.p-wedding-registry-search'),(175624,'deals-mobile','.view-all','top','50','3','',''),(175625,'deals-mobile','.p-wedding-registry-share h1','top','-4','3','','.p-wedding-registry-share'),(175626,'deals-mobile','.p-wedding-registry-manage h1','top','-4','3','','.p-wedding-registry-manage'),(175627,'deals-mobile','.p-wedding-registry-share h1','top','-4','4','','.p-wedding-registry-share'),(175628,'deals-mobile','.p-wedding-registry-view h1','top','-4','3','','.p-wedding-registry-view'),(175629,'deals-mobile','.b-bottom .pop-up-close','top','7','','','.b-bottom'),(175630,'deals-mobile','.w-filters .mobileCollapse','top','1','','','.w-filters'),(175631,'deals-mobile','.w-filters .ui-slider-handle','top','-5','','','.w-filters'),(175632,'deals-mobile','.w-languages .select','top','31','','','.w-languages'),(175633,'deals-mobile','.w-languages .current','top','1','3','','.w-languages'),(175634,'deals-mobile','.b-form .addresses .address-item input[type=\"radio\"]','top','4','','','.b-form'),(175635,'deals-mobile','.w-product-reviews .reviews-list span','top','2','','','.w-product-reviews'),(175636,'deals-mobile','.w-reviews .heading-3','top','0','3','','.w-reviews'),(175637,'deals-mobile','.w-search .button-search','top','0','','','.w-search'),(175638,'deals-mobile','.w-reviews .rating','top','2','','','.w-reviews'),(175639,'deals-mobile','.w-reviews .reviews-list span','top','2','','','.w-reviews'),(175640,'deals-mobile','.b-form .middle-form .required-message','top','-15','','','.b-form'),(175641,'deals-mobile','.b-form .payment-method .item-radio input','top','5','','','.b-form'),(175642,'deals-mobile','.b-form .shipping-method .input input','top','2','','','.b-form'),(175643,'deals-mobile','.b-info .info','top','3','3','','.b-info'),(175644,'deals-mobile','.b-info-popup .info-popup','top','5','3','','.b-info-popup'),(175645,'deals-mobile','.b-products-listing .hover-box-content','top','-10','3','','.b-products-listing'),(175646,'deals-mobile','.b-products-listing .hover-box-content','top','40','','','.b-products-listing'),(175647,'deals-mobile','.b-products-listing .loader','top','calc(50% - 15px)','4','','.b-products-listing'),(175648,'deals-mobile','.b-products-listing .loader','top','0','3','','.b-products-listing'),(175649,'deals-mobile','.b-products-listing .products-listing .btn-buy','top','3','3','','.b-products-listing'),(175650,'deals-mobile','.b-products-listing .products-listing .promos-info','top','0','','','.b-products-listing'),(175651,'deals-mobile','.b-products-listing .products-listing .qty-input.hidden','top','0','3','','.b-products-listing'),(175652,'deals-mobile','.b-products-listing .products-listing .radio-attributes input','top','2','','','.b-products-listing'),(175653,'deals-mobile','.b-products-listing .promo','top','0','','','.b-products-listing'),(175654,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(175655,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(175656,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(175657,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(175658,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(175659,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(175660,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(175661,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(175662,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(175663,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(175664,'deals-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(175665,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(175666,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top','100','','','.b-menu-lev_display-down'),(175667,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top','100','','','.b-menu-lev_display-down'),(175668,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top','100','','','.b-menu-lev_display-down'),(175669,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top','100','','','.b-menu-lev_display-down'),(175670,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top','100','','','.b-menu-lev_display-down'),(175671,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','top','0','','','.b-menu-lev_display-left'),(175672,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','top','0','','','.b-menu-lev_display-left'),(175673,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','top','0','','','.b-menu-lev_display-left'),(175674,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','top','0','','','.b-menu-lev_display-left'),(175675,'deals-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','top','0','','','.b-menu-lev_display-left'),(175676,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','top','0','','','.b-menu-lev_display-lra'),(175677,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','top','0','','','.b-menu-lev_display-lra'),(175678,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','top','0','','','.b-menu-lev_display-lra'),(175679,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','top','0','','','.b-menu-lev_display-lra'),(175680,'deals-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','top','0','','','.b-menu-lev_display-lra'),(175681,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','top','0','','','.b-menu-lev_display-right'),(175682,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','top','0','','','.b-menu-lev_display-right'),(175683,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','top','0','','','.b-menu-lev_display-right'),(175684,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','top','0','','','.b-menu-lev_display-right'),(175685,'deals-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','top','0','','','.b-menu-lev_display-right'),(175686,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','top','0','','','.b-menu-lev_display-slide'),(175687,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','top','0','','','.b-menu-lev_display-slide'),(175688,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','top','0','','','.b-menu-lev_display-slide'),(175689,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','top','0','','','.b-menu-lev_display-slide'),(175690,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','top','0','','','.b-menu-lev_display-slide'),(175691,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','top','0','','','.b-menu-open_from-left'),(175692,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','top','8','','','.b-menu-style-1'),(175693,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','top','0','','','.b-menu-style-2'),(175694,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','top','50','3','','.b-menu-style-2'),(175695,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','top','0','','','.b-menu-style-2'),(175696,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','top','50','3','','.b-menu-style-2'),(175697,'deals-mobile','.b-messages span.starred::before','top','3','','','.b-messages'),(175698,'deals-mobile','.b-messages .messBtnMenuUnread','top','3','3','','.b-messages'),(175699,'deals-mobile','.b-messages .messBtnMenuStarred','top','3','3','','.b-messages'),(175700,'deals-mobile','.b-messages .messBtnMenuDelete','top','3','3','','.b-messages'),(175701,'deals-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','top','5','','','.b-messages'),(175702,'deals-mobile','.b-preloader .preloader','top','0','','','.b-preloader'),(175703,'deals-mobile','.b-preloader .preloader','top','calc(50% - 20px)','3','','.b-preloader'),(175704,'deals-mobile','.b-select-suggest .select2-search-choice-close','top','4','','','.b-select-suggest'),(175705,'deals-mobile','.b-select-suggest .select2-drop','top','100','','','.b-select-suggest'),(175706,'deals-mobile','.b-select-suggest .select2-drop-mask','top','0','','','.b-select-suggest'),(175707,'deals-mobile','.b-select-suggest .select2-measure-scrollbar','top','-10000','','','.b-select-suggest'),(175708,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','top','8','','','.b-select-suggest'),(175709,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top','0','','','.b-select-suggest'),(175710,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','top','0','','','.b-select-suggest'),(175711,'deals-mobile','.b-upload-file .upload-remove','top','5','','','.b-upload-file'),(175712,'deals-mobile','.b-upload-files .attach-active-holder .attach-file','top','-200','','','.b-upload-files'),(175713,'deals-mobile','.batchPr .batchSelect','top','15','','','.batchPr'),(175714,'deals-mobile','.batchPr .btn-batch-remove','top','10','','','.batchPr'),(175715,'deals-mobile','.bell-ico .heading-2','top','5','3','','.bell-ico'),(175716,'deals-mobile','.heading-ordered-items .heading-4','top','2','3','','.heading-ordered-items'),(175717,'deals-mobile','.heading-saved-lists .heading-4','top','2','3','','.heading-saved-lists'),(175718,'deals-mobile','.heading-settings .heading-4','top','2','3','','.heading-settings'),(175719,'deals-mobile','.p-account-samples-history .view_link','top','4','4','','.p-account-samples-history'),(175720,'deals-mobile','.p-account-samples-history .view_link','top','4','4','','.p-account-samples-history'),(175721,'deals-mobile','.p-account-samples-history .view_link','top','4','4','','.p-account-samples-history'),(175722,'deals-mobile','.p-account-samples-history .not_fully_paid_td','top','19','','','.p-account-samples-history'),(175723,'deals-mobile','.p-account-samples-history .not_fully_paid_td','top','19','','','.p-account-samples-history'),(175724,'deals-mobile','.p-account-samples-history .not_fully_paid_td','top','19','','','.p-account-samples-history'),(175725,'deals-mobile','.p-account-samples-history .not_fully_paid_td','top','19','','','.p-account-samples-history'),(175726,'deals-mobile','.p-account-samples-history .not_fully_paid_td','top','19','','','.p-account-samples-history'),(175727,'deals-mobile','.p-account-samples-history .view_link','top','4','4','','.p-account-samples-history'),(175728,'deals-mobile','.p-account-samples-history .view_link','top','4','4','','.p-account-samples-history'),(175729,'deals-mobile','.p-account-samples-history .view_link','top','4','4','','.p-account-samples-history'),(175730,'deals-mobile','.p-account-samples-history .not_fully_paid_td','top','19','','','.p-account-samples-history'),(175731,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','top','2','3','','.p-account-samples-history-info'),(175732,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','top','19','','','.p-account-samples-history-info'),(175733,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','top','19','','','.p-account-samples-history-info'),(175734,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','top','2','3','','.p-account-samples-history-info'),(175735,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','top','2','3','','.p-account-samples-history-info'),(175736,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','top','2','3','','.p-account-samples-history-info'),(175737,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','top','2','3','','.p-account-samples-history-info'),(175738,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','top','19','','','.p-account-samples-history-info'),(175739,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','top','19','','','.p-account-samples-history-info'),(175740,'deals-mobile','.p-account-samples-history-info .historyInfoColumn h2, .p-account-samples-history-info h2.product_details, .p-account-samples-history-info h2.o_history_info','top','2','3','','.p-account-samples-history-info'),(175741,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','top','19','','','.p-account-samples-history-info'),(175742,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','top','19','','','.p-account-samples-history-info'),(175743,'deals-mobile','.p-catalog-product .prev-next-product','top','calc(50% - 200px)','','','.p-catalog-product'),(175744,'deals-mobile','.p-catalog-product .pn-image','top','120','3','','.p-catalog-product'),(175745,'deals-mobile','.p-payer-order-confirmation .discount-ico','top','3','3','','.p-payer-order-confirmation'),(175746,'deals-mobile','.p-payer-order-confirmation .order-ico','top','7','3','','.p-payer-order-confirmation'),(175747,'deals-mobile','.p-payer-order-confirmation .comment-ico','top','7','3','','.p-payer-order-confirmation'),(175748,'deals-mobile','.p-payer-order-pay .order-ico','top','7','3','','.p-payer-order-pay'),(175749,'deals-mobile','.p-payer-order-pay .comment-ico','top','7','3','','.p-payer-order-pay'),(175750,'deals-mobile','.p-payer-order-pay .discount-ico','top','3','3','','.p-payer-order-pay'),(175751,'deals-mobile','.savings-ico .heading-2','top','5','3','','.savings-ico'),(175752,'deals-mobile','.shipping-ico .heading-2','top','5','3','','.shipping-ico'),(175753,'deals-mobile','.shipping-ico .heading-2','top','5','3','','.shipping-ico'),(175754,'deals-mobile','.shipping-ico .heading-2','top','5','3','','.shipping-ico'),(175755,'deals-mobile','.w-account-address-book .btn-del','top','0','','','.w-account-address-book'),(175756,'deals-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','top','4','','','.w-account-addresses-list'),(175757,'deals-mobile','.w-blog-widget-categories-list a','top','5','3','','.w-blog-widget-categories-list'),(175758,'deals-mobile','.w-blog-widget-most-popular-posts a','top','5','3','','.w-blog-widget-most-popular-posts'),(175759,'deals-mobile','.w-blog-widget-post-comments-count span','top','2','3','','.w-blog-widget-post-comments-count'),(175760,'deals-mobile','.w-blog-widget-post-listing .post_comment','top','0','3','','.w-blog-widget-post-listing'),(175761,'deals-mobile','.w-blog-widget-post-share ','top','0','4','','.w-blog-widget-post-share'),(175762,'deals-mobile','.w-blog-widget-post-share','top','15','0,4','','.w-blog-widget-post-share'),(175763,'deals-mobile','.w-cart-bonus-points .title','top','-2','3','','.w-cart-bonus-points'),(175764,'deals-mobile','.w-cart-compare .remove-cart','top','0','','','.w-cart-compare'),(175765,'deals-mobile','.w-cart-compare .atr-col','top','0','3','','.w-cart-compare'),(175766,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top','0','','','.w-catalog-paging'),(175767,'deals-mobile','.w-checkout-billing-address .genders-title input','top','2','','','.w-checkout-billing-address'),(175768,'deals-mobile','.w-checkout-create-account .account-benefits strong','top','3','3','','.w-checkout-create-account'),(175769,'deals-mobile','.w-checkout-gdpr .candlestick-wrapper','top','0','','','.w-checkout-gdpr'),(175770,'deals-mobile','.w-checkout-shipping-address .genders-title input','top','2','','','.w-checkout-shipping-address'),(175771,'deals-mobile','.w-checkout-shipping-choice input','top','-200','','','.w-checkout-shipping-choice'),(175772,'deals-mobile','.w-checkout-terms input[type=\"checkbox\"]','top','2','','','.w-checkout-terms'),(175773,'deals-mobile','.w-checkout-terms .required-message','top','40','','','.w-checkout-terms'),(175774,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','top','0','','','.w-image-maps'),(175775,'deals-mobile','.w-image-maps .svg-wrap svg','top','0','','','.w-image-maps'),(175776,'deals-mobile','.w-multi-cart-actions .cart-actions','top','-3','','','.w-multi-cart-actions'),(175777,'deals-mobile','.w-neighbour-checkout .bootstrap-switch','top','-2','','','.w-neighbour-checkout'),(175778,'deals-mobile','.w-personal-gift-status-bar .inform','top','3','4','','.w-personal-gift-status-bar'),(175779,'deals-mobile','.w-personal-gift-status-bar .end-date','top','4','3','','.w-personal-gift-status-bar'),(175780,'deals-mobile','.w-product-customers-activity .close','top','5','','','.w-product-customers-activity'),(175781,'deals-mobile','.w-promotions .prom-multi-discount .products','top','-13','','','.w-promotions'),(175782,'deals-mobile','.w-promotions .prom-multi-discount > .heading','top','2','3','','.w-promotions'),(175783,'deals-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','top','2','3','','.w-promotions'),(175784,'deals-mobile','.w-promotions .promo-cart-discount .promo-min-qty','top','-19','','','.w-promotions'),(175785,'deals-mobile','.w-promotions .promo-cart-discount .slave .content','top','-17','','','.w-promotions'),(175786,'deals-mobile','.w-promotions .promo-date','top','-10','','','.w-promotions'),(175787,'deals-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','top','2','3','','.w-promotions'),(175788,'deals-mobile','.w-reviews-content .review','top','-16','3','','.w-reviews-content'),(175789,'deals-mobile','.w-taxable input[type=\"checkbox\"]','top','2','','','.w-taxable'),(175790,'deals-mobile','.w-taxable input[type=\"radio\"]','top','2','','','.w-taxable'),(175791,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(175792,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(175793,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(175794,'deals-mobile','.w-wedding-registry-widgets-delete-link a','top','-1','4','','.w-wedding-registry-widgets-delete-link'),(175795,'deals-mobile','.w-wedding-registry-widgets-products .remove','top','0','','','.w-wedding-registry-widgets-products'),(175796,'deals-mobile','.w-wedding-registry-widgets-share-link a','top','-1','4','','.w-wedding-registry-widgets-share-link'),(175797,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top_important','important','','','.b-select-suggest'),(175798,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top_important','important','','','.w-catalog-paging'),(175799,'deals-mobile','.w-menu-horizontal > ul > li > ul','top_measure','%','','','.w-menu-horizontal'),(175800,'deals-mobile','.w-menu-big > ul > li > ul','top_measure','%','','','.w-menu-big'),(175801,'deals-mobile','.w-menu-slider > ul > li > ul','top_measure','%','','','.w-menu-slider'),(175802,'deals-mobile','.w-menu-style-1 > ul > li > ul','top_measure','%','','','.w-menu-style-1'),(175803,'deals-mobile','.b-fancybox .fancybox-nav span','top_measure','%','','','.b-fancybox'),(175804,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','top_measure','%','','','.b-slick'),(175805,'deals-mobile','.w-search .search form','top_measure','%','','','.w-search'),(175806,'deals-mobile','.b-fancybox #fancybox-loading','top_measure','%','','','.b-fancybox'),(175807,'deals-mobile','.w-search .suggest','top_measure','%','','','.w-search'),(175808,'deals-mobile','.view-all','top_measure','%','3','',''),(175809,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(175810,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(175811,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(175812,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(175813,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(175814,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(175815,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top_measure','%','','','.b-menu-lev_display-down'),(175816,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top_measure','%','','','.b-menu-lev_display-down'),(175817,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top_measure','%','','','.b-menu-lev_display-down'),(175818,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top_measure','%','','','.b-menu-lev_display-down'),(175819,'deals-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top_measure','%','','','.b-menu-lev_display-down'),(175820,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','top_measure','%','3','','.b-menu-style-2'),(175821,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','top_measure','%','3','','.b-menu-style-2'),(175822,'deals-mobile','.b-select-suggest .select2-drop','top_measure','%','','','.b-select-suggest'),(175823,'deals-mobile','.b-slick .slick-slider','touch-action','pan-y','','','.b-slick'),(175824,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container','transform','translate3d(0, 0, 0)','','','.b-switch'),(175825,'deals-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','transform','translate3d(0, 0, 0)','','','.b-slick'),(175826,'deals-mobile','.b-products-listing .hover-box-content','transform','rotate( 45deg )','3','','.b-products-listing'),(175827,'deals-mobile','.b-menu-lev_display-slide .menu-style .slide-parent','transform','translateX(-100vw)','','','.b-menu-lev_display-slide'),(175828,'deals-mobile','.b-switch .bootstrap-switch','transition','border-color ease-in-out .15s, box-shadow ease-in-out .15s','','','.b-switch'),(175829,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-animate .bootstrap-switch-container','transition','margin-left 0.5s','','','.b-switch'),(175830,'deals-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','transition','max-height 1s','','','.b-menu-burger_icon'),(175831,'deals-mobile','.b-menu-lev_display-slide .menu-style ul','transition','visibility 300ms, transform 300ms','','','.b-menu-lev_display-slide'),(175832,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','transition','left 300ms','','','.b-menu-open_from-left'),(175833,'deals-mobile','.b-slick .slick-slider','user-select','none','','','.b-slick'),(175834,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','user-select','none','','','.b-select-suggest'),(175835,'deals-mobile','.b-select-suggest .select2-results .select2-result-label','user-select','none','','','.b-select-suggest'),(175836,'deals-mobile','.b-select-suggest .select2-container .select2-choice','user-select','none','','','.b-select-suggest'),(175837,'deals-mobile','.w-menu-big li li','vertical-align','top','','','.w-menu-big'),(175838,'deals-mobile','.w-menu-big li a, .w-menu-big li .no-link','vertical-align','middle','','','.w-menu-big'),(175839,'deals-mobile','.w-menu-slider > ul > li','vertical-align','top','','','.w-menu-slider'),(175840,'deals-mobile','.w-menu-slider .close','vertical-align','20px','','','.w-menu-slider'),(175841,'deals-mobile','.w-menu-slider > ul > li > ul > li','vertical-align','top','','','.w-menu-slider'),(175842,'deals-mobile','.w-account .my-acc-link','vertical-align','middle','3','','.w-account'),(175843,'deals-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','vertical-align','middle','','','.b-cookie-notice'),(175844,'deals-mobile','.b-form .checkbox-style:checked + .checkbox-span','vertical-align','middle','','','.b-form'),(175845,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','vertical-align','middle','','','.b-form'),(175846,'deals-mobile','.w-cart .cart-box-link','vertical-align','middle','3','','.w-cart'),(175847,'deals-mobile','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','vertical-align','middle','','','.w-menu-horizontal'),(175848,'deals-mobile','.b-product-images .additional-images .item > div, .b-product-images .additional-videos .item > div','vertical-align','middle','','','.b-product-images'),(175849,'deals-mobile','.w-compare-box-item .checkbox','vertical-align','top','','','.w-compare-box-item'),(175850,'deals-mobile','.w-compare-box-item .checkbox + span','vertical-align','middle','','','.w-compare-box-item'),(175851,'deals-mobile','.w-categories .item','vertical-align','top','','','.w-categories'),(175852,'deals-mobile','.w-quote .no-text','vertical-align','top','','','.w-quote'),(175853,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','vertical-align','middle','3','','.b-multi-page-checkout'),(175854,'deals-mobile','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(175855,'deals-mobile','.b-compare .compare_select_items','vertical-align','middle','','','.b-compare'),(175856,'deals-mobile','.w-catalog-listing-look .b2b','vertical-align','top','','','.w-catalog-listing-look'),(175857,'deals-mobile','.w-catalog-listing-look .list','vertical-align','top','','','.w-catalog-listing-look'),(175858,'deals-mobile','.b-pagination .pagination .prev-pages','vertical-align','top','','','.b-pagination'),(175859,'deals-mobile','.b-pagination .pagination .prev','vertical-align','top','','','.b-pagination'),(175860,'deals-mobile','.b-pagination .pagination .page-number','vertical-align','top','','','.b-pagination'),(175861,'deals-mobile','.b-pagination .pagination .next-pages','vertical-align','top','','','.b-pagination'),(175862,'deals-mobile','.b-pagination .pagination .next','vertical-align','top','','','.b-pagination'),(175863,'deals-mobile','.b-pagination .pagination span','vertical-align','top','2','','.b-pagination'),(175864,'deals-mobile','.p-account-history .view_link','vertical-align','middle','4','','.p-account-history'),(175865,'deals-mobile','.p-reviews-info .review_by span','vertical-align','middle','','','.p-reviews-info'),(175866,'deals-mobile','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(175867,'deals-mobile','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(175868,'deals-mobile','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(175869,'deals-mobile','.p-wedding-registry-manage .links a','vertical-align','middle','','','.p-wedding-registry-manage'),(175870,'deals-mobile','.b-pagination .pagination a','vertical-align','top','','','.b-pagination'),(175871,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align','top','','','.b-switch'),(175872,'deals-mobile','.b-switch .bootstrap-switch','vertical-align','middle','','','.b-switch'),(175873,'deals-mobile','.w-filters .input-checkbox:checked + .checkbox-span','vertical-align','middle','','','.w-filters'),(175874,'deals-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','vertical-align','middle','','','.w-filters'),(175875,'deals-mobile','.w-quote .cart-box-link','vertical-align','middle','3','','.w-quote'),(175876,'deals-mobile','.w-tabs .tab-li','vertical-align','bottom','','','.w-tabs'),(175877,'deals-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','vertical-align','middle','','','.w-banner'),(175878,'deals-mobile','.p-account-index .view_link','vertical-align','middle','4','','.p-account-index'),(175879,'deals-mobile','.p-account-index td.acc_wish_remove','vertical-align','middle','','','.p-account-index'),(175880,'deals-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','vertical-align','top','','','.b-fancybox'),(175881,'deals-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','vertical-align','top','','','.b-fancybox'),(175882,'deals-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(175883,'deals-mobile','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(175884,'deals-mobile','.w-product-configurator .item-content > div','vertical-align','middle','','','.w-product-configurator'),(175885,'deals-mobile','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(175886,'deals-mobile','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(175887,'deals-mobile','.w-catalog-listing-look .grid','vertical-align','top','','','.w-catalog-listing-look'),(175888,'deals-mobile','.w-cart .no-text','vertical-align','top','','','.w-cart'),(175889,'deals-mobile','.w-top-categories .item','vertical-align','top','','','.w-top-categories'),(175890,'deals-mobile','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','vertical-align','middle','','','.b-form'),(175891,'deals-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','vertical-align','middle','','','.w-menu-style-1'),(175892,'deals-mobile','.b-products-listing .products-listing .item','vertical-align','top','','','.b-products-listing'),(175893,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.b-data-table'),(175894,'deals-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.b-data-table'),(175895,'deals-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(175896,'deals-mobile','.b-email .image','vertical-align','top','','','.b-email'),(175897,'deals-mobile','.b-email .model','vertical-align','top','','','.b-email'),(175898,'deals-mobile','.b-email .price','vertical-align','top','','','.b-email'),(175899,'deals-mobile','.b-email .model','vertical-align','top','','','.b-email'),(175900,'deals-mobile','.b-email .model','vertical-align','top','','','.b-email'),(175901,'deals-mobile','.b-email .price','vertical-align','top','','','.b-email'),(175902,'deals-mobile','.b-email .name','vertical-align','top','','','.b-email'),(175903,'deals-mobile','.b-email .model','vertical-align','top','','','.b-email'),(175904,'deals-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(175905,'deals-mobile','.b-email .image','vertical-align','top','','','.b-email'),(175906,'deals-mobile','.b-email .image','vertical-align','top','','','.b-email'),(175907,'deals-mobile','.b-email .model','vertical-align','top','','','.b-email'),(175908,'deals-mobile','.b-email .name','vertical-align','top','','','.b-email'),(175909,'deals-mobile','.b-email .price','vertical-align','top','','','.b-email'),(175910,'deals-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(175911,'deals-mobile','.b-email .image','vertical-align','top','','','.b-email'),(175912,'deals-mobile','.b-email .name','vertical-align','top','','','.b-email'),(175913,'deals-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(175914,'deals-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(175915,'deals-mobile','.b-email .image','vertical-align','top','','','.b-email'),(175916,'deals-mobile','.b-email .image','vertical-align','top','','','.b-email'),(175917,'deals-mobile','.b-email .name','vertical-align','top','','','.b-email'),(175918,'deals-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(175919,'deals-mobile','.b-email .name','vertical-align','top','','','.b-email'),(175920,'deals-mobile','.b-email .name','vertical-align','top','','','.b-email'),(175921,'deals-mobile','.b-email .price','vertical-align','top','','','.b-email'),(175922,'deals-mobile','.b-email .price','vertical-align','top','','','.b-email'),(175923,'deals-mobile','.b-email .model','vertical-align','top','','','.b-email'),(175924,'deals-mobile','.b-email .price','vertical-align','top','','','.b-email'),(175925,'deals-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(175926,'deals-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(175927,'deals-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(175928,'deals-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(175929,'deals-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(175930,'deals-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(175931,'deals-mobile','.b-messages .msv_to_cc div span','vertical-align','middle','','','.b-messages'),(175932,'deals-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(175933,'deals-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(175934,'deals-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(175935,'deals-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(175936,'deals-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(175937,'deals-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(175938,'deals-mobile','.b-upload-file .upload-file-template','vertical-align','top','','','.b-upload-file'),(175939,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','vertical-align','top','','','.b-warehouses-popup'),(175940,'deals-mobile','.batchPr .checkbox input + span','vertical-align','middle','','','.batchPr'),(175941,'deals-mobile','.p-account-samples-history .view_link','vertical-align','middle','4','','.p-account-samples-history'),(175942,'deals-mobile','.p-account-samples-history .view_link','vertical-align','middle','4','','.p-account-samples-history'),(175943,'deals-mobile','.p-account-samples-history .view_link','vertical-align','middle','4','','.p-account-samples-history'),(175944,'deals-mobile','.p-account-samples-history .view_link','vertical-align','middle','4','','.p-account-samples-history'),(175945,'deals-mobile','.p-account-samples-history .view_link','vertical-align','middle','4','','.p-account-samples-history'),(175946,'deals-mobile','.p-account-samples-history .view_link','vertical-align','middle','4','','.p-account-samples-history'),(175947,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.p-quick-order-index'),(175948,'deals-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.p-quick-order-index'),(175949,'deals-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','vertical-align','middle','','','.w-blog-widget-post-share'),(175950,'deals-mobile','.w-cart-compare .product-label','vertical-align','bottom','','','.w-cart-compare'),(175951,'deals-mobile','.w-cart-compare .product-actions .dropdown-toggle','vertical-align','middle','3','','.w-cart-compare'),(175952,'deals-mobile','.w-cart-compare .product-cell','vertical-align','top','','','.w-cart-compare'),(175953,'deals-mobile','.w-cart-credit-amount .amount-title','vertical-align','top','3','','.w-cart-credit-amount'),(175954,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','vertical-align','middle','3','','.w-catalog-compare'),(175955,'deals-mobile','.w-catalog-paging ','vertical-align','top','2','','.w-catalog-paging'),(175956,'deals-mobile','.w-catalog-paging .prev','vertical-align','top','','','.w-catalog-paging'),(175957,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','vertical-align','top','','','.w-catalog-paging'),(175958,'deals-mobile','.w-catalog-paging .page-number','vertical-align','top','','','.w-catalog-paging'),(175959,'deals-mobile','.w-catalog-paging .next-pages','vertical-align','top','','','.w-catalog-paging'),(175960,'deals-mobile','.w-catalog-paging .next','vertical-align','top','','','.w-catalog-paging'),(175961,'deals-mobile','.w-catalog-paging .prev-pages','vertical-align','top','','','.w-catalog-paging'),(175962,'deals-mobile','.w-checkout-billing-address .genders-title > div','vertical-align','top','','','.w-checkout-billing-address'),(175963,'deals-mobile','.w-checkout-shipping-address .genders-title > div','vertical-align','top','','','.w-checkout-shipping-address'),(175964,'deals-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','vertical-align','bottom','','','.w-communication-new-topic'),(175965,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','vertical-align','top','','','.w-communication-new-topic'),(175966,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','3','','.w-communication-new-topic'),(175967,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','','','.w-communication-new-topic'),(175968,'deals-mobile','.w-product-available-in-warehouses .warehouse-item','vertical-align','top','','','.w-product-available-in-warehouses'),(175969,'deals-mobile','.w-promotions .heading-3','vertical-align','top','','','.w-promotions'),(175970,'deals-mobile','.b-quantity .qty-box input[type=\'text\']','vertical-align','top','','','.b-quantity'),(175971,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align_important','important','','','.b-switch'),(175972,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no','visibility','hidden','','','.b-form'),(175973,'deals-mobile','.w-compare-box-item .checkbox:not(checked)','visibility','hidden','','','.w-compare-box-item'),(175974,'deals-mobile','.b-fancybox .fancybox-title','visibility','hidden','','','.b-fancybox'),(175975,'deals-mobile','.b-fancybox .fancybox-tmp','visibility','hidden','','','.b-fancybox'),(175976,'deals-mobile','.b-fancybox .fancybox-nav:hover span','visibility','visible','','','.b-fancybox'),(175977,'deals-mobile','.b-fancybox .fancybox-opened .fancybox-title','visibility','visible','','','.b-fancybox'),(175978,'deals-mobile','.b-slick .slick-loading .slick-track','visibility','hidden','','','.b-slick'),(175979,'deals-mobile','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(175980,'deals-mobile','.b-slick .slick-loading .slick-slide','visibility','hidden','','','.b-slick'),(175981,'deals-mobile','.b-fancybox .fancybox-nav span','visibility','hidden','','','.b-fancybox'),(175982,'deals-mobile','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(175983,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','visibility','hidden','','','.b-menu-lev_display-slide'),(175984,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-1 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(175985,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','visibility','hidden','','','.b-menu-lev_display-slide'),(175986,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','visibility','hidden','','','.b-menu-lev_display-slide'),(175987,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','visibility','hidden','','','.b-menu-lev_display-slide'),(175988,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','visibility','hidden','','','.b-menu-lev_display-slide'),(175989,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-2 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(175990,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-4 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(175991,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-5 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(175992,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-3 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(175993,'deals-mobile','.b-upload-files .attach-active-holder .attach-file','visibility','hidden','','','.b-upload-files'),(175994,'deals-mobile','.batchPr .checkbox input','visibility','hidden','','','.batchPr'),(175995,'deals-mobile','.w-menu-horizontal > ul','white-space','nowrap','','','.w-menu-horizontal'),(175996,'deals-mobile','.w-menu-style-1 > ul','white-space','nowrap','','','.w-menu-style-1'),(175997,'deals-mobile','.w-menu-horizontal > ul','white-space','normal','864','','.w-menu-horizontal'),(175998,'deals-mobile','.p-account-history .view_link','white-space','nowrap','','','.p-account-history'),(175999,'deals-mobile','.b-fancybox .fancybox-error','white-space','nowrap','','','.b-fancybox'),(176000,'deals-mobile','.b-fancybox .fancybox-title-float-wrap .child','white-space','nowrap','','','.b-fancybox'),(176001,'deals-mobile','.p-account-index .view_link','white-space','nowrap','','','.p-account-index'),(176002,'deals-mobile','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(176003,'deals-mobile','.b-select-suggest .select2-search','white-space','nowrap','','','.b-select-suggest'),(176004,'deals-mobile','.b-select-suggest .select2-container .select2-choice','white-space','nowrap','','','.b-select-suggest'),(176005,'deals-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','white-space','nowrap','','','.b-select-suggest'),(176006,'deals-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','white-space','nowrap','','','.b-select-suggest'),(176007,'deals-mobile','.p-account-samples-history .view_link','white-space','nowrap','','','.p-account-samples-history'),(176008,'deals-mobile','.p-account-samples-history .view_link','white-space','nowrap','','','.p-account-samples-history'),(176009,'deals-mobile','.p-account-samples-history .view_link','white-space','nowrap','','','.p-account-samples-history'),(176010,'deals-mobile','.p-account-samples-history .view_link','white-space','nowrap','','','.p-account-samples-history'),(176011,'deals-mobile','.p-account-samples-history .view_link','white-space','nowrap','','','.p-account-samples-history'),(176012,'deals-mobile','.p-account-samples-history .view_link','white-space','nowrap','','','.p-account-samples-history'),(176013,'deals-mobile','.w-checkout-shipping-choice span','white-space','nowrap','','','.w-checkout-shipping-choice'),(176014,'deals-mobile','.w-menu .hided.menu ul li','width','auto','','','.w-menu'),(176015,'deals-mobile','.w-menu .hided.menu ul ul','width','auto','','','.w-menu'),(176016,'deals-mobile','.w-menu-big li','width','auto','','','.w-menu-big'),(176017,'deals-mobile','.w-menu-slider > ul > li > ul','width','100','','','.w-menu-slider'),(176018,'deals-mobile','.w-bestsellers .item','width','31','3','','.w-bestsellers'),(176019,'deals-mobile','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(176020,'deals-mobile','.w-bestsellers .counter','width','31','','','.w-bestsellers'),(176021,'deals-mobile','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(176022,'deals-mobile','.b-form .checkbox-style:checked + .checkbox-span','width','15','','','.b-form'),(176023,'deals-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','width','15','','','.b-form'),(176024,'deals-mobile','.b-form .checkbox-style','width','0','','','.b-form'),(176025,'deals-mobile','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(176026,'deals-mobile','.w-login-block .guest','width','50','','','.w-login-block'),(176027,'deals-mobile','.w-login-block .input','width','100','','','.w-login-block'),(176028,'deals-mobile','.w-login-block .returning','width','50','','','.w-login-block'),(176029,'deals-mobile','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(176030,'deals-mobile','.w-login-block .new','width','50','','','.w-login-block'),(176031,'deals-mobile','.w-sale .left-count','width','23','','','.w-sale'),(176032,'deals-mobile','.w-menu-horizontal .menu-ico','width','54','','','.w-menu-horizontal'),(176033,'deals-mobile','.w-list-type-2_2 .sale','width','100','4','','.w-list-type-2_2'),(176034,'deals-mobile','.w-sale .image','width','50','','','.w-sale'),(176035,'deals-mobile','.w-sale .holder-1','width','25','','','.w-sale'),(176036,'deals-mobile','.w-sale .holder-2','width','25','','','.w-sale'),(176037,'deals-mobile','.w-sale .badge','width','80','','','.w-sale'),(176038,'deals-mobile','.w-menu-style-1 .menu-ico','width','54','','','.w-menu-style-1'),(176039,'deals-mobile','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(176040,'deals-mobile','.w-product-attributes .select','width','100','','','.w-product-attributes'),(176041,'deals-mobile','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(176042,'deals-mobile','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(176043,'deals-mobile','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(176044,'deals-mobile','.w-product-wedding-registry-button .btn','width','18','4','','.w-product-wedding-registry-button'),(176045,'deals-mobile','.w-product-sale-ends .left-count','width','23','','','.w-product-sale-ends'),(176046,'deals-mobile','.w-product-sale-ends .left-text-left','width','24','','','.w-product-sale-ends'),(176047,'deals-mobile','.w-product-sale-ends .left-text-right','width','24','','','.w-product-sale-ends'),(176048,'deals-mobile','.w-product-collection .right-area','width','25','','','.w-product-collection'),(176049,'deals-mobile','.w-product-collection .chosen-products','width','50','','','.w-product-collection'),(176050,'deals-mobile','.w-product-collection .current-product','width','25','','','.w-product-collection'),(176051,'deals-mobile','.b-fancybox .fancybox-nav','width','40','','','.b-fancybox'),(176052,'deals-mobile','.w-top-categories .item','width','50','863','','.w-top-categories'),(176053,'deals-mobile','.w-product-personal-catalog-button .btn','width','160','','','.w-product-personal-catalog-button'),(176054,'deals-mobile','.w-currencies .select','width','100','','','.w-currencies'),(176055,'deals-mobile','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(176056,'deals-mobile','.w-categories .item','width','50','863','','.w-categories'),(176057,'deals-mobile','.p-account-history-info .not_fully_paid_td','width','300','','','.p-account-history-info'),(176058,'deals-mobile','.p-account-index .not_fully_paid_td','width','300','','','.p-account-index'),(176059,'deals-mobile','.w-compare-box-item .checkbox','width','22','','','.w-compare-box-item'),(176060,'deals-mobile','.w-compare-box-item .checkbox + span','width','24','','','.w-compare-box-item'),(176061,'deals-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width','49','','','.p-account-trade-form'),(176062,'deals-mobile','.w-categories .item','width','25','','','.w-categories'),(176063,'deals-mobile','.w-cart-order-total.box','width','100','892','','.w-cart-order-total'),(176064,'deals-mobile','.w-cart-checkout-btn','width','100','863','','.w-cart-checkout-btn'),(176065,'deals-mobile','.b-product-images .additional-horizontal .additional-images, .b-product-images .additional-horizontal .additional-videos','width','100','','','.b-product-images'),(176066,'deals-mobile','.b-price-box .price-box .price','width','200','','','.b-price-box'),(176067,'deals-mobile','.w-cart-give-away .ga_column','width','100','863','','.w-cart-give-away'),(176068,'deals-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-videos .item img','width','auto','','','.b-product-images'),(176069,'deals-mobile','.w-product-properties li','width','50','','','.w-product-properties'),(176070,'deals-mobile','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(176071,'deals-mobile','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(176072,'deals-mobile','.w-product-in-bundles .bundle_item','width','48','','','.w-product-in-bundles'),(176073,'deals-mobile','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(176074,'deals-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','width','48','','','.p-account-address-book'),(176075,'deals-mobile','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(176076,'deals-mobile','.w-product-bundle .bundle_item','width','48','','','.w-product-bundle'),(176077,'deals-mobile','.w-menu-slider .menu-ico','width','54','','','.w-menu-slider'),(176078,'deals-mobile','.w-catalog-listing-look .b2b','width','31','','','.w-catalog-listing-look'),(176079,'deals-mobile','.w-catalog-listing-look .list','width','31','','','.w-catalog-listing-look'),(176080,'deals-mobile','.p-account-address-book .topInfo > div','width','100','863','','.p-account-address-book'),(176081,'deals-mobile','.p-account-address-book .address_book_row .column + .column','width','100','863','','.p-account-address-book'),(176082,'deals-mobile','.p-account-address-book .address_book_row .column','width','100','863','','.p-account-address-book'),(176083,'deals-mobile','.p-account-index .topAccount > li','width','100','863','','.p-account-index'),(176084,'deals-mobile','.p-account-address-book .topInfo > div + div','width','100','863','','.p-account-address-book'),(176085,'deals-mobile','.p-blog-index .nav-next','width','100','888','','.p-blog-index'),(176086,'deals-mobile','.p-account-history-info .history_info > div','width','100','864','','.p-account-history-info'),(176087,'deals-mobile','.p-blog-index .nav-previous','width','100','888','','.p-blog-index'),(176088,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','width','35','3','','.b-multi-page-checkout'),(176089,'deals-mobile','.p-blog-index .post-thumbnail','width','200','','','.p-blog-index'),(176090,'deals-mobile','.w-list-type-1_2 .right-area','width','100','864','','.w-list-type-1_2'),(176091,'deals-mobile','.p-blog-index .comment-form p label','width','100','','','.p-blog-index'),(176092,'deals-mobile','.w-list-type-1_2 .right-area .name','width','60','','','.w-list-type-1_2'),(176093,'deals-mobile','.w-list-type-1_2 .image','width','100','864','','.w-list-type-1_2'),(176094,'deals-mobile','.w-list-type-1_2 .right-area .right-area-2','width','100','864','','.w-list-type-1_2'),(176095,'deals-mobile','.w-list-type-1_2 .right-area .right-area-2','width','38','','','.w-list-type-1_2'),(176096,'deals-mobile','.w-list-type-1_2 .right-area .name','width','100','864','','.w-list-type-1_2'),(176097,'deals-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','width','33','','','.b-multi-page-checkout'),(176098,'deals-mobile','.b-info-popup .info-popup div','width','250','','','.b-info-popup'),(176099,'deals-mobile','.w-menu-mobile .menu-slider .open','width','100','','','.w-menu-mobile'),(176100,'deals-mobile','.w-promo-code .promo-text','width','100','864','','.w-promo-code'),(176101,'deals-mobile','.w-promo-code .promo-code-form','width','100','864','','.w-promo-code'),(176102,'deals-mobile','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(176103,'deals-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 110px)','864','','.w-promo-code'),(176104,'deals-mobile','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(176105,'deals-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(176106,'deals-mobile','.w-catalog-sorting select','width','100','','','.w-catalog-sorting'),(176107,'deals-mobile','.b-form .col-right','width','100','890','','.b-form'),(176108,'deals-mobile','.b-form .columns .col-2','width','100','893','','.b-form'),(176109,'deals-mobile','.b-form .col-left','width','100','890','','.b-form'),(176110,'deals-mobile','.p-account-order-pay .history_info > div','width','33.3','','','.p-account-order-pay'),(176111,'deals-mobile','.p-account-order-pay .history_info > div','width','100','864','','.p-account-order-pay'),(176112,'deals-mobile','.p-account-order-pay .not_fully_paid_td','width','300','','','.p-account-order-pay'),(176113,'deals-mobile','.w-product-configurator .item-content','width','100','872','','.w-product-configurator'),(176114,'deals-mobile','.w-product-configurator .pc_item','width','100','872','','.w-product-configurator'),(176115,'deals-mobile','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(176116,'deals-mobile','.p-wedding-registry-manage .wr-search input','width','100','','','.p-wedding-registry-manage'),(176117,'deals-mobile','.p-wedding-registry-manage .wr-search','width','400','','','.p-wedding-registry-manage'),(176118,'deals-mobile','.p-wedding-registry-manage .wr-search button','width','30','','','.p-wedding-registry-manage'),(176119,'deals-mobile','.p-account-history .orders-table .hidden','width','130','890','','.p-account-history'),(176120,'deals-mobile','.p-account-history .orders-table .td-alignright','width','100','890','','.p-account-history'),(176121,'deals-mobile','.p-account-index .orders-table .hidden','width','130','890','','.p-account-index'),(176122,'deals-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','50','890','','.p-blog-index'),(176123,'deals-mobile','.p-account-index .orders-table .td-alignright','width','100','890','','.p-account-index'),(176124,'deals-mobile','.p-blog-index .nav-next','width','50','','','.p-blog-index'),(176125,'deals-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','100','893','','.p-blog-index'),(176126,'deals-mobile','.p-blog-index .nav-previous','width','50','','','.p-blog-index'),(176127,'deals-mobile','.pop-up-content .buttons .btn','width','100','864','',''),(176128,'deals-mobile','.w-list-type-1_3 .right-area .right-area-2','width','38','','','.w-list-type-1_3'),(176129,'deals-mobile','.pop-up-content .buttons .btn-2','width','100','864','',''),(176130,'deals-mobile','.w-list-type-2_2 .sale','width','94','','','.w-list-type-2_2'),(176131,'deals-mobile','.pop-up-content .buttons .right-buttons','width','100','864','',''),(176132,'deals-mobile','.pop-up-content .buttons .left-buttons','width','100','864','',''),(176133,'deals-mobile','.w-list-type-2_2 .image','width','170','','','.w-list-type-2_2'),(176134,'deals-mobile','.w-list-type-2_2 .sale','width','100','3','','.w-list-type-2_2'),(176135,'deals-mobile','.w-list-type-2_2 .button-wishlist button','width','100','','','.w-list-type-2_2'),(176136,'deals-mobile','.w-list-type-2 .sale','width','100','3','','.w-list-type-2'),(176137,'deals-mobile','.w-list-type-2 .sale','width','94','','','.w-list-type-2'),(176138,'deals-mobile','.w-list-type-2_2 .button-wishlist','width','50','','','.w-list-type-2_2'),(176139,'deals-mobile','.personal-buttons > div > div','width','50','','','.personal-buttons'),(176140,'deals-mobile','.w-product-bonus-points > div > div','width','50','','','.w-product-bonus-points'),(176141,'deals-mobile','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(176142,'deals-mobile','.w-cart-continue-btn a','width','100','863','','.w-cart-continue-btn'),(176143,'deals-mobile','.b-fancybox #fancybox-loading div','width','44','','','.b-fancybox'),(176144,'deals-mobile','.w-brands .brands-listing > div','width','16','','','.w-brands'),(176145,'deals-mobile','.w-product-wedding-registry-button .btn','width','160','','','.w-product-wedding-registry-button'),(176146,'deals-mobile','.b-fancybox .fancybox-close','width','36','','','.b-fancybox'),(176147,'deals-mobile','.b-fancybox .fancybox-lock','width','auto','','','.b-fancybox'),(176148,'deals-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width','100','','','.b-fancybox'),(176149,'deals-mobile','.w-delivery-location-top-location-list .deliveryList li','width','23','','','.w-delivery-location-top-location-list'),(176150,'deals-mobile','.w-menu-horizontal li','width','auto','','','.w-menu-horizontal'),(176151,'deals-mobile','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(176152,'deals-mobile','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(176153,'deals-mobile','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(176154,'deals-mobile','.b-form .radio-button input[type=\"radio\"].no + span','width','30','3','','.b-form'),(176155,'deals-mobile','.p-wedding-registry-index .search-list input','width','300','','','.p-wedding-registry-index'),(176156,'deals-mobile','.p-wedding-registry-index .search-list','width','150','3','','.p-wedding-registry-index'),(176157,'deals-mobile','.p-wedding-registry-search .search-list input','width','100','','','.p-wedding-registry-search'),(176158,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width','20','3','','.b-switch'),(176159,'deals-mobile','.b-bottom .popup-credit-amount .popup-box','width','100','','','.b-bottom'),(176160,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width','20','3','','.b-switch'),(176161,'deals-mobile','.b-compare .col-two label','width','20','','','.b-compare'),(176162,'deals-mobile','.b-compare .col-two select','width','80','','','.b-compare'),(176163,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-label','width','30','','','.b-switch'),(176164,'deals-mobile','.w-list-type-1 .image img','width','auto','','','.w-list-type-1'),(176165,'deals-mobile','.w-search .search form','width','100','','','.w-search'),(176166,'deals-mobile','.w-languages .lang-link','width','61','872','','.w-languages'),(176167,'deals-mobile','.w-product-buttons .btn, .w-product-buttons .btn-2, .w-product-buttons .btn-3, .w-product-buttons .btn-4','width','100','','','.w-product-buttons'),(176168,'deals-mobile','.b-quantity .qty-box .smaller, .b-quantity .qty-box .bigger','width','39','','','.b-quantity'),(176169,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','width','40','','','.b-slick'),(176170,'deals-mobile','.w-filters .input-checkbox:checked + .checkbox-span','width','24','','','.w-filters'),(176171,'deals-mobile','.b-form .col-left','width','48','','','.b-form'),(176172,'deals-mobile','.w-search .suggest','width','100','','','.w-search'),(176173,'deals-mobile','.w-search .image','width','40','','','.w-search'),(176174,'deals-mobile','.w-search .search-input','width','100','','','.w-search'),(176175,'deals-mobile','.w-socials .post_item_img','width','100','','','.w-socials'),(176176,'deals-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width','100','','','.w-banner'),(176177,'deals-mobile','textarea','width','100','','',''),(176178,'deals-mobile','.w-filters .input-txt','width','60','','','.w-filters'),(176179,'deals-mobile','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width','100','','','.w-banner'),(176180,'deals-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width','48','','','.p-account-trade-form'),(176181,'deals-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width','55','','','.p-account-trade-form'),(176182,'deals-mobile','.p-account-trade-form .wl-td label','width','40','','','.p-account-trade-form'),(176183,'deals-mobile','.p-account-trade-form .wl-td select','width','55','','','.p-account-trade-form'),(176184,'deals-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width','48','','','.p-account-trade-form'),(176185,'deals-mobile','.b-price-box .price-box .price','width','120','892','','.b-price-box'),(176186,'deals-mobile','.w-filters .handle-from','width','50','','','.w-filters'),(176187,'deals-mobile','.b-bottom .popup-box.popupCompare','width','80','','','.b-bottom'),(176188,'deals-mobile','.w-filters .handle-to','width','50','','','.w-filters'),(176189,'deals-mobile','.w-filters .input-checkbox','width','0','','','.w-filters'),(176190,'deals-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','width','24','','','.w-filters'),(176191,'deals-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(176192,'deals-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','width','22','','','.w-compare-box-item'),(176193,'deals-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width','49','','','.p-account-trade-form'),(176194,'deals-mobile','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(176195,'deals-mobile','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(176196,'deals-mobile','.b-info-popup .info-popup div','width','20','3','','.b-info-popup'),(176197,'deals-mobile','.p-reviews-info .review-info-image','width','24','','','.p-reviews-info'),(176198,'deals-mobile','.b-fancybox .fancybox-nav span','width','40','','','.b-fancybox'),(176199,'deals-mobile','.p-checkout-success .page-success','width','100','3','','.p-checkout-success'),(176200,'deals-mobile','.w-menu-mobile .menu-ico','width','54','','','.w-menu-mobile'),(176201,'deals-mobile','.w-product-quantity-discounts .quantity-discounts .count','width','40','','','.w-product-quantity-discounts'),(176202,'deals-mobile','.w-product-wedding-registry-button .btn','width','18','3','','.w-product-wedding-registry-button'),(176203,'deals-mobile','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(176204,'deals-mobile','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(176205,'deals-mobile','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(176206,'deals-mobile','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(176207,'deals-mobile','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(176208,'deals-mobile','.w-menu-style-1 li','width','auto','','','.w-menu-style-1'),(176209,'deals-mobile','.p-account-history .not_fully_paid_td','width','300','','','.p-account-history'),(176210,'deals-mobile','.w-sale .left-text-right','width','24','','','.w-sale'),(176211,'deals-mobile','.w-sale .left-text-left','width','24','','','.w-sale'),(176212,'deals-mobile','.w-banner .carousel-text','width','100','','','.w-banner'),(176213,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','width','50','876','','.b-slick'),(176214,'deals-mobile','.b-quantity .qty-box .smaller','width','35','','','.b-quantity'),(176215,'deals-mobile','.b-quantity .qty-input input','width','40','','','.b-quantity'),(176216,'deals-mobile','.b-quantity .qty-box .bigger','width','35','','','.b-quantity'),(176217,'deals-mobile','.w-cart-checkout-btn a','width','100','863','','.w-cart-checkout-btn'),(176218,'deals-mobile','.w-cart .cart-box.hover-box .cart-content','width','410','','','.w-cart'),(176219,'deals-mobile','.p-account-index .account_info li','width','100','863','','.p-account-index'),(176220,'deals-mobile','.w-product-images .item-div','width','80','893','','.w-product-images'),(176221,'deals-mobile','.w-product-images .item','width','80','893','','.w-product-images'),(176222,'deals-mobile','.w-list-type-1_3 .right-area .name','width','60','','','.w-list-type-1_3'),(176223,'deals-mobile','.w-list-type-1_3 .right-area','width','100','864','','.w-list-type-1_3'),(176224,'deals-mobile','.w-list-type-1_3 .right-area .right-area-2','width','100','864','','.w-list-type-1_3'),(176225,'deals-mobile','.w-list-type-1_3 .image','width','100','864','','.w-list-type-1_3'),(176226,'deals-mobile','.w-list-type-1_3 .right-area .name','width','100','864','','.w-list-type-1_3'),(176227,'deals-mobile','.w-cart-order-total.box','width','100','','','.w-cart-order-total'),(176228,'deals-mobile','.w-cart-discount-coupon .gift-code input','width','100','','','.w-cart-discount-coupon'),(176229,'deals-mobile','.w-cart .image','width','70','','','.w-cart'),(176230,'deals-mobile','.b-form .addresses .address-item','width','48','','','.b-form'),(176231,'deals-mobile','.w-catalog-listing-look .grid','width','31','','','.w-catalog-listing-look'),(176232,'deals-mobile','.b-form .discount-box input[type=\"text\"]','width','100','','','.b-form'),(176233,'deals-mobile','.p-account-index .account_info li','width','30.33','','','.p-account-index'),(176234,'deals-mobile','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width','100','','','.b-form'),(176235,'deals-mobile','.b-form .hide-billing-address','width','100','','','.b-form'),(176236,'deals-mobile','.b-form .col-right','width','48','','','.b-form'),(176237,'deals-mobile','.b-form .columns .col-2','width','48','','','.b-form'),(176238,'deals-mobile','.p-account-index .topAccount > li','width','20','','','.p-account-index'),(176239,'deals-mobile','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(176240,'deals-mobile','.w-cart-give-away .ga_attributes select','width','100','','','.w-cart-give-away'),(176241,'deals-mobile','.w-cart-give-away .ga_column','width','46','','','.w-cart-give-away'),(176242,'deals-mobile','.w-cart-give-away .ga_attributes > div','width','48','','','.w-cart-give-away'),(176243,'deals-mobile','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','width','79','','','.b-datepicker'),(176244,'deals-mobile','.w-cart-give-away .ga_img','width','30','','','.w-cart-give-away'),(176245,'deals-mobile','.w-list-type-1_3 .right-area','width','calc(100% - 190px)','','','.w-list-type-1_3'),(176246,'deals-mobile','.view-all','width','100','3','',''),(176247,'deals-mobile','.w-list-type-2 .button-wishlist button','width','100','','','.w-list-type-2'),(176248,'deals-mobile','.w-list-type-2 .button-wishlist','width','50','','','.w-list-type-2'),(176249,'deals-mobile','.w-list-type-1_3 .sale','width','100','4','','.w-list-type-1_3'),(176250,'deals-mobile','.w-list-type-1_3 .sale','width','100','3','','.w-list-type-1_3'),(176251,'deals-mobile','.w-list-type-2 .sale','width','100','4','','.w-list-type-2'),(176252,'deals-mobile','.w-list-type-1_3 .sale','width','94','','','.w-list-type-1_3'),(176253,'deals-mobile','.w-list-type-1_3 .image','width','170','','','.w-list-type-1_3'),(176254,'deals-mobile','.w-list-type-1_3 .button-wishlist','width','50','','','.w-list-type-1_3'),(176255,'deals-mobile','.w-list-type-1_2 .sale','width','100','4','','.w-list-type-1_2'),(176256,'deals-mobile','.w-list-type-1_3 .button-wishlist button','width','100','','','.w-list-type-1_3'),(176257,'deals-mobile','.w-list-type-1_3 .attributes > .attributes > div','width','48','','','.w-list-type-1_3'),(176258,'deals-mobile','.w-list-type-1_2 .right-area','width','calc(100% - 190px)','','','.w-list-type-1_2'),(176259,'deals-mobile','.w-list-type-1_2 .sale','width','100','3','','.w-list-type-1_2'),(176260,'deals-mobile','.w-list-type-1_2 .sale','width','94','','','.w-list-type-1_2'),(176261,'deals-mobile','.b-bottom .pop-up-close','width','31','','','.b-bottom'),(176262,'deals-mobile','.w-list-type-1 .sale','width','100','4','','.w-list-type-1'),(176263,'deals-mobile','.w-list-type-1_2 .button-view','width','50','','','.w-list-type-1_2'),(176264,'deals-mobile','.w-list-type-1_2 .button-wishlist button','width','100','','','.w-list-type-1_2'),(176265,'deals-mobile','.w-list-type-1_2 .button-wishlist','width','50','','','.w-list-type-1_2'),(176266,'deals-mobile','.w-list-type-1 .sale','width','94','','','.w-list-type-1'),(176267,'deals-mobile','.w-list-type-1 .sale','width','100','3','','.w-list-type-1'),(176268,'deals-mobile','.b-bottom .popup-box','width','530','','','.b-bottom'),(176269,'deals-mobile','.w-list-type-1 .button-wishlist button','width','100','','','.w-list-type-1'),(176270,'deals-mobile','.w-filters .mobileCollapse','width','17','','','.w-filters'),(176271,'deals-mobile','.w-filters .input-txt-keywords','width','100','','','.w-filters'),(176272,'deals-mobile','.w-filters .ui-slider-handle','width','15','','','.w-filters'),(176273,'deals-mobile','.w-filters .ui-slider','width','92','','','.w-filters'),(176274,'deals-mobile','.w-tabs .tab-navigation','width','100','','','.w-tabs'),(176275,'deals-mobile','.w-list-type-1 .button-wishlist','width','50','','','.w-list-type-1'),(176276,'deals-mobile','.p-account-index .ai_title','width','40','','','.p-account-index'),(176277,'deals-mobile','.w-top-categories .item','width','25','','','.w-top-categories'),(176278,'deals-mobile','.w-search .button-search','width','48','','','.w-search'),(176279,'deals-mobile','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width','100','','','.b-form'),(176280,'deals-mobile','.p-account-history-info .history_info > div','width','33.3','','','.p-account-history-info'),(176281,'deals-mobile','.b-form .middle-form .dob-input input[type=\"text\"]','width','48','','','.b-form'),(176282,'deals-mobile','div.cart-popup','width','850','','',''),(176283,'deals-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width','80','','','.b-products-listing'),(176284,'deals-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width','20','','','.b-products-listing'),(176285,'deals-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width','40','','','.b-products-listing'),(176286,'deals-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width','60','','','.b-products-listing'),(176287,'deals-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width','60','','','.b-products-listing'),(176288,'deals-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width','40','','','.b-products-listing'),(176289,'deals-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width','20','','','.b-products-listing'),(176290,'deals-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width','60','','','.b-products-listing'),(176291,'deals-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width','20','','','.b-products-listing'),(176292,'deals-mobile','.b-products-listing .BlockBox.type-14 > .col','width','25','','','.b-products-listing'),(176293,'deals-mobile','.b-products-listing .BlockBox.type-15 > .col','width','20','','','.b-products-listing'),(176294,'deals-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width','50','','','.b-products-listing'),(176295,'deals-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width','50','','','.b-products-listing'),(176296,'deals-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(176297,'deals-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(176298,'deals-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width','33.33','','','.b-products-listing'),(176299,'deals-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width','66.66','','','.b-products-listing'),(176300,'deals-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(176301,'deals-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(176302,'deals-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width','66.66','','','.b-products-listing'),(176303,'deals-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width','25','','','.b-products-listing'),(176304,'deals-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width','75','','','.b-products-listing'),(176305,'deals-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width','75','','','.b-products-listing'),(176306,'deals-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width','25','','','.b-products-listing'),(176307,'deals-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width','25','','','.b-products-listing'),(176308,'deals-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width','50','','','.b-products-listing'),(176309,'deals-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width','25','','','.b-products-listing'),(176310,'deals-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width','20','','','.b-products-listing'),(176311,'deals-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width','80','','','.b-products-listing'),(176312,'deals-mobile','.b-products-listing .btn-choose-options','width','100','','','.b-products-listing'),(176313,'deals-mobile','.b-products-listing .btn-preloader','width','24','3','','.b-products-listing'),(176314,'deals-mobile','.b-products-listing .hover-box-content','width','20','3','','.b-products-listing'),(176315,'deals-mobile','.b-products-listing .loader','width','30','4','','.b-products-listing'),(176316,'deals-mobile','.b-products-listing .loader','width','100','3','','.b-products-listing'),(176317,'deals-mobile','.b-products-listing .products-listing .attribute-qty-block','width','47','','','.b-products-listing'),(176318,'deals-mobile','.b-products-listing .products-listing .attribute-qty-block > span','width','50','','','.b-products-listing'),(176319,'deals-mobile','.b-products-listing .products-listing .attributes select','width','100','','','.b-products-listing'),(176320,'deals-mobile','.b-products-listing .products-listing .btn-buy','width','100','','','.b-products-listing'),(176321,'deals-mobile','.b-products-listing .products-listing .btn-preloader','width','100','','','.b-products-listing'),(176322,'deals-mobile','.b-products-listing .products-listing .buyButton .btn','width','100','','','.b-products-listing'),(176323,'deals-mobile','.b-products-listing .products-listing .in-cart','width','100','','','.b-products-listing'),(176324,'deals-mobile','.b-products-listing .products-listing .item','width','25','','','.b-products-listing'),(176325,'deals-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','width','35','','','.b-products-listing'),(176326,'deals-mobile','.b-products-listing .products-listing .qty-input.hidden','width','100','3','','.b-products-listing'),(176327,'deals-mobile','.b-products-listing .products-listing .radio-attributes .item-title','width','33','','','.b-products-listing'),(176328,'deals-mobile','.b-products-listing .products-listing a.btn.view-button','width','100','','','.b-products-listing'),(176329,'deals-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','width','auto','','','.b-products-listing'),(176330,'deals-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width','100','','','.b-products-listing'),(176331,'deals-mobile','.b-products-listing .select-attributes .item-title','width','33','','','.b-products-listing'),(176332,'deals-mobile','.b-products-listing .select-attributes select','width','66','','','.b-products-listing'),(176333,'deals-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(176334,'deals-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(176335,'deals-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(176336,'deals-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(176337,'deals-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(176338,'deals-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(176339,'deals-mobile','.b-email .totals-title','width','70','','','.b-email'),(176340,'deals-mobile','.b-email .heading-image','width','100','','','.b-email'),(176341,'deals-mobile','.b-email .image','width','100','','','.b-email'),(176342,'deals-mobile','.b-email .heading-image','width','100','','','.b-email'),(176343,'deals-mobile','.b-email .totals-title','width','70','','','.b-email'),(176344,'deals-mobile','.b-email .totals-table','width','100','','','.b-email'),(176345,'deals-mobile','.b-email .image','width','100','','','.b-email'),(176346,'deals-mobile','.b-email .totals-table','width','100','','','.b-email'),(176347,'deals-mobile','.b-email .totals-table','width','100','','','.b-email'),(176348,'deals-mobile','.b-email .totals-value','width','30','','','.b-email'),(176349,'deals-mobile','.b-email .totals-value','width','30','','','.b-email'),(176350,'deals-mobile','.b-email .products-table','width','100','','','.b-email'),(176351,'deals-mobile','.b-email .products-table','width','100','','','.b-email'),(176352,'deals-mobile','.b-email img','width','60','','','.b-email'),(176353,'deals-mobile','.b-email .heading-image','width','100','','','.b-email'),(176354,'deals-mobile','.b-email .totals-value','width','30','','','.b-email'),(176355,'deals-mobile','.b-email .products-table','width','100','','','.b-email'),(176356,'deals-mobile','.b-email .image','width','100','','','.b-email'),(176357,'deals-mobile','.b-email .totals-value','width','30','','','.b-email'),(176358,'deals-mobile','.b-email .totals-title','width','70','','','.b-email'),(176359,'deals-mobile','.b-email .products-table','width','100','','','.b-email'),(176360,'deals-mobile','.b-email .totals-title','width','70','','','.b-email'),(176361,'deals-mobile','.b-email .image','width','100','','','.b-email'),(176362,'deals-mobile','.b-email .totals-value','width','30','','','.b-email'),(176363,'deals-mobile','.b-email .image','width','100','','','.b-email'),(176364,'deals-mobile','.b-email img','width','60','','','.b-email'),(176365,'deals-mobile','.b-email .totals-title','width','70','','','.b-email'),(176366,'deals-mobile','.b-email .heading-image','width','100','','','.b-email'),(176367,'deals-mobile','.b-email img','width','60','','','.b-email'),(176368,'deals-mobile','.b-email .totals-table','width','100','','','.b-email'),(176369,'deals-mobile','.b-email .products-table','width','100','','','.b-email'),(176370,'deals-mobile','.b-email .totals-title','width','70','','','.b-email'),(176371,'deals-mobile','.b-email img','width','60','','','.b-email'),(176372,'deals-mobile','.b-email .totals-table','width','100','','','.b-email'),(176373,'deals-mobile','.b-email .heading-image','width','100','','','.b-email'),(176374,'deals-mobile','.b-email img','width','60','','','.b-email'),(176375,'deals-mobile','.b-email img','width','60','','','.b-email'),(176376,'deals-mobile','.b-email .products-table','width','100','','','.b-email'),(176377,'deals-mobile','.b-email .totals-table','width','100','','','.b-email'),(176378,'deals-mobile','.b-email .totals-value','width','30','','','.b-email'),(176379,'deals-mobile','.b-email .image','width','100','','','.b-email'),(176380,'deals-mobile','.b-email .heading-image','width','100','','','.b-email'),(176381,'deals-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(176382,'deals-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(176383,'deals-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(176384,'deals-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(176385,'deals-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(176386,'deals-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(176387,'deals-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','width','30','','','.b-menu-burger_icon'),(176388,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width','100','','','.b-menu-lev_display-slide'),(176389,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width','100','','','.b-menu-lev_display-slide'),(176390,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width','100','','','.b-menu-lev_display-slide'),(176391,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width','100','','','.b-menu-lev_display-slide'),(176392,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width','100','','','.b-menu-lev_display-slide'),(176393,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(176394,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(176395,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(176396,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(176397,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(176398,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width','100','','','.b-menu-open_from-left'),(176399,'deals-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(176400,'deals-mobile','.b-menu-style-1 .menu-style[data-lev2_display=\"width\"] .level-2 > li','width','300','','','.b-menu-style-1'),(176401,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','width','100','','','.b-menu-style-1'),(176402,'deals-mobile','.b-menu-style-1 .menu-style[data-lev2_display=\"width_cont\"] .level-2 > li','width','300','','','.b-menu-style-1'),(176403,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','width','100','','','.b-menu-style-1'),(176404,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','width','40','','','.b-menu-style-2'),(176405,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','width','50','','','.b-menu-style-2'),(176406,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','width','36','','','.b-menu-style-2'),(176407,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','width','40','','','.b-menu-style-2'),(176408,'deals-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','width','36','','','.b-menu-style-2'),(176409,'deals-mobile','.b-messages .msv_to_cc div span.msv_to_cc_bold','width','100','','','.b-messages'),(176410,'deals-mobile','.b-messages .box-block.type-6 > .block:nth-child(1)','width','25','','','.b-messages'),(176411,'deals-mobile','.b-messages .messages-sidebar .btn-2','width','100','','','.b-messages'),(176412,'deals-mobile','.b-messages .pre_upload','width','auto','','','.b-messages'),(176413,'deals-mobile','.b-messages .email-line input','width','100','','','.b-messages'),(176414,'deals-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead td:last-child, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td:last-child','width','200','','','.b-messages'),(176415,'deals-mobile','.b-messages .email-line label','width','150','','','.b-messages'),(176416,'deals-mobile','.b-preloader .preloader','width','100','','','.b-preloader'),(176417,'deals-mobile','.b-preloader .preloader','width','40','3','','.b-preloader'),(176418,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width','1','','','.b-select-suggest'),(176419,'deals-mobile','.b-select-suggest .select2-drop','width','100','','','.b-select-suggest'),(176420,'deals-mobile','.b-select-suggest .select2-drop-mask','width','auto','','','.b-select-suggest'),(176421,'deals-mobile','.b-select-suggest .select2-drop-auto-width','width','auto','','','.b-select-suggest'),(176422,'deals-mobile','.b-select-suggest .select2-measure-scrollbar','width','100','','','.b-select-suggest'),(176423,'deals-mobile','.b-select-suggest .select2-container .select2-choice abbr','width','12','','','.b-select-suggest'),(176424,'deals-mobile','.b-select-suggest .select2-container','width','100','','','.b-select-suggest'),(176425,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width','100','','','.b-select-suggest'),(176426,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','width','18','','','.b-select-suggest'),(176427,'deals-mobile','.b-select-suggest .select2-search','width','100','','','.b-select-suggest'),(176428,'deals-mobile','.b-select-suggest .select2-search-choice-close','width','12','','','.b-select-suggest'),(176429,'deals-mobile','.b-select-suggest .select2-search input','width','100','','','.b-select-suggest'),(176430,'deals-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(176431,'deals-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(176432,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(176433,'deals-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(176434,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(176435,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(176436,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(176437,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(176438,'deals-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(176439,'deals-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(176440,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(176441,'deals-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(176442,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(176443,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(176444,'deals-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(176445,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(176446,'deals-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(176447,'deals-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(176448,'deals-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(176449,'deals-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(176450,'deals-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(176451,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(176452,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(176453,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(176454,'deals-mobile','.b-trade-approval .steps-bar','width','100','','','.b-trade-approval'),(176455,'deals-mobile','.b-trade-approval .col-right','width','48','','','.b-trade-approval'),(176456,'deals-mobile','.b-trade-approval .col-left','width','48','','','.b-trade-approval'),(176457,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width','100','','','.b-trade-approval'),(176458,'deals-mobile','.b-trade-approval .col-3','width','31.33','','','.b-trade-approval'),(176459,'deals-mobile','.b-upload-file .upload-file-template','width','150','','','.b-upload-file'),(176460,'deals-mobile','.b-upload-file .snapshot','width','38','','','.b-upload-file'),(176461,'deals-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','width','230','','','.b-warehouses-popup'),(176462,'deals-mobile','.b-warehouses-popup .warehouses-popup','width','570','','','.b-warehouses-popup'),(176463,'deals-mobile','.batchPr .w-batch-products .products-listing .attribute-qty-block','width','100','','','.batchPr'),(176464,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(2)','width','auto','','','.batchPr'),(176465,'deals-mobile','.batchPr .checkbox input + span','width','80','','','.batchPr'),(176466,'deals-mobile','.batchPr .batchSelect .checkbox','width','80','','','.batchPr'),(176467,'deals-mobile','.batchPr .box-block.type-5 > .block:nth-child(1), .batchPr .box-block.type-5 > .block:nth-child(2)','width','50','','','.batchPr'),(176468,'deals-mobile','.batchPr .checkbox input + span','width','32','','','.batchPr'),(176469,'deals-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','width','40','','','.batchPr'),(176470,'deals-mobile','.batchPr .checkbox input:not(checked) + span:before','width','30','','','.batchPr'),(176471,'deals-mobile','.batchPr .btn-batch-remove','width','20','','','.batchPr'),(176472,'deals-mobile','.p-account-samples-history .orders-table .hidden','width','130','','','.p-account-samples-history'),(176473,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','width','100','','','.p-account-samples-history'),(176474,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','width','100','','','.p-account-samples-history'),(176475,'deals-mobile','.p-account-samples-history .not_fully_paid_td','width','300','','','.p-account-samples-history'),(176476,'deals-mobile','.p-account-samples-history .orders-table .hidden','width','130','','','.p-account-samples-history'),(176477,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','width','100','','','.p-account-samples-history'),(176478,'deals-mobile','.p-account-samples-history .orders-table .hidden','width','130','','','.p-account-samples-history'),(176479,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','width','100','','','.p-account-samples-history'),(176480,'deals-mobile','.p-account-samples-history .orders-table .hidden','width','130','','','.p-account-samples-history'),(176481,'deals-mobile','.p-account-samples-history .not_fully_paid_td','width','300','','','.p-account-samples-history'),(176482,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','width','100','','','.p-account-samples-history'),(176483,'deals-mobile','.p-account-samples-history .not_fully_paid_td','width','300','','','.p-account-samples-history'),(176484,'deals-mobile','.p-account-samples-history .not_fully_paid_td','width','300','','','.p-account-samples-history'),(176485,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','width','100','','','.p-account-samples-history'),(176486,'deals-mobile','.p-account-samples-history .not_fully_paid_td','width','300','','','.p-account-samples-history'),(176487,'deals-mobile','.p-account-samples-history .orders-table .hidden','width','130','','','.p-account-samples-history'),(176488,'deals-mobile','.p-account-samples-history .not_fully_paid_td','width','300','','','.p-account-samples-history'),(176489,'deals-mobile','.p-account-samples-history .orders-table .hidden','width','130','','','.p-account-samples-history'),(176490,'deals-mobile','.p-account-samples-history-info .history_info > div','width','100','','','.p-account-samples-history-info'),(176491,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','width','300','','','.p-account-samples-history-info'),(176492,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','width','300','','','.p-account-samples-history-info'),(176493,'deals-mobile','.p-account-samples-history-info .history_info > div','width','33.3','','','.p-account-samples-history-info'),(176494,'deals-mobile','.p-account-samples-history-info .history_info > div','width','100','','','.p-account-samples-history-info'),(176495,'deals-mobile','.p-account-samples-history-info .history_info > div','width','100','','','.p-account-samples-history-info'),(176496,'deals-mobile','.p-account-samples-history-info .history_info > div','width','33.3','','','.p-account-samples-history-info'),(176497,'deals-mobile','.p-account-samples-history-info .history_info > div','width','33.3','','','.p-account-samples-history-info'),(176498,'deals-mobile','.p-account-samples-history-info .history_info > div','width','100','','','.p-account-samples-history-info'),(176499,'deals-mobile','.p-account-samples-history-info .history_info > div','width','100','','','.p-account-samples-history-info'),(176500,'deals-mobile','.p-account-samples-history-info .history_info > div','width','100','','','.p-account-samples-history-info'),(176501,'deals-mobile','.p-account-samples-history-info .history_info > div','width','33.3','','','.p-account-samples-history-info'),(176502,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','width','300','','','.p-account-samples-history-info'),(176503,'deals-mobile','.p-account-samples-history-info .history_info > div','width','33.3','','','.p-account-samples-history-info'),(176504,'deals-mobile','.p-account-samples-history-info .history_info > div','width','33.3','','','.p-account-samples-history-info'),(176505,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','width','300','','','.p-account-samples-history-info'),(176506,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','width','300','','','.p-account-samples-history-info'),(176507,'deals-mobile','.p-account-samples-history-info .not_fully_paid_td','width','300','','','.p-account-samples-history-info'),(176508,'deals-mobile','.p-catalog-product .prev-next-product','width','190','','','.p-catalog-product'),(176509,'deals-mobile','.p-catalog-product .pn-image','width','24','3','','.p-catalog-product'),(176510,'deals-mobile','.p-checkout-login .middle-form .btn-2','width','100','','','.p-checkout-login'),(176511,'deals-mobile','.p-checkout-login .col-left, .p-checkout-login .col-right','width','100','','','.p-checkout-login'),(176512,'deals-mobile','.p-payer-order-confirmation .order-summary2 .btn-2','width','100','','','.p-payer-order-confirmation'),(176513,'deals-mobile','.p-payer-order-confirmation .dob-hide > div','width','48','','','.p-payer-order-confirmation'),(176514,'deals-mobile','.p-payer-order-pay .order-summary2 .btn-2','width','100','','','.p-payer-order-pay'),(176515,'deals-mobile','.p-payer-order-pay .dob-hide > div','width','48','','','.p-payer-order-pay'),(176516,'deals-mobile','.p-quick-order-index .all-scroll-div','width','100','','','.p-quick-order-index'),(176517,'deals-mobile','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width','100','','','.p-quote-checkout-login'),(176518,'deals-mobile','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width','100','','','.p-sample-checkout-login'),(176519,'deals-mobile','.w-account-address-book .item','width','50','','','.w-account-address-book'),(176520,'deals-mobile','.w-account-address-book .add_item a','width','100','','','.w-account-address-book'),(176521,'deals-mobile','.w-account-addresses-list .addsess-suggestion-item','width','50','','','.w-account-addresses-list'),(176522,'deals-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width','60','','','.w-account-customer-additional-field'),(176523,'deals-mobile','.w-account-customer-additional-field .field-type-text label','width','40','','','.w-account-customer-additional-field'),(176524,'deals-mobile','.w-account-customer-additional-field .field-type-checkbox label','width','40','','','.w-account-customer-additional-field'),(176525,'deals-mobile','.w-account-personal-catalog .list-switcher','width','100','','','.w-account-personal-catalog'),(176526,'deals-mobile','.w-blog-widget-post-date ','width','100','','','.w-blog-widget-post-date'),(176527,'deals-mobile','.w-blog-widget-post-image ','width','100','','','.w-blog-widget-post-image'),(176528,'deals-mobile','.w-blog-widget-post-listing .post','width','33.33','','','.w-blog-widget-post-listing'),(176529,'deals-mobile','.w-blog-widget-post-listing .post','width','100','','','.w-blog-widget-post-listing'),(176530,'deals-mobile','.w-blog-widget-post-listing .post','width','50','','','.w-blog-widget-post-listing'),(176531,'deals-mobile','.w-blog-widget-post-share ','width','1','4','','.w-blog-widget-post-share'),(176532,'deals-mobile','.w-blog-widget-post-title ','width','100','','','.w-blog-widget-post-title'),(176533,'deals-mobile','.w-blog-widget-related-posts .post','width','50','','','.w-blog-widget-related-posts'),(176534,'deals-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','width','35','','','.w-blog-widget-related-posts'),(176535,'deals-mobile','.w-blog-widget-related-posts-by-category .post','width','50','','','.w-blog-widget-related-posts-by-category'),(176536,'deals-mobile','.w-cart-bonus-points .bonus_points_amount','width','150','','','.w-cart-bonus-points'),(176537,'deals-mobile','.w-cart-bonus-points .btn-remove','width','25','','','.w-cart-bonus-points'),(176538,'deals-mobile','.w-cart-compare .product .image','width','50','','','.w-cart-compare'),(176539,'deals-mobile','.w-cart-credit-amount .btn-remove','width','25','','','.w-cart-credit-amount'),(176540,'deals-mobile','.w-cart-credit-amount input[type=\"text\"]','width','150','','','.w-cart-credit-amount'),(176541,'deals-mobile','.w-catalog-b2b-add-button ','width','100','','','.w-catalog-b2b-add-button'),(176542,'deals-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','width','auto','','','.w-catalog-compare'),(176543,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','width','50','','','.w-catalog-compare'),(176544,'deals-mobile','.w-catalog-paging .paging-holder','width','150','','','.w-catalog-paging'),(176545,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width','30','','','.w-catalog-paging'),(176546,'deals-mobile','.w-checkout-billing-address .addresses .address-item','width','50','','','.w-checkout-billing-address'),(176547,'deals-mobile','.w-checkout-billing-address .addresses.address-main .address-item','width','100','','','.w-checkout-billing-address'),(176548,'deals-mobile','.w-checkout-bonus-points .btn-remove','width','25','','','.w-checkout-bonus-points'),(176549,'deals-mobile','.w-checkout-bonus-points .bonus_points_amount','width','150','','','.w-checkout-bonus-points'),(176550,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','width','25','3','','.w-checkout-contact-information'),(176551,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','width','25','3','','.w-checkout-contact-information'),(176552,'deals-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','width','25','3','','.w-checkout-contact-information'),(176553,'deals-mobile','.w-checkout-create-account .col-2','width','100','','','.w-checkout-create-account'),(176554,'deals-mobile','.w-checkout-create-btn .btn-2','width','240','','','.w-checkout-create-btn'),(176555,'deals-mobile','.w-checkout-credit-amount .cot_gv_amount','width','150','','','.w-checkout-credit-amount'),(176556,'deals-mobile','.w-checkout-credit-amount .btn-remove','width','25','','','.w-checkout-credit-amount'),(176557,'deals-mobile','.w-checkout-guest-btn .btn-2','width','240','','','.w-checkout-guest-btn'),(176558,'deals-mobile','.w-checkout-shipping-address .addresses.address-main .address-item','width','100','','','.w-checkout-shipping-address'),(176559,'deals-mobile','.w-checkout-shipping-address .addresses .address-item','width','50','','','.w-checkout-shipping-address'),(176560,'deals-mobile','.w-checkout-shipping-choice #shippingchoice-choice','width','430','','','.w-checkout-shipping-choice'),(176561,'deals-mobile','.w-checkout-shipping-choice label','width','50','','','.w-checkout-shipping-choice'),(176562,'deals-mobile','.w-checkout-shipping-choice input:checked + span:before','width','10','','','.w-checkout-shipping-choice'),(176563,'deals-mobile','.w-checkout-shipping-choice label','width','auto','','','.w-checkout-shipping-choice'),(176564,'deals-mobile','.w-checkout-shipping-choice #shippingchoice-choice','width','auto','','','.w-checkout-shipping-choice'),(176565,'deals-mobile','.w-checkout-terms .required-message','width','100','','','.w-checkout-terms'),(176566,'deals-mobile','.w-communication-new-topic .return-reason','width','150','','','.w-communication-new-topic'),(176567,'deals-mobile','.w-communication-new-topic .request-type','width','150','','','.w-communication-new-topic'),(176568,'deals-mobile','.w-communication-new-topic .date-purchased','width','130','','','.w-communication-new-topic'),(176569,'deals-mobile','.w-communication-new-topic .middle-form select','width','100','','','.w-communication-new-topic'),(176570,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','width','36','','','.w-communication-new-topic'),(176571,'deals-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateTo\"]','width','60','','','.w-communication-new-topic'),(176572,'deals-mobile','.w-communication-new-topic .btn-submit','width','200','','','.w-communication-new-topic'),(176573,'deals-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterOrderId\"]','width','60','','','.w-communication-new-topic'),(176574,'deals-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','width','36','','','.w-communication-new-topic'),(176575,'deals-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateFrom\"]','width','60','','','.w-communication-new-topic'),(176576,'deals-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterName\"]','width','100','','','.w-communication-new-topic'),(176577,'deals-mobile','.w-communication-new-topic .model','width','100','','','.w-communication-new-topic'),(176578,'deals-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterSku\"]','width','60','','','.w-communication-new-topic'),(176579,'deals-mobile','.w-coupons-and-vauchers-checkout .btn-remove','width','25','','','.w-coupons-and-vauchers-checkout'),(176580,'deals-mobile','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width','150','','','.w-coupons-and-vauchers-checkout'),(176581,'deals-mobile','.w-delayed-despatch-checkout #delivery_date','width','150','','','.w-delayed-despatch-checkout'),(176582,'deals-mobile','.w-image-maps .svg-wrap svg','width','100','','','.w-image-maps'),(176583,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','width','250','','','.w-image-maps'),(176584,'deals-mobile','.w-list-b2b .select-attributes','width','47','','','.w-list-b2b'),(176585,'deals-mobile','.w-personal-gift-status-bar .progress-bar','width','230','','','.w-personal-gift-status-bar'),(176586,'deals-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(176587,'deals-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(176588,'deals-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(176589,'deals-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(176590,'deals-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(176591,'deals-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(176592,'deals-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(176593,'deals-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(176594,'deals-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(176595,'deals-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(176596,'deals-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(176597,'deals-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(176598,'deals-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(176599,'deals-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(176600,'deals-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(176601,'deals-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(176602,'deals-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(176603,'deals-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(176604,'deals-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(176605,'deals-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(176606,'deals-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(176607,'deals-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(176608,'deals-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(176609,'deals-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(176610,'deals-mobile','.w-product-customers-activity .customers-activity','width','255','','','.w-product-customers-activity'),(176611,'deals-mobile','.w-product-customers-activity .close','width','30','','','.w-product-customers-activity'),(176612,'deals-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(176613,'deals-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(176614,'deals-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(176615,'deals-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(176616,'deals-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(176617,'deals-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(176618,'deals-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(176619,'deals-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(176620,'deals-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(176621,'deals-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(176622,'deals-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(176623,'deals-mobile','.w-product-images-additional .item','width','80','','','.w-product-images-additional'),(176624,'deals-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(176625,'deals-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(176626,'deals-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(176627,'deals-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(176628,'deals-mobile','.w-product-images-additional .additional-images','width','80','','','.w-product-images-additional'),(176629,'deals-mobile','.w-product-images-additional .item-div','width','80','','','.w-product-images-additional'),(176630,'deals-mobile','.w-promotions .prom-multi-discount .list','width','100','','','.w-promotions'),(176631,'deals-mobile','.w-promotions .nextdiscount .item-holder .image','width','40','','','.w-promotions'),(176632,'deals-mobile','.w-promotions .promo-cart-discount .master .item','width','calc(50% - 24px)','','','.w-promotions'),(176633,'deals-mobile','.w-promotions .promo-cart-discount .image img','width','auto','','','.w-promotions'),(176634,'deals-mobile','.w-promotions .promo-cart-discount > div','width','50','','','.w-promotions'),(176635,'deals-mobile','.w-promotions .promo-cart-discount .slave .item','width','calc(50% - 4px)','','','.w-promotions'),(176636,'deals-mobile','.w-promotions .promo-salemaker .image img','width','auto','','','.w-promotions'),(176637,'deals-mobile','.w-promotions .promo-salemaker .item','width','50','','','.w-promotions'),(176638,'deals-mobile','.w-promotions .promo-salemaker > div','width','50','','','.w-promotions'),(176639,'deals-mobile','.w-promotions .prom-multi-discount .image img','width','auto','','','.w-promotions'),(176640,'deals-mobile','.w-promotions .nextdiscount .item-holder .name','width','60','','','.w-promotions'),(176641,'deals-mobile','.w-promotions .icon','width','45','','','.w-promotions'),(176642,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul > li','width','25','','','.w-sitemap-delivery-location'),(176643,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(176644,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','width','150','','','.w-upload-customer-id-upload-customer-id-form'),(176645,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(176646,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box-full','width','auto','','','.w-wedding-registry-widgets-photos'),(176647,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-box','width','180','','','.w-wedding-registry-widgets-photos'),(176648,'deals-mobile','.w-wedding-registry-widgets-photos .avatar-container','width','144','','','.w-wedding-registry-widgets-photos'),(176649,'deals-mobile','.w-wedding-registry-widgets-products .products-listing .item','width','33','','','.w-wedding-registry-widgets-products'),(176650,'deals-mobile','.w-wedding-registry-widgets-products .products-listing .item','width','50','','','.w-wedding-registry-widgets-products'),(176651,'deals-mobile','.w-wedding-registry-widgets-products .products-listing .item','width','100','','','.w-wedding-registry-widgets-products'),(176652,'deals-mobile','.w-wedding-registry-widgets-share-url input','width','100','','','.w-wedding-registry-widgets-share-url'),(176653,'deals-mobile','.b-quantity .qty-box input[type=\'text\']','width','60','','','.b-quantity'),(176654,'deals-mobile','.p-shopping-cart-index .order-summary .btn-2','width','100','','','.p-shopping-cart-index'),(176655,'deals-mobile','.w-menu .hided.menu ul ul','width_important','important','','','.w-menu'),(176656,'deals-mobile','.w-menu .hided.menu ul li','width_important','important','','','.w-menu'),(176657,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width_important','important','3','','.b-switch'),(176658,'deals-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width_important','important','3','','.b-switch'),(176659,'deals-mobile','.b-messages .pre_upload','width_important','important','','','.b-messages'),(176660,'deals-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width_important','important','','','.b-select-suggest'),(176661,'deals-mobile','.b-warehouses-popup .warehouses-popup','width_important','important','','','.b-warehouses-popup'),(176662,'deals-mobile','.w-cart-bonus-points .bonus_points_amount','width_important','important','','','.w-cart-bonus-points'),(176663,'deals-mobile','.w-cart-credit-amount input[type=\"text\"]','width_important','important','','','.w-cart-credit-amount'),(176664,'deals-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width_important','important','','','.w-catalog-paging'),(176665,'deals-mobile','.w-checkout-bonus-points .bonus_points_amount','width_important','important','','','.w-checkout-bonus-points'),(176666,'deals-mobile','.w-checkout-credit-amount .cot_gv_amount','width_important','important','','','.w-checkout-credit-amount'),(176667,'deals-mobile','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width_important','important','','','.w-coupons-and-vauchers-checkout'),(176668,'deals-mobile','.w-menu-slider > ul > li > ul','width_measure','%','','','.w-menu-slider'),(176669,'deals-mobile','.b-form .checkbox-style:checked + .checkbox-span','width_measure','x','','','.b-form'),(176670,'deals-mobile','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(176671,'deals-mobile','.w-login-block .returning','width_measure','%','','','.w-login-block'),(176672,'deals-mobile','.w-login-block .new','width_measure','%','','','.w-login-block'),(176673,'deals-mobile','.w-login-block .guest','width_measure','%','','','.w-login-block'),(176674,'deals-mobile','.w-login-block .input','width_measure','%','','','.w-login-block'),(176675,'deals-mobile','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(176676,'deals-mobile','.w-list-type-2_2 .sale','width_measure','%','4','','.w-list-type-2_2'),(176677,'deals-mobile','.w-sale .holder-1','width_measure','%','','','.w-sale'),(176678,'deals-mobile','.w-sale .image','width_measure','%','','','.w-sale'),(176679,'deals-mobile','.w-sale .holder-2','width_measure','%','','','.w-sale'),(176680,'deals-mobile','.w-product-attributes .select','width_measure','%','','','.w-product-attributes'),(176681,'deals-mobile','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(176682,'deals-mobile','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(176683,'deals-mobile','.w-menu-mobile .menu-slider .open','width_measure','vw','','','.w-menu-mobile'),(176684,'deals-mobile','.w-product-sale-ends .left-count','width_measure','%','','','.w-product-sale-ends'),(176685,'deals-mobile','.w-product-sale-ends .left-text-left','width_measure','%','','','.w-product-sale-ends'),(176686,'deals-mobile','.w-product-sale-ends .left-text-right','width_measure','%','','','.w-product-sale-ends'),(176687,'deals-mobile','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(176688,'deals-mobile','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(176689,'deals-mobile','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(176690,'deals-mobile','.b-fancybox .fancybox-nav','width_measure','%','','','.b-fancybox'),(176691,'deals-mobile','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(176692,'deals-mobile','.w-categories .item','width_measure','%','863','','.w-categories'),(176693,'deals-mobile','.w-top-categories .item','width_measure','%','863','','.w-top-categories'),(176694,'deals-mobile','.w-currencies .select','width_measure','%','','','.w-currencies'),(176695,'deals-mobile','.w-categories .item','width_measure','%','','','.w-categories'),(176696,'deals-mobile','.w-cart-give-away .ga_column','width_measure','%','863','','.w-cart-give-away'),(176697,'deals-mobile','.w-cart-order-total.box','width_measure','%','892','','.w-cart-order-total'),(176698,'deals-mobile','.w-cart-checkout-btn','width_measure','%','863','','.w-cart-checkout-btn'),(176699,'deals-mobile','.b-product-images .additional-horizontal .additional-images, .b-product-images .additional-horizontal .additional-videos','width_measure','%','','','.b-product-images'),(176700,'deals-mobile','.w-product-properties li','width_measure','%','','','.w-product-properties'),(176701,'deals-mobile','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(176702,'deals-mobile','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(176703,'deals-mobile','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(176704,'deals-mobile','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(176705,'deals-mobile','.p-account-address-book .address_book_row .column, .p-account-address-book .topInfo > div','width_measure','%','','','.p-account-address-book'),(176706,'deals-mobile','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(176707,'deals-mobile','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(176708,'deals-mobile','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(176709,'deals-mobile','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(176710,'deals-mobile','.p-account-index .topAccount > li','width_measure','%','863','','.p-account-index'),(176711,'deals-mobile','.p-account-address-book .address_book_row .column','width_measure','%','863','','.p-account-address-book'),(176712,'deals-mobile','.p-account-address-book .address_book_row .column + .column','width_measure','%','863','','.p-account-address-book'),(176713,'deals-mobile','.p-account-history-info .history_info > div','width_measure','%','864','','.p-account-history-info'),(176714,'deals-mobile','.p-account-address-book .topInfo > div','width_measure','%','863','','.p-account-address-book'),(176715,'deals-mobile','.p-account-address-book .topInfo > div + div','width_measure','%','863','','.p-account-address-book'),(176716,'deals-mobile','.p-blog-index .nav-next','width_measure','%','888','','.p-blog-index'),(176717,'deals-mobile','.w-list-type-1_2 .right-area','width_measure','%','864','','.w-list-type-1_2'),(176718,'deals-mobile','.w-list-type-1_2 .right-area .right-area-2','width_measure','%','864','','.w-list-type-1_2'),(176719,'deals-mobile','.p-blog-index .nav-previous','width_measure','%','888','','.p-blog-index'),(176720,'deals-mobile','.w-list-type-1_2 .image','width_measure','%','864','','.w-list-type-1_2'),(176721,'deals-mobile','.w-list-type-1_2 .right-area .name','width_measure','%','864','','.w-list-type-1_2'),(176722,'deals-mobile','.w-list-type-1_2 .right-area .name','width_measure','%','','','.w-list-type-1_2'),(176723,'deals-mobile','.w-list-type-1_2 .right-area .right-area-2','width_measure','%','','','.w-list-type-1_2'),(176724,'deals-mobile','.w-promo-code .promo-code-form','width_measure','%','864','','.w-promo-code'),(176725,'deals-mobile','.w-promo-code .promo-text','width_measure','%','864','','.w-promo-code'),(176726,'deals-mobile','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(176727,'deals-mobile','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(176728,'deals-mobile','.b-form .col-right','width_measure','%','890','','.b-form'),(176729,'deals-mobile','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(176730,'deals-mobile','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(176731,'deals-mobile','.b-form .col-left','width_measure','%','890','','.b-form'),(176732,'deals-mobile','.b-form .columns .col-2','width_measure','%','893','','.b-form'),(176733,'deals-mobile','.p-account-order-pay .history_info > div','width_measure','%','864','','.p-account-order-pay'),(176734,'deals-mobile','.p-account-order-pay .history_info > div','width_measure','%','','','.p-account-order-pay'),(176735,'deals-mobile','.w-product-configurator .item-content','width_measure','%','872','','.w-product-configurator'),(176736,'deals-mobile','.w-product-configurator .pc_item','width_measure','%','872','','.w-product-configurator'),(176737,'deals-mobile','.p-wedding-registry-manage .wr-search input','width_measure','%','','','.p-wedding-registry-manage'),(176738,'deals-mobile','.p-account-history .orders-table .td-alignright','width_measure','%','890','','.p-account-history'),(176739,'deals-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','890','','.p-blog-index'),(176740,'deals-mobile','.p-blog-index .nav-previous','width_measure','%','','','.p-blog-index'),(176741,'deals-mobile','.p-account-index .orders-table .td-alignright','width_measure','%','890','','.p-account-index'),(176742,'deals-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','893','','.p-blog-index'),(176743,'deals-mobile','.p-blog-index .nav-next','width_measure','%','','','.p-blog-index'),(176744,'deals-mobile','.w-list-type-1_3 .right-area .right-area-2','width_measure','%','','','.w-list-type-1_3'),(176745,'deals-mobile','.pop-up-content .buttons .right-buttons','width_measure','%','864','',''),(176746,'deals-mobile','.w-list-type-2_2 .sale','width_measure','%','3','','.w-list-type-2_2'),(176747,'deals-mobile','.pop-up-content .buttons .btn-2','width_measure','%','864','',''),(176748,'deals-mobile','.pop-up-content .buttons .left-buttons','width_measure','%','864','',''),(176749,'deals-mobile','.pop-up-content .buttons .btn','width_measure','%','864','',''),(176750,'deals-mobile','.b-form .columns .col-2','width_measure','%','','','.b-form'),(176751,'deals-mobile','.w-list-type-2_2 .button-wishlist button','width_measure','%','','','.w-list-type-2_2'),(176752,'deals-mobile','.w-list-type-2 .sale','width_measure','%','3','','.w-list-type-2'),(176753,'deals-mobile','.w-list-type-2_2 .button-wishlist','width_measure','%','','','.w-list-type-2_2'),(176754,'deals-mobile','.personal-buttons > div > div','width_measure','%','','','.personal-buttons'),(176755,'deals-mobile','.w-product-bonus-points > div > div','width_measure','%','','','.w-product-bonus-points'),(176756,'deals-mobile','.w-cart-checkout-btn a','width_measure','%','863','','.w-cart-checkout-btn'),(176757,'deals-mobile','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(176758,'deals-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width_measure','%','','','.b-fancybox'),(176759,'deals-mobile','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(176760,'deals-mobile','.p-wedding-registry-search .search-list input','width_measure','%','','','.p-wedding-registry-search'),(176761,'deals-mobile','.b-bottom .popup-credit-amount .popup-box','width_measure','%','','','.b-bottom'),(176762,'deals-mobile','.b-compare .col-two select','width_measure','%','','','.b-compare'),(176763,'deals-mobile','.b-compare .col-two label','width_measure','%','','','.b-compare'),(176764,'deals-mobile','.w-list-type-1 .button-wishlist','width_measure','%','','','.w-list-type-1'),(176765,'deals-mobile','.w-search .suggest','width_measure','vw','','','.w-search'),(176766,'deals-mobile','.w-search .search-input','width_measure','%','','','.w-search'),(176767,'deals-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width_measure','%','','','.w-banner'),(176768,'deals-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(176769,'deals-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(176770,'deals-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width_measure','%','','','.p-account-trade-form'),(176771,'deals-mobile','.p-account-trade-form .wl-td label','width_measure','%','','','.p-account-trade-form'),(176772,'deals-mobile','.p-account-trade-form .wl-td select','width_measure','%','','','.p-account-trade-form'),(176773,'deals-mobile','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width_measure','%','','','.w-banner'),(176774,'deals-mobile','.w-filters .handle-to','width_measure','%','','','.w-filters'),(176775,'deals-mobile','.b-bottom .popup-box.popupCompare','width_measure','%','','','.b-bottom'),(176776,'deals-mobile','.w-filters .handle-from','width_measure','%','','','.w-filters'),(176777,'deals-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(176778,'deals-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(176779,'deals-mobile','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(176780,'deals-mobile','.w-product-buttons .btn, .w-product-buttons .btn-2, .w-product-buttons .btn-3, .w-product-buttons .btn-4','width_measure','%','','','.w-product-buttons'),(176781,'deals-mobile','.p-reviews-info .review-info-image','width_measure','%','','','.p-reviews-info'),(176782,'deals-mobile','.w-search .search form','width_measure','vw','','','.w-search'),(176783,'deals-mobile','.p-checkout-success .page-success','width_measure','%','3','','.p-checkout-success'),(176784,'deals-mobile','.p-account-index .topAccount > li','width_measure','%','','','.p-account-index'),(176785,'deals-mobile','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(176786,'deals-mobile','.w-sale .left-text-right','width_measure','%','','','.w-sale'),(176787,'deals-mobile','.w-sale .left-count','width_measure','%','','','.w-sale'),(176788,'deals-mobile','.w-sale .left-text-left','width_measure','%','','','.w-sale'),(176789,'deals-mobile','.w-banner .carousel-text','width_measure','%','','','.w-banner'),(176790,'deals-mobile','.w-list-type-1_3 .right-area .name','width_measure','%','','','.w-list-type-1_3'),(176791,'deals-mobile','.w-list-type-1_3 .right-area .right-area-2','width_measure','%','864','','.w-list-type-1_3'),(176792,'deals-mobile','.w-list-type-1_3 .right-area .name','width_measure','%','864','','.w-list-type-1_3'),(176793,'deals-mobile','.w-list-type-1_3 .right-area','width_measure','%','864','','.w-list-type-1_3'),(176794,'deals-mobile','.w-list-type-1_3 .image','width_measure','%','864','','.w-list-type-1_3'),(176795,'deals-mobile','.w-cart-continue-btn a','width_measure','%','863','','.w-cart-continue-btn'),(176796,'deals-mobile','.w-top-categories .item','width_measure','%','','','.w-top-categories'),(176797,'deals-mobile','.w-cart-discount-coupon .gift-code input','width_measure','%','','','.w-cart-discount-coupon'),(176798,'deals-mobile','.w-cart-order-total.box','width_measure','%','','','.w-cart-order-total'),(176799,'deals-mobile','.p-account-index .account_info li','width_measure','%','863','','.p-account-index'),(176800,'deals-mobile','.p-account-index .ai_title','width_measure','%','','','.p-account-index'),(176801,'deals-mobile','.b-form .addresses .address-item','width_measure','%','','','.b-form'),(176802,'deals-mobile','textarea','width_measure','%','','',''),(176803,'deals-mobile','.b-form .discount-box input[type=\"text\"]','width_measure','%','','','.b-form'),(176804,'deals-mobile','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width_measure','%','','','.b-form'),(176805,'deals-mobile','.p-account-index .account_info li','width_measure','%','','','.p-account-index'),(176806,'deals-mobile','.p-account-history-info .history_info > div','width_measure','%','','','.p-account-history-info'),(176807,'deals-mobile','.b-form .col-right','width_measure','%','','','.b-form'),(176808,'deals-mobile','.w-cart-give-away .ga_attributes > div','width_measure','%','','','.w-cart-give-away'),(176809,'deals-mobile','.w-cart-give-away .ga_attributes select','width_measure','%','','','.w-cart-give-away'),(176810,'deals-mobile','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(176811,'deals-mobile','.w-cart-give-away .ga_column','width_measure','%','','','.w-cart-give-away'),(176812,'deals-mobile','.w-cart-give-away .ga_img','width_measure','%','','','.w-cart-give-away'),(176813,'deals-mobile','.view-all','width_measure','%','3','',''),(176814,'deals-mobile','.w-list-type-1_3 .sale','width_measure','%','4','','.w-list-type-1_3'),(176815,'deals-mobile','.w-list-type-2 .button-wishlist','width_measure','%','','','.w-list-type-2'),(176816,'deals-mobile','.w-list-type-1_3 .sale','width_measure','%','3','','.w-list-type-1_3'),(176817,'deals-mobile','.w-list-type-2 .sale','width_measure','%','4','','.w-list-type-2'),(176818,'deals-mobile','.w-list-type-2 .button-wishlist button','width_measure','%','','','.w-list-type-2'),(176819,'deals-mobile','.w-list-type-1_3 .button-wishlist','width_measure','%','','','.w-list-type-1_3'),(176820,'deals-mobile','.w-list-type-1_3 .button-wishlist button','width_measure','%','','','.w-list-type-1_3'),(176821,'deals-mobile','.w-list-type-1_2 .sale','width_measure','%','3','','.w-list-type-1_2'),(176822,'deals-mobile','.w-list-type-1_2 .sale','width_measure','%','4','','.w-list-type-1_2'),(176823,'deals-mobile','.w-list-type-1_3 .attributes > .attributes > div','width_measure','%','','','.w-list-type-1_3'),(176824,'deals-mobile','.w-list-type-1_2 .button-wishlist button','width_measure','%','','','.w-list-type-1_2'),(176825,'deals-mobile','.w-list-type-1_2 .button-wishlist','width_measure','%','','','.w-list-type-1_2'),(176826,'deals-mobile','.w-list-type-1_2 .button-view','width_measure','%','','','.w-list-type-1_2'),(176827,'deals-mobile','.w-list-type-1 .sale','width_measure','%','4','','.w-list-type-1'),(176828,'deals-mobile','.w-list-type-1 .sale','width_measure','%','3','','.w-list-type-1'),(176829,'deals-mobile','.w-list-type-1 .button-wishlist button','width_measure','%','','','.w-list-type-1'),(176830,'deals-mobile','.w-filters .input-txt','width_measure','%','','','.w-filters'),(176831,'deals-mobile','.w-filters .input-txt-keywords','width_measure','%','','','.w-filters'),(176832,'deals-mobile','.w-filters .ui-slider','width_measure','%','','','.w-filters'),(176833,'deals-mobile','.w-tabs .tab-navigation','width_measure','%','','','.w-tabs'),(176834,'deals-mobile','.b-form .hide-billing-address','width_measure','%','','','.b-form'),(176835,'deals-mobile','.b-form .col-left','width_measure','%','','','.b-form'),(176836,'deals-mobile','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width_measure','%','','','.b-form'),(176837,'deals-mobile','.b-form .middle-form .dob-input input[type=\"text\"]','width_measure','%','','','.b-form'),(176838,'deals-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(176839,'deals-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(176840,'deals-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(176841,'deals-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(176842,'deals-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(176843,'deals-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(176844,'deals-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(176845,'deals-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(176846,'deals-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(176847,'deals-mobile','.b-products-listing .BlockBox.type-14 > .col','width_measure','%','','','.b-products-listing'),(176848,'deals-mobile','.b-products-listing .BlockBox.type-15 > .col','width_measure','%','','','.b-products-listing'),(176849,'deals-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(176850,'deals-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(176851,'deals-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(176852,'deals-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(176853,'deals-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(176854,'deals-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(176855,'deals-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(176856,'deals-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(176857,'deals-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(176858,'deals-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(176859,'deals-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(176860,'deals-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(176861,'deals-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(176862,'deals-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(176863,'deals-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(176864,'deals-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(176865,'deals-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(176866,'deals-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(176867,'deals-mobile','.b-products-listing .btn-choose-options','width_measure','%','','','.b-products-listing'),(176868,'deals-mobile','.b-products-listing .loader','width_measure','%','3','','.b-products-listing'),(176869,'deals-mobile','.b-products-listing .products-listing .attribute-qty-block','width_measure','%','','','.b-products-listing'),(176870,'deals-mobile','.b-products-listing .products-listing .attribute-qty-block > span','width_measure','%','','','.b-products-listing'),(176871,'deals-mobile','.b-products-listing .products-listing .attributes select','width_measure','%','','','.b-products-listing'),(176872,'deals-mobile','.b-products-listing .products-listing .btn-buy','width_measure','%','','','.b-products-listing'),(176873,'deals-mobile','.b-products-listing .products-listing .btn-preloader','width_measure','%','','','.b-products-listing'),(176874,'deals-mobile','.b-products-listing .products-listing .buyButton .btn','width_measure','%','','','.b-products-listing'),(176875,'deals-mobile','.b-products-listing .products-listing .in-cart','width_measure','%','','','.b-products-listing'),(176876,'deals-mobile','.b-products-listing .products-listing .item','width_measure','%','','','.b-products-listing'),(176877,'deals-mobile','.b-products-listing .products-listing .qty-input.hidden','width_measure','%','3','','.b-products-listing'),(176878,'deals-mobile','.b-products-listing .products-listing .radio-attributes .item-title','width_measure','%','','','.b-products-listing'),(176879,'deals-mobile','.b-products-listing .products-listing a.btn.view-button','width_measure','%','','','.b-products-listing'),(176880,'deals-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width_measure','%','','','.b-products-listing'),(176881,'deals-mobile','.b-products-listing .select-attributes .item-title','width_measure','%','','','.b-products-listing'),(176882,'deals-mobile','.b-products-listing .select-attributes select','width_measure','%','','','.b-products-listing'),(176883,'deals-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(176884,'deals-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(176885,'deals-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(176886,'deals-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(176887,'deals-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(176888,'deals-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(176889,'deals-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(176890,'deals-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(176891,'deals-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(176892,'deals-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(176893,'deals-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(176894,'deals-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(176895,'deals-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(176896,'deals-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(176897,'deals-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(176898,'deals-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(176899,'deals-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(176900,'deals-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(176901,'deals-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(176902,'deals-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(176903,'deals-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(176904,'deals-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(176905,'deals-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(176906,'deals-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(176907,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width_measure','vw','','','.b-menu-lev_display-slide'),(176908,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width_measure','vw','','','.b-menu-lev_display-slide'),(176909,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width_measure','vw','','','.b-menu-lev_display-slide'),(176910,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width_measure','vw','','','.b-menu-lev_display-slide'),(176911,'deals-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width_measure','vw','','','.b-menu-lev_display-slide'),(176912,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_measure','vw','','','.b-menu-open_from-left'),(176913,'deals-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(176914,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','width_measure','%','','','.b-menu-style-1'),(176915,'deals-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','width_measure','%','','','.b-menu-style-1'),(176916,'deals-mobile','.b-messages .box-block.type-6 > .block:nth-child(1)','width_measure','%','','','.b-messages'),(176917,'deals-mobile','.b-messages .messages-sidebar .btn-2','width_measure','%','','','.b-messages'),(176918,'deals-mobile','.b-messages .email-line input','width_measure','%','','','.b-messages'),(176919,'deals-mobile','.b-preloader .preloader','width_measure','%','','','.b-preloader'),(176920,'deals-mobile','.b-select-suggest .select2-search input','width_measure','%','','','.b-select-suggest'),(176921,'deals-mobile','.b-select-suggest .select2-container','width_measure','%','','','.b-select-suggest'),(176922,'deals-mobile','.b-select-suggest .select2-drop','width_measure','%','','','.b-select-suggest'),(176923,'deals-mobile','.b-select-suggest .select2-search','width_measure','%','','','.b-select-suggest'),(176924,'deals-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width_measure','%','','','.b-select-suggest'),(176925,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(176926,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(176927,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(176928,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(176929,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(176930,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(176931,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(176932,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(176933,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(176934,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(176935,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(176936,'deals-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(176937,'deals-mobile','.b-trade-approval .steps-bar','width_measure','%','','','.b-trade-approval'),(176938,'deals-mobile','.b-trade-approval .col-right','width_measure','%','','','.b-trade-approval'),(176939,'deals-mobile','.b-trade-approval .col-left','width_measure','%','','','.b-trade-approval'),(176940,'deals-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width_measure','%','','','.b-trade-approval'),(176941,'deals-mobile','.b-trade-approval .col-3','width_measure','%','','','.b-trade-approval'),(176942,'deals-mobile','.batchPr .w-batch-products .products-listing .attribute-qty-block','width_measure','%','','','.batchPr'),(176943,'deals-mobile','.batchPr .box-block.type-5 > .block:nth-child(1), .batchPr .box-block.type-5 > .block:nth-child(2)','width_measure','%','','','.batchPr'),(176944,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','width_measure','%','','','.p-account-samples-history'),(176945,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','width_measure','%','','','.p-account-samples-history'),(176946,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','width_measure','%','','','.p-account-samples-history'),(176947,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','width_measure','%','','','.p-account-samples-history'),(176948,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','width_measure','%','','','.p-account-samples-history'),(176949,'deals-mobile','.p-account-samples-history .orders-table .td-alignright','width_measure','%','','','.p-account-samples-history'),(176950,'deals-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(176951,'deals-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(176952,'deals-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(176953,'deals-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(176954,'deals-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(176955,'deals-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(176956,'deals-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(176957,'deals-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(176958,'deals-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(176959,'deals-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(176960,'deals-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(176961,'deals-mobile','.p-account-samples-history-info .history_info > div','width_measure','%','','','.p-account-samples-history-info'),(176962,'deals-mobile','.p-checkout-login .col-left, .p-checkout-login .col-right','width_measure','%','','','.p-checkout-login'),(176963,'deals-mobile','.p-checkout-login .middle-form .btn-2','width_measure','%','','','.p-checkout-login'),(176964,'deals-mobile','.p-payer-order-confirmation .dob-hide > div','width_measure','%','','','.p-payer-order-confirmation'),(176965,'deals-mobile','.p-payer-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-confirmation'),(176966,'deals-mobile','.p-payer-order-pay .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-pay'),(176967,'deals-mobile','.p-payer-order-pay .dob-hide > div','width_measure','%','','','.p-payer-order-pay'),(176968,'deals-mobile','.p-quick-order-index .all-scroll-div','width_measure','%','','','.p-quick-order-index'),(176969,'deals-mobile','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width_measure','%','','','.p-quote-checkout-login'),(176970,'deals-mobile','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width_measure','%','','','.p-sample-checkout-login'),(176971,'deals-mobile','.w-account-address-book .item','width_measure','%','','','.w-account-address-book'),(176972,'deals-mobile','.w-account-address-book .add_item a','width_measure','%','','','.w-account-address-book'),(176973,'deals-mobile','.w-account-addresses-list .addsess-suggestion-item','width_measure','%','','','.w-account-addresses-list'),(176974,'deals-mobile','.w-account-customer-additional-field .field-type-checkbox label','width_measure','%','','','.w-account-customer-additional-field'),(176975,'deals-mobile','.w-account-customer-additional-field .field-type-text label','width_measure','%','','','.w-account-customer-additional-field'),(176976,'deals-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width_measure','%','','','.w-account-customer-additional-field'),(176977,'deals-mobile','.w-account-personal-catalog .list-switcher','width_measure','%','','','.w-account-personal-catalog'),(176978,'deals-mobile','.w-blog-widget-post-date ','width_measure','%','','','.w-blog-widget-post-date'),(176979,'deals-mobile','.w-blog-widget-post-image ','width_measure','%','','','.w-blog-widget-post-image'),(176980,'deals-mobile','.w-blog-widget-post-listing .post','width_measure','%','','','.w-blog-widget-post-listing'),(176981,'deals-mobile','.w-blog-widget-post-listing .post','width_measure','%','','','.w-blog-widget-post-listing'),(176982,'deals-mobile','.w-blog-widget-post-listing .post','width_measure','%','','','.w-blog-widget-post-listing'),(176983,'deals-mobile','.w-blog-widget-post-title ','width_measure','%','','','.w-blog-widget-post-title'),(176984,'deals-mobile','.w-blog-widget-related-posts .post','width_measure','%','','','.w-blog-widget-related-posts'),(176985,'deals-mobile','.w-blog-widget-related-posts-by-category .post','width_measure','%','','','.w-blog-widget-related-posts-by-category'),(176986,'deals-mobile','.w-catalog-b2b-add-button ','width_measure','%','','','.w-catalog-b2b-add-button'),(176987,'deals-mobile','.w-catalog-compare .cross-box .different-all > div','width_measure','%','','','.w-catalog-compare'),(176988,'deals-mobile','.w-checkout-billing-address .addresses .address-item','width_measure','%','','','.w-checkout-billing-address'),(176989,'deals-mobile','.w-checkout-billing-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-billing-address'),(176990,'deals-mobile','.w-checkout-create-account .col-2','width_measure','%','','','.w-checkout-create-account'),(176991,'deals-mobile','.w-checkout-shipping-address .addresses .address-item','width_measure','%','','','.w-checkout-shipping-address'),(176992,'deals-mobile','.w-checkout-shipping-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-shipping-address'),(176993,'deals-mobile','.w-checkout-shipping-choice label','width_measure','%','','','.w-checkout-shipping-choice'),(176994,'deals-mobile','.w-checkout-terms .required-message','width_measure','%','','','.w-checkout-terms'),(176995,'deals-mobile','.w-communication-new-topic .middle-form select','width_measure','%','','','.w-communication-new-topic'),(176996,'deals-mobile','.w-image-maps .svg-wrap svg','width_measure','%','','','.w-image-maps'),(176997,'deals-mobile','.w-list-b2b .select-attributes','width_measure','%','','','.w-list-b2b'),(176998,'deals-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(176999,'deals-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(177000,'deals-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(177001,'deals-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(177002,'deals-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(177003,'deals-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(177004,'deals-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(177005,'deals-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(177006,'deals-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(177007,'deals-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(177008,'deals-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(177009,'deals-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(177010,'deals-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(177011,'deals-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(177012,'deals-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(177013,'deals-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(177014,'deals-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(177015,'deals-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(177016,'deals-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(177017,'deals-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(177018,'deals-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(177019,'deals-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(177020,'deals-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(177021,'deals-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(177022,'deals-mobile','.w-promotions .prom-multi-discount .list','width_measure','%','','','.w-promotions'),(177023,'deals-mobile','.w-promotions .promo-cart-discount > div','width_measure','%','','','.w-promotions'),(177024,'deals-mobile','.w-promotions .promo-salemaker .item','width_measure','%','','','.w-promotions'),(177025,'deals-mobile','.w-promotions .promo-salemaker > div','width_measure','%','','','.w-promotions'),(177026,'deals-mobile','.w-promotions .nextdiscount .item-holder .name','width_measure','%','','','.w-promotions'),(177027,'deals-mobile','.w-promotions .nextdiscount .item-holder .image','width_measure','%','','','.w-promotions'),(177028,'deals-mobile','.w-sitemap-delivery-location > ul > li > ul > li','width_measure','%','','','.w-sitemap-delivery-location'),(177029,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(177030,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(177031,'deals-mobile','.w-wedding-registry-widgets-products .products-listing .item','width_measure','%','','','.w-wedding-registry-widgets-products'),(177032,'deals-mobile','.w-wedding-registry-widgets-products .products-listing .item','width_measure','%','','','.w-wedding-registry-widgets-products'),(177033,'deals-mobile','.w-wedding-registry-widgets-products .products-listing .item','width_measure','%','','','.w-wedding-registry-widgets-products'),(177034,'deals-mobile','.w-wedding-registry-widgets-share-url input','width_measure','%','','','.w-wedding-registry-widgets-share-url'),(177035,'deals-mobile','.p-shopping-cart-index .order-summary .btn-2','width_measure','%','','','.p-shopping-cart-index'),(177036,'deals-mobile','.w-menu .hided.menu > ul','z-index','100','','','.w-menu'),(177037,'deals-mobile','.w-menu-horizontal > ul','z-index','21','','','.w-menu-horizontal'),(177038,'deals-mobile','.w-menu-slider > ul > li > ul','z-index','100','','','.w-menu-slider'),(177039,'deals-mobile','.w-menu-horizontal > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-horizontal'),(177040,'deals-mobile','.w-menu-horizontal > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-horizontal'),(177041,'deals-mobile','.w-menu-horizontal > ul > li > ul','z-index','22','','','.w-menu-horizontal'),(177042,'deals-mobile','.w-menu-horizontal > ul > li > ul > li > ul','z-index','23','','','.w-menu-horizontal'),(177043,'deals-mobile','.w-menu-big li','z-index','20','','','.w-menu-big'),(177044,'deals-mobile','.w-menu-big > ul > li > ul','z-index','100','','','.w-menu-big'),(177045,'deals-mobile','.w-menu-style-1 > ul > li > ul','z-index','22','','','.w-menu-style-1'),(177046,'deals-mobile','.w-menu-style-1 > ul','z-index','21','','','.w-menu-style-1'),(177047,'deals-mobile','.w-cart .cart-box-link','z-index','1','','','.w-cart'),(177048,'deals-mobile','.w-cart .cart-box','z-index','100','','','.w-cart'),(177049,'deals-mobile','.b-fancybox .fancybox-opened','z-index','8030','','','.b-fancybox'),(177050,'deals-mobile','.w-quote .cart-box','z-index','100','','','.w-quote'),(177051,'deals-mobile','.w-quote .cart-box-link','z-index','1','','','.w-quote'),(177052,'deals-mobile','.b-info-popup .info-popup div','z-index','1000','','','.b-info-popup'),(177053,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > ul','z-index','23','','','.w-menu-style-1'),(177054,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-style-1'),(177055,'deals-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-style-1'),(177056,'deals-mobile','.w-account a.my-acc-link','z-index','1','','','.w-account'),(177057,'deals-mobile','.b-fancybox .fancybox-close','z-index','8040','','','.b-fancybox'),(177058,'deals-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','z-index','-1','','','.b-switch'),(177059,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','z-index','1','','','.b-switch'),(177060,'deals-mobile','.b-switch .bootstrap-switch .bootstrap-switch-label','z-index','100','','','.b-switch'),(177061,'deals-mobile','.b-switch .bootstrap-switch','z-index','0','','','.b-switch'),(177062,'deals-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','z-index','1','','','.b-slick'),(177063,'deals-mobile','.w-languages .select','z-index','100','','','.w-languages'),(177064,'deals-mobile','.w-search .suggest','z-index','500','','','.w-search'),(177065,'deals-mobile','.w-banner .banner img + img','z-index','-1','','','.w-banner'),(177066,'deals-mobile','.w-currencies .select','z-index','10','','','.w-currencies'),(177067,'deals-mobile','.b-fancybox .fancybox-title','z-index','8050','','','.b-fancybox'),(177068,'deals-mobile','.p-checkout-success .page-success','z-index','-1','','','.p-checkout-success'),(177069,'deals-mobile','.b-fancybox .fancybox-title-float-wrap','z-index','8050','','','.b-fancybox'),(177070,'deals-mobile','.b-fancybox .fancybox-wrap','z-index','8020','','','.b-fancybox'),(177071,'deals-mobile','.p-checkout-success .page-success > div','z-index','1','','','.p-checkout-success'),(177072,'deals-mobile','.b-fancybox .fancybox-overlay','z-index','8010','','','.b-fancybox'),(177073,'deals-mobile','.b-fancybox #fancybox-loading','z-index','8060','','','.b-fancybox'),(177074,'deals-mobile','.b-fancybox .fancybox-nav span','z-index','8040','','','.b-fancybox'),(177075,'deals-mobile','.b-fancybox .fancybox-nav','z-index','8040','','','.b-fancybox'),(177076,'deals-mobile','.b-form .form-inputs div.required-message','z-index','1','','','.b-form'),(177077,'deals-mobile','.b-form .hide-billing-address','z-index','70','','','.b-form'),(177078,'deals-mobile','.b-fancybox .filter-listing-preloader','z-index','100001','','','.b-fancybox'),(177079,'deals-mobile','.b-fancybox .filter-listing-loader','z-index','100000','','','.b-fancybox'),(177080,'deals-mobile','.b-bottom .pop-up-close','z-index','1','','','.b-bottom'),(177081,'deals-mobile','.b-form .same-address','z-index','80','','','.b-form'),(177082,'deals-mobile','.b-products-listing .promos-info','z-index','1','','','.b-products-listing'),(177083,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(177084,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(177085,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(177086,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(177087,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(177088,'deals-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(177089,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(177090,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(177091,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(177092,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(177093,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(177094,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(177095,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(177096,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(177097,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(177098,'deals-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(177099,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(177100,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(177101,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(177102,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(177103,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(177104,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(177105,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(177106,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(177107,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(177108,'deals-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(177109,'deals-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','z-index','1000','','','.b-menu-open_from-left'),(177110,'deals-mobile','.b-messages .messMenuButton span','z-index','1','','','.b-messages'),(177111,'deals-mobile','.b-preloader .preloader','z-index','10','','','.b-preloader'),(177112,'deals-mobile','.b-select-suggest .select2-search','z-index','10000','','','.b-select-suggest'),(177113,'deals-mobile','.b-select-suggest .select2-drop-mask','z-index','9998','','','.b-select-suggest'),(177114,'deals-mobile','.b-select-suggest .select2-drop','z-index','9999','','','.b-select-suggest'),(177115,'deals-mobile','.batchPr .batchSelect','z-index','1','','','.batchPr'),(177116,'deals-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(177117,'deals-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(177118,'deals-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(177119,'deals-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(177120,'deals-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(177121,'deals-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(177122,'deals-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(177123,'deals-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(177124,'deals-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(177125,'deals-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(177126,'deals-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(177127,'deals-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(177128,'deals-mobile','.p-sample-checkout-success .page-success > div','z-index','1','','','.p-sample-checkout-success'),(177129,'deals-mobile','.p-sample-checkout-success .page-success','z-index','-1','','','.p-sample-checkout-success'),(177130,'deals-mobile','.w-catalog-b2b-add-button ','z-index','1','','','.w-catalog-b2b-add-button'),(177131,'deals-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','z-index','1000','','','.w-image-maps'),(177132,'deals-mobile','.w-promotions .promo-cart-discount .slave .condition','z-index','1','','','.w-promotions'),(177133,'deals-mobile','.w-promotions .prom-multi-discount .promo-range','z-index','1','','','.w-promotions'),(177134,'deals-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','z-index','10','','','.w-upload-customer-id-upload-customer-id-form'),(290645,'watch-mobile','.b-bottom .closeable-heading','position','absolute','3','','.b-bottom'),(290646,'watch-mobile','.b-bottom .closeable-heading','right','0','3','','.b-bottom'),(290647,'watch-mobile','.b-bottom .closeable-heading','top','0','3','','.b-bottom'),(290648,'watch-mobile','.b-bottom .closeable-heading','content','\\f068','3','','.b-bottom'),(290649,'watch-mobile','.b-bottom .closeable-heading','font-family','$font-icons-1','3','','.b-bottom'),(290650,'watch-mobile','.b-bottom .closeable-heading.closed','content','\\f067','3','','.b-bottom'),(290651,'watch-mobile','.w-cart-discount-coupon .discount-box .inp','display','flex','','','.w-cart-discount-coupon'),(291098,'watch-mobile','.w-search .search form','z-index','2','','','.w-search'),(291111,'watch-mobile','.w-search .products','order','2','','','.w-search'),(291112,'watch-mobile','.w-search .wrap','order','3','','','.w-search'),(291147,'watch-mobile','.w-search .item a','display','flex','','','.w-search'),(291148,'watch-mobile','.w-search .name','width','calc(100% - 40px)','','','.w-search'),(291185,'watch-mobile','.w-search .products .item','padding-left','20','','','.w-search'),(291188,'watch-mobile','.w-search .products .item','margin-left','-21','','','.w-search'),(291189,'watch-mobile','.w-search .products .item a','border-bottom-width','1','','','.w-search'),(291190,'watch-mobile','.w-search .products .item a','border-bottom-color','#e0e0e0','','','.w-search'),(291191,'watch-mobile','.w-search .products .item:last-child a','border-bottom','none','','','.w-search'),(291274,'watch-mobile','.w-search .item.category-link','display','flex','','','.w-search'),(291275,'watch-mobile','.w-search .item.category-link','padding-top','5','','','.w-search'),(291276,'watch-mobile','.w-search .item.category-link','padding-right','0','','','.w-search'),(291277,'watch-mobile','.w-search .item.category-link','padding-bottom','5','','','.w-search'),(291278,'watch-mobile','.w-search .item.category-link','padding-left','0','','','.w-search'),(291279,'watch-mobile','.w-search .item.category-link picture','width','50','','','.w-search'),(291280,'watch-mobile','.w-search .item.category-link h2','border','none','','','.w-search'),(291285,'watch-mobile','.w-search .item.category-link h2','text-align','left','','','.w-search'),(291753,'watch-mobile','.w-search .suggest','flex-direction','column','','','.w-search'),(291754,'watch-mobile','.w-search .wrap','background-color','$background-6','','','.w-search'),(291756,'watch-mobile','.w-search .wrap','padding-left','15','','','.w-search'),(291758,'watch-mobile','.w-search .products','padding-right','15','','','.w-search'),(291759,'watch-mobile','.w-search .search-ico','color','$color-font-1','3','','.w-search'),(291760,'watch-mobile','.w-search .search-ico','font-size','23','3','','.w-search'),(291761,'watch-mobile','.w-search .search-ico','text-align','center','3','','.w-search'),(291762,'watch-mobile','.w-search .search-ico','line-height','48','3','','.w-search'),(291763,'watch-mobile','.w-search .search-ico','line_height_measure','px','3','','.w-search'),(291764,'watch-mobile','.w-search .search-ico','content','\\e90a','3','','.w-search'),(291765,'watch-mobile','.w-search .search-ico','display','block','3','','.w-search'),(291766,'watch-mobile','.w-search .search-ico','font-family','$font-icons-2','3','','.w-search'),(291767,'watch-mobile','.w-search .item a','align-items','center','','','.w-search'),(291768,'watch-mobile','.w-search .products .name','padding-left','15','','','.w-search'),(291811,'watch-mobile','.w-search .wrap','padding-bottom','15','','','.w-search'),(291812,'watch-mobile','.w-search .products .item a','padding-top','10','','','.w-search'),(291813,'watch-mobile','.w-search .products .item a','padding-right','0','','','.w-search'),(291814,'watch-mobile','.w-search .products .item a','padding-bottom','10','','','.w-search'),(291815,'watch-mobile','.w-search .products .item a','padding-left','0','','','.w-search'),(291816,'watch-mobile','.w-search .suggest','box-shadow','0 15px 15px -10px rgba(0,0,0,.5)','','','.w-search'),(291857,'watch-mobile','.w-search .products','border-top-width','1','','','.w-search'),(291866,'watch-mobile','.w-search .type-block.history','order','1','','','.w-search'),(291867,'watch-mobile','.w-search .type-block.history .image','display','none','3','','.w-search'),(335685,'watch-mobile','.account-index .account_block','padding-top','10','','','.account-index'),(335686,'watch-mobile','.account-index .account_block','padding-right','0','','','.account-index'),(335687,'watch-mobile','.account-index .account_block','padding-bottom','20','','','.account-index'),(335688,'watch-mobile','.account-index .account_block','padding-left','40','','','.account-index'),(335689,'watch-mobile','.account-index .account_info','list-style','none','','','.account-index'),(335690,'watch-mobile','.account-index .account_info','padding-top','0','','','.account-index'),(335691,'watch-mobile','.account-index .account_info','padding-right','0','','','.account-index'),(335692,'watch-mobile','.account-index .account_info','padding-bottom','0','','','.account-index'),(335693,'watch-mobile','.account-index .account_info','padding-left','0','','','.account-index'),(335694,'watch-mobile','.account-index .account_info','margin-top','0','','','.account-index'),(335695,'watch-mobile','.account-index .account_info','margin-right','0','','','.account-index'),(335696,'watch-mobile','.account-index .account_info','margin-bottom','0','','','.account-index'),(335697,'watch-mobile','.account-index .account_info','margin-left','0','','','.account-index'),(335698,'watch-mobile','.account-index .account_info .info','display','none','3','','.account-index'),(335699,'watch-mobile','.account-index .account_info .info','padding-bottom','25','','','.account-index'),(335700,'watch-mobile','.account-index .account_info .info .info_span','color','$color-font-7','','','.account-index'),(335701,'watch-mobile','.account-index .account_info .info .info_span','font-weight','bold','','','.account-index'),(335702,'watch-mobile','.account-index .account_info .info .info_span','padding-right','5','','','.account-index'),(335703,'watch-mobile','.account-index .account_info li','float','left','','','.account-index'),(335704,'watch-mobile','.account-index .account_info li','width','30.33','','','.account-index'),(335705,'watch-mobile','.account-index .account_info li','width_measure','%','','','.account-index'),(335706,'watch-mobile','.account-index .account_info li','padding-top','0','','','.account-index'),(335707,'watch-mobile','.account-index .account_info li','padding-right','0','','','.account-index'),(335708,'watch-mobile','.account-index .account_info li','padding-bottom','0','','','.account-index'),(335709,'watch-mobile','.account-index .account_info li','padding-left','0','','','.account-index'),(335710,'watch-mobile','.account-index .account_info li','margin-top','0','','','.account-index'),(335711,'watch-mobile','.account-index .account_info li','margin-right','0','','','.account-index'),(335712,'watch-mobile','.account-index .account_info li','margin-bottom','20','','','.account-index'),(335713,'watch-mobile','.account-index .account_info li','margin-left','4.5','','','.account-index'),(335714,'watch-mobile','.account-index .account_info li','margin_left_measure','%','','','.account-index'),(335715,'watch-mobile','.account-index .account_info li:nth-child(3n+1)','margin-left','0','','','.account-index'),(335716,'watch-mobile','.account-index .account_page','overflow','hidden','','','.account-index'),(335717,'watch-mobile','.account-index .account_page','padding-top','10','','','.account-index'),(335718,'watch-mobile','.account-index .account_page','padding-right','0','','','.account-index'),(335719,'watch-mobile','.account-index .account_page','padding-bottom','0','','','.account-index'),(335720,'watch-mobile','.account-index .account_page','padding-left','0','','','.account-index'),(335721,'watch-mobile','.account-index .account_page .icon-address','content','\\e905','3','','.account-index'),(335722,'watch-mobile','.account-index .account_page h1','font-size','30','','','.account-index'),(335723,'watch-mobile','.account-index .account_page h1','margin-top','0','','','.account-index'),(335724,'watch-mobile','.account-index .account_page h1','margin-right','0','','','.account-index'),(335725,'watch-mobile','.account-index .account_page h1','margin-bottom','10','','','.account-index'),(335726,'watch-mobile','.account-index .account_page h1','margin-left','0','','','.account-index'),(335727,'watch-mobile','.account-index .account_page h2.order-table-title','padding-left','30','','','.account-index'),(335728,'watch-mobile','.account-index .account_page h4','font-size','22','3','','.account-index'),(335729,'watch-mobile','.account-index .account_page h4','font-weight','normal','3','','.account-index'),(335730,'watch-mobile','.account-index .account_page h4','left','9','3','','.account-index'),(335731,'watch-mobile','.account-index .account_page h4','position','absolute','3','','.account-index'),(335732,'watch-mobile','.account-index .account_page h4','top','-4','3','','.account-index'),(335733,'watch-mobile','.account-index .account_page h4','line-height','30','3','','.account-index'),(335734,'watch-mobile','.account-index .account_page h4','line_height_measure','px','3','','.account-index'),(335735,'watch-mobile','.account-index .account_page h4','font-family','$font-icons-2','3','','.account-index'),(335736,'watch-mobile','.account-index .account_page h4','position','relative','','','.account-index'),(335737,'watch-mobile','.account-index .account_page h4','padding-left','40','','','.account-index'),(335738,'watch-mobile','.account-index .account_page h4.icon-mail','content','\\e927','3','','.account-index'),(335739,'watch-mobile','.account-index .account_page h4.icon-password','content','\\e906','3','','.account-index'),(335740,'watch-mobile','.account-index .account_page h4.icon-user','content','\\e921','3','','.account-index'),(335741,'watch-mobile','.account-index .acount_row','overflow','hidden','','','.account-index'),(335742,'watch-mobile','.account-index .ai_title','font-weight','bold','','','.account-index'),(335743,'watch-mobile','.account-index .ai_title','width','40','','','.account-index'),(335744,'watch-mobile','.account-index .ai_title','width_measure','%','','','.account-index'),(335745,'watch-mobile','.account-index .ai_title, .account-index .ai_value','float','left','','','.account-index'),(335746,'watch-mobile','.account-index .badc_bottom','text-align','center','','','.account-index'),(335747,'watch-mobile','.account-index .badc_bottom','padding-top','0','','','.account-index'),(335748,'watch-mobile','.account-index .badc_bottom','padding-right','0','','','.account-index'),(335749,'watch-mobile','.account-index .badc_bottom','padding-bottom','58','','','.account-index'),(335750,'watch-mobile','.account-index .badc_bottom','padding-left','0','','','.account-index'),(335751,'watch-mobile','.account-index .date_title','color','$color-font-7','','','.account-index'),(335752,'watch-mobile','.account-index .date_title','font-size','14','','','.account-index'),(335753,'watch-mobile','.account-index .date_title','text-transform','uppercase','','','.account-index'),(335754,'watch-mobile','.account-index .date_title','padding-top','5','','','.account-index'),(335755,'watch-mobile','.account-index .date_title','padding-right','0','','','.account-index'),(335756,'watch-mobile','.account-index .date_title','padding-bottom','0','','','.account-index'),(335757,'watch-mobile','.account-index .date_title','padding-left','0','','','.account-index'),(335758,'watch-mobile','.account-index .date_value','color','$attention-color','','','.account-index'),(335759,'watch-mobile','.account-index .date_value','font-size','18','','','.account-index'),(335760,'watch-mobile','.account-index .date_value strong','color','$color-font-7','','','.account-index'),(335761,'watch-mobile','.account-index .date_value strong','font-size','16','','','.account-index'),(335762,'watch-mobile','.account-index .date_value strong','font-weight','normal','','','.account-index'),(335763,'watch-mobile','.account-index .date_value strong','font-family','$font-2','','','.account-index'),(335764,'watch-mobile','.account-index .date_value, .account-index .date_title','font-size','18','','','.account-index'),(335765,'watch-mobile','.account-index .date_value, .account-index .date_title','line-height','22','','','.account-index'),(335766,'watch-mobile','.account-index .date_value, .account-index .date_title','line_height_measure','px','','','.account-index'),(335767,'watch-mobile','.account-index .date_value, .account-index .date_title','display','block','','','.account-index'),(335768,'watch-mobile','.account-index .date_value, .account-index .date_title','font-family','$font-1','','','.account-index'),(335769,'watch-mobile','.account-index .moduleRowDue td','color','$color-font-2','','','.account-index'),(335770,'watch-mobile','.account-index .moduleRowDue td','position','relative','','','.account-index'),(335771,'watch-mobile','.account-index .moduleRowDue td','background-image','url(\'\')','','','.account-index'),(335772,'watch-mobile','.account-index .not_fully_paid_td','color','$attention-color','','','.account-index'),(335773,'watch-mobile','.account-index .not_fully_paid_td','font-size','30','','','.account-index'),(335774,'watch-mobile','.account-index .not_fully_paid_td','font-weight','700','','','.account-index'),(335775,'watch-mobile','.account-index .not_fully_paid_td','left','15','','','.account-index'),(335776,'watch-mobile','.account-index .not_fully_paid_td','position','absolute','','','.account-index'),(335777,'watch-mobile','.account-index .not_fully_paid_td','text-transform','uppercase','','','.account-index'),(335778,'watch-mobile','.account-index .not_fully_paid_td','top','19','','','.account-index'),(335779,'watch-mobile','.account-index .not_fully_paid_td','width','300','','','.account-index'),(335780,'watch-mobile','.account-index .orders-table','border-top','none','','','.account-index'),(335781,'watch-mobile','.account-index .orders-table .hidden','display','none','','','.account-index'),(335782,'watch-mobile','.account-index .orders-table a, .account-index .order-info a','text-decoration','none','1','','.account-index'),(335783,'watch-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','font-size','16','','','.account-index'),(335784,'watch-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','line-height','20','','','.account-index'),(335785,'watch-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','line_height_measure','px','','','.account-index'),(335786,'watch-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','padding-top','10','','','.account-index'),(335787,'watch-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','padding-right','10','','','.account-index'),(335788,'watch-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','padding-bottom','10','','','.account-index'),(335789,'watch-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','padding-left','10','','','.account-index'),(335790,'watch-mobile','.account-index .orders-table th','background-color','$background-6','','','.account-index'),(335791,'watch-mobile','.account-index .orders-table th','text-align','left','','','.account-index'),(335792,'watch-mobile','.account-index .orders-table th','font-family','$font-1','','','.account-index'),(335793,'watch-mobile','.account-index .orders-table th','padding-top','2','','','.account-index'),(335794,'watch-mobile','.account-index .orders-table th','padding-right','10','','','.account-index'),(335795,'watch-mobile','.account-index .orders-table th','padding-bottom','2','','','.account-index'),(335796,'watch-mobile','.account-index .orders-table th','padding-left','10','','','.account-index'),(335797,'watch-mobile','.account-index .orders-table tr:first-child','border','none','','','.account-index'),(335798,'watch-mobile','.account-index .topAccount','background-color','$background-6','','','.account-index'),(335799,'watch-mobile','.account-index .topAccount','list-style','none','','','.account-index'),(335800,'watch-mobile','.account-index .topAccount','overflow','hidden','','','.account-index'),(335801,'watch-mobile','.account-index .topAccount','padding-top','24','','','.account-index'),(335802,'watch-mobile','.account-index .topAccount','padding-right','19','','','.account-index'),(335803,'watch-mobile','.account-index .topAccount','padding-bottom','17','','','.account-index'),(335804,'watch-mobile','.account-index .topAccount','padding-left','19','','','.account-index'),(335805,'watch-mobile','.account-index .topAccount','margin-top','0','','','.account-index'),(335806,'watch-mobile','.account-index .topAccount','margin-right','0','','','.account-index'),(335807,'watch-mobile','.account-index .topAccount','margin-bottom','30','','','.account-index'),(335808,'watch-mobile','.account-index .topAccount','margin-left','0','','','.account-index'),(335809,'watch-mobile','.account-index .topAccount > li','float','left','','','.account-index'),(335810,'watch-mobile','.account-index .topAccount > li','width','20','','','.account-index'),(335811,'watch-mobile','.account-index .topAccount > li','width_measure','%','','','.account-index'),(335812,'watch-mobile','.account-index .topAccount > li','padding-top','0','','','.account-index'),(335813,'watch-mobile','.account-index .topAccount > li','padding-right','2','','','.account-index'),(335814,'watch-mobile','.account-index .topAccount > li','padding_right_measure','%','','','.account-index'),(335815,'watch-mobile','.account-index .topAccount > li','padding-bottom','0','','','.account-index'),(335816,'watch-mobile','.account-index .topAccount > li','padding-left','2','','','.account-index'),(335817,'watch-mobile','.account-index .topAccount > li','padding_left_measure','%','','','.account-index'),(335818,'watch-mobile','.account-index .topAccount > li > div','color','$attention-color','3','','.account-index'),(335819,'watch-mobile','.account-index .topAccount > li > div','font-size','42','3','','.account-index'),(335820,'watch-mobile','.account-index .topAccount > li > div','text-align','center','3','','.account-index'),(335821,'watch-mobile','.account-index .topAccount > li > div','line-height','40','3','','.account-index'),(335822,'watch-mobile','.account-index .topAccount > li > div','line_height_measure','px','3','','.account-index'),(335823,'watch-mobile','.account-index .topAccount > li > div','display','block','3','','.account-index'),(335824,'watch-mobile','.account-index .topAccount > li > div','font-family','$font-icons-2','3','','.account-index'),(335825,'watch-mobile','.account-index .topAccount > li > div','text-align','center','','','.account-index'),(335826,'watch-mobile','.account-index .topAccount > li > div.credit_amount_ac','content','\\e994','3','','.account-index'),(335827,'watch-mobile','.account-index .topAccount > li > div.dateLast','content','\\e920','3','','.account-index'),(335828,'watch-mobile','.account-index .topAccount > li > div.order_count','content','\\e928','3','','.account-index'),(335829,'watch-mobile','.account-index .topAccount > li > div.points_earnt','content','\\e990','3','','.account-index'),(335830,'watch-mobile','.account-index .topAccount > li > div.points_earnt .date_value, .account-index .topAccount > li > div.points_earnt, .account-index .topAccount > li > div.points_earnt .date_title','color','$color-font-8','3','','.account-index'),(335831,'watch-mobile','.account-index .topAccount > li > div.total_count','content','\\e922','3','','.account-index'),(335832,'watch-mobile','.account-index .view_history','color','$color-font-6','','','.account-index'),(335833,'watch-mobile','.account-index .view_history','font-size','16','','','.account-index'),(335834,'watch-mobile','.account-index .view_history','text-decoration','underline','','','.account-index'),(335835,'watch-mobile','.account-index .view_history','font-size','14','3','','.account-index'),(335836,'watch-mobile','.account-index .view_history','content','\\e991','3','','.account-index'),(335837,'watch-mobile','.account-index .view_history','display','inline-block','3','','.account-index'),(335838,'watch-mobile','.account-index .view_history','font-family','$font-icons-2','3','','.account-index'),(335839,'watch-mobile','.account-index .view_history','margin-top','0','3','','.account-index'),(335840,'watch-mobile','.account-index .view_history','margin-right','7','3','','.account-index'),(335841,'watch-mobile','.account-index .view_history','margin-bottom','0','3','','.account-index'),(335842,'watch-mobile','.account-index .view_history','margin-left','0','3','','.account-index'),(335843,'watch-mobile','.account-index .view_link','color','$color-font-6','','','.account-index'),(335844,'watch-mobile','.account-index .view_link','position','relative','','','.account-index'),(335845,'watch-mobile','.account-index .view_link','text-decoration','underline','','','.account-index'),(335846,'watch-mobile','.account-index .view_link','white-space','nowrap','','','.account-index'),(335847,'watch-mobile','.account-index .view_link','padding-top','0','','','.account-index'),(335848,'watch-mobile','.account-index .view_link','padding-right','20','','','.account-index'),(335849,'watch-mobile','.account-index .view_link','padding-bottom','0','','','.account-index'),(335850,'watch-mobile','.account-index .view_link','padding-left','0','','','.account-index'),(335851,'watch-mobile','.account-index .view_link','font-size','18','4','','.account-index'),(335852,'watch-mobile','.account-index .view_link','position','absolute','4','','.account-index'),(335853,'watch-mobile','.account-index .view_link','top','4','4','','.account-index'),(335854,'watch-mobile','.account-index .view_link','vertical-align','middle','4','','.account-index'),(335855,'watch-mobile','.account-index .view_link','line-height','17','4','','.account-index'),(335856,'watch-mobile','.account-index .view_link','line_height_measure','px','4','','.account-index'),(335857,'watch-mobile','.account-index .view_link','content','\\e901','4','','.account-index'),(335858,'watch-mobile','.account-index .view_link','display','inline-block','4','','.account-index'),(335859,'watch-mobile','.account-index .view_link','font-family','$font-icons-2','4','','.account-index'),(335860,'watch-mobile','.account-index td.acc_wish_remove','vertical-align','middle','','','.account-index'),(335861,'watch-mobile','.account-index td.td-alignright','text-align','right','','','.account-index'),(335862,'watch-mobile','.account-index th','background-color','$background-6','','','.account-index'),(335863,'watch-mobile','.account-index th','padding-top','10','','','.account-index'),(335864,'watch-mobile','.account-index th','padding-right','15','','','.account-index'),(335865,'watch-mobile','.account-index th','padding-bottom','10','','','.account-index'),(335866,'watch-mobile','.account-index th','padding-left','15','','','.account-index'),(335867,'watch-mobile','.account-index th, .account-index td','text-align','left','','','.account-index'),(335868,'watch-mobile','.account-index th.wish_remove_title, .account-index td.acc_wish_remove','text-align','center','','','.account-index'),(335869,'watch-mobile','.account-index .account_info','padding-top','0','303','','.account-index'),(335870,'watch-mobile','.account-index .account_info','padding-right','0','303','','.account-index'),(335871,'watch-mobile','.account-index .account_info','padding-bottom','0','303','','.account-index'),(335872,'watch-mobile','.account-index .account_info','padding-left','0','303','','.account-index'),(335873,'watch-mobile','.account-index .account_info','margin-top','0','303','','.account-index'),(335874,'watch-mobile','.account-index .account_info','margin-right','0','303','','.account-index'),(335875,'watch-mobile','.account-index .account_info','margin-bottom','20','303','','.account-index'),(335876,'watch-mobile','.account-index .account_info','margin-left','0','303','','.account-index'),(335877,'watch-mobile','.account-index .orders-table .headings','display','none','317','','.account-index'),(335878,'watch-mobile','.account-index .orders-table .hidden','width','130','317','','.account-index'),(335879,'watch-mobile','.account-index .orders-table .hidden','display','inline-block','317','','.account-index'),(335880,'watch-mobile','.account-index .orders-table .item','position','relative','317','','.account-index'),(335881,'watch-mobile','.account-index .orders-table .item','display','block','317','','.account-index'),(335882,'watch-mobile','.account-index .orders-table .item','border-top-width','1','317','','.account-index'),(335883,'watch-mobile','.account-index .orders-table .item','border-left-width','1','317','','.account-index'),(335884,'watch-mobile','.account-index .orders-table .item','border-right-width','1','317','','.account-index'),(335885,'watch-mobile','.account-index .orders-table .item','border-bottom-width','1','317','','.account-index'),(335886,'watch-mobile','.account-index .orders-table .item','border-top-color','$border-color-10','317','','.account-index'),(335887,'watch-mobile','.account-index .orders-table .item','border-left-color','$border-color-10','317','','.account-index'),(335888,'watch-mobile','.account-index .orders-table .item','border-right-color','$border-color-10','317','','.account-index'),(335889,'watch-mobile','.account-index .orders-table .item','border-bottom-color','$border-color-10','317','','.account-index'),(335890,'watch-mobile','.account-index .orders-table .item','padding-bottom','45','317','','.account-index'),(335891,'watch-mobile','.account-index .orders-table .item','margin-bottom','10','317','','.account-index'),(335892,'watch-mobile','.account-index .orders-table .item td','display','block','317','','.account-index'),(335893,'watch-mobile','.account-index .orders-table .order-total','bottom','45','317','','.account-index'),(335894,'watch-mobile','.account-index .orders-table .order-total','position','absolute','317','','.account-index'),(335895,'watch-mobile','.account-index .orders-table .order-total','right','0','317','','.account-index'),(335896,'watch-mobile','.account-index .orders-table .status-name','bottom','7','317','','.account-index'),(335897,'watch-mobile','.account-index .orders-table .status-name','left','0','317','','.account-index'),(335898,'watch-mobile','.account-index .orders-table .status-name','position','absolute','317','','.account-index'),(335899,'watch-mobile','.account-index .orders-table .td-alignright','bottom','0','317','','.account-index'),(335900,'watch-mobile','.account-index .orders-table .td-alignright','height','45','317','','.account-index'),(335901,'watch-mobile','.account-index .orders-table .td-alignright','left','0','317','','.account-index'),(335902,'watch-mobile','.account-index .orders-table .td-alignright','position','absolute','317','','.account-index'),(335903,'watch-mobile','.account-index .orders-table .td-alignright','width','100','317','','.account-index'),(335904,'watch-mobile','.account-index .orders-table .td-alignright','width_measure','%','317','','.account-index'),(335905,'watch-mobile','.account-index .orders-table .td-alignright','line-height','35','317','','.account-index'),(335906,'watch-mobile','.account-index .orders-table .td-alignright','line_height_measure','px','317','','.account-index'),(335907,'watch-mobile','.account-index .orders-table .td-alignright','border-top-width','1','317','','.account-index'),(335908,'watch-mobile','.account-index .orders-table .td-alignright','padding-top','5','317','','.account-index'),(335909,'watch-mobile','.account-index .orders-table .td-alignright','padding-right','10','317','','.account-index'),(335910,'watch-mobile','.account-index .orders-table .td-alignright','padding-bottom','5','317','','.account-index'),(335911,'watch-mobile','.account-index .orders-table .td-alignright','padding-left','10','317','','.account-index'),(335912,'watch-mobile','.account-index .orders-table td','padding-top','5','317','','.account-index'),(335913,'watch-mobile','.account-index .orders-table td','padding-right','10','317','','.account-index'),(335914,'watch-mobile','.account-index .orders-table td','padding-bottom','5','317','','.account-index'),(335915,'watch-mobile','.account-index .orders-table td','padding-left','10','317','','.account-index'),(335916,'watch-mobile','.account-index .orders-table td.name','display','none','317','','.account-index'),(335917,'watch-mobile','.account-index .orders-table, .account-index .orders-table tbody','display','block','317','','.account-index'),(335918,'watch-mobile','.account-index .account_info li','float','none','290','','.account-index'),(335919,'watch-mobile','.account-index .account_info li','width','100','290','','.account-index'),(335920,'watch-mobile','.account-index .account_info li','width_measure','%','290','','.account-index'),(335921,'watch-mobile','.account-index .account_info li','padding-top','0','290','','.account-index'),(335922,'watch-mobile','.account-index .account_info li','padding-right','0','290','','.account-index'),(335923,'watch-mobile','.account-index .account_info li','padding-bottom','10','290','','.account-index'),(335924,'watch-mobile','.account-index .account_info li','padding-left','0','290','','.account-index'),(335925,'watch-mobile','.account-index .topAccount > li','float','none','290','','.account-index'),(335926,'watch-mobile','.account-index .topAccount > li','width','100','290','','.account-index'),(335927,'watch-mobile','.account-index .topAccount > li','width_measure','%','290','','.account-index'),(335928,'watch-mobile','.account-index .topAccount > li','padding-top','0','290','','.account-index'),(335929,'watch-mobile','.account-index .topAccount > li','padding-right','0','290','','.account-index'),(335930,'watch-mobile','.account-index .topAccount > li','padding-bottom','10','290','','.account-index'),(335931,'watch-mobile','.account-index .topAccount > li','padding-left','0','290','','.account-index'),(335932,'watch-mobile','.account-index .topAccount > li > div','left','0','290,3','','.account-index'),(335933,'watch-mobile','.account-index .topAccount > li > div','position','absolute','290,3','','.account-index'),(335934,'watch-mobile','.account-index .topAccount > li > div','top','4','290,3','','.account-index'),(335935,'watch-mobile','.account-index .topAccount > li > div','position','relative','290','','.account-index'),(335936,'watch-mobile','.account-index .topAccount > li > div','text-align','left','290','','.account-index'),(335937,'watch-mobile','.account-index .topAccount > li > div','padding-top','0','290','','.account-index'),(335938,'watch-mobile','.account-index .topAccount > li > div','padding-right','0','290','','.account-index'),(335939,'watch-mobile','.account-index .topAccount > li > div','padding-bottom','0','290','','.account-index'),(335940,'watch-mobile','.account-index .topAccount > li > div','padding-left','55','290','','.account-index'),(335941,'watch-mobile','.account-index h1, .account-index .reviews-info h1','font-size','21','290','','.account-index'),(335942,'watch-mobile','.account-address-book .address_book','padding-top','0','','','.account-address-book'),(335943,'watch-mobile','.account-address-book .address_book','padding-right','0','','','.account-address-book'),(335944,'watch-mobile','.account-address-book .address_book','padding-bottom','30','','','.account-address-book'),(335945,'watch-mobile','.account-address-book .address_book','padding-left','0','','','.account-address-book'),(335946,'watch-mobile','.account-address-book .address_book .btn-edit, .account-address-book .address_book .btn-delete','font-size','16','4','','.account-address-book'),(335947,'watch-mobile','.account-address-book .address_book .row-buttons a','margin-top','0','','','.account-address-book'),(335948,'watch-mobile','.account-address-book .address_book .row-buttons a','margin-right','10','','','.account-address-book'),(335949,'watch-mobile','.account-address-book .address_book .row-buttons a','margin-bottom','0','','','.account-address-book'),(335950,'watch-mobile','.account-address-book .address_book .row-buttons a','margin-left','0','','','.account-address-book'),(335951,'watch-mobile','.account-address-book .address_book h1','border-bottom-width','1','','','.account-address-book'),(335952,'watch-mobile','.account-address-book .address_book h1','padding-top','0','','','.account-address-book'),(335953,'watch-mobile','.account-address-book .address_book h1','padding-right','0','','','.account-address-book'),(335954,'watch-mobile','.account-address-book .address_book h1','padding-bottom','5','','','.account-address-book'),(335955,'watch-mobile','.account-address-book .address_book h1','padding-left','0','','','.account-address-book'),(335956,'watch-mobile','.account-address-book .address_book h1','margin-top','0','','','.account-address-book'),(335957,'watch-mobile','.account-address-book .address_book h1','margin-right','0','','','.account-address-book'),(335958,'watch-mobile','.account-address-book .address_book h1','margin-bottom','18','','','.account-address-book'),(335959,'watch-mobile','.account-address-book .address_book h1','margin-left','0','','','.account-address-book'),(335960,'watch-mobile','.account-address-book .address_book h2','font-size','18','','','.account-address-book'),(335961,'watch-mobile','.account-address-book .address_book h2','font-weight','normal','','','.account-address-book'),(335962,'watch-mobile','.account-address-book .address_book h2','text-align','right','','','.account-address-book'),(335963,'watch-mobile','.account-address-book .address_book h2','text-transform','uppercase','','','.account-address-book'),(335964,'watch-mobile','.account-address-book .address_book h2','border-bottom-width','1','','','.account-address-book'),(335965,'watch-mobile','.account-address-book .address_book h2','padding-top','15','','','.account-address-book'),(335966,'watch-mobile','.account-address-book .address_book h2','padding-right','10','','','.account-address-book'),(335967,'watch-mobile','.account-address-book .address_book h2','padding-bottom','10','','','.account-address-book'),(335968,'watch-mobile','.account-address-book .address_book h2','padding-left','10','','','.account-address-book'),(335969,'watch-mobile','.account-address-book .address_book h2','margin-top','0','','','.account-address-book'),(335970,'watch-mobile','.account-address-book .address_book h2','margin-right','0','','','.account-address-book'),(335971,'watch-mobile','.account-address-book .address_book h2','margin-bottom','15','','','.account-address-book'),(335972,'watch-mobile','.account-address-book .address_book h2','margin-left','0','','','.account-address-book'),(335973,'watch-mobile','.account-address-book .address_book h2 strong','float','left','','','.account-address-book'),(335974,'watch-mobile','.account-address-book .address_book, .account-address-book .account_history_info','padding-top','10','','','.account-address-book'),(335975,'watch-mobile','.account-address-book .address_book, .account-address-book .account_history_info','padding-right','0','','','.account-address-book'),(335976,'watch-mobile','.account-address-book .address_book, .account-address-book .account_history_info','padding-bottom','10','','','.account-address-book'),(335977,'watch-mobile','.account-address-book .address_book, .account-address-book .account_history_info','padding-left','0','','','.account-address-book'),(335978,'watch-mobile','.account-address-book .address_book_row','clear','both','','','.account-address-book'),(335979,'watch-mobile','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-top','0','','','.account-address-book'),(335980,'watch-mobile','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-right','0','','','.account-address-book'),(335981,'watch-mobile','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-bottom','15','','','.account-address-book'),(335982,'watch-mobile','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-left','2','','','.account-address-book'),(335983,'watch-mobile','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin_left_measure','%','','','.account-address-book'),(335984,'watch-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','float','left','','','.account-address-book'),(335985,'watch-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','width','48','','','.account-address-book'),(335986,'watch-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','width_measure','%','','','.account-address-book'),(335987,'watch-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-top','0','','','.account-address-book'),(335988,'watch-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-right','2','','','.account-address-book'),(335989,'watch-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin_right_measure','%','','','.account-address-book'),(335990,'watch-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-bottom','10','','','.account-address-book'),(335991,'watch-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-left','0','','','.account-address-book'),(335992,'watch-mobile','.account-address-book .address_book_row h2 a','text-transform','none','','','.account-address-book'),(335993,'watch-mobile','.account-address-book .address_book_row h2 a','margin-top','0','','','.account-address-book'),(335994,'watch-mobile','.account-address-book .address_book_row h2 a','margin-right','0','','','.account-address-book'),(335995,'watch-mobile','.account-address-book .address_book_row h2 a','margin-bottom','0','','','.account-address-book'),(335996,'watch-mobile','.account-address-book .address_book_row h2 a','margin-left','15','','','.account-address-book'),(335997,'watch-mobile','.account-address-book .btn-edit','font-size','16','4','','.account-address-book'),(335998,'watch-mobile','.account-address-book .btn-edit','content','\\e917','4','','.account-address-book'),(335999,'watch-mobile','.account-address-book .btn-edit','font-family','$font-icons-2','4','','.account-address-book'),(336000,'watch-mobile','.account-address-book .btn-edit','padding-top','0','4','','.account-address-book'),(336001,'watch-mobile','.account-address-book .btn-edit','padding-right','0','4','','.account-address-book'),(336002,'watch-mobile','.account-address-book .btn-edit','padding-bottom','0','4','','.account-address-book'),(336003,'watch-mobile','.account-address-book .btn-edit','padding-left','10','4','','.account-address-book'),(336004,'watch-mobile','.account-address-book .button1','float','right','','','.account-address-book'),(336005,'watch-mobile','.account-address-book .button2','float','left','','','.account-address-book'),(336006,'watch-mobile','.account-address-book .buttonBox','overflow','hidden','','','.account-address-book'),(336007,'watch-mobile','.account-address-book .buttonBox','padding-top','15','','','.account-address-book'),(336008,'watch-mobile','.account-address-book .buttonBox','padding-right','0','','','.account-address-book'),(336009,'watch-mobile','.account-address-book .buttonBox','padding-bottom','15','','','.account-address-book'),(336010,'watch-mobile','.account-address-book .buttonBox','padding-left','0','','','.account-address-book'),(336011,'watch-mobile','.account-address-book .buttonBox .info','left','-6','3','','.account-address-book'),(336012,'watch-mobile','.account-address-book .buttonBox .info','margin-top','0','','','.account-address-book'),(336013,'watch-mobile','.account-address-book .buttonBox .info','margin-right','25','','','.account-address-book'),(336014,'watch-mobile','.account-address-book .buttonBox .info','margin-bottom','0','','','.account-address-book'),(336015,'watch-mobile','.account-address-book .buttonBox .info','margin-left','0','','','.account-address-book'),(336016,'watch-mobile','.account-address-book .leftMes div','color','$attention-color','','','.account-address-book'),(336017,'watch-mobile','.account-address-book .leftMes div','font-size','18','','','.account-address-book'),(336018,'watch-mobile','.account-address-book .leftMes div','text-transform','uppercase','','','.account-address-book'),(336019,'watch-mobile','.account-address-book .leftMes div','font-family','$font-1','','','.account-address-book'),(336020,'watch-mobile','.account-address-book .leftMes ul','color','$attention-color','','','.account-address-book'),(336021,'watch-mobile','.account-address-book .leftMes ul','list-style','disc inside','','','.account-address-book'),(336022,'watch-mobile','.account-address-book .leftMes ul','padding-left','0','','','.account-address-book'),(336023,'watch-mobile','.account-address-book .rightMes ul','color','$attention-color','','','.account-address-book'),(336024,'watch-mobile','.account-address-book .rightMes ul','list-style','disc inside','','','.account-address-book'),(336025,'watch-mobile','.account-address-book .rightMes ul','padding-top','22','','','.account-address-book'),(336026,'watch-mobile','.account-address-book .rightMes ul','padding-right','0','','','.account-address-book'),(336027,'watch-mobile','.account-address-book .rightMes ul','padding-bottom','0','','','.account-address-book'),(336028,'watch-mobile','.account-address-book .rightMes ul','padding-left','19','','','.account-address-book'),(336029,'watch-mobile','.account-address-book .topButtons','padding-top','0','','','.account-address-book'),(336030,'watch-mobile','.account-address-book .topButtons','padding-right','0','','','.account-address-book'),(336031,'watch-mobile','.account-address-book .topButtons','padding-bottom','15','','','.account-address-book'),(336032,'watch-mobile','.account-address-book .topButtons','padding-left','0','','','.account-address-book'),(336033,'watch-mobile','.account-address-book .address_book_row .column','float','none','290','','.account-address-book'),(336034,'watch-mobile','.account-address-book .address_book_row .column','width','100','290','','.account-address-book'),(336035,'watch-mobile','.account-address-book .address_book_row .column','width_measure','%','290','','.account-address-book'),(336036,'watch-mobile','.account-address-book .address_book_row .column','margin-top','0','290','','.account-address-book'),(336037,'watch-mobile','.account-address-book .address_book_row .column','margin-right','0','290','','.account-address-book'),(336038,'watch-mobile','.account-address-book .address_book_row .column','margin-bottom','12','290','','.account-address-book'),(336039,'watch-mobile','.account-address-book .address_book_row .column','margin-left','0','290','','.account-address-book'),(336040,'watch-mobile','.account-address-book .address_book_row .column + .column','float','none','290','','.account-address-book'),(336041,'watch-mobile','.account-address-book .address_book_row .column + .column','width','100','290','','.account-address-book'),(336042,'watch-mobile','.account-address-book .address_book_row .column + .column','width_measure','%','290','','.account-address-book'),(336043,'watch-mobile','.account-address-book .address_book_row .column + .column','margin-top','0','290','','.account-address-book'),(336044,'watch-mobile','.account-address-book .address_book_row .column + .column','margin-right','0','290','','.account-address-book'),(336045,'watch-mobile','.account-address-book .address_book_row .column + .column','margin-bottom','12','290','','.account-address-book'),(336046,'watch-mobile','.account-address-book .address_book_row .column + .column','margin-left','0','290','','.account-address-book'),(336047,'watch-mobile','.account-address-book .topInfo > div','float','none','290','','.account-address-book'),(336048,'watch-mobile','.account-address-book .topInfo > div','width','100','290','','.account-address-book'),(336049,'watch-mobile','.account-address-book .topInfo > div','width_measure','%','290','','.account-address-book'),(336050,'watch-mobile','.account-address-book .topInfo > div','margin-top','0','290','','.account-address-book'),(336051,'watch-mobile','.account-address-book .topInfo > div','margin-right','0','290','','.account-address-book'),(336052,'watch-mobile','.account-address-book .topInfo > div','margin-bottom','12','290','','.account-address-book'),(336053,'watch-mobile','.account-address-book .topInfo > div','margin-left','0','290','','.account-address-book'),(336054,'watch-mobile','.account-address-book .topInfo > div + div','float','none','290','','.account-address-book'),(336055,'watch-mobile','.account-address-book .topInfo > div + div','width','100','290','','.account-address-book'),(336056,'watch-mobile','.account-address-book .topInfo > div + div','width_measure','%','290','','.account-address-book'),(336057,'watch-mobile','.account-address-book .topInfo > div + div','margin-top','0','290','','.account-address-book'),(336058,'watch-mobile','.account-address-book .topInfo > div + div','margin-right','0','290','','.account-address-book'),(336059,'watch-mobile','.account-address-book .topInfo > div + div','margin-bottom','12','290','','.account-address-book'),(336060,'watch-mobile','.account-address-book .topInfo > div + div','margin-left','0','290','','.account-address-book'),(336061,'watch-mobile','.account-address-book-process .buttons','margin-top','-70','','','.account-address-book-process'),(336062,'watch-mobile','.account-address-book-process .buttons','margin-bottom','20','','','.account-address-book-process'),(336063,'watch-mobile','.account-edit-wrap .buttons','margin-top','-70','','','.account-edit-wrap'),(336064,'watch-mobile','.account-edit-wrap .buttons','margin-bottom','20','','','.account-edit-wrap'),(336065,'watch-mobile','.account-order-history .buttonBox','margin-top','15','','','.account-order-history'),(336066,'watch-mobile','.account-order-history .buttonBox','margin-right','0','','','.account-order-history'),(336067,'watch-mobile','.account-order-history .buttonBox','margin-bottom','15','','','.account-order-history'),(336068,'watch-mobile','.account-order-history .buttonBox','margin-left','0','','','.account-order-history'),(336069,'watch-mobile','.account-order-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.account-order-history'),(336070,'watch-mobile','.account-order-history .moduleRowDue td','color','$color-font-2','','','.account-order-history'),(336071,'watch-mobile','.account-order-history .moduleRowDue td','position','relative','','','.account-order-history'),(336072,'watch-mobile','.account-order-history .not_fully_paid_td','color','$attention-color','','','.account-order-history'),(336073,'watch-mobile','.account-order-history .not_fully_paid_td','font-size','30','','','.account-order-history'),(336074,'watch-mobile','.account-order-history .not_fully_paid_td','font-weight','700','','','.account-order-history'),(336075,'watch-mobile','.account-order-history .not_fully_paid_td','left','15','','','.account-order-history'),(336076,'watch-mobile','.account-order-history .not_fully_paid_td','position','absolute','','','.account-order-history'),(336077,'watch-mobile','.account-order-history .not_fully_paid_td','text-transform','uppercase','','','.account-order-history'),(336078,'watch-mobile','.account-order-history .not_fully_paid_td','top','19','','','.account-order-history'),(336079,'watch-mobile','.account-order-history .not_fully_paid_td','width','300','','','.account-order-history'),(336080,'watch-mobile','.account-order-history .orders-table','border-top','none','','','.account-order-history'),(336081,'watch-mobile','.account-order-history .orders-table .hidden','display','none','','','.account-order-history'),(336082,'watch-mobile','.account-order-history .orders-table a, .account-order-history .order-info a','text-decoration','none','1','','.account-order-history'),(336083,'watch-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','font-size','16','','','.account-order-history'),(336084,'watch-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','line-height','20','','','.account-order-history'),(336085,'watch-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','line_height_measure','px','','','.account-order-history'),(336086,'watch-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','padding-top','10','','','.account-order-history'),(336087,'watch-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','padding-right','10','','','.account-order-history'),(336088,'watch-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','padding-bottom','10','','','.account-order-history'),(336089,'watch-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','padding-left','10','','','.account-order-history'),(336090,'watch-mobile','.account-order-history .orders-table td.td-alignright','text-align','right','','','.account-order-history'),(336091,'watch-mobile','.account-order-history .orders-table th','background-color','$background-6','','','.account-order-history'),(336092,'watch-mobile','.account-order-history .orders-table th','text-align','left','','','.account-order-history'),(336093,'watch-mobile','.account-order-history .orders-table th','font-family','$font-1','','','.account-order-history'),(336094,'watch-mobile','.account-order-history .orders-table th','padding-top','2','','','.account-order-history'),(336095,'watch-mobile','.account-order-history .orders-table th','padding-right','10','','','.account-order-history'),(336096,'watch-mobile','.account-order-history .orders-table th','padding-bottom','2','','','.account-order-history'),(336097,'watch-mobile','.account-order-history .orders-table th','padding-left','10','','','.account-order-history'),(336098,'watch-mobile','.account-order-history .orders-table tr:first-child','border','none','','','.account-order-history'),(336099,'watch-mobile','.account-order-history .order_history_table h2','font-size','24','','','.account-order-history'),(336100,'watch-mobile','.account-order-history .order_history_table h2','font-weight','normal','','','.account-order-history'),(336101,'watch-mobile','.account-order-history .order_history_table h2','text-transform','uppercase','','','.account-order-history'),(336102,'watch-mobile','.account-order-history .order_history_table h2','margin-top','0','','','.account-order-history'),(336103,'watch-mobile','.account-order-history .order_history_table h2','margin-right','0','','','.account-order-history'),(336104,'watch-mobile','.account-order-history .order_history_table h2','margin-bottom','8','','','.account-order-history'),(336105,'watch-mobile','.account-order-history .order_history_table h2','margin-left','0','','','.account-order-history'),(336106,'watch-mobile','.account-order-history .order_history_table th','background-color','$background-6','','','.account-order-history'),(336107,'watch-mobile','.account-order-history .order_history_table th','font-size','16','','','.account-order-history'),(336108,'watch-mobile','.account-order-history .order_history_table th','text-transform','none','','','.account-order-history'),(336109,'watch-mobile','.account-order-history .order_history_table th','line-height','16','','','.account-order-history'),(336110,'watch-mobile','.account-order-history .order_history_table th','line_height_measure','px','','','.account-order-history'),(336111,'watch-mobile','.account-order-history .order_history_table th','padding-top','10','','','.account-order-history'),(336112,'watch-mobile','.account-order-history .order_history_table th','padding-right','10','','','.account-order-history'),(336113,'watch-mobile','.account-order-history .order_history_table th','padding-bottom','10','','','.account-order-history'),(336114,'watch-mobile','.account-order-history .order_history_table th','padding-left','10','','','.account-order-history'),(336115,'watch-mobile','.account-order-history .short-date','display','none','','','.account-order-history'),(336116,'watch-mobile','.account-order-history .view_link','color','$color-font-6','','','.account-order-history'),(336117,'watch-mobile','.account-order-history .view_link','position','relative','','','.account-order-history'),(336118,'watch-mobile','.account-order-history .view_link','text-decoration','underline','','','.account-order-history'),(336119,'watch-mobile','.account-order-history .view_link','white-space','nowrap','','','.account-order-history'),(336120,'watch-mobile','.account-order-history .view_link','padding-top','0','','','.account-order-history'),(336121,'watch-mobile','.account-order-history .view_link','padding-right','20','','','.account-order-history'),(336122,'watch-mobile','.account-order-history .view_link','padding-bottom','0','','','.account-order-history'),(336123,'watch-mobile','.account-order-history .view_link','padding-left','0','','','.account-order-history'),(336124,'watch-mobile','.account-order-history .view_link','font-size','18','4','','.account-order-history'),(336125,'watch-mobile','.account-order-history .view_link','position','absolute','4','','.account-order-history'),(336126,'watch-mobile','.account-order-history .view_link','top','4','4','','.account-order-history'),(336127,'watch-mobile','.account-order-history .view_link','vertical-align','middle','4','','.account-order-history'),(336128,'watch-mobile','.account-order-history .view_link','line-height','17','4','','.account-order-history'),(336129,'watch-mobile','.account-order-history .view_link','line_height_measure','px','4','','.account-order-history'),(336130,'watch-mobile','.account-order-history .view_link','content','\\e901','4','','.account-order-history'),(336131,'watch-mobile','.account-order-history .view_link','display','inline-block','4','','.account-order-history'),(336132,'watch-mobile','.account-order-history .view_link','font-family','$font-icons-2','4','','.account-order-history'),(336133,'watch-mobile','.account-order-history .orders-table .headings','display','none','317','','.account-order-history'),(336134,'watch-mobile','.account-order-history .orders-table .hidden','width','130','317','','.account-order-history'),(336135,'watch-mobile','.account-order-history .orders-table .hidden','display','inline-block','317','','.account-order-history'),(336136,'watch-mobile','.account-order-history .orders-table .item','position','relative','317','','.account-order-history'),(336137,'watch-mobile','.account-order-history .orders-table .item','display','block','317','','.account-order-history'),(336138,'watch-mobile','.account-order-history .orders-table .item','border-top-width','1','317','','.account-order-history'),(336139,'watch-mobile','.account-order-history .orders-table .item','border-left-width','1','317','','.account-order-history'),(336140,'watch-mobile','.account-order-history .orders-table .item','border-right-width','1','317','','.account-order-history'),(336141,'watch-mobile','.account-order-history .orders-table .item','border-bottom-width','1','317','','.account-order-history'),(336142,'watch-mobile','.account-order-history .orders-table .item','border-top-color','$border-color-10','317','','.account-order-history'),(336143,'watch-mobile','.account-order-history .orders-table .item','border-left-color','$border-color-10','317','','.account-order-history'),(336144,'watch-mobile','.account-order-history .orders-table .item','border-right-color','$border-color-10','317','','.account-order-history'),(336145,'watch-mobile','.account-order-history .orders-table .item','border-bottom-color','$border-color-10','317','','.account-order-history'),(336146,'watch-mobile','.account-order-history .orders-table .item','padding-bottom','60','317','','.account-order-history'),(336147,'watch-mobile','.account-order-history .orders-table .item','margin-bottom','10','317','','.account-order-history'),(336148,'watch-mobile','.account-order-history .orders-table .item td','display','block','317','','.account-order-history'),(336149,'watch-mobile','.account-order-history .orders-table .order-total','bottom','45','317','','.account-order-history'),(336150,'watch-mobile','.account-order-history .orders-table .order-total','position','absolute','317','','.account-order-history'),(336151,'watch-mobile','.account-order-history .orders-table .order-total','right','0','317','','.account-order-history'),(336152,'watch-mobile','.account-order-history .orders-table .status-name','bottom','7','317','','.account-order-history'),(336153,'watch-mobile','.account-order-history .orders-table .status-name','left','0','317','','.account-order-history'),(336154,'watch-mobile','.account-order-history .orders-table .status-name','position','absolute','317','','.account-order-history'),(336155,'watch-mobile','.account-order-history .orders-table .td-alignright','bottom','0','317','','.account-order-history'),(336156,'watch-mobile','.account-order-history .orders-table .td-alignright','height','45','317','','.account-order-history'),(336157,'watch-mobile','.account-order-history .orders-table .td-alignright','left','0','317','','.account-order-history'),(336158,'watch-mobile','.account-order-history .orders-table .td-alignright','position','absolute','317','','.account-order-history'),(336159,'watch-mobile','.account-order-history .orders-table .td-alignright','width','100','317','','.account-order-history'),(336160,'watch-mobile','.account-order-history .orders-table .td-alignright','width_measure','%','317','','.account-order-history'),(336161,'watch-mobile','.account-order-history .orders-table .td-alignright','line-height','35','317','','.account-order-history'),(336162,'watch-mobile','.account-order-history .orders-table .td-alignright','line_height_measure','px','317','','.account-order-history'),(336163,'watch-mobile','.account-order-history .orders-table .td-alignright','border-top-width','1','317','','.account-order-history'),(336164,'watch-mobile','.account-order-history .orders-table .td-alignright','padding-top','5','317','','.account-order-history'),(336165,'watch-mobile','.account-order-history .orders-table .td-alignright','padding-right','10','317','','.account-order-history'),(336166,'watch-mobile','.account-order-history .orders-table .td-alignright','padding-bottom','5','317','','.account-order-history'),(336167,'watch-mobile','.account-order-history .orders-table .td-alignright','padding-left','10','317','','.account-order-history'),(336168,'watch-mobile','.account-order-history .orders-table td','padding-top','5','317','','.account-order-history'),(336169,'watch-mobile','.account-order-history .orders-table td','padding-right','10','317','','.account-order-history'),(336170,'watch-mobile','.account-order-history .orders-table td','padding-bottom','5','317','','.account-order-history'),(336171,'watch-mobile','.account-order-history .orders-table td','padding-left','10','317','','.account-order-history'),(336172,'watch-mobile','.account-order-history .orders-table td.name','display','none','317','','.account-order-history'),(336173,'watch-mobile','.account-order-history .orders-table, .account-order-history .orders-table tbody','display','block','317','','.account-order-history'),(336174,'watch-mobile','.account-order-history-info .account_history_info.account_history_info_due','position','relative','','','.account-order-history-info'),(336175,'watch-mobile','.account-order-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.account-order-history-info'),(336176,'watch-mobile','.account-order-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-order-history-info'),(336177,'watch-mobile','.account-order-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-order-history-info'),(336178,'watch-mobile','.account-order-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-order-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-order-history-info'),(336179,'watch-mobile','.account-order-history-info .buttons','margin-top','20','','','.account-order-history-info'),(336180,'watch-mobile','.account-order-history-info .buttons','margin-right','0','','','.account-order-history-info'),(336181,'watch-mobile','.account-order-history-info .buttons','margin-bottom','20','','','.account-order-history-info'),(336182,'watch-mobile','.account-order-history-info .buttons','margin-left','0','','','.account-order-history-info'),(336183,'watch-mobile','.account-order-history-info .contentColumn','padding-top','10','','','.account-order-history-info'),(336184,'watch-mobile','.account-order-history-info .contentColumn','padding-right','10','','','.account-order-history-info'),(336185,'watch-mobile','.account-order-history-info .contentColumn','padding-bottom','10','','','.account-order-history-info'),(336186,'watch-mobile','.account-order-history-info .contentColumn','padding-left','40','','','.account-order-history-info'),(336187,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','font-size','18','','','.account-order-history-info'),(336188,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','position','relative','','','.account-order-history-info'),(336189,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','text-align','left','','','.account-order-history-info'),(336190,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','text-transform','uppercase','','','.account-order-history-info'),(336191,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','border-bottom-width','1','','','.account-order-history-info'),(336192,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','padding-top','5','','','.account-order-history-info'),(336193,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','padding-right','0','','','.account-order-history-info'),(336194,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','padding-bottom','5','','','.account-order-history-info'),(336195,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','padding-left','40','','','.account-order-history-info'),(336196,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','color','$color-font-6','3','','.account-order-history-info'),(336197,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','font-size','22','3','','.account-order-history-info'),(336198,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','font-weight','normal','3','','.account-order-history-info'),(336199,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','left','1','3','','.account-order-history-info'),(336200,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','position','absolute','3','','.account-order-history-info'),(336201,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','text-align','left','3','','.account-order-history-info'),(336202,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','top','2','3','','.account-order-history-info'),(336203,'watch-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','font-family','$font-icons-2','3','','.account-order-history-info'),(336204,'watch-mobile','.account-order-history-info .historyInfoColumn h2.title-delivery-address, .account-order-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.account-order-history-info'),(336205,'watch-mobile','.account-order-history-info .historyInfoColumn h2.title-delivery-address, .account-order-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-order-history-info'),(336206,'watch-mobile','.account-order-history-info .historyInfoColumn h2.title-payment','left','10','3','','.account-order-history-info'),(336207,'watch-mobile','.account-order-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-order-history-info'),(336208,'watch-mobile','.account-order-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-order-history-info'),(336209,'watch-mobile','.account-order-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-order-history-info'),(336210,'watch-mobile','.account-order-history-info .historyTotal table','border','none','','','.account-order-history-info'),(336211,'watch-mobile','.account-order-history-info .historyTotal table','float','right','','','.account-order-history-info'),(336212,'watch-mobile','.account-order-history-info .historyTotal table td','font-size','18','','','.account-order-history-info'),(336213,'watch-mobile','.account-order-history-info .historyTotal table td','text-align','right','','','.account-order-history-info'),(336214,'watch-mobile','.account-order-history-info .historyTotal table tr:last-child td','font-size','24','','','.account-order-history-info'),(336215,'watch-mobile','.account-order-history-info .historyTotal table tr:last-child td','font-weight','bold','','','.account-order-history-info'),(336216,'watch-mobile','.account-order-history-info .historyTotal td','border','none','','','.account-order-history-info'),(336217,'watch-mobile','.account-order-history-info .historyTotal td','padding-top','2','','','.account-order-history-info'),(336218,'watch-mobile','.account-order-history-info .historyTotal td','padding-right','5','','','.account-order-history-info'),(336219,'watch-mobile','.account-order-history-info .historyTotal td','padding-bottom','2','','','.account-order-history-info'),(336220,'watch-mobile','.account-order-history-info .historyTotal td','padding-left','5','','','.account-order-history-info'),(336221,'watch-mobile','.account-order-history-info .history_attr','font-size','14','','','.account-order-history-info'),(336222,'watch-mobile','.account-order-history-info .history_attr','display','table','','','.account-order-history-info'),(336223,'watch-mobile','.account-order-history-info .history_attr','padding-top','5','','','.account-order-history-info'),(336224,'watch-mobile','.account-order-history-info .history_attr div','display','table-row','','','.account-order-history-info'),(336225,'watch-mobile','.account-order-history-info .history_attr div strong, .account-order-history-info .history_attr div span','display','table-cell','','','.account-order-history-info'),(336226,'watch-mobile','.account-order-history-info .history_attr div strong, .account-order-history-info .history_attr div span','padding-right','10','','','.account-order-history-info'),(336227,'watch-mobile','.account-order-history-info .history_info','overflow','hidden','','','.account-order-history-info'),(336228,'watch-mobile','.account-order-history-info .history_info','margin-top','0','','','.account-order-history-info'),(336229,'watch-mobile','.account-order-history-info .history_info','margin-right','0','','','.account-order-history-info'),(336230,'watch-mobile','.account-order-history-info .history_info','margin-bottom','20','','','.account-order-history-info'),(336231,'watch-mobile','.account-order-history-info .history_info','margin-left','0','','','.account-order-history-info'),(336232,'watch-mobile','.account-order-history-info .history_info > div','float','left','','','.account-order-history-info'),(336233,'watch-mobile','.account-order-history-info .history_info > div','width','33.3','','','.account-order-history-info'),(336234,'watch-mobile','.account-order-history-info .history_info > div','width_measure','%','','','.account-order-history-info'),(336235,'watch-mobile','.account-order-history-info .history_info > div + div','padding-top','0','','','.account-order-history-info'),(336236,'watch-mobile','.account-order-history-info .history_info > div + div','padding-right','0','','','.account-order-history-info'),(336237,'watch-mobile','.account-order-history-info .history_info > div + div','padding-bottom','0','','','.account-order-history-info'),(336238,'watch-mobile','.account-order-history-info .history_info > div + div','padding-left','2','','','.account-order-history-info'),(336239,'watch-mobile','.account-order-history-info .history_info > div + div','padding_left_measure','%','','','.account-order-history-info'),(336240,'watch-mobile','.account-order-history-info .not_fully_paid_td','color','$attention-color','','','.account-order-history-info'),(336241,'watch-mobile','.account-order-history-info .not_fully_paid_td','font-size','30','','','.account-order-history-info'),(336242,'watch-mobile','.account-order-history-info .not_fully_paid_td','font-weight','700','','','.account-order-history-info'),(336243,'watch-mobile','.account-order-history-info .not_fully_paid_td','left','15','','','.account-order-history-info'),(336244,'watch-mobile','.account-order-history-info .not_fully_paid_td','position','absolute','','','.account-order-history-info'),(336245,'watch-mobile','.account-order-history-info .not_fully_paid_td','text-transform','uppercase','','','.account-order-history-info'),(336246,'watch-mobile','.account-order-history-info .not_fully_paid_td','top','19','','','.account-order-history-info'),(336247,'watch-mobile','.account-order-history-info .not_fully_paid_td','width','300','','','.account-order-history-info'),(336248,'watch-mobile','.account-order-history-info .popup-tracking-number','text-align','center','','','.account-order-history-info'),(336249,'watch-mobile','.account-order-history-info .popup-tracking-number','padding-top','10','','','.account-order-history-info'),(336250,'watch-mobile','.account-order-history-info .popup-tracking-number','padding-right','10','','','.account-order-history-info'),(336251,'watch-mobile','.account-order-history-info .popup-tracking-number','padding-bottom','10','','','.account-order-history-info'),(336252,'watch-mobile','.account-order-history-info .popup-tracking-number','padding-left','10','','','.account-order-history-info'),(336253,'watch-mobile','.account-order-history-info .popup-tracking-number a','display','block','','','.account-order-history-info'),(336254,'watch-mobile','.account-order-history-info .popup-tracking-number-link','font-size','18','','','.account-order-history-info'),(336255,'watch-mobile','.account-order-history-info .popup-tracking-number-link','font-weight','600','','','.account-order-history-info'),(336256,'watch-mobile','.account-order-history-info .popup-tracking-number-link','display','block','','','.account-order-history-info'),(336257,'watch-mobile','.account-order-history-info .popup-tracking-number-link','margin-top','10','','','.account-order-history-info'),(336258,'watch-mobile','.account-order-history-info .tableForm th','text-align','left','','','.account-order-history-info'),(336259,'watch-mobile','.account-order-history-info .trackings-nambers','text-align','center','','','.account-order-history-info'),(336260,'watch-mobile','.account-order-history-info .trackings-nambers-label','font-size','20','','','.account-order-history-info'),(336261,'watch-mobile','.account-order-history-info .trackings-nambers-label','font-weight','600','','','.account-order-history-info'),(336262,'watch-mobile','.account-order-history-info .history_info > div','width','100','291','','.account-order-history-info'),(336263,'watch-mobile','.account-order-history-info .history_info > div','width_measure','%','291','','.account-order-history-info'),(336264,'watch-mobile','.account-order-history-info .history_info > div','padding-top','0','291','','.account-order-history-info'),(336265,'watch-mobile','.account-order-history-info .history_info > div','padding-right','0','291','','.account-order-history-info'),(336266,'watch-mobile','.account-order-history-info .history_info > div','padding-bottom','0','291','','.account-order-history-info'),(336267,'watch-mobile','.account-order-history-info .history_info > div','padding-left','0','291','','.account-order-history-info'),(336268,'watch-mobile','.account-order-history-info .history_info > div','margin-top','0','291','','.account-order-history-info'),(336269,'watch-mobile','.account-order-history-info .history_info > div','margin-right','0','291','','.account-order-history-info'),(336270,'watch-mobile','.account-order-history-info .history_info > div','margin-bottom','12','291','','.account-order-history-info'),(336271,'watch-mobile','.account-order-history-info .history_info > div','margin-left','0','291','','.account-order-history-info'),(336272,'watch-mobile','.account-order-history-info .history_info > div + div','padding-top','0','291','','.account-order-history-info'),(336273,'watch-mobile','.account-order-history-info .history_info > div + div','padding-right','0','291','','.account-order-history-info'),(336274,'watch-mobile','.account-order-history-info .history_info > div + div','padding-bottom','0','291','','.account-order-history-info'),(336275,'watch-mobile','.account-order-history-info .history_info > div + div','padding-left','0','291','','.account-order-history-info'),(336276,'watch-mobile','.account-order-pay .account_history_info.account_history_info_due','position','relative','','','.account-order-pay'),(336277,'watch-mobile','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.account-order-pay'),(336278,'watch-mobile','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-order-pay'),(336279,'watch-mobile','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-order-pay'),(336280,'watch-mobile','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-order-pay'),(336281,'watch-mobile','.account-order-pay .buttons','margin-top','20','','','.account-order-pay'),(336282,'watch-mobile','.account-order-pay .buttons','margin-right','0','','','.account-order-pay'),(336283,'watch-mobile','.account-order-pay .buttons','margin-bottom','20','','','.account-order-pay'),(336284,'watch-mobile','.account-order-pay .buttons','margin-left','0','','','.account-order-pay'),(336285,'watch-mobile','.account-order-pay .contentColumn','padding-top','10','','','.account-order-pay'),(336286,'watch-mobile','.account-order-pay .contentColumn','padding-right','10','','','.account-order-pay'),(336287,'watch-mobile','.account-order-pay .contentColumn','padding-bottom','10','','','.account-order-pay'),(336288,'watch-mobile','.account-order-pay .contentColumn','padding-left','40','','','.account-order-pay'),(336289,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-size','18','','','.account-order-pay'),(336290,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','position','relative','','','.account-order-pay'),(336291,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-align','left','','','.account-order-pay'),(336292,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-transform','uppercase','','','.account-order-pay'),(336293,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','border-bottom-width','1','','','.account-order-pay'),(336294,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-top','5','','','.account-order-pay'),(336295,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-right','0','','','.account-order-pay'),(336296,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-bottom','5','','','.account-order-pay'),(336297,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-left','40','','','.account-order-pay'),(336298,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','color','$color-font-6','3','','.account-order-pay'),(336299,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-size','22','3','','.account-order-pay'),(336300,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-weight','normal','3','','.account-order-pay'),(336301,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','left','1','3','','.account-order-pay'),(336302,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','position','absolute','3','','.account-order-pay'),(336303,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-align','left','3','','.account-order-pay'),(336304,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','top','2','3','','.account-order-pay'),(336305,'watch-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-family','$font-icons-2','3','','.account-order-pay'),(336306,'watch-mobile','.account-order-pay .historyInfoColumn h2.title-delivery-address, .account-order-pay .historyInfoColumn h2.title-billing-address','left','10','3','','.account-order-pay'),(336307,'watch-mobile','.account-order-pay .historyInfoColumn h2.title-delivery-address, .account-order-pay .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-order-pay'),(336308,'watch-mobile','.account-order-pay .historyInfoColumn h2.title-payment','left','10','3','','.account-order-pay'),(336309,'watch-mobile','.account-order-pay .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-order-pay'),(336310,'watch-mobile','.account-order-pay .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-order-pay'),(336311,'watch-mobile','.account-order-pay .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-order-pay'),(336312,'watch-mobile','.account-order-pay .historyTotal table','border','none','','','.account-order-pay'),(336313,'watch-mobile','.account-order-pay .historyTotal table','float','right','','','.account-order-pay'),(336314,'watch-mobile','.account-order-pay .historyTotal table td','font-size','18','','','.account-order-pay'),(336315,'watch-mobile','.account-order-pay .historyTotal table td','text-align','right','','','.account-order-pay'),(336316,'watch-mobile','.account-order-pay .historyTotal table tr:last-child td','font-size','24','','','.account-order-pay'),(336317,'watch-mobile','.account-order-pay .historyTotal table tr:last-child td','font-weight','bold','','','.account-order-pay'),(336318,'watch-mobile','.account-order-pay .historyTotal td','border','none','','','.account-order-pay'),(336319,'watch-mobile','.account-order-pay .historyTotal td','padding-top','2','','','.account-order-pay'),(336320,'watch-mobile','.account-order-pay .historyTotal td','padding-right','5','','','.account-order-pay'),(336321,'watch-mobile','.account-order-pay .historyTotal td','padding-bottom','2','','','.account-order-pay'),(336322,'watch-mobile','.account-order-pay .historyTotal td','padding-left','5','','','.account-order-pay'),(336323,'watch-mobile','.account-order-pay .history_attr','font-size','14','','','.account-order-pay'),(336324,'watch-mobile','.account-order-pay .history_attr','display','table','','','.account-order-pay'),(336325,'watch-mobile','.account-order-pay .history_attr','padding-top','5','','','.account-order-pay'),(336326,'watch-mobile','.account-order-pay .history_attr div','display','table-row','','','.account-order-pay'),(336327,'watch-mobile','.account-order-pay .history_attr div strong, .account-order-pay .history_attr div span','display','table-cell','','','.account-order-pay'),(336328,'watch-mobile','.account-order-pay .history_attr div strong, .account-order-pay .history_attr div span','padding-right','10','','','.account-order-pay'),(336329,'watch-mobile','.account-order-pay .history_info','overflow','hidden','','','.account-order-pay'),(336330,'watch-mobile','.account-order-pay .history_info','margin-top','0','','','.account-order-pay'),(336331,'watch-mobile','.account-order-pay .history_info','margin-right','0','','','.account-order-pay'),(336332,'watch-mobile','.account-order-pay .history_info','margin-bottom','20','','','.account-order-pay'),(336333,'watch-mobile','.account-order-pay .history_info','margin-left','0','','','.account-order-pay'),(336334,'watch-mobile','.account-order-pay .history_info > div','float','left','','','.account-order-pay'),(336335,'watch-mobile','.account-order-pay .history_info > div','width','33.3','','','.account-order-pay'),(336336,'watch-mobile','.account-order-pay .history_info > div','width_measure','%','','','.account-order-pay'),(336337,'watch-mobile','.account-order-pay .history_info > div + div','padding-top','0','','','.account-order-pay'),(336338,'watch-mobile','.account-order-pay .history_info > div + div','padding-right','0','','','.account-order-pay'),(336339,'watch-mobile','.account-order-pay .history_info > div + div','padding-bottom','0','','','.account-order-pay'),(336340,'watch-mobile','.account-order-pay .history_info > div + div','padding-left','2','','','.account-order-pay'),(336341,'watch-mobile','.account-order-pay .history_info > div + div','padding_left_measure','%','','','.account-order-pay'),(336342,'watch-mobile','.account-order-pay .not_fully_paid_td','color','$attention-color','','','.account-order-pay'),(336343,'watch-mobile','.account-order-pay .not_fully_paid_td','font-size','30','','','.account-order-pay'),(336344,'watch-mobile','.account-order-pay .not_fully_paid_td','font-weight','700','','','.account-order-pay'),(336345,'watch-mobile','.account-order-pay .not_fully_paid_td','left','15','','','.account-order-pay'),(336346,'watch-mobile','.account-order-pay .not_fully_paid_td','position','absolute','','','.account-order-pay'),(336347,'watch-mobile','.account-order-pay .not_fully_paid_td','text-transform','uppercase','','','.account-order-pay'),(336348,'watch-mobile','.account-order-pay .not_fully_paid_td','top','19','','','.account-order-pay'),(336349,'watch-mobile','.account-order-pay .not_fully_paid_td','width','300','','','.account-order-pay'),(336350,'watch-mobile','.account-order-pay .tableForm th','text-align','left','','','.account-order-pay'),(336351,'watch-mobile','.account-order-pay .history_info > div','width','100','291','','.account-order-pay'),(336352,'watch-mobile','.account-order-pay .history_info > div','width_measure','%','291','','.account-order-pay'),(336353,'watch-mobile','.account-order-pay .history_info > div','padding-top','0','291','','.account-order-pay'),(336354,'watch-mobile','.account-order-pay .history_info > div','padding-right','0','291','','.account-order-pay'),(336355,'watch-mobile','.account-order-pay .history_info > div','padding-bottom','0','291','','.account-order-pay'),(336356,'watch-mobile','.account-order-pay .history_info > div','padding-left','0','291','','.account-order-pay'),(336357,'watch-mobile','.account-order-pay .history_info > div','margin-top','0','291','','.account-order-pay'),(336358,'watch-mobile','.account-order-pay .history_info > div','margin-right','0','291','','.account-order-pay'),(336359,'watch-mobile','.account-order-pay .history_info > div','margin-bottom','12','291','','.account-order-pay'),(336360,'watch-mobile','.account-order-pay .history_info > div','margin-left','0','291','','.account-order-pay'),(336361,'watch-mobile','.account-order-pay .history_info > div + div','padding-top','0','291','','.account-order-pay'),(336362,'watch-mobile','.account-order-pay .history_info > div + div','padding-right','0','291','','.account-order-pay'),(336363,'watch-mobile','.account-order-pay .history_info > div + div','padding-bottom','0','291','','.account-order-pay'),(336364,'watch-mobile','.account-order-pay .history_info > div + div','padding-left','0','291','','.account-order-pay'),(336365,'watch-mobile','.account-password-wrap .buttonedit','margin-top','-40','','','.account-password-wrap'),(336366,'watch-mobile','.account-password-wrap .buttonedit','margin-right','0','','','.account-password-wrap'),(336367,'watch-mobile','.account-password-wrap .buttonedit','margin-bottom','0','','','.account-password-wrap'),(336368,'watch-mobile','.account-password-wrap .buttonedit','margin-left','0','','','.account-password-wrap'),(336369,'watch-mobile','.account-password-wrap .buttons','margin-top','-70','','','.account-password-wrap'),(336370,'watch-mobile','.account-password-wrap .buttons','margin-bottom','20','','','.account-password-wrap'),(336371,'watch-mobile','.account-samples .buttonBox','margin-top','15','','','.account-samples'),(336372,'watch-mobile','.account-samples .buttonBox','margin-right','0','','','.account-samples'),(336373,'watch-mobile','.account-samples .buttonBox','margin-bottom','15','','','.account-samples'),(336374,'watch-mobile','.account-samples .buttonBox','margin-left','0','','','.account-samples'),(336375,'watch-mobile','.account-samples .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.account-samples'),(336376,'watch-mobile','.account-samples .moduleRowDue td','color','$color-font-2','','','.account-samples'),(336377,'watch-mobile','.account-samples .moduleRowDue td','position','relative','','','.account-samples'),(336378,'watch-mobile','.account-samples .not_fully_paid_td','color','$attention-color','','','.account-samples'),(336379,'watch-mobile','.account-samples .not_fully_paid_td','font-size','30','','','.account-samples'),(336380,'watch-mobile','.account-samples .not_fully_paid_td','font-weight','700','','','.account-samples'),(336381,'watch-mobile','.account-samples .not_fully_paid_td','left','15','','','.account-samples'),(336382,'watch-mobile','.account-samples .not_fully_paid_td','position','absolute','','','.account-samples'),(336383,'watch-mobile','.account-samples .not_fully_paid_td','text-transform','uppercase','','','.account-samples'),(336384,'watch-mobile','.account-samples .not_fully_paid_td','top','19','','','.account-samples'),(336385,'watch-mobile','.account-samples .not_fully_paid_td','width','300','','','.account-samples'),(336386,'watch-mobile','.account-samples .orders-table','border-top','none','','','.account-samples'),(336387,'watch-mobile','.account-samples .orders-table .headings','display','none','','','.account-samples'),(336388,'watch-mobile','.account-samples .orders-table .hidden','width','130','','','.account-samples'),(336389,'watch-mobile','.account-samples .orders-table .hidden','display','inline-block','','','.account-samples'),(336390,'watch-mobile','.account-samples .orders-table .item','position','relative','','','.account-samples'),(336391,'watch-mobile','.account-samples .orders-table .item','display','block','','','.account-samples'),(336392,'watch-mobile','.account-samples .orders-table .item','border-top-width','1','','','.account-samples'),(336393,'watch-mobile','.account-samples .orders-table .item','border-left-width','1','','','.account-samples'),(336394,'watch-mobile','.account-samples .orders-table .item','border-right-width','1','','','.account-samples'),(336395,'watch-mobile','.account-samples .orders-table .item','border-bottom-width','1','','','.account-samples'),(336396,'watch-mobile','.account-samples .orders-table .item','border-top-color','$border-color-1','','','.account-samples'),(336397,'watch-mobile','.account-samples .orders-table .item','border-left-color','$border-color-1','','','.account-samples'),(336398,'watch-mobile','.account-samples .orders-table .item','border-right-color','$border-color-1','','','.account-samples'),(336399,'watch-mobile','.account-samples .orders-table .item','border-bottom-color','$border-color-1','','','.account-samples'),(336400,'watch-mobile','.account-samples .orders-table .item','padding-bottom','60','','','.account-samples'),(336401,'watch-mobile','.account-samples .orders-table .item','margin-bottom','10','','','.account-samples'),(336402,'watch-mobile','.account-samples .orders-table .item td','display','block','','','.account-samples'),(336403,'watch-mobile','.account-samples .orders-table .order-total','bottom','45','','','.account-samples'),(336404,'watch-mobile','.account-samples .orders-table .order-total','position','absolute','','','.account-samples'),(336405,'watch-mobile','.account-samples .orders-table .order-total','right','0','','','.account-samples'),(336406,'watch-mobile','.account-samples .orders-table .status-name','bottom','7','','','.account-samples'),(336407,'watch-mobile','.account-samples .orders-table .status-name','left','0','','','.account-samples'),(336408,'watch-mobile','.account-samples .orders-table .status-name','position','absolute','','','.account-samples'),(336409,'watch-mobile','.account-samples .orders-table .td-alignright','bottom','0','','','.account-samples'),(336410,'watch-mobile','.account-samples .orders-table .td-alignright','height','45','','','.account-samples'),(336411,'watch-mobile','.account-samples .orders-table .td-alignright','left','0','','','.account-samples'),(336412,'watch-mobile','.account-samples .orders-table .td-alignright','position','absolute','','','.account-samples'),(336413,'watch-mobile','.account-samples .orders-table .td-alignright','width','100','','','.account-samples'),(336414,'watch-mobile','.account-samples .orders-table .td-alignright','width_measure','%','','','.account-samples'),(336415,'watch-mobile','.account-samples .orders-table .td-alignright','line-height','35','','','.account-samples'),(336416,'watch-mobile','.account-samples .orders-table .td-alignright','line_height_measure','px','','','.account-samples'),(336417,'watch-mobile','.account-samples .orders-table .td-alignright','border-top-width','1','','','.account-samples'),(336418,'watch-mobile','.account-samples .orders-table .td-alignright','padding-top','5','','','.account-samples'),(336419,'watch-mobile','.account-samples .orders-table .td-alignright','padding-right','10','','','.account-samples'),(336420,'watch-mobile','.account-samples .orders-table .td-alignright','padding-bottom','5','','','.account-samples'),(336421,'watch-mobile','.account-samples .orders-table .td-alignright','padding-left','10','','','.account-samples'),(336422,'watch-mobile','.account-samples .orders-table a, .account-samples .order-info a','text-decoration','none','1','','.account-samples'),(336423,'watch-mobile','.account-samples .orders-table td','padding-top','5','','','.account-samples'),(336424,'watch-mobile','.account-samples .orders-table td','padding-right','10','','','.account-samples'),(336425,'watch-mobile','.account-samples .orders-table td','padding-bottom','5','','','.account-samples'),(336426,'watch-mobile','.account-samples .orders-table td','padding-left','10','','','.account-samples'),(336427,'watch-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','font-size','16','','','.account-samples'),(336428,'watch-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','line-height','20','','','.account-samples'),(336429,'watch-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','line_height_measure','px','','','.account-samples'),(336430,'watch-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-top','10','','','.account-samples'),(336431,'watch-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-right','10','','','.account-samples'),(336432,'watch-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-bottom','10','','','.account-samples'),(336433,'watch-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-left','10','','','.account-samples'),(336434,'watch-mobile','.account-samples .orders-table td.name','display','none','','','.account-samples'),(336435,'watch-mobile','.account-samples .orders-table td.td-alignright','text-align','right','','','.account-samples'),(336436,'watch-mobile','.account-samples .orders-table th','background-color','$background-6','','','.account-samples'),(336437,'watch-mobile','.account-samples .orders-table th','text-align','left','','','.account-samples'),(336438,'watch-mobile','.account-samples .orders-table th','font-family','$font-1','','','.account-samples'),(336439,'watch-mobile','.account-samples .orders-table th','padding-top','2','','','.account-samples'),(336440,'watch-mobile','.account-samples .orders-table th','padding-right','10','','','.account-samples'),(336441,'watch-mobile','.account-samples .orders-table th','padding-bottom','2','','','.account-samples'),(336442,'watch-mobile','.account-samples .orders-table th','padding-left','10','','','.account-samples'),(336443,'watch-mobile','.account-samples .orders-table tr:first-child','border','none','','','.account-samples'),(336444,'watch-mobile','.account-samples .orders-table, .account-samples .orders-table tbody','display','block','','','.account-samples'),(336445,'watch-mobile','.account-samples .order_history_table h2','font-size','24','','','.account-samples'),(336446,'watch-mobile','.account-samples .order_history_table h2','font-weight','normal','','','.account-samples'),(336447,'watch-mobile','.account-samples .order_history_table h2','text-transform','uppercase','','','.account-samples'),(336448,'watch-mobile','.account-samples .order_history_table h2','margin-top','0','','','.account-samples'),(336449,'watch-mobile','.account-samples .order_history_table h2','margin-right','0','','','.account-samples'),(336450,'watch-mobile','.account-samples .order_history_table h2','margin-bottom','8','','','.account-samples'),(336451,'watch-mobile','.account-samples .order_history_table h2','margin-left','0','','','.account-samples'),(336452,'watch-mobile','.account-samples .order_history_table th','background-color','$background-6','','','.account-samples'),(336453,'watch-mobile','.account-samples .order_history_table th','font-size','16','','','.account-samples'),(336454,'watch-mobile','.account-samples .order_history_table th','text-transform','none','','','.account-samples'),(336455,'watch-mobile','.account-samples .order_history_table th','line-height','16','','','.account-samples'),(336456,'watch-mobile','.account-samples .order_history_table th','line_height_measure','px','','','.account-samples'),(336457,'watch-mobile','.account-samples .order_history_table th','padding-top','10','','','.account-samples'),(336458,'watch-mobile','.account-samples .order_history_table th','padding-right','10','','','.account-samples'),(336459,'watch-mobile','.account-samples .order_history_table th','padding-bottom','10','','','.account-samples'),(336460,'watch-mobile','.account-samples .order_history_table th','padding-left','10','','','.account-samples'),(336461,'watch-mobile','.account-samples .short-date','display','none','','','.account-samples'),(336462,'watch-mobile','.account-samples .view_link','color','$color-font-6','','','.account-samples'),(336463,'watch-mobile','.account-samples .view_link','position','relative','','','.account-samples'),(336464,'watch-mobile','.account-samples .view_link','text-decoration','underline','','','.account-samples'),(336465,'watch-mobile','.account-samples .view_link','white-space','nowrap','','','.account-samples'),(336466,'watch-mobile','.account-samples .view_link','padding-top','0','','','.account-samples'),(336467,'watch-mobile','.account-samples .view_link','padding-right','20','','','.account-samples'),(336468,'watch-mobile','.account-samples .view_link','padding-bottom','0','','','.account-samples'),(336469,'watch-mobile','.account-samples .view_link','padding-left','0','','','.account-samples'),(336470,'watch-mobile','.account-samples .view_link','font-size','18','4','','.account-samples'),(336471,'watch-mobile','.account-samples .view_link','position','absolute','4','','.account-samples'),(336472,'watch-mobile','.account-samples .view_link','top','4','4','','.account-samples'),(336473,'watch-mobile','.account-samples .view_link','vertical-align','middle','4','','.account-samples'),(336474,'watch-mobile','.account-samples .view_link','line-height','17','4','','.account-samples'),(336475,'watch-mobile','.account-samples .view_link','line_height_measure','px','4','','.account-samples'),(336476,'watch-mobile','.account-samples .view_link','content','\\e901','4','','.account-samples'),(336477,'watch-mobile','.account-samples .view_link','display','inline-block','4','','.account-samples'),(336478,'watch-mobile','.account-samples .view_link','font-family','trueloaded','4','','.account-samples'),(336479,'watch-mobile','.account-sample-info .account_history_info.account_history_info_due','position','relative','','','.account-sample-info'),(336480,'watch-mobile','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.account-sample-info'),(336481,'watch-mobile','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-sample-info'),(336482,'watch-mobile','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-sample-info'),(336483,'watch-mobile','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-sample-info'),(336484,'watch-mobile','.account-sample-info .buttons','margin-top','20','','','.account-sample-info'),(336485,'watch-mobile','.account-sample-info .buttons','margin-right','0','','','.account-sample-info'),(336486,'watch-mobile','.account-sample-info .buttons','margin-bottom','20','','','.account-sample-info'),(336487,'watch-mobile','.account-sample-info .buttons','margin-left','0','','','.account-sample-info'),(336488,'watch-mobile','.account-sample-info .contentColumn','padding-top','10','','','.account-sample-info'),(336489,'watch-mobile','.account-sample-info .contentColumn','padding-right','10','','','.account-sample-info'),(336490,'watch-mobile','.account-sample-info .contentColumn','padding-bottom','10','','','.account-sample-info'),(336491,'watch-mobile','.account-sample-info .contentColumn','padding-left','40','','','.account-sample-info'),(336492,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-size','18','','','.account-sample-info'),(336493,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','position','relative','','','.account-sample-info'),(336494,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-align','left','','','.account-sample-info'),(336495,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-transform','uppercase','','','.account-sample-info'),(336496,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','border-bottom-width','1','','','.account-sample-info'),(336497,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-top','5','','','.account-sample-info'),(336498,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-right','0','','','.account-sample-info'),(336499,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-bottom','5','','','.account-sample-info'),(336500,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-left','40','','','.account-sample-info'),(336501,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','color','$color-font-6','3','','.account-sample-info'),(336502,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-size','22','3','','.account-sample-info'),(336503,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-weight','normal','3','','.account-sample-info'),(336504,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','left','1','3','','.account-sample-info'),(336505,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','position','absolute','3','','.account-sample-info'),(336506,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-align','left','3','','.account-sample-info'),(336507,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','top','2','3','','.account-sample-info'),(336508,'watch-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-family','trueloaded','3','','.account-sample-info'),(336509,'watch-mobile','.account-sample-info .historyInfoColumn h2.title-delivery-address, .account-sample-info .historyInfoColumn h2.title-billing-address','left','10','3','','.account-sample-info'),(336510,'watch-mobile','.account-sample-info .historyInfoColumn h2.title-delivery-address, .account-sample-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-sample-info'),(336511,'watch-mobile','.account-sample-info .historyInfoColumn h2.title-payment','left','10','3','','.account-sample-info'),(336512,'watch-mobile','.account-sample-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-sample-info'),(336513,'watch-mobile','.account-sample-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-sample-info'),(336514,'watch-mobile','.account-sample-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-sample-info'),(336515,'watch-mobile','.account-sample-info .history_attr','font-size','14','','','.account-sample-info'),(336516,'watch-mobile','.account-sample-info .history_attr','display','table','','','.account-sample-info'),(336517,'watch-mobile','.account-sample-info .history_attr','padding-top','5','','','.account-sample-info'),(336518,'watch-mobile','.account-sample-info .history_attr div','display','table-row','','','.account-sample-info'),(336519,'watch-mobile','.account-sample-info .history_attr div strong, .account-sample-info .history_attr div span','display','table-cell','','','.account-sample-info'),(336520,'watch-mobile','.account-sample-info .history_attr div strong, .account-sample-info .history_attr div span','padding-right','10','','','.account-sample-info'),(336521,'watch-mobile','.account-sample-info .history_info','overflow','hidden','','','.account-sample-info'),(336522,'watch-mobile','.account-sample-info .history_info','margin-top','0','','','.account-sample-info'),(336523,'watch-mobile','.account-sample-info .history_info','margin-right','0','','','.account-sample-info'),(336524,'watch-mobile','.account-sample-info .history_info','margin-bottom','20','','','.account-sample-info'),(336525,'watch-mobile','.account-sample-info .history_info','margin-left','0','','','.account-sample-info'),(336526,'watch-mobile','.account-sample-info .history_info > div','float','left','','','.account-sample-info'),(336527,'watch-mobile','.account-sample-info .history_info > div','width','33.3','','','.account-sample-info'),(336528,'watch-mobile','.account-sample-info .history_info > div','width_measure','%','','','.account-sample-info'),(336529,'watch-mobile','.account-sample-info .history_info > div','padding-top','0','','','.account-sample-info'),(336530,'watch-mobile','.account-sample-info .history_info > div','padding-right','0','','','.account-sample-info'),(336531,'watch-mobile','.account-sample-info .history_info > div','padding-bottom','0','','','.account-sample-info'),(336532,'watch-mobile','.account-sample-info .history_info > div','padding-left','0','','','.account-sample-info'),(336533,'watch-mobile','.account-sample-info .history_info > div','margin-top','0','','','.account-sample-info'),(336534,'watch-mobile','.account-sample-info .history_info > div','margin-right','0','','','.account-sample-info'),(336535,'watch-mobile','.account-sample-info .history_info > div','margin-bottom','12','','','.account-sample-info'),(336536,'watch-mobile','.account-sample-info .history_info > div','margin-left','0','','','.account-sample-info'),(336537,'watch-mobile','.account-sample-info .history_info > div + div','padding-top','0','','','.account-sample-info'),(336538,'watch-mobile','.account-sample-info .history_info > div + div','padding-right','0','','','.account-sample-info'),(336539,'watch-mobile','.account-sample-info .history_info > div + div','padding-bottom','0','','','.account-sample-info'),(336540,'watch-mobile','.account-sample-info .history_info > div + div','padding-left','2','','','.account-sample-info'),(336541,'watch-mobile','.account-sample-info .history_info > div + div','padding_left_measure','%','','','.account-sample-info'),(336542,'watch-mobile','.account-sample-info .not_fully_paid_td','color','$attention-color','','','.account-sample-info'),(336543,'watch-mobile','.account-sample-info .not_fully_paid_td','font-size','30','','','.account-sample-info'),(336544,'watch-mobile','.account-sample-info .not_fully_paid_td','font-weight','700','','','.account-sample-info'),(336545,'watch-mobile','.account-sample-info .not_fully_paid_td','left','15','','','.account-sample-info'),(336546,'watch-mobile','.account-sample-info .not_fully_paid_td','position','absolute','','','.account-sample-info'),(336547,'watch-mobile','.account-sample-info .not_fully_paid_td','text-transform','uppercase','','','.account-sample-info'),(336548,'watch-mobile','.account-sample-info .not_fully_paid_td','top','19','','','.account-sample-info'),(336549,'watch-mobile','.account-sample-info .not_fully_paid_td','width','300','','','.account-sample-info'),(336550,'watch-mobile','.account-sample-info .popup-tracking-number','text-align','center','','','.account-sample-info'),(336551,'watch-mobile','.account-sample-info .popup-tracking-number','padding-top','10','','','.account-sample-info'),(336552,'watch-mobile','.account-sample-info .popup-tracking-number','padding-right','10','','','.account-sample-info'),(336553,'watch-mobile','.account-sample-info .popup-tracking-number','padding-bottom','10','','','.account-sample-info'),(336554,'watch-mobile','.account-sample-info .popup-tracking-number','padding-left','10','','','.account-sample-info'),(336555,'watch-mobile','.account-sample-info .popup-tracking-number a','display','block','','','.account-sample-info'),(336556,'watch-mobile','.account-sample-info .popup-tracking-number-link','font-size','18','','','.account-sample-info'),(336557,'watch-mobile','.account-sample-info .popup-tracking-number-link','font-weight','600','','','.account-sample-info'),(336558,'watch-mobile','.account-sample-info .popup-tracking-number-link','display','block','','','.account-sample-info'),(336559,'watch-mobile','.account-sample-info .popup-tracking-number-link','margin-top','10','','','.account-sample-info'),(336560,'watch-mobile','.account-sample-info .tableForm th','text-align','left','','','.account-sample-info'),(336561,'watch-mobile','.account-sample-info .trackings-nambers','text-align','center','','','.account-sample-info'),(336562,'watch-mobile','.account-sample-info .trackings-nambers-label','font-size','20','','','.account-sample-info'),(336563,'watch-mobile','.account-sample-info .trackings-nambers-label','font-weight','600','','','.account-sample-info'),(336564,'watch-mobile','.catalog-product-wrap .next-product','right','0','','','.catalog-product-wrap'),(336565,'watch-mobile','.catalog-product-wrap .next-product','border-left-width','1','','','.catalog-product-wrap'),(336566,'watch-mobile','.catalog-product-wrap .next-product','padding-top','20','','','.catalog-product-wrap'),(336567,'watch-mobile','.catalog-product-wrap .next-product','padding-right','50','','','.catalog-product-wrap'),(336568,'watch-mobile','.catalog-product-wrap .next-product','padding-bottom','20','','','.catalog-product-wrap'),(336569,'watch-mobile','.catalog-product-wrap .next-product','padding-left','20','','','.catalog-product-wrap'),(336570,'watch-mobile','.catalog-product-wrap .next-product .pn-image','right','20','3','','.catalog-product-wrap'),(336571,'watch-mobile','.catalog-product-wrap .next-product .pn-image','content','\\f054','3','','.catalog-product-wrap'),(336572,'watch-mobile','.catalog-product-wrap .next-product .pn-image','padding-left','2','3','','.catalog-product-wrap'),(336573,'watch-mobile','.catalog-product-wrap .pn-direction','color','$color-font-6','','','.catalog-product-wrap'),(336574,'watch-mobile','.catalog-product-wrap .pn-direction','font-size','14','','','.catalog-product-wrap'),(336575,'watch-mobile','.catalog-product-wrap .pn-direction','font-weight','600','','','.catalog-product-wrap'),(336576,'watch-mobile','.catalog-product-wrap .pn-direction','text-transform','uppercase','','','.catalog-product-wrap'),(336577,'watch-mobile','.catalog-product-wrap .pn-direction','line-height','1.2','','','.catalog-product-wrap'),(336578,'watch-mobile','.catalog-product-wrap .pn-direction','font-family','$font-1','','','.catalog-product-wrap'),(336579,'watch-mobile','.catalog-product-wrap .pn-direction','padding-top','0','','','.catalog-product-wrap'),(336580,'watch-mobile','.catalog-product-wrap .pn-direction','padding-right','4','','','.catalog-product-wrap'),(336581,'watch-mobile','.catalog-product-wrap .pn-direction','padding-bottom','0','','','.catalog-product-wrap'),(336582,'watch-mobile','.catalog-product-wrap .pn-direction','padding-left','4','','','.catalog-product-wrap'),(336583,'watch-mobile','.catalog-product-wrap .pn-direction','margin-bottom','15','','','.catalog-product-wrap'),(336584,'watch-mobile','.catalog-product-wrap .pn-image','color','$color-font-2','3','','.catalog-product-wrap'),(336585,'watch-mobile','.catalog-product-wrap .pn-image','font-size','14','3','','.catalog-product-wrap'),(336586,'watch-mobile','.catalog-product-wrap .pn-image','height','24','3','','.catalog-product-wrap'),(336587,'watch-mobile','.catalog-product-wrap .pn-image','position','absolute','3','','.catalog-product-wrap'),(336588,'watch-mobile','.catalog-product-wrap .pn-image','top','120','3','','.catalog-product-wrap'),(336589,'watch-mobile','.catalog-product-wrap .pn-image','width','24','3','','.catalog-product-wrap'),(336590,'watch-mobile','.catalog-product-wrap .pn-image','line-height','24','3','','.catalog-product-wrap'),(336591,'watch-mobile','.catalog-product-wrap .pn-image','line_height_measure','px','3','','.catalog-product-wrap'),(336592,'watch-mobile','.catalog-product-wrap .pn-image','display','inline-block','3','','.catalog-product-wrap'),(336593,'watch-mobile','.catalog-product-wrap .pn-image','font-family','FontAwesome','3','','.catalog-product-wrap'),(336594,'watch-mobile','.catalog-product-wrap .pn-image','border-top-width','2','3','','.catalog-product-wrap'),(336595,'watch-mobile','.catalog-product-wrap .pn-image','border-left-width','2','3','','.catalog-product-wrap'),(336596,'watch-mobile','.catalog-product-wrap .pn-image','border-right-width','2','3','','.catalog-product-wrap'),(336597,'watch-mobile','.catalog-product-wrap .pn-image','border-bottom-width','2','3','','.catalog-product-wrap'),(336598,'watch-mobile','.catalog-product-wrap .pn-image','border-top-color','$border-color-1','3','','.catalog-product-wrap'),(336599,'watch-mobile','.catalog-product-wrap .pn-image','border-left-color','$border-color-1','3','','.catalog-product-wrap'),(336600,'watch-mobile','.catalog-product-wrap .pn-image','border-right-color','$border-color-1','3','','.catalog-product-wrap'),(336601,'watch-mobile','.catalog-product-wrap .pn-image','border-bottom-color','$border-color-1','3','','.catalog-product-wrap'),(336602,'watch-mobile','.catalog-product-wrap .pn-image','border-top-left-radius','50','3','','.catalog-product-wrap'),(336603,'watch-mobile','.catalog-product-wrap .pn-image','border_radius_1_measure','%','3','','.catalog-product-wrap'),(336604,'watch-mobile','.catalog-product-wrap .pn-image','border-top-right-radius','50','3','','.catalog-product-wrap'),(336605,'watch-mobile','.catalog-product-wrap .pn-image','border_radius_2_measure','%','3','','.catalog-product-wrap'),(336606,'watch-mobile','.catalog-product-wrap .pn-image','border-bottom-right-radius','50','3','','.catalog-product-wrap'),(336607,'watch-mobile','.catalog-product-wrap .pn-image','border_radius_3_measure','%','3','','.catalog-product-wrap'),(336608,'watch-mobile','.catalog-product-wrap .pn-image','border-bottom-left-radius','50','3','','.catalog-product-wrap'),(336609,'watch-mobile','.catalog-product-wrap .pn-image','border_radius_4_measure','%','3','','.catalog-product-wrap'),(336610,'watch-mobile','.catalog-product-wrap .pn-image','border-top-width','1','','','.catalog-product-wrap'),(336611,'watch-mobile','.catalog-product-wrap .pn-image','padding-top','20','','','.catalog-product-wrap'),(336612,'watch-mobile','.catalog-product-wrap .pn-image','padding-right','5','','','.catalog-product-wrap'),(336613,'watch-mobile','.catalog-product-wrap .pn-image','padding-bottom','20','','','.catalog-product-wrap'),(336614,'watch-mobile','.catalog-product-wrap .pn-image','padding-left','5','','','.catalog-product-wrap'),(336615,'watch-mobile','.catalog-product-wrap .pn-name','font-size','14','','','.catalog-product-wrap'),(336616,'watch-mobile','.catalog-product-wrap .pn-name','border-top-width','1','','','.catalog-product-wrap'),(336617,'watch-mobile','.catalog-product-wrap .pn-name','padding-top','15','','','.catalog-product-wrap'),(336618,'watch-mobile','.catalog-product-wrap .pn-price','display','none','','','.catalog-product-wrap'),(336619,'watch-mobile','.catalog-product-wrap .pn-price','display_important','important','','','.catalog-product-wrap'),(336620,'watch-mobile','.catalog-product-wrap .prev-next-product','background-color','$background-9','','','.catalog-product-wrap'),(336621,'watch-mobile','.catalog-product-wrap .prev-next-product','position','fixed','','','.catalog-product-wrap'),(336622,'watch-mobile','.catalog-product-wrap .prev-next-product','text-align','center','','','.catalog-product-wrap'),(336623,'watch-mobile','.catalog-product-wrap .prev-next-product','top','calc(50% - 200px)','','','.catalog-product-wrap'),(336624,'watch-mobile','.catalog-product-wrap .prev-next-product','width','190','','','.catalog-product-wrap'),(336625,'watch-mobile','.catalog-product-wrap .prev-next-product','border-top-width','1','','','.catalog-product-wrap'),(336626,'watch-mobile','.catalog-product-wrap .prev-next-product','border-bottom-width','1','','','.catalog-product-wrap'),(336627,'watch-mobile','.catalog-product-wrap .prev-next-product > span','display','block','','','.catalog-product-wrap'),(336628,'watch-mobile','.catalog-product-wrap .prev-product','left','0','','','.catalog-product-wrap'),(336629,'watch-mobile','.catalog-product-wrap .prev-product','border-right-width','1','','','.catalog-product-wrap'),(336630,'watch-mobile','.catalog-product-wrap .prev-product','padding-top','20','','','.catalog-product-wrap'),(336631,'watch-mobile','.catalog-product-wrap .prev-product','padding-right','20','','','.catalog-product-wrap'),(336632,'watch-mobile','.catalog-product-wrap .prev-product','padding-bottom','20','','','.catalog-product-wrap'),(336633,'watch-mobile','.catalog-product-wrap .prev-product','padding-left','50','','','.catalog-product-wrap'),(336634,'watch-mobile','.catalog-product-wrap .prev-product .pn-image','left','20','3','','.catalog-product-wrap'),(336635,'watch-mobile','.catalog-product-wrap .prev-product .pn-image','content','\\f053','3','','.catalog-product-wrap'),(336636,'watch-mobile','.catalog-product-wrap .prev-product .pn-image','padding-right','2','3','','.catalog-product-wrap'),(336637,'watch-mobile','.catalog-product-wrap a.prev-next-product','text-decoration','none','1','','.catalog-product-wrap'),(336699,'watch-mobile','.checkout-order-confirmation .buttons','margin-bottom','20','','','.checkout-order-confirmation'),(336700,'watch-mobile','.checkout-order-confirmation .confirm-info','margin-bottom','20','','','.checkout-order-confirmation'),(336701,'watch-mobile','.checkout-index-wrap #frmCheckout .box-block.type-4 > .block:nth-child(1)','width','100','','','.checkout-index-wrap'),(336702,'watch-mobile','.checkout-index-wrap #frmCheckout .box-block.type-4 > .block:nth-child(1)','width_measure','%','','','.checkout-index-wrap'),(336703,'watch-mobile','.checkout-index-wrap #frmCheckout .box-block.type-4 > .block:nth-child(1)','width_important','important','','','.checkout-index-wrap'),(336704,'watch-mobile','.checkout-index-wrap #frmCheckout .box-block.type-4 > .block:nth-child(1)','width_measure_important','important','','','.checkout-index-wrap'),(336705,'watch-mobile','.checkout-index-wrap #frmCheckout .box-block.type-4 > .block:nth-child(2)','width','100','','','.checkout-index-wrap'),(336706,'watch-mobile','.checkout-index-wrap #frmCheckout .box-block.type-4 > .block:nth-child(2)','width_measure','%','','','.checkout-index-wrap'),(336707,'watch-mobile','.checkout-index-wrap #frmCheckout .box-block.type-4 > .block:nth-child(2)','width_important','important','','','.checkout-index-wrap'),(336708,'watch-mobile','.checkout-index-wrap #frmCheckout .box-block.type-4 > .block:nth-child(2)','width_measure_important','important','','','.checkout-index-wrap'),(336709,'watch-mobile','.checkout-index-wrap #frmCheckout .type-1 > .block > .type-4 > .block > .type-1','padding-right','0','','','.checkout-index-wrap'),(336710,'watch-mobile','.checkout-index-wrap #frmCheckout .type-1 > .block > .type-4 > .block > .type-1','padding-right_important','important','','','.checkout-index-wrap'),(336711,'watch-mobile','.checkout-index-wrap .add-buttons.hide-box','position','relative','','','.checkout-index-wrap'),(336712,'watch-mobile','.checkout-index-wrap .buttons','margin-bottom','20','','','.checkout-index-wrap'),(336713,'watch-mobile','.checkout-index-wrap .closeable-heading .heading-2','padding-right','25','','','.checkout-index-wrap'),(336714,'watch-mobile','.checkout-index-wrap .discount-box','margin-bottom','20','','','.checkout-index-wrap'),(336715,'watch-mobile','.checkout-index-wrap .heading-2','font-size','20','','','.checkout-index-wrap'),(336716,'watch-mobile','.checkout-index-wrap .heading-2','text-align','left','','','.checkout-index-wrap'),(336717,'watch-mobile','.checkout-index-wrap .same-address','font-size','16','','','.checkout-index-wrap'),(336718,'watch-mobile','.checkout-index-wrap .same-address','font-weight','bold','','','.checkout-index-wrap'),(336719,'watch-mobile','.checkout-index-wrap .same-address','padding-bottom','15','','','.checkout-index-wrap'),(336720,'watch-mobile','.checkout-index-wrap .same-address div.bootstrap-switch','margin-left','30','','','.checkout-index-wrap'),(336721,'watch-mobile','.checkout-index-wrap .sel_pr_values','overflow','hidden','','','.checkout-index-wrap'),(336722,'watch-mobile','.checkout-index-wrap .shipping-address, .checkout-index-wrap .billing-address','margin-bottom','30','','','.checkout-index-wrap'),(336723,'watch-mobile','.checkout-index-wrap .shipping-estimator .info','border-top','none','','','.checkout-index-wrap'),(336724,'watch-mobile','.checkout-index-wrap .shipping-estimator .info','text-align','center','','','.checkout-index-wrap'),(336725,'watch-mobile','.checkout-index-wrap .shipping-estimator .info','margin-bottom','20','','','.checkout-index-wrap'),(336726,'watch-mobile','.checkout-index-wrap .shipping-method .item','padding-top','10','','','.checkout-index-wrap'),(336727,'watch-mobile','.checkout-index-wrap .shipping-method .item','padding-right','0','','','.checkout-index-wrap'),(336728,'watch-mobile','.checkout-index-wrap .shipping-method .item','padding-bottom','10','','','.checkout-index-wrap'),(336729,'watch-mobile','.checkout-index-wrap .shipping-method .item','padding-left','0','','','.checkout-index-wrap'),(336730,'watch-mobile','.checkout-index-wrap .shipping-method .item + .item','border-top-width','1','','','.checkout-index-wrap'),(336731,'watch-mobile','.checkout-index-wrap .shipping-method .item + .item','border-top-color','#e0e0e0','','','.checkout-index-wrap'),(336732,'watch-mobile','.checkout-index-wrap .shipping-method .row','cursor','pointer','','','.checkout-index-wrap'),(336733,'watch-mobile','.checkout-index-wrap .shipping-method .row','display','block','','','.checkout-index-wrap'),(336734,'watch-mobile','.checkout-index-wrap .shipping-method .row','padding-top','5','','','.checkout-index-wrap'),(336735,'watch-mobile','.checkout-index-wrap .shipping-method .row','padding-right','5','','','.checkout-index-wrap'),(336736,'watch-mobile','.checkout-index-wrap .shipping-method .row','padding-bottom','5','','','.checkout-index-wrap'),(336737,'watch-mobile','.checkout-index-wrap .shipping-method .row','padding-left','5','','','.checkout-index-wrap'),(336738,'watch-mobile','.checkout-index-wrap .shipping-method .title','font-weight','bold','','','.checkout-index-wrap'),(336739,'watch-mobile','.checkout-index-wrap .shipping-method .title','padding-top','0','','','.checkout-index-wrap'),(336740,'watch-mobile','.checkout-index-wrap .shipping-method .title','padding-right','5','','','.checkout-index-wrap'),(336741,'watch-mobile','.checkout-index-wrap .shipping-method .title','padding-bottom','0','','','.checkout-index-wrap'),(336742,'watch-mobile','.checkout-index-wrap .shipping-method .title','padding-left','5','','','.checkout-index-wrap'),(336743,'watch-mobile','.checkout-index-wrap .w-checkout-login-on-form','margin-bottom','20','','','.checkout-index-wrap'),(336744,'watch-mobile','.checkout-index-wrap #frmCheckout .type-1 > .block > .type-4 > .block > .type-1.order-summary','padding-right','20','1314','','.checkout-index-wrap'),(336745,'watch-mobile','.checkout-index-wrap #frmCheckout .type-1 > .block > .type-4 > .block > .type-1.order-summary','padding-right_important','important','1314','','.checkout-index-wrap'),(336746,'watch-mobile','.checkout-index-wrap .checkout > .type-1 > .type-1 > .type-1','padding-right','0','1314','','.checkout-index-wrap'),(336747,'watch-mobile','.checkout-index-wrap .checkout > .type-1 > .type-1 > .type-1','padding-right_important','important','1314','','.checkout-index-wrap'),(336748,'watch-mobile','.checkout-index-wrap #frmCheckout .type-1 > .block > .type-4 > .block > .type-1.order-summary .w-cart-products','display','none','1315','','.checkout-index-wrap'),(336749,'watch-mobile','.checkout-index-wrap #frmCheckout .type-1 > .block > .type-4 > .block > .type-1.order-summary .w-cart-products','display_important','important','1315','','.checkout-index-wrap'),(336750,'watch-mobile','.checkout-index-wrap .hiding-box .box-block.type-2 > .block:nth-child(1)','width','100','1315','','.checkout-index-wrap'),(336751,'watch-mobile','.checkout-index-wrap .hiding-box .box-block.type-2 > .block:nth-child(1)','width_measure','%','1315','','.checkout-index-wrap'),(336752,'watch-mobile','.checkout-index-wrap .hiding-box .box-block.type-2 > .block:nth-child(1)','width_important','important','1315','','.checkout-index-wrap'),(336753,'watch-mobile','.checkout-index-wrap .hiding-box .box-block.type-2 > .block:nth-child(1)','width_measure_important','important','1315','','.checkout-index-wrap'),(336754,'watch-mobile','.checkout-index-wrap .hiding-box .box-block.type-2 > .block:nth-child(1) > .type-1','padding-right','0','1315','','.checkout-index-wrap'),(336755,'watch-mobile','.checkout-index-wrap .hiding-box .box-block.type-2 > .block:nth-child(1) > .type-1','padding-right_important','important','1315','','.checkout-index-wrap'),(336756,'watch-mobile','.checkout-index-wrap .hiding-box .box-block.type-2 > .block:nth-child(2)','width','100','1315','','.checkout-index-wrap'),(336757,'watch-mobile','.checkout-index-wrap .hiding-box .box-block.type-2 > .block:nth-child(2)','width_measure','%','1315','','.checkout-index-wrap'),(336758,'watch-mobile','.checkout-index-wrap .hiding-box .box-block.type-2 > .block:nth-child(2)','width_important','important','1315','','.checkout-index-wrap'),(336759,'watch-mobile','.checkout-index-wrap .hiding-box .box-block.type-2 > .block:nth-child(2)','width_measure_important','important','1315','','.checkout-index-wrap'),(336760,'watch-mobile','.checkout-index-wrap .hiding-box .box-block.type-2 > .block:nth-child(2) > .type-1','padding-left','0','1315','','.checkout-index-wrap'),(336761,'watch-mobile','.checkout-index-wrap .hiding-box .box-block.type-2 > .block:nth-child(2) > .type-1','padding-left_important','important','1315','','.checkout-index-wrap'),(336762,'watch-mobile','.checkout-index-wrap .hiding-box.w-cart-products','background-color','$background-7','1315','','.checkout-index-wrap'),(336763,'watch-mobile','.checkout-index-wrap .hiding-box.w-cart-products','padding-top','20','1315','','.checkout-index-wrap'),(336764,'watch-mobile','.checkout-index-wrap .hiding-box.w-cart-products','padding-right','20','1315','','.checkout-index-wrap'),(336765,'watch-mobile','.checkout-index-wrap .hiding-box.w-cart-products','padding-bottom','20','1315','','.checkout-index-wrap'),(336766,'watch-mobile','.checkout-index-wrap .hiding-box.w-cart-products','padding-left','20','1315','','.checkout-index-wrap'),(336767,'watch-mobile','.checkout-index-wrap .checkoutDoubleBox','display','flex','','','.checkout-index-wrap'),(336768,'watch-mobile','.checkout-index-wrap .checkoutDoubleBox','flex-direction','column','','','.checkout-index-wrap'),(336777,'watch-mobile','.order-summary ','margin-bottom','20','','','.order-summary'),(336778,'watch-mobile','.order-summary .box','text-align','center','','','.order-summary'),(336779,'watch-mobile','.order-summary .btn-2','float','none','1314','','.order-summary'),(336780,'watch-mobile','.order-summary .btn-2, .order-summary .btn-3','font-size','15','','','.order-summary'),(336781,'watch-mobile','.order-summary .btn-2, .order-summary .btn-3','margin-bottom','15','','','.order-summary'),(336782,'watch-mobile','.order-summary .btn-2, .order-summary .btn-3','padding-left','5','','','.order-summary'),(336783,'watch-mobile','.order-summary .btn-2, .order-summary .btn-3','padding-right','5','','','.order-summary'),(336784,'watch-mobile','.order-summary .btn-2, .order-summary .btn-3','width','100','','','.order-summary'),(336785,'watch-mobile','.order-summary .btn-2, .order-summary .btn-3','width_measure','%','','','.order-summary'),(336786,'watch-mobile','.order-summary .checkout-cart-listing','border-bottom-color','#e0e0e0','','','.order-summary'),(336787,'watch-mobile','.order-summary .checkout-cart-listing','border-bottom-width','1','','','.order-summary'),(336788,'watch-mobile','.order-summary .checkout-cart-listing.main-listing','display','none','','','.order-summary'),(336789,'watch-mobile','.order-summary .heading-2','color','$color-font-6','3','','.order-summary'),(336790,'watch-mobile','.order-summary .heading-2','content','\\e922','3','','.order-summary'),(336791,'watch-mobile','.order-summary .heading-2','font-family','trueloaded','3','','.order-summary'),(336792,'watch-mobile','.order-summary .heading-2','font-size','36','3','','.order-summary'),(336793,'watch-mobile','.order-summary .heading-2','line-height','20','3','','.order-summary'),(336794,'watch-mobile','.order-summary .heading-2','line_height_measure','px','3','','.order-summary'),(336795,'watch-mobile','.order-summary .heading-2','margin-right','10','3','','.order-summary'),(336796,'watch-mobile','.order-summary .heading-2','padding-bottom','0','','','.order-summary'),(336797,'watch-mobile','.order-summary .heading-2','padding-left','25','','','.order-summary'),(336798,'watch-mobile','.order-summary .heading-2','padding-right','25','','','.order-summary'),(336799,'watch-mobile','.order-summary .heading-2','padding-top','10','','','.order-summary'),(336800,'watch-mobile','.order-summary .heading-2','position','relative','3','','.order-summary'),(336801,'watch-mobile','.order-summary .heading-2','text-align','left','','','.order-summary'),(336802,'watch-mobile','.order-summary .heading-2','top','7','3','','.order-summary'),(336803,'watch-mobile','.order-summary .icon','content','\\f067','3','','.order-summary'),(336804,'watch-mobile','.order-summary .icon','cursor','pointer','','','.order-summary'),(336805,'watch-mobile','.order-summary .icon','display','block','','','.order-summary'),(336806,'watch-mobile','.order-summary .icon','display_important','important','','','.order-summary'),(336807,'watch-mobile','.order-summary .icon','font-family','$font-icons-1','3','','.order-summary'),(336808,'watch-mobile','.order-summary .icon','font-size','18','3','','.order-summary'),(336809,'watch-mobile','.order-summary .icon','height','30','','','.order-summary'),(336810,'watch-mobile','.order-summary .icon','line-height','30','','','.order-summary'),(336811,'watch-mobile','.order-summary .icon','line_height_measure','px','','','.order-summary'),(336812,'watch-mobile','.order-summary .icon','position','relative','','','.order-summary'),(336813,'watch-mobile','.order-summary .icon','position','absolute','3','','.order-summary'),(336814,'watch-mobile','.order-summary .icon','right','0','3','','.order-summary'),(336815,'watch-mobile','.order-summary .icon','top','0','3','','.order-summary'),(336816,'watch-mobile','.order-summary .icon.opened','content','\\f068','3','','.order-summary'),(336817,'watch-mobile','.order-summary .price','font-size','18','','','.order-summary'),(336818,'watch-mobile','.order-summary .price-box','margin-bottom','10','','','.order-summary'),(336819,'watch-mobile','.order-summary .price-box .price','width','auto','','','.order-summary'),(336820,'watch-mobile','.order-summary .price-box .price-row.total','display','flex','','','.order-summary'),(336821,'watch-mobile','.order-summary .price-box .price-row.total','font-size','22','','','.order-summary'),(336822,'watch-mobile','.order-summary .price-box .price-row.total','font-weight','600','','','.order-summary'),(336823,'watch-mobile','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-size','22','','','.order-summary'),(336824,'watch-mobile','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-weight','600','','','.order-summary'),(336825,'watch-mobile','.order-summary .price-box .title','font-size','15','','','.order-summary'),(336826,'watch-mobile','.order-summary .price-box .title','text-align','left','','','.order-summary'),(336827,'watch-mobile','.order-summary .price-row','align-items','baseline','','','.order-summary'),(336828,'watch-mobile','.order-summary .price-row','display','none','','','.order-summary'),(336829,'watch-mobile','.order-summary .price-row','display','flex','2','','.order-summary'),(336830,'watch-mobile','.order-summary .price-row','justify-content','space-between','','','.order-summary'),(336831,'watch-mobile','.order-summary .price-row','padding-bottom','7','','','.order-summary'),(336832,'watch-mobile','.order-summary .price-row','padding-left','0','','','.order-summary'),(336833,'watch-mobile','.order-summary .price-row','padding-right','0','','','.order-summary'),(336834,'watch-mobile','.order-summary .price-row','padding-top','7','','','.order-summary'),(336835,'watch-mobile','.order-summary .price-row + .price-row','border-top-color','#e0e0e0','','','.order-summary'),(336836,'watch-mobile','.order-summary .price-row + .price-row','border-top-width','1','','','.order-summary'),(336837,'watch-mobile','.order-summary .price-row.ot_bonus_points .title','color','$message-color','3','','.order-summary'),(336838,'watch-mobile','.order-summary .price-row.ot_bonus_points .title','content','\\e9a9','3','','.order-summary'),(336839,'watch-mobile','.order-summary .price-row.ot_bonus_points .title','display','inline-block','3','','.order-summary'),(336840,'watch-mobile','.order-summary .price-row.ot_bonus_points .title','font-family','trueloaded','3','','.order-summary'),(336841,'watch-mobile','.order-summary .price-row.ot_bonus_points .title','font-size','12','3','','.order-summary'),(336842,'watch-mobile','.order-summary .price-row.ot_bonus_points .title','text-align','center','3','','.order-summary'),(336843,'watch-mobile','.order-summary .price-row.ot_bonus_points .title','vertical-align','top','3','','.order-summary'),(336844,'watch-mobile','.order-summary .price-row.ot_bonus_points .title','width','32','3','','.order-summary'),(336845,'watch-mobile','.order-summary .price-row.ot_coupon .title','color','$message-color','3','','.order-summary'),(336846,'watch-mobile','.order-summary .price-row.ot_coupon .title','content','%','3','','.order-summary'),(336847,'watch-mobile','.order-summary .price-row.ot_coupon .title','display','inline-block','3','','.order-summary'),(336848,'watch-mobile','.order-summary .price-row.ot_coupon .title','font-size','18','3','','.order-summary'),(336849,'watch-mobile','.order-summary .price-row.ot_coupon .title','font-weight','bold','3','','.order-summary'),(336850,'watch-mobile','.order-summary .price-row.ot_coupon .title','line-height','22','3','','.order-summary'),(336851,'watch-mobile','.order-summary .price-row.ot_coupon .title','line_height_measure','px','3','','.order-summary'),(336852,'watch-mobile','.order-summary .price-row.ot_coupon .title','text-align','center','3','','.order-summary'),(336853,'watch-mobile','.order-summary .price-row.ot_coupon .title','vertical-align','top','3','','.order-summary'),(336854,'watch-mobile','.order-summary .price-row.ot_coupon .title','width','32','3','','.order-summary'),(336855,'watch-mobile','.order-summary .price-row.ot_gv + .price-row, .order-summary .price-row.ot_coupon + .price-row, .order-summary .price-row.ot_bonus_points + .price-row','border-top','none','','','.order-summary'),(336856,'watch-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','color','$color-font-8','3','','.order-summary'),(336857,'watch-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','content','\\e913','3','','.order-summary'),(336858,'watch-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','cursor','pointer','3','','.order-summary'),(336859,'watch-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','font-family','trueloaded','3','','.order-summary'),(336860,'watch-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','font-size','12','3','','.order-summary'),(336861,'watch-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','margin-left','7','3','','.order-summary'),(336862,'watch-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','position','relative','3','','.order-summary'),(336863,'watch-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','top','-1','3','','.order-summary'),(336864,'watch-mobile','.order-summary .price-row.ot_gv .title','color','$message-color','3','','.order-summary'),(336865,'watch-mobile','.order-summary .price-row.ot_gv .title','content','\\e99f','3','','.order-summary'),(336866,'watch-mobile','.order-summary .price-row.ot_gv .title','display','inline-block','3','','.order-summary'),(336867,'watch-mobile','.order-summary .price-row.ot_gv .title','font-family','trueloaded','3','','.order-summary'),(336868,'watch-mobile','.order-summary .price-row.ot_gv .title','text-align','center','3','','.order-summary'),(336869,'watch-mobile','.order-summary .price-row.ot_gv .title','vertical-align','top','3','','.order-summary'),(336870,'watch-mobile','.order-summary .price-row.ot_gv .title','width','32','3','','.order-summary'),(336871,'watch-mobile','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','background-color','$background-6','','','.order-summary'),(336872,'watch-mobile','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','border-top','none','','','.order-summary'),(336873,'watch-mobile','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-bottom','7','','','.order-summary'),(336874,'watch-mobile','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-left','0','','','.order-summary'),(336875,'watch-mobile','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-right','10','','','.order-summary'),(336876,'watch-mobile','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-top','7','','','.order-summary'),(336877,'watch-mobile','.order-summary .top-totals .price-box .price-row.total','display','none','','','.order-summary'),(336878,'watch-mobile','.order-summary .top-totals .price-row','display','flex','2','','.order-summary'),(336879,'watch-mobile','.order-summary .w-cart-listing .headings','border','none','','','.order-summary'),(336880,'watch-mobile','.order-summary .w-cart-listing .headings','grid-template-columns','3fr 1fr 1fr','','','.order-summary'),(336881,'watch-mobile','.order-summary .w-cart-listing .item','border','none','','','.order-summary'),(336882,'watch-mobile','.order-summary .w-cart-listing .item','grid-template-columns','3fr 1fr 1fr','','','.order-summary'),(336883,'watch-mobile','.order-summary .w-cart-listing .item','grid-template-rows','1fr','','','.order-summary'),(336884,'watch-mobile','.order-summary .w-cart-listing .item .name','grid-column','1/2','','','.order-summary'),(336885,'watch-mobile','.order-summary .w-cart-listing .item .name','padding-left','0','','','.order-summary'),(336886,'watch-mobile','.order-summary .w-cart-listing .item .name','text-align','left','','','.order-summary'),(336887,'watch-mobile','.order-summary .w-cart-listing .item .points','display','none','','','.order-summary'),(336888,'watch-mobile','.order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price','grid-column','3/4','','','.order-summary'),(336889,'watch-mobile','.order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price','grid-row','1/2','','','.order-summary'),(336890,'watch-mobile','.order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty','grid-column','2/3','','','.order-summary'),(336891,'watch-mobile','.order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty','grid-row','1/2','','','.order-summary'),(336892,'watch-mobile','.order-summary .w-cart-listing .item > div ~ div','padding-bottom','10','','','.order-summary'),(336893,'watch-mobile','.order-summary .w-cart-listing .item > div ~ div','padding-left','10','','','.order-summary'),(336894,'watch-mobile','.order-summary .w-cart-listing .item > div ~ div','padding-right','0','','','.order-summary'),(336895,'watch-mobile','.order-summary .w-cart-listing .item > div ~ div','padding-top','0','','','.order-summary'),(336896,'watch-mobile','.order-summary .w-cart-listing .item > div.image','display','none','','','.order-summary'),(336897,'watch-mobile','.order-summary .w-cart-listing .price','font-size','18','','','.order-summary'),(336898,'watch-mobile','.order-summary .w-cart-listing.type-2 .image','grid-column','1 / 3','','','.order-summary'),(336899,'watch-mobile','.order-summary .w-cart-listing.type-2 .image','text-align','left','','','.order-summary'),(336900,'watch-mobile','.order-summary > div','background-color','$background-7','','','.order-summary'),(336901,'watch-mobile','.order-summary > div','padding-top','10','','','.order-summary'),(336902,'watch-mobile','.w-checkout-continue-btn .button-hide','display','none','','','.w-checkout-continue-btn'),(336903,'watch-mobile','.w-checkout-continue-btn .or-text','display','none','','','.w-checkout-continue-btn'),(336904,'watch-mobile','.checkout-login-wrap .col-left, .checkout-login-wrap .col-right','width','100','','','.checkout-login-wrap'),(336905,'watch-mobile','.checkout-login-wrap .col-left, .checkout-login-wrap .col-right','width_measure','%','','','.checkout-login-wrap'),(336906,'watch-mobile','.checkout-login-wrap .middle-form .btn-2','width','100','','','.checkout-login-wrap'),(336907,'watch-mobile','.checkout-login-wrap .middle-form .btn-2','width_measure','%','','','.checkout-login-wrap'),(336908,'watch-mobile','.checkout-login-wrap .password-forgotten-link','font-size','14','','','.checkout-login-wrap'),(336909,'watch-mobile','.checkout-login-wrap .password-forgotten-link','padding-top','0','','','.checkout-login-wrap'),(336910,'watch-mobile','.checkout-success-wrap .page-success','content','\\_','3','','.checkout-success-wrap'),(336911,'watch-mobile','.checkout-success-wrap .page-success','position','relative','','','.checkout-success-wrap'),(336912,'watch-mobile','.checkout-success-wrap .page-success','text-align','center','','','.checkout-success-wrap'),(336913,'watch-mobile','.checkout-success-wrap .page-success','z-index','-1','','','.checkout-success-wrap'),(336914,'watch-mobile','.checkout-success-wrap .page-success .text-1','color','$color-font-6','3','','.checkout-success-wrap'),(336915,'watch-mobile','.checkout-success-wrap .page-success .text-1','font-size','80','3','','.checkout-success-wrap'),(336916,'watch-mobile','.checkout-success-wrap .page-success .text-1','content','\\e916','3','','.checkout-success-wrap'),(336917,'watch-mobile','.checkout-success-wrap .page-success .text-1','display','block','3','','.checkout-success-wrap'),(336918,'watch-mobile','.checkout-success-wrap .page-success .text-1','font-family','trueloaded','3','','.checkout-success-wrap'),(336919,'watch-mobile','.checkout-success-wrap .page-success .text-1','font-size','60','','','.checkout-success-wrap'),(336920,'watch-mobile','.checkout-success-wrap .page-success .text-1','text-transform','uppercase','','','.checkout-success-wrap'),(336921,'watch-mobile','.checkout-success-wrap .page-success .text-1','padding-top','120','','','.checkout-success-wrap'),(336922,'watch-mobile','.checkout-success-wrap .page-success .text-1, .checkout-success-wrap .page-success .text-2, .checkout-success-wrap .page-success .text-3','font-family','$font-family-1','','','.checkout-success-wrap'),(336923,'watch-mobile','.checkout-success-wrap .page-success .text-2','font-size','34','','','.checkout-success-wrap'),(336924,'watch-mobile','.checkout-success-wrap .page-success .text-2','text-transform','uppercase','','','.checkout-success-wrap'),(336925,'watch-mobile','.checkout-success-wrap .page-success .text-3','color','$attention-color','','','.checkout-success-wrap'),(336926,'watch-mobile','.checkout-success-wrap .page-success .text-3','font-size','27','','','.checkout-success-wrap'),(336927,'watch-mobile','.checkout-success-wrap .page-success > div','position','relative','','','.checkout-success-wrap'),(336928,'watch-mobile','.checkout-success-wrap .page-success > div','z-index','1','','','.checkout-success-wrap'),(336929,'watch-mobile','.checkout-success-wrap .page-success .text-1','font-size','40','1315','','.checkout-success-wrap'),(336930,'watch-mobile','.checkout-success-wrap .page-success .text-1','padding-top','5','1315','','.checkout-success-wrap'),(336931,'watch-mobile','.checkout-success-wrap .page-success .text-2','font-size','30','1315','','.checkout-success-wrap'),(336932,'watch-mobile','.shopping-cart-index .cart-page .empty','font-size','24','','','.shopping-cart-index'),(336933,'watch-mobile','.shopping-cart-index .cart-page .empty','font-weight','700','','','.shopping-cart-index'),(336934,'watch-mobile','.shopping-cart-index .cart-page .empty','text-align','center','','','.shopping-cart-index'),(336935,'watch-mobile','.shopping-cart-index .cart-page .empty','padding-top','100','','','.shopping-cart-index'),(336936,'watch-mobile','.shopping-cart-index .cart-page .empty','padding-bottom','100','','','.shopping-cart-index'),(336937,'watch-mobile','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-top','0','','','.shopping-cart-index'),(336938,'watch-mobile','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-right','20','','','.shopping-cart-index'),(336939,'watch-mobile','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-bottom','10','','','.shopping-cart-index'),(336940,'watch-mobile','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-left','20','','','.shopping-cart-index'),(336941,'watch-mobile','.shopping-cart-index .cart-popup .gift-wrap','display','none','','','.shopping-cart-index'),(336942,'watch-mobile','.shopping-cart-index .order-summary .btn-2','width','100','','','.shopping-cart-index'),(336943,'watch-mobile','.shopping-cart-index .order-summary .btn-2','width_measure','%','','','.shopping-cart-index'),(342129,'watch-mobile','.b-slick .slick-dots','display','flex','','','.b-slick'),(342130,'watch-mobile','.b-slick .slick-dots','list-style','none','','','.b-slick'),(342131,'watch-mobile','.b-slick .slick-dots','justify-content','center','','','.b-slick'),(342132,'watch-mobile','.b-slick .slick-dots li','padding-top','5','','','.b-slick'),(342133,'watch-mobile','.b-slick .slick-dots li','padding-right','5','','','.b-slick'),(342134,'watch-mobile','.b-slick .slick-dots li','padding-bottom','5','','','.b-slick'),(342135,'watch-mobile','.b-slick .slick-dots li','padding-left','5','','','.b-slick'),(342136,'watch-mobile','.b-slick .slick-dots li','margin-top','0','','','.b-slick'),(342137,'watch-mobile','.b-slick .slick-dots li','margin-right','5','','','.b-slick'),(342138,'watch-mobile','.b-slick .slick-dots li','margin-bottom','0','','','.b-slick'),(342139,'watch-mobile','.b-slick .slick-dots li','margin-left','5','','','.b-slick'),(342140,'watch-mobile','.b-slick .slick-dots li','cursor','pointer','','','.b-slick'),(342141,'watch-mobile','.b-slick .slick-dots li','content','\\_','3','','.b-slick'),(342142,'watch-mobile','.b-slick .slick-dots li','width','10','3','','.b-slick'),(342143,'watch-mobile','.b-slick .slick-dots li','height','10','3','','.b-slick'),(342144,'watch-mobile','.b-slick .slick-dots li','display','block','3','','.b-slick'),(342145,'watch-mobile','.b-slick .slick-dots li','background-color','#cccccc','3','','.b-slick'),(342146,'watch-mobile','.b-slick .slick-dots li','border-top-left-radius','50','3','','.b-slick'),(342147,'watch-mobile','.b-slick .slick-dots li','border_radius_1_measure','%','3','','.b-slick'),(342148,'watch-mobile','.b-slick .slick-dots li','border-top-right-radius','50','3','','.b-slick'),(342149,'watch-mobile','.b-slick .slick-dots li','border_radius_2_measure','%','3','','.b-slick'),(342150,'watch-mobile','.b-slick .slick-dots li','border-bottom-right-radius','50','3','','.b-slick'),(342151,'watch-mobile','.b-slick .slick-dots li','border_radius_3_measure','%','3','','.b-slick'),(342152,'watch-mobile','.b-slick .slick-dots li','border-bottom-left-radius','50','3','','.b-slick'),(342153,'watch-mobile','.b-slick .slick-dots li','border_radius_4_measure','%','3','','.b-slick'),(342154,'watch-mobile','.b-slick .slick-dots li.slick-active','background-color','#212121','3','','.b-slick'),(342155,'watch-mobile','.b-slick .slick-dots button','display','none','','','.b-slick'),(342156,'watch-mobile','.w-banner .banner-image','grid-column','1','','','.w-banner'),(342157,'watch-mobile','.w-banner .banner-image','grid-row','1','','','.w-banner'),(342158,'watch-mobile','.w-banner .banner-item','display','grid','','','.w-banner'),(342159,'watch-mobile','.w-banner .banner-item.text-bottom-center .banner-text','align-items','end','','','.w-banner'),(342160,'watch-mobile','.w-banner .banner-item.text-bottom-center .banner-text','justify-content','center','','','.w-banner'),(342161,'watch-mobile','.w-banner .banner-item.text-bottom-left .banner-text','align-items','end','','','.w-banner'),(342162,'watch-mobile','.w-banner .banner-item.text-bottom-left .banner-text','justify-content','start','','','.w-banner'),(342163,'watch-mobile','.w-banner .banner-item.text-bottom-right .banner-text','align-items','end','','','.w-banner'),(342164,'watch-mobile','.w-banner .banner-item.text-bottom-right .banner-text','justify-content','end','','','.w-banner'),(342165,'watch-mobile','.w-banner .banner-item.text-bottom-text .banner-text','grid-row','2','','','.w-banner'),(342166,'watch-mobile','.w-banner .banner-item.text-bottom-text .banner-text-holder','max-width','100','','','.w-banner'),(342167,'watch-mobile','.w-banner .banner-item.text-bottom-text .banner-text-holder','max_width_measure','%','','','.w-banner'),(342168,'watch-mobile','.w-banner .banner-item.text-middle-center .banner-text','align-items','center','','','.w-banner'),(342169,'watch-mobile','.w-banner .banner-item.text-middle-center .banner-text','justify-content','center','','','.w-banner'),(342170,'watch-mobile','.w-banner .banner-item.text-middle-left .banner-text','align-items','center','','','.w-banner'),(342171,'watch-mobile','.w-banner .banner-item.text-middle-left .banner-text','justify-content','start','','','.w-banner'),(342172,'watch-mobile','.w-banner .banner-item.text-middle-right .banner-text','align-items','center','','','.w-banner'),(342173,'watch-mobile','.w-banner .banner-item.text-middle-right .banner-text','justify-content','end','','','.w-banner'),(342174,'watch-mobile','.w-banner .banner-item.text-top-center .banner-text','align-items','start','','','.w-banner'),(342175,'watch-mobile','.w-banner .banner-item.text-top-center .banner-text','justify-content','center','','','.w-banner'),(342176,'watch-mobile','.w-banner .banner-item.text-top-left .banner-text','align-items','start','','','.w-banner'),(342177,'watch-mobile','.w-banner .banner-item.text-top-left .banner-text','justify-content','start','','','.w-banner'),(342178,'watch-mobile','.w-banner .banner-item.text-top-right .banner-text','align-items','start','','','.w-banner'),(342179,'watch-mobile','.w-banner .banner-item.text-top-right .banner-text','justify-content','end','','','.w-banner'),(342180,'watch-mobile','.w-banner .banner-text','grid-column','1','','','.w-banner'),(342181,'watch-mobile','.w-banner .banner-text','grid-row','1','','','.w-banner'),(342182,'watch-mobile','.w-banner .banner-text','z-index','1','','','.w-banner'),(342183,'watch-mobile','.w-banner .banner-text','display','flex','','','.w-banner'),(342184,'watch-mobile','.w-banner .banner-text','padding-top','20','','','.w-banner'),(342185,'watch-mobile','.w-banner .banner-text','padding-right','20','','','.w-banner'),(342186,'watch-mobile','.w-banner .banner-text','padding-bottom','20','','','.w-banner'),(342187,'watch-mobile','.w-banner .banner-text','padding-left','20','','','.w-banner'),(342188,'watch-mobile','.w-banner .banner-text-holder','max-width','500','','','.w-banner'),(342189,'watch-mobile','.w-banner .banner-text-holder','width','100','','','.w-banner'),(342190,'watch-mobile','.w-banner .banner-text-holder','width_measure','%','','','.w-banner'),(342377,'printshop-mobile','.b-slick .slick-dots','display','flex','','','.b-slick'),(342378,'printshop-mobile','.b-slick .slick-dots','list-style','none','','','.b-slick'),(342379,'printshop-mobile','.b-slick .slick-dots','justify-content','center','','','.b-slick'),(342380,'printshop-mobile','.b-slick .slick-dots li','padding-top','5','','','.b-slick'),(342381,'printshop-mobile','.b-slick .slick-dots li','padding-right','5','','','.b-slick'),(342382,'printshop-mobile','.b-slick .slick-dots li','padding-bottom','5','','','.b-slick'),(342383,'printshop-mobile','.b-slick .slick-dots li','padding-left','5','','','.b-slick'),(342384,'printshop-mobile','.b-slick .slick-dots li','margin-top','0','','','.b-slick'),(342385,'printshop-mobile','.b-slick .slick-dots li','margin-right','5','','','.b-slick'),(342386,'printshop-mobile','.b-slick .slick-dots li','margin-bottom','0','','','.b-slick'),(342387,'printshop-mobile','.b-slick .slick-dots li','margin-left','5','','','.b-slick'),(342388,'printshop-mobile','.b-slick .slick-dots li','cursor','pointer','','','.b-slick'),(342389,'printshop-mobile','.b-slick .slick-dots li','content','\\_','3','','.b-slick'),(342390,'printshop-mobile','.b-slick .slick-dots li','width','10','3','','.b-slick'),(342391,'printshop-mobile','.b-slick .slick-dots li','height','10','3','','.b-slick'),(342392,'printshop-mobile','.b-slick .slick-dots li','display','block','3','','.b-slick'),(342393,'printshop-mobile','.b-slick .slick-dots li','background-color','#cccccc','3','','.b-slick'),(342394,'printshop-mobile','.b-slick .slick-dots li','border-top-left-radius','50','3','','.b-slick'),(342395,'printshop-mobile','.b-slick .slick-dots li','border_radius_1_measure','%','3','','.b-slick'),(342396,'printshop-mobile','.b-slick .slick-dots li','border-top-right-radius','50','3','','.b-slick'),(342397,'printshop-mobile','.b-slick .slick-dots li','border_radius_2_measure','%','3','','.b-slick'),(342398,'printshop-mobile','.b-slick .slick-dots li','border-bottom-right-radius','50','3','','.b-slick'),(342399,'printshop-mobile','.b-slick .slick-dots li','border_radius_3_measure','%','3','','.b-slick'),(342400,'printshop-mobile','.b-slick .slick-dots li','border-bottom-left-radius','50','3','','.b-slick'),(342401,'printshop-mobile','.b-slick .slick-dots li','border_radius_4_measure','%','3','','.b-slick'),(342402,'printshop-mobile','.b-slick .slick-dots li.slick-active','background-color','#212121','3','','.b-slick'),(342403,'printshop-mobile','.b-slick .slick-dots button','display','none','','','.b-slick'),(342404,'printshop-mobile','.w-banner .banner-image','grid-column','1','','','.w-banner'),(342405,'printshop-mobile','.w-banner .banner-image','grid-row','1','','','.w-banner'),(342406,'printshop-mobile','.w-banner .banner-item','display','grid','','','.w-banner'),(342407,'printshop-mobile','.w-banner .banner-item.text-bottom-center .banner-text','align-items','end','','','.w-banner'),(342408,'printshop-mobile','.w-banner .banner-item.text-bottom-center .banner-text','justify-content','center','','','.w-banner'),(342409,'printshop-mobile','.w-banner .banner-item.text-bottom-left .banner-text','align-items','end','','','.w-banner'),(342410,'printshop-mobile','.w-banner .banner-item.text-bottom-left .banner-text','justify-content','start','','','.w-banner'),(342411,'printshop-mobile','.w-banner .banner-item.text-bottom-right .banner-text','align-items','end','','','.w-banner'),(342412,'printshop-mobile','.w-banner .banner-item.text-bottom-right .banner-text','justify-content','end','','','.w-banner'),(342413,'printshop-mobile','.w-banner .banner-item.text-bottom-text .banner-text','grid-row','2','','','.w-banner'),(342414,'printshop-mobile','.w-banner .banner-item.text-bottom-text .banner-text-holder','max-width','100','','','.w-banner'),(342415,'printshop-mobile','.w-banner .banner-item.text-bottom-text .banner-text-holder','max_width_measure','%','','','.w-banner'),(342416,'printshop-mobile','.w-banner .banner-item.text-middle-center .banner-text','align-items','center','','','.w-banner'),(342417,'printshop-mobile','.w-banner .banner-item.text-middle-center .banner-text','justify-content','center','','','.w-banner'),(342418,'printshop-mobile','.w-banner .banner-item.text-middle-left .banner-text','align-items','center','','','.w-banner'),(342419,'printshop-mobile','.w-banner .banner-item.text-middle-left .banner-text','justify-content','start','','','.w-banner'),(342420,'printshop-mobile','.w-banner .banner-item.text-middle-right .banner-text','align-items','center','','','.w-banner'),(342421,'printshop-mobile','.w-banner .banner-item.text-middle-right .banner-text','justify-content','end','','','.w-banner'),(342422,'printshop-mobile','.w-banner .banner-item.text-top-center .banner-text','align-items','start','','','.w-banner'),(342423,'printshop-mobile','.w-banner .banner-item.text-top-center .banner-text','justify-content','center','','','.w-banner'),(342424,'printshop-mobile','.w-banner .banner-item.text-top-left .banner-text','align-items','start','','','.w-banner'),(342425,'printshop-mobile','.w-banner .banner-item.text-top-left .banner-text','justify-content','start','','','.w-banner'),(342426,'printshop-mobile','.w-banner .banner-item.text-top-right .banner-text','align-items','start','','','.w-banner'),(342427,'printshop-mobile','.w-banner .banner-item.text-top-right .banner-text','justify-content','end','','','.w-banner'),(342428,'printshop-mobile','.w-banner .banner-text','grid-column','1','','','.w-banner'),(342429,'printshop-mobile','.w-banner .banner-text','grid-row','1','','','.w-banner'),(342430,'printshop-mobile','.w-banner .banner-text','z-index','1','','','.w-banner'),(342431,'printshop-mobile','.w-banner .banner-text','display','flex','','','.w-banner'),(342432,'printshop-mobile','.w-banner .banner-text','padding-top','20','','','.w-banner'),(342433,'printshop-mobile','.w-banner .banner-text','padding-right','20','','','.w-banner'),(342434,'printshop-mobile','.w-banner .banner-text','padding-bottom','20','','','.w-banner'),(342435,'printshop-mobile','.w-banner .banner-text','padding-left','20','','','.w-banner'),(342436,'printshop-mobile','.w-banner .banner-text-holder','max-width','500','','','.w-banner'),(342437,'printshop-mobile','.w-banner .banner-text-holder','width','100','','','.w-banner'),(342438,'printshop-mobile','.w-banner .banner-text-holder','width_measure','%','','','.w-banner'),(342501,'deals-mobile','.b-slick .slick-dots','display','flex','','','.b-slick'),(342502,'deals-mobile','.b-slick .slick-dots','list-style','none','','','.b-slick'),(342503,'deals-mobile','.b-slick .slick-dots','justify-content','center','','','.b-slick'),(342504,'deals-mobile','.b-slick .slick-dots li','padding-top','5','','','.b-slick'),(342505,'deals-mobile','.b-slick .slick-dots li','padding-right','5','','','.b-slick'),(342506,'deals-mobile','.b-slick .slick-dots li','padding-bottom','5','','','.b-slick'),(342507,'deals-mobile','.b-slick .slick-dots li','padding-left','5','','','.b-slick'),(342508,'deals-mobile','.b-slick .slick-dots li','margin-top','0','','','.b-slick'),(342509,'deals-mobile','.b-slick .slick-dots li','margin-right','5','','','.b-slick'),(342510,'deals-mobile','.b-slick .slick-dots li','margin-bottom','0','','','.b-slick'),(342511,'deals-mobile','.b-slick .slick-dots li','margin-left','5','','','.b-slick'),(342512,'deals-mobile','.b-slick .slick-dots li','cursor','pointer','','','.b-slick'),(342513,'deals-mobile','.b-slick .slick-dots li','content','\\_','3','','.b-slick'),(342514,'deals-mobile','.b-slick .slick-dots li','width','10','3','','.b-slick'),(342515,'deals-mobile','.b-slick .slick-dots li','height','10','3','','.b-slick'),(342516,'deals-mobile','.b-slick .slick-dots li','display','block','3','','.b-slick'),(342517,'deals-mobile','.b-slick .slick-dots li','background-color','#cccccc','3','','.b-slick'),(342518,'deals-mobile','.b-slick .slick-dots li','border-top-left-radius','50','3','','.b-slick'),(342519,'deals-mobile','.b-slick .slick-dots li','border_radius_1_measure','%','3','','.b-slick'),(342520,'deals-mobile','.b-slick .slick-dots li','border-top-right-radius','50','3','','.b-slick'),(342521,'deals-mobile','.b-slick .slick-dots li','border_radius_2_measure','%','3','','.b-slick'),(342522,'deals-mobile','.b-slick .slick-dots li','border-bottom-right-radius','50','3','','.b-slick'),(342523,'deals-mobile','.b-slick .slick-dots li','border_radius_3_measure','%','3','','.b-slick'),(342524,'deals-mobile','.b-slick .slick-dots li','border-bottom-left-radius','50','3','','.b-slick'),(342525,'deals-mobile','.b-slick .slick-dots li','border_radius_4_measure','%','3','','.b-slick'),(342526,'deals-mobile','.b-slick .slick-dots li.slick-active','background-color','#212121','3','','.b-slick'),(342527,'deals-mobile','.b-slick .slick-dots button','display','none','','','.b-slick'),(342528,'deals-mobile','.w-banner .banner-image','grid-column','1','','','.w-banner'),(342529,'deals-mobile','.w-banner .banner-image','grid-row','1','','','.w-banner'),(342530,'deals-mobile','.w-banner .banner-item','display','grid','','','.w-banner'),(342531,'deals-mobile','.w-banner .banner-item.text-bottom-center .banner-text','align-items','end','','','.w-banner'),(342532,'deals-mobile','.w-banner .banner-item.text-bottom-center .banner-text','justify-content','center','','','.w-banner'),(342533,'deals-mobile','.w-banner .banner-item.text-bottom-left .banner-text','align-items','end','','','.w-banner'),(342534,'deals-mobile','.w-banner .banner-item.text-bottom-left .banner-text','justify-content','start','','','.w-banner'),(342535,'deals-mobile','.w-banner .banner-item.text-bottom-right .banner-text','align-items','end','','','.w-banner'),(342536,'deals-mobile','.w-banner .banner-item.text-bottom-right .banner-text','justify-content','end','','','.w-banner'),(342537,'deals-mobile','.w-banner .banner-item.text-bottom-text .banner-text','grid-row','2','','','.w-banner'),(342538,'deals-mobile','.w-banner .banner-item.text-bottom-text .banner-text-holder','max-width','100','','','.w-banner'),(342539,'deals-mobile','.w-banner .banner-item.text-bottom-text .banner-text-holder','max_width_measure','%','','','.w-banner'),(342540,'deals-mobile','.w-banner .banner-item.text-middle-center .banner-text','align-items','center','','','.w-banner'),(342541,'deals-mobile','.w-banner .banner-item.text-middle-center .banner-text','justify-content','center','','','.w-banner'),(342542,'deals-mobile','.w-banner .banner-item.text-middle-left .banner-text','align-items','center','','','.w-banner'),(342543,'deals-mobile','.w-banner .banner-item.text-middle-left .banner-text','justify-content','start','','','.w-banner'),(342544,'deals-mobile','.w-banner .banner-item.text-middle-right .banner-text','align-items','center','','','.w-banner'),(342545,'deals-mobile','.w-banner .banner-item.text-middle-right .banner-text','justify-content','end','','','.w-banner'),(342546,'deals-mobile','.w-banner .banner-item.text-top-center .banner-text','align-items','start','','','.w-banner'),(342547,'deals-mobile','.w-banner .banner-item.text-top-center .banner-text','justify-content','center','','','.w-banner'),(342548,'deals-mobile','.w-banner .banner-item.text-top-left .banner-text','align-items','start','','','.w-banner'),(342549,'deals-mobile','.w-banner .banner-item.text-top-left .banner-text','justify-content','start','','','.w-banner'),(342550,'deals-mobile','.w-banner .banner-item.text-top-right .banner-text','align-items','start','','','.w-banner'),(342551,'deals-mobile','.w-banner .banner-item.text-top-right .banner-text','justify-content','end','','','.w-banner'),(342552,'deals-mobile','.w-banner .banner-text','grid-column','1','','','.w-banner'),(342553,'deals-mobile','.w-banner .banner-text','grid-row','1','','','.w-banner'),(342554,'deals-mobile','.w-banner .banner-text','z-index','1','','','.w-banner'),(342555,'deals-mobile','.w-banner .banner-text','display','flex','','','.w-banner'),(342556,'deals-mobile','.w-banner .banner-text','padding-top','20','','','.w-banner'),(342557,'deals-mobile','.w-banner .banner-text','padding-right','20','','','.w-banner'),(342558,'deals-mobile','.w-banner .banner-text','padding-bottom','20','','','.w-banner'),(342559,'deals-mobile','.w-banner .banner-text','padding-left','20','','','.w-banner'),(342560,'deals-mobile','.w-banner .banner-text-holder','max-width','500','','','.w-banner'),(342561,'deals-mobile','.w-banner .banner-text-holder','width','100','','','.w-banner'),(342562,'deals-mobile','.w-banner .banner-text-holder','width_measure','%','','','.w-banner'),(342701,'watch-mobile','.fake-input','height','0','','',''),(342702,'watch-mobile','.fake-input','overflow','hidden','','',''),(342703,'watch-mobile','.hide-page','align-items','center','','',''),(342704,'watch-mobile','.hide-page','background-color','rgba(255, 255, 255, 0.7)','','',''),(342705,'watch-mobile','.hide-page','height','100','','',''),(342706,'watch-mobile','.hide-page','height_measure','%','','',''),(342707,'watch-mobile','.hide-page','justify-content','center','','',''),(342708,'watch-mobile','.hide-page','left','0','','',''),(342709,'watch-mobile','.hide-page','position','fixed','','',''),(342710,'watch-mobile','.hide-page','top','0','','',''),(342711,'watch-mobile','.hide-page','width','100','','',''),(342712,'watch-mobile','.hide-page','width_measure','%','','',''),(342713,'watch-mobile','.hide-page','z-index','100000','','',''),(342714,'watch-mobile','.hide-page','display','flex','','',''),(342757,'printshop-mobile','.fake-input','height','0','','',''),(342758,'printshop-mobile','.fake-input','overflow','hidden','','',''),(342759,'printshop-mobile','.hide-page','align-items','center','','',''),(342760,'printshop-mobile','.hide-page','background-color','rgba(255, 255, 255, 0.7)','','',''),(342761,'printshop-mobile','.hide-page','height','100','','',''),(342762,'printshop-mobile','.hide-page','height_measure','%','','',''),(342763,'printshop-mobile','.hide-page','justify-content','center','','',''),(342764,'printshop-mobile','.hide-page','left','0','','',''),(342765,'printshop-mobile','.hide-page','position','fixed','','',''),(342766,'printshop-mobile','.hide-page','top','0','','',''),(342767,'printshop-mobile','.hide-page','width','100','','',''),(342768,'printshop-mobile','.hide-page','width_measure','%','','',''),(342769,'printshop-mobile','.hide-page','z-index','100000','','',''),(342770,'printshop-mobile','.hide-page','display','flex','','',''),(342785,'deals-mobile','.fake-input','height','0','','',''),(342786,'deals-mobile','.fake-input','overflow','hidden','','',''),(342787,'deals-mobile','.hide-page','align-items','center','','',''),(342788,'deals-mobile','.hide-page','background-color','rgba(255, 255, 255, 0.7)','','',''),(342789,'deals-mobile','.hide-page','height','100','','',''),(342790,'deals-mobile','.hide-page','height_measure','%','','',''),(342791,'deals-mobile','.hide-page','justify-content','center','','',''),(342792,'deals-mobile','.hide-page','left','0','','',''),(342793,'deals-mobile','.hide-page','position','fixed','','',''),(342794,'deals-mobile','.hide-page','top','0','','',''),(342795,'deals-mobile','.hide-page','width','100','','',''),(342796,'deals-mobile','.hide-page','width_measure','%','','',''),(342797,'deals-mobile','.hide-page','z-index','100000','','',''),(342798,'deals-mobile','.hide-page','display','flex','','',''),(342831,'watch-mobile','.b-info .danger-message','color','$attention-color','','','.b-info'),(342832,'watch-mobile','.b-info .info-message','color','$message-color','','','.b-info'),(342833,'watch-mobile','.b-info .success-message','color','$success-color','','','.b-info'),(342834,'watch-mobile','.b-info .warning-message','color','$warning-color','','','.b-info'),(342847,'printshop-mobile','.b-info .danger-message','color','$attention-color','','','.b-info'),(342848,'printshop-mobile','.b-info .info-message','color','$message-color','','','.b-info'),(342849,'printshop-mobile','.b-info .success-message','color','$success-color','','','.b-info'),(342850,'printshop-mobile','.b-info .warning-message','color','$warning-color','','','.b-info'),(342855,'deals-mobile','.b-info .danger-message','color','$attention-color','','','.b-info'),(342856,'deals-mobile','.b-info .info-message','color','$message-color','','','.b-info'),(342857,'deals-mobile','.b-info .success-message','color','$success-color','','','.b-info'),(342858,'deals-mobile','.b-info .warning-message','color','$warning-color','','','.b-info'),(342985,'watch-mobile','.w-search .button-search','padding-top','6','','','.w-search'),(342986,'watch-mobile','.w-search .button-search','padding-right','0','','','.w-search'),(342987,'watch-mobile','.w-search .button-search','padding-bottom','6','','','.w-search'),(342988,'watch-mobile','.w-search .button-search','padding-left','0','','','.w-search'),(342998,'watch-mobile','.w-search .search form','background-color','$background-color-1','','','.w-search'),(342999,'watch-mobile','.w-search .search form','left','-25','','','.w-search'),(343000,'watch-mobile','.w-search .search form','left_measure','vw','','','.w-search'),(343001,'watch-mobile','.w-search .search form','position','relative','','','.w-search'),(343002,'watch-mobile','.w-search .search form','top','100','','','.w-search'),(343003,'watch-mobile','.w-search .search form','top_measure','%','','','.w-search'),(343004,'watch-mobile','.w-search .search form','width','100','','','.w-search'),(343005,'watch-mobile','.w-search .search form','width_measure','vw','','','.w-search'),(343006,'watch-mobile','.w-search .search form','display','none','','','.w-search'),(343007,'watch-mobile','.w-search .search form','padding-top','5','','','.w-search'),(343008,'watch-mobile','.w-search .search form','padding-right','5','','','.w-search'),(343009,'watch-mobile','.w-search .search form','padding-bottom','5','','','.w-search'),(343010,'watch-mobile','.w-search .search form','padding-left','5','','','.w-search'),(343011,'watch-mobile','.w-search .search.opened form','display','block','','','.w-search'),(343012,'watch-mobile','.w-search .suggest','left_measure','vw','','','.w-search'),(343013,'watch-mobile','.w-search .suggest','max-height','400','','','.w-search'),(343015,'watch-mobile','.w-search .background','background-color','$background-3','','','.w-search'),(343016,'watch-mobile','.w-search .background','bottom','0','','','.w-search'),(343017,'watch-mobile','.w-search .background','left','0','','','.w-search'),(343018,'watch-mobile','.w-search .background','position','fixed','','','.w-search'),(343019,'watch-mobile','.w-search .background','right','0','','','.w-search'),(343020,'watch-mobile','.w-search .background','top','0','','','.w-search'),(343021,'watch-mobile','.w-search .background','z-index','2','','','.w-search'),(343022,'watch-mobile','.w-search .background','display','none','','','.w-search'),(343023,'watch-mobile','.w-search .background.show','display','block','','','.w-search'),(343024,'watch-mobile','.w-search .extra','font-size','16','3','','.w-search'),(343025,'watch-mobile','.w-search .extra','content','\\f115','3','','.w-search'),(343026,'watch-mobile','.w-search .extra','font-family','fontAwesome','3','','.w-search'),(343027,'watch-mobile','.w-search .extra','margin-right','10','3','','.w-search'),(343028,'watch-mobile','.w-search .extra','font-size','12','','','.w-search'),(343029,'watch-mobile','.w-search .products','width','100','','','.w-search'),(343030,'watch-mobile','.w-search .products','width_measure','%','','','.w-search'),(343033,'watch-mobile','.w-search .products','padding-bottom','15','','','.w-search'),(343041,'watch-mobile','.w-search .wrap','width','100','','','.w-search'),(343042,'watch-mobile','.w-search .wrap','width_measure','%','','','.w-search'),(343043,'watch-mobile','.w-search .wrap','padding-right','15','','','.w-search'),(343044,'watch-mobile','.w-search .wrap .image','content','\\f115','3','','.w-search'),(343045,'watch-mobile','.w-search .wrap .image','font-family','fontAwesome','3','','.w-search'),(343048,'watch-mobile','.w-search .wrap .info-suggest .image','font-size','12','3','','.w-search'),(343049,'watch-mobile','.w-search .wrap .info-suggest .image','content','\\f219','3','','.w-search'),(343050,'watch-mobile','.w-search .wrap .info-suggest .image','font-family','fontAwesome','3','','.w-search'),(343052,'watch-mobile','.w-search .image','max-height','40','','','.w-search'),(343053,'watch-mobile','.w-search .name','font-size','12','','','.w-search'),(343054,'watch-mobile','.w-search .suggest','display','flex','','','.w-search'),(343055,'watch-mobile','.w-search .suggest','top','100','','','.w-search'),(343056,'watch-mobile','.w-search .suggest','top_measure','%','','','.w-search'),(343132,'watch-mobile','.w-search form','position','relative','','','.w-search'),(343133,'watch-mobile','.w-search form','z-index','3','','','.w-search'),(343362,'watch-mobile','.w-search .products','padding-left','15','','','.w-search'),(470194,'furniture-mobile','.b-slick .slick-slider','-khtml-user-select','none','','','.b-slick'),(470195,'furniture-mobile','.b-fancybox .fancybox-skin','-moz-border-radius','4px','','','.b-fancybox'),(470196,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','-moz-border-radius','15px','','','.b-fancybox'),(470197,'furniture-mobile','.b-fancybox .fancybox-opened .fancybox-skin','-moz-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(470198,'furniture-mobile','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-moz-box-sizing','border-box','','','.b-select-suggest'),(470199,'furniture-mobile','.b-rating .glyphicon','-moz-osx-font-smoothing','grayscale','','','.b-rating'),(470200,'furniture-mobile','.b-products-listing .hover-box-content','-moz-transform','rotate( 45deg )','3','','.b-products-listing'),(470201,'furniture-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-moz-transform','translate3d(0, 0, 0)','','','.b-slick'),(470202,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-moz-user-select','none','','','.b-select-suggest'),(470203,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','-moz-user-select','none','','','.b-select-suggest'),(470204,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','-moz-user-select','none','','','.b-select-suggest'),(470205,'furniture-mobile','.b-slick .slick-slider','-moz-user-select','none','','','.b-slick'),(470206,'furniture-mobile','.b-slick .slick-slider','-ms-touch-action','pan-y','','','.b-slick'),(470207,'furniture-mobile','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(470208,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(470209,'furniture-mobile','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(470210,'furniture-mobile','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(470211,'furniture-mobile','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(470212,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(470213,'furniture-mobile','.b-products-listing .hover-box-content','-ms-transform','rotate( 45deg )','3','','.b-products-listing'),(470214,'furniture-mobile','.w-cart .cart-box-link','-ms-transform','rotate(45deg)','4','','.w-cart'),(470215,'furniture-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-ms-transform','translate3d(0, 0, 0)','','','.b-slick'),(470216,'furniture-mobile','.w-account .my-acc-link','-ms-transform','rotate(45deg)','4','','.w-account'),(470217,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','-ms-user-select','none','','','.b-select-suggest'),(470218,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','-ms-user-select','none','','','.b-select-suggest'),(470219,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-ms-user-select','none','','','.b-select-suggest'),(470220,'furniture-mobile','.b-slick .slick-slider','-ms-user-select','none','','','.b-slick'),(470221,'furniture-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-o-transform','translate3d(0, 0, 0)','','','.b-slick'),(470222,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','-webkit-border-radius','15px','','','.b-fancybox'),(470223,'furniture-mobile','.b-fancybox .fancybox-skin','-webkit-border-radius','4px','','','.b-fancybox'),(470224,'furniture-mobile','.b-fancybox .fancybox-opened .fancybox-skin','-webkit-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(470225,'furniture-mobile','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-webkit-box-sizing','border-box','','','.b-select-suggest'),(470226,'furniture-mobile','.b-rating .glyphicon','-webkit-font-smoothing','antialiased','','','.b-rating'),(470227,'furniture-mobile','.b-fancybox .fancybox-type-iframe .fancybox-inner','-webkit-overflow-scrolling','touch','','','.b-fancybox'),(470228,'furniture-mobile','.b-fancybox .fancybox-nav','-webkit-tap-highlight-color','rgba(0,0,0,0)','','','.b-fancybox'),(470229,'furniture-mobile','.b-select-suggest .select2-results','-webkit-tap-highlight-color','rgba(0, 0, 0, 0)','','','.b-select-suggest'),(470230,'furniture-mobile','.b-slick .slick-slider','-webkit-tap-highlight-color','transparent','','','.b-slick'),(470231,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(470232,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(470233,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','-webkit-touch-callout','none','','','.b-select-suggest'),(470234,'furniture-mobile','.b-slick .slick-slider','-webkit-touch-callout','none','','','.b-slick'),(470235,'furniture-mobile','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(470236,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(470237,'furniture-mobile','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(470238,'furniture-mobile','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(470239,'furniture-mobile','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(470240,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(470241,'furniture-mobile','.b-products-listing .hover-box-content','-webkit-transform','rotate( 45deg )','3','','.b-products-listing'),(470242,'furniture-mobile','.w-cart .cart-box-link','-webkit-transform','rotate(45deg)','4','','.w-cart'),(470243,'furniture-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-webkit-transform','translate3d(0, 0, 0)','','','.b-slick'),(470244,'furniture-mobile','.w-account .my-acc-link','-webkit-transform','rotate(45deg)','4','','.w-account'),(470245,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','-webkit-user-select','none','','','.b-select-suggest'),(470246,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-user-select','none','','','.b-select-suggest'),(470247,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','-webkit-user-select','none','','','.b-select-suggest'),(470248,'furniture-mobile','.b-slick .slick-slider','-webkit-user-select','none','','','.b-slick'),(470249,'furniture-mobile','.p-wedding-registry-search .search-form','align-items','center','','','.p-wedding-registry-search'),(470250,'furniture-mobile','.w-promotions .promo-cart-discount','align-items','flex-start','','','.w-promotions'),(470251,'furniture-mobile','.b-messages .email-line','align-items','center','','','.b-messages'),(470252,'furniture-mobile','.p-quick-order-index .quick-order-total','align-items','center','','','.p-quick-order-index'),(470253,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(470254,'furniture-mobile','.b-products-listing .select-attributes','align-items','center','','','.b-products-listing'),(470255,'furniture-mobile','.order-summary .price-row','align-items','baseline','','','.order-summary'),(470256,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(470257,'furniture-mobile','.w-banner .carousel .top-center','align-items','flex-start','','','.w-banner'),(470258,'furniture-mobile','.w-banner .carousel .top-left','align-items','flex-start','','','.w-banner'),(470259,'furniture-mobile','.w-banner .carousel .top-right','align-items','flex-start','','','.w-banner'),(470260,'furniture-mobile','.w-banner .carousel .middle-right','align-items','center','','','.w-banner'),(470261,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(470262,'furniture-mobile','.w-personal-gift-status-bar .timeline','align-items','center','','','.w-personal-gift-status-bar'),(470263,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(470264,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block','align-items','center','','','.b-products-listing'),(470265,'furniture-mobile','.b-products-listing .promos-info .promo-item','align-items','center','','','.b-products-listing'),(470266,'furniture-mobile','.w-taxable form','align-items','center','','','.w-taxable'),(470267,'furniture-mobile','.w-cart-listing .item .gift-wrap label','align-items','center','','','.w-cart-listing'),(470268,'furniture-mobile','.w-banner .carousel .middle-left','align-items','center','','','.w-banner'),(470269,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(470270,'furniture-mobile','.w-banner .carousel .middle-center','align-items','center','','','.w-banner'),(470271,'furniture-mobile','.w-banner .carousel .bottom-right','align-items','flex-end','','','.w-banner'),(470272,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(470273,'furniture-mobile','.w-banner .carousel .bottom-center','align-items','flex-end','','','.w-banner'),(470274,'furniture-mobile','.w-banner .carousel .bottom-left','align-items','flex-end','','','.w-banner'),(470275,'furniture-mobile','.b-product-images .media-popup .mp-big-images .item','align-items','center','','','.b-product-images'),(470276,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(470277,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .languages','align-items','center','','','.b-menu-style-2'),(470278,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','align-items','center','','','.b-menu-style-2'),(470279,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies','align-items','center','','','.b-menu-style-2'),(470280,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','align-items','center','','','.b-menu-style-2'),(470281,'furniture-mobile','.w-account-subscription .subscription-variant','align-items','center','','','.w-account-subscription'),(470282,'furniture-mobile','.w-catalog-compare .cross-box .different-all','align-items','flex-end','','','.w-catalog-compare'),(470283,'furniture-mobile','.w-product-images .img-holder','align-items','center','','','.w-product-images'),(470284,'furniture-mobile','.w-cart .cart-box-link','align-items','center','','','.w-cart'),(470285,'furniture-mobile','.w-account .my-acc-link','align-items','center','','','.w-account'),(470286,'furniture-mobile','.w-quote .cart-box-link','align-items','center','','','.w-quote'),(470287,'furniture-mobile','.w-product-images .additional-vertical','align-items','stretch','','','.w-product-images'),(470288,'furniture-mobile','.w-files-catalog-widgets-files-catalog .image','align-items','center','','','.w-files-catalog-widgets-files-catalog'),(470289,'furniture-mobile','.w-sample .cart-box-link','align-items','center','','','.w-sample'),(470290,'furniture-mobile','.w-filters-simple .filter-row','align-items','flex-end','','','.w-filters-simple'),(470291,'furniture-mobile','.w-account-customer-additional-field .field-type-text, .w-account-customer-additional-field .field-type-file','align-items','center','','','.w-account-customer-additional-field'),(470292,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','align-items','center','','','.b-menu-style-1'),(470293,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(470294,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(470295,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(470296,'furniture-mobile','.w-predefined-promotion .promo-cart-discount','align-items','flex-start','','','.w-predefined-promotion'),(470297,'furniture-mobile','.w-supplier-purchase-supplier-products .item','align-items','center','','','.w-supplier-purchase-supplier-products'),(470298,'furniture-mobile','.w-supplier-purchase-supplier-products .qty_col','align-items','center','','','.w-supplier-purchase-supplier-products'),(470299,'furniture-mobile','.w-search .image','align-items','center','','','.w-search'),(470300,'furniture-mobile','.checkout-order-confirmation .price-row','align-items','baseline','','','.checkout-order-confirmation'),(470301,'furniture-mobile','.w-cart-listing .remove','align-self','center','','','.w-cart-listing'),(470302,'furniture-mobile','.b-preloader .preloader','animation','load8 1.5s infinite linear','3','','.b-preloader'),(470303,'furniture-mobile','.w-product-customers-activity .customers-activity','animation','customers-activity-show 4s ease-in-out','','','.w-product-customers-activity'),(470304,'furniture-mobile','.w-product-customers-activity .customers-activity.closed','animation','customers-activity-hide 2s ease-in-out','','','.w-product-customers-activity'),(470305,'furniture-mobile','.b-products-listing .btn-preloader','animation','load8 1.5s infinite linear','3','','.b-products-listing'),(470306,'furniture-mobile','.b-products-listing .loader','animation','load8 1.5s infinite linear','4','','.b-products-listing'),(470307,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.p-quick-order-index'),(470308,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(470309,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','background','transparent','','','.b-fancybox'),(470310,'furniture-mobile','.w-filters .ui-slider','background','none','','','.w-filters'),(470311,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','background','none','','','.b-select-suggest'),(470312,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.p-quick-order-index'),(470313,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(470314,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(470315,'furniture-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','background','none','','','.b-products-listing'),(470316,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(470317,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background','transparent','','','.b-select-suggest'),(470318,'furniture-mobile','.b-select-suggest .select2-results .select2-highlighted em','background','transparent','','','.b-select-suggest'),(470319,'furniture-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','background','transparent','','','.b-select-suggest'),(470320,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(470321,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.b-data-table'),(470322,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(470323,'furniture-mobile','.w-filters .ui-slider-range','background','none','','','.w-filters'),(470324,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.b-data-table'),(470325,'furniture-mobile','.w-top-categories .categories h2','background','none','','','.w-top-categories'),(470326,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','background','none','','','.b-product-images'),(470327,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','background','none','','','.b-menu-style-2'),(470328,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','background','none','','','.b-menu-style-2'),(470329,'furniture-mobile','.batchPr .checkbox input + span','background','none','','','.batchPr'),(470330,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','background','none','','','.w-catalog-compare'),(470331,'furniture-mobile','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','background','none','','','.b-products-listing'),(470332,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','background','none','','','.b-products-listing'),(470333,'furniture-mobile','.w-product-personal-catalog-button .btn','background','none','','','.w-product-personal-catalog-button'),(470334,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','background','none','','','.b-products-listing'),(470335,'furniture-mobile','.w-product-designer-designer .prodDesignerType','background','none','','','.w-product-designer-designer'),(470336,'furniture-mobile','.w-communication-post .btn.refresh','background','none','','','.w-communication-post'),(470337,'furniture-mobile','.w-rma-returns-history .column:last-child .title','background','transparent','','','.w-rma-returns-history'),(470338,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','background','none','','','.w-rma-returns-history'),(470339,'furniture-mobile','.mainBanner .bottomBox .btn','background','none','','','.mainBanner'),(470340,'furniture-mobile','.mainBanner .topBox > .right','background','linear-gradient( 90deg, rgba(200,199,212,1) 0%, rgba(181,186,205,1) 22%, rgba(193,193,207,1) 50%, rgba(173,177,197,1) 100%)','','','.mainBanner'),(470341,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','background','linear-gradient(-45deg, rgba(255,214,0,1) 25%, rgba(255,218,3,1) 39%, rgba(255,221,5,1) 51%, rgba(255,232,11,1) 76%, rgba(255,235,14,1) 100%)','','','.lowestPricedBox'),(470342,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','background','none','','','.lowestPricedBox'),(470343,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','background-clip','padding-box','','','.b-select-suggest'),(470344,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','background-clip','padding-box','','','.b-select-suggest'),(470345,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','background-clip','padding-box','','','.b-select-suggest'),(470347,'furniture-mobile','.p-account-trade-form .trade-form-area','background-color','$background-6','','','.p-account-trade-form'),(470348,'furniture-mobile','.b-table .table .headings td','background-color','$background-6','','','.b-table'),(470349,'furniture-mobile','.b-table .table .headings td','background-color','$background-6','','','.b-table'),(470350,'furniture-mobile','.w-cart .current-multi-cart.item','background-color','$background-6','','','.w-cart'),(470351,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','background-color','$background-7','','','.w-compare-box-item'),(470352,'furniture-mobile','.b-fancybox .filter-listing-loader','background-color','$background-8','','','.b-fancybox'),(470353,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','$background-6','','','.p-quick-order-index'),(470354,'furniture-mobile','.w-promotions .promo-item','background-color','$background-6','','','.w-promotions'),(470355,'furniture-mobile','.w-account .account-dropdown','background-color','$background-7','','','.w-account'),(470356,'furniture-mobile','.p-reviews-info .review-info-text','background-color','$background-7','','','.p-reviews-info'),(470357,'furniture-mobile','.p-reviews-info .review-info-image','background-color','$background-7','','','.p-reviews-info'),(470358,'furniture-mobile','.p-reviews-info .review-info-content','background-color','$background-6','','','.p-reviews-info'),(470359,'furniture-mobile','.testimonials .review','background-color','$background-6','','',''),(470360,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','background-color','$background-4','','','.w-compare-box-item'),(470361,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','background-color','$background-7','','','.w-compare-box-item'),(470362,'furniture-mobile','.w-chat .w-chat-box','background-color','$background-2','','','.w-chat'),(470363,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','background-color','$background-7','','','.w-promotions'),(470364,'furniture-mobile','.w-promotions .prom-multi-discount .promo-product','background-color','$background-7','','','.w-promotions'),(470365,'furniture-mobile','.w-promotions .nextdiscount .promo-for-each','background-color','$background-6','','','.w-promotions'),(470366,'furniture-mobile','.w-promotions .nextdiscount .content > div','background-color','$background-7','','','.w-promotions'),(470367,'furniture-mobile','.w-promotions .promo-salemaker .item','background-color','$background-7','','','.w-promotions'),(470368,'furniture-mobile','.w-promotions .promo-salemaker .discount','background-color','$background-7','','','.w-promotions'),(470369,'furniture-mobile','.w-promotions .promo-cart-discount .slave .item','background-color','$background-7','','','.w-promotions'),(470370,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','background-color','$background-7','','','.w-promotions'),(470371,'furniture-mobile','.b-preloader .preloader','background-color','$background-8','','','.b-preloader'),(470372,'furniture-mobile','.w-menu-slider .menu-ico','background-color','$background-2','','','.w-menu-slider'),(470373,'furniture-mobile','.w-cart-compare .attributes-cell','background-color','$background-6','','','.w-cart-compare'),(470374,'furniture-mobile','.w-cart-checkout-btn + .w-image','background-color','$background-6','','','.w-cart-checkout-btn'),(470375,'furniture-mobile','.w-menu-slider > ul > li.active > ul','background-color','$background-2','','','.w-menu-slider'),(470376,'furniture-mobile','.w-menu-style-1 > ul','background-color','$background-2','','','.w-menu-style-1'),(470377,'furniture-mobile','.b-messages .msv_history','background-color','$background-6','','','.b-messages'),(470378,'furniture-mobile','.b-messages .email-heading','background-color','$background-6','','','.b-messages'),(470379,'furniture-mobile','.w-sale .left-count','background-color','$background-2','','','.w-sale'),(470380,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','background-color','$background-6','','','.b-messages'),(470381,'furniture-mobile','.w-sale .left-count-days','background-color','$background-7','','','.w-sale'),(470382,'furniture-mobile','.w-reviews .author','background-color','$background-7','','','.w-reviews'),(470383,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.p-quick-order-index'),(470384,'furniture-mobile','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','background-color','$background-6','','','.order-summary'),(470385,'furniture-mobile','.p-reviews-info .review-info-image','background-color','$background-7','','','.p-reviews-info'),(470386,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li ul','background-color','$background-2','','','.w-menu-style-1'),(470387,'furniture-mobile','.w-menu-style-1 > ul > li > ul','background-color','$background-2','','','.w-menu-style-1'),(470388,'furniture-mobile','.w-menu-style-1 .menu-ico','background-color','$background-2','','','.w-menu-style-1'),(470389,'furniture-mobile','.b-fancybox .fancybox-close','background-color','$background-3','','','.b-fancybox'),(470390,'furniture-mobile','.b-messages .msv_to_cc','background-color','$background-6','','','.b-messages'),(470391,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','background-color','$backgroond-transparent','3','','.b-switch'),(470392,'furniture-mobile','.w-menu-style-1 > ul','background-color','$background-2','','','.w-menu-style-1'),(470393,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li','background-color','$background-2','1','','.w-menu-style-1'),(470394,'furniture-mobile','.p-account-trade-form .trade-form-area','background-color','$background-6','','','.p-account-trade-form'),(470395,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','background-color','$background-6','','','.p-account-subscription-historyinfo'),(470396,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','background-color','$background-2','','','.w-checkout-shipping-choice'),(470397,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','background-color','$background-6','','','.w-upload-customer-id-upload-customer-id-form'),(470398,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','background-color','$background-7','','','.w-upload-customer-id-upload-customer-id-form'),(470399,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','background-color','$background-6','3','','.b-switch'),(470400,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','background-color','$background-4','','','.w-compare-box-item'),(470401,'furniture-mobile','.w-menu .hided.menu','background-color','inherit','','','.w-menu'),(470402,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li > ul','background-color','$background-7','','','.w-menu-horizontal'),(470403,'furniture-mobile','.w-menu-slider > ul','background-color','$background-2','','','.w-menu-slider'),(470404,'furniture-mobile','.w-menu-slider > ul > li > ul','background-color','$background-2','','','.w-menu-slider'),(470405,'furniture-mobile','.w-menu-slider .menu-ico','background-color','$background-2','','','.w-menu-slider'),(470407,'furniture-mobile','.w-sale .left-count-days','background-color','$background-7','','','.w-sale'),(470408,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','background-color','$background-3','','','.b-fancybox'),(470409,'furniture-mobile','.b-table .table .headings td','background-color','$background-6','','','.b-table'),(470410,'furniture-mobile','.b-info-popup .info-popup div','background-color','$background-7','','','.b-info-popup'),(470411,'furniture-mobile','.w-menu .hided.menu','background-color','inherit','','','.w-menu'),(470412,'furniture-mobile','.w-menu-slider > ul > li > ul','background-color','$background-2','','','.w-menu-slider'),(470413,'furniture-mobile','.w-menu-style-1 > ul > li > ul','background-color','$background-2','','','.w-menu-style-1'),(470414,'furniture-mobile','.w-menu-slider > ul > li.active > ul','background-color','$background-2','','','.w-menu-slider'),(470415,'furniture-mobile','.w-menu-slider > ul','background-color','$background-2','','','.w-menu-slider'),(470416,'furniture-mobile','.w-menu-slider > ul','background-color','$background-2','','','.w-menu-slider'),(470417,'furniture-mobile','.p-reviews-info .review-info-image','background-color','$background-7','','','.p-reviews-info'),(470418,'furniture-mobile','.p-reviews-info .review-info-content','background-color','$background-6','','','.p-reviews-info'),(470419,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li ul','background-color','$background-2','','','.w-menu-style-1'),(470420,'furniture-mobile','.w-menu-style-1 .menu-ico','background-color','$background-2','','','.w-menu-style-1'),(470421,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li','background-color','$background-2','1','','.w-menu-style-1'),(470422,'furniture-mobile','.w-sale .badge','background-color','$background-2','','','.w-sale'),(470423,'furniture-mobile','.w-sale .left-count-days','background-color','$background-7','','','.w-sale'),(470424,'furniture-mobile','.w-menu-slider > ul > li > ul','background-color','$background-2','','','.w-menu-slider'),(470425,'furniture-mobile','.w-filters .ui-slider','background-color','$background-8','','','.w-filters'),(470426,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg','background-color','$background-6','','','.b-switch'),(470427,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-color','$background-7','','','.w-wedding-registry-widgets-photos'),(470428,'furniture-mobile','.p-account-trade-form .trade-form-area','background-color','$background-6','','','.p-account-trade-form'),(470429,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','background-color','$background-6','','','.p-account-subscription-historyinfo'),(470430,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','background-color','$background-4','','','.w-compare-box-item'),(470431,'furniture-mobile','.b-email .heading-products','background-color','$background-6','','','.b-email'),(470432,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-color','$background-6','','','.b-select-suggest'),(470433,'furniture-mobile','.w-reviews .review','background-color','$background-7','','','.w-reviews'),(470434,'furniture-mobile','.w-sale .badge','background-color','$background-2','','','.w-sale'),(470435,'furniture-mobile','.w-search .suggest','background-color','$background-7','','','.w-search'),(470436,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','background-color','$background-6','','','.p-account-subscription-historyinfo'),(470437,'furniture-mobile','.p-quick-order-index .all-scroll-div','background-color','$background-2','','','.p-quick-order-index'),(470438,'furniture-mobile','.w-menu .hided.menu','background-color','inherit','','','.w-menu'),(470439,'furniture-mobile','.btn-1','background-color','$background-9','','',''),(470441,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','$background-7','','','.b-dropdown'),(470442,'furniture-mobile','.w-sale .badge','background-color','$background-2','','','.w-sale'),(470443,'furniture-mobile','.w-menu-slider > ul > li.active > ul','background-color','$background-2','','','.w-menu-slider'),(470444,'furniture-mobile','.w-menu-style-1 > ul','background-color','$background-2','','','.w-menu-style-1'),(470445,'furniture-mobile','.w-menu-style-1 .menu-ico','background-color','$background-2','','','.w-menu-style-1'),(470446,'furniture-mobile','.w-menu-style-1 > ul > li','background-color','$background-2','1','','.w-menu-style-1'),(470447,'furniture-mobile','.w-menu-style-1 > ul > li > ul','background-color','$background-2','','','.w-menu-style-1'),(470448,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li','background-color','$background-2','1','','.w-menu-style-1'),(470449,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li ul','background-color','$background-2','','','.w-menu-style-1'),(470450,'furniture-mobile','.order-summary > div','background-color','$background-7','','','.order-summary'),(470451,'furniture-mobile','.b-fancybox .fancybox-overlay','background-color','$background-3','','','.b-fancybox'),(470452,'furniture-mobile','.b-bottom .popup-box.popupCompare','background-color','$background-6','','','.b-bottom'),(470453,'furniture-mobile','.w-languages .select','background-color','$background-7','','','.w-languages'),(470454,'furniture-mobile','.w-checkout-billing-address .same-address','background-color','$background-6','','','.w-checkout-billing-address'),(470455,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','$background-7','','','.b-dropdown'),(470456,'furniture-mobile','.p-reviews-info .review-info-image','background-color','$background-7','','','.p-reviews-info'),(470457,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','background-color','$background-9','','','.b-switch'),(470458,'furniture-mobile','.w-menu-slider > ul','background-color','$background-2','','','.w-menu-slider'),(470459,'furniture-mobile','.b-email .heading-products','background-color','$background-6','','','.b-email'),(470460,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','background-color','$backgroond-transparent','4','','.b-switch'),(470461,'furniture-mobile','.b-form .required-message','background-color','$background-6','','','.b-form'),(470462,'furniture-mobile','.w-menu-style-1 .menu-ico','background-color','$background-2','','','.w-menu-style-1'),(470463,'furniture-mobile','.w-menu-style-1 > ul > li','background-color','$background-2','1','','.w-menu-style-1'),(470464,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li','background-color','$background-2','1','','.w-menu-style-1'),(470465,'furniture-mobile','.w-menu-style-1 > ul > li > ul','background-color','$background-2','','','.w-menu-style-1'),(470466,'furniture-mobile','.w-sale .left-count-hours','background-color','$background-7','','','.w-sale'),(470467,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg.off','background-color','$background-9','','','.b-switch'),(470468,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-off','background-color','$background-9','3','','.b-switch'),(470469,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg.on','background-color','$background-4','','','.b-switch'),(470470,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-on','background-color','$background-9','4','','.b-switch'),(470471,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','background-color','$background-7','','','.b-switch'),(470472,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-on','background-color','$background-4','4','','.b-switch'),(470473,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-off','background-color','$background-4','3','','.b-switch'),(470474,'furniture-mobile','.w-product-reviews .reviews-list .review','background-color','$background-6','','','.w-product-reviews'),(470475,'furniture-mobile','.b-fancybox .fancybox-skin','background-color','$background-6','','','.b-fancybox'),(470476,'furniture-mobile','.b-info-popup .info-popup div','background-color','$background-7','3','','.b-info-popup'),(470477,'furniture-mobile','.w-menu-slider .menu-ico','background-color','$background-2','','','.w-menu-slider'),(470478,'furniture-mobile','.b-email .heading-products','background-color','$background-6','','','.b-email'),(470479,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','$background-7','','','.b-dropdown'),(470480,'furniture-mobile','.btn','background-color','$background-9','','',''),(470481,'furniture-mobile','.b-email .heading-products','background-color','$background-6','','','.b-email'),(470482,'furniture-mobile','.p-reviews-info .review-info-image','background-color','$background-7','','','.p-reviews-info'),(470483,'furniture-mobile','.p-reviews-info .review-info-content','background-color','$background-6','','','.p-reviews-info'),(470484,'furniture-mobile','.b-table .table .headings td','background-color','$background-6','','','.b-table'),(470485,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','background-color','$background-6','','','.p-account-subscription-historyinfo'),(470486,'furniture-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','background-color','$background-6','','','.b-select-suggest'),(470489,'furniture-mobile','.w-personal-gift-status-bar .timeline','background-color','$background-6','','','.w-personal-gift-status-bar'),(470490,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','background-color','$background-9','','','.b-switch'),(470491,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label','background-color','$background-7','3','','.b-switch'),(470492,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','background-color','$background-6','4','','.b-switch'),(470493,'furniture-mobile','.w-sale .left-count','background-color','$background-2','','','.w-sale'),(470494,'furniture-mobile','.w-sale .left-count-days','background-color','$background-7','','','.w-sale'),(470495,'furniture-mobile','.w-sale .left-count-hours','background-color','$background-7','','','.w-sale'),(470496,'furniture-mobile','.b-form .hide-billing-address','background-color','$background-7','','','.b-form'),(470497,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','background-color','$background-4','','','.w-compare-box-item'),(470498,'furniture-mobile','.p-reviews-info .review-info-text','background-color','$background-7','','','.p-reviews-info'),(470499,'furniture-mobile','.w-reviews-content .author','background-color','$background-6','','','.w-reviews-content'),(470500,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li','background-color','$background-2','1','','.w-menu-style-1'),(470501,'furniture-mobile','.w-menu-slider .menu-ico','background-color','$background-2','','','.w-menu-slider'),(470502,'furniture-mobile','.w-menu .menu .menu-ico','background-color','inherit','','','.w-menu'),(470503,'furniture-mobile','.w-personal-gift-status-bar .progress-bar-content','background-color','$background-2','','','.w-personal-gift-status-bar'),(470504,'furniture-mobile','.w-cart-compare .price-cell','background-color','$background-6','','','.w-cart-compare'),(470506,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','$background-7','','','.b-dropdown'),(470507,'furniture-mobile','.b-compare .popupCompare .pop-up-content','background-color','$background-6','','','.b-compare'),(470508,'furniture-mobile','.w-promotions .promo-cart-discount .master .item','background-color','$background-7','','','.w-promotions'),(470509,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','background-color','$background-7','','','.w-promotions'),(470510,'furniture-mobile','.w-sale .left-count-hours','background-color','$background-7','','','.w-sale'),(470511,'furniture-mobile','.b-bottom .around-pop-up','background-color','$background-2','','','.b-bottom'),(470512,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','background-color','$background-7','','','.w-compare-box-item'),(470513,'furniture-mobile','.w-cart-compare .price-block + .attributes-block .attributes-cell','background-color','$background-7','','','.w-cart-compare'),(470514,'furniture-mobile','.p-reviews-info .review-info-content','background-color','$background-6','','','.p-reviews-info'),(470515,'furniture-mobile','.p-reviews-info .review-info-text','background-color','$background-7','','','.p-reviews-info'),(470516,'furniture-mobile','.w-menu-slider .menu-ico','background-color','$background-2','','','.w-menu-slider'),(470517,'furniture-mobile','.w-sale .left-count-days','background-color','$background-7','','','.w-sale'),(470518,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li','background-color','$background-2','1','','.w-menu-style-1'),(470519,'furniture-mobile','.w-menu-style-1 > ul','background-color','$background-2','','','.w-menu-style-1'),(470520,'furniture-mobile','.w-menu-style-1 > ul > li','background-color','$background-2','1','','.w-menu-style-1'),(470521,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','$background-7','','','.b-dropdown'),(470522,'furniture-mobile','.b-bottom .pop-up-content','background-color','$background-7','','','.b-bottom'),(470523,'furniture-mobile','.w-menu .hided.menu','background-color','inherit','','','.w-menu'),(470524,'furniture-mobile','.w-menu-style-1 > ul','background-color','$background-2','','','.w-menu-style-1'),(470525,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li','background-color','$background-2','1','','.w-menu-style-1'),(470526,'furniture-mobile','.w-sale .left-count','background-color','$background-2','','','.w-sale'),(470527,'furniture-mobile','.w-sale .badge','background-color','$background-2','','','.w-sale'),(470528,'furniture-mobile','.b-bottom .popup-box','background-color','$background-7','','','.b-bottom'),(470529,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','background-color','$background-7','','','.b-dropdown'),(470531,'furniture-mobile','.w-menu-style-1 > ul > li > ul','background-color','$background-2','','','.w-menu-style-1'),(470532,'furniture-mobile','.w-menu-style-1 > ul > li','background-color','$background-2','1','','.w-menu-style-1'),(470533,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li','background-color','$background-2','1','','.w-menu-style-1'),(470534,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li','background-color','$background-2','1','','.w-menu-style-1'),(470536,'furniture-mobile','.w-product-customers-activity .customers-activity','background-color','$background-6','','','.w-product-customers-activity'),(470537,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','background-color','$background-4','','','.w-compare-box-item'),(470539,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li ul','background-color','$background-2','','','.w-menu-style-1'),(470540,'furniture-mobile','.w-menu .hided.menu','background-color','inherit','','','.w-menu'),(470541,'furniture-mobile','.w-checkout-shipping-choice input:checked + span','background-color','$background-2','','','.w-checkout-shipping-choice'),(470543,'furniture-mobile','.b-table .table .headings td','background-color','$background-6','','','.b-table'),(470544,'furniture-mobile','.b-autocomplete .ui-autocomplete li','background-color','$background-6','1','','.b-autocomplete'),(470545,'furniture-mobile','.p-reviews-info .review-info-text','background-color','$background-7','','','.p-reviews-info'),(470546,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label','background-color','$background-7','3','','.b-switch'),(470547,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','background-color','$background-4','','','.b-switch'),(470548,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-color','$background-6','','','.b-select-suggest'),(470549,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus','background-color','$background-6','','','.b-select-suggest'),(470550,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color','$background-7','','','.b-select-suggest'),(470551,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','background-color','$background-7','','','.b-select-suggest'),(470552,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-color','$background-6','','','.b-select-suggest'),(470553,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-color','$background-6','','','.b-select-suggest'),(470554,'furniture-mobile','.b-select-suggest .select2-results .select2-highlighted ul','background-color','$background-7','','','.b-select-suggest'),(470555,'furniture-mobile','.b-select-suggest .select2-more-results','background-color','$background-6','','','.b-select-suggest'),(470556,'furniture-mobile','.b-select-suggest .select2-more-results.select2-active','background-color','$background-6','','','.b-select-suggest'),(470557,'furniture-mobile','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','background-color','$background-6','','','.b-select-suggest'),(470558,'furniture-mobile','.b-select-suggest .select2-results .select2-highlighted','background-color','$background-6','','','.b-select-suggest'),(470559,'furniture-mobile','.b-select-suggest .select2-results .select2-disabled','background-color','$background-6','','','.b-select-suggest');
INSERT INTO `themes_styles` VALUES (470560,'furniture-mobile','.b-select-suggest .select2-results li em','background-color','$background-6','','','.b-select-suggest'),(470561,'furniture-mobile','.w-menu-horizontal > ul > li > ul','background-color','$background-7','','','.w-menu-horizontal'),(470562,'furniture-mobile','.w-menu-slider > ul > li > ul','background-color','$background-2','','','.w-menu-slider'),(470563,'furniture-mobile','.b-select-suggest .select2-search input','background-color','$background-7','','','.b-select-suggest'),(470564,'furniture-mobile','.b-select-suggest .select2-search input.select2-active','background-color','$background-7','','','.b-select-suggest'),(470565,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li','background-color','$background-2','1','','.w-menu-style-1'),(470566,'furniture-mobile','.b-select-suggest .select2-drop-mask','background-color','$background-7','','','.b-select-suggest'),(470567,'furniture-mobile','.b-select-suggest .select2-drop','background-color','$background-7','','','.b-select-suggest'),(470568,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li','background-color','$background-2','1','','.w-menu-style-1'),(470569,'furniture-mobile','.w-menu-slider .menu-ico','background-color','$background-2','','','.w-menu-slider'),(470570,'furniture-mobile','.w-menu .menu .menu-ico','background-color','inherit','','','.w-menu'),(470571,'furniture-mobile','.w-menu-style-1 > ul > li > ul','background-color','$background-2','','','.w-menu-style-1'),(470572,'furniture-mobile','.w-menu-slider > ul','background-color','$background-2','','','.w-menu-slider'),(470573,'furniture-mobile','.w-menu .hided.menu','background-color','inherit','','','.w-menu'),(470574,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','background-color','$background-7','','','.w-compare-box-item'),(470575,'furniture-mobile','.w-menu-style-1 .menu-ico','background-color','$background-2','','','.w-menu-style-1'),(470576,'furniture-mobile','.w-sale .left-count','background-color','$background-2','','','.w-sale'),(470577,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','$background-6','','','.b-data-table'),(470578,'furniture-mobile','.b-products-listing .loader','background-color','$background-8','3','','.b-products-listing'),(470579,'furniture-mobile','.w-catalog-b2b-add-button ','background-color','$background-2','','','.w-catalog-b2b-add-button'),(470580,'furniture-mobile','.b-products-listing .products-listing .qty-input.hidden','background-color','$background-7','3','','.b-products-listing'),(470581,'furniture-mobile','.checkbox input:checked + span','background-color','$background-4','','',''),(470582,'furniture-mobile','.w-blog-widget-tag-cloud a','background-color','$background-6','','','.w-blog-widget-tag-cloud'),(470583,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_img','background-color','$background-7','','','.w-blog-widget-related-posts-by-category'),(470584,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_content','background-color','$background-7','','','.w-blog-widget-related-posts-by-category'),(470585,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','background-color','$background-10','','','.w-blog-widget-related-posts'),(470586,'furniture-mobile','.w-blog-widget-related-posts .post_content a','background-color','$background-7','','','.w-blog-widget-related-posts'),(470587,'furniture-mobile','.w-blog-widget-post-share ','background-color','$background-10','4','','.w-blog-widget-post-share'),(470588,'furniture-mobile','.w-blog-widget-post-listing .post_image','background-color','$background-7','','','.w-blog-widget-post-listing'),(470589,'furniture-mobile','.w-blog-widget-post-listing .post_content','background-color','$background-7','','','.w-blog-widget-post-listing'),(470590,'furniture-mobile','.checkbox input + span','background-color','$background-7','','',''),(470591,'furniture-mobile','.b-autocomplete .ui-autocomplete','background-color','$background-7','','','.b-autocomplete'),(470592,'furniture-mobile','.w-currencies .select','background-color','$background-7','','','.w-currencies'),(470593,'furniture-mobile','.w-sale .left-count','background-color','$background-2','','','.w-sale'),(470594,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','background-color','$background-7','3','','.b-switch'),(470595,'furniture-mobile','.b-compare .compare-box-item','background-color','$background-6','','','.b-compare'),(470596,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','background-color','$background-6','','','.p-account-subscription-historyinfo'),(470597,'furniture-mobile','.w-search .button-search','background-color','transparent','','','.w-search'),(470598,'furniture-mobile','.w-sale .left-count-hours','background-color','$background-7','','','.w-sale'),(470599,'furniture-mobile','.w-menu-style-1 > ul','background-color','$background-2','','','.w-menu-style-1'),(470600,'furniture-mobile','.w-menu-slider > ul > li.active > ul','background-color','$background-2','','','.w-menu-slider'),(470601,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','background-color','$background-6','','','.w-communication-new-topic'),(470602,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','background-color','$background-6','','','.w-communication-new-topic'),(470603,'furniture-mobile','.b-datepicker .datepicker-dropdown','background-color','$background-7','','','.b-datepicker'),(470604,'furniture-mobile','.b-bottom .popup-heading','background-color','$background-6','','','.b-bottom'),(470605,'furniture-mobile','.w-personal-gift-status-bar .progress-bar','background-color','$background-7','','','.w-personal-gift-status-bar'),(470606,'furniture-mobile','.w-sale .left-count-hours','background-color','$background-7','','','.w-sale'),(470607,'furniture-mobile','.p-reviews-info .review-info-image','background-color','$background-7','','','.p-reviews-info'),(470608,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li ul','background-color','$background-2','','','.w-menu-style-1'),(470609,'furniture-mobile','.w-menu-style-1 > ul > li','background-color','$background-2','1','','.w-menu-style-1'),(470610,'furniture-mobile','.w-menu .menu .menu-ico','background-color','inherit','','','.w-menu'),(470611,'furniture-mobile','.b-table .table .headings td','background-color','$background-6','','','.b-table'),(470612,'furniture-mobile','.b-email .heading-products','background-color','$background-6','','','.b-email'),(470613,'furniture-mobile','.w-sale .left-count-hours','background-color','$background-7','','','.w-sale'),(470614,'furniture-mobile','.w-sale .badge','background-color','$background-2','','','.w-sale'),(470615,'furniture-mobile','.w-sale .left-count-days','background-color','$background-7','','','.w-sale'),(470616,'furniture-mobile','.w-sale .left-count','background-color','$background-2','','','.w-sale'),(470617,'furniture-mobile','.b-email .heading-products','background-color','$background-6','','','.b-email'),(470618,'furniture-mobile','.b-compare .vary td','background-color','$background-9','','','.b-compare'),(470619,'furniture-mobile','.p-account-trade-form .trade-form-area','background-color','$background-6','','','.p-account-trade-form'),(470620,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li','background-color','$background-2','1','','.w-menu-style-1'),(470622,'furniture-mobile','.w-cart .cart-content','background-color','$background-7','','','.w-cart'),(470623,'furniture-mobile','.w-cart .multicart a.name','background-color','$background-6','1','','.w-cart'),(470624,'furniture-mobile','.w-sale .badge','background-color','$background-2','','','.w-sale'),(470625,'furniture-mobile','.w-menu-style-1 .menu-ico','background-color','$background-2','','','.w-menu-style-1'),(470626,'furniture-mobile','.b-fancybox .fancybox-nav span','background-color','$background-3','','','.b-fancybox'),(470627,'furniture-mobile','.w-tabs .tab-a','background-color','$background-7','2','','.w-tabs'),(470628,'furniture-mobile','.w-menu-slider > ul','background-color','$background-2','','','.w-menu-slider'),(470629,'furniture-mobile','.w-menu-slider > ul > li.active > ul','background-color','$background-2','','','.w-menu-slider'),(470630,'furniture-mobile','.w-menu-slider > ul > li > ul','background-color','$background-2','','','.w-menu-slider'),(470631,'furniture-mobile','.w-menu .menu .menu-ico','background-color','inherit','','','.w-menu'),(470632,'furniture-mobile','.p-reviews-info .review-info-content','background-color','$background-6','','','.p-reviews-info'),(470633,'furniture-mobile','.p-account-trade-form .trade-form-area','background-color','$background-6','','','.p-account-trade-form'),(470634,'furniture-mobile','.w-menu .menu .menu-ico','background-color','inherit','','','.w-menu'),(470635,'furniture-mobile','.w-menu-style-1 > ul > li','background-color','$background-2','1','','.w-menu-style-1'),(470636,'furniture-mobile','.w-menu-slider > ul > li.active > ul','background-color','$background-2','','','.w-menu-slider'),(470637,'furniture-mobile','.w-filters .head-filter-widget','background-color','$background-2','2885','','.w-filters'),(470638,'furniture-mobile','.w-filters .ui-slider-range','background-color','$background-8','','','.w-filters'),(470639,'furniture-mobile','.w-catalog-paging ','background-color','$background-2','2','','.w-catalog-paging'),(470640,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','background-color','$background-4','','','.w-compare-box-item'),(470641,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li ul','background-color','$background-2','','','.w-menu-style-1'),(470643,'furniture-mobile','.w-menu-slider > ul > li > ul','background-color','$background-2','','','.w-menu-slider'),(470644,'furniture-mobile','body','background-color','$background-7','','',''),(470645,'furniture-mobile','.w-reviews-content .review','background-color','$background-6','','','.w-reviews-content'),(470646,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.b-data-table'),(470647,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','background-color','$background-7','','','.w-compare-box-item'),(470648,'furniture-mobile','.b-compare .popupCompare table','background-color','$background-7','','','.b-compare'),(470649,'furniture-mobile','.w-menu .menu .menu-ico','background-color','inherit','','','.w-menu'),(470650,'furniture-mobile','.p-reviews-info .review-info-content','background-color','$background-6','','','.p-reviews-info'),(470651,'furniture-mobile','.p-reviews-info .review-info-text','background-color','$background-7','','','.p-reviews-info'),(470652,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','background-color','$background-7','','','.w-compare-box-item'),(470653,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','background-color','$background-6','','','.p-account-subscription-historyinfo'),(470654,'furniture-mobile','.p-account-trade-form .trade-form-area','background-color','$background-6','','','.p-account-trade-form'),(470655,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','background-color','$background-7','','','.w-image-maps'),(470656,'furniture-mobile','.p-reviews-info .review-info-text','background-color','$background-7','','','.p-reviews-info'),(470657,'furniture-mobile','.b-product-images .mp-shadow','background-color','$background-3','','','.b-product-images'),(470658,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','background-color','$background-6','','','.b-menu-style-1'),(470659,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2','background-color','$background-6','','','.b-menu-style-1'),(470660,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .menu-content','background-color','$background-2','','','.b-menu-style-2'),(470661,'furniture-mobile','.b-trade-approval .steps-bar','background-color','$background-6','','','.b-trade-approval'),(470662,'furniture-mobile','.b-trade-approval .steps-bar li.current a','background-color','$background-2','','','.b-trade-approval'),(470663,'furniture-mobile','.batchPr .checkbox input:checked + span','background-color','$background-2','','','.batchPr'),(470664,'furniture-mobile','.batchPr .checkbox input + span','background-color','$background-7','','','.batchPr'),(470665,'furniture-mobile','.batchPr .btn-batch-remove','background-color','$background-5','','','.batchPr'),(470666,'furniture-mobile','.w-account-personal-catalog .list-switcher a','background-color','$background-7','2','','.w-account-personal-catalog'),(470667,'furniture-mobile','.w-catalog-compare tr','background-color','$background-6','1','','.w-catalog-compare'),(470668,'furniture-mobile','.w-catalog-compare .compare .checkbox input:checked + span','background-color','$background-7','','','.w-catalog-compare'),(470669,'furniture-mobile','.w-catalog-compare .compare-fix-bar','background-color','$background-7','','','.w-catalog-compare'),(470670,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','background-color','$background-7','2','','.w-catalog-compare'),(470671,'furniture-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','background-color','$background-7','','','.w-delivery-day'),(470672,'furniture-mobile','.w-delivery-day .left-count','background-color','$background-2','','','.w-delivery-day'),(470673,'furniture-mobile','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','background-color','$background-9','','','.b-cookie-notice'),(470674,'furniture-mobile','.w-cart .cart-box-link','background-color','$background-9','3','','.w-cart'),(470675,'furniture-mobile','.w-search .search-input','background-color','$background-7','','','.w-search'),(470676,'furniture-mobile','.w-currencies .currencies-title','background-color','$background-7','','','.w-currencies'),(470677,'furniture-mobile','.w-account .my-acc-link','background-color','$background-9','3','','.w-account'),(470678,'furniture-mobile','.w-account .account-dropdown','background-color','$background-6','3','','.w-account'),(470679,'furniture-mobile','.tripleBanner .w-html_box','background-color','$background-6','','','.tripleBanner'),(470680,'furniture-mobile','.tripleBanner .w-html_box','background-color','$background-9','3','','.tripleBanner'),(470681,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','background-color','$background-6','','','.b-slick'),(470682,'furniture-mobile','.w-search .search-ico','background-color','$background-9','2885,3','','.w-search'),(470683,'furniture-mobile','.menu-header .burger-icon','background-color','$background-9','2885','','.menu-header'),(470684,'furniture-mobile','.btn-2','background-color','$background-9','','',''),(470685,'furniture-mobile','.w-catalog-listing-look .b2b','background-color','$background-2','2','','.w-catalog-listing-look'),(470686,'furniture-mobile','.w-catalog-listing-look .grid','background-color','$background-2','2','','.w-catalog-listing-look'),(470687,'furniture-mobile','.w-catalog-listing-look .list','background-color','$background-2','2','','.w-catalog-listing-look'),(470688,'furniture-mobile','.LeftCategories ul li a','background-color','$background-10','1','','.LeftCategories'),(470689,'furniture-mobile','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','background-color','$background-10','','','.w-filters'),(470690,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-content','background-color','$background-10','4','','.b-products-listing'),(470691,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','background-color','$background-7','','','.b-products-listing'),(470692,'furniture-mobile','.w-subscribers .btn-submit','background-color','$background-9','','','.w-subscribers'),(470693,'furniture-mobile','.w-quote .cart-box-link','background-color','$background-9','3','','.w-quote'),(470694,'furniture-mobile','.w-quote .cart-content','background-color','$background-7','','','.w-quote'),(470695,'furniture-mobile','.w-quote .current-multi-cart.item','background-color','$background-6','','','.w-quote'),(470696,'furniture-mobile','.w-quote .multicart a.name','background-color','$background-6','1','','.w-quote'),(470697,'furniture-mobile','.w-social-links a','background-color','$background-8','','','.w-social-links'),(470698,'furniture-mobile','.w-product-sale-ends .left-count','background-color','$background-9','','','.w-product-sale-ends'),(470699,'furniture-mobile','.w-product-sale-ends .left-count-days','background-color','$background-7','','','.w-product-sale-ends'),(470700,'furniture-mobile','.w-product-sale-ends .left-count-hours','background-color','$background-7','','','.w-product-sale-ends'),(470701,'furniture-mobile','h1, .heading-1','background-color','$background-10','3','',''),(470702,'furniture-mobile','h1, .heading-1','background-color','$background-10','4','',''),(470703,'furniture-mobile','.w-compare ','background-color','$background-7','','','.w-compare'),(470704,'furniture-mobile','.w-files-catalog-widgets-files-catalog .name','background-color','$background-1','','','.w-files-catalog-widgets-files-catalog'),(470705,'furniture-mobile','.w-sample .cart-box-link','background-color','$background-9','3','','.w-sample'),(470706,'furniture-mobile','.w-sample .cart-content','background-color','$background-7','','','.w-sample'),(470707,'furniture-mobile','.w-sample .current-multi-cart.item','background-color','$background-6','','','.w-sample'),(470708,'furniture-mobile','.w-sample .multicart a.name','background-color','$background-6','1','','.w-sample'),(470709,'furniture-mobile','.w-cart-listing .points-earn','background-color','$background-6','','','.w-cart-listing'),(470710,'furniture-mobile','.w-cart-discount-coupon .btn','background-color','$background-7','','','.w-cart-discount-coupon'),(470711,'furniture-mobile','.w-cart-order-reference .btn','background-color','$background-7','','','.w-cart-order-reference'),(470712,'furniture-mobile','.w-cart-gift-certificate .btn','background-color','$background-7','','','.w-cart-gift-certificate'),(470713,'furniture-mobile','.w-cart-shipping-estimator .btn','background-color','$background-7','','','.w-cart-shipping-estimator'),(470714,'furniture-mobile','.heading-2','background-color','$background-10','3','',''),(470715,'furniture-mobile','.heading-2','background-color','$background-10','4','',''),(470716,'furniture-mobile','.b-pagination .pagination span','background-color','$background-2','2','','.b-pagination'),(470717,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .item','background-color','$background-9','','','.w-product-properties-filters-widgets-chosen-filters'),(470718,'furniture-mobile','.w-tabs .tab-a','background-color','$background-6','','','.w-tabs'),(470719,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','background-color','$background-10','3','','.p-quote-checkout-index'),(470720,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','background-color','$background-10','4','','.p-quote-checkout-index'),(470721,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','background-color','$background-10','3','','.p-sample-checkout-index'),(470722,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','background-color','$background-10','4','','.p-sample-checkout-index'),(470723,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','background-color','$background-7','','','.w-account-personal-catalog'),(470724,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent a','background-color','$background-9','','','.w-delivery-location-location-list'),(470725,'furniture-mobile','.w-sale-category .badge','background-color','$background-2','','','.w-sale-category'),(470726,'furniture-mobile','.w-sale-category .left-count','background-color','$background-2','','','.w-sale-category'),(470727,'furniture-mobile','.w-sale-category .left-count-days','background-color','$background-7','','','.w-sale-category'),(470728,'furniture-mobile','.w-sale-category .left-count-hours','background-color','$background-7','','','.w-sale-category'),(470729,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','background-color','$background-7','','','.w-product-properties-icons'),(470730,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content:before','background-color','$background-7','','','.w-product-properties-icons'),(470731,'furniture-mobile','.w-delivery-location-product-categories .name','background-color','$background-9','','','.w-delivery-location-product-categories'),(470732,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','background-color','$background-2','','','.w-wedding-registry-widgets-search-paging'),(470733,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','background-color','$background-6','','','.w-product-bonus-points'),(470734,'furniture-mobile','.w-product-designer-designer .grnamebox .title-sortable','background-color','$background-9','','','.w-product-designer-designer'),(470735,'furniture-mobile','.w-press-reviews-widgets-press-reviews ','background-color','$background-7','','','.w-press-reviews-widgets-press-reviews'),(470736,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .item','background-color','$background-7','','','.w-press-reviews-widgets-press-reviews-list'),(470737,'furniture-mobile','.w-support-system-listing .support-head','background-color','$background-6','','','.w-support-system-listing'),(470738,'furniture-mobile','.w-support-system-listing .product_icon','background-color','$background-7','','','.w-support-system-listing'),(470739,'furniture-mobile','.w-rma-returns-history .column .title','background-color','$background-8','','','.w-rma-returns-history'),(470740,'furniture-mobile','.w-rma-returns-history table.dataTable tbody tr.odd, .w-rma-returns-history table.dataTable.display tbody tr.odd','background-color','$background-6','','','.w-rma-returns-history'),(470741,'furniture-mobile','.w-rma-returns-history thead tr','background-color','$background-8','','','.w-rma-returns-history'),(470742,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-4','background-color','$background-6','','','.b-menu-style-1'),(470743,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-5','background-color','$background-6','','','.b-menu-style-1'),(470744,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-6','background-color','$background-10','','','.b-menu-style-1'),(470745,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li:hover > a','background-color','$background-6','','','.b-menu-style-1'),(470746,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li:hover > a','background-color','$background-6','','','.b-menu-style-1'),(470747,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-4 > li:hover > a','background-color','$background-6','','','.b-menu-style-1'),(470748,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-5 > li:hover > a','background-color','$background-10','','','.b-menu-style-1'),(470749,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','background-color','$background-6','','','.b-products-listing'),(470750,'furniture-mobile','.b-products-listing .promos-info .promo-name-span','background-color','$background-9','','','.b-products-listing'),(470751,'furniture-mobile','.w-predefined-promotion .nextdiscount .content > div','background-color','$background-7','','','.w-predefined-promotion'),(470752,'furniture-mobile','.w-predefined-promotion .nextdiscount .promo-for-each','background-color','$background-6','','','.w-predefined-promotion'),(470753,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-product','background-color','$background-7','','','.w-predefined-promotion'),(470754,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','background-color','$background-7','','','.w-predefined-promotion'),(470755,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .item','background-color','$background-7','','','.w-predefined-promotion'),(470756,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','background-color','$background-7','','','.w-predefined-promotion'),(470757,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','background-color','$background-7','','','.w-predefined-promotion'),(470758,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .item','background-color','$background-7','','','.w-predefined-promotion'),(470759,'furniture-mobile','.w-predefined-promotion .promo-item','background-color','$background-6','','','.w-predefined-promotion'),(470760,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','background-color','$background-7','','','.w-predefined-promotion'),(470761,'furniture-mobile','.w-predefined-promotion .promo-salemaker .item','background-color','$background-7','','','.w-predefined-promotion'),(470762,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner:nth-child(1) .ybg:before','background-color','$background-6','','','.lowestPricedBox'),(470763,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner:nth-child(2) .ybg:before','background-color','$background-10','','','.lowestPricedBox'),(470764,'furniture-mobile','.lowestPricedBox .w-banner .ybg','background-color','$background-7','3','','.lowestPricedBox'),(470765,'furniture-mobile','.shopByCollectionBox .content','background-color','$background-9','','','.shopByCollectionBox'),(470766,'furniture-mobile','.w-search .background','background-color','$background-3','','','.w-search'),(470767,'furniture-mobile','.w-search .opened','background-color','$background-3','3','','.w-search'),(470768,'furniture-mobile','.w-search .products','background-color','$background-7','','','.w-search'),(470769,'furniture-mobile','.w-search .products .item','background-color','$background-7','','','.w-search'),(470770,'furniture-mobile','.w-search .suggest','background-color','$background-7','4','','.w-search'),(470771,'furniture-mobile','.w-search .wrap','background-color','$background-6','','','.w-search'),(470772,'furniture-mobile','.account-order-history .orders-table th','background-color','$background-6','','','.account-order-history'),(470773,'furniture-mobile','.account-order-history .order_history_table th','background-color','$background-6','','','.account-order-history'),(470774,'furniture-mobile','.account-index .topAccount','background-color','$background-6','','','.account-index'),(470775,'furniture-mobile','.account-samples .orders-table th','background-color','$background-6','','','.account-samples'),(470776,'furniture-mobile','.account-samples .order_history_table th','background-color','$background-6','','','.account-samples'),(470777,'furniture-mobile','.catalog-product-wrap .prev-next-product','background-color','$background-8','','','.catalog-product-wrap'),(470778,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','background-color','$background-9','','','.checkout-index-wrap'),(470779,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','background-color','$background-10','3','','.checkout-index-wrap'),(470780,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','background-color','$background-10','4','','.checkout-index-wrap'),(470781,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.p-quick-order-index'),(470782,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color_important','important','','','.b-select-suggest'),(470783,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.b-data-table'),(470784,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-image','url(\'\')','','','.b-select-suggest'),(470785,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-image','none','','','.b-select-suggest'),(470786,'furniture-mobile','.b-select-suggest .select2-search input','background-image','url(\'\')','','','.b-select-suggest'),(470787,'furniture-mobile','.b-select-suggest .select2-more-results.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(470788,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(470789,'furniture-mobile','.b-select-suggest .select2-search input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(470790,'furniture-mobile','.b-select-suggest .select2-search-choice-close','background-image','url(\'\')','','','.b-select-suggest'),(470791,'furniture-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-image','url(\'\')','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(470792,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-image','none','','','.b-select-suggest'),(470793,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-image','none','','','.b-select-suggest'),(470794,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-image','none','','','.b-select-suggest'),(470795,'furniture-mobile','.b-select-suggest .select2-results li','background-image','none','','','.b-select-suggest'),(470796,'furniture-mobile','.p-wedding-registry-search .main-content','background-image','url(\'\')','','','.p-wedding-registry-search'),(470797,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-image','url(\'\')','','','.w-wedding-registry-widgets-photos'),(470798,'furniture-mobile','.account-order-history .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.account-order-history'),(470799,'furniture-mobile','.account-order-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.account-order-history-info'),(470800,'furniture-mobile','.account-index .moduleRowDue td','background-image','url(\'\')','','','.account-index'),(470801,'furniture-mobile','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.account-order-pay'),(470802,'furniture-mobile','.account-samples .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.account-samples'),(470803,'furniture-mobile','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.account-sample-info'),(470804,'furniture-mobile','.b-select-suggest .select2-search input','background-position','100% -21px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(470805,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-position','right -11px','1','','.b-select-suggest'),(470806,'furniture-mobile','.w-top-categories .image','background-position','50% 50%','','','.w-top-categories'),(470807,'furniture-mobile','.p-wedding-registry-search .main-content','background-position','50% 0','','','.p-wedding-registry-search'),(470808,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-position','top right','','','.b-select-suggest'),(470809,'furniture-mobile','.w-categories .image','background-position','50% 50%','','','.w-categories'),(470810,'furniture-mobile','.b-select-suggest .select2-search input','background-position','100% -22px','','','.b-select-suggest'),(470811,'furniture-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','background-position','50%','','','.w-wedding-registry-widgets-manage-banner'),(470812,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close','background-position','right -11px','','','.b-select-suggest'),(470813,'furniture-mobile','.b-select-suggest .select2-search-choice-close','background-position','top right','','','.b-select-suggest'),(470814,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close','background-position','right -11px','1','','.b-select-suggest'),(470815,'furniture-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow b','background-position','-18px 1px','','','.b-select-suggest'),(470816,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-position','center','','','.w-wedding-registry-widgets-photos'),(470817,'furniture-mobile','.tripleBanner .w-html_box','background-position','50% 50%','3','','.tripleBanner'),(470818,'furniture-mobile','.mainBanner .buttonBox','background-position-x','27%','','','.mainBanner'),(470819,'furniture-mobile','.b-select-suggest .select2-search input','background-position_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(470820,'furniture-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(470821,'furniture-mobile','.p-wedding-registry-search .main-content','background-repeat','no-repeat','','','.p-wedding-registry-search'),(470822,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','background-repeat','no-repeat','','','.b-select-suggest'),(470823,'furniture-mobile','.b-select-suggest .select2-search-choice-close','background-repeat','no-repeat','','','.b-select-suggest'),(470824,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(470825,'furniture-mobile','.b-select-suggest .select2-more-results.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(470826,'furniture-mobile','.b-select-suggest .select2-search input','background-repeat','no-repeat','','','.b-select-suggest'),(470827,'furniture-mobile','.b-select-suggest .select2-search input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(470828,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','','.b-select-suggest'),(470829,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','background-repeat','no-repeat','','','.w-wedding-registry-widgets-photos'),(470830,'furniture-mobile','.tripleBanner .w-html_box','background-repeat','no-repeat','3','','.tripleBanner'),(470831,'furniture-mobile','.mainBanner .bottomBox','background-repeat','no-repeat','','','.mainBanner'),(470832,'furniture-mobile','.mainBanner .buttonBox','background-repeat','no-repeat','','','.mainBanner'),(470833,'furniture-mobile','.mainBanner .title','background-repeat','no-repeat','3','','.mainBanner'),(470834,'furniture-mobile','.mainBanner .topBox > .right','background-repeat','no-repeat','3','','.mainBanner'),(470835,'furniture-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(470836,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat_important','important','','','.b-select-suggest'),(470837,'furniture-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','background-size','cover','','','.w-wedding-registry-widgets-manage-banner'),(470838,'furniture-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size','60px 40px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(470839,'furniture-mobile','.w-top-categories .image','background-size','cover','','','.w-top-categories'),(470840,'furniture-mobile','.w-categories .image','background-size','cover','','','.w-categories'),(470841,'furniture-mobile','.mainBanner .bottomBox','background-size','contain','','','.mainBanner'),(470842,'furniture-mobile','.mainBanner .buttonBox','background-size','12vw','','','.mainBanner'),(470843,'furniture-mobile','.mainBanner .topBox > .right','background-size','90%','2890,3','','.mainBanner'),(470844,'furniture-mobile','.mainBanner .buttonBox','background-size','15vw','2876','','.mainBanner'),(470845,'furniture-mobile','.mainBanner .topBox > .right','background-size','75%','2876,3','','.mainBanner'),(470846,'furniture-mobile','.mainBanner .buttonBox','background-size','21vw','2906','','.mainBanner'),(470847,'furniture-mobile','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(470848,'furniture-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','background_image','themes/furniture-mobile/img/wedding-registry-page-1.jpg','','','.w-wedding-registry-widgets-manage-banner'),(470849,'furniture-mobile','.tripleBanner .returns.w-html_box','background_image','themes/furniture-mobile/img/returns.webp','3','','.tripleBanner'),(470850,'furniture-mobile','.tripleBanner .warranty.w-html_box','background_image','themes/furniture-mobile/img/warranty.webp','3','','.tripleBanner'),(470851,'furniture-mobile','.tripleBanner .track.w-html_box','background_image','themes/furniture-mobile/img/track.webp','3','','.tripleBanner'),(470852,'furniture-mobile','.warrantyProduct .warranty','background_image','themes/furniture-mobile/img/calendar-1.png','3','','.warrantyProduct'),(470853,'furniture-mobile','.warrantyProduct .delivery','background_image','themes/furniture-mobile/img/wallet.png','3','','.warrantyProduct'),(470854,'furniture-mobile','.mainBanner .bottomBox','background_image','themes/furniture-mobile/img/ybg.webp','','','.mainBanner'),(470855,'furniture-mobile','.mainBanner .buttonBox','background_image','themes/furniture-mobile/img/everyday.webp','','','.mainBanner'),(470856,'furniture-mobile','.mainBanner .title','background_image','themes/furniture-mobile/img/elf.svg','3','','.mainBanner'),(470857,'furniture-mobile','.mainBanner .topBox > .right','background_image','themes/furniture-mobile/img/collection.webp','3','','.mainBanner'),(470858,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.p-quick-order-index'),(470859,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background_important','important','','','.b-select-suggest'),(470860,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.b-data-table'),(470861,'furniture-mobile','.w-product-designer-designer .prodDesignerType','background_important','important','','','.w-product-designer-designer'),(470862,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','background_important','important','','','.w-rma-returns-history'),(470863,'furniture-mobile','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(470864,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','1','','.p-quick-order-index'),(470865,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.p-quick-order-index'),(470866,'furniture-mobile','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(470867,'furniture-mobile','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(470868,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(470869,'furniture-mobile','.w-compare-box-item .checkbox','border','none','','','.w-compare-box-item'),(470870,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.p-quick-order-index'),(470871,'furniture-mobile','.b-messages .select2-container-multi input.select2-input','border','none','','','.b-messages'),(470872,'furniture-mobile','.b-messages .emailLineTextArea textarea','border','none','','','.b-messages'),(470873,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border','none','3','','.b-switch'),(470874,'furniture-mobile','.w-compare-box-item .checkbox','border','none','','','.w-compare-box-item'),(470875,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(470876,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg','border','none','','','.b-switch'),(470877,'furniture-mobile','.w-compare-box-item .checkbox','border','none','','','.w-compare-box-item'),(470878,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(470879,'furniture-mobile','.b-autocomplete .ui-autocomplete li','border','none','','','.b-autocomplete'),(470880,'furniture-mobile','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(470881,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(470882,'furniture-mobile','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(470883,'furniture-mobile','.w-cart-cart-tabs .w-tabs > .block','border','none','','','.w-cart-cart-tabs'),(470884,'furniture-mobile','.b-bottom .popup-box.popupCompare','border','none','','','.b-bottom'),(470885,'furniture-mobile','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(470886,'furniture-mobile','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(470887,'furniture-mobile','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(470888,'furniture-mobile','.w-top-categories .categories h2','border','none','','','.w-top-categories'),(470889,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border','none','4','','.b-switch'),(470890,'furniture-mobile','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(470891,'furniture-mobile','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(470892,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border','none','','','.b-switch'),(470893,'furniture-mobile','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(470894,'furniture-mobile','.w-compare-box-item .checkbox','border','none','','','.w-compare-box-item'),(470895,'furniture-mobile','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(470896,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(470897,'furniture-mobile','.b-form .checkbox-style','border','none','','','.b-form'),(470898,'furniture-mobile','.b-sub-totals .historyTotal table','border','none','','','.b-sub-totals'),(470899,'furniture-mobile','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(470900,'furniture-mobile','.b-bottom .cart-options .heading-4','border','none','','','.b-bottom'),(470901,'furniture-mobile','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(470902,'furniture-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input + span','border','none','','','.b-products-listing'),(470903,'furniture-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','border','none','','','.b-products-listing'),(470904,'furniture-mobile','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(470905,'furniture-mobile','.b-compare .compare-head','border','none','','','.b-compare'),(470906,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.p-quick-order-index'),(470907,'furniture-mobile','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(470908,'furniture-mobile','.w-compare-box-item .checkbox','border','none','','','.w-compare-box-item'),(470909,'furniture-mobile','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(470910,'furniture-mobile','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(470911,'furniture-mobile','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(470912,'furniture-mobile','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(470913,'furniture-mobile','.b-sub-totals .historyTotal td','border','none','','','.b-sub-totals'),(470914,'furniture-mobile','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(470915,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.b-data-table'),(470916,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','border','none','','','.b-products-listing'),(470917,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border','none','','','.w-blog-widget-related-posts'),(470918,'furniture-mobile','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(470919,'furniture-mobile','.w-checkout-gdpr .privacy-row','border','none','','','.w-checkout-gdpr'),(470920,'furniture-mobile','.b-autocomplete .ui-autocomplete li','border','none','1','','.b-autocomplete'),(470921,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','border','none','','','.w-communication-new-topic'),(470922,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','border','none','','','.w-communication-new-topic'),(470923,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','border','none','','','.w-communication-new-topic'),(470924,'furniture-mobile','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(470925,'furniture-mobile','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(470926,'furniture-mobile','.w-compare-box-item .checkbox','border','none','','','.w-compare-box-item'),(470927,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(470928,'furniture-mobile','.w-filters .input-checkbox','border','none','','','.w-filters'),(470929,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','border','none','','',''),(470930,'furniture-mobile','.b-data-table table.dataTable thead td','border','none','','','.b-data-table'),(470931,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.b-data-table'),(470932,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.b-data-table'),(470933,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border','none','','','.b-product-images'),(470934,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','border','none','','','.b-menu-style-2'),(470935,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','border','none','','','.b-menu-style-2'),(470936,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','border','none','','','.b-menu-style-2'),(470937,'furniture-mobile','.b-trade-approval .w-login-block .heading-3','border','none','','','.b-trade-approval'),(470938,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','border','none','','','.w-catalog-compare'),(470939,'furniture-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','border','none','','','.b-cookie-notice'),(470940,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','border','none','','','.b-slick'),(470941,'furniture-mobile','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border','none','','','.b-products-listing'),(470942,'furniture-mobile','.w-product-personal-catalog-button .btn','border','none','','','.w-product-personal-catalog-button'),(470943,'furniture-mobile','.b-bottom div + .info','border','none','','','.b-bottom'),(470944,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','border','none','','','.b-products-listing'),(470945,'furniture-mobile','.w-product-wedding-registry-button .btn','border','none','','','.w-product-wedding-registry-button'),(470946,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','border','none','','','.w-rma-returns-history'),(470947,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','border','none','','','.w-filters'),(470948,'furniture-mobile','.account-order-history .orders-table tr:first-child','border','none','','','.account-order-history'),(470949,'furniture-mobile','.account-index .orders-table tr:first-child','border','none','','','.account-index'),(470950,'furniture-mobile','.account-index .orders-table .price','border','none','2885','','.account-index'),(470951,'furniture-mobile','.account-samples .orders-table tr:first-child','border','none','','','.account-samples'),(470952,'furniture-mobile','.w-promotions .heading-3','border-bottom','none','','','.w-promotions'),(470953,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable.no-footer','border-bottom','none','','','.b-messages'),(470954,'furniture-mobile','.w-cart-shipping-estimator .addresses','border-bottom','none','','','.w-cart-shipping-estimator'),(470955,'furniture-mobile','.w-account-personal-catalog .list-switcher a','border-bottom','none','2','','.w-account-personal-catalog'),(470956,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','border-bottom','none','2','','.w-catalog-compare'),(470957,'furniture-mobile','.w-tabs .tab-li','border-bottom','none','2','','.w-tabs'),(470958,'furniture-mobile','.w-predefined-promotion .heading-3','border-bottom','none','','','.w-predefined-promotion'),(470959,'furniture-mobile','.w-search .products .item:last-child a','border-bottom','none','','','.w-search'),(470960,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-color','$border-message','','','.w-compare-box-item'),(470962,'furniture-mobile','.b-upload-file .upload-file-template','border-bottom-color','$border-color-4','','','.b-upload-file'),(470963,'furniture-mobile','.p-account-trade-form .widget .widget','border-bottom-color','$border-color-4','','','.p-account-trade-form'),(470964,'furniture-mobile','.p-reviews-info .review-info-text','border-bottom-color','$border-reverse','4','','.p-reviews-info'),(470965,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-color','$border-message','','','.w-compare-box-item'),(470966,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-color','$border-attention','','','.w-promotions'),(470967,'furniture-mobile','.w-sale .sale-holder','border-bottom-color','$border-color-4','','','.w-sale'),(470968,'furniture-mobile','.w-promo-code .holder','border-bottom-color','$border-color-4','','','.w-promo-code'),(470969,'furniture-mobile','.p-blog-index .comments-area article','border-bottom-color','$border-color-4','','','.p-blog-index'),(470970,'furniture-mobile','.w-account .account-dropdown','border-bottom-color','$border-color-4','','','.w-account'),(470971,'furniture-mobile','.p-reviews-info .review-info-text','border-bottom-color','$border-reverse','4','','.p-reviews-info'),(470972,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$border-color-4','','','.b-dropdown'),(470973,'furniture-mobile','.testimonials .review','border-bottom-color','transparent','3','',''),(470974,'furniture-mobile','.w-compare-box-item .checkbox + span','border-bottom-color','$border-color-4','','','.w-compare-box-item'),(470975,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-color','$border-message','','','.w-compare-box-item'),(470976,'furniture-mobile','.w-promotions .promo-salemaker .discount','border-bottom-color','$border-warning','','','.w-promotions'),(470977,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-color','$border-attention','','','.w-promotions'),(470978,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-color','$border-attention','','','.w-promotions'),(470979,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-color','$border-message','','','.w-compare-box-item'),(470980,'furniture-mobile','.w-cart-give-away .ga_column','border-bottom-color','$border-color-4','','','.w-cart-give-away'),(470981,'furniture-mobile','.w-cart-compare .cart-cell > div','border-bottom-color','$border-color-4','','','.w-cart-compare'),(470982,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-color','$border-color-4','','','.p-account-trade-form'),(470983,'furniture-mobile','.b-messages .msv_btn','border-bottom-color','$border-color-4','','','.b-messages'),(470984,'furniture-mobile','.b-messages .content_management_attach button','border-bottom-color','$border-color-5','','','.b-messages'),(470985,'furniture-mobile','.b-messages .content_management_attach','border-bottom-color','$border-color-4','','','.b-messages'),(470986,'furniture-mobile','.b-messages .email-heading','border-bottom-color','$border-color-4','','','.b-messages'),(470987,'furniture-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-color','$border-color-4','','','.b-messages'),(470988,'furniture-mobile','.b-messages .msv_to_cc','border-bottom-color','$border-color-4','','','.b-messages'),(470989,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-color','$border-color-4','','','.b-messages'),(470990,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-bottom-color','$border-color-4','','',''),(470991,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-color','$border-color-4','','','.b-messages'),(470992,'furniture-mobile','.b-messages .dataTables_wrapper > .bottom','border-bottom-color','$border-color-4','','','.b-messages'),(470993,'furniture-mobile','.w-sale .left-text-left','border-bottom-color','$border-color-4','','','.w-sale'),(470994,'furniture-mobile','.w-socials > li','border-bottom-color','$border-color-4','','','.w-socials'),(470995,'furniture-mobile','.w-product-reviews .reviews-list .review','border-bottom-color','transparent','3','','.w-product-reviews'),(470996,'furniture-mobile','.b-form .required-error','border-bottom-color','$border-attention','','','.b-form'),(470997,'furniture-mobile','.p-payer-order-confirmation .input-wrapper','border-bottom-color','$border-color-4','','','.p-payer-order-confirmation'),(470998,'furniture-mobile','.p-payer-order-pay .input-wrapper','border-bottom-color','$border-color-4','','','.p-payer-order-pay'),(470999,'furniture-mobile','.b-upload-file .snapshot','border-bottom-color','$border-color-6','','','.b-upload-file'),(471000,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-color','$border-color-4','','','.p-blog-index'),(471001,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-color','$border-color-4','','','.b-switch'),(471003,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-color','$border-color-4','','','.p-account-trade-form'),(471004,'furniture-mobile','.p-account-trade-form .widget .widget','border-bottom-color','$border-color-4','','','.p-account-trade-form'),(471006,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-color','$border-color-3','','','.w-upload-customer-id-upload-customer-id-form'),(471007,'furniture-mobile','.w-filters .filter-box-head','border-bottom-color','$border-color-4','','','.w-filters'),(471009,'furniture-mobile','.w-sale .sale-holder','border-bottom-color','$border-color-4','','','.w-sale'),(471010,'furniture-mobile','.w-sale .left-text-right','border-bottom-color','$border-color-4','','','.w-sale'),(471011,'furniture-mobile','.p-blog-index .comments-area article','border-bottom-color','$border-color-4','','','.p-blog-index'),(471012,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-color','$border-color-4','','','.p-account-trade-form'),(471013,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-bottom-color','$border-color-3','','','.w-wedding-registry-widgets-photos'),(471015,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-color','$border-color-4','','','.p-account-trade-form'),(471016,'furniture-mobile','.b-upload-file .upload-file-template div','border-bottom-color','$border-color-4','','','.b-upload-file'),(471017,'furniture-mobile','.w-compare-box-item .checkbox + span','border-bottom-color','$border-color-4','','','.w-compare-box-item'),(471018,'furniture-mobile','.w-sale .sale-holder','border-bottom-color','$border-color-4','','','.w-sale'),(471019,'furniture-mobile','.w-sale .left-text-left','border-bottom-color','$border-color-4','','','.w-sale'),(471020,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-color','$border-color-4','','','.p-blog-index'),(471021,'furniture-mobile','.p-blog-index .comments-area article','border-bottom-color','$border-color-4','','','.p-blog-index'),(471022,'furniture-mobile','.b-bottom .popup-heading','border-bottom-color','$border-color-4','','','.b-bottom'),(471024,'furniture-mobile','.w-checkout-shipping-choice span','border-bottom-color','$border-color-5','','','.w-checkout-shipping-choice'),(471025,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-color','$border-color-4','','','.b-select-suggest'),(471026,'furniture-mobile','.w-socials > li','border-bottom-color','$border-color-4','','','.w-socials'),(471027,'furniture-mobile','.b-info-popup .info-popup div','border-bottom-color','$border-color-4','','','.b-info-popup'),(471028,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-color','$border-color-4','','','.p-blog-index'),(471029,'furniture-mobile','.p-account-trade-form .widget .widget','border-bottom-color','$border-color-4','','','.p-account-trade-form'),(471030,'furniture-mobile','.w-promo-code .holder','border-bottom-color','$border-color-4','','','.w-promo-code'),(471032,'furniture-mobile','.w-tabs > .block','border-bottom-color','$border-color-3','','','.w-tabs'),(471033,'furniture-mobile','.w-tabs .accordion-heading','border-bottom-color','$border-color-5','2','','.w-tabs'),(471034,'furniture-mobile','.w-socials > li','border-bottom-color','$border-color-4','','','.w-socials'),(471035,'furniture-mobile','.w-sale .sale-holder','border-bottom-color','$border-color-4','','','.w-sale'),(471036,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$border-color-4','','','.b-dropdown'),(471037,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-color','$border-color-4','','','.p-blog-index'),(471038,'furniture-mobile','.w-cart-compare .compare-table','border-bottom-color','$border-color-4','','','.w-cart-compare'),(471039,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-color','$border-reverse','','','.b-switch'),(471040,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$border-color-4','','','.b-dropdown'),(471042,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$border-color-4','','','.b-dropdown'),(471043,'furniture-mobile','.w-socials > li','border-bottom-color','$border-color-4','','','.w-socials'),(471044,'furniture-mobile','.w-sale .left-text-right','border-bottom-color','$border-color-4','','','.w-sale'),(471045,'furniture-mobile','.w-socials > li','border-bottom-color','$border-color-4','','','.w-socials'),(471046,'furniture-mobile','.p-blog-index .comments-area article','border-bottom-color','$border-color-4','','','.p-blog-index'),(471047,'furniture-mobile','.w-reviews-content .review','border-bottom-color','$border-color-4','3','','.w-reviews-content'),(471048,'furniture-mobile','.w-compare-box-item .checkbox + span','border-bottom-color','$border-color-4','','','.w-compare-box-item'),(471049,'furniture-mobile','.w-sale .sale-holder','border-bottom-color','$border-color-4','','','.w-sale'),(471051,'furniture-mobile','.w-promo-code .holder','border-bottom-color','$border-color-4','','','.w-promo-code'),(471052,'furniture-mobile','.b-select-suggest .select2-container.select2-drop-above .select2-choice','border-bottom-color','$border-color-4','','','.b-select-suggest'),(471054,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-color','$border-color-4','4','','.b-switch'),(471055,'furniture-mobile','.w-sale .left-text-left','border-bottom-color','$border-color-4','','','.w-sale'),(471056,'furniture-mobile','.w-sale .left-text-right','border-bottom-color','$border-color-4','','','.w-sale'),(471057,'furniture-mobile','.w-languages .select','border-bottom-color','$border-color-4','','','.w-languages'),(471058,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-color','$border-color-4','3','','.b-form'),(471059,'furniture-mobile','.w-cart-products .checkout-attention-message','border-bottom-color','$border-attention','','','.w-cart-products'),(471060,'furniture-mobile','.w-cart-products .checkout-attention-message','border-bottom-color','$border-attention','','','.w-cart-products'),(471061,'furniture-mobile','.p-reviews-info .review-info-text','border-bottom-color','$border-reverse','4','','.p-reviews-info'),(471062,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-bottom-color','$border-color-4','','','.b-bottom'),(471063,'furniture-mobile','.w-socials > li','border-bottom-color','$border-color-4','','','.w-socials'),(471064,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-bottom-color','$border-reverse','','','.b-bottom'),(471065,'furniture-mobile','.w-sale .sale-holder','border-bottom-color','$border-color-4','','','.w-sale'),(471067,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-color','$border-message','','','.w-compare-box-item'),(471068,'furniture-mobile','.w-sale .left-text-left','border-bottom-color','$border-color-4','','','.w-sale'),(471070,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-color','$border-color-4','','','.p-blog-index'),(471071,'furniture-mobile','textarea','border-bottom-color','$border-color-4','','',''),(471074,'furniture-mobile','.b-bottom .footerTitle','border-bottom-color','$border-color-4','2876','','.b-bottom'),(471075,'furniture-mobile','.w-sale .left-text-right','border-bottom-color','$border-color-4','','','.w-sale'),(471076,'furniture-mobile','.b-bottom .popup-box','border-bottom-color','$border-color-4','','','.b-bottom'),(471077,'furniture-mobile','.w-product-customers-activity .customers-activity','border-bottom-color','$border-color-4','','','.w-product-customers-activity'),(471078,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-color','$border-color-4','','','.p-account-trade-form'),(471079,'furniture-mobile','.w-compare-box-item .checkbox + span','border-bottom-color','$border-color-4','','','.w-compare-box-item'),(471081,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-color','$border-message','','','.w-compare-box-item'),(471082,'furniture-mobile','.w-tabs .accordion-heading','border-bottom-color','$border-color-4','','','.w-tabs'),(471083,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-color','$border-color-4','','','.p-account-trade-form'),(471084,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-color','$border-color-4','','','.b-select-suggest'),(471085,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-color','$border-color-4','','','.b-select-suggest'),(471086,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-color','$border-color-4','','','.b-select-suggest'),(471087,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-color','$border-color-4','','','.b-select-suggest'),(471088,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-color','$border-color-4','','','.b-select-suggest'),(471089,'furniture-mobile','.b-select-suggest .select2-dropdown-open .select2-choice','border-bottom-color','$border-transparent','','','.b-select-suggest'),(471090,'furniture-mobile','.b-select-suggest .select2-drop-active','border-bottom-color','$border-color-4','','','.b-select-suggest'),(471091,'furniture-mobile','.b-select-suggest .select2-drop','border-bottom-color','$border-color-4','','','.b-select-suggest'),(471092,'furniture-mobile','.p-account-trade-form .widget .widget','border-bottom-color','$border-color-4','','','.p-account-trade-form'),(471093,'furniture-mobile','.w-cart-products .checkout-attention-message','border-bottom-color','$border-attention','','','.w-cart-products'),(471094,'furniture-mobile','.w-promo-code .holder','border-bottom-color','$border-color-4','','','.w-promo-code'),(471095,'furniture-mobile','.w-sale .left-text-left','border-bottom-color','$border-color-4','','','.w-sale'),(471096,'furniture-mobile','.w-compare-box-item .checkbox + span','border-bottom-color','$border-color-4','','','.w-compare-box-item'),(471097,'furniture-mobile','.b-form input.required-error','border-bottom-color','$border-attention','','','.b-form'),(471098,'furniture-mobile','.w-communication-post .communication-post','border-bottom-color','$border-color-4','','','.w-communication-post'),(471099,'furniture-mobile','.w-blog-widget-post-title ','border-bottom-color','$border-color-4','','','.w-blog-widget-post-title'),(471100,'furniture-mobile','.w-blog-widget-post-listing .post_name','border-bottom-color','$border-color-4','','','.w-blog-widget-post-listing'),(471101,'furniture-mobile','.w-blog-widget-post-listing .post_content','border-bottom-color','$border-color-4','','','.w-blog-widget-post-listing'),(471102,'furniture-mobile','.checkbox input + span','border-bottom-color','$border-color-4','','',''),(471103,'furniture-mobile','.p-account-trade-form .widget .widget','border-bottom-color','$border-color-4','','','.p-account-trade-form'),(471104,'furniture-mobile','.checkbox input:checked + span','border-bottom-color','$border-message','','',''),(471105,'furniture-mobile','.b-autocomplete .ui-autocomplete','border-bottom-color','$border-color-4','','','.b-autocomplete'),(471106,'furniture-mobile','.w-currencies .select','border-bottom-color','$border-color-4','','','.w-currencies'),(471107,'furniture-mobile','.w-currencies .currencies-title','border-bottom-color','$border-color-5','','','.w-currencies'),(471108,'furniture-mobile','.w-promo-code .holder','border-bottom-color','$border-color-4','','','.w-promo-code'),(471109,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','border-bottom-color','$border-color-4','','','.b-select-suggest'),(471110,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-color','$border-color-4','3','','.b-switch'),(471112,'furniture-mobile','.p-account-trade-form .widget .widget','border-bottom-color','$border-color-4','','','.p-account-trade-form'),(471113,'furniture-mobile','.w-sale .left-text-right','border-bottom-color','$border-color-4','','','.w-sale'),(471114,'furniture-mobile','.w-reviews .review','border-bottom-color','$border-reverse','3','','.w-reviews'),(471115,'furniture-mobile','.w-compare-box-item .checkbox + span','border-bottom-color','$border-color-4','','','.w-compare-box-item'),(471116,'furniture-mobile','.p-reviews-info .review-info-text','border-bottom-color','$border-reverse','4','','.p-reviews-info'),(471117,'furniture-mobile','.blogsidebar .heading-title','border-bottom-color','$border-color-4','','','.blogsidebar'),(471118,'furniture-mobile','.blogsidebar .heading-title','border-bottom-color','$border-color-4','','','.blogsidebar'),(471119,'furniture-mobile','.blogsidebar .heading-title','border-bottom-color','$border-color-4','','','.blogsidebar'),(471120,'furniture-mobile','.w-reviews-content .item','border-bottom-color','$border-color-4','','','.w-reviews-content'),(471121,'furniture-mobile','.b-upload-files .upload-files','border-bottom-color','$border-color-4','','','.b-upload-files'),(471122,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$border-color-4','','','.b-dropdown'),(471123,'furniture-mobile','.w-reviews .item','border-bottom-color','$border-color-4','','','.w-reviews'),(471124,'furniture-mobile','.w-sale .left-text-left','border-bottom-color','$border-color-4','','','.w-sale'),(471125,'furniture-mobile','.w-promo-code .holder','border-bottom-color','$border-color-4','','','.w-promo-code'),(471126,'furniture-mobile','.w-sale .left-text-right','border-bottom-color','$border-color-4','','','.w-sale'),(471127,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$border-color-4','','','.b-dropdown'),(471128,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-color','$border-color-4','','','.p-blog-index'),(471129,'furniture-mobile','.p-blog-index .comments-area article','border-bottom-color','$border-color-4','','','.p-blog-index'),(471130,'furniture-mobile','.b-select-suggest .select2-search input','border-bottom-color','$border-color-4','','','.b-select-suggest'),(471131,'furniture-mobile','.blogsidebar .heading-title','border-bottom-color','$border-color-4','','','.blogsidebar'),(471132,'furniture-mobile','.w-cart-products .checkout-attention-message','border-bottom-color','$border-attention','','','.w-cart-products'),(471133,'furniture-mobile','.w-cart-listing .item .gift-wrap label','border-bottom-color','$border-color-4','','','.w-cart-listing'),(471134,'furniture-mobile','.w-cart-listing .item','border-bottom-color','$border-color-4','2885','','.w-cart-listing'),(471135,'furniture-mobile','.w-cart .cart-content','border-bottom-color','$border-color-4','','','.w-cart'),(471136,'furniture-mobile','.p-reviews-info .review-info-text','border-bottom-color','$border-reverse','4','','.p-reviews-info'),(471137,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-bottom-color','$border-color-3','','','.w-wedding-registry-widgets-photos'),(471138,'furniture-mobile','.p-blog-index .comments-area article','border-bottom-color','$border-color-4','','','.p-blog-index'),(471139,'furniture-mobile','.w-cart-products .checkout-attention-message','border-bottom-color','$border-attention','','','.w-cart-products'),(471140,'furniture-mobile','.p-reviews-info .review-info-text','border-bottom-color','$border-reverse','4','','.p-reviews-info'),(471143,'furniture-mobile','.b-data-table table.dataTable.no-footer','border-bottom-color','$border-color-4','','','.b-data-table'),(471144,'furniture-mobile','.w-cart-products .checkout-attention-message','border-bottom-color','$border-attention','','','.w-cart-products'),(471145,'furniture-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-color','$border-color-6','','','.b-compare'),(471146,'furniture-mobile','.b-compare .compare_pagination','border-bottom-color','$border-color-4','','','.b-compare'),(471147,'furniture-mobile','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-bottom-color','$border-reverse','','','.b-product-images'),(471148,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-bottom-color','$border-color-2','','','.b-menu-style-2'),(471149,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','border-bottom-color','$border-color-2','','','.b-menu-style-2'),(471150,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-bottom-color','$border-color-2','','','.b-menu-style-2'),(471151,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-bottom-color','$border-color-2','','','.b-menu-style-2'),(471152,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-bottom-color','$border-color-2','','','.b-menu-style-2'),(471153,'furniture-mobile','.b-trade-approval .orders-table th','border-bottom-color','$border-color-4','','','.b-trade-approval'),(471154,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-color','$border-color-4','','','.b-trade-approval'),(471155,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-color','$border-color-4','','','.batchPr'),(471156,'furniture-mobile','.batchPr .checkbox input + span','border-bottom-color','$border-color-4','','','.batchPr'),(471157,'furniture-mobile','.batchPr .checkbox input + span','border-bottom-color','$border-color-4','','','.batchPr'),(471158,'furniture-mobile','.batchPr .w-batch-selected-products','border-bottom-color','$border-color-4','','','.batchPr'),(471159,'furniture-mobile','.batchPr .checkbox input:checked + span','border-bottom-color','$border-color-2','','','.batchPr'),(471160,'furniture-mobile','.w-account-personal-catalog .list-switcher a','border-bottom-color','$border-color-4','','','.w-account-personal-catalog'),(471161,'furniture-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-color','$border-reverse','','','.w-catalog-compare'),(471162,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','border-bottom-color','$border-color-4','','','.w-catalog-compare'),(471163,'furniture-mobile','.w-delivery-day .left-text-left','border-bottom-color','$border-color-4','','','.w-delivery-day'),(471164,'furniture-mobile','.w-delivery-day .left-text-right','border-bottom-color','$border-color-4','','','.w-delivery-day'),(471165,'furniture-mobile','.w-search .search-input','border-bottom-color','$border-color-2','','','.w-search'),(471166,'furniture-mobile','.w-account .my-acc-link','border-bottom-color','$border-color-2','4','','.w-account'),(471167,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','border-bottom-color','$border-color-6','2885','','.b-menu-style-3'),(471168,'furniture-mobile','.w-cart-listing .item, .w-cart-listing .headings','border-bottom-color','$border-color-4','','','.w-cart-listing'),(471169,'furniture-mobile','.b-products-listing .products-listing .compare input + span','border-bottom-color','$border-color-5','','','.b-products-listing'),(471170,'furniture-mobile','.w-filters .filter-widget','border-bottom-color','$border-color-4','','','.w-filters'),(471171,'furniture-mobile','.w-quote .cart-content','border-bottom-color','$border-color-4','','','.w-quote'),(471172,'furniture-mobile','.w-quote .cart-total','border-bottom-color','$border-color-4','','','.w-quote'),(471173,'furniture-mobile','.w-quote .multicart .item','border-bottom-color','$border-color-4','','','.w-quote'),(471174,'furniture-mobile','.b-product-images .additional-images .active img','border-bottom-color','$border-color-5','','','.b-product-images'),(471175,'furniture-mobile','.b-product-images .additional-images img','border-bottom-color','$border-reverse','','','.b-product-images'),(471176,'furniture-mobile','.b-quantity .qty-box .bigger','border-bottom-color','$border-color-1','','','.b-quantity'),(471177,'furniture-mobile','.b-quantity .qty-box .smaller','border-bottom-color','$border-color-1','','','.b-quantity'),(471178,'furniture-mobile','.w-product-sale-ends .left-text-left','border-bottom-color','$border-color-3','','','.w-product-sale-ends'),(471179,'furniture-mobile','.w-product-sale-ends .left-text-right','border-bottom-color','$border-color-3','','','.w-product-sale-ends'),(471180,'furniture-mobile','.w-product-quantity .qty_packs .qty-input','border-bottom-color','$border-color-4','','','.w-product-quantity'),(471181,'furniture-mobile','.w-sample .cart-box-link','border-bottom-color','$border-color-2','4','','.w-sample'),(471182,'furniture-mobile','.w-sample .cart-content','border-bottom-color','$border-color-4','','','.w-sample'),(471183,'furniture-mobile','.w-sample .cart-total','border-bottom-color','$border-color-4','','','.w-sample'),(471184,'furniture-mobile','.w-sample .multicart .item','border-bottom-color','$border-color-4','','','.w-sample'),(471185,'furniture-mobile','.w-cart-listing .points-earn','border-bottom-color','$border-transparent','4','','.w-cart-listing'),(471186,'furniture-mobile','.w-cart-discount-coupon .title','border-bottom-color','$border-color-1','','','.w-cart-discount-coupon'),(471187,'furniture-mobile','.w-cart-discount-coupon .btn','border-bottom-color','$border-color-5','','','.w-cart-discount-coupon'),(471188,'furniture-mobile','.w-product-video .item img, .w-product-video .item video','border-bottom-color','$border-reverse','','','.w-product-video'),(471189,'furniture-mobile','.w-product-video .item.active img, .w-product-video .item.active video','border-bottom-color','$border-color-7','','','.w-product-video'),(471190,'furniture-mobile','.shipping-ico .heading-3','border-bottom-color','$border-color-1','','','.shipping-ico'),(471191,'furniture-mobile','.w-cart-order-reference .btn','border-bottom-color','$border-color-5','','','.w-cart-order-reference'),(471192,'furniture-mobile','.w-cart-gift-certificate .btn','border-bottom-color','$border-color-5','','','.w-cart-gift-certificate'),(471193,'furniture-mobile','.w-cart-shipping-estimator .btn','border-bottom-color','$border-color-5','','','.w-cart-shipping-estimator'),(471194,'furniture-mobile','.w-account-address-book .item','border-bottom-color','$border-color-3','','','.w-account-address-book'),(471195,'furniture-mobile','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-bottom-color','$border-color-8','','','.b-pagination'),(471196,'furniture-mobile','.b-pagination .pagination .next-pages','border-bottom-color','$border-color-4','','','.b-pagination'),(471197,'furniture-mobile','.b-pagination .pagination .page-number','border-bottom-color','$border-color-4','','','.b-pagination'),(471198,'furniture-mobile','.b-pagination .pagination .prev-pages','border-bottom-color','$border-color-4','','','.b-pagination'),(471199,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-bottom-color','$border-color-4','','','.b-pagination'),(471200,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-bottom-color','$border-color-4','','','.b-pagination'),(471201,'furniture-mobile','.b-pagination .pagination span','border-bottom-color','$border-color-4','2','','.b-pagination'),(471202,'furniture-mobile','.w-tabs .tab-li','border-bottom-color','$border-color-4','','','.w-tabs'),(471203,'furniture-mobile','.w-product-multi-inventory .radio-attributes','border-bottom-color','$border-color-3','','','.w-product-multi-inventory'),(471204,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','border-bottom-color','$border-color-4','','','.w-product-multi-inventory'),(471205,'furniture-mobile','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-bottom-color','$border-color-5','','','.w-product-multi-inventory'),(471206,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-bottom-color','$border-color-3','','','.w-account-personal-catalog'),(471207,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','border-bottom-color','$border-color-3','','','.w-account-personal-catalog'),(471208,'furniture-mobile','.b-products-listing .products-listing .radio-attributes','border-bottom-color','$border-color-3','','','.b-products-listing'),(471209,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','border-bottom-color','$border-color-4','','','.b-products-listing'),(471210,'furniture-mobile','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-bottom-color','$border-color-5','','','.b-products-listing'),(471211,'furniture-mobile','.w-product-attributes .radio-attributes','border-bottom-color','$border-color-3','','','.w-product-attributes'),(471212,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','border-bottom-color','$border-color-4','','','.w-product-attributes'),(471213,'furniture-mobile','.w-product-attributes .radio-attributes input:checked + .option-item','border-bottom-color','$border-color-5','','','.w-product-attributes'),(471214,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-color','$border-color-3','','','.w-questionnaire-widgets-questionnaire'),(471215,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-bottom-color','$border-attention','','','.w-questionnaire-widgets-questionnaire'),(471216,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-bottom-color','$border-message','','','.w-questionnaire-widgets-questionnaire'),(471217,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-bottom-color','$border-attention','1','','.w-questionnaire-widgets-questionnaire'),(471218,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-bottom-color','$border-message','1','','.w-questionnaire-widgets-questionnaire'),(471219,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','border-bottom-color','$border-color-3','','','.w-product-groups'),(471220,'furniture-mobile','.w-product-groups .radioBox label .containerBlock.selected','border-bottom-color','$border-color-5','','','.w-product-groups'),(471221,'furniture-mobile','.w-product-groups .radioBox label input:checked + .containerBlock','border-bottom-color','$border-color-5','','','.w-product-groups'),(471222,'furniture-mobile','.w-delivery-location-top-location-list .deliveryName','border-bottom-color','$border-color-3','','','.w-delivery-location-top-location-list'),(471223,'furniture-mobile','.w-delivery-location-location-list .deliveryName','border-bottom-color','$border-color-3','','','.w-delivery-location-location-list'),(471224,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-bottom-color','$border-color-4','','','.w-delivery-location-location-list'),(471225,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-bottom-color','$border-color-5','1','','.w-delivery-location-location-list'),(471226,'furniture-mobile','.w-wedding-registry-widgets-search-form .closeable-heading','border-bottom-color','$border-color-3','','','.w-wedding-registry-widgets-search-form'),(471227,'furniture-mobile','.w-sale-category .left-text-left','border-bottom-color','$border-color-4','','','.w-sale-category'),(471228,'furniture-mobile','.w-sale-category .left-text-right','border-bottom-color','$border-color-4','','','.w-sale-category'),(471229,'furniture-mobile','.w-sale-category .sale-holder','border-bottom-color','$border-color-4','','','.w-sale-category'),(471230,'furniture-mobile','.w-wedding-registry-widgets-photos .upload-file-template','border-bottom-color','$border-color-3','','','.w-wedding-registry-widgets-photos'),(471231,'furniture-mobile','.w-product-wedding-registry-button .btn','border-bottom-color','$border-color-5','3','','.w-product-wedding-registry-button'),(471232,'furniture-mobile','.w-product-wedding-registry-button .btn','border-bottom-color','$border-color-5','4','','.w-product-wedding-registry-button'),(471233,'furniture-mobile','.w-catalog-delivery-locations .name','border-bottom-color','$border-color-3','','','.w-catalog-delivery-locations'),(471234,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','border-bottom-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(471235,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','border-bottom-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(471236,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','border-bottom-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(471237,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','border-bottom-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(471238,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','border-bottom-color','$border-color-3','','','.w-product-designer-designer'),(471239,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small ','border-bottom-color','$border-color-1','','','.w-press-reviews-widgets-press-reviews-small'),(471240,'furniture-mobile','.b-products-listing .productGroup label a','border-bottom-color','$border-color-5','','','.b-products-listing'),(471241,'furniture-mobile','.w-support-system-listing .support-head','border-bottom-color','$border-color-1','','','.w-support-system-listing'),(471242,'furniture-mobile','.w-support-system-listing .product_icon','border-bottom-color','$border-color-1','','','.w-support-system-listing'),(471243,'furniture-mobile','.w-rma-returns-history .topRow','border-bottom-color','$border-color-1','','','.w-rma-returns-history'),(471244,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-color','$border-attention','','','.w-predefined-promotion'),(471245,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-color','$border-attention','','','.w-predefined-promotion'),(471246,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-color','$border-attention','','','.w-predefined-promotion'),(471247,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border-bottom-color','$border-warning','','','.w-predefined-promotion'),(471248,'furniture-mobile','.w-supplier-purchase-supplier-products .item','border-bottom-color','$border-color-3','','','.w-supplier-purchase-supplier-products'),(471249,'furniture-mobile','.mainBanner .bottomBox .btn','border-bottom-color','$border-color-2','','','.mainBanner'),(471250,'furniture-mobile','.mainBanner .bottomBox .btn','border-bottom-color','$border-color-2','2890','','.mainBanner'),(471251,'furniture-mobile','.mainBanner .bottomBox .btn','border-bottom-color','$border-color-2','2876','','.mainBanner'),(471252,'furniture-mobile','.mainBanner .bottomBox .btn','border-bottom-color','$border-color-2','2906','','.mainBanner'),(471253,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','border-bottom-color','$border-color-5','','','.lowestPricedBox'),(471254,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-bottom-color','$border-color-2','','','.shopByCollectionBox'),(471255,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-bottom-color','$border-color-2','2890','','.shopByCollectionBox'),(471256,'furniture-mobile','.w-search .products .item a','border-bottom-color','$border-color-4','','','.w-search'),(471257,'furniture-mobile','.account-order-history .orders-table .item','border-bottom-color','$border-color-4','2885','','.account-order-history'),(471258,'furniture-mobile','.account-index .orders-table .item','border-bottom-color','$border-color-4','2885','','.account-index'),(471259,'furniture-mobile','.account-samples .orders-table .item','border-bottom-color','$border-color-4','2885','','.account-samples'),(471260,'furniture-mobile','.catalog-product-wrap .pn-image','border-bottom-color','$border-color-4','3','','.catalog-product-wrap'),(471261,'furniture-mobile','.shopping-cart-index .btn-3','border-bottom-color','$border-color-5','','','.shopping-cart-index'),(471262,'furniture-mobile','.checkout-index-wrap .input-wrapper','border-bottom-color','$border-color-4','','','.checkout-index-wrap'),(471263,'furniture-mobile','.b-data-table table.dataTable.no-footer','border-bottom-color_important','important','','','.b-data-table'),(471265,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-left-radius','15','4','','.b-switch'),(471266,'furniture-mobile','.p-blog-index .avatar','border-bottom-left-radius','50','','','.p-blog-index'),(471267,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.p-quick-order-index'),(471268,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-left-radius','12','','','.w-promotions'),(471269,'furniture-mobile','.w-sale .left-count','border-bottom-left-radius','3','','','.w-sale'),(471270,'furniture-mobile','.w-promotions .promo-salemaker .discount','border-bottom-left-radius','12','','','.w-promotions'),(471271,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-left-radius','12','','','.w-promotions'),(471272,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-left-radius','12','','','.w-promotions'),(471273,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.p-quick-order-index'),(471274,'furniture-mobile','.w-personal-gift-status-bar .progress-bar','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(471275,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-left-radius','5','','','.b-messages'),(471276,'furniture-mobile','.w-sale .left-count-days','border-bottom-left-radius','3','','','.w-sale'),(471277,'furniture-mobile','.p-blog-index .avatar','border-bottom-left-radius','50','','','.p-blog-index'),(471280,'furniture-mobile','.b-fancybox .fancybox-close','border-bottom-left-radius','50','','','.b-fancybox'),(471281,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-left-radius','25','','','.b-switch'),(471283,'furniture-mobile','.b-upload-file .snapshot','border-bottom-left-radius','50','','','.b-upload-file'),(471285,'furniture-mobile','.p-blog-index .avatar','border-bottom-left-radius','50','','','.p-blog-index'),(471286,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-left-radius','15','3','','.b-switch'),(471287,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg','border-bottom-left-radius','15','','','.b-switch'),(471288,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(471289,'furniture-mobile','.p-blog-index .avatar','border-bottom-left-radius','50','','','.p-blog-index'),(471290,'furniture-mobile','.w-checkout-shipping-choice label:last-child span','border-bottom-left-radius','0','','','.w-checkout-shipping-choice'),(471291,'furniture-mobile','.w-checkout-shipping-choice label:first-child span','border-bottom-left-radius','16','','','.w-checkout-shipping-choice'),(471292,'furniture-mobile','.w-sale .badge','border-bottom-left-radius','50','','','.w-sale'),(471293,'furniture-mobile','.w-sale .left-count-hours','border-bottom-left-radius','3','','','.w-sale'),(471294,'furniture-mobile','.p-blog-index .avatar','border-bottom-left-radius','50','','','.p-blog-index'),(471296,'furniture-mobile','.w-sale .badge','border-bottom-left-radius','50','','','.w-sale'),(471297,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-bottom-left-radius','0','4','','.b-switch'),(471298,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-bottom-left-radius','0','3','','.b-switch'),(471299,'furniture-mobile','.w-sale .left-count','border-bottom-left-radius','3','','','.w-sale'),(471300,'furniture-mobile','.w-sale .left-count-hours','border-bottom-left-radius','3','','','.w-sale'),(471301,'furniture-mobile','.w-sale .left-count','border-bottom-left-radius','3','','','.w-sale'),(471302,'furniture-mobile','.w-sale .left-count-days','border-bottom-left-radius','3','','','.w-sale'),(471303,'furniture-mobile','.w-sale .badge','border-bottom-left-radius','50','','','.w-sale'),(471304,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-left-radius','15','','','.b-fancybox'),(471305,'furniture-mobile','.b-fancybox .fancybox-skin','border-bottom-left-radius','4','','','.b-fancybox'),(471306,'furniture-mobile','.w-sale .badge','border-bottom-left-radius','50','','','.w-sale'),(471308,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-bottom-left-radius','50','3','','.b-switch'),(471309,'furniture-mobile','.w-sale .left-count-hours','border-bottom-left-radius','3','','','.w-sale'),(471310,'furniture-mobile','.w-sale .left-count','border-bottom-left-radius','3','','','.w-sale'),(471311,'furniture-mobile','.w-sale .left-count-days','border-bottom-left-radius','3','','','.w-sale'),(471312,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-left-radius','50','3','','.b-form'),(471316,'furniture-mobile','.b-fancybox .fancybox-nav span','border-bottom-left-radius','50','','','.b-fancybox'),(471317,'furniture-mobile','.w-product-customers-activity .customers-activity','border-bottom-left-radius','0','','','.w-product-customers-activity'),(471318,'furniture-mobile','.w-product-customers-activity .close','border-bottom-left-radius','50','','','.w-product-customers-activity'),(471319,'furniture-mobile','.w-sale .left-count-hours','border-bottom-left-radius','3','','','.w-sale'),(471320,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(471321,'furniture-mobile','.w-sale .left-count-days','border-bottom-left-radius','3','','','.w-sale'),(471322,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.b-data-table'),(471323,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.b-data-table'),(471324,'furniture-mobile','.b-products-listing .promos-info .promo-name','border-bottom-left-radius','0','','','.b-products-listing'),(471325,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-bottom-left-radius','0','','','.w-blog-widget-related-posts'),(471326,'furniture-mobile','.w-personal-gift-status-bar .progress-bar-content','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(471328,'furniture-mobile','.w-sale .badge','border-bottom-left-radius','50','','','.w-sale'),(471329,'furniture-mobile','.w-sale .left-count','border-bottom-left-radius','3','','','.w-sale'),(471330,'furniture-mobile','.w-sale .left-count-hours','border-bottom-left-radius','3','','','.w-sale'),(471331,'furniture-mobile','.w-sale .left-count-hours','border-bottom-left-radius','3','','','.w-sale'),(471332,'furniture-mobile','.w-sale .left-count-days','border-bottom-left-radius','3','','','.w-sale'),(471333,'furniture-mobile','.w-sale .badge','border-bottom-left-radius','50','','','.w-sale'),(471334,'furniture-mobile','.w-sale .left-count','border-bottom-left-radius','3','','','.w-sale'),(471335,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-left-radius','0','','','.w-catalog-paging'),(471336,'furniture-mobile','.w-sale .left-count-days','border-bottom-left-radius','3','','','.w-sale'),(471337,'furniture-mobile','.p-blog-index .avatar','border-bottom-left-radius','50','','','.p-blog-index'),(471338,'furniture-mobile','.b-switch .bootstrap-switch','border-bottom-left-radius','14','','','.b-switch'),(471339,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-left-radius','25','','','.b-switch'),(471341,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-bottom-left-radius','0','','','.b-product-images'),(471342,'furniture-mobile','.b-trade-approval .steps-bar','border-bottom-left-radius','18','','','.b-trade-approval'),(471343,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-left-radius','10','','','.batchPr'),(471344,'furniture-mobile','.batchPr .checkbox input + span','border-bottom-left-radius','18','','','.batchPr'),(471345,'furniture-mobile','.batchPr .btn-batch-remove','border-bottom-left-radius','100','','','.batchPr'),(471346,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-bottom-left-radius','0','','','.batchPr'),(471347,'furniture-mobile','.w-delivery-day .left-count','border-bottom-left-radius','3','','','.w-delivery-day'),(471348,'furniture-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-left-radius','3','','','.w-delivery-day'),(471349,'furniture-mobile','.w-cart .cart-box-link','border-bottom-left-radius','50','3','','.w-cart'),(471350,'furniture-mobile','.w-account .my-acc-link','border-bottom-left-radius','50','3','','.w-account'),(471351,'furniture-mobile','.w-account .account-dropdown','border-bottom-left-radius','100','3','','.w-account'),(471352,'furniture-mobile','.w-search .search-ico','border-bottom-left-radius','50','2885,3','','.w-search'),(471353,'furniture-mobile','.menu-header .burger-icon','border-bottom-left-radius','50','2885','','.menu-header'),(471354,'furniture-mobile','.w-quote .cart-box-link','border-bottom-left-radius','50','3','','.w-quote'),(471355,'furniture-mobile','.w-product-sale-ends .left-count','border-bottom-left-radius','3','','','.w-product-sale-ends'),(471356,'furniture-mobile','.w-product-sale-ends .left-count-days','border-bottom-left-radius','3','','','.w-product-sale-ends'),(471357,'furniture-mobile','.w-product-sale-ends .left-count-hours','border-bottom-left-radius','3','','','.w-product-sale-ends'),(471358,'furniture-mobile','.w-sample .cart-box-link','border-bottom-left-radius','50','3','','.w-sample'),(471359,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-left-radius','50','','','.w-questionnaire-widgets-questionnaire'),(471360,'furniture-mobile','.w-sale-category .badge','border-bottom-left-radius','50','','','.w-sale-category'),(471361,'furniture-mobile','.w-sale-category .left-count','border-bottom-left-radius','3','','','.w-sale-category'),(471362,'furniture-mobile','.w-sale-category .left-count-days','border-bottom-left-radius','3','','','.w-sale-category'),(471363,'furniture-mobile','.w-sale-category .left-count-hours','border-bottom-left-radius','3','','','.w-sale-category'),(471364,'furniture-mobile','.w-product-wedding-registry-button .btn','border-bottom-left-radius','50','3','','.w-product-wedding-registry-button'),(471365,'furniture-mobile','.w-product-wedding-registry-button .btn','border-bottom-left-radius','50','4','','.w-product-wedding-registry-button'),(471366,'furniture-mobile','.b-products-listing .productGroup label a','border-bottom-left-radius','3','','','.b-products-listing'),(471367,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-left-radius','12','','','.w-predefined-promotion'),(471368,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-left-radius','12','','','.w-predefined-promotion'),(471369,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-left-radius','12','','','.w-predefined-promotion'),(471370,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border-bottom-left-radius','12','','','.w-predefined-promotion'),(471371,'furniture-mobile','.lowestPricedBox .w-banner .ybg','border-bottom-left-radius','50','3','','.lowestPricedBox'),(471372,'furniture-mobile','.catalog-product-wrap .pn-image','border-bottom-left-radius','50','3','','.catalog-product-wrap'),(471374,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-bottom-right-radius','0','4','','.b-switch'),(471375,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-right-radius','15','4','','.b-switch'),(471376,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.p-quick-order-index'),(471377,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.p-quick-order-index'),(471378,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-right-radius','12','','','.w-promotions'),(471379,'furniture-mobile','.w-promotions .promo-salemaker .discount','border-bottom-right-radius','12','','','.w-promotions'),(471380,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-right-radius','12','','','.w-promotions'),(471381,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-right-radius','12','','','.w-promotions'),(471382,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-right-radius','5','','','.b-messages'),(471383,'furniture-mobile','.w-sale .left-count','border-bottom-right-radius','3','','','.w-sale'),(471384,'furniture-mobile','.p-blog-index .avatar','border-bottom-right-radius','50','','','.p-blog-index'),(471385,'furniture-mobile','.b-fancybox .fancybox-close','border-bottom-right-radius','50','','','.b-fancybox'),(471386,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-right-radius','25','','','.b-switch'),(471387,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-bottom-right-radius','0','3','','.b-switch'),(471392,'furniture-mobile','.w-sale .left-count-days','border-bottom-right-radius','3','','','.w-sale'),(471393,'furniture-mobile','.w-sale .badge','border-bottom-right-radius','50','','','.w-sale'),(471394,'furniture-mobile','.w-sale .left-count','border-bottom-right-radius','3','','','.w-sale'),(471395,'furniture-mobile','.w-sale .left-count-hours','border-bottom-right-radius','3','','','.w-sale'),(471396,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-right-radius','15','3','','.b-switch'),(471398,'furniture-mobile','.w-sale .badge','border-bottom-right-radius','50','','','.w-sale'),(471399,'furniture-mobile','.w-sale .left-count','border-bottom-right-radius','3','','','.w-sale'),(471400,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg','border-bottom-right-radius','15','','','.b-switch'),(471401,'furniture-mobile','.w-checkout-shipping-choice label:last-child span','border-bottom-right-radius','16','','','.w-checkout-shipping-choice'),(471402,'furniture-mobile','.w-checkout-shipping-choice label:first-child span','border-bottom-right-radius','0','','','.w-checkout-shipping-choice'),(471403,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-right-radius','0','','','.w-catalog-paging'),(471404,'furniture-mobile','.w-sale .left-count','border-bottom-right-radius','3','','','.w-sale'),(471405,'furniture-mobile','.p-blog-index .avatar','border-bottom-right-radius','50','','','.p-blog-index'),(471406,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(471407,'furniture-mobile','.w-sale .badge','border-bottom-right-radius','50','','','.w-sale'),(471408,'furniture-mobile','.w-sale .left-count-days','border-bottom-right-radius','3','','','.w-sale'),(471409,'furniture-mobile','.p-blog-index .avatar','border-bottom-right-radius','50','','','.p-blog-index'),(471410,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-right-radius','15','','','.b-fancybox'),(471411,'furniture-mobile','.b-fancybox .fancybox-skin','border-bottom-right-radius','4','','','.b-fancybox'),(471412,'furniture-mobile','.w-sale .badge','border-bottom-right-radius','50','','','.w-sale'),(471413,'furniture-mobile','.b-upload-file .snapshot','border-bottom-right-radius','50','','','.b-upload-file'),(471415,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-bottom-right-radius','50','3','','.b-switch'),(471416,'furniture-mobile','.w-sale .left-count','border-bottom-right-radius','3','','','.w-sale'),(471417,'furniture-mobile','.w-sale .left-count-hours','border-bottom-right-radius','3','','','.w-sale'),(471418,'furniture-mobile','.w-sale .left-count-days','border-bottom-right-radius','3','','','.w-sale'),(471419,'furniture-mobile','.p-blog-index .avatar','border-bottom-right-radius','50','','','.p-blog-index'),(471420,'furniture-mobile','.w-sale .left-count-hours','border-bottom-right-radius','3','','','.w-sale'),(471421,'furniture-mobile','.w-sale .left-count-days','border-bottom-right-radius','3','','','.w-sale'),(471423,'furniture-mobile','.w-sale .badge','border-bottom-right-radius','50','','','.w-sale'),(471424,'furniture-mobile','.w-sale .left-count-hours','border-bottom-right-radius','3','','','.w-sale'),(471426,'furniture-mobile','.b-fancybox .fancybox-nav span','border-bottom-right-radius','50','','','.b-fancybox'),(471427,'furniture-mobile','.w-product-customers-activity .close','border-bottom-right-radius','50','','','.w-product-customers-activity'),(471428,'furniture-mobile','.w-product-customers-activity .customers-activity','border-bottom-right-radius','0','','','.w-product-customers-activity'),(471429,'furniture-mobile','.w-personal-gift-status-bar .progress-bar','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(471431,'furniture-mobile','.p-blog-index .avatar','border-bottom-right-radius','50','','','.p-blog-index'),(471432,'furniture-mobile','.b-switch .bootstrap-switch','border-bottom-right-radius','14','','','.b-switch'),(471433,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.b-data-table'),(471434,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.b-data-table'),(471435,'furniture-mobile','.b-products-listing .promos-info .promo-name','border-bottom-right-radius','8','','','.b-products-listing'),(471436,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-bottom-right-radius','0','','','.w-blog-widget-related-posts'),(471437,'furniture-mobile','.w-sale .left-count-hours','border-bottom-right-radius','3','','','.w-sale'),(471438,'furniture-mobile','.w-sale .left-count-days','border-bottom-right-radius','3','','','.w-sale'),(471439,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(471441,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-right-radius','50','3','','.b-form'),(471442,'furniture-mobile','.w-personal-gift-status-bar .progress-bar-content','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(471443,'furniture-mobile','.w-sale .left-count-hours','border-bottom-right-radius','3','','','.w-sale'),(471444,'furniture-mobile','.w-sale .left-count-days','border-bottom-right-radius','3','','','.w-sale'),(471445,'furniture-mobile','.w-sale .badge','border-bottom-right-radius','50','','','.w-sale'),(471446,'furniture-mobile','.w-sale .left-count','border-bottom-right-radius','3','','','.w-sale'),(471447,'furniture-mobile','.p-blog-index .avatar','border-bottom-right-radius','50','','','.p-blog-index'),(471449,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-right-radius','25','','','.b-switch'),(471450,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-bottom-right-radius','0','','','.b-product-images'),(471451,'furniture-mobile','.b-trade-approval .steps-bar','border-bottom-right-radius','18','','','.b-trade-approval'),(471452,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-right-radius','10','','','.batchPr'),(471453,'furniture-mobile','.batchPr .checkbox input + span','border-bottom-right-radius','18','','','.batchPr'),(471454,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-bottom-right-radius','0','','','.batchPr'),(471455,'furniture-mobile','.batchPr .btn-batch-remove','border-bottom-right-radius','100','','','.batchPr'),(471456,'furniture-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-right-radius','3','','','.w-delivery-day'),(471457,'furniture-mobile','.w-delivery-day .left-count','border-bottom-right-radius','3','','','.w-delivery-day'),(471458,'furniture-mobile','.w-cart .cart-box-link','border-bottom-right-radius','50','3','','.w-cart'),(471459,'furniture-mobile','.w-account .my-acc-link','border-bottom-right-radius','50','3','','.w-account'),(471460,'furniture-mobile','.w-account .account-dropdown','border-bottom-right-radius','100','3','','.w-account'),(471461,'furniture-mobile','.w-search .search-ico','border-bottom-right-radius','50','2885,3','','.w-search'),(471462,'furniture-mobile','.menu-header .burger-icon','border-bottom-right-radius','50','2885','','.menu-header'),(471463,'furniture-mobile','.w-quote .cart-box-link','border-bottom-right-radius','50','3','','.w-quote'),(471464,'furniture-mobile','.w-product-sale-ends .left-count','border-bottom-right-radius','3','','','.w-product-sale-ends'),(471465,'furniture-mobile','.w-product-sale-ends .left-count-days','border-bottom-right-radius','3','','','.w-product-sale-ends'),(471466,'furniture-mobile','.w-product-sale-ends .left-count-hours','border-bottom-right-radius','3','','','.w-product-sale-ends'),(471467,'furniture-mobile','.w-sample .cart-box-link','border-bottom-right-radius','50','3','','.w-sample'),(471468,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-right-radius','50','','','.w-questionnaire-widgets-questionnaire'),(471469,'furniture-mobile','.w-sale-category .badge','border-bottom-right-radius','50','','','.w-sale-category'),(471470,'furniture-mobile','.w-sale-category .left-count','border-bottom-right-radius','3','','','.w-sale-category'),(471471,'furniture-mobile','.w-sale-category .left-count-days','border-bottom-right-radius','3','','','.w-sale-category'),(471472,'furniture-mobile','.w-sale-category .left-count-hours','border-bottom-right-radius','3','','','.w-sale-category'),(471473,'furniture-mobile','.w-product-wedding-registry-button .btn','border-bottom-right-radius','50','3','','.w-product-wedding-registry-button'),(471474,'furniture-mobile','.w-product-wedding-registry-button .btn','border-bottom-right-radius','50','4','','.w-product-wedding-registry-button'),(471475,'furniture-mobile','.b-products-listing .productGroup label a','border-bottom-right-radius','3','','','.b-products-listing'),(471476,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-right-radius','12','','','.w-predefined-promotion'),(471477,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-right-radius','12','','','.w-predefined-promotion'),(471478,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-right-radius','12','','','.w-predefined-promotion'),(471479,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border-bottom-right-radius','12','','','.w-predefined-promotion'),(471480,'furniture-mobile','.lowestPricedBox .w-banner .ybg','border-bottom-right-radius','50','3','','.lowestPricedBox'),(471481,'furniture-mobile','.catalog-product-wrap .pn-image','border-bottom-right-radius','50','3','','.catalog-product-wrap'),(471482,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(471483,'furniture-mobile','.b-upload-file .upload-file-template div','border-bottom-style','dotted','','','.b-upload-file'),(471484,'furniture-mobile','.mainBanner .title','border-bottom-style','dashed','','','.mainBanner'),(471486,'furniture-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(471487,'furniture-mobile','.p-blog-index .comments-area article','border-bottom-width','1','','','.p-blog-index'),(471488,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border-bottom-width','1','','','.w-promotions'),(471489,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-width','2','','','.p-blog-index'),(471490,'furniture-mobile','.w-account .account-dropdown','border-bottom-width','1','','','.w-account'),(471491,'furniture-mobile','.p-reviews-info .review-info-text','border-bottom-width','5','4','','.p-reviews-info'),(471492,'furniture-mobile','.testimonials .review','border-bottom-width','7','3','',''),(471493,'furniture-mobile','.w-compare-box-item .checkbox + span','border-bottom-width','1','','','.w-compare-box-item'),(471494,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-width','1','','','.w-compare-box-item'),(471495,'furniture-mobile','.w-promotions .promo-salemaker .discount','border-bottom-width','1','','','.w-promotions'),(471496,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-width','1','','','.w-promotions'),(471497,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-width','1','','','.w-promotions'),(471498,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-width','1','','','.p-account-trade-form'),(471499,'furniture-mobile','.b-upload-file .upload-file-template div','border-bottom-width','1','','','.b-upload-file'),(471500,'furniture-mobile','.w-cart-compare .cart-cell > div','border-bottom-width','1','','','.w-cart-compare'),(471501,'furniture-mobile','.p-reviews-info .review-info-text','border-bottom-width','5','4','','.p-reviews-info'),(471502,'furniture-mobile','.w-filters .filter-box-head','border-bottom-width','1','','','.w-filters'),(471503,'furniture-mobile','.p-blog-index .comments-area article','border-bottom-width','1','','','.p-blog-index'),(471504,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-width','2','','','.p-blog-index'),(471505,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-bottom-width','1','','','.b-bottom'),(471506,'furniture-mobile','.b-messages .msv_btn','border-bottom-width','1','','','.b-messages'),(471507,'furniture-mobile','.b-messages .email-heading','border-bottom-width','1','','','.b-messages'),(471508,'furniture-mobile','.b-messages .content_management_attach button','border-bottom-width','1','','','.b-messages'),(471509,'furniture-mobile','.b-messages .content_management_attach','border-bottom-width','1','','','.b-messages'),(471510,'furniture-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-width','2','','','.b-messages'),(471511,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-width','1','','','.b-messages'),(471512,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-width','1','','','.b-messages'),(471513,'furniture-mobile','.b-messages .dataTables_wrapper > .bottom','border-bottom-width','1','','','.b-messages'),(471514,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-bottom-width','2','','',''),(471515,'furniture-mobile','.w-sale .left-text-right','border-bottom-width','2','','','.w-sale'),(471517,'furniture-mobile','.p-payer-order-confirmation .input-wrapper','border-bottom-width','2','','','.p-payer-order-confirmation'),(471518,'furniture-mobile','.p-payer-order-pay .input-wrapper','border-bottom-width','2','','','.p-payer-order-pay'),(471519,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-width','2','','','.p-blog-index'),(471520,'furniture-mobile','.b-messages .msv_to_cc','border-bottom-width','1','','','.b-messages'),(471521,'furniture-mobile','.w-product-reviews .reviews-list .review','border-bottom-width','7','3','','.w-product-reviews'),(471522,'furniture-mobile','.w-reviews .review','border-bottom-width','8','3','','.w-reviews'),(471524,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-width','1','','','.p-account-trade-form'),(471525,'furniture-mobile','.p-account-trade-form .widget .widget','border-bottom-width','1','','','.p-account-trade-form'),(471526,'furniture-mobile','.w-compare-box-item .checkbox + span','border-bottom-width','1','','','.w-compare-box-item'),(471527,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(471528,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(471529,'furniture-mobile','.w-tabs .accordion-heading','border-bottom-width','1','','','.w-tabs'),(471530,'furniture-mobile','.p-blog-index .comments-area article','border-bottom-width','1','','','.p-blog-index'),(471531,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-width','1','','','.p-account-trade-form'),(471532,'furniture-mobile','.p-account-trade-form .widget .widget','border-bottom-width','1','','','.p-account-trade-form'),(471533,'furniture-mobile','.b-form .required-error','border-bottom-width','1','','','.b-form'),(471535,'furniture-mobile','.p-account-trade-form .widget .widget','border-bottom-width','1','','','.p-account-trade-form'),(471536,'furniture-mobile','.p-reviews-info .review-info-text','border-bottom-width','5','4','','.p-reviews-info'),(471537,'furniture-mobile','.w-socials > li','border-bottom-width','1','','','.w-socials'),(471538,'furniture-mobile','.w-sale .left-text-right','border-bottom-width','2','','','.w-sale'),(471539,'furniture-mobile','.p-account-trade-form .widget .widget','border-bottom-width','1','','','.p-account-trade-form'),(471540,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-width','1','','','.w-compare-box-item'),(471541,'furniture-mobile','.b-bottom .popup-heading','border-bottom-width','1','','','.b-bottom'),(471542,'furniture-mobile','.w-checkout-shipping-choice span','border-bottom-width','2','','','.w-checkout-shipping-choice'),(471543,'furniture-mobile','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(471544,'furniture-mobile','.w-socials > li','border-bottom-width','1','','','.w-socials'),(471545,'furniture-mobile','.w-search .button-search','border-bottom-width','0','','','.w-search'),(471546,'furniture-mobile','.w-search .search-input','border-bottom-width','1','','','.w-search'),(471547,'furniture-mobile','.b-info-popup .info-popup div','border-bottom-width','1','','','.b-info-popup'),(471548,'furniture-mobile','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(471549,'furniture-mobile','.w-sale .sale-holder','border-bottom-width','2','','','.w-sale'),(471552,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(471554,'furniture-mobile','.w-tabs > .block','border-bottom-width','1','','','.w-tabs'),(471555,'furniture-mobile','.w-tabs .accordion-heading','border-bottom-width','3','2','','.w-tabs'),(471556,'furniture-mobile','.w-socials > li','border-bottom-width','1','','','.w-socials'),(471557,'furniture-mobile','.w-sale .sale-holder','border-bottom-width','2','','','.w-sale'),(471558,'furniture-mobile','.w-cart-give-away .ga_column','border-bottom-width','1','','','.w-cart-give-away'),(471559,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(471560,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-width','4','','','.b-switch'),(471561,'furniture-mobile','.w-filters .ui-slider-handle','border-bottom-width','0','','','.w-filters'),(471562,'furniture-mobile','.w-filters .ui-slider','border-bottom-width','0','','','.w-filters'),(471563,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(471564,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-bottom-width','1','','','.w-wedding-registry-widgets-photos'),(471565,'furniture-mobile','.w-sale .sale-holder','border-bottom-width','2','','','.w-sale'),(471566,'furniture-mobile','.w-sale .sale-holder','border-bottom-width','2','','','.w-sale'),(471567,'furniture-mobile','.p-blog-index .comments-area article','border-bottom-width','1','','','.p-blog-index'),(471568,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-width','2','3','','.b-form'),(471569,'furniture-mobile','.w-compare-box-item .checkbox + span','border-bottom-width','1','','','.w-compare-box-item'),(471570,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-width','1','','','.w-compare-box-item'),(471571,'furniture-mobile','.w-sale .sale-holder','border-bottom-width','2','','','.w-sale'),(471572,'furniture-mobile','.b-upload-file .upload-file-template','border-bottom-width','1','','','.b-upload-file'),(471573,'furniture-mobile','.w-socials > li','border-bottom-width','1','','','.w-socials'),(471574,'furniture-mobile','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(471575,'furniture-mobile','.w-reviews .item','border-bottom-width','1','','','.w-reviews'),(471576,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-bottom-width','1','','','.w-wedding-registry-widgets-photos'),(471577,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','border-bottom-width','2','','','.b-select-suggest'),(471578,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-width','2','4','','.b-switch'),(471579,'furniture-mobile','.w-sale .left-text-right','border-bottom-width','2','','','.w-sale'),(471580,'furniture-mobile','.w-sale .left-text-left','border-bottom-width','2','','','.w-sale'),(471581,'furniture-mobile','.w-languages .select','border-bottom-width','1','','','.w-languages'),(471582,'furniture-mobile','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(471583,'furniture-mobile','.w-compare-box-item .checkbox + span','border-bottom-width','1','','','.w-compare-box-item'),(471584,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-width','1','','','.p-account-trade-form'),(471585,'furniture-mobile','.w-sale .left-text-left','border-bottom-width','2','','','.w-sale'),(471586,'furniture-mobile','.w-sale .sale-holder','border-bottom-width','2','','','.w-sale'),(471587,'furniture-mobile','.p-reviews-info .review-info-text','border-bottom-width','5','4','','.p-reviews-info'),(471589,'furniture-mobile','.w-sale .left-text-right','border-bottom-width','2','','','.w-sale'),(471591,'furniture-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-width','1','','','.b-compare'),(471592,'furniture-mobile','.w-cart-compare .compare-table','border-bottom-width','1','','','.w-cart-compare'),(471593,'furniture-mobile','.w-sale .left-text-right','border-bottom-width','2','','','.w-sale'),(471594,'furniture-mobile','.w-reviews-content .review','border-bottom-width','8','3','','.w-reviews-content'),(471596,'furniture-mobile','textarea','border-bottom-width','2','','',''),(471597,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-width','2','','','.p-blog-index'),(471599,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-bottom-width','1','','','.b-bottom'),(471600,'furniture-mobile','.b-bottom .footerTitle','border-bottom-width','1','2876','','.b-bottom'),(471601,'furniture-mobile','.w-socials > li','border-bottom-width','1','','','.w-socials'),(471602,'furniture-mobile','.b-bottom .popup-box','border-bottom-width','1','','','.b-bottom'),(471604,'furniture-mobile','.w-product-customers-activity .customers-activity','border-bottom-width','1','','','.w-product-customers-activity'),(471605,'furniture-mobile','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(471606,'furniture-mobile','.w-compare-box-item .checkbox + span','border-bottom-width','1','','','.w-compare-box-item'),(471607,'furniture-mobile','.w-sale .left-text-left','border-bottom-width','2','','','.w-sale'),(471608,'furniture-mobile','.w-compare-box-item .checkbox + span','border-bottom-width','1','','','.w-compare-box-item'),(471609,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-width','1','','','.w-compare-box-item'),(471612,'furniture-mobile','.w-sale .left-text-left','border-bottom-width','2','','','.w-sale'),(471613,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-width','1','','','.w-compare-box-item'),(471614,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-width','2','','','.p-blog-index'),(471615,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(471616,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(471617,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(471618,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(471619,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-width','1','','','.b-select-suggest'),(471620,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(471621,'furniture-mobile','.b-select-suggest .select2-search input','border-bottom-width','1','','','.b-select-suggest'),(471622,'furniture-mobile','.b-select-suggest .select2-drop-active','border-bottom-width','1','','','.b-select-suggest'),(471623,'furniture-mobile','.b-select-suggest .select2-drop','border-bottom-width','1','','','.b-select-suggest'),(471624,'furniture-mobile','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(471625,'furniture-mobile','.p-blog-index .comments-area article','border-bottom-width','1','','','.p-blog-index'),(471626,'furniture-mobile','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(471627,'furniture-mobile','.w-communication-post .communication-post','border-bottom-width','1','','','.w-communication-post'),(471628,'furniture-mobile','.checkbox input:checked + span','border-bottom-width','1','','',''),(471629,'furniture-mobile','.w-blog-widget-post-title ','border-bottom-width','1','','','.w-blog-widget-post-title'),(471630,'furniture-mobile','.w-blog-widget-post-listing .post_name','border-bottom-width','1','','','.w-blog-widget-post-listing'),(471631,'furniture-mobile','.w-blog-widget-post-listing .post_content','border-bottom-width','1','','','.w-blog-widget-post-listing'),(471632,'furniture-mobile','.checkbox input + span','border-bottom-width','1','','',''),(471633,'furniture-mobile','.b-autocomplete .ui-autocomplete','border-bottom-width','1','','','.b-autocomplete'),(471634,'furniture-mobile','.w-currencies .select','border-bottom-width','1','','','.w-currencies'),(471635,'furniture-mobile','.w-currencies .currencies-title','border-bottom-width','2','','','.w-currencies'),(471636,'furniture-mobile','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(471638,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(471639,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-width','1','','','.p-account-trade-form'),(471640,'furniture-mobile','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(471641,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-width','2','3','','.b-switch'),(471642,'furniture-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(471643,'furniture-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(471645,'furniture-mobile','.w-sale .left-text-left','border-bottom-width','2','','','.w-sale'),(471646,'furniture-mobile','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(471647,'furniture-mobile','.w-sale .left-text-right','border-bottom-width','2','','','.w-sale'),(471648,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(471649,'furniture-mobile','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(471650,'furniture-mobile','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(471651,'furniture-mobile','.blogsidebar .heading-title','border-bottom-width','1','','','.blogsidebar'),(471652,'furniture-mobile','.w-cart-listing .item .gift-wrap label','border-bottom-width','1','','','.w-cart-listing'),(471653,'furniture-mobile','.w-cart-listing .item','border-bottom-width','1','2885','','.w-cart-listing'),(471654,'furniture-mobile','.w-cart .cart-content','border-bottom-width','1','','','.w-cart'),(471655,'furniture-mobile','.w-cart .multicart .item','border-bottom-width','1','','','.w-cart'),(471656,'furniture-mobile','.w-socials > li','border-bottom-width','1','','','.w-socials'),(471657,'furniture-mobile','.w-sale .left-text-left','border-bottom-width','2','','','.w-sale'),(471658,'furniture-mobile','.w-cart .cart-total','border-bottom-width','1','','','.w-cart'),(471659,'furniture-mobile','.p-reviews-info .review-info-text','border-bottom-width','5','4','','.p-reviews-info'),(471660,'furniture-mobile','.p-account-trade-form .widget .widget','border-bottom-width','1','','','.p-account-trade-form'),(471661,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','border-bottom-width','1','','','.p-account-trade-form'),(471662,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-bottom-width','2','','','.p-blog-index'),(471663,'furniture-mobile','.p-blog-index .comments-area article','border-bottom-width','1','','','.p-blog-index'),(471664,'furniture-mobile','.w-reviews-content .item','border-bottom-width','1','','','.w-reviews-content'),(471665,'furniture-mobile','.w-filters .ui-slider-range','border-bottom-width','0','','','.w-filters'),(471666,'furniture-mobile','.p-reviews-info .review-info-text','border-bottom-width','5','4','','.p-reviews-info'),(471667,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-bottom-width','1','','','.w-compare-box-item'),(471670,'furniture-mobile','.b-upload-files .upload-files','border-bottom-width','1','','','.b-upload-files'),(471671,'furniture-mobile','.b-compare .compare_pagination','border-bottom-width','1','','','.b-compare'),(471672,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-width','3','','','.b-switch'),(471673,'furniture-mobile','.p-account-trade-form .widget .widget','border-bottom-width','1','','','.p-account-trade-form'),(471674,'furniture-mobile','.b-upload-file .snapshot','border-bottom-width','1','','','.b-upload-file'),(471675,'furniture-mobile','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-bottom-width','2','','','.b-product-images'),(471676,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','border-bottom-width','1','','','.b-menu-style-2'),(471677,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-bottom-width','1','','','.b-menu-style-2'),(471678,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-bottom-width','3','','','.b-menu-style-2'),(471679,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-bottom-width','1','','','.b-menu-style-2'),(471680,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-bottom-width','3','','','.b-menu-style-2'),(471681,'furniture-mobile','.b-trade-approval .orders-table th','border-bottom-width','1','','','.b-trade-approval'),(471682,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-width','2','','','.b-trade-approval'),(471683,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-bottom-width','1','','','.batchPr'),(471684,'furniture-mobile','.batchPr .checkbox input + span','border-bottom-width','1','','','.batchPr'),(471685,'furniture-mobile','.batchPr .checkbox input + span','border-bottom-width','1','','','.batchPr'),(471686,'furniture-mobile','.batchPr .checkbox input:checked + span','border-bottom-width','1','','','.batchPr'),(471687,'furniture-mobile','.batchPr .w-batch-selected-products','border-bottom-width','1','','','.batchPr'),(471688,'furniture-mobile','.w-account-personal-catalog .list-switcher a','border-bottom-width','1','','','.w-account-personal-catalog'),(471689,'furniture-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-width','1','','','.w-catalog-compare'),(471690,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','border-bottom-width','1','','','.w-catalog-compare'),(471691,'furniture-mobile','.w-delivery-day .left-text-right','border-bottom-width','2','','','.w-delivery-day'),(471692,'furniture-mobile','.w-delivery-day .left-text-left','border-bottom-width','2','','','.w-delivery-day'),(471693,'furniture-mobile','.w-cart .cart-box-link','border-bottom-width','1','4','','.w-cart'),(471694,'furniture-mobile','.w-account .my-acc-link','border-bottom-width','1','4','','.w-account'),(471695,'furniture-mobile','.b-slick .slick-vertical .slick-slide','border-bottom-width','1','','','.b-slick'),(471696,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','border-bottom-width','1','2885','','.b-menu-style-3'),(471697,'furniture-mobile','.w-cart-listing .item, .w-cart-listing .headings','border-bottom-width','1','','','.w-cart-listing'),(471698,'furniture-mobile','.b-products-listing .products-listing .compare input + span','border-bottom-width','1','','','.b-products-listing'),(471699,'furniture-mobile','.w-filters .filter-widget','border-bottom-width','1','','','.w-filters'),(471700,'furniture-mobile','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-bottom-width','0','','','.w-filters'),(471701,'furniture-mobile','.w-quote .cart-content','border-bottom-width','1','','','.w-quote'),(471702,'furniture-mobile','.w-quote .cart-total','border-bottom-width','1','','','.w-quote'),(471703,'furniture-mobile','.w-quote .multicart .item','border-bottom-width','1','','','.w-quote'),(471704,'furniture-mobile','.b-product-images .additional-images .active img','border-bottom-width','2','','','.b-product-images'),(471705,'furniture-mobile','.b-product-images .additional-images img','border-bottom-width','2','','','.b-product-images'),(471706,'furniture-mobile','.b-quantity .qty-box .bigger','border-bottom-width','2','','','.b-quantity'),(471707,'furniture-mobile','.b-quantity .qty-box .smaller','border-bottom-width','2','','','.b-quantity'),(471708,'furniture-mobile','.w-product-sale-ends .left-text-left','border-bottom-width','2','','','.w-product-sale-ends'),(471709,'furniture-mobile','.w-product-sale-ends .left-text-right','border-bottom-width','2','','','.w-product-sale-ends'),(471710,'furniture-mobile','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(471711,'furniture-mobile','.warrantyProduct .warranty, .warrantyProduct .delivery','border-bottom-width','1','','','.warrantyProduct'),(471712,'furniture-mobile','.w-sample .cart-box-link','border-bottom-width','1','4','','.w-sample'),(471713,'furniture-mobile','.w-sample .cart-content','border-bottom-width','1','','','.w-sample'),(471714,'furniture-mobile','.w-sample .cart-total','border-bottom-width','1','','','.w-sample'),(471715,'furniture-mobile','.w-sample .multicart .item','border-bottom-width','1','','','.w-sample'),(471716,'furniture-mobile','.w-cart-listing .points-earn','border-bottom-width','17','4','','.w-cart-listing'),(471717,'furniture-mobile','.w-cart-discount-coupon .title','border-bottom-width','1','','','.w-cart-discount-coupon'),(471718,'furniture-mobile','.w-cart-discount-coupon .btn','border-bottom-width','2','','','.w-cart-discount-coupon'),(471719,'furniture-mobile','.w-product-video .item img, .w-product-video .item video','border-bottom-width','2','','','.w-product-video'),(471720,'furniture-mobile','.w-product-video .item.active img, .w-product-video .item.active video','border-bottom-width','2','','','.w-product-video'),(471721,'furniture-mobile','.shipping-ico .heading-3','border-bottom-width','1','','','.shipping-ico'),(471722,'furniture-mobile','.w-cart-order-reference .btn','border-bottom-width','2','','','.w-cart-order-reference'),(471723,'furniture-mobile','.w-cart-gift-certificate .btn','border-bottom-width','2','','','.w-cart-gift-certificate'),(471724,'furniture-mobile','.w-cart-shipping-estimator .btn','border-bottom-width','2','','','.w-cart-shipping-estimator'),(471725,'furniture-mobile','.w-account-address-book .item','border-bottom-width','1','','','.w-account-address-book'),(471726,'furniture-mobile','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-bottom-width','1','','','.b-pagination'),(471727,'furniture-mobile','.b-pagination .pagination .next-pages','border-bottom-width','1','','','.b-pagination'),(471728,'furniture-mobile','.b-pagination .pagination .page-number','border-bottom-width','1','','','.b-pagination'),(471729,'furniture-mobile','.b-pagination .pagination .prev-pages','border-bottom-width','1','','','.b-pagination'),(471730,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-bottom-width','1','','','.b-pagination'),(471731,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-bottom-width','1','','','.b-pagination'),(471732,'furniture-mobile','.b-pagination .pagination span','border-bottom-width','1','2','','.b-pagination'),(471733,'furniture-mobile','.w-tabs .tab-li','border-bottom-width','1','','','.w-tabs'),(471734,'furniture-mobile','.w-product-multi-inventory .radio-attributes','border-bottom-width','1','','','.w-product-multi-inventory'),(471735,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','border-bottom-width','2','','','.w-product-multi-inventory'),(471736,'furniture-mobile','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-bottom-width','2','','','.w-product-multi-inventory'),(471737,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-bottom-width','1','','','.w-account-personal-catalog'),(471738,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','border-bottom-width','1','','','.w-account-personal-catalog'),(471739,'furniture-mobile','.b-products-listing .products-listing .radio-attributes','border-bottom-width','1','','','.b-products-listing'),(471740,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','border-bottom-width','2','','','.b-products-listing'),(471741,'furniture-mobile','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-bottom-width','2','','','.b-products-listing'),(471742,'furniture-mobile','.w-product-attributes .radio-attributes','border-bottom-width','1','','','.w-product-attributes'),(471743,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','border-bottom-width','2','','','.w-product-attributes'),(471744,'furniture-mobile','.w-product-attributes .radio-attributes input:checked + .option-item','border-bottom-width','2','','','.w-product-attributes'),(471745,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-width','2','','','.w-questionnaire-widgets-questionnaire'),(471746,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-bottom-width','2','','','.w-questionnaire-widgets-questionnaire'),(471747,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-bottom-width','2','','','.w-questionnaire-widgets-questionnaire'),(471748,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-bottom-width','2','1','','.w-questionnaire-widgets-questionnaire'),(471749,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-bottom-width','2','1','','.w-questionnaire-widgets-questionnaire'),(471750,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','border-bottom-width','2','','','.w-product-groups'),(471751,'furniture-mobile','.w-product-groups .radioBox label .containerBlock.selected','border-bottom-width','2','','','.w-product-groups'),(471752,'furniture-mobile','.w-product-groups .radioBox label input:checked + .containerBlock','border-bottom-width','2','','','.w-product-groups'),(471753,'furniture-mobile','.w-delivery-location-top-location-list .deliveryName','border-bottom-width','1','','','.w-delivery-location-top-location-list'),(471754,'furniture-mobile','.w-delivery-location-location-list .deliveryName','border-bottom-width','1','','','.w-delivery-location-location-list'),(471755,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-bottom-width','2','','','.w-delivery-location-location-list'),(471756,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-bottom-width','2','1','','.w-delivery-location-location-list'),(471757,'furniture-mobile','.w-wedding-registry-widgets-search-form .closeable-heading','border-bottom-width','1','','','.w-wedding-registry-widgets-search-form'),(471758,'furniture-mobile','.w-sale-category .left-text-left','border-bottom-width','2','','','.w-sale-category'),(471759,'furniture-mobile','.w-sale-category .left-text-right','border-bottom-width','2','','','.w-sale-category'),(471760,'furniture-mobile','.w-sale-category .sale-holder','border-bottom-width','2','','','.w-sale-category'),(471761,'furniture-mobile','.w-wedding-registry-widgets-photos .upload-file-template','border-bottom-width','1','','','.w-wedding-registry-widgets-photos'),(471762,'furniture-mobile','.w-product-wedding-registry-button .btn','border-bottom-width','2','3','','.w-product-wedding-registry-button'),(471763,'furniture-mobile','.w-product-wedding-registry-button .btn','border-bottom-width','2','4','','.w-product-wedding-registry-button'),(471764,'furniture-mobile','.w-catalog-delivery-locations .name','border-bottom-width','1','','','.w-catalog-delivery-locations'),(471765,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','border-bottom-width','1','','','.w-wedding-registry-widgets-search-paging'),(471766,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','border-bottom-width','1','','','.w-wedding-registry-widgets-search-paging'),(471767,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','border-bottom-width','1','','','.w-wedding-registry-widgets-search-paging'),(471768,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','border-bottom-width','1','','','.w-wedding-registry-widgets-search-paging'),(471769,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','border-bottom-width','1','','','.w-product-designer-designer'),(471770,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small ','border-bottom-width','1','','','.w-press-reviews-widgets-press-reviews-small'),(471771,'furniture-mobile','.b-products-listing .productGroup label a','border-bottom-width','1','','','.b-products-listing'),(471772,'furniture-mobile','.w-support-system-listing .support-head','border-bottom-width','1','','','.w-support-system-listing'),(471773,'furniture-mobile','.w-support-system-listing .product_icon','border-bottom-width','1','','','.w-support-system-listing'),(471774,'furniture-mobile','.w-rma-returns-history .topRow','border-bottom-width','1','','','.w-rma-returns-history'),(471775,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-width','1','','','.w-predefined-promotion'),(471776,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-width','1','','','.w-predefined-promotion'),(471777,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-width','1','','','.w-predefined-promotion'),(471778,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border-bottom-width','1','','','.w-predefined-promotion'),(471779,'furniture-mobile','.w-supplier-purchase-supplier-products .item','border-bottom-width','1','','','.w-supplier-purchase-supplier-products'),(471780,'furniture-mobile','.mainBanner .bottomBox .btn','border-bottom-width','0.21','','','.mainBanner'),(471781,'furniture-mobile','.mainBanner .title','border-bottom-width','2','','','.mainBanner'),(471782,'furniture-mobile','.mainBanner .topBox > .right','border-bottom-width','23','4','','.mainBanner'),(471783,'furniture-mobile','.mainBanner .bottomBox .btn','border-bottom-width','2','2890','','.mainBanner'),(471784,'furniture-mobile','.mainBanner .topBox > .right','border-bottom-width','20','2890,4','','.mainBanner'),(471785,'furniture-mobile','.mainBanner .bottomBox .btn','border-bottom-width','3','2876','','.mainBanner'),(471786,'furniture-mobile','.mainBanner .topBox > .right','border-bottom-width','15','2876,4','','.mainBanner'),(471787,'furniture-mobile','.mainBanner .bottomBox .btn','border-bottom-width','2','2906','','.mainBanner'),(471788,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','border-bottom-width','2','','','.lowestPricedBox'),(471789,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-bottom-width','2','','','.shopByCollectionBox'),(471790,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-bottom-width','2','2890','','.shopByCollectionBox'),(471791,'furniture-mobile','.w-search .products .item a','border-bottom-width','1','','','.w-search'),(471792,'furniture-mobile','.account-address-book .address_book h1','border-bottom-width','1','','','.account-address-book'),(471793,'furniture-mobile','.account-address-book .address_book h2','border-bottom-width','1','','','.account-address-book'),(471794,'furniture-mobile','.account-order-history .orders-table .item','border-bottom-width','1','2885','','.account-order-history'),(471795,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','border-bottom-width','1','','','.account-order-history-info'),(471796,'furniture-mobile','.account-index .orders-table .item','border-bottom-width','1','2885','','.account-index'),(471797,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','border-bottom-width','1','','','.account-order-pay'),(471798,'furniture-mobile','.account-samples .orders-table .item','border-bottom-width','1','2885','','.account-samples'),(471799,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','border-bottom-width','1','','','.account-sample-info'),(471800,'furniture-mobile','.catalog-product-wrap .pn-image','border-bottom-width','2','3','','.catalog-product-wrap'),(471801,'furniture-mobile','.catalog-product-wrap .prev-next-product','border-bottom-width','1','','','.catalog-product-wrap'),(471802,'furniture-mobile','.shopping-cart-index .btn-3','border-bottom-width','2','','','.shopping-cart-index'),(471803,'furniture-mobile','.checkout-index-wrap .input-wrapper','border-bottom-width','2','','','.checkout-index-wrap'),(471804,'furniture-mobile','.b-compare .popupCompare table','border-collapse','collapse','','','.b-compare'),(471805,'furniture-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','border-left','none','','','.b-select-suggest'),(471806,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border-left-color','$border-attention','','','.w-promotions'),(471807,'furniture-mobile','.w-cart-compare .attributes-block td:nth-child(1)','border-left-color','$border-color-4','','','.w-cart-compare'),(471808,'furniture-mobile','.w-account .account-dropdown','border-left-color','$border-color-4','','','.w-account'),(471809,'furniture-mobile','.p-reviews-info .review-info-text','border-left-color','$border-reverse','4','','.p-reviews-info'),(471810,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-left-color','$border-message','','','.w-compare-box-item'),(471811,'furniture-mobile','.w-compare-box-item .checkbox + span','border-left-color','$border-color-4','','','.w-compare-box-item'),(471812,'furniture-mobile','.w-promotions .promo-salemaker .discount','border-left-color','$border-warning','','','.w-promotions'),(471813,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-color','$border-attention','','','.w-promotions'),(471814,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-left-color','$border-attention','','','.w-promotions'),(471815,'furniture-mobile','.w-cart-compare .cart-cell > div','border-left-color','$border-color-4','','','.w-cart-compare'),(471816,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','$border-color-4','','','.b-dropdown'),(471817,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-left-color','$border-color-4','','','.b-bottom'),(471818,'furniture-mobile','.b-messages .content_management_attach button','border-left-color','$border-color-5','','','.b-messages'),(471819,'furniture-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-color','$border-color-4','','','.b-messages'),(471820,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-left-color','$border-color-4','','',''),(471821,'furniture-mobile','.w-sale .sale-holder','border-left-color','$border-color-4','','','.w-sale'),(471822,'furniture-mobile','.w-promo-code .holder','border-left-color','$border-color-4','','','.w-promo-code'),(471823,'furniture-mobile','.w-cart-products .checkout-attention-message','border-left-color','$border-attention','','','.w-cart-products'),(471824,'furniture-mobile','.w-socials > li','border-left-color','$border-color-4','','','.w-socials'),(471825,'furniture-mobile','.p-payer-order-confirmation .input-wrapper','border-left-color','$border-color-4','','','.p-payer-order-confirmation'),(471826,'furniture-mobile','.p-payer-order-pay .input-wrapper','border-left-color','$border-color-4','','','.p-payer-order-pay'),(471827,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-color','$border-color-4','','','.p-blog-index'),(471829,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-left-color','$border-color-4','','','.b-switch'),(471830,'furniture-mobile','.w-cart-products .checkout-attention-message','border-left-color','$border-attention','','','.w-cart-products'),(471832,'furniture-mobile','.w-cart-products .checkout-attention-message','border-left-color','$border-attention','','','.w-cart-products'),(471833,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-color','$border-color-3','','','.w-upload-customer-id-upload-customer-id-form'),(471834,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-left-color','$border-color-3','','','.w-wedding-registry-widgets-photos'),(471835,'furniture-mobile','.b-info-popup .info-popup div','border-left-color','$border-color-4','3','','.b-info-popup'),(471836,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-left-color','$border-message','','','.w-compare-box-item'),(471837,'furniture-mobile','.p-reviews-info .review-info-text','border-left-color','$border-reverse','4','','.p-reviews-info'),(471839,'furniture-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-color','$border-color-6','','','.b-compare'),(471840,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-color','$border-color-4','','','.p-blog-index'),(471841,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-color','$border-color-4','','','.p-blog-index'),(471842,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','$border-color-4','','','.b-dropdown'),(471843,'furniture-mobile','.b-form .required-error','border-left-color','$border-attention','','','.b-form'),(471845,'furniture-mobile','.w-socials > li','border-left-color','$border-color-4','','','.w-socials'),(471846,'furniture-mobile','.b-info-popup .info-popup div','border-left-color','$border-color-4','','','.b-info-popup'),(471847,'furniture-mobile','.w-checkout-shipping-choice label:first-child span','border-left-color','$border-color-5','','','.w-checkout-shipping-choice'),(471849,'furniture-mobile','.w-promo-code .holder','border-left-color','$border-color-4','','','.w-promo-code'),(471850,'furniture-mobile','.w-tabs > .block','border-left-color','$border-color-3','','','.w-tabs'),(471851,'furniture-mobile','.w-socials > li','border-left-color','$border-color-4','','','.w-socials'),(471852,'furniture-mobile','.w-sale .sale-holder','border-left-color','$border-color-4','','','.w-sale'),(471853,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-left-color','$border-color-3','','','.w-wedding-registry-widgets-photos'),(471854,'furniture-mobile','.w-compare-box-item .checkbox + span','border-left-color','$border-color-4','','','.w-compare-box-item'),(471855,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','$border-color-4','','','.b-dropdown'),(471856,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-left-color','$border-reverse','','','.b-switch'),(471858,'furniture-mobile','.w-sale .sale-holder','border-left-color','$border-color-4','','','.w-sale'),(471859,'furniture-mobile','.w-reviews .review','border-left-color','$border-reverse','3','','.w-reviews'),(471861,'furniture-mobile','.w-reviews-content .review','border-left-color','$border-color-4','3','','.w-reviews-content'),(471862,'furniture-mobile','.p-reviews-info .review-info-text','border-left-color','$border-reverse','4','','.p-reviews-info'),(471863,'furniture-mobile','.w-sale .sale-holder','border-left-color','$border-color-4','','','.w-sale'),(471864,'furniture-mobile','.w-promo-code .holder','border-left-color','$border-color-4','','','.w-promo-code'),(471865,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','border-left-color','$border-color-4','','','.b-select-suggest'),(471868,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-left-color','$border-color-4','4','','.b-switch'),(471869,'furniture-mobile','.w-languages .select','border-left-color','$border-color-4','','','.w-languages'),(471870,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-left-color','$border-message','','','.w-compare-box-item'),(471871,'furniture-mobile','.w-cart-products .checkout-attention-message','border-left-color','$border-attention','','','.w-cart-products'),(471872,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-left-color','$border-message','','','.w-compare-box-item'),(471873,'furniture-mobile','.w-socials > li','border-left-color','$border-color-4','','','.w-socials'),(471874,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-left-color','$border-reverse','','','.b-bottom'),(471875,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-color','$border-color-4','','','.p-blog-index'),(471876,'furniture-mobile','textarea','border-left-color','$border-color-4','','',''),(471878,'furniture-mobile','.b-bottom .popup-box','border-left-color','$border-color-4','','','.b-bottom'),(471881,'furniture-mobile','.w-product-customers-activity .customers-activity','border-left-color','$border-color-4','','','.w-product-customers-activity'),(471882,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','$border-color-4','','','.b-dropdown'),(471883,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-left-color','$border-color-4','3','','.b-form'),(471884,'furniture-mobile','.w-cart-compare .price-block td:nth-child(1)','border-left-color','$border-color-4','','','.w-cart-compare'),(471885,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-left-color','$border-message','','','.w-compare-box-item'),(471886,'furniture-mobile','.w-compare-box-item .checkbox + span','border-left-color','$border-color-4','','','.w-compare-box-item'),(471888,'furniture-mobile','.w-compare-box-item .checkbox + span','border-left-color','$border-color-4','','','.w-compare-box-item'),(471889,'furniture-mobile','.w-sale .sale-holder','border-left-color','$border-color-4','','','.w-sale'),(471891,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-color','$border-color-4','','','.p-blog-index'),(471892,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-color','$border-color-4','','','.b-select-suggest'),(471893,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-color','$border-color-4','','','.b-select-suggest'),(471894,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-left-color','$border-message','','','.w-compare-box-item'),(471895,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-color','$border-color-4','','','.b-select-suggest'),(471896,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-color','$border-color-4','','','.b-select-suggest'),(471897,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-left-color','$border-color-4','','','.b-select-suggest'),(471898,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-color','$border-color-4','','','.b-select-suggest'),(471899,'furniture-mobile','.b-select-suggest .select2-search input','border-left-color','$border-color-4','','','.b-select-suggest'),(471900,'furniture-mobile','.b-select-suggest .select2-drop','border-left-color','$border-color-4','','','.b-select-suggest'),(471901,'furniture-mobile','.b-select-suggest .select2-drop-active','border-left-color','$border-color-4','','','.b-select-suggest'),(471902,'furniture-mobile','.w-socials > li','border-left-color','$border-color-4','','','.w-socials'),(471903,'furniture-mobile','.p-reviews-info .review-info-text','border-left-color','$border-reverse','4','','.p-reviews-info'),(471904,'furniture-mobile','.w-promo-code .holder','border-left-color','$border-color-4','','','.w-promo-code'),(471905,'furniture-mobile','.w-sale .sale-holder','border-left-color','$border-color-4','','','.w-sale'),(471906,'furniture-mobile','.b-form input.required-error','border-left-color','$border-attention','','','.b-form'),(471907,'furniture-mobile','.checkbox input:checked + span','border-left-color','$border-message','','',''),(471908,'furniture-mobile','.checkbox input + span','border-left-color','$border-color-4','','',''),(471909,'furniture-mobile','.b-autocomplete .ui-autocomplete','border-left-color','$border-color-4','','','.b-autocomplete'),(471910,'furniture-mobile','.w-currencies .select','border-left-color','$border-color-4','','','.w-currencies'),(471911,'furniture-mobile','.w-currencies .currencies-title','border-left-color','$border-color-5','','','.w-currencies'),(471912,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-left-color','$border-color-4','3','','.b-switch'),(471913,'furniture-mobile','.p-reviews-info .review-info-text','border-left-color','$border-reverse','4','','.p-reviews-info'),(471914,'furniture-mobile','.b-upload-file .snapshot','border-left-color','$border-color-6','','','.b-upload-file'),(471915,'furniture-mobile','.w-socials > li','border-left-color','$border-color-4','','','.w-socials'),(471916,'furniture-mobile','.w-promo-code .holder','border-left-color','$border-color-4','','','.w-promo-code'),(471918,'furniture-mobile','.b-upload-files .upload-files','border-left-color','$border-color-4','','','.b-upload-files'),(471919,'furniture-mobile','.w-compare-box-item .checkbox + span','border-left-color','$border-color-4','','','.w-compare-box-item'),(471920,'furniture-mobile','.b-upload-file .upload-file-template','border-left-color','$border-color-4','','','.b-upload-file'),(471921,'furniture-mobile','.w-promo-code .holder','border-left-color','$border-color-4','','','.w-promo-code'),(471922,'furniture-mobile','.w-cart-products .checkout-attention-message','border-left-color','$border-attention','','','.w-cart-products'),(471924,'furniture-mobile','.w-cart-listing .item .gift-wrap label','border-left-color','$border-color-4','','','.w-cart-listing'),(471925,'furniture-mobile','.w-cart-listing .item','border-left-color','$border-color-4','2885','','.w-cart-listing'),(471926,'furniture-mobile','.w-cart .cart-content','border-left-color','$border-color-4','','','.w-cart'),(471927,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','$border-color-4','','','.b-dropdown'),(471928,'furniture-mobile','.w-cart-products .checkout-attention-message','border-left-color','$border-attention','','','.w-cart-products'),(471929,'furniture-mobile','.w-compare-box-item .checkbox + span','border-left-color','$border-color-4','','','.w-compare-box-item'),(471931,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-color','$border-color-4','','','.p-blog-index'),(471932,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-color','$border-color-4','','','.b-dropdown'),(471933,'furniture-mobile','.w-cart-compare .product-block td:nth-child(1)','border-left-color','$border-color-4','','','.w-cart-compare'),(471934,'furniture-mobile','.b-data-table table.dataTable.no-footer','border-left-color','$border-color-4','','','.b-data-table'),(471936,'furniture-mobile','.p-reviews-info .review-info-text','border-left-color','$border-reverse','4','','.p-reviews-info'),(471937,'furniture-mobile','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-left-color','$border-reverse','','','.b-product-images'),(471938,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-left-color','$border-color-2','','','.b-menu-style-2'),(471939,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-left-color','$border-color-2','','','.b-menu-style-2'),(471940,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-left-color','$border-color-2','','','.b-menu-style-2'),(471941,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-left-color','$border-color-2','','','.b-menu-style-2'),(471942,'furniture-mobile','.b-trade-approval .steps-bar li ~ li a','border-left-color','$border-reverse','','','.b-trade-approval'),(471943,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-color','$border-color-4','','','.b-trade-approval'),(471944,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-left-color','$border-color-4','','','.batchPr'),(471945,'furniture-mobile','.batchPr .checkbox input + span','border-left-color','$border-color-4','','','.batchPr'),(471946,'furniture-mobile','.batchPr .checkbox input + span','border-left-color','$border-color-4','','','.batchPr'),(471947,'furniture-mobile','.batchPr .checkbox input:checked + span','border-left-color','$border-color-2','','','.batchPr'),(471948,'furniture-mobile','.batchPr .w-batch-selected-products','border-left-color','$border-color-4','','','.batchPr'),(471949,'furniture-mobile','.w-account-personal-catalog .list-switcher a','border-left-color','$border-color-4','2','','.w-account-personal-catalog'),(471950,'furniture-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-left-color','$border-reverse','','','.w-catalog-compare'),(471951,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','border-left-color','$border-color-4','2','','.w-catalog-compare'),(471952,'furniture-mobile','.w-search .search-input','border-left-color','$border-color-2','','','.w-search'),(471953,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li + li','border-left-color','$border-color-2','2945','','.b-menu-style-3'),(471954,'furniture-mobile','.b-products-listing .products-listing .compare input + span','border-left-color','$border-color-5','','','.b-products-listing'),(471955,'furniture-mobile','.w-filters .filter-widget','border-left-color','$border-color-4','','','.w-filters'),(471956,'furniture-mobile','.w-quote .cart-content','border-left-color','$border-color-4','','','.w-quote'),(471957,'furniture-mobile','.b-product-images .additional-images .active img','border-left-color','$border-color-5','','','.b-product-images'),(471958,'furniture-mobile','.b-product-images .additional-images img','border-left-color','$border-reverse','','','.b-product-images'),(471959,'furniture-mobile','.b-quantity .qty-box .bigger','border-left-color','$border-color-1','','','.b-quantity'),(471960,'furniture-mobile','.b-quantity .qty-box .smaller','border-left-color','$border-color-1','','','.b-quantity'),(471961,'furniture-mobile','.w-sample .cart-content','border-left-color','$border-color-4','','','.w-sample'),(471962,'furniture-mobile','.w-cart-listing .points-earn','border-left-color','$border-color-4','4','','.w-cart-listing'),(471963,'furniture-mobile','.w-cart-discount-coupon .btn','border-left-color','$border-color-5','','','.w-cart-discount-coupon'),(471964,'furniture-mobile','.w-product-video .item img, .w-product-video .item video','border-left-color','$border-reverse','','','.w-product-video'),(471965,'furniture-mobile','.w-product-video .item.active img, .w-product-video .item.active video','border-left-color','$border-color-7','','','.w-product-video'),(471966,'furniture-mobile','.w-cart-order-reference .btn','border-left-color','$border-color-5','','','.w-cart-order-reference'),(471967,'furniture-mobile','.w-cart-gift-certificate .btn','border-left-color','$border-color-5','','','.w-cart-gift-certificate'),(471968,'furniture-mobile','.w-cart-shipping-estimator .btn','border-left-color','$border-color-5','','','.w-cart-shipping-estimator'),(471969,'furniture-mobile','.w-account-address-book .item','border-left-color','$border-color-3','','','.w-account-address-book'),(471970,'furniture-mobile','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-left-color','$border-color-8','','','.b-pagination'),(471971,'furniture-mobile','.b-pagination .pagination .next-pages','border-left-color','$border-color-4','','','.b-pagination'),(471972,'furniture-mobile','.b-pagination .pagination .page-number','border-left-color','$border-color-4','','','.b-pagination'),(471973,'furniture-mobile','.b-pagination .pagination .prev-pages','border-left-color','$border-color-4','','','.b-pagination'),(471974,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-left-color','$border-color-4','','','.b-pagination'),(471975,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-left-color','$border-color-4','','','.b-pagination'),(471976,'furniture-mobile','.b-pagination .pagination span','border-left-color','$border-color-4','2','','.b-pagination'),(471977,'furniture-mobile','.w-tabs .tab-li','border-left-color','$border-color-4','2','','.w-tabs'),(471978,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','border-left-color','$border-color-4','','','.w-product-multi-inventory'),(471979,'furniture-mobile','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-left-color','$border-color-5','','','.w-product-multi-inventory'),(471980,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-left-color','$border-color-3','','','.w-account-personal-catalog'),(471981,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','border-left-color','$border-color-3','','','.w-account-personal-catalog'),(471982,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','border-left-color','$border-color-4','','','.b-products-listing'),(471983,'furniture-mobile','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-left-color','$border-color-5','','','.b-products-listing'),(471984,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','border-left-color','$border-color-4','','','.w-product-attributes'),(471985,'furniture-mobile','.w-product-attributes .radio-attributes input:checked + .option-item','border-left-color','$border-color-5','','','.w-product-attributes'),(471986,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-left-color','$border-color-3','','','.w-questionnaire-widgets-questionnaire'),(471987,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-left-color','$border-attention','','','.w-questionnaire-widgets-questionnaire'),(471988,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-left-color','$border-message','','','.w-questionnaire-widgets-questionnaire'),(471989,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-left-color','$border-attention','1','','.w-questionnaire-widgets-questionnaire'),(471990,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-left-color','$border-message','1','','.w-questionnaire-widgets-questionnaire'),(471991,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','border-left-color','$border-color-3','','','.w-product-groups'),(471992,'furniture-mobile','.w-product-groups .radioBox label .containerBlock.selected','border-left-color','$border-color-5','','','.w-product-groups'),(471993,'furniture-mobile','.w-product-groups .radioBox label input:checked + .containerBlock','border-left-color','$border-color-5','','','.w-product-groups'),(471994,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-left-color','$border-color-4','','','.w-delivery-location-location-list'),(471995,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-left-color','$border-color-5','1','','.w-delivery-location-location-list'),(471996,'furniture-mobile','.w-sale-category .sale-holder','border-left-color','$border-color-4','','','.w-sale-category'),(471997,'furniture-mobile','.w-wedding-registry-widgets-photos .upload-file-template','border-left-color','$border-color-3','','','.w-wedding-registry-widgets-photos'),(471998,'furniture-mobile','.w-product-wedding-registry-button .btn','border-left-color','$border-color-5','3','','.w-product-wedding-registry-button'),(471999,'furniture-mobile','.w-product-wedding-registry-button .btn','border-left-color','$border-color-5','4','','.w-product-wedding-registry-button'),(472000,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-left-color','$border-color-4','','','.w-product-properties-icons'),(472001,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','border-left-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(472002,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','border-left-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(472003,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','border-left-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(472004,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','border-left-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(472005,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','border-left-color','$border-color-3','','','.w-product-designer-designer'),(472006,'furniture-mobile','.b-products-listing .productGroup label a','border-left-color','$border-color-5','','','.b-products-listing'),(472007,'furniture-mobile','.w-support-system-listing .support-head','border-left-color','$border-color-1','','','.w-support-system-listing'),(472008,'furniture-mobile','.w-support-system-listing .product_icon','border-left-color','$border-color-1','','','.w-support-system-listing'),(472009,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border-left-color','$border-attention','','','.w-predefined-promotion'),(472010,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-left-color','$border-attention','','','.w-predefined-promotion'),(472011,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-left-color','$border-attention','','','.w-predefined-promotion'),(472012,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border-left-color','$border-warning','','','.w-predefined-promotion'),(472013,'furniture-mobile','.w-supplier-purchase-supplier-products .item','border-left-color','$border-color-3','','','.w-supplier-purchase-supplier-products'),(472014,'furniture-mobile','.mainBanner .bottomBox .btn','border-left-color','$border-color-2','','','.mainBanner'),(472015,'furniture-mobile','.mainBanner .bottomBox .btn','border-left-color','$border-color-2','2890','','.mainBanner'),(472016,'furniture-mobile','.mainBanner .bottomBox .btn','border-left-color','$border-color-2','2876','','.mainBanner'),(472017,'furniture-mobile','.mainBanner .bottomBox .btn','border-left-color','$border-color-2','2906','','.mainBanner'),(472018,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','border-left-color','$border-color-5','','','.lowestPricedBox'),(472019,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-left-color','$border-color-2','','','.shopByCollectionBox'),(472020,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-left-color','$border-color-2','2890','','.shopByCollectionBox'),(472021,'furniture-mobile','.account-order-history .orders-table .item','border-left-color','$border-color-4','2885','','.account-order-history'),(472022,'furniture-mobile','.account-index .orders-table .item','border-left-color','$border-color-4','2885','','.account-index'),(472023,'furniture-mobile','.account-samples .orders-table .item','border-left-color','$border-color-4','2885','','.account-samples'),(472024,'furniture-mobile','.catalog-product-wrap .pn-image','border-left-color','$border-color-4','3','','.catalog-product-wrap'),(472025,'furniture-mobile','.shopping-cart-index .btn-3','border-left-color','$border-color-5','','','.shopping-cart-index'),(472026,'furniture-mobile','.checkout-index-wrap .input-wrapper','border-left-color','$border-color-4','','','.checkout-index-wrap'),(472027,'furniture-mobile','.b-data-table table.dataTable.no-footer','border-left-color_important','important','','','.b-data-table'),(472028,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(472029,'furniture-mobile','.w-compare-box-item .checkbox + span','border-left-width','1','','','.w-compare-box-item'),(472030,'furniture-mobile','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(472031,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-left-width','1','','','.w-compare-box-item'),(472032,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border-left-width','1','','','.w-promotions'),(472033,'furniture-mobile','.w-cart-compare .attributes-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(472034,'furniture-mobile','.w-account .acc-returning','border-left-width','1','','','.w-account'),(472035,'furniture-mobile','.w-account .account-dropdown','border-left-width','1','','','.w-account'),(472036,'furniture-mobile','.p-reviews-info .review-info-text','border-left-width','5','4','','.p-reviews-info'),(472037,'furniture-mobile','.testimonials .review','border-left-width','10','3','',''),(472038,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-left-width','1','','','.w-compare-box-item'),(472039,'furniture-mobile','.w-compare-box-item .checkbox + span','border-left-width','1','','','.w-compare-box-item'),(472040,'furniture-mobile','.w-promotions .promo-salemaker .discount','border-left-width','1','','','.w-promotions'),(472041,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-width','1','','','.w-promotions'),(472042,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-left-width','1','','','.w-promotions'),(472043,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-left-width','1','','','.w-compare-box-item'),(472044,'furniture-mobile','.b-messages .content_management_attach button','border-left-width','1','','','.b-messages'),(472045,'furniture-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-width','2','','','.b-messages'),(472046,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-left-width','2','','',''),(472047,'furniture-mobile','.p-payer-order-confirmation .input-wrapper','border-left-width','2','','','.p-payer-order-confirmation'),(472048,'furniture-mobile','.p-payer-order-pay .input-wrapper','border-left-width','2','','','.p-payer-order-pay'),(472049,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-width','2','','','.p-blog-index'),(472050,'furniture-mobile','.w-product-reviews .reviews-list .review','border-left-width','10','3','','.w-product-reviews'),(472052,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(472054,'furniture-mobile','.w-sale .sale-holder','border-left-width','2','','','.w-sale'),(472055,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-left-width','1','','','.w-wedding-registry-widgets-photos'),(472058,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-left-width','2','3','','.b-form'),(472059,'furniture-mobile','.b-info-popup .info-popup div','border-left-width','1','3','','.b-info-popup'),(472060,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-left-width','2','3','','.b-switch'),(472061,'furniture-mobile','.w-compare-box-item .checkbox + span','border-left-width','1','','','.w-compare-box-item'),(472062,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(472063,'furniture-mobile','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(472064,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-left-width','1','','','.b-bottom'),(472065,'furniture-mobile','.w-socials > li','border-left-width','1','','','.w-socials'),(472066,'furniture-mobile','.w-search .search-input','border-left-width','1','','','.w-search'),(472067,'furniture-mobile','.w-cart-compare .cart-cell > div','border-left-width','1','','','.w-cart-compare'),(472068,'furniture-mobile','.b-info-popup .info-popup div','border-left-width','1','','','.b-info-popup'),(472069,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-width','2','','','.p-blog-index'),(472072,'furniture-mobile','.w-tabs > .block','border-left-width','1','','','.w-tabs'),(472073,'furniture-mobile','.w-socials > li','border-left-width','1','','','.w-socials'),(472074,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(472075,'furniture-mobile','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(472076,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-left-width','4','','','.b-switch'),(472077,'furniture-mobile','.w-filters .ui-slider-handle','border-left-width','0','','','.w-filters'),(472078,'furniture-mobile','.w-filters .ui-slider','border-left-width','0','','','.w-filters'),(472081,'furniture-mobile','.w-socials > li','border-left-width','1','','','.w-socials'),(472082,'furniture-mobile','.w-sale .sale-holder','border-left-width','2','','','.w-sale'),(472083,'furniture-mobile','.w-reviews .review','border-left-width','12','3','','.w-reviews'),(472084,'furniture-mobile','.w-search .button-search','border-left-width','0','','','.w-search'),(472085,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-left-width','3','','','.b-switch'),(472086,'furniture-mobile','.w-reviews-content .review','border-left-width','12','3','','.w-reviews-content'),(472087,'furniture-mobile','.w-sale .sale-holder','border-left-width','2','','','.w-sale'),(472088,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(472089,'furniture-mobile','.w-socials > li','border-left-width','1','','','.w-socials'),(472090,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-left-width','1','','','.w-wedding-registry-widgets-photos'),(472091,'furniture-mobile','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(472092,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','border-left-width','2','','','.b-select-suggest'),(472094,'furniture-mobile','.w-compare-box-item .checkbox + span','border-left-width','1','','','.w-compare-box-item'),(472095,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-left-width','2','4','','.b-switch'),(472096,'furniture-mobile','.w-languages .select','border-left-width','1','','','.w-languages'),(472097,'furniture-mobile','.b-form .required-error','border-left-width','1','','','.b-form'),(472098,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-left-width','1','','','.w-compare-box-item'),(472099,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-left-width','1','','','.w-compare-box-item'),(472100,'furniture-mobile','.p-reviews-info .review-info-text','border-left-width','5','4','','.p-reviews-info'),(472101,'furniture-mobile','.p-reviews-info .review-info-text','border-left-width','5','4','','.p-reviews-info'),(472103,'furniture-mobile','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(472105,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-width','2','','','.p-blog-index'),(472106,'furniture-mobile','textarea','border-left-width','2','','',''),(472107,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(472108,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-left-width','1','','','.b-bottom'),(472110,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(472112,'furniture-mobile','.w-cart-compare .product-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(472113,'furniture-mobile','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(472114,'furniture-mobile','.w-sale .sale-holder','border-left-width','2','','','.w-sale'),(472115,'furniture-mobile','.b-bottom .popup-box','border-left-width','1','','','.b-bottom'),(472117,'furniture-mobile','.w-product-customers-activity .customers-activity','border-left-width','1','','','.w-product-customers-activity'),(472118,'furniture-mobile','.p-reviews-info .review-info-text','border-left-width','5','4','','.p-reviews-info'),(472119,'furniture-mobile','.w-cart-compare .price-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(472120,'furniture-mobile','.w-socials > li','border-left-width','1','','','.w-socials'),(472123,'furniture-mobile','.w-compare-box-item .checkbox + span','border-left-width','1','','','.w-compare-box-item'),(472124,'furniture-mobile','.w-socials > li','border-left-width','1','','','.w-socials'),(472125,'furniture-mobile','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(472126,'furniture-mobile','.p-reviews-info .review-info-text','border-left-width','5','4','','.p-reviews-info'),(472127,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(472128,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-width','1','','','.b-select-suggest'),(472129,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(472130,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-left-width','1','','','.b-select-suggest'),(472131,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-width','1','','','.b-select-suggest'),(472132,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','border-left-width','0','','','.b-select-suggest'),(472133,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-width','1','','','.b-select-suggest'),(472134,'furniture-mobile','.b-select-suggest .select2-search input','border-left-width','1','','','.b-select-suggest'),(472135,'furniture-mobile','.b-select-suggest .select2-drop-active','border-left-width','1','','','.b-select-suggest'),(472136,'furniture-mobile','.b-select-suggest .select2-drop','border-left-width','1','','','.b-select-suggest'),(472137,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-width','2','','','.p-blog-index'),(472138,'furniture-mobile','.b-upload-file .upload-file-template','border-left-width','1','','','.b-upload-file'),(472139,'furniture-mobile','.p-reviews-info .review-info-text','border-left-width','5','4','','.p-reviews-info'),(472140,'furniture-mobile','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(472141,'furniture-mobile','.checkbox input:checked + span','border-left-width','1','','',''),(472142,'furniture-mobile','.checkbox input + span','border-left-width','1','','',''),(472143,'furniture-mobile','.b-autocomplete .ui-autocomplete','border-left-width','1','','','.b-autocomplete'),(472144,'furniture-mobile','.w-currencies .select','border-left-width','1','','','.w-currencies'),(472145,'furniture-mobile','.w-currencies .currencies-title','border-left-width','2','','','.w-currencies'),(472146,'furniture-mobile','.w-checkout-shipping-choice label:first-child span','border-left-width','2','','','.w-checkout-shipping-choice'),(472148,'furniture-mobile','.w-sale .sale-holder','border-left-width','2','','','.w-sale'),(472149,'furniture-mobile','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(472150,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-width','2','','','.p-blog-index'),(472151,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-left-width','1','','','.w-compare-box-item'),(472152,'furniture-mobile','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(472153,'furniture-mobile','.w-sale .sale-holder','border-left-width','2','','','.w-sale'),(472154,'furniture-mobile','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(472155,'furniture-mobile','.w-cart-listing .item .gift-wrap label','border-left-width','1','','','.w-cart-listing'),(472156,'furniture-mobile','.w-cart-listing .item','border-left-width','1','2885','','.w-cart-listing'),(472157,'furniture-mobile','.w-cart .cart-content','border-left-width','1','','','.w-cart'),(472158,'furniture-mobile','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(472159,'furniture-mobile','.w-filters .ui-slider-range','border-left-width','0','','','.w-filters'),(472160,'furniture-mobile','.w-compare-box-item .checkbox + span','border-left-width','1','','','.w-compare-box-item'),(472161,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(472163,'furniture-mobile','.b-upload-files .upload-files','border-left-width','1','','','.b-upload-files'),(472164,'furniture-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-width','1','','','.b-compare'),(472165,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-left-width','2','','','.p-blog-index'),(472166,'furniture-mobile','.b-upload-file .snapshot','border-left-width','1','','','.b-upload-file'),(472167,'furniture-mobile','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-left-width','2','','','.b-product-images'),(472168,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-left-width','1','','','.b-menu-style-2'),(472169,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-left-width','3','','','.b-menu-style-2'),(472170,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-left-width','1','','','.b-menu-style-2'),(472171,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-left-width','3','','','.b-menu-style-2'),(472172,'furniture-mobile','.b-trade-approval .steps-bar li ~ li a','border-left-width','1','','','.b-trade-approval'),(472173,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-width','2','','','.b-trade-approval'),(472174,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-left-width','1','','','.batchPr'),(472175,'furniture-mobile','.batchPr .checkbox input + span','border-left-width','1','','','.batchPr'),(472176,'furniture-mobile','.batchPr .checkbox input + span','border-left-width','1','','','.batchPr'),(472177,'furniture-mobile','.batchPr .checkbox input:checked + span','border-left-width','1','','','.batchPr'),(472178,'furniture-mobile','.batchPr .w-batch-selected-products','border-left-width','1','','','.batchPr'),(472179,'furniture-mobile','.w-account-personal-catalog .list-switcher a','border-left-width','1','2','','.w-account-personal-catalog'),(472180,'furniture-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-left-width','1','','','.w-catalog-compare'),(472181,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','border-left-width','1','2','','.w-catalog-compare'),(472182,'furniture-mobile','.b-slick .slick-vertical .slick-slide','border-left-width','1','','','.b-slick'),(472183,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li + li','border-left-width','1','2945','','.b-menu-style-3'),(472184,'furniture-mobile','.b-products-listing .products-listing .compare input + span','border-left-width','1','','','.b-products-listing'),(472185,'furniture-mobile','.w-filters .filter-widget','border-left-width','1','','','.w-filters'),(472186,'furniture-mobile','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-left-width','0','','','.w-filters'),(472187,'furniture-mobile','.w-quote .cart-content','border-left-width','1','','','.w-quote'),(472188,'furniture-mobile','.b-product-images .additional-images .active img','border-left-width','2','','','.b-product-images'),(472189,'furniture-mobile','.b-product-images .additional-images img','border-left-width','2','','','.b-product-images'),(472190,'furniture-mobile','.b-quantity .qty-box .bigger','border-left-width','2','','','.b-quantity'),(472191,'furniture-mobile','.b-quantity .qty-box .smaller','border-left-width','2','','','.b-quantity'),(472192,'furniture-mobile','.w-sample .cart-content','border-left-width','1','','','.w-sample'),(472193,'furniture-mobile','.w-cart-listing .points-earn','border-left-width','12','4','','.w-cart-listing'),(472194,'furniture-mobile','.w-cart-discount-coupon .btn','border-left-width','2','','','.w-cart-discount-coupon'),(472195,'furniture-mobile','.w-product-video .item img, .w-product-video .item video','border-left-width','2','','','.w-product-video'),(472196,'furniture-mobile','.w-product-video .item.active img, .w-product-video .item.active video','border-left-width','2','','','.w-product-video'),(472197,'furniture-mobile','.w-cart-order-reference .btn','border-left-width','2','','','.w-cart-order-reference'),(472198,'furniture-mobile','.w-cart-gift-certificate .btn','border-left-width','2','','','.w-cart-gift-certificate'),(472199,'furniture-mobile','.w-cart-shipping-estimator .btn','border-left-width','2','','','.w-cart-shipping-estimator'),(472200,'furniture-mobile','.w-account-address-book .item','border-left-width','1','','','.w-account-address-book'),(472201,'furniture-mobile','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-left-width','1','','','.b-pagination'),(472202,'furniture-mobile','.b-pagination .pagination .next-pages','border-left-width','1','','','.b-pagination'),(472203,'furniture-mobile','.b-pagination .pagination .page-number','border-left-width','1','','','.b-pagination'),(472204,'furniture-mobile','.b-pagination .pagination .prev-pages','border-left-width','1','','','.b-pagination'),(472205,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-left-width','1','','','.b-pagination'),(472206,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-left-width','1','','','.b-pagination'),(472207,'furniture-mobile','.b-pagination .pagination span','border-left-width','1','2','','.b-pagination'),(472208,'furniture-mobile','.w-tabs .tab-li','border-left-width','1','2','','.w-tabs'),(472209,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','border-left-width','2','','','.w-product-multi-inventory'),(472210,'furniture-mobile','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-left-width','2','','','.w-product-multi-inventory'),(472211,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-left-width','1','','','.w-account-personal-catalog'),(472212,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','border-left-width','1','','','.w-account-personal-catalog'),(472213,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','border-left-width','2','','','.b-products-listing'),(472214,'furniture-mobile','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-left-width','2','','','.b-products-listing'),(472215,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','border-left-width','2','','','.w-product-attributes'),(472216,'furniture-mobile','.w-product-attributes .radio-attributes input:checked + .option-item','border-left-width','2','','','.w-product-attributes'),(472217,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-left-width','2','','','.w-questionnaire-widgets-questionnaire'),(472218,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-left-width','2','','','.w-questionnaire-widgets-questionnaire'),(472219,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-left-width','2','','','.w-questionnaire-widgets-questionnaire'),(472220,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-left-width','2','1','','.w-questionnaire-widgets-questionnaire'),(472221,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-left-width','2','1','','.w-questionnaire-widgets-questionnaire'),(472222,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','border-left-width','2','','','.w-product-groups'),(472223,'furniture-mobile','.w-product-groups .radioBox label .containerBlock.selected','border-left-width','2','','','.w-product-groups'),(472224,'furniture-mobile','.w-product-groups .radioBox label input:checked + .containerBlock','border-left-width','2','','','.w-product-groups'),(472225,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-left-width','2','','','.w-delivery-location-location-list'),(472226,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-left-width','2','1','','.w-delivery-location-location-list'),(472227,'furniture-mobile','.w-sale-category .sale-holder','border-left-width','2','','','.w-sale-category'),(472228,'furniture-mobile','.w-wedding-registry-widgets-photos .upload-file-template','border-left-width','1','','','.w-wedding-registry-widgets-photos'),(472229,'furniture-mobile','.w-product-wedding-registry-button .btn','border-left-width','2','3','','.w-product-wedding-registry-button'),(472230,'furniture-mobile','.w-product-wedding-registry-button .btn','border-left-width','2','4','','.w-product-wedding-registry-button'),(472231,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-left-width','1','','','.w-product-properties-icons'),(472232,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','border-left-width','1','','','.w-wedding-registry-widgets-search-paging'),(472233,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','border-left-width','1','','','.w-wedding-registry-widgets-search-paging'),(472234,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','border-left-width','1','','','.w-wedding-registry-widgets-search-paging'),(472235,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','border-left-width','1','','','.w-wedding-registry-widgets-search-paging'),(472236,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','border-left-width','1','','','.w-product-designer-designer'),(472237,'furniture-mobile','.b-products-listing .productGroup label a','border-left-width','1','','','.b-products-listing'),(472238,'furniture-mobile','.w-support-system-listing .support-head','border-left-width','1','','','.w-support-system-listing'),(472239,'furniture-mobile','.w-support-system-listing .product_icon','border-left-width','1','','','.w-support-system-listing'),(472240,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border-left-width','1','','','.w-predefined-promotion'),(472241,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-left-width','1','','','.w-predefined-promotion'),(472242,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-left-width','1','','','.w-predefined-promotion'),(472243,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border-left-width','1','','','.w-predefined-promotion'),(472244,'furniture-mobile','.w-supplier-purchase-supplier-products .item','border-left-width','1','','','.w-supplier-purchase-supplier-products'),(472245,'furniture-mobile','.mainBanner .bottomBox .btn','border-left-width','0.21','','','.mainBanner'),(472246,'furniture-mobile','.mainBanner .topBox > .right','border-left-width','4','4','','.mainBanner'),(472247,'furniture-mobile','.mainBanner .bottomBox .btn','border-left-width','2','2890','','.mainBanner'),(472248,'furniture-mobile','.mainBanner .bottomBox .btn','border-left-width','3','2876','','.mainBanner'),(472249,'furniture-mobile','.mainBanner .bottomBox .btn','border-left-width','2','2906','','.mainBanner'),(472250,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','border-left-width','2','','','.lowestPricedBox'),(472251,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-left-width','2','','','.shopByCollectionBox'),(472252,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-left-width','2','2890','','.shopByCollectionBox'),(472253,'furniture-mobile','.account-order-history .orders-table .item','border-left-width','1','2885','','.account-order-history'),(472254,'furniture-mobile','.account-index .orders-table .item','border-left-width','1','2885','','.account-index'),(472255,'furniture-mobile','.account-samples .orders-table .item','border-left-width','1','2885','','.account-samples'),(472256,'furniture-mobile','.catalog-product-wrap .next-product','border-left-width','1','','','.catalog-product-wrap'),(472257,'furniture-mobile','.catalog-product-wrap .pn-image','border-left-width','2','3','','.catalog-product-wrap'),(472258,'furniture-mobile','.shopping-cart-index .btn-3','border-left-width','2','','','.shopping-cart-index'),(472259,'furniture-mobile','.checkout-index-wrap .input-wrapper','border-left-width','2','','','.checkout-index-wrap'),(472261,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','$border-color-4','','','.b-dropdown'),(472262,'furniture-mobile','.w-cart-products .checkout-attention-message','border-right-color','$border-attention','','','.w-cart-products'),(472263,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-right-color','$border-color-4','3','','.b-form'),(472264,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border-right-color','$border-attention','','','.w-promotions'),(472265,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-color','$border-color-4','','','.p-blog-index'),(472266,'furniture-mobile','.w-cart-compare .attributes-block td','border-right-color','$border-color-4','','','.w-cart-compare'),(472267,'furniture-mobile','.w-account .account-dropdown','border-right-color','$border-color-4','','','.w-account'),(472268,'furniture-mobile','.p-reviews-info .review-info-text','border-right-color','$border-reverse','4','','.p-reviews-info'),(472269,'furniture-mobile','.testimonials .review','border-right-color','transparent','3','',''),(472270,'furniture-mobile','.w-compare-box-item .checkbox + span','border-right-color','$border-color-4','','','.w-compare-box-item'),(472271,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-right-color','$border-message','','','.w-compare-box-item'),(472272,'furniture-mobile','.w-promotions .promo-salemaker .discount','border-right-color','$border-warning','','','.w-promotions'),(472273,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-color','$border-attention','','','.w-promotions'),(472274,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-right-color','$border-attention','','','.w-promotions'),(472275,'furniture-mobile','.w-cart-compare .cart-cell > div','border-right-color','$border-color-4','','','.w-cart-compare'),(472276,'furniture-mobile','.w-cart-compare .price-block td','border-right-color','$border-color-4','','','.w-cart-compare'),(472277,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-right-color','$border-color-4','','','.b-bottom'),(472278,'furniture-mobile','.b-messages .content_management_attach button','border-right-color','$border-color-5','','','.b-messages'),(472279,'furniture-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-color','$border-color-4','','','.b-messages'),(472280,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-right-color','$border-color-4','','',''),(472281,'furniture-mobile','.w-cart-products .checkout-attention-message','border-right-color','$border-attention','','','.w-cart-products'),(472282,'furniture-mobile','.w-socials > li','border-right-color','$border-color-4','','','.w-socials'),(472283,'furniture-mobile','.p-payer-order-confirmation .input-wrapper','border-right-color','$border-color-4','','','.p-payer-order-confirmation'),(472284,'furniture-mobile','.p-payer-order-pay .input-wrapper','border-right-color','$border-color-4','','','.p-payer-order-pay'),(472285,'furniture-mobile','.b-upload-file .upload-file-template','border-right-color','$border-color-4','','','.b-upload-file'),(472286,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-right-color','$border-color-4','','','.b-switch'),(472290,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-color','$border-color-4','','','.p-blog-index'),(472291,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-color','$border-color-3','','','.w-upload-customer-id-upload-customer-id-form'),(472292,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','$border-color-4','','','.b-dropdown'),(472293,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-right-color','$border-message','','','.w-compare-box-item'),(472294,'furniture-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-color','$border-color-6','','','.b-compare'),(472297,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','$border-color-4','','','.b-dropdown'),(472298,'furniture-mobile','.w-cart-products .checkout-attention-message','border-right-color','$border-attention','','','.w-cart-products'),(472299,'furniture-mobile','.w-compare-box-item .checkbox + span','border-right-color','$border-color-4','','','.w-compare-box-item'),(472301,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-color','$border-color-4','','','.b-select-suggest'),(472302,'furniture-mobile','.w-checkout-shipping-choice label:last-child span','border-right-color','$border-color-5','','','.w-checkout-shipping-choice'),(472303,'furniture-mobile','.w-socials > li','border-right-color','$border-color-4','','','.w-socials'),(472304,'furniture-mobile','.b-info-popup .info-popup div','border-right-color','$border-color-4','','','.b-info-popup'),(472305,'furniture-mobile','.w-cart-compare .product-block td','border-right-color','$border-color-4','','','.w-cart-compare'),(472306,'furniture-mobile','.w-sale .sale-holder','border-right-color','$border-color-4','','','.w-sale'),(472307,'furniture-mobile','.w-promo-code .holder','border-right-color','$border-color-4','','','.w-promo-code'),(472309,'furniture-mobile','.w-reviews .review','border-right-color','$border-transparent','3','','.w-reviews'),(472310,'furniture-mobile','.w-tabs > .block','border-right-color','$border-color-3','','','.w-tabs'),(472311,'furniture-mobile','.w-socials > li','border-right-color','$border-color-4','','','.w-socials'),(472312,'furniture-mobile','.w-sale .sale-holder','border-right-color','$border-color-4','','','.w-sale'),(472313,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','$border-color-4','','','.b-dropdown'),(472314,'furniture-mobile','.p-reviews-info .review-info-text','border-right-color','$border-reverse','4','','.p-reviews-info'),(472315,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-color','$border-color-4','','','.p-blog-index'),(472316,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-right-color','$border-color-3','','','.w-wedding-registry-widgets-photos'),(472317,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-right-color','$border-reverse','','','.b-switch'),(472318,'furniture-mobile','.w-socials > li','border-right-color','$border-color-4','','','.w-socials'),(472320,'furniture-mobile','.w-promo-code .holder','border-right-color','$border-color-4','','','.w-promo-code'),(472321,'furniture-mobile','.w-socials > li','border-right-color','$border-color-4','','','.w-socials'),(472322,'furniture-mobile','.w-reviews-content .review','border-right-color','$border-transparent','3','','.w-reviews-content'),(472323,'furniture-mobile','.w-sale .sale-holder','border-right-color','$border-color-4','','','.w-sale'),(472324,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','border-right-color','$border-color-4','','','.b-select-suggest'),(472326,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-right-color','$border-color-4','4','','.b-switch'),(472327,'furniture-mobile','.w-languages .select','border-right-color','$border-color-4','','','.w-languages'),(472328,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-right-color','$border-message','','','.w-compare-box-item'),(472329,'furniture-mobile','.w-cart-products .checkout-attention-message','border-right-color','$border-attention','','','.w-cart-products'),(472330,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-right-color','$border-message','','','.w-compare-box-item'),(472331,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-color','$border-color-4','','','.p-blog-index'),(472332,'furniture-mobile','.w-socials > li','border-right-color','$border-color-4','','','.w-socials'),(472333,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-right-color','$border-reverse','','','.b-bottom'),(472334,'furniture-mobile','.w-sale .sale-holder','border-right-color','$border-color-4','','','.w-sale'),(472338,'furniture-mobile','textarea','border-right-color','$border-color-4','','',''),(472339,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-color','$border-color-4','','','.p-blog-index'),(472340,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','$border-color-4','','','.b-dropdown'),(472341,'furniture-mobile','.w-promo-code .holder','border-right-color','$border-color-4','','','.w-promo-code'),(472342,'furniture-mobile','.w-sale .sale-holder','border-right-color','$border-color-4','','','.w-sale'),(472343,'furniture-mobile','.b-bottom .popup-box','border-right-color','$border-color-4','','','.b-bottom'),(472345,'furniture-mobile','.w-product-customers-activity .customers-activity','border-right-color','$border-color-4','','','.w-product-customers-activity'),(472346,'furniture-mobile','.p-reviews-info .review-info-text','border-right-color','$border-reverse','4','','.p-reviews-info'),(472347,'furniture-mobile','.w-compare-box-item .checkbox + span','border-right-color','$border-color-4','','','.w-compare-box-item'),(472348,'furniture-mobile','.w-compare-box-item .checkbox + span','border-right-color','$border-color-4','','','.w-compare-box-item'),(472349,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-right-color','$border-message','','','.w-compare-box-item'),(472351,'furniture-mobile','.p-reviews-info .review-info-text','border-right-color','$border-reverse','4','','.p-reviews-info'),(472352,'furniture-mobile','.w-sale .sale-holder','border-right-color','$border-color-4','','','.w-sale'),(472353,'furniture-mobile','.w-product-reviews .reviews-list .review','border-right-color','transparent','3','','.w-product-reviews'),(472354,'furniture-mobile','.w-cart-products .checkout-attention-message','border-right-color','$border-attention','','','.w-cart-products'),(472355,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-color','$border-color-4','','','.b-select-suggest'),(472356,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-color','$border-color-4','','','.b-select-suggest'),(472357,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-color','$border-color-4','','','.b-select-suggest'),(472358,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-right-color','$border-color-4','','','.b-select-suggest'),(472359,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-color','$border-color-4','','','.b-select-suggest'),(472360,'furniture-mobile','.b-select-suggest .select2-search input','border-right-color','$border-color-4','','','.b-select-suggest'),(472361,'furniture-mobile','.b-select-suggest .select2-drop-active','border-right-color','$border-color-4','','','.b-select-suggest'),(472362,'furniture-mobile','.b-select-suggest .select2-drop','border-right-color','$border-color-4','','','.b-select-suggest'),(472363,'furniture-mobile','.p-reviews-info .review-info-text','border-right-color','$border-reverse','4','','.p-reviews-info'),(472364,'furniture-mobile','.w-promo-code .holder','border-right-color','$border-color-4','','','.w-promo-code'),(472365,'furniture-mobile','.b-form input.required-error','border-right-color','$border-attention','','','.b-form'),(472366,'furniture-mobile','.checkbox input:checked + span','border-right-color','$border-message','','',''),(472367,'furniture-mobile','.checkbox input + span','border-right-color','$border-color-4','','',''),(472368,'furniture-mobile','.b-autocomplete .ui-autocomplete','border-right-color','$border-color-4','','','.b-autocomplete'),(472369,'furniture-mobile','.w-currencies .select','border-right-color','$border-color-4','','','.w-currencies'),(472370,'furniture-mobile','.w-currencies .currencies-title','border-right-color','$border-color-5','','','.w-currencies'),(472371,'furniture-mobile','.w-compare-box-item .checkbox + span','border-right-color','$border-color-4','','','.w-compare-box-item'),(472372,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-right-color','$border-color-4','3','','.b-switch'),(472373,'furniture-mobile','.b-upload-file .snapshot','border-right-color','$border-color-6','','','.b-upload-file'),(472374,'furniture-mobile','.p-reviews-info .review-info-text','border-right-color','$border-reverse','4','','.p-reviews-info'),(472375,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-color','$border-color-4','','','.b-dropdown'),(472376,'furniture-mobile','.b-upload-files .upload-files','border-right-color','$border-color-4','','','.b-upload-files'),(472377,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-right-color','$border-message','','','.w-compare-box-item'),(472378,'furniture-mobile','.b-form .required-error','border-right-color','$border-attention','','','.b-form'),(472379,'furniture-mobile','.w-promo-code .holder','border-right-color','$border-color-4','','','.w-promo-code'),(472380,'furniture-mobile','.w-cart-products .checkout-attention-message','border-right-color','$border-attention','','','.w-cart-products'),(472382,'furniture-mobile','.w-cart-listing .item .gift-wrap label','border-right-color','$border-color-4','','','.w-cart-listing'),(472383,'furniture-mobile','.w-cart-listing .item','border-right-color','$border-color-4','2885','','.w-cart-listing'),(472385,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-right-color','$border-color-3','','','.w-wedding-registry-widgets-photos'),(472386,'furniture-mobile','.w-promo-code .holder','border-right-color','$border-color-4','','','.w-promo-code'),(472387,'furniture-mobile','.w-cart .cart-content','border-right-color','$border-color-4','','','.w-cart'),(472388,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-color','$border-color-4','','','.p-blog-index'),(472389,'furniture-mobile','.w-compare-box-item .checkbox + span','border-right-color','$border-color-4','','','.w-compare-box-item'),(472391,'furniture-mobile','.b-data-table table.dataTable.no-footer','border-right-color','$border-color-4','','','.b-data-table'),(472392,'furniture-mobile','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-right-color','$border-reverse','','','.b-product-images'),(472393,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-right-color','$border-color-2','','','.b-menu-style-2'),(472394,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-right-color','$border-color-2','','','.b-menu-style-2'),(472395,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-right-color','$border-color-2','','','.b-menu-style-2'),(472396,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-right-color','$border-color-2','','','.b-menu-style-2'),(472397,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-color','$border-color-4','','','.b-trade-approval'),(472398,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-right-color','$border-color-4','','','.batchPr'),(472399,'furniture-mobile','.batchPr .checkbox input + span','border-right-color','$border-color-4','','','.batchPr'),(472400,'furniture-mobile','.batchPr .checkbox input + span','border-right-color','$border-color-4','','','.batchPr'),(472401,'furniture-mobile','.batchPr .w-batch-selected-products','border-right-color','$border-color-4','','','.batchPr'),(472402,'furniture-mobile','.batchPr .checkbox input:checked + span','border-right-color','$border-color-2','','','.batchPr'),(472403,'furniture-mobile','.w-account-personal-catalog .list-switcher a','border-right-color','$border-color-4','2','','.w-account-personal-catalog'),(472404,'furniture-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-right-color','$border-reverse','','','.w-catalog-compare'),(472405,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','border-right-color','$border-color-4','2','','.w-catalog-compare'),(472406,'furniture-mobile','.w-catalog-compare td:first-child','border-right-color','$border-color-4','','','.w-catalog-compare'),(472407,'furniture-mobile','.w-search .search-input','border-right-color','$border-color-2','','','.w-search'),(472408,'furniture-mobile','.w-account .my-acc-link','border-right-color','$border-color-2','4','','.w-account'),(472409,'furniture-mobile','.b-products-listing .products-listing .compare input + span','border-right-color','$border-color-5','','','.b-products-listing'),(472410,'furniture-mobile','.w-filters .filter-widget','border-right-color','$border-color-4','','','.w-filters'),(472411,'furniture-mobile','.w-quote .cart-content','border-right-color','$border-color-4','','','.w-quote'),(472412,'furniture-mobile','.b-product-images .additional-images .active img','border-right-color','$border-color-5','','','.b-product-images'),(472413,'furniture-mobile','.b-product-images .additional-images img','border-right-color','$border-reverse','','','.b-product-images'),(472414,'furniture-mobile','.b-quantity .qty-box .bigger','border-right-color','$border-color-1','','','.b-quantity'),(472415,'furniture-mobile','.b-quantity .qty-box .smaller','border-right-color','$border-color-1','','','.b-quantity'),(472416,'furniture-mobile','.w-sample .cart-box-link','border-right-color','$border-color-2','4','','.w-sample'),(472417,'furniture-mobile','.w-sample .cart-content','border-right-color','$border-color-4','','','.w-sample'),(472418,'furniture-mobile','.w-cart-listing .points-earn','border-right-color','$border-transparent','4','','.w-cart-listing'),(472419,'furniture-mobile','.w-cart-discount-coupon .btn','border-right-color','$border-color-5','','','.w-cart-discount-coupon'),(472420,'furniture-mobile','.w-product-video .item img, .w-product-video .item video','border-right-color','$border-reverse','','','.w-product-video'),(472421,'furniture-mobile','.w-product-video .item.active img, .w-product-video .item.active video','border-right-color','$border-color-7','','','.w-product-video'),(472422,'furniture-mobile','.w-cart-order-reference .btn','border-right-color','$border-color-5','','','.w-cart-order-reference'),(472423,'furniture-mobile','.w-cart-gift-certificate .btn','border-right-color','$border-color-5','','','.w-cart-gift-certificate'),(472424,'furniture-mobile','.w-cart-shipping-estimator .btn','border-right-color','$border-color-5','','','.w-cart-shipping-estimator'),(472425,'furniture-mobile','.w-account-address-book .item','border-right-color','$border-color-3','','','.w-account-address-book'),(472426,'furniture-mobile','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-right-color','$border-color-8','','','.b-pagination'),(472427,'furniture-mobile','.b-pagination .pagination .next-pages','border-right-color','$border-color-4','','','.b-pagination'),(472428,'furniture-mobile','.b-pagination .pagination .page-number','border-right-color','$border-color-4','','','.b-pagination'),(472429,'furniture-mobile','.b-pagination .pagination .prev-pages','border-right-color','$border-color-4','','','.b-pagination'),(472430,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-right-color','$border-color-4','','','.b-pagination'),(472431,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-right-color','$border-color-4','','','.b-pagination'),(472432,'furniture-mobile','.b-pagination .pagination span','border-right-color','$border-color-4','2','','.b-pagination'),(472433,'furniture-mobile','.w-tabs .tab-li','border-right-color','$border-color-4','2','','.w-tabs'),(472434,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','border-right-color','$border-color-4','','','.w-product-multi-inventory'),(472435,'furniture-mobile','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-right-color','$border-color-5','','','.w-product-multi-inventory'),(472436,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-right-color','$border-color-3','','','.w-account-personal-catalog'),(472437,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','border-right-color','$border-color-3','','','.w-account-personal-catalog'),(472438,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','border-right-color','$border-color-4','','','.b-products-listing'),(472439,'furniture-mobile','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-right-color','$border-color-5','','','.b-products-listing'),(472440,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','border-right-color','$border-color-4','','','.w-product-attributes'),(472441,'furniture-mobile','.w-product-attributes .radio-attributes input:checked + .option-item','border-right-color','$border-color-5','','','.w-product-attributes'),(472442,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-right-color','$border-color-3','','','.w-questionnaire-widgets-questionnaire'),(472443,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-right-color','$border-attention','','','.w-questionnaire-widgets-questionnaire'),(472444,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-right-color','$border-message','','','.w-questionnaire-widgets-questionnaire'),(472445,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-right-color','$border-attention','1','','.w-questionnaire-widgets-questionnaire'),(472446,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-right-color','$border-message','1','','.w-questionnaire-widgets-questionnaire'),(472447,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','border-right-color','$border-color-3','','','.w-product-groups'),(472448,'furniture-mobile','.w-product-groups .radioBox label .containerBlock.selected','border-right-color','$border-color-5','','','.w-product-groups'),(472449,'furniture-mobile','.w-product-groups .radioBox label input:checked + .containerBlock','border-right-color','$border-color-5','','','.w-product-groups'),(472450,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-right-color','$border-color-4','','','.w-delivery-location-location-list'),(472451,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-right-color','$border-color-5','1','','.w-delivery-location-location-list'),(472452,'furniture-mobile','.w-sale-category .sale-holder','border-right-color','$border-color-4','','','.w-sale-category'),(472453,'furniture-mobile','.w-wedding-registry-widgets-photos .upload-file-template','border-right-color','$border-color-3','','','.w-wedding-registry-widgets-photos'),(472454,'furniture-mobile','.w-product-wedding-registry-button .btn','border-right-color','$border-color-5','3','','.w-product-wedding-registry-button'),(472455,'furniture-mobile','.w-product-wedding-registry-button .btn','border-right-color','$border-color-5','4','','.w-product-wedding-registry-button'),(472456,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','border-right-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(472457,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','border-right-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(472458,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','border-right-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(472459,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','border-right-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(472460,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','border-right-color','$border-color-3','','','.w-product-designer-designer'),(472461,'furniture-mobile','.b-products-listing .productGroup label a','border-right-color','$border-color-5','','','.b-products-listing'),(472462,'furniture-mobile','.w-support-system-listing .support-head','border-right-color','$border-color-1','','','.w-support-system-listing'),(472463,'furniture-mobile','.w-support-system-listing .product_icon','border-right-color','$border-color-1','','','.w-support-system-listing'),(472464,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border-right-color','$border-attention','','','.w-predefined-promotion'),(472465,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-right-color','$border-attention','','','.w-predefined-promotion'),(472466,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-right-color','$border-attention','','','.w-predefined-promotion'),(472467,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border-right-color','$border-warning','','','.w-predefined-promotion'),(472468,'furniture-mobile','.w-supplier-purchase-supplier-products .item','border-right-color','$border-color-3','','','.w-supplier-purchase-supplier-products'),(472469,'furniture-mobile','.mainBanner .bottomBox .btn','border-right-color','$border-color-2','','','.mainBanner'),(472470,'furniture-mobile','.mainBanner .topBox > .right','border-right-color','transparent','4','','.mainBanner'),(472471,'furniture-mobile','.mainBanner .bottomBox .btn','border-right-color','$border-color-2','2890','','.mainBanner'),(472472,'furniture-mobile','.mainBanner .bottomBox .btn','border-right-color','$border-color-2','2876','','.mainBanner'),(472473,'furniture-mobile','.mainBanner .bottomBox .btn','border-right-color','$border-color-2','2906','','.mainBanner'),(472474,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','border-right-color','$border-color-5','','','.lowestPricedBox'),(472475,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-right-color','$border-color-2','','','.shopByCollectionBox'),(472476,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-right-color','$border-color-2','2890','','.shopByCollectionBox'),(472477,'furniture-mobile','.account-order-history .orders-table .item','border-right-color','$border-color-4','2885','','.account-order-history'),(472478,'furniture-mobile','.account-index .orders-table .item','border-right-color','$border-color-4','2885','','.account-index'),(472479,'furniture-mobile','.account-samples .orders-table .item','border-right-color','$border-color-4','2885','','.account-samples'),(472480,'furniture-mobile','.catalog-product-wrap .pn-image','border-right-color','$border-color-4','3','','.catalog-product-wrap'),(472481,'furniture-mobile','.shopping-cart-index .btn-3','border-right-color','$border-color-5','','','.shopping-cart-index'),(472482,'furniture-mobile','.checkout-index-wrap .input-wrapper','border-right-color','$border-color-4','','','.checkout-index-wrap'),(472483,'furniture-mobile','.b-data-table table.dataTable.no-footer','border-right-color_important','important','','','.b-data-table'),(472484,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(472485,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(472486,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-width','2','','','.p-blog-index'),(472487,'furniture-mobile','.p-reviews-info .review-info-text','border-right-width','5','4','','.p-reviews-info'),(472488,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border-right-width','1','','','.w-promotions'),(472489,'furniture-mobile','.w-sale .sale-holder','border-right-width','2','','','.w-sale'),(472490,'furniture-mobile','.w-cart-compare .attributes-block td','border-right-width','1','','','.w-cart-compare'),(472491,'furniture-mobile','.w-account .account-dropdown','border-right-width','1','','','.w-account'),(472492,'furniture-mobile','.p-reviews-info .review-info-text','border-right-width','5','4','','.p-reviews-info'),(472493,'furniture-mobile','.testimonials .review','border-right-width','10','3','',''),(472494,'furniture-mobile','.w-compare-box-item .checkbox + span','border-right-width','1','','','.w-compare-box-item'),(472495,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-right-width','1','','','.w-compare-box-item'),(472496,'furniture-mobile','.w-promotions .promo-salemaker .discount','border-right-width','1','','','.w-promotions'),(472497,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-width','1','','','.w-promotions'),(472498,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-right-width','1','','','.w-promotions'),(472499,'furniture-mobile','.w-cart-compare .cart-cell > div','border-right-width','1','','','.w-cart-compare'),(472500,'furniture-mobile','.p-reviews-info .review-info-text','border-right-width','5','4','','.p-reviews-info'),(472501,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-right-width','1','','','.b-bottom'),(472502,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-right-width','1','','','.w-wedding-registry-widgets-photos'),(472503,'furniture-mobile','.b-messages .content_management_attach button','border-right-width','1','','','.b-messages'),(472504,'furniture-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-width','2','','','.b-messages'),(472505,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-right-width','2','','',''),(472506,'furniture-mobile','.w-socials > li','border-right-width','1','','','.w-socials'),(472507,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-width','2','','','.p-blog-index'),(472508,'furniture-mobile','.p-payer-order-confirmation .input-wrapper','border-right-width','2','','','.p-payer-order-confirmation'),(472509,'furniture-mobile','.p-payer-order-pay .input-wrapper','border-right-width','2','','','.p-payer-order-pay'),(472510,'furniture-mobile','.w-compare-box-item .checkbox + span','border-right-width','1','','','.w-compare-box-item'),(472511,'furniture-mobile','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(472513,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-width','2','','','.p-blog-index'),(472514,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(472516,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-right-width','2','3','','.b-form'),(472518,'furniture-mobile','.w-socials > li','border-right-width','1','','','.w-socials'),(472520,'furniture-mobile','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(472521,'furniture-mobile','.w-socials > li','border-right-width','1','','','.w-socials'),(472522,'furniture-mobile','.w-search .button-search','border-right-width','0','','','.w-search'),(472523,'furniture-mobile','.w-search .search-input','border-right-width','1','','','.w-search'),(472524,'furniture-mobile','.b-info-popup .info-popup div','border-right-width','1','','','.b-info-popup'),(472525,'furniture-mobile','.w-checkout-shipping-choice label:last-child span','border-right-width','2','','','.w-checkout-shipping-choice'),(472526,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-width','2','','','.p-blog-index'),(472527,'furniture-mobile','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(472529,'furniture-mobile','.w-tabs > .block','border-right-width','1','','','.w-tabs'),(472530,'furniture-mobile','.w-socials > li','border-right-width','1','','','.w-socials'),(472531,'furniture-mobile','.w-sale .sale-holder','border-right-width','2','','','.w-sale'),(472532,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(472533,'furniture-mobile','.p-reviews-info .review-info-text','border-right-width','5','4','','.p-reviews-info'),(472534,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-right-width','4','','','.b-switch'),(472536,'furniture-mobile','.w-filters .ui-slider-handle','border-right-width','0','','','.w-filters'),(472537,'furniture-mobile','.w-filters .ui-slider','border-right-width','0','','','.w-filters'),(472538,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(472539,'furniture-mobile','.w-socials > li','border-right-width','1','','','.w-socials'),(472540,'furniture-mobile','.w-reviews .review','border-right-width','12','3','','.w-reviews'),(472541,'furniture-mobile','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(472542,'furniture-mobile','.w-product-reviews .reviews-list .review','border-right-width','10','3','','.w-product-reviews'),(472543,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-right-width','3','','','.b-switch'),(472544,'furniture-mobile','.w-reviews-content .review','border-right-width','12','3','','.w-reviews-content'),(472545,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-right-width','1','','','.w-compare-box-item'),(472546,'furniture-mobile','.w-compare-box-item .checkbox + span','border-right-width','1','','','.w-compare-box-item'),(472547,'furniture-mobile','.w-sale .sale-holder','border-right-width','2','','','.w-sale'),(472548,'furniture-mobile','.w-socials > li','border-right-width','1','','','.w-socials'),(472549,'furniture-mobile','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(472550,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','border-right-width','2','','','.b-select-suggest'),(472552,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-right-width','2','4','','.b-switch'),(472553,'furniture-mobile','.w-languages .select','border-right-width','1','','','.w-languages'),(472554,'furniture-mobile','.w-cart-compare .product-block td','border-right-width','1','','','.w-cart-compare'),(472555,'furniture-mobile','.b-form .required-error','border-right-width','1','','','.b-form'),(472556,'furniture-mobile','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(472557,'furniture-mobile','.p-reviews-info .review-info-text','border-right-width','5','4','','.p-reviews-info'),(472558,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(472559,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-right-width','1','','','.w-compare-box-item'),(472560,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-width','2','','','.p-blog-index'),(472561,'furniture-mobile','textarea','border-right-width','2','','',''),(472563,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-right-width','1','','','.w-wedding-registry-widgets-photos'),(472564,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-right-width','1','','','.b-bottom'),(472565,'furniture-mobile','.b-bottom .popup-box','border-right-width','1','','','.b-bottom'),(472566,'furniture-mobile','.w-product-customers-activity .customers-activity','border-right-width','1','','','.w-product-customers-activity'),(472567,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(472568,'furniture-mobile','.w-compare-box-item .checkbox + span','border-right-width','1','','','.w-compare-box-item'),(472569,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-right-width','1','','','.w-compare-box-item'),(472572,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-right-width','1','','','.w-compare-box-item'),(472574,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-right-width','2','','','.p-blog-index'),(472575,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(472576,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-width','1','','','.b-select-suggest'),(472577,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(472578,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-width','1','','','.b-select-suggest'),(472579,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-right-width','1','','','.b-select-suggest'),(472580,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-width','1','','','.b-select-suggest'),(472581,'furniture-mobile','.b-select-suggest .select2-search input','border-right-width','1','','','.b-select-suggest'),(472582,'furniture-mobile','.b-select-suggest .select2-drop','border-right-width','1','','','.b-select-suggest'),(472583,'furniture-mobile','.b-select-suggest .select2-drop-active','border-right-width','1','','','.b-select-suggest'),(472584,'furniture-mobile','.w-cart-compare .price-block td','border-right-width','1','','','.w-cart-compare'),(472585,'furniture-mobile','.p-reviews-info .review-info-text','border-right-width','5','4','','.p-reviews-info'),(472586,'furniture-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-width','1','','','.b-compare'),(472587,'furniture-mobile','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(472588,'furniture-mobile','.w-compare-box-item .checkbox + span','border-right-width','1','','','.w-compare-box-item'),(472589,'furniture-mobile','.checkbox input:checked + span','border-right-width','1','','',''),(472590,'furniture-mobile','.checkbox input + span','border-right-width','1','','',''),(472591,'furniture-mobile','.b-autocomplete .ui-autocomplete','border-right-width','1','','','.b-autocomplete'),(472592,'furniture-mobile','.w-currencies .select','border-right-width','1','','','.w-currencies'),(472593,'furniture-mobile','.w-currencies .currencies-title','border-right-width','2','','','.w-currencies'),(472594,'furniture-mobile','.b-upload-file .upload-file-template','border-right-width','1','','','.b-upload-file'),(472595,'furniture-mobile','.w-sale .sale-holder','border-right-width','2','','','.w-sale'),(472596,'furniture-mobile','.w-compare-box-item .checkbox + span','border-right-width','1','','','.w-compare-box-item'),(472597,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-right-width','2','3','','.b-switch'),(472600,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(472601,'furniture-mobile','.w-sale .sale-holder','border-right-width','2','','','.w-sale'),(472603,'furniture-mobile','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(472604,'furniture-mobile','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(472606,'furniture-mobile','.w-cart-listing .item .gift-wrap label','border-right-width','1','','','.w-cart-listing'),(472607,'furniture-mobile','.w-cart-listing .item','border-right-width','1','2885','','.w-cart-listing'),(472608,'furniture-mobile','.w-cart .cart-content','border-right-width','1','','','.w-cart'),(472609,'furniture-mobile','.w-sale .sale-holder','border-right-width','2','','','.w-sale'),(472610,'furniture-mobile','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(472611,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-right-width','1','','','.w-compare-box-item'),(472612,'furniture-mobile','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(472613,'furniture-mobile','.w-filters .ui-slider-range','border-right-width','0','','','.w-filters'),(472616,'furniture-mobile','.b-upload-files .upload-files','border-right-width','1','','','.b-upload-files'),(472617,'furniture-mobile','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(472619,'furniture-mobile','.b-upload-file .snapshot','border-right-width','1','','','.b-upload-file'),(472620,'furniture-mobile','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-right-width','2','','','.b-product-images'),(472621,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-right-width','1','','','.b-menu-style-2'),(472622,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-right-width','3','','','.b-menu-style-2'),(472623,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-right-width','1','','','.b-menu-style-2'),(472624,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-right-width','3','','','.b-menu-style-2'),(472625,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-width','2','','','.b-trade-approval'),(472626,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-right-width','1','','','.batchPr'),(472627,'furniture-mobile','.batchPr .checkbox input + span','border-right-width','1','','','.batchPr'),(472628,'furniture-mobile','.batchPr .checkbox input + span','border-right-width','1','','','.batchPr'),(472629,'furniture-mobile','.batchPr .checkbox input:checked + span','border-right-width','1','','','.batchPr'),(472630,'furniture-mobile','.batchPr .w-batch-selected-products','border-right-width','1','','','.batchPr'),(472631,'furniture-mobile','.w-account-personal-catalog .list-switcher a','border-right-width','1','2','','.w-account-personal-catalog'),(472632,'furniture-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-right-width','1','','','.w-catalog-compare'),(472633,'furniture-mobile','.w-catalog-compare td:first-child','border-right-width','1','','','.w-catalog-compare'),(472634,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','border-right-width','1','2','','.w-catalog-compare'),(472635,'furniture-mobile','.w-cart .cart-box-link','border-right-width','1','4','','.w-cart'),(472636,'furniture-mobile','.w-account .my-acc-link','border-right-width','1','4','','.w-account'),(472637,'furniture-mobile','.b-slick .slick-vertical .slick-slide','border-right-width','1','','','.b-slick'),(472638,'furniture-mobile','.b-products-listing .products-listing .compare input + span','border-right-width','1','','','.b-products-listing'),(472639,'furniture-mobile','.w-filters .filter-widget','border-right-width','1','','','.w-filters'),(472640,'furniture-mobile','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-right-width','0','','','.w-filters'),(472641,'furniture-mobile','.w-quote .cart-content','border-right-width','1','','','.w-quote'),(472642,'furniture-mobile','.b-product-images .additional-images .active img','border-right-width','2','','','.b-product-images'),(472643,'furniture-mobile','.b-product-images .additional-images img','border-right-width','2','','','.b-product-images'),(472644,'furniture-mobile','.b-quantity .qty-box .bigger','border-right-width','2','','','.b-quantity'),(472645,'furniture-mobile','.b-quantity .qty-box .smaller','border-right-width','2','','','.b-quantity'),(472646,'furniture-mobile','.w-sample .cart-box-link','border-right-width','1','4','','.w-sample'),(472647,'furniture-mobile','.w-sample .cart-content','border-right-width','1','','','.w-sample'),(472648,'furniture-mobile','.w-cart-listing .points-earn','border-right-width','0','4','','.w-cart-listing'),(472649,'furniture-mobile','.w-cart-discount-coupon .btn','border-right-width','2','','','.w-cart-discount-coupon'),(472650,'furniture-mobile','.w-product-video .item img, .w-product-video .item video','border-right-width','2','','','.w-product-video'),(472651,'furniture-mobile','.w-product-video .item.active img, .w-product-video .item.active video','border-right-width','2','','','.w-product-video'),(472652,'furniture-mobile','.w-cart-order-reference .btn','border-right-width','2','','','.w-cart-order-reference'),(472653,'furniture-mobile','.w-cart-gift-certificate .btn','border-right-width','2','','','.w-cart-gift-certificate'),(472654,'furniture-mobile','.w-cart-shipping-estimator .btn','border-right-width','2','','','.w-cart-shipping-estimator'),(472655,'furniture-mobile','.w-account-address-book .item','border-right-width','1','','','.w-account-address-book'),(472656,'furniture-mobile','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-right-width','1','','','.b-pagination'),(472657,'furniture-mobile','.b-pagination .pagination .next-pages','border-right-width','1','','','.b-pagination'),(472658,'furniture-mobile','.b-pagination .pagination .page-number','border-right-width','1','','','.b-pagination'),(472659,'furniture-mobile','.b-pagination .pagination .prev-pages','border-right-width','1','','','.b-pagination'),(472660,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-right-width','1','','','.b-pagination'),(472661,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-right-width','1','','','.b-pagination'),(472662,'furniture-mobile','.b-pagination .pagination span','border-right-width','1','2','','.b-pagination'),(472663,'furniture-mobile','.w-tabs .tab-li','border-right-width','1','2','','.w-tabs'),(472664,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','border-right-width','2','','','.w-product-multi-inventory'),(472665,'furniture-mobile','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-right-width','2','','','.w-product-multi-inventory'),(472666,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-right-width','1','','','.w-account-personal-catalog'),(472667,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','border-right-width','1','','','.w-account-personal-catalog'),(472668,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','border-right-width','2','','','.b-products-listing'),(472669,'furniture-mobile','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-right-width','2','','','.b-products-listing'),(472670,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','border-right-width','2','','','.w-product-attributes'),(472671,'furniture-mobile','.w-product-attributes .radio-attributes input:checked + .option-item','border-right-width','2','','','.w-product-attributes'),(472672,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-right-width','2','','','.w-questionnaire-widgets-questionnaire'),(472673,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-right-width','2','','','.w-questionnaire-widgets-questionnaire'),(472674,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-right-width','2','','','.w-questionnaire-widgets-questionnaire'),(472675,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-right-width','2','1','','.w-questionnaire-widgets-questionnaire'),(472676,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-right-width','2','1','','.w-questionnaire-widgets-questionnaire'),(472677,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','border-right-width','2','','','.w-product-groups'),(472678,'furniture-mobile','.w-product-groups .radioBox label .containerBlock.selected','border-right-width','2','','','.w-product-groups'),(472679,'furniture-mobile','.w-product-groups .radioBox label input:checked + .containerBlock','border-right-width','2','','','.w-product-groups'),(472680,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-right-width','2','','','.w-delivery-location-location-list'),(472681,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-right-width','2','1','','.w-delivery-location-location-list'),(472682,'furniture-mobile','.w-sale-category .sale-holder','border-right-width','2','','','.w-sale-category'),(472683,'furniture-mobile','.w-wedding-registry-widgets-photos .upload-file-template','border-right-width','1','','','.w-wedding-registry-widgets-photos'),(472684,'furniture-mobile','.w-product-wedding-registry-button .btn','border-right-width','2','3','','.w-product-wedding-registry-button'),(472685,'furniture-mobile','.w-product-wedding-registry-button .btn','border-right-width','2','4','','.w-product-wedding-registry-button'),(472686,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','border-right-width','1','','','.w-wedding-registry-widgets-search-paging'),(472687,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','border-right-width','1','','','.w-wedding-registry-widgets-search-paging'),(472688,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','border-right-width','1','','','.w-wedding-registry-widgets-search-paging'),(472689,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','border-right-width','1','','','.w-wedding-registry-widgets-search-paging'),(472690,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','border-right-width','1','','','.w-product-designer-designer'),(472691,'furniture-mobile','.b-products-listing .productGroup label a','border-right-width','1','','','.b-products-listing'),(472692,'furniture-mobile','.w-support-system-listing .support-head','border-right-width','1','','','.w-support-system-listing'),(472693,'furniture-mobile','.w-support-system-listing .product_icon','border-right-width','1','','','.w-support-system-listing'),(472694,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border-right-width','1','','','.w-predefined-promotion'),(472695,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-right-width','1','','','.w-predefined-promotion'),(472696,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-right-width','1','','','.w-predefined-promotion'),(472697,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border-right-width','1','','','.w-predefined-promotion'),(472698,'furniture-mobile','.w-supplier-purchase-supplier-products .item','border-right-width','1','','','.w-supplier-purchase-supplier-products'),(472699,'furniture-mobile','.mainBanner .bottomBox .btn','border-right-width','0.21','','','.mainBanner'),(472700,'furniture-mobile','.mainBanner .topBox > .right','border-right-width','14','4','','.mainBanner'),(472701,'furniture-mobile','.mainBanner .bottomBox .btn','border-right-width','2','2890','','.mainBanner'),(472702,'furniture-mobile','.mainBanner .bottomBox .btn','border-right-width','3','2876','','.mainBanner'),(472703,'furniture-mobile','.mainBanner .bottomBox .btn','border-right-width','2','2906','','.mainBanner'),(472704,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','border-right-width','2','','','.lowestPricedBox'),(472705,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-right-width','2','','','.shopByCollectionBox'),(472706,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-right-width','2','2890','','.shopByCollectionBox'),(472707,'furniture-mobile','.account-order-history .orders-table .item','border-right-width','1','2885','','.account-order-history'),(472708,'furniture-mobile','.account-index .orders-table .item','border-right-width','1','2885','','.account-index'),(472709,'furniture-mobile','.account-samples .orders-table .item','border-right-width','1','2885','','.account-samples'),(472710,'furniture-mobile','.catalog-product-wrap .pn-image','border-right-width','2','3','','.catalog-product-wrap'),(472711,'furniture-mobile','.catalog-product-wrap .prev-product','border-right-width','1','','','.catalog-product-wrap'),(472712,'furniture-mobile','.shopping-cart-index .btn-3','border-right-width','2','','','.shopping-cart-index'),(472713,'furniture-mobile','.checkout-index-wrap .input-wrapper','border-right-width','2','','','.checkout-index-wrap'),(472714,'furniture-mobile','.b-select-suggest .select2-drop-active','border-top','none','','','.b-select-suggest'),(472715,'furniture-mobile','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','border-top','none','','','.order-summary'),(472716,'furniture-mobile','.order-summary .price-row.ot_gv + .price-row, .order-summary .price-row.ot_coupon + .price-row, .order-summary .price-row.ot_bonus_points + .price-row','border-top','none','','','.order-summary'),(472717,'furniture-mobile','.account-order-history .orders-table','border-top','none','','','.account-order-history'),(472718,'furniture-mobile','.account-index .orders-table','border-top','none','','','.account-index'),(472719,'furniture-mobile','.account-samples .orders-table','border-top','none','','','.account-samples'),(472720,'furniture-mobile','.catalog-product-wrap .pn-image','border-top','none','2885','','.catalog-product-wrap'),(472721,'furniture-mobile','.w-communication-new-topic td','border-top-color','$border-color-4','','','.w-communication-new-topic'),(472723,'furniture-mobile','.b-email .model','border-top-color','$border-color-4','','','.b-email'),(472724,'furniture-mobile','.order-summary .price-row + .price-row','border-top-color','$border-color-4','','','.order-summary'),(472726,'furniture-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-4','4','','.b-social-login'),(472727,'furniture-mobile','.b-email .totals-table','border-top-color','$border-color-4','','','.b-email'),(472728,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-color','$border-attention','','','.w-promotions'),(472729,'furniture-mobile','.w-socials > li','border-top-color','$border-color-4','','','.w-socials'),(472730,'furniture-mobile','.w-cart-compare .attributes-block td','border-top-color','$border-color-4','','','.w-cart-compare'),(472731,'furniture-mobile','.w-account .account-dropdown','border-top-color','$border-color-4','','','.w-account'),(472732,'furniture-mobile','.p-reviews-info .review-info-text','border-top-color','$border-reverse','4','','.p-reviews-info'),(472733,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','$border-color-4','','','.b-dropdown'),(472734,'furniture-mobile','.b-email .price','border-top-color','$border-color-4','','','.b-email'),(472735,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-top-color','$border-message','','','.w-compare-box-item'),(472736,'furniture-mobile','.w-compare-box-item .checkbox + span','border-top-color','$border-color-4','','','.w-compare-box-item'),(472737,'furniture-mobile','.w-promotions .promo-salemaker .discount','border-top-color','$border-warning','','','.w-promotions'),(472738,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-color','$border-attention','','','.w-promotions'),(472739,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-color','$border-attention','','','.w-promotions'),(472740,'furniture-mobile','.w-cart-compare .cart-cell > div','border-top-color','$border-color-4','','','.w-cart-compare'),(472741,'furniture-mobile','.w-cart-products .checkout-attention-message','border-top-color','$border-attention','','','.w-cart-products'),(472743,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-top-color','$border-message','','','.w-compare-box-item'),(472744,'furniture-mobile','.b-upload-file .upload-file-template','border-top-color','$border-color-4','','','.b-upload-file'),(472745,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-top-color','$border-color-4','','','.b-bottom'),(472746,'furniture-mobile','.b-messages .messMenuButtonTop','border-top-color','$border-color-4','','','.b-messages'),(472747,'furniture-mobile','.b-messages .msv_btn','border-top-color','$border-color-4','','','.b-messages'),(472748,'furniture-mobile','.b-messages .email-heading','border-top-color','$border-color-4','','','.b-messages'),(472749,'furniture-mobile','.b-messages .dataTable','border-top-color','$border-color-4','','','.b-messages'),(472750,'furniture-mobile','.b-messages .messages-menu li + li','border-top-color','$border-color-4','','','.b-messages'),(472751,'furniture-mobile','.b-messages .content_management_attach button','border-top-color','$border-color-5','','','.b-messages'),(472752,'furniture-mobile','.b-messages .content_management_attach','border-top-color','$border-color-4','','','.b-messages'),(472753,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-top-color','$border-color-4','','',''),(472754,'furniture-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-4','4','','.b-social-login'),(472755,'furniture-mobile','.p-payer-order-confirmation .input-wrapper','border-top-color','$border-color-4','','','.p-payer-order-confirmation'),(472756,'furniture-mobile','.p-payer-order-pay .input-wrapper','border-top-color','$border-color-4','','','.p-payer-order-pay'),(472757,'furniture-mobile','.b-email .name','border-top-color','$border-color-4','','','.b-email'),(472758,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','$border-color-4','','','.b-dropdown'),(472759,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-color','$border-color-4','','','.b-switch'),(472760,'furniture-mobile','.w-menu-slider > ul > li > ul','border-top-color','$border-reverse','','','.w-menu-slider'),(472761,'furniture-mobile','.p-reviews-info .review-info-text','border-top-color','$border-reverse','4','','.p-reviews-info'),(472762,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-color','$border-color-4','','','.p-blog-index'),(472763,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-color','$border-color-3','','','.w-upload-customer-id-upload-customer-id-form'),(472764,'furniture-mobile','.b-table .table .headings + tr ~ tr td','border-top-color','$border-color-4','','','.b-table'),(472766,'furniture-mobile','.w-menu-slider > ul > li > ul','border-top-color','$border-reverse','','','.w-menu-slider'),(472767,'furniture-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-4','3','','.b-social-login'),(472768,'furniture-mobile','.b-form .shipping-method .item + .item','border-top-color','$border-color-4','','','.b-form'),(472770,'furniture-mobile','.b-info div + .info','border-top-color','$border-color-4','','','.b-info'),(472773,'furniture-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-color','$border-color-6','','','.b-compare'),(472774,'furniture-mobile','.b-table-list .table-list td','border-top-color','$border-color-4','','','.b-table-list'),(472775,'furniture-mobile','.w-cart-products .checkout-attention-message','border-top-color','$border-attention','','','.w-cart-products'),(472776,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-top-color','$border-message','','','.w-compare-box-item'),(472777,'furniture-mobile','.w-compare-box-item .checkbox + span','border-top-color','$border-color-4','','','.w-compare-box-item'),(472778,'furniture-mobile','.w-promo-code .holder','border-top-color','$border-color-4','','','.w-promo-code'),(472779,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','$border-color-4','','','.b-tracking-numbers'),(472780,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-color','$border-color-4','','','.p-blog-index'),(472781,'furniture-mobile','.b-email .price','border-top-color','$border-color-4','','','.b-email'),(472782,'furniture-mobile','.b-email .model','border-top-color','$border-color-4','','','.b-email'),(472783,'furniture-mobile','.w-compare-box-item .checkbox + span','border-top-color','$border-color-4','','','.w-compare-box-item'),(472784,'furniture-mobile','.w-checkout-shipping-choice span','border-top-color','$border-color-5','','','.w-checkout-shipping-choice'),(472785,'furniture-mobile','.w-sale .sale-holder','border-top-color','$border-color-4','','','.w-sale'),(472786,'furniture-mobile','.w-socials > li','border-top-color','$border-color-4','','','.w-socials'),(472787,'furniture-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-4','4','','.b-social-login'),(472788,'furniture-mobile','.b-info-popup .info-popup div','border-top-color','$border-color-4','','','.b-info-popup'),(472789,'furniture-mobile','.b-form .payment-method .item + .item','border-top-color','$border-color-4','','','.b-form'),(472791,'furniture-mobile','.w-socials > li','border-top-color','$border-color-4','','','.w-socials'),(472792,'furniture-mobile','.b-info div + .info','border-top-color','$border-color-4','','','.b-info'),(472793,'furniture-mobile','.b-email .price','border-top-color','$border-color-4','','','.b-email'),(472794,'furniture-mobile','.b-email .name','border-top-color','$border-color-4','','','.b-email'),(472795,'furniture-mobile','.b-email .totals-table','border-top-color','$border-color-4','','','.b-email'),(472796,'furniture-mobile','.b-email .image','border-top-color','$border-color-4','','','.b-email'),(472797,'furniture-mobile','.w-menu .hided.menu ul li','border-top-color','$border-color-5','2885','','.w-menu'),(472798,'furniture-mobile','.w-socials > li','border-top-color','$border-color-4','','','.w-socials'),(472799,'furniture-mobile','.w-sale .sale-holder','border-top-color','$border-color-4','','','.w-sale'),(472800,'furniture-mobile','.b-bottom .popup-buttons','border-top-color','$border-color-4','','','.b-bottom'),(472801,'furniture-mobile','.w-menu .hided.menu ul li','border-top-color','$border-color-5','2885','','.w-menu'),(472802,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','$border-color-4','','','.b-dropdown'),(472804,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','$border-color-4','','','.b-tracking-numbers'),(472805,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-color','$border-reverse','','','.b-switch'),(472806,'furniture-mobile','.w-sale .sale-holder','border-top-color','$border-color-4','','','.w-sale'),(472807,'furniture-mobile','.w-menu-slider > ul > li > ul','border-top-color','$border-reverse','','','.w-menu-slider'),(472808,'furniture-mobile','.b-info div + .info','border-top-color','$border-color-4','','','.b-info'),(472809,'furniture-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-color','$border-color-4','','','.b-messages'),(472812,'furniture-mobile','.b-email .model','border-top-color','$border-color-4','','','.b-email'),(472813,'furniture-mobile','.w-menu-slider > ul > li > ul','border-top-color','$border-reverse','','','.w-menu-slider'),(472814,'furniture-mobile','.w-sale .left-text-left','border-top-color','$border-color-4','','','.w-sale'),(472815,'furniture-mobile','.w-sale .sale-holder','border-top-color','$border-color-4','','','.w-sale'),(472816,'furniture-mobile','.w-reviews .review','border-top-color','$border-transparent','3','','.w-reviews'),(472817,'furniture-mobile','.b-email .price','border-top-color','$border-color-4','','','.b-email'),(472818,'furniture-mobile','.w-reviews-content .review','border-top-color','$border-transparent','3','','.w-reviews-content'),(472819,'furniture-mobile','.w-compare-box-item .checkbox + span','border-top-color','$border-color-4','','','.w-compare-box-item'),(472820,'furniture-mobile','.w-sale .sale-holder','border-top-color','$border-color-4','','','.w-sale'),(472821,'furniture-mobile','.w-menu .hided.menu ul li','border-top-color','$border-color-5','2885','','.w-menu'),(472822,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','$border-color-4','','','.b-tracking-numbers'),(472823,'furniture-mobile','.b-email .name','border-top-color','$border-color-4','','','.b-email'),(472824,'furniture-mobile','.b-email .qty','border-top-color','$border-color-4','','','.b-email'),(472825,'furniture-mobile','.w-socials > li','border-top-color','$border-color-4','','','.w-socials'),(472826,'furniture-mobile','.b-email .image','border-top-color','$border-color-4','','','.b-email'),(472827,'furniture-mobile','.b-email .totals-table','border-top-color','$border-color-4','','','.b-email'),(472828,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','$border-color-4','','','.b-tracking-numbers'),(472829,'furniture-mobile','.b-email .image','border-top-color','$border-color-4','','','.b-email'),(472830,'furniture-mobile','.b-email .name','border-top-color','$border-color-4','','','.b-email'),(472831,'furniture-mobile','.b-email .qty','border-top-color','$border-color-4','','','.b-email'),(472832,'furniture-mobile','.b-email .model','border-top-color','$border-color-4','','','.b-email'),(472833,'furniture-mobile','.b-email .price','border-top-color','$border-color-4','','','.b-email'),(472834,'furniture-mobile','.w-checkout-shipping .sub-item + .sub-item','border-top-color','$border-color-4','','','.w-checkout-shipping'),(472835,'furniture-mobile','.b-form .required-error','border-top-color','$border-attention','','','.b-form'),(472836,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','$border-color-4','','','.b-dropdown'),(472837,'furniture-mobile','.b-table .table .headings + tr ~ tr td','border-top-color','$border-color-4','','','.b-table'),(472838,'furniture-mobile','.w-promo-code .holder','border-top-color','$border-color-4','','','.w-promo-code'),(472839,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','$border-color-4','','','.b-tracking-numbers'),(472840,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','border-top-color','$border-color-4','','','.b-select-suggest'),(472842,'furniture-mobile','.w-menu .hided.menu ul li','border-top-color','$border-color-5','2885','','.w-menu'),(472843,'furniture-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-4','4','','.b-social-login'),(472844,'furniture-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-4','3','','.b-social-login'),(472845,'furniture-mobile','textarea','border-top-color','$border-color-4','','',''),(472846,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-color','$border-color-4','4','','.b-switch'),(472847,'furniture-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-4','4','','.b-social-login'),(472848,'furniture-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-4','3','','.b-social-login'),(472849,'furniture-mobile','.w-sale .left-text-left','border-top-color','$border-color-4','','','.w-sale'),(472850,'furniture-mobile','.w-sale .left-text-right','border-top-color','$border-color-4','','','.w-sale'),(472851,'furniture-mobile','.w-languages .select','border-top-color','$border-color-4','','','.w-languages'),(472852,'furniture-mobile','.b-info div + .info','border-top-color','$border-color-4','','','.b-info'),(472853,'furniture-mobile','.b-form .form-buttons','border-top-color','$border-color-4','','','.b-form'),(472854,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-color','$border-color-4','3','','.b-form'),(472855,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-top-color','$border-message','','','.w-compare-box-item'),(472856,'furniture-mobile','.w-cart-products .checkout-attention-message','border-top-color','$border-attention','','','.w-cart-products'),(472857,'furniture-mobile','.w-cart-products .checkout-attention-message','border-top-color','$border-attention','','','.w-cart-products'),(472858,'furniture-mobile','.w-sale .left-text-right','border-top-color','$border-color-4','','','.w-sale'),(472859,'furniture-mobile','.p-reviews-info .review-info-text','border-top-color','$border-reverse','4','','.p-reviews-info'),(472860,'furniture-mobile','.b-table-list .table-list td','border-top-color','$border-color-4','','','.b-table-list'),(472861,'furniture-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-4','3','','.b-social-login'),(472862,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','$border-color-4','','','.b-dropdown'),(472863,'furniture-mobile','.b-email .name','border-top-color','$border-color-4','','','.b-email'),(472864,'furniture-mobile','.b-email .qty','border-top-color','$border-color-4','','','.b-email'),(472865,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-top-color','$border-reverse','','','.b-bottom'),(472866,'furniture-mobile','.w-menu .hided.menu ul li','border-top-color','$border-color-5','2885','','.w-menu'),(472867,'furniture-mobile','.w-sale .left-text-left','border-top-color','$border-color-4','','','.w-sale'),(472868,'furniture-mobile','.w-promo-code .holder','border-top-color','$border-color-4','','','.w-promo-code'),(472870,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-color','$border-color-4','','','.b-select-suggest'),(472871,'furniture-mobile','.b-email .totals-table','border-top-color','$border-color-4','','','.b-email'),(472872,'furniture-mobile','.w-sale .sale-holder','border-top-color','$border-color-4','','','.w-sale'),(472873,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-color','$border-color-4','','','.p-blog-index'),(472877,'furniture-mobile','.b-email .image','border-top-color','$border-color-4','','','.b-email'),(472879,'furniture-mobile','.b-email .qty','border-top-color','$border-color-4','','','.b-email'),(472880,'furniture-mobile','.b-table-list .table-list td','border-top-color','$border-color-4','','','.b-table-list'),(472881,'furniture-mobile','.w-cart-compare .product-block td','border-top-color','$border-color-4','','','.w-cart-compare'),(472882,'furniture-mobile','.b-bottom .popup-box','border-top-color','$border-color-4','','','.b-bottom'),(472883,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-color','$border-color-4','','','.b-dropdown'),(472884,'furniture-mobile','.b-email .model','border-top-color','$border-color-4','','','.b-email'),(472885,'furniture-mobile','.b-info div + .info','border-top-color','$border-color-4','','','.b-info'),(472886,'furniture-mobile','.w-product-customers-activity .customers-activity','border-top-color','$border-color-4','','','.w-product-customers-activity'),(472887,'furniture-mobile','.b-table .table .headings + tr ~ tr td','border-top-color','$border-color-4','','','.b-table'),(472888,'furniture-mobile','.b-email .model','border-top-color','$border-color-4','','','.b-email'),(472889,'furniture-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-4','3','','.b-social-login'),(472890,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-color','$border-color-4','','','.p-blog-index'),(472891,'furniture-mobile','.w-cart-compare .price-block td','border-top-color','$border-color-4','','','.w-cart-compare'),(472892,'furniture-mobile','.w-sale .left-text-right','border-top-color','$border-color-4','','','.w-sale'),(472893,'furniture-mobile','.w-promo-code .holder','border-top-color','$border-color-4','','','.w-promo-code'),(472894,'furniture-mobile','.w-compare-box-item .checkbox + span','border-top-color','$border-color-4','','','.w-compare-box-item'),(472895,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-top-color','$border-message','','','.w-compare-box-item'),(472898,'furniture-mobile','.w-sale .left-text-left','border-top-color','$border-color-4','','','.w-sale'),(472899,'furniture-mobile','.w-sale .left-text-right','border-top-color','$border-color-4','','','.w-sale'),(472901,'furniture-mobile','.w-wedding-registry-widgets-products .rating','border-top-color','$border-color-3','','','.w-wedding-registry-widgets-products'),(472902,'furniture-mobile','.p-reviews-info .review-info-text','border-top-color','$border-reverse','4','','.p-reviews-info'),(472903,'furniture-mobile','.b-table-list .table-list td','border-top-color','$border-color-4','','','.b-table-list'),(472904,'furniture-mobile','.b-table .table .headings + tr ~ tr td','border-top-color','$border-color-4','','','.b-table'),(472905,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-color','$border-color-4','','','.b-select-suggest'),(472906,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-color','$border-color-4','','','.b-select-suggest'),(472907,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-color','$border-color-4','','','.b-select-suggest'),(472908,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-top-color','$border-color-4','','','.b-select-suggest'),(472909,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-color','$border-color-4','','','.b-select-suggest'),(472910,'furniture-mobile','.w-menu .hided.menu ul li','border-top-color','$border-color-5','2885','','.w-menu'),(472911,'furniture-mobile','.b-select-suggest .select2-search input','border-top-color','$border-color-4','','','.b-select-suggest'),(472912,'furniture-mobile','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-color','$border-color-4','','','.b-select-suggest'),(472913,'furniture-mobile','.b-select-suggest .select2-drop.select2-drop-above','border-top-color','$border-color-4','','','.b-select-suggest'),(472914,'furniture-mobile','.b-select-suggest .select2-drop-active','border-top-color','$border-color-4','','','.b-select-suggest'),(472915,'furniture-mobile','.b-select-suggest .select2-drop','border-top-color','$border-color-4','','','.b-select-suggest'),(472916,'furniture-mobile','.b-select-suggest .select2-drop-auto-width','border-top-color','$border-color-4','','','.b-select-suggest'),(472917,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-color','$border-color-4','','','.p-blog-index'),(472918,'furniture-mobile','.w-menu-slider > ul > li > ul','border-top-color','$border-reverse','','','.w-menu-slider'),(472919,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-color','$border-color-4','','','.p-blog-index'),(472920,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-top-color','$border-color-3','','','.w-wedding-registry-widgets-photos'),(472921,'furniture-mobile','.w-account .acc-bottom','border-top-color','$border-color-4','','','.w-account'),(472922,'furniture-mobile','.p-reviews-info .review-info-text','border-top-color','$border-reverse','4','','.p-reviews-info'),(472923,'furniture-mobile','.w-promo-code .holder','border-top-color','$border-color-4','','','.w-promo-code'),(472924,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-top-color','$border-message','','','.w-compare-box-item'),(472925,'furniture-mobile','.b-form input.required-error','border-top-color','$border-attention','','','.b-form'),(472926,'furniture-mobile','.w-communication-post .communication-post','border-top-color','$border-color-4','','','.w-communication-post'),(472927,'furniture-mobile','.checkbox input:checked + span','border-top-color','$border-message','','',''),(472928,'furniture-mobile','.checkbox input + span','border-top-color','$border-color-4','','',''),(472929,'furniture-mobile','.b-autocomplete .ui-autocomplete','border-top-color','$border-color-4','','','.b-autocomplete'),(472930,'furniture-mobile','.w-currencies .select','border-top-color','$border-color-4','','','.w-currencies'),(472931,'furniture-mobile','.w-currencies .currencies-title','border-top-color','$border-color-5','','','.w-currencies'),(472932,'furniture-mobile','.b-table .table .headings + tr ~ tr td','border-top-color','$border-color-4','','','.b-table'),(472934,'furniture-mobile','.b-info-popup .info-popup div','border-top-color','$border-color-4','3','','.b-info-popup'),(472935,'furniture-mobile','.b-table-list .table-list td','border-top-color','$border-color-4','','','.b-table-list'),(472936,'furniture-mobile','.w-socials > li','border-top-color','$border-color-4','','','.w-socials'),(472937,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-color','$border-color-4','3','','.b-switch'),(472938,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-top-color','$border-color-3','','','.w-wedding-registry-widgets-photos'),(472939,'furniture-mobile','.b-email .qty','border-top-color','$border-color-4','','','.b-email'),(472940,'furniture-mobile','.b-email .totals-table','border-top-color','$border-color-4','','','.b-email'),(472941,'furniture-mobile','.b-email .name','border-top-color','$border-color-4','','','.b-email'),(472942,'furniture-mobile','.w-sale .left-text-left','border-top-color','$border-color-4','','','.w-sale'),(472943,'furniture-mobile','.b-email .price','border-top-color','$border-color-4','','','.b-email'),(472944,'furniture-mobile','.w-compare-box-item .checkbox + span','border-top-color','$border-color-4','','','.w-compare-box-item'),(472945,'furniture-mobile','.b-email .image','border-top-color','$border-color-4','','','.b-email'),(472946,'furniture-mobile','.w-sale .left-text-left','border-top-color','$border-color-4','','','.w-sale'),(472947,'furniture-mobile','.w-promo-code .holder','border-top-color','$border-color-4','','','.w-promo-code'),(472948,'furniture-mobile','.w-sale .left-text-right','border-top-color','$border-color-4','','','.w-sale'),(472949,'furniture-mobile','.b-email .image','border-top-color','$border-color-4','','','.b-email'),(472950,'furniture-mobile','.b-form .privacy-row','border-top-color','$border-color-4','','','.b-form'),(472951,'furniture-mobile','.w-cart-products .checkout-attention-message','border-top-color','$border-attention','','','.w-cart-products'),(472952,'furniture-mobile','.w-cart-listing .item .gift-wrap label','border-top-color','$border-color-4','','','.w-cart-listing'),(472953,'furniture-mobile','.w-cart-listing .item','border-top-color','$border-color-4','2885','','.w-cart-listing'),(472954,'furniture-mobile','.w-cart .cart-content','border-top-color','$border-color-4','','','.w-cart'),(472955,'furniture-mobile','.w-menu-slider > ul > li > ul','border-top-color','$border-reverse','','','.w-menu-slider'),(472956,'furniture-mobile','.w-sale .left-text-right','border-top-color','$border-color-4','','','.w-sale'),(472957,'furniture-mobile','.p-reviews-info .review-info-text','border-top-color','$border-reverse','4','','.p-reviews-info'),(472959,'furniture-mobile','.w-cart-products .checkout-attention-message','border-top-color','$border-attention','','','.w-cart-products'),(472960,'furniture-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-4','4','','.b-social-login'),(472961,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','border-top-color','$border-color-4','','','.b-tracking-numbers'),(472962,'furniture-mobile','.b-table-list .table-list td','border-top-color','$border-color-4','','','.b-table-list'),(472963,'furniture-mobile','.b-upload-files .added-file','border-top-color','$border-color-4','','','.b-upload-files'),(472964,'furniture-mobile','.b-data-table table.dataTable.no-footer','border-top-color','$border-color-4','','','.b-data-table'),(472965,'furniture-mobile','.b-data-table table.dataTable tbody td','border-top-color','$border-color-4','','','.b-data-table'),(472966,'furniture-mobile','.b-upload-files .upload-files','border-top-color','$border-color-4','','','.b-upload-files'),(472967,'furniture-mobile','.b-table .table .headings + tr ~ tr td','border-top-color','$border-color-4','','','.b-table'),(472968,'furniture-mobile','.b-social-login .social-login-text-2','border-top-color','$border-color-4','3','','.b-social-login'),(472970,'furniture-mobile','.b-info div + .info','border-top-color','$border-color-4','','','.b-info'),(472972,'furniture-mobile','.b-email .totals-table','border-top-color','$border-color-4','','','.b-email'),(472973,'furniture-mobile','.b-email .qty','border-top-color','$border-color-4','','','.b-email'),(472974,'furniture-mobile','.b-upload-file .snapshot','border-top-color','$border-color-6','','','.b-upload-file'),(472975,'furniture-mobile','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-top-color','$border-reverse','','','.b-product-images'),(472976,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-top-color','$border-color-2','','','.b-menu-style-2'),(472977,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-top-color','$border-color-2','','','.b-menu-style-2'),(472978,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','border-top-color','$border-color-2','','','.b-menu-style-2'),(472979,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-top-color','$border-color-2','','','.b-menu-style-2'),(472980,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-top-color','$border-color-2','','','.b-menu-style-2'),(472981,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-color','$border-color-4','','','.b-trade-approval'),(472982,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-color','$border-color-4','','','.batchPr'),(472983,'furniture-mobile','.batchPr .checkbox input + span','border-top-color','$border-color-4','','','.batchPr'),(472984,'furniture-mobile','.batchPr .checkbox input + span','border-top-color','$border-color-4','','','.batchPr'),(472985,'furniture-mobile','.batchPr .checkbox input:checked + span','border-top-color','$border-color-2','','','.batchPr'),(472986,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .item + .item','border-top-color','$border-color-4','','','.batchPr'),(472987,'furniture-mobile','.batchPr .w-batch-selected-products','border-top-color','$border-color-4','','','.batchPr'),(472988,'furniture-mobile','.w-account-personal-catalog .list-switcher a','border-top-color','$border-color-5','2','','.w-account-personal-catalog'),(472989,'furniture-mobile','.w-account-subscription .subscription-variant + .subscription-variant','border-top-color','$border-color-3','','','.w-account-subscription'),(472990,'furniture-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-top-color','$border-reverse','','','.w-catalog-compare'),(472991,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','border-top-color','$border-color-5','2','','.w-catalog-compare'),(472992,'furniture-mobile','.w-delivery-day .left-text-left','border-top-color','$border-color-4','','','.w-delivery-day'),(472993,'furniture-mobile','.w-delivery-day .left-text-right','border-top-color','$border-color-4','','','.w-delivery-day'),(472994,'furniture-mobile','.w-search .search-input','border-top-color','$border-color-2','','','.w-search'),(472995,'furniture-mobile','.b-products-listing .products-listing .compare input + span','border-top-color','$border-color-5','','','.b-products-listing'),(472996,'furniture-mobile','.w-filters .filter-widget','border-top-color','$border-color-4','','','.w-filters'),(472997,'furniture-mobile','.w-quote .cart-content','border-top-color','$border-color-4','','','.w-quote'),(472998,'furniture-mobile','.b-product-images .additional-images .active img','border-top-color','$border-color-5','','','.b-product-images'),(472999,'furniture-mobile','.b-product-images .additional-images img','border-top-color','$border-reverse','','','.b-product-images'),(473000,'furniture-mobile','.b-quantity .qty-box .bigger','border-top-color','$border-color-1','','','.b-quantity'),(473001,'furniture-mobile','.b-quantity .qty-box .smaller','border-top-color','$border-color-1','','','.b-quantity'),(473002,'furniture-mobile','.w-product-sale-ends .left-text-left','border-top-color','$border-color-3','','','.w-product-sale-ends'),(473003,'furniture-mobile','.w-product-sale-ends .left-text-right','border-top-color','$border-color-3','','','.w-product-sale-ends'),(473004,'furniture-mobile','.w-files-catalog-widgets-files-list .item + .item','border-top-color','$border-color-3','','','.w-files-catalog-widgets-files-list'),(473005,'furniture-mobile','.w-sample .cart-content','border-top-color','$border-color-4','','','.w-sample'),(473006,'furniture-mobile','.w-cart-listing .points-earn','border-top-color','$border-transparent','4','','.w-cart-listing'),(473007,'furniture-mobile','.w-cart-discount-coupon .btn','border-top-color','$border-color-5','','','.w-cart-discount-coupon'),(473008,'furniture-mobile','.w-product-video .item img, .w-product-video .item video','border-top-color','$border-reverse','','','.w-product-video'),(473009,'furniture-mobile','.w-product-video .item.active img, .w-product-video .item.active video','border-top-color','$border-color-7','','','.w-product-video'),(473010,'furniture-mobile','.w-cart-order-reference .btn','border-top-color','$border-color-5','','','.w-cart-order-reference'),(473011,'furniture-mobile','.w-cart-gift-certificate .btn','border-top-color','$border-color-5','','','.w-cart-gift-certificate'),(473012,'furniture-mobile','.w-cart-shipping-estimator .btn','border-top-color','$border-color-5','','','.w-cart-shipping-estimator'),(473013,'furniture-mobile','.w-product-bundle .bundle_item:nth-child(3) ~ .bundle_item','border-top-color','$border-color-3','','','.w-product-bundle'),(473014,'furniture-mobile','.w-product-bundle .bundle-total-price','border-top-color','$border-color-3','','','.w-product-bundle'),(473015,'furniture-mobile','.w-product-bundle .bundle_item:nth-child(2) ~ .bundle_item','border-top-color','$border-color-3','2885','','.w-product-bundle'),(473016,'furniture-mobile','.w-product-bundle .bundle_item:nth-child(1) ~ .bundle_item','border-top-color','$border-color-3','2876','','.w-product-bundle'),(473017,'furniture-mobile','.w-product-in-bundles .bundle-total-price','border-top-color','$border-color-3','','','.w-product-in-bundles'),(473018,'furniture-mobile','.w-product-in-bundles .bundle_item:nth-child(3) ~ .bundle_item','border-top-color','$border-color-3','','','.w-product-in-bundles'),(473019,'furniture-mobile','.w-product-in-bundles .bundle_item:nth-child(2) ~ .bundle_item','border-top-color','$border-color-3','2885','','.w-product-in-bundles'),(473020,'furniture-mobile','.w-product-in-bundles .bundle_item:nth-child(1) ~ .bundle_item','border-top-color','$border-color-3','2876','','.w-product-in-bundles'),(473021,'furniture-mobile','.w-account-address-book .item','border-top-color','$border-color-3','','','.w-account-address-book'),(473022,'furniture-mobile','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-top-color','$border-color-8','','','.b-pagination'),(473023,'furniture-mobile','.b-pagination .pagination .next-pages','border-top-color','$border-color-4','','','.b-pagination'),(473024,'furniture-mobile','.b-pagination .pagination .page-number','border-top-color','$border-color-4','','','.b-pagination'),(473025,'furniture-mobile','.b-pagination .pagination .prev-pages','border-top-color','$border-color-4','','','.b-pagination'),(473026,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-top-color','$border-color-4','','','.b-pagination'),(473027,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-top-color','$border-color-4','','','.b-pagination'),(473028,'furniture-mobile','.b-pagination .pagination span','border-top-color','$border-color-4','2','','.b-pagination'),(473029,'furniture-mobile','.w-product-quantity-discounts .item + .item + .item','border-top-color','$border-color-3','','','.w-product-quantity-discounts'),(473030,'furniture-mobile','.w-product-quantity-discounts .item + .item','border-top-color','$border-color-3','2885','','.w-product-quantity-discounts'),(473031,'furniture-mobile','.w-tabs .tab-li','border-top-color','$border-color-5','2','','.w-tabs'),(473032,'furniture-mobile','.w-account-order-download tr + tr','border-top-color','$border-color-4','','','.w-account-order-download'),(473033,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','border-top-color','$border-color-4','','','.w-product-multi-inventory'),(473034,'furniture-mobile','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-top-color','$border-color-5','','','.w-product-multi-inventory'),(473035,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-top-color','$border-color-3','','','.w-account-personal-catalog'),(473036,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','border-top-color','$border-color-3','','','.w-account-personal-catalog'),(473037,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','border-top-color','$border-color-4','','','.b-products-listing'),(473038,'furniture-mobile','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-top-color','$border-color-5','','','.b-products-listing'),(473039,'furniture-mobile','.w-product-collection .choose-products','border-top-color','$border-color-3','','','.w-product-collection'),(473040,'furniture-mobile','.w-account-customer-additional-field .tf-file + .tf-file','border-top-color','$border-color-3','','','.w-account-customer-additional-field'),(473041,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','border-top-color','$border-color-4','','','.w-product-attributes'),(473042,'furniture-mobile','.w-product-attributes .radio-attributes input:checked + .option-item','border-top-color','$border-color-5','','','.w-product-attributes'),(473043,'furniture-mobile','.w-questionnaire-widgets-questionnaire .question + .question','border-top-color','$border-color-3','','','.w-questionnaire-widgets-questionnaire'),(473044,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-color','$border-color-3','','','.w-questionnaire-widgets-questionnaire'),(473045,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-top-color','$border-attention','','','.w-questionnaire-widgets-questionnaire'),(473046,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-top-color','$border-message','','','.w-questionnaire-widgets-questionnaire'),(473047,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-top-color','$border-attention','1','','.w-questionnaire-widgets-questionnaire'),(473048,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-top-color','$border-message','1','','.w-questionnaire-widgets-questionnaire'),(473049,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','border-top-color','$border-color-3','','','.w-product-groups'),(473050,'furniture-mobile','.w-product-groups .radioBox label .containerBlock.selected','border-top-color','$border-color-5','','','.w-product-groups'),(473051,'furniture-mobile','.w-product-groups .radioBox label input:checked + .containerBlock','border-top-color','$border-color-5','','','.w-product-groups'),(473052,'furniture-mobile','.w-product-custom-bundle .choose-products','border-top-color','$border-color-3','','','.w-product-custom-bundle'),(473053,'furniture-mobile','.w-product-custom-bundle .right-area .price','border-top-color','$border-color-3','2885','','.w-product-custom-bundle'),(473054,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-top-color','$border-color-4','','','.w-delivery-location-location-list'),(473055,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-top-color','$border-color-5','1','','.w-delivery-location-location-list'),(473056,'furniture-mobile','.w-sale-category .left-text-left','border-top-color','$border-color-4','','','.w-sale-category'),(473057,'furniture-mobile','.w-sale-category .left-text-right','border-top-color','$border-color-4','','','.w-sale-category'),(473058,'furniture-mobile','.w-sale-category .sale-holder','border-top-color','$border-color-4','','','.w-sale-category'),(473059,'furniture-mobile','.w-wedding-registry-widgets-photos .upload-file-template','border-top-color','$border-color-3','','','.w-wedding-registry-widgets-photos'),(473060,'furniture-mobile','.w-product-wedding-registry-button .btn','border-top-color','$border-color-5','3','','.w-product-wedding-registry-button'),(473061,'furniture-mobile','.w-product-wedding-registry-button .btn','border-top-color','$border-color-5','4','','.w-product-wedding-registry-button'),(473062,'furniture-mobile','.w-delivery-location-list-by-page .item','border-top-color','$border-color-3','','','.w-delivery-location-list-by-page'),(473063,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-top-color','$border-color-4','','','.w-product-properties-icons'),(473064,'furniture-mobile','.w-delivery-location-cross-pages .item','border-top-color','$border-color-3','','','.w-delivery-location-cross-pages'),(473065,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','border-top-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(473066,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','border-top-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(473067,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','border-top-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(473068,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','border-top-color','$border-color-4','','','.w-wedding-registry-widgets-search-paging'),(473069,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','border-top-color','$border-color-3','','','.w-product-designer-designer'),(473070,'furniture-mobile','.w-press-reviews-widgets-press-reviews .press-reviews-button','border-top-color','$border-color-1','','','.w-press-reviews-widgets-press-reviews'),(473071,'furniture-mobile','.b-products-listing .productGroup label a','border-top-color','$border-color-5','','','.b-products-listing'),(473072,'furniture-mobile','.w-support-system-listing .support-head','border-top-color','$border-color-1','','','.w-support-system-listing'),(473073,'furniture-mobile','.w-support-system-listing .product_icon','border-top-color','$border-color-1','','','.w-support-system-listing'),(473074,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-color','$border-attention','','','.w-predefined-promotion'),(473075,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-color','$border-attention','','','.w-predefined-promotion'),(473076,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-color','$border-attention','','','.w-predefined-promotion'),(473077,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border-top-color','$border-warning','','','.w-predefined-promotion'),(473078,'furniture-mobile','.w-supplier-purchase-supplier-products .item','border-top-color','$border-color-3','','','.w-supplier-purchase-supplier-products'),(473079,'furniture-mobile','.mainBanner .bottomBox .btn','border-top-color','$border-color-2','','','.mainBanner'),(473080,'furniture-mobile','.mainBanner .bottomBox .btn','border-top-color','$border-color-2','2890','','.mainBanner'),(473081,'furniture-mobile','.mainBanner .bottomBox .btn','border-top-color','$border-color-2','2876','','.mainBanner'),(473082,'furniture-mobile','.mainBanner .bottomBox .btn','border-top-color','$border-color-2','2906','','.mainBanner'),(473083,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','border-top-color','$border-color-5','','','.lowestPricedBox'),(473084,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-top-color','$border-color-2','','','.shopByCollectionBox'),(473085,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-top-color','$border-color-2','2890','','.shopByCollectionBox'),(473086,'furniture-mobile','.account-order-history .orders-table .item','border-top-color','$border-color-4','2885','','.account-order-history'),(473087,'furniture-mobile','.account-index .orders-table .item','border-top-color','$border-color-4','2885','','.account-index'),(473088,'furniture-mobile','.account-samples .orders-table .item','border-top-color','$border-color-4','2885','','.account-samples'),(473089,'furniture-mobile','.catalog-product-wrap .pn-image','border-top-color','$border-color-4','3','','.catalog-product-wrap'),(473090,'furniture-mobile','.shopping-cart-index .btn-3','border-top-color','$border-color-5','','','.shopping-cart-index'),(473091,'furniture-mobile','.checkout-index-wrap .input-wrapper','border-top-color','$border-color-4','','','.checkout-index-wrap'),(473092,'furniture-mobile','.b-data-table table.dataTable.no-footer','border-top-color_important','important','','','.b-data-table'),(473093,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-top-left-radius','0','4','','.b-switch'),(473096,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.p-quick-order-index'),(473097,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-left-radius','12','','','.w-promotions'),(473098,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.p-quick-order-index'),(473099,'furniture-mobile','.w-sale .badge','border-top-left-radius','50','','','.w-sale'),(473100,'furniture-mobile','.w-sale .left-count-hours','border-top-left-radius','3','','','.w-sale'),(473101,'furniture-mobile','.w-promotions .promo-salemaker .discount','border-top-left-radius','12','','','.w-promotions'),(473102,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-left-radius','12','','','.w-promotions'),(473103,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-left-radius','12','','','.w-promotions'),(473104,'furniture-mobile','.p-blog-index .avatar','border-top-left-radius','50','','','.p-blog-index'),(473105,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-left-radius','5','','','.b-messages'),(473106,'furniture-mobile','.p-blog-index .avatar','border-top-left-radius','50','','','.p-blog-index'),(473107,'furniture-mobile','.b-fancybox .fancybox-close','border-top-left-radius','50','','','.b-fancybox'),(473108,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-left-radius','25','','','.b-switch'),(473109,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-top-left-radius','0','3','','.b-switch'),(473110,'furniture-mobile','.w-sale .badge','border-top-left-radius','50','','','.w-sale'),(473112,'furniture-mobile','.w-sale .left-count-hours','border-top-left-radius','3','','','.w-sale'),(473114,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-left-radius','15','3','','.b-switch'),(473115,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(473116,'furniture-mobile','.b-switch .bootstrap-switch','border-top-left-radius','14','','','.b-switch'),(473117,'furniture-mobile','.w-sale .badge','border-top-left-radius','50','','','.w-sale'),(473118,'furniture-mobile','.w-sale .left-count','border-top-left-radius','3','','','.w-sale'),(473119,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg','border-top-left-radius','15','','','.b-switch'),(473120,'furniture-mobile','.w-checkout-shipping-choice label:first-child span','border-top-left-radius','16','','','.w-checkout-shipping-choice'),(473121,'furniture-mobile','.w-checkout-shipping-choice label:last-child span','border-top-left-radius','0','','','.w-checkout-shipping-choice'),(473122,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-left-radius','0','','','.w-catalog-paging'),(473123,'furniture-mobile','.w-sale .left-count-days','border-top-left-radius','3','','','.w-sale'),(473124,'furniture-mobile','.w-sale .left-count','border-top-left-radius','3','','','.w-sale'),(473127,'furniture-mobile','.p-blog-index .avatar','border-top-left-radius','50','','','.p-blog-index'),(473129,'furniture-mobile','.p-blog-index .avatar','border-top-left-radius','50','','','.p-blog-index'),(473130,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-left-radius','25','','','.b-switch'),(473132,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-left-radius','50','3','','.b-form'),(473133,'furniture-mobile','.w-sale .left-count-days','border-top-left-radius','3','','','.w-sale'),(473134,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-top-left-radius','50','3','','.b-switch'),(473135,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-top-left-radius','15','','','.b-fancybox'),(473136,'furniture-mobile','.b-fancybox .fancybox-skin','border-top-left-radius','4','','','.b-fancybox'),(473137,'furniture-mobile','.w-sale .badge','border-top-left-radius','50','','','.w-sale'),(473139,'furniture-mobile','.w-personal-gift-status-bar .progress-bar','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(473140,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-left-radius','15','4','','.b-switch'),(473141,'furniture-mobile','.w-sale .left-count-days','border-top-left-radius','3','','','.w-sale'),(473142,'furniture-mobile','.w-sale .left-count-hours','border-top-left-radius','3','','','.w-sale'),(473143,'furniture-mobile','.w-sale .left-count','border-top-left-radius','3','','','.w-sale'),(473145,'furniture-mobile','.w-sale .left-count-days','border-top-left-radius','3','','','.w-sale'),(473146,'furniture-mobile','.w-sale .left-count-hours','border-top-left-radius','3','','','.w-sale'),(473148,'furniture-mobile','.w-sale .left-count','border-top-left-radius','3','','','.w-sale'),(473149,'furniture-mobile','.w-personal-gift-status-bar .progress-bar-content','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(473150,'furniture-mobile','.b-fancybox .fancybox-nav span','border-top-left-radius','50','','','.b-fancybox'),(473151,'furniture-mobile','.w-product-customers-activity .close','border-top-left-radius','50','','','.w-product-customers-activity'),(473152,'furniture-mobile','.w-product-customers-activity .customers-activity','border-top-left-radius','10','','','.w-product-customers-activity'),(473153,'furniture-mobile','.w-sale .left-count-days','border-top-left-radius','3','','','.w-sale'),(473154,'furniture-mobile','.p-blog-index .avatar','border-top-left-radius','50','','','.p-blog-index'),(473155,'furniture-mobile','.w-sale .left-count','border-top-left-radius','3','','','.w-sale'),(473156,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.b-data-table'),(473157,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.b-data-table'),(473158,'furniture-mobile','.b-products-listing .promos-info .promo-name','border-top-left-radius','0','','','.b-products-listing'),(473159,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-top-left-radius','0','','','.w-blog-widget-related-posts'),(473160,'furniture-mobile','.w-sale .left-count-hours','border-top-left-radius','3','','','.w-sale'),(473161,'furniture-mobile','.w-sale .left-count-hours','border-top-left-radius','3','','','.w-sale'),(473162,'furniture-mobile','.w-sale .left-count-days','border-top-left-radius','3','','','.w-sale'),(473163,'furniture-mobile','.w-sale .left-count','border-top-left-radius','3','','','.w-sale'),(473164,'furniture-mobile','.w-sale .badge','border-top-left-radius','50','','','.w-sale'),(473165,'furniture-mobile','.w-sale .badge','border-top-left-radius','50','','','.w-sale'),(473166,'furniture-mobile','.p-blog-index .avatar','border-top-left-radius','50','','','.p-blog-index'),(473167,'furniture-mobile','.b-upload-file .snapshot','border-top-left-radius','50','','','.b-upload-file'),(473169,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(473170,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-top-left-radius','0','','','.b-product-images'),(473171,'furniture-mobile','.b-trade-approval .steps-bar','border-top-left-radius','18','','','.b-trade-approval'),(473172,'furniture-mobile','.batchPr .checkbox input + span','border-top-left-radius','18','','','.batchPr'),(473173,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-top-left-radius','0','','','.batchPr'),(473174,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-left-radius','10','','','.batchPr'),(473175,'furniture-mobile','.batchPr .btn-batch-remove','border-top-left-radius','100','','','.batchPr'),(473176,'furniture-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-left-radius','3','','','.w-delivery-day'),(473177,'furniture-mobile','.w-delivery-day .left-count','border-top-left-radius','3','','','.w-delivery-day'),(473178,'furniture-mobile','.w-cart .cart-box-link','border-top-left-radius','50','3','','.w-cart'),(473179,'furniture-mobile','.w-account .my-acc-link','border-top-left-radius','50','3','','.w-account'),(473180,'furniture-mobile','.w-account .account-dropdown','border-top-left-radius','100','3','','.w-account'),(473181,'furniture-mobile','.w-search .search-ico','border-top-left-radius','50','2885,3','','.w-search'),(473182,'furniture-mobile','.menu-header .burger-icon','border-top-left-radius','50','2885','','.menu-header'),(473183,'furniture-mobile','.w-quote .cart-box-link','border-top-left-radius','50','3','','.w-quote'),(473184,'furniture-mobile','.w-product-sale-ends .left-count','border-top-left-radius','3','','','.w-product-sale-ends'),(473185,'furniture-mobile','.w-product-sale-ends .left-count-days','border-top-left-radius','3','','','.w-product-sale-ends'),(473186,'furniture-mobile','.w-product-sale-ends .left-count-hours','border-top-left-radius','3','','','.w-product-sale-ends'),(473187,'furniture-mobile','.w-sample .cart-box-link','border-top-left-radius','50','3','','.w-sample'),(473188,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-left-radius','50','','','.w-questionnaire-widgets-questionnaire'),(473189,'furniture-mobile','.w-sale-category .badge','border-top-left-radius','50','','','.w-sale-category'),(473190,'furniture-mobile','.w-sale-category .left-count','border-top-left-radius','3','','','.w-sale-category'),(473191,'furniture-mobile','.w-sale-category .left-count-days','border-top-left-radius','3','','','.w-sale-category'),(473192,'furniture-mobile','.w-sale-category .left-count-hours','border-top-left-radius','3','','','.w-sale-category'),(473193,'furniture-mobile','.w-product-wedding-registry-button .btn','border-top-left-radius','50','3','','.w-product-wedding-registry-button'),(473194,'furniture-mobile','.w-product-wedding-registry-button .btn','border-top-left-radius','50','4','','.w-product-wedding-registry-button'),(473195,'furniture-mobile','.b-products-listing .productGroup label a','border-top-left-radius','3','','','.b-products-listing'),(473196,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-left-radius','12','','','.w-predefined-promotion'),(473197,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-left-radius','12','','','.w-predefined-promotion'),(473198,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-left-radius','12','','','.w-predefined-promotion'),(473199,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border-top-left-radius','12','','','.w-predefined-promotion'),(473200,'furniture-mobile','.lowestPricedBox .w-banner .ybg','border-top-left-radius','50','3','','.lowestPricedBox'),(473201,'furniture-mobile','.catalog-product-wrap .pn-image','border-top-left-radius','50','3','','.catalog-product-wrap'),(473202,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-top-right-radius','0','4','','.b-switch'),(473203,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.p-quick-order-index'),(473204,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.p-quick-order-index'),(473205,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-right-radius','12','','','.w-promotions'),(473206,'furniture-mobile','.w-promotions .promo-salemaker .discount','border-top-right-radius','12','','','.w-promotions'),(473207,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-right-radius','12','','','.w-promotions'),(473208,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-right-radius','12','','','.w-promotions'),(473209,'furniture-mobile','.b-upload-file .snapshot','border-top-right-radius','50','','','.b-upload-file'),(473210,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-right-radius','5','','','.b-messages'),(473211,'furniture-mobile','.w-personal-gift-status-bar .progress-bar','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(473212,'furniture-mobile','.p-blog-index .avatar','border-top-right-radius','50','','','.p-blog-index'),(473213,'furniture-mobile','.p-blog-index .avatar','border-top-right-radius','50','','','.p-blog-index'),(473214,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-right-radius','50','3','','.b-form'),(473215,'furniture-mobile','.b-fancybox .fancybox-close','border-top-right-radius','50','','','.b-fancybox'),(473216,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-right-radius','25','','','.b-switch'),(473217,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-top-right-radius','0','3','','.b-switch'),(473219,'furniture-mobile','.b-switch .bootstrap-switch','border-top-right-radius','14','','','.b-switch'),(473220,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-right-radius','15','3','','.b-switch'),(473221,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg','border-top-right-radius','15','','','.b-switch'),(473222,'furniture-mobile','.w-checkout-shipping-choice label:last-child span','border-top-right-radius','16','','','.w-checkout-shipping-choice'),(473224,'furniture-mobile','.w-sale .left-count','border-top-right-radius','3','','','.w-sale'),(473225,'furniture-mobile','.w-checkout-shipping-choice label:first-child span','border-top-right-radius','0','','','.w-checkout-shipping-choice'),(473226,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-right-radius','0','','','.w-catalog-paging'),(473227,'furniture-mobile','.p-blog-index .avatar','border-top-right-radius','50','','','.p-blog-index'),(473228,'furniture-mobile','.w-sale .left-count-days','border-top-right-radius','3','','','.w-sale'),(473229,'furniture-mobile','.p-blog-index .avatar','border-top-right-radius','50','','','.p-blog-index'),(473230,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-right-radius','25','','','.b-switch'),(473232,'furniture-mobile','.w-sale .left-count','border-top-right-radius','3','','','.w-sale'),(473233,'furniture-mobile','.w-sale .badge','border-top-right-radius','50','','','.w-sale'),(473234,'furniture-mobile','.w-sale .left-count','border-top-right-radius','3','','','.w-sale'),(473235,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-top-right-radius','50','3','','.b-switch'),(473236,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','border-top-right-radius','15','','','.b-fancybox'),(473237,'furniture-mobile','.b-fancybox .fancybox-skin','border-top-right-radius','4','','','.b-fancybox'),(473238,'furniture-mobile','.w-sale .badge','border-top-right-radius','50','','','.w-sale'),(473240,'furniture-mobile','.w-sale .left-count-hours','border-top-right-radius','3','','','.w-sale'),(473241,'furniture-mobile','.w-sale .left-count-days','border-top-right-radius','3','','','.w-sale'),(473242,'furniture-mobile','.w-sale .left-count','border-top-right-radius','3','','','.w-sale'),(473244,'furniture-mobile','.w-sale .left-count','border-top-right-radius','3','','','.w-sale'),(473245,'furniture-mobile','.w-sale .badge','border-top-right-radius','50','','','.w-sale'),(473250,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-right-radius','15','4','','.b-switch'),(473251,'furniture-mobile','.w-sale .left-count-days','border-top-right-radius','3','','','.w-sale'),(473252,'furniture-mobile','.b-fancybox .fancybox-nav span','border-top-right-radius','50','','','.b-fancybox'),(473253,'furniture-mobile','.w-product-customers-activity .close','border-top-right-radius','50','','','.w-product-customers-activity'),(473254,'furniture-mobile','.w-product-customers-activity .customers-activity','border-top-right-radius','10','','','.w-product-customers-activity'),(473255,'furniture-mobile','.w-sale .left-count-hours','border-top-right-radius','3','','','.w-sale'),(473256,'furniture-mobile','.w-sale .badge','border-top-right-radius','50','','','.w-sale'),(473257,'furniture-mobile','.w-sale .left-count-hours','border-top-right-radius','3','','','.w-sale'),(473258,'furniture-mobile','.p-blog-index .avatar','border-top-right-radius','50','','','.p-blog-index'),(473259,'furniture-mobile','.w-sale .badge','border-top-right-radius','50','','','.w-sale'),(473260,'furniture-mobile','.w-sale .left-count-hours','border-top-right-radius','3','','','.w-sale'),(473261,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.b-data-table'),(473262,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.b-data-table'),(473263,'furniture-mobile','.b-products-listing .promos-info .promo-name','border-top-right-radius','8','','','.b-products-listing'),(473264,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border-top-right-radius','0','','','.w-blog-widget-related-posts'),(473265,'furniture-mobile','.w-sale .left-count-days','border-top-right-radius','3','','','.w-sale'),(473266,'furniture-mobile','.w-personal-gift-status-bar .progress-bar-content','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(473267,'furniture-mobile','.p-blog-index .avatar','border-top-right-radius','50','','','.p-blog-index'),(473268,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(473270,'furniture-mobile','.w-sale .left-count-days','border-top-right-radius','3','','','.w-sale'),(473271,'furniture-mobile','.w-sale .left-count-hours','border-top-right-radius','3','','','.w-sale'),(473272,'furniture-mobile','.w-sale .left-count-days','border-top-right-radius','3','','','.w-sale'),(473273,'furniture-mobile','.w-sale .badge','border-top-right-radius','50','','','.w-sale'),(473274,'furniture-mobile','.w-sale .left-count','border-top-right-radius','3','','','.w-sale'),(473275,'furniture-mobile','.w-sale .left-count-hours','border-top-right-radius','3','','','.w-sale'),(473277,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(473279,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-top-right-radius','0','','','.b-product-images'),(473280,'furniture-mobile','.b-trade-approval .steps-bar','border-top-right-radius','18','','','.b-trade-approval'),(473281,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-right-radius','10','','','.batchPr'),(473282,'furniture-mobile','.batchPr .checkbox input + span','border-top-right-radius','18','','','.batchPr'),(473283,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border-top-right-radius','0','','','.batchPr'),(473284,'furniture-mobile','.batchPr .btn-batch-remove','border-top-right-radius','100','','','.batchPr'),(473285,'furniture-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-right-radius','3','','','.w-delivery-day'),(473286,'furniture-mobile','.w-delivery-day .left-count','border-top-right-radius','3','','','.w-delivery-day'),(473287,'furniture-mobile','.w-cart .cart-box-link','border-top-right-radius','50','3','','.w-cart'),(473288,'furniture-mobile','.w-account .my-acc-link','border-top-right-radius','50','3','','.w-account'),(473289,'furniture-mobile','.w-account .account-dropdown','border-top-right-radius','100','3','','.w-account'),(473290,'furniture-mobile','.w-search .search-ico','border-top-right-radius','50','2885,3','','.w-search'),(473291,'furniture-mobile','.menu-header .burger-icon','border-top-right-radius','50','2885','','.menu-header'),(473292,'furniture-mobile','.w-quote .cart-box-link','border-top-right-radius','50','3','','.w-quote'),(473293,'furniture-mobile','.w-product-sale-ends .left-count','border-top-right-radius','3','','','.w-product-sale-ends'),(473294,'furniture-mobile','.w-product-sale-ends .left-count-days','border-top-right-radius','3','','','.w-product-sale-ends'),(473295,'furniture-mobile','.w-product-sale-ends .left-count-hours','border-top-right-radius','3','','','.w-product-sale-ends'),(473296,'furniture-mobile','.w-sample .cart-box-link','border-top-right-radius','50','3','','.w-sample'),(473297,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-right-radius','50','','','.w-questionnaire-widgets-questionnaire'),(473298,'furniture-mobile','.w-sale-category .badge','border-top-right-radius','50','','','.w-sale-category'),(473299,'furniture-mobile','.w-sale-category .left-count','border-top-right-radius','3','','','.w-sale-category'),(473300,'furniture-mobile','.w-sale-category .left-count-days','border-top-right-radius','3','','','.w-sale-category'),(473301,'furniture-mobile','.w-sale-category .left-count-hours','border-top-right-radius','3','','','.w-sale-category'),(473302,'furniture-mobile','.w-product-wedding-registry-button .btn','border-top-right-radius','50','3','','.w-product-wedding-registry-button'),(473303,'furniture-mobile','.w-product-wedding-registry-button .btn','border-top-right-radius','50','4','','.w-product-wedding-registry-button'),(473304,'furniture-mobile','.b-products-listing .productGroup label a','border-top-right-radius','3','','','.b-products-listing'),(473305,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-right-radius','12','','','.w-predefined-promotion'),(473306,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-right-radius','12','','','.w-predefined-promotion'),(473307,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-right-radius','12','','','.w-predefined-promotion'),(473308,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border-top-right-radius','12','','','.w-predefined-promotion'),(473309,'furniture-mobile','.lowestPricedBox .w-banner .ybg','border-top-right-radius','50','3','','.lowestPricedBox'),(473310,'furniture-mobile','.catalog-product-wrap .pn-image','border-top-right-radius','50','3','','.catalog-product-wrap'),(473311,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(473312,'furniture-mobile','.w-communication-new-topic td','border-top-width','1','','','.w-communication-new-topic'),(473314,'furniture-mobile','.b-info div + .info','border-top-width','1','','','.b-info'),(473315,'furniture-mobile','.w-compare-box-item .checkbox + span','border-top-width','1','','','.w-compare-box-item'),(473316,'furniture-mobile','.w-compare-box-item .checkbox + span','border-top-width','1','','','.w-compare-box-item'),(473317,'furniture-mobile','.w-sale .left-text-left','border-top-width','2','','','.w-sale'),(473318,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border-top-width','1','','','.w-promotions'),(473319,'furniture-mobile','.w-search .search-input','border-top-width','1','','','.w-search'),(473320,'furniture-mobile','.w-search .item + .item','border-top-width','1','','','.w-search'),(473321,'furniture-mobile','.w-cart-compare .attributes-block td','border-top-width','1','','','.w-cart-compare'),(473322,'furniture-mobile','.w-account .account-dropdown','border-top-width','1','','','.w-account'),(473323,'furniture-mobile','.p-reviews-info .review-info-text','border-top-width','5','4','','.p-reviews-info'),(473324,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(473325,'furniture-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(473326,'furniture-mobile','.b-email .name','border-top-width','1','','','.b-email'),(473327,'furniture-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(473328,'furniture-mobile','.testimonials .review','border-top-width','7','3','',''),(473329,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-top-width','1','','','.w-compare-box-item'),(473330,'furniture-mobile','.w-compare-box-item .checkbox + span','border-top-width','1','','','.w-compare-box-item'),(473331,'furniture-mobile','.w-promotions .promo-salemaker .discount','border-top-width','1','','','.w-promotions'),(473332,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-width','1','','','.w-promotions'),(473333,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border-top-width','1','','','.w-promotions'),(473334,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-width','2','','','.p-blog-index'),(473335,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(473336,'furniture-mobile','.b-messages .messMenuButtonTop','border-top-width','1','','','.b-messages'),(473337,'furniture-mobile','.b-messages .msv_btn','border-top-width','1','','','.b-messages'),(473338,'furniture-mobile','.b-messages .email-heading','border-top-width','1','','','.b-messages'),(473339,'furniture-mobile','.b-messages .dataTable','border-top-width','1','','','.b-messages'),(473340,'furniture-mobile','.b-messages .messages-menu li + li','border-top-width','1','','','.b-messages'),(473341,'furniture-mobile','.b-messages .content_management_attach button','border-top-width','1','','','.b-messages'),(473342,'furniture-mobile','.b-messages .content_management_attach','border-top-width','1','','','.b-messages'),(473343,'furniture-mobile','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-width','2','','','.b-messages'),(473344,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-top-width','2','','',''),(473345,'furniture-mobile','.w-sale .sale-holder','border-top-width','2','','','.w-sale'),(473346,'furniture-mobile','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(473347,'furniture-mobile','.p-reviews-info .review-info-text','border-top-width','5','4','','.p-reviews-info'),(473348,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border-top-width','2','3','','.b-form'),(473349,'furniture-mobile','.w-socials > li','border-top-width','1','','','.w-socials'),(473350,'furniture-mobile','.p-payer-order-confirmation .input-wrapper','border-top-width','2','','','.p-payer-order-confirmation'),(473351,'furniture-mobile','.p-payer-order-pay .input-wrapper','border-top-width','2','','','.p-payer-order-pay'),(473352,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-width','2','','','.p-blog-index'),(473353,'furniture-mobile','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(473354,'furniture-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(473355,'furniture-mobile','.b-email .price','border-top-width','1','','','.b-email'),(473356,'furniture-mobile','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(473357,'furniture-mobile','.w-sale .sale-holder','border-top-width','2','','','.w-sale'),(473358,'furniture-mobile','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(473360,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(473361,'furniture-mobile','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(473362,'furniture-mobile','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(473363,'furniture-mobile','.b-info div + .info','border-top-width','1','','','.b-info'),(473364,'furniture-mobile','.b-email .model','border-top-width','1','','','.b-email'),(473365,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-top-width','1','','','.w-compare-box-item'),(473366,'furniture-mobile','.w-menu-slider > ul > li > ul','border-top-width','1','','','.w-menu-slider'),(473367,'furniture-mobile','.w-sale .left-text-left','border-top-width','2','','','.w-sale'),(473368,'furniture-mobile','.b-info div + .info','border-top-width','1','','','.b-info'),(473369,'furniture-mobile','.b-email .model','border-top-width','1','','','.b-email'),(473370,'furniture-mobile','.w-sale .sale-holder','border-top-width','2','','','.w-sale'),(473371,'furniture-mobile','.b-email .price','border-top-width','1','','','.b-email'),(473372,'furniture-mobile','.w-menu-slider > ul > li > ul','border-top-width','1','','','.w-menu-slider'),(473373,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-width','2','3','','.b-switch'),(473374,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-width','2','','','.p-blog-index'),(473375,'furniture-mobile','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(473376,'furniture-mobile','.w-filters .ui-slider','border-top-width','0','','','.w-filters'),(473377,'furniture-mobile','.w-filters .ui-slider-handle','border-top-width','0','','','.w-filters'),(473378,'furniture-mobile','.b-email .name','border-top-width','1','','','.b-email'),(473379,'furniture-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(473380,'furniture-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(473381,'furniture-mobile','.w-compare-box-item .checkbox + span','border-top-width','1','','','.w-compare-box-item'),(473382,'furniture-mobile','.w-checkout-shipping-choice span','border-top-width','2','','','.w-checkout-shipping-choice'),(473383,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-top-width','1','','','.w-compare-box-item'),(473384,'furniture-mobile','.w-socials > li','border-top-width','1','','','.w-socials'),(473385,'furniture-mobile','.w-search .button-search','border-top-width','0','','','.w-search'),(473386,'furniture-mobile','.w-cart-compare .product-block td','border-top-width','1','','','.w-cart-compare'),(473387,'furniture-mobile','.b-info-popup .info-popup div','border-top-width','1','','','.b-info-popup'),(473388,'furniture-mobile','.p-reviews-info .review-info-text','border-top-width','5','4','','.p-reviews-info'),(473389,'furniture-mobile','.w-wedding-registry-widgets-products .rating','border-top-width','1','','','.w-wedding-registry-widgets-products'),(473390,'furniture-mobile','.w-sale .left-text-left','border-top-width','2','','','.w-sale'),(473393,'furniture-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(473394,'furniture-mobile','.w-socials > li','border-top-width','1','','','.w-socials'),(473395,'furniture-mobile','.b-bottom .popup-buttons','border-top-width','1','','','.b-bottom'),(473396,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(473397,'furniture-mobile','.totals-line','border-top-width','1','','',''),(473398,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','border-top-width','1','','','.w-wedding-registry-widgets-photos'),(473399,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-width','4','','','.b-switch'),(473400,'furniture-mobile','.b-email .name','border-top-width','1','','','.b-email'),(473401,'furniture-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(473402,'furniture-mobile','.b-email .name','border-top-width','1','','','.b-email'),(473403,'furniture-mobile','.order-summary .price-row + .price-row','border-top-width','1','','','.order-summary'),(473404,'furniture-mobile','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(473405,'furniture-mobile','.w-menu .hided.menu ul li','border-top-width','1','2885','','.w-menu'),(473406,'furniture-mobile','.w-sale .left-text-right','border-top-width','2','','','.w-sale'),(473407,'furniture-mobile','.w-sale .left-text-right','border-top-width','2','','','.w-sale'),(473408,'furniture-mobile','.w-sale .left-text-left','border-top-width','2','','','.w-sale'),(473409,'furniture-mobile','.w-reviews .review','border-top-width','8','3','','.w-reviews'),(473410,'furniture-mobile','.w-menu .hided.menu ul li','border-top-width','1','2885','','.w-menu'),(473411,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-width','3','','','.b-switch'),(473412,'furniture-mobile','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(473413,'furniture-mobile','.b-email .image','border-top-width','1','','','.b-email'),(473414,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-top-width','1','','','.w-compare-box-item'),(473415,'furniture-mobile','.w-sale .sale-holder','border-top-width','2','','','.w-sale'),(473416,'furniture-mobile','.b-email .image','border-top-width','1','','','.b-email'),(473417,'furniture-mobile','.b-email .model','border-top-width','1','','','.b-email'),(473418,'furniture-mobile','.w-socials > li','border-top-width','1','','','.w-socials'),(473419,'furniture-mobile','.b-email .image','border-top-width','1','','','.b-email'),(473420,'furniture-mobile','.b-email .price','border-top-width','1','','','.b-email'),(473421,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(473422,'furniture-mobile','.b-email .name','border-top-width','1','','','.b-email'),(473423,'furniture-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(473424,'furniture-mobile','.b-email .model','border-top-width','1','','','.b-email'),(473425,'furniture-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(473426,'furniture-mobile','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(473427,'furniture-mobile','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(473428,'furniture-mobile','.b-form .shipping-method .item + .item','border-top-width','1','','','.b-form'),(473429,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(473430,'furniture-mobile','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(473431,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','border-top-width','2','','','.b-select-suggest'),(473433,'furniture-mobile','.view-all','border-top-width','1','3','',''),(473434,'furniture-mobile','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(473435,'furniture-mobile','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(473436,'furniture-mobile','textarea','border-top-width','2','','',''),(473437,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-width','2','4','','.b-switch'),(473438,'furniture-mobile','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(473439,'furniture-mobile','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(473440,'furniture-mobile','.w-languages .select','border-top-width','1','','','.w-languages'),(473441,'furniture-mobile','.w-sale .left-text-left','border-top-width','2','','','.w-sale'),(473442,'furniture-mobile','.w-sale .left-text-right','border-top-width','2','','','.w-sale'),(473443,'furniture-mobile','.w-cart-compare .cart-cell > div','border-top-width','1','','','.w-cart-compare'),(473444,'furniture-mobile','.w-menu .hided.menu ul li','border-top-width','1','2885','','.w-menu'),(473445,'furniture-mobile','.b-info div + .info','border-top-width','1','','','.b-info'),(473446,'furniture-mobile','.b-form .form-buttons','border-top-width','1','','','.b-form'),(473447,'furniture-mobile','.b-form .required-error','border-top-width','1','','','.b-form'),(473448,'furniture-mobile','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(473449,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-top-width','1','','','.w-compare-box-item'),(473450,'furniture-mobile','.p-reviews-info .review-info-text','border-top-width','5','4','','.p-reviews-info'),(473451,'furniture-mobile','.p-reviews-info .review-info-text','border-top-width','5','4','','.p-reviews-info'),(473454,'furniture-mobile','.b-info div + .info','border-top-width','1','','','.b-info'),(473455,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(473456,'furniture-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(473457,'furniture-mobile','.w-menu .hided.menu ul li','border-top-width','1','2885','','.w-menu'),(473458,'furniture-mobile','.w-sale .sale-holder','border-top-width','2','','','.w-sale'),(473459,'furniture-mobile','.w-sale .left-text-right','border-top-width','2','','','.w-sale'),(473460,'furniture-mobile','.w-compare-box-item .checkbox + span','border-top-width','1','','','.w-compare-box-item'),(473463,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-width','2','','','.p-blog-index'),(473465,'furniture-mobile','.b-email .model','border-top-width','1','','','.b-email'),(473466,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-top-width','1','','','.b-bottom'),(473468,'furniture-mobile','.b-email .model','border-top-width','1','','','.b-email'),(473469,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(473470,'furniture-mobile','.b-upload-files .upload-files','border-top-width','1','','','.b-upload-files'),(473471,'furniture-mobile','.b-upload-files .added-file','border-top-width','1','','','.b-upload-files'),(473472,'furniture-mobile','.b-bottom .popup-box','border-top-width','1','','','.b-bottom'),(473473,'furniture-mobile','.b-email .image','border-top-width','1','','','.b-email'),(473474,'furniture-mobile','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(473475,'furniture-mobile','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(473478,'furniture-mobile','.w-product-customers-activity .customers-activity','border-top-width','1','','','.w-product-customers-activity'),(473479,'furniture-mobile','.b-form .privacy-row','border-top-width','1','','','.b-form'),(473480,'furniture-mobile','.w-reviews-content .review','border-top-width','8','3','','.w-reviews-content'),(473481,'furniture-mobile','.w-cart-compare .price-block td','border-top-width','1','','','.w-cart-compare'),(473482,'furniture-mobile','.w-compare-box-item .checkbox + span','border-top-width','1','','','.w-compare-box-item'),(473483,'furniture-mobile','.w-compare-box-item .checkbox:checked + span','border-top-width','1','','','.w-compare-box-item'),(473486,'furniture-mobile','.w-socials > li','border-top-width','1','','','.w-socials'),(473487,'furniture-mobile','.w-product-reviews .reviews-list .review','border-top-width','7','3','','.w-product-reviews'),(473488,'furniture-mobile','.b-upload-file .upload-file-template','border-top-width','1','','','.b-upload-file'),(473489,'furniture-mobile','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(473490,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(473491,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-width','1','','','.b-select-suggest'),(473493,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(473494,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-width','1','','','.b-select-suggest'),(473495,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','border-top-width','1','','','.b-select-suggest'),(473496,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-width','1','','','.b-select-suggest'),(473497,'furniture-mobile','.b-select-suggest .select2-search input','border-top-width','1','','','.b-select-suggest'),(473498,'furniture-mobile','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-width','1','','','.b-select-suggest'),(473499,'furniture-mobile','.b-select-suggest .select2-drop.select2-drop-above','border-top-width','1','','','.b-select-suggest'),(473500,'furniture-mobile','.b-select-suggest .select2-drop-active','border-top-width','1','','','.b-select-suggest'),(473501,'furniture-mobile','.b-select-suggest .select2-drop-auto-width','border-top-width','1','','','.b-select-suggest'),(473502,'furniture-mobile','.w-menu-slider > ul > li > ul','border-top-width','1','','','.w-menu-slider'),(473503,'furniture-mobile','.w-socials > li','border-top-width','1','','','.w-socials'),(473504,'furniture-mobile','.w-menu-slider > ul > li > ul','border-top-width','1','','','.w-menu-slider'),(473505,'furniture-mobile','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(473506,'furniture-mobile','.w-account .acc-bottom','border-top-width','1','','','.w-account'),(473507,'furniture-mobile','.b-form .payment-method .item + .item','border-top-width','1','','','.b-form'),(473508,'furniture-mobile','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(473509,'furniture-mobile','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(473510,'furniture-mobile','.w-menu .hided.menu ul li','border-top-width','1','2885','','.w-menu'),(473511,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-top-width','1','','','.b-bottom'),(473512,'furniture-mobile','.w-communication-post .communication-post','border-top-width','1','','','.w-communication-post'),(473513,'furniture-mobile','.checkbox input:checked + span','border-top-width','1','','',''),(473514,'furniture-mobile','.checkbox input + span','border-top-width','1','','',''),(473515,'furniture-mobile','.b-autocomplete .ui-autocomplete','border-top-width','1','','','.b-autocomplete'),(473516,'furniture-mobile','.w-currencies .select','border-top-width','1','','','.w-currencies'),(473517,'furniture-mobile','.w-currencies .currencies-title','border-top-width','2','','','.w-currencies'),(473518,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(473520,'furniture-mobile','.b-info-popup .info-popup div','border-top-width','1','3','','.b-info-popup'),(473522,'furniture-mobile','.b-info div + .info','border-top-width','1','','','.b-info'),(473523,'furniture-mobile','.b-email .price','border-top-width','1','','','.b-email'),(473524,'furniture-mobile','.w-menu-slider > ul > li > ul','border-top-width','1','','','.w-menu-slider'),(473525,'furniture-mobile','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(473526,'furniture-mobile','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(473527,'furniture-mobile','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(473528,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','border-top-width','1','','','.w-wedding-registry-widgets-photos'),(473530,'furniture-mobile','.b-email .image','border-top-width','1','','','.b-email'),(473531,'furniture-mobile','.w-sale .left-text-right','border-top-width','2','','','.w-sale'),(473532,'furniture-mobile','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(473533,'furniture-mobile','.b-email .price','border-top-width','1','','','.b-email'),(473534,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(473535,'furniture-mobile','.w-menu .hided.menu ul li','border-top-width','1','2885','','.w-menu'),(473536,'furniture-mobile','.w-sale .left-text-left','border-top-width','2','','','.w-sale'),(473537,'furniture-mobile','.w-sale .left-text-right','border-top-width','2','','','.w-sale'),(473538,'furniture-mobile','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(473539,'furniture-mobile','.w-sale .sale-holder','border-top-width','2','','','.w-sale'),(473540,'furniture-mobile','.w-checkout-shipping .sub-item + .sub-item','border-top-width','1','','','.w-checkout-shipping'),(473542,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-width','2','','','.p-blog-index'),(473543,'furniture-mobile','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(473544,'furniture-mobile','.w-cart-listing .item .gift-wrap label','border-top-width','1','','','.w-cart-listing'),(473545,'furniture-mobile','.w-cart-listing .item','border-top-width','1','2885','','.w-cart-listing'),(473546,'furniture-mobile','.w-cart .cart-content','border-top-width','1','','','.w-cart'),(473547,'furniture-mobile','.w-menu-slider > ul > li > ul','border-top-width','1','','','.w-menu-slider'),(473548,'furniture-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(473549,'furniture-mobile','.b-email .image','border-top-width','1','','','.b-email'),(473550,'furniture-mobile','.b-email .price','border-top-width','1','','','.b-email'),(473551,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(473552,'furniture-mobile','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(473553,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','border-top-width','2','','','.p-blog-index'),(473554,'furniture-mobile','.w-filters .ui-slider-range','border-top-width','0','','','.w-filters'),(473555,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(473556,'furniture-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(473557,'furniture-mobile','.b-email .name','border-top-width','1','','','.b-email'),(473560,'furniture-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(473561,'furniture-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(473562,'furniture-mobile','.b-data-table table.dataTable tbody td','border-top-width','1','','','.b-data-table'),(473563,'furniture-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-width','1','','','.b-compare'),(473564,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(473565,'furniture-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(473566,'furniture-mobile','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(473569,'furniture-mobile','.b-email .totals-table','border-top-width','1','','','.b-email'),(473570,'furniture-mobile','.b-email .qty','border-top-width','1','','','.b-email'),(473571,'furniture-mobile','.b-upload-file .snapshot','border-top-width','1','','','.b-upload-file'),(473572,'furniture-mobile','.p-reviews-info .review-info-text','border-top-width','5','4','','.p-reviews-info'),(473573,'furniture-mobile','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-top-width','2','','','.b-product-images'),(473574,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-top-width','1','','','.b-menu-style-2'),(473575,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-top-width','3','','','.b-menu-style-2'),(473576,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','border-top-width','1','','','.b-menu-style-2'),(473577,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-top-width','1','','','.b-menu-style-2'),(473578,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-top-width','3','','','.b-menu-style-2'),(473579,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-width','2','','','.b-trade-approval'),(473580,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border-top-width','1','','','.batchPr'),(473581,'furniture-mobile','.batchPr .checkbox input + span','border-top-width','1','','','.batchPr'),(473582,'furniture-mobile','.batchPr .checkbox input + span','border-top-width','1','','','.batchPr'),(473583,'furniture-mobile','.batchPr .checkbox input:checked + span','border-top-width','1','','','.batchPr'),(473584,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .item + .item','border-top-width','1','','','.batchPr'),(473585,'furniture-mobile','.batchPr .w-batch-selected-products','border-top-width','1','','','.batchPr'),(473586,'furniture-mobile','.w-account-personal-catalog .list-switcher a','border-top-width','3','2','','.w-account-personal-catalog'),(473587,'furniture-mobile','.w-account-subscription .subscription-variant + .subscription-variant','border-top-width','1','','','.w-account-subscription'),(473588,'furniture-mobile','.w-catalog-compare .compare .checkbox input:checked + span','border-top-width','1','','','.w-catalog-compare'),(473589,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','border-top-width','3','2','','.w-catalog-compare'),(473590,'furniture-mobile','.w-delivery-day .left-text-left','border-top-width','2','','','.w-delivery-day'),(473591,'furniture-mobile','.w-delivery-day .left-text-right','border-top-width','2','','','.w-delivery-day'),(473592,'furniture-mobile','.b-slick .slick-vertical .slick-slide','border-top-width','1','','','.b-slick'),(473593,'furniture-mobile','.b-products-listing .products-listing .compare input + span','border-top-width','1','','','.b-products-listing'),(473594,'furniture-mobile','.w-filters .filter-widget','border-top-width','1','','','.w-filters'),(473595,'furniture-mobile','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-top-width','0','','','.w-filters'),(473596,'furniture-mobile','.b-products-listing .products-listing.list-rows .item:first-of-type .BlockBox.item-holder','border-top-width','0','','','.b-products-listing'),(473597,'furniture-mobile','.w-quote .cart-content','border-top-width','1','','','.w-quote'),(473598,'furniture-mobile','.b-product-images .additional-images .active img','border-top-width','2','','','.b-product-images'),(473599,'furniture-mobile','.b-product-images .additional-images img','border-top-width','2','','','.b-product-images'),(473600,'furniture-mobile','.b-quantity .qty-box .bigger','border-top-width','2','','','.b-quantity'),(473601,'furniture-mobile','.b-quantity .qty-box .smaller','border-top-width','2','','','.b-quantity'),(473602,'furniture-mobile','.w-product-sale-ends .left-text-left','border-top-width','2','','','.w-product-sale-ends'),(473603,'furniture-mobile','.w-product-sale-ends .left-text-right','border-top-width','2','','','.w-product-sale-ends'),(473604,'furniture-mobile','.w-files-catalog-widgets-files-list .item + .item','border-top-width','1','','','.w-files-catalog-widgets-files-list'),(473605,'furniture-mobile','.w-sample .cart-content','border-top-width','1','','','.w-sample'),(473606,'furniture-mobile','.w-cart-listing .points-earn','border-top-width','17','4','','.w-cart-listing'),(473607,'furniture-mobile','.w-cart-discount-coupon .btn','border-top-width','2','','','.w-cart-discount-coupon'),(473608,'furniture-mobile','.w-product-video .item img, .w-product-video .item video','border-top-width','2','','','.w-product-video'),(473609,'furniture-mobile','.w-product-video .item.active img, .w-product-video .item.active video','border-top-width','2','','','.w-product-video'),(473610,'furniture-mobile','.w-cart-order-reference .btn','border-top-width','2','','','.w-cart-order-reference'),(473611,'furniture-mobile','.w-cart-gift-certificate .btn','border-top-width','2','','','.w-cart-gift-certificate'),(473612,'furniture-mobile','.w-cart-shipping-estimator .btn','border-top-width','2','','','.w-cart-shipping-estimator'),(473613,'furniture-mobile','.w-product-bundle .bundle_item:nth-child(3) ~ .bundle_item','border-top-width','1','','','.w-product-bundle'),(473614,'furniture-mobile','.w-product-bundle .bundle-total-price','border-top-width','1','','','.w-product-bundle'),(473615,'furniture-mobile','.w-product-bundle .bundle_item:nth-child(2) ~ .bundle_item','border-top-width','1','2885','','.w-product-bundle'),(473616,'furniture-mobile','.w-product-bundle .bundle_item:nth-child(1) ~ .bundle_item','border-top-width','1','2876','','.w-product-bundle'),(473617,'furniture-mobile','.w-product-in-bundles .bundle-total-price','border-top-width','1','','','.w-product-in-bundles'),(473618,'furniture-mobile','.w-product-in-bundles .bundle_item:nth-child(3) ~ .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(473619,'furniture-mobile','.w-product-in-bundles .bundle_item:nth-child(2) ~ .bundle_item','border-top-width','1','2885','','.w-product-in-bundles'),(473620,'furniture-mobile','.w-product-in-bundles .bundle_item:nth-child(1) ~ .bundle_item','border-top-width','1','2876','','.w-product-in-bundles'),(473621,'furniture-mobile','.w-account-address-book .item','border-top-width','1','','','.w-account-address-book'),(473622,'furniture-mobile','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-top-width','1','','','.b-pagination'),(473623,'furniture-mobile','.b-pagination .pagination .next-pages','border-top-width','1','','','.b-pagination'),(473624,'furniture-mobile','.b-pagination .pagination .page-number','border-top-width','1','','','.b-pagination'),(473625,'furniture-mobile','.b-pagination .pagination .prev-pages','border-top-width','1','','','.b-pagination'),(473626,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-top-width','1','','','.b-pagination'),(473627,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-top-width','1','','','.b-pagination'),(473628,'furniture-mobile','.b-pagination .pagination span','border-top-width','1','2','','.b-pagination'),(473629,'furniture-mobile','.w-product-quantity-discounts .item + .item + .item','border-top-width','1','','','.w-product-quantity-discounts'),(473630,'furniture-mobile','.w-product-quantity-discounts .item + .item','border-top-width','1','2885','','.w-product-quantity-discounts'),(473631,'furniture-mobile','.w-tabs .tab-li','border-top-width','3','2','','.w-tabs'),(473632,'furniture-mobile','.w-account-order-download tr + tr','border-top-width','1','','','.w-account-order-download'),(473633,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','border-top-width','2','','','.w-product-multi-inventory'),(473634,'furniture-mobile','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-top-width','2','','','.w-product-multi-inventory'),(473635,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-top-width','1','','','.w-account-personal-catalog'),(473636,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','border-top-width','1','','','.w-account-personal-catalog'),(473637,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','border-top-width','2','','','.b-products-listing'),(473638,'furniture-mobile','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-top-width','2','','','.b-products-listing'),(473639,'furniture-mobile','.w-product-collection .choose-products','border-top-width','1','','','.w-product-collection'),(473640,'furniture-mobile','.w-account-customer-additional-field .tf-file + .tf-file','border-top-width','1','','','.w-account-customer-additional-field'),(473641,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','border-top-width','2','','','.w-product-attributes'),(473642,'furniture-mobile','.w-product-attributes .radio-attributes input:checked + .option-item','border-top-width','2','','','.w-product-attributes'),(473643,'furniture-mobile','.w-questionnaire-widgets-questionnaire .question + .question','border-top-width','1','','','.w-questionnaire-widgets-questionnaire'),(473644,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-width','2','','','.w-questionnaire-widgets-questionnaire'),(473645,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-top-width','2','','','.w-questionnaire-widgets-questionnaire'),(473646,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-top-width','2','','','.w-questionnaire-widgets-questionnaire'),(473647,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-top-width','2','1','','.w-questionnaire-widgets-questionnaire'),(473648,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-top-width','2','1','','.w-questionnaire-widgets-questionnaire'),(473649,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','border-top-width','2','','','.w-product-groups'),(473650,'furniture-mobile','.w-product-groups .radioBox label .containerBlock.selected','border-top-width','2','','','.w-product-groups'),(473651,'furniture-mobile','.w-product-groups .radioBox label input:checked + .containerBlock','border-top-width','2','','','.w-product-groups'),(473652,'furniture-mobile','.w-product-custom-bundle .choose-products','border-top-width','1','','','.w-product-custom-bundle'),(473653,'furniture-mobile','.w-product-custom-bundle .right-area .price','border-top-width','1','2885','','.w-product-custom-bundle'),(473654,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-top-width','2','','','.w-delivery-location-location-list'),(473655,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','border-top-width','2','1','','.w-delivery-location-location-list'),(473656,'furniture-mobile','.w-sale-category .left-text-left','border-top-width','2','','','.w-sale-category'),(473657,'furniture-mobile','.w-sale-category .left-text-right','border-top-width','2','','','.w-sale-category'),(473658,'furniture-mobile','.w-sale-category .sale-holder','border-top-width','2','','','.w-sale-category'),(473659,'furniture-mobile','.w-wedding-registry-widgets-photos .upload-file-template','border-top-width','1','','','.w-wedding-registry-widgets-photos'),(473660,'furniture-mobile','.w-product-wedding-registry-button .btn','border-top-width','2','3','','.w-product-wedding-registry-button'),(473661,'furniture-mobile','.w-product-wedding-registry-button .btn','border-top-width','2','4','','.w-product-wedding-registry-button'),(473662,'furniture-mobile','.w-delivery-location-list-by-page .item','border-top-width','1','','','.w-delivery-location-list-by-page'),(473663,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-top-width','1','','','.w-product-properties-icons'),(473664,'furniture-mobile','.w-delivery-location-cross-pages .item','border-top-width','1','','','.w-delivery-location-cross-pages'),(473665,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','border-top-width','1','','','.w-wedding-registry-widgets-search-paging'),(473666,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','border-top-width','1','','','.w-wedding-registry-widgets-search-paging'),(473667,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','border-top-width','1','','','.w-wedding-registry-widgets-search-paging'),(473668,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','border-top-width','1','','','.w-wedding-registry-widgets-search-paging'),(473669,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','border-top-width','1','','','.w-product-designer-designer'),(473670,'furniture-mobile','.w-press-reviews-widgets-press-reviews .press-reviews-button','border-top-width','1','','','.w-press-reviews-widgets-press-reviews'),(473671,'furniture-mobile','.b-products-listing .productGroup label a','border-top-width','1','','','.b-products-listing'),(473672,'furniture-mobile','.w-support-system-listing .support-head','border-top-width','1','','','.w-support-system-listing'),(473673,'furniture-mobile','.w-support-system-listing .product_icon','border-top-width','1','','','.w-support-system-listing'),(473674,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-width','1','','','.w-predefined-promotion'),(473675,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-width','1','','','.w-predefined-promotion'),(473676,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-width','1','','','.w-predefined-promotion'),(473677,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border-top-width','1','','','.w-predefined-promotion'),(473678,'furniture-mobile','.w-supplier-purchase-supplier-products .item','border-top-width','1','','','.w-supplier-purchase-supplier-products'),(473679,'furniture-mobile','.mainBanner .bottomBox .btn','border-top-width','0.21','','','.mainBanner'),(473680,'furniture-mobile','.mainBanner .topBox > .right','border-top-width','23','4','','.mainBanner'),(473681,'furniture-mobile','.mainBanner .bottomBox .btn','border-top-width','2','2890','','.mainBanner'),(473682,'furniture-mobile','.mainBanner .topBox > .right','border-top-width','20','2890,4','','.mainBanner'),(473683,'furniture-mobile','.mainBanner .bottomBox .btn','border-top-width','3','2876','','.mainBanner'),(473684,'furniture-mobile','.mainBanner .topBox > .right','border-top-width','15','2876,4','','.mainBanner'),(473685,'furniture-mobile','.mainBanner .bottomBox .btn','border-top-width','2','2906','','.mainBanner'),(473686,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','border-top-width','2','','','.lowestPricedBox'),(473687,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-top-width','2','','','.shopByCollectionBox'),(473688,'furniture-mobile','.shopByCollectionBox .bannerButton a','border-top-width','2','2890','','.shopByCollectionBox'),(473689,'furniture-mobile','.w-search .products','border-top-width','1','','','.w-search'),(473690,'furniture-mobile','.account-order-history .orders-table .item','border-top-width','1','2885','','.account-order-history'),(473691,'furniture-mobile','.account-order-history .orders-table .td-alignright','border-top-width','1','2885','','.account-order-history'),(473692,'furniture-mobile','.account-index .orders-table .item','border-top-width','1','2885','','.account-index'),(473693,'furniture-mobile','.account-index .orders-table .links','border-top-width','1','2885','','.account-index'),(473694,'furniture-mobile','.account-samples .orders-table .item','border-top-width','1','2885','','.account-samples'),(473695,'furniture-mobile','.account-samples .orders-table .td-alignright','border-top-width','1','2885','','.account-samples'),(473696,'furniture-mobile','.catalog-product-wrap .pn-image','border-top-width','2','3','','.catalog-product-wrap'),(473697,'furniture-mobile','.catalog-product-wrap .pn-image','border-top-width','1','','','.catalog-product-wrap'),(473698,'furniture-mobile','.catalog-product-wrap .pn-name','border-top-width','1','','','.catalog-product-wrap'),(473699,'furniture-mobile','.catalog-product-wrap .prev-next-product','border-top-width','1','','','.catalog-product-wrap'),(473700,'furniture-mobile','.shopping-cart-index .btn-3','border-top-width','2','','','.shopping-cart-index'),(473701,'furniture-mobile','.checkout-index-wrap .input-wrapper','border-top-width','2','','','.checkout-index-wrap'),(473702,'furniture-mobile','.mainBanner .bottomBox .btn','border_bottom_width_measure','vw','','','.mainBanner'),(473703,'furniture-mobile','.b-autocomplete .ui-autocomplete li','border_important','important','','','.b-autocomplete'),(473704,'furniture-mobile','.b-data-table table.dataTable thead td','border_important','important','','','.b-data-table'),(473705,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','border_important','important','','','.w-rma-returns-history'),(473706,'furniture-mobile','.mainBanner .bottomBox .btn','border_left_width_measure','vw','','','.mainBanner'),(473708,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_1_measure','px','4','','.b-switch'),(473709,'furniture-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(473710,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.p-quick-order-index'),(473711,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.p-quick-order-index'),(473712,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_1_measure','px','','','.w-promotions'),(473713,'furniture-mobile','.w-sale .left-count','border_radius_1_measure','px','','','.w-sale'),(473714,'furniture-mobile','.w-promotions .promo-salemaker .discount','border_radius_1_measure','px','','','.w-promotions'),(473715,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_1_measure','px','','','.w-promotions'),(473716,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_1_measure','px','','','.w-promotions'),(473717,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_1_measure','px','','','.b-messages'),(473718,'furniture-mobile','.w-sale .left-count-days','border_radius_1_measure','px','','','.w-sale'),(473719,'furniture-mobile','.p-blog-index .avatar','border_radius_1_measure','%','','','.p-blog-index'),(473722,'furniture-mobile','.b-fancybox .fancybox-close','border_radius_1_measure','%','','','.b-fancybox'),(473723,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_1_measure','px','','','.b-switch'),(473724,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_1_measure','px','3','','.b-switch'),(473726,'furniture-mobile','.w-sale .left-count-days','border_radius_1_measure','px','','','.w-sale'),(473727,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_1_measure','px','3','','.b-switch'),(473729,'furniture-mobile','.b-switch .bootstrap-switch','border_radius_1_measure','px','','','.b-switch'),(473730,'furniture-mobile','.p-blog-index .avatar','border_radius_1_measure','%','','','.p-blog-index'),(473731,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_1_measure','px','','','.b-switch'),(473732,'furniture-mobile','.p-blog-index .avatar','border_radius_1_measure','%','','','.p-blog-index'),(473734,'furniture-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(473735,'furniture-mobile','.w-sale .left-count','border_radius_1_measure','px','','','.w-sale'),(473736,'furniture-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(473737,'furniture-mobile','.p-blog-index .avatar','border_radius_1_measure','%','','','.p-blog-index'),(473738,'furniture-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(473739,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_1_measure','px','','','.w-catalog-paging'),(473740,'furniture-mobile','.w-sale .badge','border_radius_1_measure','%','','','.w-sale'),(473742,'furniture-mobile','.p-blog-index .avatar','border_radius_1_measure','%','','','.p-blog-index'),(473743,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_1_measure','px','','','.b-switch'),(473744,'furniture-mobile','.w-sale .left-count-hours','border_radius_1_measure','px','','','.w-sale'),(473745,'furniture-mobile','.w-sale .badge','border_radius_1_measure','%','','','.w-sale'),(473746,'furniture-mobile','.w-sale .left-count-hours','border_radius_1_measure','px','','','.w-sale'),(473747,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_1_measure','%','3','','.b-switch'),(473748,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_1_measure','px','','','.b-fancybox'),(473749,'furniture-mobile','.b-fancybox .fancybox-skin','border_radius_1_measure','px','','','.b-fancybox'),(473750,'furniture-mobile','.w-sale .badge','border_radius_1_measure','%','','','.w-sale'),(473752,'furniture-mobile','.w-sale .left-count-days','border_radius_1_measure','px','','','.w-sale'),(473753,'furniture-mobile','.w-sale .left-count','border_radius_1_measure','px','','','.w-sale'),(473754,'furniture-mobile','.w-sale .left-count-hours','border_radius_1_measure','px','','','.w-sale'),(473755,'furniture-mobile','.w-sale .left-count-hours','border_radius_1_measure','px','','','.w-sale'),(473756,'furniture-mobile','.w-sale .left-count','border_radius_1_measure','px','','','.w-sale'),(473757,'furniture-mobile','.w-sale .left-count-days','border_radius_1_measure','px','','','.w-sale'),(473759,'furniture-mobile','.b-fancybox .fancybox-nav span','border_radius_1_measure','%','','','.b-fancybox'),(473760,'furniture-mobile','.w-product-customers-activity .close','border_radius_1_measure','%','','','.w-product-customers-activity'),(473761,'furniture-mobile','.w-product-customers-activity .customers-activity','border_radius_1_measure','px','','','.w-product-customers-activity'),(473762,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_1_measure','px','4','','.b-switch'),(473763,'furniture-mobile','.w-sale .left-count-days','border_radius_1_measure','px','','','.w-sale'),(473764,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.b-data-table'),(473765,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.b-data-table'),(473766,'furniture-mobile','.b-products-listing .promos-info .promo-name','border_radius_1_measure','px','','','.b-products-listing'),(473767,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_1_measure','px','','','.w-blog-widget-related-posts'),(473768,'furniture-mobile','.w-sale .badge','border_radius_1_measure','%','','','.w-sale'),(473769,'furniture-mobile','.w-sale .left-count','border_radius_1_measure','px','','','.w-sale'),(473770,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(473772,'furniture-mobile','.w-sale .left-count-hours','border_radius_1_measure','px','','','.w-sale'),(473773,'furniture-mobile','.w-sale .badge','border_radius_1_measure','%','','','.w-sale'),(473774,'furniture-mobile','.w-sale .left-count-hours','border_radius_1_measure','px','','','.w-sale'),(473775,'furniture-mobile','.w-sale .badge','border_radius_1_measure','%','','','.w-sale'),(473776,'furniture-mobile','.w-sale .left-count','border_radius_1_measure','px','','','.w-sale'),(473777,'furniture-mobile','.w-sale .left-count-days','border_radius_1_measure','px','','','.w-sale'),(473778,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_1_measure','%','3','','.b-form'),(473780,'furniture-mobile','.b-upload-file .snapshot','border_radius_1_measure','%','','','.b-upload-file'),(473781,'furniture-mobile','.p-blog-index .avatar','border_radius_1_measure','%','','','.p-blog-index'),(473783,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(473784,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_1_measure','px','','','.b-product-images'),(473785,'furniture-mobile','.b-trade-approval .steps-bar','border_radius_1_measure','px','','','.b-trade-approval'),(473786,'furniture-mobile','.batchPr .checkbox input + span','border_radius_1_measure','px','','','.batchPr'),(473787,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_1_measure','px','','','.batchPr'),(473788,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_1_measure','px','','','.batchPr'),(473789,'furniture-mobile','.batchPr .btn-batch-remove','border_radius_1_measure','%','','','.batchPr'),(473790,'furniture-mobile','.w-delivery-day .left-count','border_radius_1_measure','px','','','.w-delivery-day'),(473791,'furniture-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_1_measure','px','','','.w-delivery-day'),(473792,'furniture-mobile','.w-cart .cart-box-link','border_radius_1_measure','%','3','','.w-cart'),(473793,'furniture-mobile','.w-account .my-acc-link','border_radius_1_measure','%','3','','.w-account'),(473794,'furniture-mobile','.w-account .account-dropdown','border_radius_1_measure','%','3','','.w-account'),(473795,'furniture-mobile','.w-search .search-ico','border_radius_1_measure','%','2885,3','','.w-search'),(473796,'furniture-mobile','.menu-header .burger-icon','border_radius_1_measure','%','2885','','.menu-header'),(473797,'furniture-mobile','.w-quote .cart-box-link','border_radius_1_measure','%','3','','.w-quote'),(473798,'furniture-mobile','.w-product-sale-ends .left-count','border_radius_1_measure','px','','','.w-product-sale-ends'),(473799,'furniture-mobile','.w-product-sale-ends .left-count-days','border_radius_1_measure','px','','','.w-product-sale-ends'),(473800,'furniture-mobile','.w-product-sale-ends .left-count-hours','border_radius_1_measure','px','','','.w-product-sale-ends'),(473801,'furniture-mobile','.w-sample .cart-box-link','border_radius_1_measure','%','3','','.w-sample'),(473802,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_1_measure','%','','','.w-questionnaire-widgets-questionnaire'),(473803,'furniture-mobile','.w-sale-category .badge','border_radius_1_measure','%','','','.w-sale-category'),(473804,'furniture-mobile','.w-sale-category .left-count','border_radius_1_measure','px','','','.w-sale-category'),(473805,'furniture-mobile','.w-sale-category .left-count-days','border_radius_1_measure','px','','','.w-sale-category'),(473806,'furniture-mobile','.w-sale-category .left-count-hours','border_radius_1_measure','px','','','.w-sale-category'),(473807,'furniture-mobile','.w-product-wedding-registry-button .btn','border_radius_1_measure','%','3','','.w-product-wedding-registry-button'),(473808,'furniture-mobile','.w-product-wedding-registry-button .btn','border_radius_1_measure','%','4','','.w-product-wedding-registry-button'),(473809,'furniture-mobile','.b-products-listing .productGroup label a','border_radius_1_measure','px','','','.b-products-listing'),(473810,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_1_measure','px','','','.w-predefined-promotion'),(473811,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_1_measure','px','','','.w-predefined-promotion'),(473812,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_1_measure','px','','','.w-predefined-promotion'),(473813,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border_radius_1_measure','px','','','.w-predefined-promotion'),(473814,'furniture-mobile','.lowestPricedBox .w-banner .ybg','border_radius_1_measure','%','3','','.lowestPricedBox'),(473815,'furniture-mobile','.catalog-product-wrap .pn-image','border_radius_1_measure','%','3','','.catalog-product-wrap'),(473817,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_2_measure','px','4','','.b-switch'),(473818,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_2_measure','px','','','.b-switch'),(473819,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.p-quick-order-index'),(473820,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.p-quick-order-index'),(473821,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_2_measure','px','','','.w-promotions'),(473822,'furniture-mobile','.w-sale .left-count-days','border_radius_2_measure','px','','','.w-sale'),(473823,'furniture-mobile','.p-blog-index .avatar','border_radius_2_measure','%','','','.p-blog-index'),(473824,'furniture-mobile','.w-promotions .promo-salemaker .discount','border_radius_2_measure','px','','','.w-promotions'),(473825,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_2_measure','px','','','.w-promotions'),(473826,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_2_measure','px','','','.w-promotions'),(473827,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_2_measure','px','4','','.b-switch'),(473828,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_2_measure','px','','','.b-messages'),(473829,'furniture-mobile','.w-sale .left-count-hours','border_radius_2_measure','px','','','.w-sale'),(473830,'furniture-mobile','.w-sale .badge','border_radius_2_measure','%','','','.w-sale'),(473831,'furniture-mobile','.p-blog-index .avatar','border_radius_2_measure','%','','','.p-blog-index'),(473832,'furniture-mobile','.b-fancybox .fancybox-close','border_radius_2_measure','%','','','.b-fancybox'),(473833,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_2_measure','px','','','.b-switch'),(473834,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_2_measure','px','3','','.b-switch'),(473836,'furniture-mobile','.b-switch .bootstrap-switch','border_radius_2_measure','px','','','.b-switch'),(473837,'furniture-mobile','.w-sale .left-count-hours','border_radius_2_measure','px','','','.w-sale'),(473838,'furniture-mobile','.w-sale .left-count-days','border_radius_2_measure','px','','','.w-sale'),(473839,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_2_measure','px','3','','.b-switch'),(473840,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_2_measure','px','','','.b-switch'),(473841,'furniture-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(473842,'furniture-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(473843,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_2_measure','px','','','.w-catalog-paging'),(473844,'furniture-mobile','.w-sale .left-count-hours','border_radius_2_measure','px','','','.w-sale'),(473845,'furniture-mobile','.w-sale .left-count-days','border_radius_2_measure','px','','','.w-sale'),(473846,'furniture-mobile','.p-blog-index .avatar','border_radius_2_measure','%','','','.p-blog-index'),(473849,'furniture-mobile','.p-blog-index .avatar','border_radius_2_measure','%','','','.p-blog-index'),(473852,'furniture-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(473853,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_2_measure','%','3','','.b-switch'),(473855,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_2_measure','px','','','.b-fancybox'),(473856,'furniture-mobile','.b-fancybox .fancybox-skin','border_radius_2_measure','px','','','.b-fancybox'),(473857,'furniture-mobile','.w-sale .badge','border_radius_2_measure','%','','','.w-sale'),(473858,'furniture-mobile','.b-upload-file .snapshot','border_radius_2_measure','%','','','.b-upload-file'),(473860,'furniture-mobile','.w-sale .left-count-days','border_radius_2_measure','px','','','.w-sale'),(473861,'furniture-mobile','.w-sale .left-count','border_radius_2_measure','px','','','.w-sale'),(473862,'furniture-mobile','.w-sale .left-count-hours','border_radius_2_measure','px','','','.w-sale'),(473864,'furniture-mobile','.w-sale .left-count-hours','border_radius_2_measure','px','','','.w-sale'),(473865,'furniture-mobile','.w-sale .left-count','border_radius_2_measure','px','','','.w-sale'),(473866,'furniture-mobile','.w-sale .badge','border_radius_2_measure','%','','','.w-sale'),(473867,'furniture-mobile','.w-sale .badge','border_radius_2_measure','%','','','.w-sale'),(473869,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_2_measure','%','3','','.b-form'),(473871,'furniture-mobile','.b-fancybox .fancybox-nav span','border_radius_2_measure','%','','','.b-fancybox'),(473872,'furniture-mobile','.w-product-customers-activity .close','border_radius_2_measure','%','','','.w-product-customers-activity'),(473873,'furniture-mobile','.w-product-customers-activity .customers-activity','border_radius_2_measure','px','','','.w-product-customers-activity'),(473874,'furniture-mobile','.w-sale .left-count','border_radius_2_measure','px','','','.w-sale'),(473875,'furniture-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(473876,'furniture-mobile','.p-blog-index .avatar','border_radius_2_measure','%','','','.p-blog-index'),(473877,'furniture-mobile','.p-blog-index .avatar','border_radius_2_measure','%','','','.p-blog-index'),(473878,'furniture-mobile','.w-sale .left-count-days','border_radius_2_measure','px','','','.w-sale'),(473879,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.b-data-table'),(473880,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.b-data-table'),(473881,'furniture-mobile','.b-products-listing .promos-info .promo-name','border_radius_2_measure','px','','','.b-products-listing'),(473882,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_2_measure','px','','','.w-blog-widget-related-posts'),(473883,'furniture-mobile','.w-sale .left-count','border_radius_2_measure','px','','','.w-sale'),(473884,'furniture-mobile','.w-sale .badge','border_radius_2_measure','%','','','.w-sale'),(473885,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(473886,'furniture-mobile','.w-sale .left-count-days','border_radius_2_measure','px','','','.w-sale'),(473887,'furniture-mobile','.w-sale .left-count-hours','border_radius_2_measure','px','','','.w-sale'),(473888,'furniture-mobile','.w-sale .badge','border_radius_2_measure','%','','','.w-sale'),(473889,'furniture-mobile','.w-sale .left-count','border_radius_2_measure','px','','','.w-sale'),(473890,'furniture-mobile','.w-sale .left-count','border_radius_2_measure','px','','','.w-sale'),(473892,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(473893,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_2_measure','px','','','.b-product-images'),(473894,'furniture-mobile','.b-trade-approval .steps-bar','border_radius_2_measure','px','','','.b-trade-approval'),(473895,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_2_measure','px','','','.batchPr'),(473896,'furniture-mobile','.batchPr .checkbox input + span','border_radius_2_measure','px','','','.batchPr'),(473897,'furniture-mobile','.batchPr .btn-batch-remove','border_radius_2_measure','%','','','.batchPr'),(473898,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_2_measure','px','','','.batchPr'),(473899,'furniture-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_2_measure','px','','','.w-delivery-day'),(473900,'furniture-mobile','.w-delivery-day .left-count','border_radius_2_measure','px','','','.w-delivery-day'),(473901,'furniture-mobile','.w-cart .cart-box-link','border_radius_2_measure','%','3','','.w-cart'),(473902,'furniture-mobile','.w-account .my-acc-link','border_radius_2_measure','%','3','','.w-account'),(473903,'furniture-mobile','.w-account .account-dropdown','border_radius_2_measure','%','3','','.w-account'),(473904,'furniture-mobile','.w-search .search-ico','border_radius_2_measure','%','2885,3','','.w-search'),(473905,'furniture-mobile','.menu-header .burger-icon','border_radius_2_measure','%','2885','','.menu-header'),(473906,'furniture-mobile','.w-quote .cart-box-link','border_radius_2_measure','%','3','','.w-quote'),(473907,'furniture-mobile','.w-product-sale-ends .left-count','border_radius_2_measure','px','','','.w-product-sale-ends'),(473908,'furniture-mobile','.w-product-sale-ends .left-count-days','border_radius_2_measure','px','','','.w-product-sale-ends'),(473909,'furniture-mobile','.w-product-sale-ends .left-count-hours','border_radius_2_measure','px','','','.w-product-sale-ends'),(473910,'furniture-mobile','.w-sample .cart-box-link','border_radius_2_measure','%','3','','.w-sample'),(473911,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_2_measure','%','','','.w-questionnaire-widgets-questionnaire'),(473912,'furniture-mobile','.w-sale-category .badge','border_radius_2_measure','%','','','.w-sale-category'),(473913,'furniture-mobile','.w-sale-category .left-count','border_radius_2_measure','px','','','.w-sale-category'),(473914,'furniture-mobile','.w-sale-category .left-count-days','border_radius_2_measure','px','','','.w-sale-category'),(473915,'furniture-mobile','.w-sale-category .left-count-hours','border_radius_2_measure','px','','','.w-sale-category'),(473916,'furniture-mobile','.w-product-wedding-registry-button .btn','border_radius_2_measure','%','3','','.w-product-wedding-registry-button'),(473917,'furniture-mobile','.w-product-wedding-registry-button .btn','border_radius_2_measure','%','4','','.w-product-wedding-registry-button'),(473918,'furniture-mobile','.b-products-listing .productGroup label a','border_radius_2_measure','px','','','.b-products-listing'),(473919,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_2_measure','px','','','.w-predefined-promotion'),(473920,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_2_measure','px','','','.w-predefined-promotion'),(473921,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_2_measure','px','','','.w-predefined-promotion'),(473922,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border_radius_2_measure','px','','','.w-predefined-promotion'),(473923,'furniture-mobile','.lowestPricedBox .w-banner .ybg','border_radius_2_measure','%','3','','.lowestPricedBox'),(473924,'furniture-mobile','.catalog-product-wrap .pn-image','border_radius_2_measure','%','3','','.catalog-product-wrap'),(473925,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_3_measure','px','4','','.b-switch'),(473926,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_3_measure','px','4','','.b-switch'),(473929,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.p-quick-order-index'),(473930,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_3_measure','px','','','.w-promotions'),(473931,'furniture-mobile','.w-sale .badge','border_radius_3_measure','%','','','.w-sale'),(473932,'furniture-mobile','.w-sale .left-count-hours','border_radius_3_measure','px','','','.w-sale'),(473933,'furniture-mobile','.w-promotions .promo-salemaker .discount','border_radius_3_measure','px','','','.w-promotions'),(473934,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_3_measure','px','','','.w-promotions'),(473935,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_3_measure','px','','','.w-promotions'),(473936,'furniture-mobile','.p-blog-index .avatar','border_radius_3_measure','%','','','.p-blog-index'),(473937,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_3_measure','px','','','.b-messages'),(473938,'furniture-mobile','.p-blog-index .avatar','border_radius_3_measure','%','','','.p-blog-index'),(473939,'furniture-mobile','.b-fancybox .fancybox-close','border_radius_3_measure','%','','','.b-fancybox'),(473940,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_3_measure','px','','','.b-switch'),(473941,'furniture-mobile','.w-sale .badge','border_radius_3_measure','%','','','.w-sale'),(473943,'furniture-mobile','.w-sale .left-count','border_radius_3_measure','px','','','.w-sale'),(473944,'furniture-mobile','.w-sale .left-count-hours','border_radius_3_measure','px','','','.w-sale'),(473945,'furniture-mobile','.w-sale .left-count-days','border_radius_3_measure','px','','','.w-sale'),(473946,'furniture-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(473947,'furniture-mobile','.p-blog-index .avatar','border_radius_3_measure','%','','','.p-blog-index'),(473949,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_3_measure','px','3','','.b-switch'),(473950,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_3_measure','px','','','.b-switch'),(473951,'furniture-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(473952,'furniture-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(473953,'furniture-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(473955,'furniture-mobile','.w-sale .left-count-days','border_radius_3_measure','px','','','.w-sale'),(473956,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_3_measure','%','3','','.b-form'),(473957,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_3_measure','px','3','','.b-switch'),(473959,'furniture-mobile','.w-sale .left-count-hours','border_radius_3_measure','px','','','.w-sale'),(473960,'furniture-mobile','.p-blog-index .avatar','border_radius_3_measure','%','','','.p-blog-index'),(473961,'furniture-mobile','.w-sale .left-count-hours','border_radius_3_measure','px','','','.w-sale'),(473962,'furniture-mobile','.p-blog-index .avatar','border_radius_3_measure','%','','','.p-blog-index'),(473963,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_3_measure','px','','','.b-fancybox'),(473964,'furniture-mobile','.b-fancybox .fancybox-skin','border_radius_3_measure','px','','','.b-fancybox'),(473965,'furniture-mobile','.w-sale .badge','border_radius_3_measure','%','','','.w-sale'),(473967,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_3_measure','%','3','','.b-switch'),(473968,'furniture-mobile','.w-sale .left-count','border_radius_3_measure','px','','','.w-sale'),(473969,'furniture-mobile','.w-sale .left-count-hours','border_radius_3_measure','px','','','.w-sale'),(473970,'furniture-mobile','.w-sale .left-count-days','border_radius_3_measure','px','','','.w-sale'),(473972,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.p-quick-order-index'),(473973,'furniture-mobile','.w-sale .left-count','border_radius_3_measure','px','','','.w-sale'),(473975,'furniture-mobile','.w-sale .left-count','border_radius_3_measure','px','','','.w-sale'),(473976,'furniture-mobile','.b-fancybox .fancybox-nav span','border_radius_3_measure','%','','','.b-fancybox'),(473977,'furniture-mobile','.w-product-customers-activity .close','border_radius_3_measure','%','','','.w-product-customers-activity'),(473978,'furniture-mobile','.w-product-customers-activity .customers-activity','border_radius_3_measure','px','','','.w-product-customers-activity'),(473979,'furniture-mobile','.w-sale .left-count-days','border_radius_3_measure','px','','','.w-sale'),(473980,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(473981,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.b-data-table'),(473982,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.b-data-table'),(473983,'furniture-mobile','.b-products-listing .promos-info .promo-name','border_radius_3_measure','px','','','.b-products-listing'),(473984,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_3_measure','px','','','.w-blog-widget-related-posts'),(473985,'furniture-mobile','.b-upload-file .snapshot','border_radius_3_measure','%','','','.b-upload-file'),(473987,'furniture-mobile','.w-sale .left-count','border_radius_3_measure','px','','','.w-sale'),(473988,'furniture-mobile','.w-sale .badge','border_radius_3_measure','%','','','.w-sale'),(473989,'furniture-mobile','.w-sale .left-count-days','border_radius_3_measure','px','','','.w-sale'),(473990,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(473992,'furniture-mobile','.w-sale .left-count-hours','border_radius_3_measure','px','','','.w-sale'),(473993,'furniture-mobile','.w-sale .left-count-days','border_radius_3_measure','px','','','.w-sale'),(473994,'furniture-mobile','.w-sale .left-count','border_radius_3_measure','px','','','.w-sale'),(473995,'furniture-mobile','.w-sale .badge','border_radius_3_measure','%','','','.w-sale'),(473996,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_3_measure','px','','','.w-catalog-paging'),(473997,'furniture-mobile','.w-sale .badge','border_radius_3_measure','%','','','.w-sale'),(473999,'furniture-mobile','.b-switch .bootstrap-switch','border_radius_3_measure','px','','','.b-switch'),(474000,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_3_measure','px','','','.b-switch'),(474001,'furniture-mobile','.p-blog-index .avatar','border_radius_3_measure','%','','','.p-blog-index'),(474002,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_3_measure','px','','','.b-product-images'),(474003,'furniture-mobile','.b-trade-approval .steps-bar','border_radius_3_measure','px','','','.b-trade-approval'),(474004,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_3_measure','px','','','.batchPr'),(474005,'furniture-mobile','.batchPr .checkbox input + span','border_radius_3_measure','px','','','.batchPr'),(474006,'furniture-mobile','.batchPr .btn-batch-remove','border_radius_3_measure','%','','','.batchPr'),(474007,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_3_measure','px','','','.batchPr'),(474008,'furniture-mobile','.w-delivery-day .left-count','border_radius_3_measure','px','','','.w-delivery-day'),(474009,'furniture-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_3_measure','px','','','.w-delivery-day'),(474010,'furniture-mobile','.w-cart .cart-box-link','border_radius_3_measure','%','3','','.w-cart'),(474011,'furniture-mobile','.w-account .my-acc-link','border_radius_3_measure','%','3','','.w-account'),(474012,'furniture-mobile','.w-account .account-dropdown','border_radius_3_measure','%','3','','.w-account'),(474013,'furniture-mobile','.w-search .search-ico','border_radius_3_measure','%','2885,3','','.w-search'),(474014,'furniture-mobile','.menu-header .burger-icon','border_radius_3_measure','%','2885','','.menu-header'),(474015,'furniture-mobile','.w-quote .cart-box-link','border_radius_3_measure','%','3','','.w-quote'),(474016,'furniture-mobile','.w-product-sale-ends .left-count','border_radius_3_measure','px','','','.w-product-sale-ends'),(474017,'furniture-mobile','.w-product-sale-ends .left-count-days','border_radius_3_measure','px','','','.w-product-sale-ends'),(474018,'furniture-mobile','.w-product-sale-ends .left-count-hours','border_radius_3_measure','px','','','.w-product-sale-ends'),(474019,'furniture-mobile','.w-sample .cart-box-link','border_radius_3_measure','%','3','','.w-sample'),(474020,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_3_measure','%','','','.w-questionnaire-widgets-questionnaire'),(474021,'furniture-mobile','.w-sale-category .badge','border_radius_3_measure','%','','','.w-sale-category'),(474022,'furniture-mobile','.w-sale-category .left-count','border_radius_3_measure','px','','','.w-sale-category'),(474023,'furniture-mobile','.w-sale-category .left-count-days','border_radius_3_measure','px','','','.w-sale-category'),(474024,'furniture-mobile','.w-sale-category .left-count-hours','border_radius_3_measure','px','','','.w-sale-category'),(474025,'furniture-mobile','.w-product-wedding-registry-button .btn','border_radius_3_measure','%','3','','.w-product-wedding-registry-button'),(474026,'furniture-mobile','.w-product-wedding-registry-button .btn','border_radius_3_measure','%','4','','.w-product-wedding-registry-button'),(474027,'furniture-mobile','.b-products-listing .productGroup label a','border_radius_3_measure','px','','','.b-products-listing'),(474028,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_3_measure','px','','','.w-predefined-promotion'),(474029,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_3_measure','px','','','.w-predefined-promotion'),(474030,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_3_measure','px','','','.w-predefined-promotion'),(474031,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border_radius_3_measure','px','','','.w-predefined-promotion'),(474032,'furniture-mobile','.lowestPricedBox .w-banner .ybg','border_radius_3_measure','%','3','','.lowestPricedBox'),(474033,'furniture-mobile','.catalog-product-wrap .pn-image','border_radius_3_measure','%','3','','.catalog-product-wrap'),(474035,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_4_measure','px','4','','.b-switch'),(474036,'furniture-mobile','.b-upload-file .snapshot','border_radius_4_measure','%','','','.b-upload-file'),(474037,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.p-quick-order-index'),(474038,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','border_radius_4_measure','px','','','.w-promotions'),(474039,'furniture-mobile','.w-promotions .promo-salemaker .discount','border_radius_4_measure','px','','','.w-promotions'),(474040,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_4_measure','px','','','.w-promotions'),(474041,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.p-quick-order-index'),(474042,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_4_measure','px','','','.w-promotions'),(474043,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_4_measure','px','','','.b-messages'),(474044,'furniture-mobile','.p-blog-index .avatar','border_radius_4_measure','%','','','.p-blog-index'),(474045,'furniture-mobile','.p-blog-index .avatar','border_radius_4_measure','%','','','.p-blog-index'),(474046,'furniture-mobile','.b-fancybox .fancybox-close','border_radius_4_measure','%','','','.b-fancybox'),(474047,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_4_measure','px','','','.b-switch'),(474050,'furniture-mobile','.w-sale .left-count-hours','border_radius_4_measure','px','','','.w-sale'),(474051,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_4_measure','px','3','','.b-switch'),(474052,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_4_measure','px','','','.b-switch'),(474053,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(474054,'furniture-mobile','.w-checkout-shipping-choice label:last-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(474055,'furniture-mobile','.w-checkout-shipping-choice label:first-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(474056,'furniture-mobile','.w-sale .left-count-days','border_radius_4_measure','px','','','.w-sale'),(474058,'furniture-mobile','.p-blog-index .avatar','border_radius_4_measure','%','','','.p-blog-index'),(474060,'furniture-mobile','.w-sale .badge','border_radius_4_measure','%','','','.w-sale'),(474061,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_4_measure','px','4','','.b-switch'),(474062,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_4_measure','px','3','','.b-switch'),(474063,'furniture-mobile','.w-sale .left-count','border_radius_4_measure','px','','','.w-sale'),(474064,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','border_radius_4_measure','px','','','.b-fancybox'),(474065,'furniture-mobile','.w-sale .badge','border_radius_4_measure','%','','','.w-sale'),(474066,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_4_measure','%','3','','.b-form'),(474067,'furniture-mobile','.w-personal-gift-status-bar .progress-bar-content','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(474068,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_4_measure','%','3','','.b-switch'),(474069,'furniture-mobile','.w-sale .left-count-hours','border_radius_4_measure','px','','','.w-sale'),(474070,'furniture-mobile','.w-sale .left-count','border_radius_4_measure','px','','','.w-sale'),(474071,'furniture-mobile','.w-sale .left-count-days','border_radius_4_measure','px','','','.w-sale'),(474072,'furniture-mobile','.w-sale .left-count-hours','border_radius_4_measure','px','','','.w-sale'),(474073,'furniture-mobile','.w-sale .left-count-days','border_radius_4_measure','px','','','.w-sale'),(474074,'furniture-mobile','.w-sale .badge','border_radius_4_measure','%','','','.w-sale'),(474075,'furniture-mobile','.w-sale .left-count-hours','border_radius_4_measure','px','','','.w-sale'),(474078,'furniture-mobile','.w-sale .left-count-days','border_radius_4_measure','px','','','.w-sale'),(474079,'furniture-mobile','.w-personal-gift-status-bar .progress-bar','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(474080,'furniture-mobile','.b-fancybox .fancybox-nav span','border_radius_4_measure','%','','','.b-fancybox'),(474081,'furniture-mobile','.w-product-customers-activity .customers-activity','border_radius_4_measure','px','','','.w-product-customers-activity'),(474082,'furniture-mobile','.w-product-customers-activity .close','border_radius_4_measure','%','','','.w-product-customers-activity'),(474083,'furniture-mobile','.w-sale .left-count-hours','border_radius_4_measure','px','','','.w-sale'),(474084,'furniture-mobile','.w-sale .left-count-days','border_radius_4_measure','px','','','.w-sale'),(474085,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(474086,'furniture-mobile','.p-blog-index .avatar','border_radius_4_measure','%','','','.p-blog-index'),(474089,'furniture-mobile','.w-sale .left-count','border_radius_4_measure','px','','','.w-sale'),(474090,'furniture-mobile','.w-sale .badge','border_radius_4_measure','%','','','.w-sale'),(474091,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.b-data-table'),(474092,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.b-data-table'),(474093,'furniture-mobile','.b-products-listing .promos-info .promo-name','border_radius_4_measure','px','','','.b-products-listing'),(474094,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','border_radius_4_measure','px','','','.w-blog-widget-related-posts'),(474095,'furniture-mobile','.w-sale .badge','border_radius_4_measure','%','','','.w-sale'),(474096,'furniture-mobile','.w-sale .left-count','border_radius_4_measure','px','','','.w-sale'),(474097,'furniture-mobile','.b-fancybox .fancybox-skin','border_radius_4_measure','px','','','.b-fancybox'),(474099,'furniture-mobile','.w-sale .left-count-hours','border_radius_4_measure','px','','','.w-sale'),(474100,'furniture-mobile','.w-sale .left-count-days','border_radius_4_measure','px','','','.w-sale'),(474101,'furniture-mobile','.w-sale .badge','border_radius_4_measure','%','','','.w-sale'),(474102,'furniture-mobile','.w-sale .left-count','border_radius_4_measure','px','','','.w-sale'),(474104,'furniture-mobile','.w-sale .left-count','border_radius_4_measure','px','','','.w-sale'),(474105,'furniture-mobile','.p-blog-index .avatar','border_radius_4_measure','%','','','.p-blog-index'),(474106,'furniture-mobile','.p-blog-index .avatar','border_radius_4_measure','%','','','.p-blog-index'),(474107,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_4_measure','px','','','.w-catalog-paging'),(474109,'furniture-mobile','.b-switch .bootstrap-switch','border_radius_4_measure','px','','','.b-switch'),(474110,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_4_measure','px','','','.b-switch'),(474111,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_4_measure','px','','','.b-product-images'),(474112,'furniture-mobile','.b-trade-approval .steps-bar','border_radius_4_measure','px','','','.b-trade-approval'),(474113,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','border_radius_4_measure','px','','','.batchPr'),(474114,'furniture-mobile','.batchPr .checkbox input + span','border_radius_4_measure','px','','','.batchPr'),(474115,'furniture-mobile','.batchPr .btn-batch-remove','border_radius_4_measure','%','','','.batchPr'),(474116,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','border_radius_4_measure','px','','','.batchPr'),(474117,'furniture-mobile','.w-delivery-day .left-count','border_radius_4_measure','px','','','.w-delivery-day'),(474118,'furniture-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_4_measure','px','','','.w-delivery-day'),(474119,'furniture-mobile','.w-cart .cart-box-link','border_radius_4_measure','%','3','','.w-cart'),(474120,'furniture-mobile','.w-account .my-acc-link','border_radius_4_measure','%','3','','.w-account'),(474121,'furniture-mobile','.w-account .account-dropdown','border_radius_4_measure','%','3','','.w-account'),(474122,'furniture-mobile','.w-search .search-ico','border_radius_4_measure','%','2885,3','','.w-search'),(474123,'furniture-mobile','.menu-header .burger-icon','border_radius_4_measure','%','2885','','.menu-header'),(474124,'furniture-mobile','.w-quote .cart-box-link','border_radius_4_measure','%','3','','.w-quote'),(474125,'furniture-mobile','.w-product-sale-ends .left-count','border_radius_4_measure','px','','','.w-product-sale-ends'),(474126,'furniture-mobile','.w-product-sale-ends .left-count-days','border_radius_4_measure','px','','','.w-product-sale-ends'),(474127,'furniture-mobile','.w-product-sale-ends .left-count-hours','border_radius_4_measure','px','','','.w-product-sale-ends'),(474128,'furniture-mobile','.w-sample .cart-box-link','border_radius_4_measure','%','3','','.w-sample'),(474129,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_4_measure','%','','','.w-questionnaire-widgets-questionnaire'),(474130,'furniture-mobile','.w-sale-category .badge','border_radius_4_measure','%','','','.w-sale-category'),(474131,'furniture-mobile','.w-sale-category .left-count','border_radius_4_measure','px','','','.w-sale-category'),(474132,'furniture-mobile','.w-sale-category .left-count-days','border_radius_4_measure','px','','','.w-sale-category'),(474133,'furniture-mobile','.w-sale-category .left-count-hours','border_radius_4_measure','px','','','.w-sale-category'),(474134,'furniture-mobile','.w-product-wedding-registry-button .btn','border_radius_4_measure','%','3','','.w-product-wedding-registry-button'),(474135,'furniture-mobile','.w-product-wedding-registry-button .btn','border_radius_4_measure','%','4','','.w-product-wedding-registry-button'),(474136,'furniture-mobile','.b-products-listing .productGroup label a','border_radius_4_measure','px','','','.b-products-listing'),(474137,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_4_measure','px','','','.w-predefined-promotion'),(474138,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_4_measure','px','','','.w-predefined-promotion'),(474139,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_4_measure','px','','','.w-predefined-promotion'),(474140,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','border_radius_4_measure','px','','','.w-predefined-promotion'),(474141,'furniture-mobile','.lowestPricedBox .w-banner .ybg','border_radius_4_measure','%','3','','.lowestPricedBox'),(474142,'furniture-mobile','.catalog-product-wrap .pn-image','border_radius_4_measure','%','3','','.catalog-product-wrap'),(474143,'furniture-mobile','.mainBanner .bottomBox .btn','border_right_width_measure','vw','','','.mainBanner'),(474144,'furniture-mobile','.mainBanner .bottomBox .btn','border_top_width_measure','vw','','','.mainBanner'),(474145,'furniture-mobile','.p-reviews-info .review-info-text','bottom','-10','4','','.p-reviews-info'),(474146,'furniture-mobile','.testimonials .review','bottom','-13','3','',''),(474147,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','bottom','-7','','','.w-checkout-shipping-choice'),(474148,'furniture-mobile','.b-fancybox .fancybox-title-over-wrap','bottom','0','','','.b-fancybox'),(474149,'furniture-mobile','.b-info-popup .info-popup.top-left div','bottom','30','','','.b-info-popup'),(474150,'furniture-mobile','.b-info-popup .info-popup.top-left div','bottom','-11','3','','.b-info-popup'),(474151,'furniture-mobile','.b-upload-file .snapshot','bottom','5','','','.b-upload-file'),(474152,'furniture-mobile','.w-product-reviews .reviews-list .review','bottom','-13','3','','.w-product-reviews'),(474153,'furniture-mobile','.b-fancybox .fancybox-overlay-fixed','bottom','0','','','.b-fancybox'),(474154,'furniture-mobile','.w-banner .image-text-banner.bottom-center .text-banner','bottom','0','','','.w-banner'),(474155,'furniture-mobile','.w-banner .image-text-banner.bottom-left .text-banner','bottom','0','','','.w-banner'),(474156,'furniture-mobile','.w-banner .image-text-banner.bottom-right .text-banner','bottom','0','','','.w-banner'),(474157,'furniture-mobile','.p-reviews-info .review-info-text','bottom','-10','4','','.p-reviews-info'),(474158,'furniture-mobile','.p-reviews-info .review-info-text','bottom','-10','4','','.p-reviews-info'),(474159,'furniture-mobile','.p-reviews-info .review-info-text','bottom','-10','4','','.p-reviews-info'),(474160,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','bottom','0','','','.b-switch'),(474161,'furniture-mobile','.w-product-customers-activity .customers-activity','bottom','0','','','.w-product-customers-activity'),(474162,'furniture-mobile','.w-product-customers-activity .customers-activity.closed','bottom','-1000','','','.w-product-customers-activity'),(474163,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','bottom','0','','','.b-switch'),(474164,'furniture-mobile','.p-reviews-info .review-info-text','bottom','-10','4','','.p-reviews-info'),(474165,'furniture-mobile','.w-catalog-b2b-add-button ','bottom','0','','','.w-catalog-b2b-add-button'),(474166,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap','bottom','0','','','.b-fancybox'),(474167,'furniture-mobile','.p-quick-order-index .all-scroll-div','bottom','0','','','.p-quick-order-index'),(474168,'furniture-mobile','.w-cart-listing .item .remove','bottom','0','2885','','.w-cart-listing'),(474169,'furniture-mobile','.p-reviews-info .review-info-text','bottom','-10','4','','.p-reviews-info'),(474170,'furniture-mobile','.b-product-images .mp-shadow, .b-product-images .media-popup','bottom','0','','','.b-product-images'),(474171,'furniture-mobile','.b-slick .slick-vertical button.slick-next','bottom','0','','','.b-slick'),(474172,'furniture-mobile','.b-slick .slick-vertical button.slick-prev','bottom','auto','','','.b-slick'),(474173,'furniture-mobile','.w-compare ','bottom','0','','','.w-compare'),(474174,'furniture-mobile','.w-compare .remove','bottom','10','','','.w-compare'),(474175,'furniture-mobile','.w-search .background','bottom','0','','','.w-search'),(474176,'furniture-mobile','.w-search .opened','bottom','0','3','','.w-search'),(474177,'furniture-mobile','.w-search .suggest','bottom','0','4','','.w-search'),(474178,'furniture-mobile','.account-order-history .orders-table .order-total','bottom','45','2885','','.account-order-history'),(474179,'furniture-mobile','.account-order-history .orders-table .status-name','bottom','7','2885','','.account-order-history'),(474180,'furniture-mobile','.account-order-history .orders-table .td-alignright','bottom','0','2885','','.account-order-history'),(474181,'furniture-mobile','.account-index .orders-table .links','bottom','0','2885','','.account-index'),(474182,'furniture-mobile','.account-index .orders-table .price','bottom','7','2885','','.account-index'),(474183,'furniture-mobile','.account-samples .orders-table .order-total','bottom','45','2885','','.account-samples'),(474184,'furniture-mobile','.account-samples .orders-table .status-name','bottom','7','2885','','.account-samples'),(474185,'furniture-mobile','.account-samples .orders-table .td-alignright','bottom','0','2885','','.account-samples'),(474186,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(474187,'furniture-mobile','.w-menu .hided.menu ul ul','box-shadow','none','','','.w-menu'),(474189,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(474191,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(474193,'furniture-mobile','.w-menu .hided.menu ul ul','box-shadow','none','','','.w-menu'),(474194,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(474195,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(474196,'furniture-mobile','.b-fancybox .fancybox-opened .fancybox-skin','box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(474197,'furniture-mobile','.w-menu .hided.menu ul ul','box-shadow','none','','','.w-menu'),(474198,'furniture-mobile','.w-menu .hided.menu ul ul','box-shadow','none','','','.w-menu'),(474199,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(474201,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','box-shadow','0 0 4px rgba(75,75,75,0.5)','3','','.b-switch'),(474203,'furniture-mobile','.w-menu .hided.menu ul ul','box-shadow','none','','','.w-menu'),(474204,'furniture-mobile','.w-menu .hided.menu ul ul','box-shadow','none','','','.w-menu'),(474206,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','box-shadow','none','','','.batchPr'),(474207,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','box-shadow','none','','','.batchPr'),(474208,'furniture-mobile','.w-catalog-compare .compare-fix-bar.fix-bar-fix','box-shadow','0 10px 10px -10px #cccccc','','','.w-catalog-compare'),(474209,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item:hover .item-wrapper','box-shadow','0 0 20px rgb(0 0 0 / 15%)','','','.b-products-listing'),(474210,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','box-shadow','0 10px 10px rgb(0 0 0 / 15%)','','','.b-products-listing'),(474211,'furniture-mobile','.w-search .suggest','box-shadow','0 5px 15px 5px rgba(0,0,0,.5)','','','.w-search'),(474212,'furniture-mobile','.b-fancybox .filter-listing-loader','box-sizing','content-box','','','.b-fancybox'),(474213,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','box-sizing','border-box','','','.b-switch'),(474214,'furniture-mobile','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','box-sizing','border-box','','','.b-select-suggest'),(474215,'furniture-mobile','.b-slick .slick-slider','box-sizing','border-box','','','.b-slick'),(474216,'furniture-mobile','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(474217,'furniture-mobile','.w-support-system-listing .support-head','box-sizing','border-box','','','.w-support-system-listing'),(474218,'furniture-mobile','.b-info-popup .info-popup div','box_shadow_blur','10','','','.b-info-popup'),(474219,'furniture-mobile','.w-product-customers-activity .customers-activity','box_shadow_blur','20','','','.w-product-customers-activity'),(474220,'furniture-mobile','.b-datepicker .datepicker-dropdown','box_shadow_blur','10','','','.b-datepicker'),(474221,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur','5','','','.w-image-maps'),(474222,'furniture-mobile','.w-compare ','box_shadow_blur','20','','','.w-compare'),(474223,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_blur','10','','','.w-product-properties-icons'),(474224,'furniture-mobile','.b-info-popup .info-popup div','box_shadow_blur_measure','px','','','.b-info-popup'),(474225,'furniture-mobile','.b-datepicker .datepicker-dropdown','box_shadow_blur_measure','px','','','.b-datepicker'),(474226,'furniture-mobile','.w-product-customers-activity .customers-activity','box_shadow_blur_measure','px','','','.w-product-customers-activity'),(474227,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur_measure','px','','','.w-image-maps'),(474228,'furniture-mobile','.w-compare ','box_shadow_blur_measure','px','','','.w-compare'),(474229,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_blur_measure','px','','','.w-product-properties-icons'),(474230,'furniture-mobile','.b-info-popup .info-popup div','box_shadow_color','#ccc','','','.b-info-popup'),(474231,'furniture-mobile','.b-datepicker .datepicker-dropdown','box_shadow_color','#ccc','','','.b-datepicker'),(474232,'furniture-mobile','.w-product-customers-activity .customers-activity','box_shadow_color','#eee','','','.w-product-customers-activity'),(474233,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_color','#ccc','','','.w-image-maps'),(474234,'furniture-mobile','.w-compare ','box_shadow_color','#cccc','','','.w-compare'),(474235,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_color','#bdbdbd','','','.w-product-properties-icons'),(474236,'furniture-mobile','.b-info-popup .info-popup div','box_shadow_left','0','','','.b-info-popup'),(474237,'furniture-mobile','.b-datepicker .datepicker-dropdown','box_shadow_left','0','','','.b-datepicker'),(474238,'furniture-mobile','.w-product-customers-activity .customers-activity','box_shadow_left','0','','','.w-product-customers-activity'),(474239,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left','0','','','.w-image-maps'),(474240,'furniture-mobile','.w-compare ','box_shadow_left','0','','','.w-compare'),(474241,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_left','1','','','.w-product-properties-icons'),(474242,'furniture-mobile','.b-info-popup .info-popup div','box_shadow_left_measure','','','','.b-info-popup'),(474243,'furniture-mobile','.b-datepicker .datepicker-dropdown','box_shadow_left_measure','','','','.b-datepicker'),(474244,'furniture-mobile','.w-product-customers-activity .customers-activity','box_shadow_left_measure','','','','.w-product-customers-activity'),(474245,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left_measure','','','','.w-image-maps'),(474246,'furniture-mobile','.w-compare ','box_shadow_left_measure','','','','.w-compare'),(474247,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_left_measure','px','','','.w-product-properties-icons'),(474248,'furniture-mobile','.b-info-popup .info-popup div','box_shadow_top','0','','','.b-info-popup'),(474249,'furniture-mobile','.w-product-customers-activity .customers-activity','box_shadow_top','0','','','.w-product-customers-activity'),(474250,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top','0','','','.w-image-maps'),(474251,'furniture-mobile','.b-datepicker .datepicker-dropdown','box_shadow_top','0','','','.b-datepicker'),(474252,'furniture-mobile','.w-compare ','box_shadow_top','0','','','.w-compare'),(474253,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_top','1','','','.w-product-properties-icons'),(474254,'furniture-mobile','.b-info-popup .info-popup div','box_shadow_top_measure','','','','.b-info-popup'),(474255,'furniture-mobile','.w-product-customers-activity .customers-activity','box_shadow_top_measure','','','','.w-product-customers-activity'),(474256,'furniture-mobile','.b-datepicker .datepicker-dropdown','box_shadow_top_measure','','','','.b-datepicker'),(474257,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top_measure','','','','.w-image-maps'),(474258,'furniture-mobile','.w-compare ','box_shadow_top_measure','','','','.w-compare'),(474259,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_top_measure','px','','','.w-product-properties-icons'),(474260,'furniture-mobile','.b-form .addresses .address-item:nth-child(2n + 1)','clear','left','','','.b-form'),(474261,'furniture-mobile','.w-checkout-billing-address .btn-cancel','clear','both','','','.w-checkout-billing-address'),(474262,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','clear','both','','','.p-account-trade-form'),(474263,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(474264,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(474265,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(474266,'furniture-mobile','.w-cart a.item','clear','both','4','','.w-cart'),(474267,'furniture-mobile','.b-form .col-full','clear','both','','','.b-form'),(474268,'furniture-mobile','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(474269,'furniture-mobile','.w-account-address-book .button-add','clear','both','','','.w-account-address-book'),(474270,'furniture-mobile','.w-account .account-dropdown','clear','both','4','','.w-account'),(474271,'furniture-mobile','.w-wedding-registry-widgets-search-form .button','clear','both','','','.w-wedding-registry-widgets-search-form'),(474272,'furniture-mobile','.w-promotions .prom-multi-discount','clear','both','4','','.w-promotions'),(474273,'furniture-mobile','.p-blog-index .entry-content','clear','both','4','','.p-blog-index'),(474274,'furniture-mobile','.w-product-available-in-warehouses .content','clear','both','4','','.w-product-available-in-warehouses'),(474275,'furniture-mobile','.b-products-listing .products-listing .mix-attributes','clear','bpth','4','','.b-products-listing'),(474276,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','clear','both','','','.p-account-trade-form'),(474277,'furniture-mobile','.p-account-trade-form .wd-line-row-2','clear','both','4','','.p-account-trade-form'),(474278,'furniture-mobile','.w-cart-compare .product .name','clear','right','','','.w-cart-compare'),(474279,'furniture-mobile','.p-account-trade-form .wd-line-row-2','clear','both','4','','.p-account-trade-form'),(474280,'furniture-mobile','.b-messages .dataTables_wrapper > .top','clear','both','4','','.b-messages'),(474281,'furniture-mobile','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(474282,'furniture-mobile','.b-messages .dataTables_wrapper > .bottom','clear','both','4','','.b-messages'),(474283,'furniture-mobile','.p-blog-index .comment-meta','clear','both','4','','.p-blog-index'),(474284,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','clear','both','','','.p-account-trade-form'),(474285,'furniture-mobile','.b-form .columns','clear','both','4','','.b-form'),(474286,'furniture-mobile','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(474287,'furniture-mobile','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(474288,'furniture-mobile','.p-blog-index .comment-meta','clear','both','4','','.p-blog-index'),(474289,'furniture-mobile','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(474290,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(474291,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','clear','both','','','.p-account-trade-form'),(474292,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(474293,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','clear','left','','','.p-account-trade-form'),(474294,'furniture-mobile','.p-account-trade-form .wd-line-row-2','clear','both','4','','.p-account-trade-form'),(474295,'furniture-mobile','.p-account-trade-form .widget','clear','both','','','.p-account-trade-form'),(474297,'furniture-mobile','.w-login-block .buttons','clear','none','','','.w-login-block'),(474298,'furniture-mobile','.w-login-block .cols','clear','both','4','','.w-login-block'),(474299,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(474300,'furniture-mobile','.w-login-block .guest','clear','right','','','.w-login-block'),(474301,'furniture-mobile','.w-menu-horizontal li','clear','none','','','.w-menu-horizontal'),(474302,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(474303,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(474304,'furniture-mobile','.b-form .col-left','clear','left','','','.b-form'),(474305,'furniture-mobile','.p-blog-index .comment-meta','clear','both','4','','.p-blog-index'),(474306,'furniture-mobile','.p-blog-index .entry-content','clear','both','4','','.p-blog-index'),(474307,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(474308,'furniture-mobile','.w-menu-style-1 li','clear','none','','','.w-menu-style-1'),(474309,'furniture-mobile','.p-account-trade-form .widget','clear','both','','','.p-account-trade-form'),(474310,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','clear','both','','','.p-account-trade-form'),(474311,'furniture-mobile','.buttons','clear','both','','',''),(474312,'furniture-mobile','.buttons','clear','both','4','',''),(474313,'furniture-mobile','.w-cart-give-away .ga_column:nth-child(2n + 1)','clear','both','','','.w-cart-give-away'),(474314,'furniture-mobile','.w-top-categories .categories','clear','both','4','','.w-top-categories'),(474315,'furniture-mobile','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(474316,'furniture-mobile','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(474317,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(474318,'furniture-mobile','.p-account-trade-form .widget','clear','both','','','.p-account-trade-form'),(474319,'furniture-mobile','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(474320,'furniture-mobile','.w-checkout-billing-address .addresses','clear','both','4','','.w-checkout-billing-address'),(474321,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','clear','left','','','.p-account-trade-form'),(474322,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(474323,'furniture-mobile','.w-cart-listing .right-area','clear','both','2885','','.w-cart-listing'),(474324,'furniture-mobile','.w-checkout-shipping-address .addresses','clear','both','4','','.w-checkout-shipping-address'),(474325,'furniture-mobile','.w-checkout-shipping-address .btn-cancel','clear','both','','','.w-checkout-shipping-address'),(474326,'furniture-mobile','.b-form .addresses','clear','both','4','','.b-form'),(474327,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget:nth-child(2n + 1)','clear','both','2885','','.p-blog-index'),(474328,'furniture-mobile','.w-top-categories .item:nth-child(4n + 1)','clear','both','','','.w-top-categories'),(474329,'furniture-mobile','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(474330,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','clear','left','','','.p-account-trade-form'),(474331,'furniture-mobile','.b-form .newsletter-row','clear','both','4','','.b-form'),(474332,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(474333,'furniture-mobile','.w-login-block .cols','clear','both','4','','.w-login-block'),(474334,'furniture-mobile','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(474335,'furniture-mobile','.p-blog-index .entry-content','clear','both','4','','.p-blog-index'),(474336,'furniture-mobile','.w-login-block .guest','clear','right','','','.w-login-block'),(474337,'furniture-mobile','.w-menu-style-1 li','clear','none','','','.w-menu-style-1'),(474338,'furniture-mobile','.w-login-block .guest','clear','right','','','.w-login-block'),(474339,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget:nth-child(2n + 1)','clear','both','2885','','.p-blog-index'),(474340,'furniture-mobile','.p-blog-index .entry-content','clear','both','4','','.p-blog-index'),(474341,'furniture-mobile','.w-menu-style-1 li','clear','none','','','.w-menu-style-1'),(474342,'furniture-mobile','.w-list-b2b .attributes','clear','both','4','','.w-list-b2b'),(474343,'furniture-mobile','.p-blog-index .comment-meta','clear','both','4','','.p-blog-index'),(474344,'furniture-mobile','.w-account-address-book .item:nth-child(2n + 1)','clear','both','','','.w-account-address-book'),(474345,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(474346,'furniture-mobile','.w-cart-shipping-estimator .item .row: after','clear','both','','','.w-cart-shipping-estimator'),(474347,'furniture-mobile','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(474348,'furniture-mobile','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(474349,'furniture-mobile','.w-menu-style-1 li','clear','none','','','.w-menu-style-1'),(474350,'furniture-mobile','.w-login-block .guest','clear','right','','','.w-login-block'),(474351,'furniture-mobile','.w-login-block .buttons','clear','none','','','.w-login-block'),(474352,'furniture-mobile','.w-login-block .cols','clear','both','4','','.w-login-block'),(474353,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(474354,'furniture-mobile','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(474355,'furniture-mobile','.b-form .col-right','clear','right','','','.b-form'),(474356,'furniture-mobile','.w-cart-compare .product','clear','both','4','','.w-cart-compare'),(474357,'furniture-mobile','.w-login-block .buttons','clear','none','','','.w-login-block'),(474358,'furniture-mobile','.p-blog-index .comment-meta','clear','both','4','','.p-blog-index'),(474359,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','clear','left','','','.p-account-trade-form'),(474360,'furniture-mobile','.p-blog-index .entry-content','clear','both','4','','.p-blog-index'),(474361,'furniture-mobile','.b-bottom .cart-options .option-item:nth-child(2n + 1)','clear','both','','','.b-bottom'),(474362,'furniture-mobile','.b-bottom .cart-options .heading-4','clear','both','','','.b-bottom'),(474363,'furniture-mobile','.b-bottom .cart-options .cart-item:nth-child(2n + 1)','clear','both','','','.b-bottom'),(474364,'furniture-mobile','.b-bottom .cart-options .options','clear','both','','','.b-bottom'),(474365,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget:nth-child(2n + 1)','clear','both','2885','','.p-blog-index'),(474366,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(474367,'furniture-mobile','.w-login-block .guest','clear','right','','','.w-login-block'),(474369,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(474370,'furniture-mobile','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-billing-address'),(474371,'furniture-mobile','.b-form .center-buttons','clear','both','','','.b-form'),(474372,'furniture-mobile','.w-list-b2b .mix-attributes','clear','both','','','.w-list-b2b'),(474373,'furniture-mobile','.w-cart-shipping-estimator .address-item .lastname','clear','both','4','','.w-cart-shipping-estimator'),(474374,'furniture-mobile','.w-login-block .buttons','clear','none','','','.w-login-block'),(474375,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget:nth-child(2n + 1)','clear','both','2885','','.p-blog-index'),(474376,'furniture-mobile','.w-cart-compare .product .image','clear','both','','','.w-cart-compare'),(474377,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(474378,'furniture-mobile','.p-account-trade-form .widget','clear','both','','','.p-account-trade-form'),(474379,'furniture-mobile','.p-blog-index .comment-meta','clear','both','4','','.p-blog-index'),(474380,'furniture-mobile','.p-account-trade-form .wd-line-row-2','clear','both','4','','.p-account-trade-form'),(474382,'furniture-mobile','.w-login-block .cols','clear','both','4','','.w-login-block'),(474383,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(474384,'furniture-mobile','.p-account-trade-form .wd-line-row-2','clear','both','4','','.p-account-trade-form'),(474385,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(474386,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','clear','left','','','.p-account-trade-form'),(474387,'furniture-mobile','.w-product-reviews .reviews-list','clear','right','','','.w-product-reviews'),(474388,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','clear','left','','','.p-account-trade-form'),(474389,'furniture-mobile','.w-cart-compare .buttons','clear','none','','','.w-cart-compare'),(474390,'furniture-mobile','.w-menu-big li','clear','none','','','.w-menu-big'),(474391,'furniture-mobile','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(474392,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(474393,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','clear','both','','','.p-account-trade-form'),(474394,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(474395,'furniture-mobile','.w-login-block .cols','clear','both','4','','.w-login-block'),(474396,'furniture-mobile','.p-account-trade-form .wd-line-row-2','clear','both','4','','.p-account-trade-form'),(474397,'furniture-mobile','.w-login-block .guest','clear','right','','','.w-login-block'),(474398,'furniture-mobile','.w-login-block .buttons','clear','none','','','.w-login-block'),(474399,'furniture-mobile','.b-products-listing .BlockBox','clear','both','4','','.b-products-listing'),(474400,'furniture-mobile','.b-products-listing .products-listing','clear','both','4','','.b-products-listing'),(474401,'furniture-mobile','.w-blog-widget-post-share ','clear','both','2906','','.w-blog-widget-post-share'),(474402,'furniture-mobile','.w-blog-widget-post-listing .post:nth-child(3n+1)','clear','none','2885','','.w-blog-widget-post-listing'),(474403,'furniture-mobile','.w-blog-widget-post-listing .post:nth-child(2n+1)','clear','both','2885','','.w-blog-widget-post-listing'),(474404,'furniture-mobile','.w-blog-widget-post-listing .products','clear','both','4','','.w-blog-widget-post-listing'),(474405,'furniture-mobile','.w-account .acc-top','clear','both','4','','.w-account'),(474406,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(474408,'furniture-mobile','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(474409,'furniture-mobile','.w-categories .categories','clear','both','4','','.w-categories'),(474410,'furniture-mobile','.b-form .password-forgotten-link','clear','both','','','.b-form'),(474412,'furniture-mobile','.b-form .requiredM','clear','both','','','.b-form'),(474413,'furniture-mobile','.w-login-block .cols','clear','both','4','','.w-login-block'),(474414,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget:nth-child(2n + 1)','clear','both','2885','','.p-blog-index'),(474415,'furniture-mobile','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(474416,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-shipping-address'),(474417,'furniture-mobile','.w-categories .item:nth-child(4n + 1)','clear','both','','','.w-categories'),(474418,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','clear','right','','','.p-account-trade-form'),(474419,'furniture-mobile','.w-menu-style-1 li','clear','none','','','.w-menu-style-1'),(474420,'furniture-mobile','.w-cart-give-away .ga_name','clear','both','4','','.w-cart-give-away'),(474421,'furniture-mobile','.b-form .login_btns','clear','both','','','.b-form'),(474423,'furniture-mobile','.w-login-block .buttons','clear','none','','','.w-login-block'),(474424,'furniture-mobile','.w-filters .fsl_handle','clear','both','4','','.w-filters'),(474425,'furniture-mobile','.p-account-trade-form .widget','clear','both','','','.p-account-trade-form'),(474426,'furniture-mobile','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(474427,'furniture-mobile','.w-cart-shipping-estimator .shipping-estimator','clear','both','4','','.w-cart-shipping-estimator'),(474428,'furniture-mobile','.p-account-trade-form .widget','clear','both','','','.p-account-trade-form'),(474429,'furniture-mobile','.b-form .col-right + .col-left','clear','both','','','.b-form'),(474430,'furniture-mobile','.w-menu-style-1 li','clear','none','','','.w-menu-style-1'),(474431,'furniture-mobile','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(474432,'furniture-mobile','.w-cart-shipping-estimator .item .row','clear','both','','','.w-cart-shipping-estimator'),(474433,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(474434,'furniture-mobile','.b-form .columns .col-2:nth-child(2n + 1)','clear','left','','','.b-form'),(474435,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget:nth-child(2n + 1)','clear','both','2885','','.p-blog-index'),(474436,'furniture-mobile','.p-blog-index .entry-content','clear','both','4','','.p-blog-index'),(474437,'furniture-mobile','.b-trade-approval .col-right','clear','right','','','.b-trade-approval'),(474438,'furniture-mobile','.b-trade-approval .col-left','clear','left','','','.b-trade-approval'),(474439,'furniture-mobile','.b-trade-approval .center-buttons','clear','both','','','.b-trade-approval'),(474440,'furniture-mobile','.b-trade-approval .columns','clear','both','4','','.b-trade-approval'),(474441,'furniture-mobile','.w-catalog-compare .BlockBox','clear','both','','','.w-catalog-compare'),(474442,'furniture-mobile','.w-social-links ','clear','both','','','.w-social-links'),(474443,'furniture-mobile','.b-slick .slick-slide','clear','none','','','.b-slick'),(474444,'furniture-mobile','.b-slick .slick-track','clear','both','4','','.b-slick'),(474445,'furniture-mobile','.w-quote a.item','clear','both','4','','.w-quote'),(474446,'furniture-mobile','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(474447,'furniture-mobile','.w-product-bonus-points > div','clear','both','4','','.w-product-bonus-points'),(474448,'furniture-mobile','.w-compare .compare-button','clear','both','','','.w-compare'),(474449,'furniture-mobile','.w-sample a.item','clear','both','4','','.w-sample'),(474450,'furniture-mobile','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(474451,'furniture-mobile','.b-products-listing .products-listing .radio-attributes','clear','both','4','','.b-products-listing'),(474452,'furniture-mobile','.b-pagination .pagination','clear','both','4','','.b-pagination'),(474453,'furniture-mobile','.w-product-multi-inventory .select-box:nth-child(2n+1)','clear','both','','','.w-product-multi-inventory'),(474454,'furniture-mobile','.w-product-multi-inventory .select-box:last-of-type:after','clear','both','','','.w-product-multi-inventory'),(474455,'furniture-mobile','.w-product-multi-inventory .radio-attributes','clear','both','','','.w-product-multi-inventory'),(474456,'furniture-mobile','.w-product-multi-inventory #product-attributes','clear','both','4','','.w-product-multi-inventory'),(474457,'furniture-mobile','.w-product-multi-inventory .radio-attributes','clear','both','4','','.w-product-multi-inventory'),(474458,'furniture-mobile','.w-product-quantity-discounts .quantity-discounts','clear','both','4','','.w-product-quantity-discounts'),(474459,'furniture-mobile','.b-products-listing .products-listing .radio-attributes','clear','both','','','.b-products-listing'),(474460,'furniture-mobile','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(474461,'furniture-mobile','.w-product-attributes #product-attributes','clear','both','4','','.w-product-attributes'),(474462,'furniture-mobile','.w-product-attributes .radio-attributes','clear','both','','','.w-product-attributes'),(474463,'furniture-mobile','.w-product-attributes .radio-attributes','clear','both','4','','.w-product-attributes'),(474464,'furniture-mobile','.w-product-attributes .select-box:last-of-type:after','clear','both','','','.w-product-attributes'),(474465,'furniture-mobile','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(474466,'furniture-mobile','.w-product-groups .prop-group-swatch','clear','both','4','','.w-product-groups'),(474467,'furniture-mobile','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(474468,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list'),(474469,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list-block'),(474470,'furniture-mobile','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(474471,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li:nth-child(2n+1)','clear','both','2876','','.w-catalog-pages-category-pages-last-list'),(474472,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li:nth-child(2n+1)','clear','both','2876','','.w-catalog-pages-category-pages-last-list-block'),(474473,'furniture-mobile','.w-delivery-location-featured-list .deliveryList ul','clear','both','4','','.w-delivery-location-featured-list'),(474474,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list-by-catalog'),(474475,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(474476,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li:nth-child(2n+1)','clear','both','2876','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(474477,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li:nth-child(2n+1)','clear','both','2876','','.w-catalog-pages-category-pages-last-list-by-catalog'),(474478,'furniture-mobile','.w-delivery-location-list-by-page .page-list','clear','both','4','','.w-delivery-location-list-by-page'),(474479,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList','clear','both','4','','.w-delivery-location-top-location-list'),(474480,'furniture-mobile','.w-delivery-location-list-by-page .item:nth-child(3n+1)','clear','left','','','.w-delivery-location-list-by-page'),(474481,'furniture-mobile','.w-delivery-location-list-by-page .item:nth-child(3n+1)','clear','none','2885','','.w-delivery-location-list-by-page'),(474482,'furniture-mobile','.w-delivery-location-list-by-page .item:nth-child(2n+1)','clear','left','2885','','.w-delivery-location-list-by-page'),(474483,'furniture-mobile','.w-delivery-location-cross-pages .item:nth-child(3n+1)','clear','left','','','.w-delivery-location-cross-pages'),(474484,'furniture-mobile','.w-delivery-location-cross-pages .page-list','clear','both','4','','.w-delivery-location-cross-pages'),(474485,'furniture-mobile','.w-delivery-location-cross-pages .item:nth-child(2n+1)','clear','left','2885','','.w-delivery-location-cross-pages'),(474486,'furniture-mobile','.w-delivery-location-cross-pages .item:nth-child(3n+1)','clear','none','2885','','.w-delivery-location-cross-pages'),(474487,'furniture-mobile','.w-catalog-delivery-locations .item:nth-child(2n+1)','clear','left','','','.w-catalog-delivery-locations'),(474488,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination','clear','both','4','','.w-wedding-registry-widgets-search-paging'),(474489,'furniture-mobile','.delivery-options-popup','clear','both','4','',''),(474490,'furniture-mobile','.w-gift-wrap-message-checkout .gift_message-comment-box','clear','both','','','.w-gift-wrap-message-checkout'),(474491,'furniture-mobile','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(474492,'furniture-mobile','.w-product-configurator .pc_attr','clear','both','2876','','.w-product-configurator'),(474493,'furniture-mobile','.w-product-configurator .pc_qty','clear','both','2876','','.w-product-configurator'),(474494,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-list'),(474495,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li:nth-child(2n+1)','clear','both','2876','','.w-catalog-pages-category-pages-list'),(474496,'furniture-mobile','.w-predefined-promotion .prom-multi-discount','clear','both','4','','.w-predefined-promotion'),(474497,'furniture-mobile','.mainBanner .buttonBox','clear','both','4','','.mainBanner'),(474498,'furniture-mobile','.shopByCollectionBox .content','clear','both','4','','.shopByCollectionBox'),(474499,'furniture-mobile','.w-cart-shipping-estimator .estimate-shipping','clear','both','4','','.w-cart-shipping-estimator'),(474500,'furniture-mobile','.account-address-book .address_book_row','clear','both','','','.account-address-book'),(474501,'furniture-mobile','.account-index .topInfo','clear','both','4','','.account-index'),(474502,'furniture-mobile','.w-menu-style-1 li','clear_important','important','','','.w-menu-style-1'),(474503,'furniture-mobile','.w-menu-style-1 li','clear_important','important','','','.w-menu-style-1'),(474504,'furniture-mobile','.w-menu-horizontal li','clear_important','important','','','.w-menu-horizontal'),(474505,'furniture-mobile','.w-menu-style-1 li','clear_important','important','','','.w-menu-style-1'),(474506,'furniture-mobile','.w-menu-big li','clear_important','important','','','.w-menu-big'),(474507,'furniture-mobile','.w-blog-widget-post-share ','clear_important','important','2906','','.w-blog-widget-post-share'),(474508,'furniture-mobile','.w-menu-style-1 li','clear_important','important','','','.w-menu-style-1'),(474509,'furniture-mobile','.w-menu-style-1 li','clear_important','important','','','.w-menu-style-1'),(474510,'furniture-mobile','.w-menu-style-1 li','clear_important','important','','','.w-menu-style-1'),(474511,'furniture-mobile','.b-slick .slick-slide','clear_important','important','','','.b-slick'),(474512,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip','rect(0 0 0 0)','','','.b-select-suggest'),(474513,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','clip-path','polygon( 0% 0%, calc(100% - 1.1em) 0%, 100% 50%, calc(100% - 1.1em) 100%, 0% 100%)','','','.w-product-bonus-points'),(474514,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','clip-path','polygon( 0% 0%, calc(100% - 1.1em) 0%, 100% 50%, calc(100% - 1.1em) 100%, 0% 100%)','','','.b-products-listing'),(474515,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip_important','important','','','.b-select-suggest'),(474516,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-on i','color','$warning-color','','','.b-switch'),(474517,'furniture-mobile','.b-info .info a','color','$color-font-7','','','.b-info'),(474518,'furniture-mobile','.b-email-editor a','color','$color-font-8','','','.b-email-editor'),(474519,'furniture-mobile','.b-rating .glyphicon','color','$color-font-3','','','.b-rating'),(474520,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(474523,'furniture-mobile','.p-blog-index .nav-next a','color','$color-font-9','3','','.p-blog-index'),(474524,'furniture-mobile','.p-wedding-registry-view h1','color','$attention-color','4','','.p-wedding-registry-view'),(474525,'furniture-mobile','.w-cart .multicart .count','color','$color-font-9','','','.w-cart'),(474526,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','color','$color-font-1','','','.w-compare-box-item'),(474527,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(474528,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','$color-font-8','','','.p-quick-order-index'),(474529,'furniture-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .specials_category .promo-conditions','color','$warning-color','3','','.w-promotions'),(474530,'furniture-mobile','.w-promotions .promo-salemaker .content a','color','$color-font-8','','','.w-promotions'),(474531,'furniture-mobile','.w-promotions .promo-cart-discount .item a','color','$color-font-8','','','.w-promotions'),(474532,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','color','$attention-color','','','.w-promotions'),(474533,'furniture-mobile','.w-sale .badge','color','$color-font-1','','','.w-sale'),(474534,'furniture-mobile','.w-sale .left-count-days-text','color','$color-font-1','','','.w-sale'),(474535,'furniture-mobile','.p-blog-index .nav-next a','color','$color-font-9','3','','.p-blog-index'),(474536,'furniture-mobile','.p-wedding-registry-view h1','color','$attention-color','4','','.p-wedding-registry-view'),(474537,'furniture-mobile','.p-wedding-registry-view h1','color','$attention-color','3','','.p-wedding-registry-view'),(474538,'furniture-mobile','.w-wedding-registry-widgets-share-link a','color','$color-font-3','4','','.w-wedding-registry-widgets-share-link'),(474539,'furniture-mobile','.w-wedding-registry-widgets-manage-names .names-separator','color','$attention-color','','','.w-wedding-registry-widgets-manage-names'),(474540,'furniture-mobile','.w-personal-gift-status-bar .end-label','color','$color-font-7','','','.w-personal-gift-status-bar'),(474541,'furniture-mobile','.p-sample-checkout-success .page-success .text-3','color','$attention-color','','','.p-sample-checkout-success'),(474542,'furniture-mobile','.p-reviews-info .review-info-text, .p-reviews-info .review-info-reviewed_by, .p-reviews-info .review-info-date','color','$color-font-8','','','.p-reviews-info'),(474543,'furniture-mobile','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(474544,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','color','$color-font-7','3','','.p-quote-checkout-success'),(474545,'furniture-mobile','.p-blog-index .wp-widget li','color','$color-font-7','3','','.p-blog-index'),(474546,'furniture-mobile','.p-blog-index .reply a','color','$color-font-7','','','.p-blog-index'),(474547,'furniture-mobile','.p-blog-index .nav-previous a','color','$color-font-9','3','','.p-blog-index'),(474548,'furniture-mobile','.p-blog-index .nav-next a','color','$color-font-9','3','','.p-blog-index'),(474549,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(474550,'furniture-mobile','.testimonials .reviews-list .date','color','$color-font-9','','',''),(474551,'furniture-mobile','.testimonials .heading-3','color','$color-font-7','3','',''),(474552,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$color-font-3','3','','.w-contact-contacts'),(474553,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','color','$color-font-1','','','.w-compare-box-item'),(474554,'furniture-mobile','.w-chat .w-chat-box a','color','$color-font-1','3','','.w-chat'),(474555,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range, .w-promotions .prom-multi-discount > .heading','color','$attention-color','3','','.w-promotions'),(474556,'furniture-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','color','$color-font-8','','','.w-promotions'),(474557,'furniture-mobile','.w-promotions .cart_discount .promo-date','color','$warning-color','3','','.w-promotions'),(474558,'furniture-mobile','.w-promotions .multidiscount .promo-date, .w-promotions .multidiscount .heading-3','color','$attention-color','','','.w-promotions'),(474559,'furniture-mobile','.w-promotions .cart_discount .heading-3','color','$warning-color','','','.w-promotions'),(474560,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','$color-font-7','','','.p-quick-order-index'),(474561,'furniture-mobile','.w-promotions .specials_category .promo-salemaker .content a, .w-promotions .specials_category .promo-date','color','$warning-color','3','','.w-promotions'),(474562,'furniture-mobile','.w-promotions .specials_category .heading-3','color','$warning-color','','','.w-promotions'),(474563,'furniture-mobile','.w-promotions .promo-salemaker .discount','color','$warning-color','','','.w-promotions'),(474564,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','color','$attention-color','','','.w-promotions'),(474565,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','color','$attention-color','','','.w-promotions'),(474566,'furniture-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','color','$warning-color','3','','.w-promotions'),(474567,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','color','$color-font-7','','','.b-warehouses-popup'),(474568,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','color','$attention-color','','','.b-warehouses-popup'),(474569,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','color','$message-color','','','.b-warehouses-popup'),(474570,'furniture-mobile','.b-warehouses-popup a.warehouses-popup-link','color','$color-font-8','','','.b-warehouses-popup'),(474571,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','color','$color-font-1','','','.w-compare-box-item'),(474572,'furniture-mobile','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(474573,'furniture-mobile','.p-blog-index .wp-widget li','color','$color-font-7','3','','.p-blog-index'),(474574,'furniture-mobile','.p-blog-index .posted-on','color','$color-font-8','','','.p-blog-index'),(474575,'furniture-mobile','.p-blog-index .nav-previous a','color','$color-font-9','3','','.p-blog-index'),(474576,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','color','$color-font-1','','','.w-compare-box-item'),(474577,'furniture-mobile','.p-payer-order-confirmation .ship-ico','color','$color-font-7','3','','.p-payer-order-confirmation'),(474578,'furniture-mobile','.b-bottom .closeable-heading','color','$color-font-7','3','','.b-bottom'),(474579,'furniture-mobile','.w-sale .badge','color','$color-font-1','','','.w-sale'),(474580,'furniture-mobile','.w-menu-style-1 .menu-ico','color','$color-font-1','','','.w-menu-style-1'),(474581,'furniture-mobile','.b-messages .messMenuButton span','color','$color-font-7','','','.b-messages'),(474582,'furniture-mobile','.b-messages .messages-menu li a','color','$color-font-8','','','.b-messages'),(474583,'furniture-mobile','.b-messages .content_management_attach','color','$color-font-7','','','.b-messages'),(474584,'furniture-mobile','.b-messages .content_management_attach button','color','$color-font-7','','','.b-messages'),(474585,'furniture-mobile','.b-messages .select2-search-choice-close','color','$color-font-9','3','','.b-messages'),(474586,'furniture-mobile','.w-text .customer-service b','color','$color-font-7','','','.w-text'),(474587,'furniture-mobile','.w-sale .left-count-hours-text','color','$color-font-1','','','.w-sale'),(474588,'furniture-mobile','.w-socials .post_item > div.tw_post_item','color','$color-font-10','3','','.w-socials'),(474589,'furniture-mobile','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(474590,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(474591,'furniture-mobile','.p-blog-index .reply a','color','$color-font-7','','','.p-blog-index'),(474592,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','color','$color-font-7','3','','.p-quote-checkout-success'),(474593,'furniture-mobile','.b-info .info','color','$attention-color','','','.b-info'),(474594,'furniture-mobile','.w-text .customer-service','color','$color-font-7','3','','.w-text'),(474595,'furniture-mobile','.w-menu-slider > ul','color','$color-font-1','','','.w-menu-slider'),(474596,'furniture-mobile','.p-payer-order-confirmation .pay-ico','color','$color-font-7','3','','.p-payer-order-confirmation'),(474597,'furniture-mobile','.p-payer-order-confirmation .order-ico','color','$color-font-7','3','','.p-payer-order-confirmation'),(474598,'furniture-mobile','.p-payer-order-confirmation .discount-ico','color','$color-font-7','3','','.p-payer-order-confirmation'),(474599,'furniture-mobile','.p-payer-order-confirmation .comment-ico','color','$color-font-7','3','','.p-payer-order-confirmation'),(474600,'furniture-mobile','.p-payer-order-pay .ship-ico','color','$color-font-7','3','','.p-payer-order-pay'),(474601,'furniture-mobile','.p-payer-order-pay .pay-ico','color','$color-font-7','3','','.p-payer-order-pay'),(474602,'furniture-mobile','.p-payer-order-pay .order-ico','color','$color-font-7','3','','.p-payer-order-pay'),(474603,'furniture-mobile','.p-payer-order-pay .discount-ico','color','$color-font-7','3','','.p-payer-order-pay'),(474604,'furniture-mobile','.p-payer-order-pay .comment-ico','color','$color-font-7','3','','.p-payer-order-pay'),(474605,'furniture-mobile','.p-account-update .main-text a','color','$color-font-7','','','.p-account-update'),(474607,'furniture-mobile','.b-form .inputRequirement','color','$attention-color','','','.b-form'),(474608,'furniture-mobile','.b-fancybox .fancybox-close','color','$color-font-1','','','.b-fancybox'),(474609,'furniture-mobile','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(474610,'furniture-mobile','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(474611,'furniture-mobile','.w-menu-slider > ul','color','$color-font-1','','','.w-menu-slider'),(474612,'furniture-mobile','.w-sale .ends','color','$attention-color','','','.w-sale'),(474613,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','$color-font-7','1','','.p-quick-order-index'),(474615,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','color','$attention-color','','','.w-upload-customer-id-upload-customer-id-form'),(474617,'furniture-mobile','.w-menu-horizontal a','color','inherit','','','.w-menu-horizontal'),(474618,'furniture-mobile','.w-menu-slider .menu-ico','color','$color-font-1','','','.w-menu-slider'),(474619,'furniture-mobile','.w-menu-slider > ul','color','$color-font-1','','','.w-menu-slider'),(474620,'furniture-mobile','.w-sale .special-price','color','$attention-color','','','.w-sale'),(474621,'furniture-mobile','.w-sale .left-count-days-text','color','$color-font-1','','','.w-sale'),(474622,'furniture-mobile','.p-account-update .main-text a','color','$color-font-7','','','.p-account-update'),(474623,'furniture-mobile','.order-summary .price-row.ot_bonus_points .title','color','$message-color','3','','.order-summary'),(474624,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$color-font-3','3','','.w-contact-contacts'),(474625,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','color','$color-font-1','3','','.b-form'),(474626,'furniture-mobile','.b-info .info a','color','$color-font-7','','','.b-info'),(474628,'furniture-mobile','.b-info .info-plus','color','$message-color','','','.b-info'),(474629,'furniture-mobile','.w-coupons-and-vauchers-checkout #credit_modules_message','color','$message-color','','','.w-coupons-and-vauchers-checkout'),(474630,'furniture-mobile','.b-fancybox .fancybox-title-outside-wrap','color','$color-font-1','','','.b-fancybox'),(474631,'furniture-mobile','.b-fancybox .fancybox-title-over-wrap','color','$color-font-1','','','.b-fancybox'),(474632,'furniture-mobile','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(474634,'furniture-mobile','.b-info .info','color','$attention-color','','','.b-info'),(474635,'furniture-mobile','.b-email-editor .price','color','$color-font-7','','','.b-email-editor'),(474636,'furniture-mobile','.p-blog-index .posted-on','color','$color-font-8','','','.p-blog-index'),(474637,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','color','$color-font-7','3','','.p-quote-checkout-success'),(474638,'furniture-mobile','.p-blog-index .wp-widget li','color','$color-font-7','3','','.p-blog-index'),(474639,'furniture-mobile','.w-social-links .twitter','color','$color-font-10','3','','.w-social-links'),(474640,'furniture-mobile','.w-social-links .stumbleupon','color','$attention-color','3','','.w-social-links'),(474641,'furniture-mobile','.w-social-links .facebook','color','$color-font-7','3','','.w-social-links'),(474642,'furniture-mobile','.w-social-links .pinterest','color','$attention-color','3','','.w-social-links'),(474643,'furniture-mobile','.btn-1','color','$color-font-7','','',''),(474644,'furniture-mobile','.price .specials','color','$attention-color','','',''),(474645,'furniture-mobile','.w-menu .menu .menu-ico','color','inherit','','','.w-menu'),(474646,'furniture-mobile','.w-socials .post_item > div.tw_post_item','color','$color-font-10','3','','.w-socials'),(474647,'furniture-mobile','.w-socials .post_item_name a','color','$color-font-8','','','.w-socials'),(474648,'furniture-mobile','.w-sale .special-price','color','$attention-color','','','.w-sale'),(474649,'furniture-mobile','.w-menu-slider .menu-ico','color','$color-font-1','','','.w-menu-slider'),(474650,'furniture-mobile','.w-sale .special-price','color','$attention-color','','','.w-sale'),(474651,'furniture-mobile','.w-sale .ends','color','$attention-color','','','.w-sale'),(474652,'furniture-mobile','.w-sale .left-count-days-text','color','$color-font-1','','','.w-sale'),(474653,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(474654,'furniture-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','color','$color-font-7','','','.w-filters'),(474655,'furniture-mobile','.w-cart-compare .product .name a','color','$color-font-8','','','.w-cart-compare'),(474656,'furniture-mobile','.w-personal-gift-status-bar .inform','color','$color-font-7','4','','.w-personal-gift-status-bar'),(474659,'furniture-mobile','.b-info .info a','color','$color-font-7','','','.b-info'),(474660,'furniture-mobile','.w-reviews .date','color','$color-font-3','','','.w-reviews'),(474661,'furniture-mobile','.w-checkout-shipping-choice span','color','$color-font-7','','','.w-checkout-shipping-choice'),(474662,'furniture-mobile','.w-sale .badge','color','$color-font-1','','','.w-sale'),(474663,'furniture-mobile','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(474664,'furniture-mobile','.w-socials .post_item > div.fb_post_item','color','$color-font-7','3','','.w-socials'),(474665,'furniture-mobile','.w-socials .post_item > div.tw_post_item','color','$color-font-10','3','','.w-socials'),(474666,'furniture-mobile','.w-socials .post_item_name a','color','$color-font-8','','','.w-socials'),(474667,'furniture-mobile','.w-search .button-search','color','$color-font-7','3','','.w-search'),(474668,'furniture-mobile','.w-socials .post_item_name a','color','$color-font-8','','','.w-socials'),(474669,'furniture-mobile','.b-rating .glyphicon.coloron ~ .glyphicon-star','color','$color-font-7','','','.b-rating'),(474670,'furniture-mobile','.p-blog-index .nav-next a','color','$color-font-9','3','','.p-blog-index'),(474671,'furniture-mobile','.p-blog-index .wp-widget li','color','$color-font-7','3','','.p-blog-index'),(474672,'furniture-mobile','.p-blog-index .nav-previous a','color','$color-font-9','3','','.p-blog-index'),(474673,'furniture-mobile','.p-reviews-info .review-info-text, .p-reviews-info .review-info-reviewed_by, .p-reviews-info .review-info-date','color','$color-font-8','','','.p-reviews-info'),(474674,'furniture-mobile','.p-wedding-registry-view h1','color','$attention-color','4','','.p-wedding-registry-view'),(474675,'furniture-mobile','.w-image-maps .default-links .item .description','color','$color-font-8','','','.w-image-maps'),(474676,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$color-font-3','3','','.w-contact-contacts'),(474677,'furniture-mobile','.w-personal-gift-status-bar .end-date','color','$color-font-7','3','','.w-personal-gift-status-bar'),(474678,'furniture-mobile','.price .special','color','$attention-color','','',''),(474679,'furniture-mobile','.w-reviews-content .date','color','$color-font-3','','','.w-reviews-content'),(474681,'furniture-mobile','.b-delete-account .delete-box .delete-message','color','$attention-color','','','.b-delete-account'),(474682,'furniture-mobile','.b-info .info','color','$attention-color','','','.b-info'),(474686,'furniture-mobile','.b-form .radio-button input[type=\"radio\"]:checked + span:before','color','$color-font-8','','','.b-form'),(474688,'furniture-mobile','.w-sale .left-count-hours-text','color','$color-font-1','','','.w-sale'),(474689,'furniture-mobile','.w-menu-style-1 .menu-ico','color','$color-font-1','','','.w-menu-style-1'),(474690,'furniture-mobile','.w-menu-style-1 > ul','color','$color-font-1','','','.w-menu-style-1'),(474691,'furniture-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','color','$color-font-9','3','','.w-multi-cart-actions'),(474692,'furniture-mobile','.w-text .customer-service b','color','$color-font-7','','','.w-text'),(474693,'furniture-mobile','.w-text .customer-service','color','$color-font-7','3','','.w-text'),(474694,'furniture-mobile','.w-tabs .tab-a','color','$color-font-7','2','','.w-tabs'),(474695,'furniture-mobile','.w-socials .post_item_name a','color','$color-font-8','','','.w-socials'),(474696,'furniture-mobile','.w-socials .post_item > div.tw_post_item','color','$color-font-10','3','','.w-socials'),(474697,'furniture-mobile','.w-socials .post_item > div.fb_post_item','color','$color-font-7','3','','.w-socials'),(474698,'furniture-mobile','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(474699,'furniture-mobile','.w-sale .special-price','color','$attention-color','','','.w-sale'),(474700,'furniture-mobile','.btn-edit','color','$color-font-7','3','',''),(474701,'furniture-mobile','.bell-ico .heading-2','color','$color-font-7','3','','.bell-ico'),(474702,'furniture-mobile','.w-tabs a.tab-a','color','$color-font-8','','','.w-tabs'),(474703,'furniture-mobile','.w-tabs .tab-li:hover a.tab-a','color','$color-font-7','','','.w-tabs'),(474704,'furniture-mobile','.w-cart-credit-amount #credit_modules_message.error','color','$attention-color','','','.w-cart-credit-amount'),(474705,'furniture-mobile','.w-cart-credit-amount #credit_modules_message','color','$message-color','','','.w-cart-credit-amount'),(474706,'furniture-mobile','.p-account-update .main-text a','color','$color-font-7','','','.p-account-update'),(474707,'furniture-mobile','.w-cart-listing .attention_mark','color','$attention-color','','','.w-cart-listing'),(474708,'furniture-mobile','.w-menu-slider > ul','color','$color-font-1','','','.w-menu-slider'),(474709,'furniture-mobile','.w-socials .post_item_name a','color','$color-font-8','','','.w-socials'),(474710,'furniture-mobile','.w-sale .ends','color','$attention-color','','','.w-sale'),(474711,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(474712,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(474715,'furniture-mobile','.w-personal-gift-status-bar .start-label','color','$color-font-7','','','.w-personal-gift-status-bar'),(474716,'furniture-mobile','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(474717,'furniture-mobile','.p-blog-index .posted-on','color','$color-font-8','','','.p-blog-index'),(474718,'furniture-mobile','.p-blog-index .posted-on','color','$color-font-8','','','.p-blog-index'),(474719,'furniture-mobile','a.btn-2','color','$color-font-7','','',''),(474720,'furniture-mobile','.btn-2','color','$color-font-7','','',''),(474721,'furniture-mobile','.heading-4 .edit, h4 .edit','color','$color-font-7','','',''),(474722,'furniture-mobile','.w-cart-compare .delete-cart','color','$color-font-8','3','','.w-cart-compare'),(474723,'furniture-mobile','.w-cart-compare .cart-name a','color','$color-font-8','','','.w-cart-compare'),(474724,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','color','$message-color','','','.b-switch'),(474725,'furniture-mobile','.w-menu-slider .menu-ico','color','$color-font-1','','','.w-menu-slider'),(474726,'furniture-mobile','.p-sample-checkout-success .page-success .text-1','color','$color-font-7','3','','.p-sample-checkout-success'),(474727,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$color-font-3','3','','.w-contact-contacts'),(474728,'furniture-mobile','.w-top-categories .categories h2','color','inherit','','','.w-top-categories'),(474729,'furniture-mobile','.out-stock','color','$attention-color','','',''),(474730,'furniture-mobile','.transit','color','$color-font-9','','',''),(474731,'furniture-mobile','.in-stock','color','$message-color','','',''),(474732,'furniture-mobile','.heading-3 .edit, h3 .edit','color','$color-font-7','','',''),(474733,'furniture-mobile','.b-email-editor .name a','color','$color-font-8','','','.b-email-editor'),(474735,'furniture-mobile','.b-bottom .header-error','color','$attention-color','','','.b-bottom'),(474736,'furniture-mobile','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(474737,'furniture-mobile','.savings-ico .heading-2','color','$message-color','3','','.savings-ico'),(474738,'furniture-mobile','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(474739,'furniture-mobile','.w-menu-style-1 > ul','color','$color-font-1','','','.w-menu-style-1'),(474740,'furniture-mobile','.w-sale .special-price','color','$attention-color','','','.w-sale'),(474741,'furniture-mobile','.w-text .customer-service b','color','$color-font-7','','','.w-text'),(474742,'furniture-mobile','.w-socials .post_item > div.fb_post_item','color','$color-font-7','3','','.w-socials'),(474743,'furniture-mobile','.testimonials .date','color','$color-font-9','','',''),(474744,'furniture-mobile','.js-stock','color','$message-color','','',''),(474745,'furniture-mobile','.p-blog-index .nav-previous a','color','$color-font-9','3','','.p-blog-index'),(474747,'furniture-mobile','.b-email-editor .price','color','$color-font-7','','','.b-email-editor'),(474748,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','color','$color-font-1','','','.b-fancybox'),(474749,'furniture-mobile','.w-reviews-content .product-name a','color','$color-font-7','','','.w-reviews-content'),(474750,'furniture-mobile','.b-fancybox .fancybox-skin','color','$color-font-8','','','.b-fancybox'),(474751,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(474752,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(474753,'furniture-mobile','.p-blog-index .wp-widget li','color','$color-font-7','3','','.p-blog-index'),(474754,'furniture-mobile','.p-blog-index .posted-on','color','$color-font-8','','','.p-blog-index'),(474755,'furniture-mobile','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(474756,'furniture-mobile','.w-socials .post_item > div.tw_post_item','color','$color-font-10','3','','.w-socials'),(474757,'furniture-mobile','.w-socials .post_item > div.fb_post_item','color','$color-font-7','3','','.w-socials'),(474758,'furniture-mobile','.b-info .info-plus','color','$message-color','','','.b-info'),(474759,'furniture-mobile','.main-content a','color','$color-font-7','','',''),(474760,'furniture-mobile','.btn','color','$color-font-7','','',''),(474761,'furniture-mobile','.heading-ordered-items .heading-4','color','$color-font-7','3','','.heading-ordered-items'),(474762,'furniture-mobile','.heading-saved-lists .heading-4','color','$color-font-7','3','','.heading-saved-lists'),(474763,'furniture-mobile','.message.success','color','$message-color','','',''),(474764,'furniture-mobile','.b-form .required-message','color','$attention-color','','','.b-form'),(474765,'furniture-mobile','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(474766,'furniture-mobile','.b-email-editor .price','color','$color-font-7','','','.b-email-editor'),(474767,'furniture-mobile','.p-wedding-registry-view h1','color','$attention-color','4','','.p-wedding-registry-view'),(474768,'furniture-mobile','.p-wedding-registry-view h1','color','$attention-color','3','','.p-wedding-registry-view'),(474769,'furniture-mobile','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(474770,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(474771,'furniture-mobile','.w-reviews .heading-3','color','$color-font-7','3','','.w-reviews'),(474772,'furniture-mobile','.w-reviews .product-name a','color','$color-font-7','','','.w-reviews'),(474773,'furniture-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','color','$color-font-8','','','.b-select-suggest'),(474776,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','color','$color-font-3','','','.b-form'),(474781,'furniture-mobile','.b-info .info a','color','$color-font-7','','','.b-info'),(474782,'furniture-mobile','.w-social-links .linkedin','color','$color-font-7','3','','.w-social-links'),(474783,'furniture-mobile','.b-info .info','color','$attention-color','','','.b-info'),(474784,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','color','$warning-color','','','.b-switch'),(474785,'furniture-mobile','a','color','inherit','','',''),(474786,'furniture-mobile','.w-menu-style-1 a','color','inherit','','','.w-menu-style-1'),(474787,'furniture-mobile','.w-sale .left-count-days-text','color','$color-font-1','','','.w-sale'),(474788,'furniture-mobile','.w-sale .left-count-hours-text','color','$color-font-1','','','.w-sale'),(474789,'furniture-mobile','.w-text .customer-service b','color','$color-font-7','','','.w-text'),(474790,'furniture-mobile','a.btn','color','$color-font-7','','',''),(474791,'furniture-mobile','.heading-settings .heading-4','color','$color-font-7','3','','.heading-settings'),(474792,'furniture-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','color','$color-font-7','','','.b-form'),(474793,'furniture-mobile','.btn-del','color','$attention-color','4','',''),(474794,'furniture-mobile','.b-form .required','color','$attention-color','','','.b-form'),(474795,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(474796,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','color','$color-font-7','3','','.p-quote-checkout-success'),(474797,'furniture-mobile','.w-menu .menu .menu-ico','color','inherit','','','.w-menu'),(474798,'furniture-mobile','.w-menu-style-1 .menu-ico','color','$color-font-1','','','.w-menu-style-1'),(474799,'furniture-mobile','.b-rating .glyphicon-star.coloron','color','$color-font-7','3','','.b-rating'),(474800,'furniture-mobile','.w-social-links .instagram','color','$attention-color','3','','.w-social-links'),(474801,'furniture-mobile','.p-wedding-registry-view h1','color','$attention-color','4','','.p-wedding-registry-view'),(474802,'furniture-mobile','.p-reviews-info .review-info-text, .p-reviews-info .review-info-reviewed_by, .p-reviews-info .review-info-date','color','$color-font-8','','','.p-reviews-info'),(474803,'furniture-mobile','.b-email-editor a','color','$color-font-8','','','.b-email-editor'),(474804,'furniture-mobile','.b-pass-strength span.good-pass','color','$message-color','','','.b-pass-strength'),(474805,'furniture-mobile','.b-pass-strength span.strong-pass, .b-pass-strength span.pass-match','color','$message-color','','','.b-pass-strength'),(474806,'furniture-mobile','.b-email-editor .price','color','$color-font-7','','','.b-email-editor'),(474807,'furniture-mobile','.b-info .info','color','$attention-color','','','.b-info'),(474808,'furniture-mobile','.b-email-editor .name a','color','$color-font-8','','','.b-email-editor'),(474809,'furniture-mobile','.w-text .customer-service','color','$color-font-7','3','','.w-text'),(474810,'furniture-mobile','.w-text .customer-service b','color','$color-font-7','','','.w-text'),(474811,'furniture-mobile','.w-sale .left-count-hours-text','color','$color-font-1','','','.w-sale'),(474812,'furniture-mobile','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(474813,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(474814,'furniture-mobile','.w-menu-style-1 a','color','inherit','','','.w-menu-style-1'),(474815,'furniture-mobile','.w-menu-style-1 .menu-ico','color','$color-font-1','','','.w-menu-style-1'),(474816,'furniture-mobile','.w-menu-slider .menu-ico','color','$color-font-1','','','.w-menu-slider'),(474817,'furniture-mobile','.p-wedding-registry-view h1','color','$attention-color','3','','.p-wedding-registry-view'),(474818,'furniture-mobile','.p-wedding-registry-view h1','color','$attention-color','4','','.p-wedding-registry-view'),(474819,'furniture-mobile','.b-email-editor .name a','color','$color-font-8','','','.b-email-editor'),(474820,'furniture-mobile','.w-menu-style-1 .menu-ico','color','$color-font-1','','','.w-menu-style-1'),(474821,'furniture-mobile','.w-sale .left-count-days-text','color','$color-font-1','','','.w-sale'),(474822,'furniture-mobile','.w-languages .current','color','$color-font-3','3','','.w-languages'),(474823,'furniture-mobile','.b-info .info-plus','color','$message-color','','','.b-info'),(474824,'furniture-mobile','.p-blog-index .wp-widget li','color','$color-font-7','3','','.p-blog-index'),(474825,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(474829,'furniture-mobile','.b-email-editor a','color','$color-font-8','','','.b-email-editor'),(474830,'furniture-mobile','.b-bottom .pop-up-close','color','$color-font-9','1','','.b-bottom'),(474831,'furniture-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','color','$color-font-9','3','','.order-summary'),(474832,'furniture-mobile','.order-summary .price-row.ot_gv .title','color','$message-color','3','','.order-summary'),(474833,'furniture-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','color','$message-color','','','.b-products-listing'),(474834,'furniture-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','color','$message-color','','','.b-products-listing'),(474835,'furniture-mobile','.w-menu-style-1 .menu-ico','color','$color-font-1','','','.w-menu-style-1'),(474836,'furniture-mobile','.w-socials .post_item > div.fb_post_item','color','$color-font-7','3','','.w-socials'),(474837,'furniture-mobile','.w-text .customer-service','color','$color-font-7','3','','.w-text'),(474838,'furniture-mobile','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(474839,'furniture-mobile','.b-info .info a','color','$color-font-7','','','.b-info'),(474840,'furniture-mobile','.w-menu-style-1 > ul','color','$color-font-1','','','.w-menu-style-1'),(474841,'furniture-mobile','.b-email-editor a','color','$color-font-8','','','.b-email-editor'),(474842,'furniture-mobile','.w-social-links .google-plus','color','$attention-color','3','','.w-social-links'),(474845,'furniture-mobile','.b-info .info-plus','color','$message-color','','','.b-info'),(474846,'furniture-mobile','.b-info .info','color','$attention-color','','','.b-info'),(474848,'furniture-mobile','.b-form .privacy-row a','color','$color-font-7','','','.b-form'),(474849,'furniture-mobile','.w-text .customer-service b','color','$color-font-7','','','.w-text'),(474850,'furniture-mobile','.p-blog-index .nav-previous a','color','$color-font-9','3','','.p-blog-index'),(474851,'furniture-mobile','.w-text .customer-service','color','$color-font-7','3','','.w-text'),(474852,'furniture-mobile','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(474853,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(474855,'furniture-mobile','.w-menu-slider .menu-ico','color','$color-font-1','','','.w-menu-slider'),(474856,'furniture-mobile','.w-image-maps .categories-items .item .description','color','$color-font-8','','','.w-image-maps'),(474857,'furniture-mobile','.w-checkout-shipping-choice input:checked + span','color','$color-font-1','','','.w-checkout-shipping-choice'),(474858,'furniture-mobile','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(474859,'furniture-mobile','.w-tabs .accordion-heading','color','$color-font-7','2','','.w-tabs'),(474860,'furniture-mobile','.w-categories h2.name','color','$color-font-8','','','.w-categories'),(474863,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on i, .b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-off i','color','$message-color','','','.b-switch'),(474864,'furniture-mobile','.p-account-update .main-text a','color','$color-font-7','','','.p-account-update'),(474865,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','color','$color-font-7','3','','.p-quote-checkout-success'),(474866,'furniture-mobile','.p-blog-index .reply a','color','$color-font-7','','','.p-blog-index'),(474869,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','color','$color-font-8','','','.b-select-suggest'),(474870,'furniture-mobile','.b-select-suggest .select2-default','color','$color-font-9','','','.b-select-suggest'),(474871,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','color','$color-font-8','','','.b-select-suggest'),(474872,'furniture-mobile','.b-select-suggest .select2-results .select2-highlighted ul','color','$color-font-8','','','.b-select-suggest'),(474873,'furniture-mobile','.b-select-suggest .select2-results .select2-highlighted','color','$color-font-8','','','.b-select-suggest'),(474874,'furniture-mobile','.b-select-suggest .select2-drop','color','$color-font-8','','','.b-select-suggest'),(474875,'furniture-mobile','.w-menu-style-1 a','color','inherit','','','.w-menu-style-1'),(474876,'furniture-mobile','.w-menu .menu .menu-ico','color','inherit','','','.w-menu'),(474877,'furniture-mobile','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(474878,'furniture-mobile','.w-menu-big a','color','inherit','','','.w-menu-big'),(474879,'furniture-mobile','.w-menu .menu .menu-ico','color','inherit','','','.w-menu'),(474880,'furniture-mobile','.p-account-update .main-text a','color','$color-font-7','','','.p-account-update'),(474881,'furniture-mobile','.w-menu-slider .menu-ico','color','$color-font-1','','','.w-menu-slider'),(474882,'furniture-mobile','.w-menu-style-1 a','color','inherit','','','.w-menu-style-1'),(474883,'furniture-mobile','.w-menu-style-1 > ul','color','$color-font-1','','','.w-menu-style-1'),(474884,'furniture-mobile','.w-menu-slider > ul','color','$color-font-1','','','.w-menu-slider'),(474885,'furniture-mobile','.b-email-editor a','color','$color-font-8','','','.b-email-editor'),(474886,'furniture-mobile','.p-reviews-info .review-info-text, .p-reviews-info .review-info-reviewed_by, .p-reviews-info .review-info-date','color','$color-font-8','','','.p-reviews-info'),(474887,'furniture-mobile','.w-menu .menu .menu-ico','color','inherit','','','.w-menu'),(474889,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','color','$color-font-1','','','.w-compare-box-item'),(474890,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','$color-font-8','','','.b-data-table'),(474891,'furniture-mobile','.b-products-listing .products-listing .bonus-points span:first-child','color','$color-font-7','','','.b-products-listing'),(474892,'furniture-mobile','.b-products-listing .products-listing .bonus-points-price','color','$color-font-7','3','','.b-products-listing'),(474893,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','color','$color-font-7','3','','.b-products-listing'),(474894,'furniture-mobile','.w-catalog-b2b-add-button ','color','$color-font-1','','','.w-catalog-b2b-add-button'),(474895,'furniture-mobile','.w-blog-widget-tag-cloud a','color','$color-font-8','','','.w-blog-widget-tag-cloud'),(474896,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_content a','color','$color-font-8','','','.w-blog-widget-related-posts-by-category'),(474897,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','color','$color-font-8','3','','.w-blog-widget-related-posts'),(474898,'furniture-mobile','.w-blog-widget-related-posts .post_content a','color','$attention-color','','','.w-blog-widget-related-posts'),(474899,'furniture-mobile','.w-blog-widget-post-share .pinterest-btn','color','$color-font-8','3','','.w-blog-widget-post-share'),(474900,'furniture-mobile','.w-blog-widget-post-share .printto','color','$color-font-3','3','','.w-blog-widget-post-share'),(474901,'furniture-mobile','.w-blog-widget-post-share .twitter-btn','color','$color-font-8','3','','.w-blog-widget-post-share'),(474902,'furniture-mobile','.w-blog-widget-post-share .mailto','color','$color-font-3','3','','.w-blog-widget-post-share'),(474903,'furniture-mobile','.w-blog-widget-post-share .facebook-btn','color','$color-font-8','3','','.w-blog-widget-post-share'),(474904,'furniture-mobile','.w-blog-widget-post-listing .post_name a','color','$color-font-8','','','.w-blog-widget-post-listing'),(474905,'furniture-mobile','.w-blog-widget-post-listing .post_tagged a','color','$color-font-8','','','.w-blog-widget-post-listing'),(474906,'furniture-mobile','.w-blog-widget-post-listing .post_comment','color','$color-font-3','3','','.w-blog-widget-post-listing'),(474907,'furniture-mobile','.w-blog-widget-post-comments-count span','color','$color-font-3','3','','.w-blog-widget-post-comments-count'),(474908,'furniture-mobile','.w-blog-widget-post-date ','color','$color-font-8','','','.w-blog-widget-post-date'),(474909,'furniture-mobile','.w-blog-widget-most-popular-posts a','color','$color-font-8','','','.w-blog-widget-most-popular-posts'),(474910,'furniture-mobile','.w-blog-widget-categories-list a','color','$color-font-8','','','.w-blog-widget-categories-list'),(474911,'furniture-mobile','.w-currencies .select-link','color','$color-font-7','','','.w-currencies'),(474912,'furniture-mobile','.w-currencies .current','color','$color-font-3','3','','.w-currencies'),(474913,'furniture-mobile','.w-currencies .currencies-title','color','$color-font-7','','','.w-currencies'),(474914,'furniture-mobile','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(474915,'furniture-mobile','.p-reviews-info .review-info-text, .p-reviews-info .review-info-reviewed_by, .p-reviews-info .review-info-date','color','$color-font-8','','','.p-reviews-info'),(474916,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','color','$color-font-8','','','.b-select-suggest'),(474917,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','color','$color-font-1','','','.w-compare-box-item'),(474918,'furniture-mobile','.b-upload-file .snapshot','color','$color-font-9','','','.b-upload-file'),(474919,'furniture-mobile','.b-email-editor .price','color','$color-font-7','','','.b-email-editor'),(474920,'furniture-mobile','.b-info .info-plus','color','$message-color','','','.b-info'),(474921,'furniture-mobile','.b-info .info a','color','$color-font-7','','','.b-info'),(474922,'furniture-mobile','.w-top-categories h2.name','color','$color-font-8','','','.w-top-categories'),(474923,'furniture-mobile','.w-text .customer-service','color','$color-font-7','3','','.w-text'),(474924,'furniture-mobile','.w-sale .left-count-hours-text','color','$color-font-1','','','.w-sale'),(474925,'furniture-mobile','.w-sale .badge','color','$color-font-1','','','.w-sale'),(474926,'furniture-mobile','.w-sale .ends','color','$attention-color','','','.w-sale'),(474927,'furniture-mobile','.w-menu-style-1 a','color','inherit','','','.w-menu-style-1'),(474928,'furniture-mobile','.w-coupons-and-vauchers-checkout #credit_modules_message.error','color','$attention-color','','','.w-coupons-and-vauchers-checkout'),(474929,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$color-font-3','3','','.w-contact-contacts'),(474930,'furniture-mobile','.p-wedding-registry-view h1','color','$attention-color','3','','.p-wedding-registry-view'),(474931,'furniture-mobile','.p-blog-index .nav-next a','color','$color-font-9','3','','.p-blog-index'),(474932,'furniture-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','color','$color-font-1','','','.w-taxable'),(474933,'furniture-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','color','$color-font-1','','','.w-taxable'),(474934,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','color','$color-font-9','','','.w-communication-new-topic'),(474935,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','color','$color-font-9','','','.w-communication-new-topic'),(474938,'furniture-mobile','.b-form .middle-form label','color','$color-font-8','','','.b-form'),(474939,'furniture-mobile','.btn-3','color','$color-font-7','','',''),(474940,'furniture-mobile','.order-summary .price-row.ot_coupon .title','color','$message-color','3','','.order-summary'),(474941,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(474942,'furniture-mobile','.w-menu-style-1 > ul','color','$color-font-1','','','.w-menu-style-1'),(474943,'furniture-mobile','.b-email-editor .name a','color','$color-font-8','','','.b-email-editor'),(474944,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(474946,'furniture-mobile','.w-cart-compare .product-actions .dropdown-toggle','color','$color-font-9','','','.w-cart-compare'),(474947,'furniture-mobile','.w-sale .left-count-days-text','color','$color-font-1','','','.w-sale'),(474948,'furniture-mobile','.w-sale .left-count-hours-text','color','$color-font-1','','','.w-sale'),(474949,'furniture-mobile','.w-sale .ends','color','$attention-color','','','.w-sale'),(474950,'furniture-mobile','.w-sale .badge','color','$color-font-1','','','.w-sale'),(474951,'furniture-mobile','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(474952,'furniture-mobile','.b-info .info-plus','color','$message-color','','','.b-info'),(474953,'furniture-mobile','.b-email-editor a','color','$color-font-8','','','.b-email-editor'),(474954,'furniture-mobile','.w-menu-style-1 a','color','inherit','','','.w-menu-style-1'),(474955,'furniture-mobile','.b-email-editor .name a','color','$color-font-8','','','.b-email-editor'),(474956,'furniture-mobile','.w-catalog-listing-look .grid','color','$color-font-3','','','.w-catalog-listing-look'),(474957,'furniture-mobile','.w-catalog-listing-look .b2b','color','$color-font-1','2','','.w-catalog-listing-look'),(474958,'furniture-mobile','.w-catalog-listing-look .b2b','color','$color-font-7','','','.w-catalog-listing-look'),(474959,'furniture-mobile','.w-catalog-listing-look .list','color','$color-font-7','','','.w-catalog-listing-look'),(474960,'furniture-mobile','.w-catalog-listing-look .grid','color','$color-font-1','2','','.w-catalog-listing-look'),(474961,'furniture-mobile','.w-catalog-listing-look .list','color','$color-font-1','2','','.w-catalog-listing-look'),(474962,'furniture-mobile','.checkbox input:checked + span:before','color','$color-font-1','','',''),(474963,'furniture-mobile','.p-quick-order-index .all-scroll-div','color','$color-font-1','','','.p-quick-order-index'),(474965,'furniture-mobile','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','color','$color-font-9','','','.w-cart-listing'),(474966,'furniture-mobile','.w-cart-listing .actions a','color','$color-font-9','','','.w-cart-listing'),(474967,'furniture-mobile','.w-cart-listing .points-redeem','color','$message-color','','','.w-cart-listing'),(474968,'furniture-mobile','.w-cart-listing .remove-btn','color','$color-font-9','','','.w-cart-listing'),(474969,'furniture-mobile','.w-cart-discount-coupon #credit_modules_message.error','color','$attention-color','','','.w-cart-discount-coupon'),(474970,'furniture-mobile','.w-cart .multicart a.switch-cart','color','$attention-color','1','','.w-cart'),(474971,'furniture-mobile','.w-cart .multicart .switch-cart','color','$color-font-3','','','.w-cart'),(474972,'furniture-mobile','.w-cart .multicart .item.current-multi-cart .switch-cart','color','$color-font-7','3','','.w-cart'),(474973,'furniture-mobile','.w-cart-discount-coupon #credit_modules_message','color','$message-color','','','.w-cart-discount-coupon'),(474974,'furniture-mobile','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(474975,'furniture-mobile','.w-image-maps .float-items .item .description','color','$color-font-8','','','.w-image-maps'),(474976,'furniture-mobile','.b-fancybox .fancybox-nav span','color','$color-font-1','','','.b-fancybox'),(474977,'furniture-mobile','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(474978,'furniture-mobile','.b-email-editor .name a','color','$color-font-8','','','.b-email-editor'),(474979,'furniture-mobile','.w-socials .post_item > div.tw_post_item','color','$color-font-10','3','','.w-socials'),(474980,'furniture-mobile','.w-socials .post_item > div.fb_post_item','color','$color-font-7','3','','.w-socials'),(474981,'furniture-mobile','.w-socials .post_item_name a','color','$color-font-8','','','.w-socials'),(474982,'furniture-mobile','.w-sale .special-price','color','$attention-color','','','.w-sale'),(474983,'furniture-mobile','.w-menu-slider > ul','color','$color-font-1','','','.w-menu-slider'),(474984,'furniture-mobile','.w-sale .badge','color','$color-font-1','','','.w-sale'),(474985,'furniture-mobile','.w-sale .ends','color','$attention-color','','','.w-sale'),(474986,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(474987,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(474988,'furniture-mobile','.p-wedding-registry-view h1','color','$attention-color','3','','.p-wedding-registry-view'),(474989,'furniture-mobile','.w-wedding-registry-widgets-products .remove-btn','color','$color-font-9','3','','.w-wedding-registry-widgets-products'),(474990,'furniture-mobile','.w-wedding-registry-widgets-delete-link a','color','$color-font-3','4','','.w-wedding-registry-widgets-delete-link'),(474991,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','color','$color-font-7','3','','.p-quote-checkout-success'),(474992,'furniture-mobile','.p-blog-index .reply a','color','$color-font-7','','','.p-blog-index'),(474993,'furniture-mobile','.p-account-update .main-text a','color','$color-font-7','','','.p-account-update'),(474994,'furniture-mobile','.p-reviews-info .review-info-text, .p-reviews-info .review-info-reviewed_by, .p-reviews-info .review-info-date','color','$color-font-8','','','.p-reviews-info'),(474995,'furniture-mobile','.w-filters .open','color','$color-font-7','3','','.w-filters'),(474996,'furniture-mobile','.w-menu-style-1 > ul','color','$color-font-1','','','.w-menu-style-1'),(474997,'furniture-mobile','.w-filters .head-filter-widget','color','$color-font-1','2885','','.w-filters'),(474998,'furniture-mobile','.w-filters .filter-box-head','color','$color-font-8','','','.w-filters'),(474999,'furniture-mobile','.w-filters .view_more','color','$color-font-7','','','.w-filters'),(475000,'furniture-mobile','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(475001,'furniture-mobile','.p-blog-index .nav-previous a','color','$color-font-9','3','','.p-blog-index'),(475002,'furniture-mobile','.w-catalog-paging ','color','$color-font-1','2','','.w-catalog-paging'),(475003,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$color-font-3','3','','.w-contact-contacts'),(475004,'furniture-mobile','.b-bottom .pop-up-close','color','$color-font-9','','','.b-bottom'),(475005,'furniture-mobile','.b-email-editor .price','color','$color-font-7','','','.b-email-editor'),(475007,'furniture-mobile','.p-blog-index .posted-on','color','$color-font-8','','','.p-blog-index'),(475008,'furniture-mobile','.p-blog-index .reply a','color','$color-font-7','','','.p-blog-index'),(475009,'furniture-mobile','.b-pass-strength span.bad-pass','color','$warning-color','','','.b-pass-strength'),(475010,'furniture-mobile','.w-product-reviews .reviews-list .date','color','$color-font-9','','','.w-product-reviews'),(475011,'furniture-mobile','.b-upload-files .remove-file','color','$attention-color','3','','.b-upload-files'),(475012,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','$color-font-7','1','','.b-data-table'),(475013,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','$color-font-7','','','.b-data-table'),(475014,'furniture-mobile','.w-menu .menu .menu-ico','color','inherit','','','.w-menu'),(475015,'furniture-mobile','a.btn-3','color','$color-font-7','','',''),(475016,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.off .candlestick-off','color','$color-font-1','4','','.b-switch'),(475017,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.on .candlestick-on','color','$color-font-1','4','','.b-switch'),(475018,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.default .candlestick-nc','color','$color-font-1','4','','.b-switch'),(475019,'furniture-mobile','.b-pass-strength .short-pass, .b-pass-strength .pass-strength, .b-pass-strength .pass-no-match','color','$attention-color','','','.b-pass-strength'),(475021,'furniture-mobile','.b-form .message.error','color','$attention-color','','','.b-form'),(475022,'furniture-mobile','a.btn-1','color','$color-font-7','','',''),(475023,'furniture-mobile','.p-blog-index .nav-next a','color','$color-font-9','3','','.p-blog-index'),(475024,'furniture-mobile','.w-filters .mobileCollapse','color','$color-font-1','4','','.w-filters'),(475025,'furniture-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','color','$color-font-3','','','.w-filters'),(475026,'furniture-mobile','.p-blog-index .reply a','color','$color-font-7','','','.p-blog-index'),(475027,'furniture-mobile','.p-wedding-registry-view h1','color','$attention-color','3','','.p-wedding-registry-view'),(475028,'furniture-mobile','.b-product-images .media-popup .mp-close','color','$color-font-3','','','.b-product-images'),(475029,'furniture-mobile','.b-product-images .media-popup .mp-close','color','$color-font-1','1','','.b-product-images'),(475030,'furniture-mobile','.b-product-images .media-popup .slick-dots li','color','$color-font-3','','','.b-product-images'),(475031,'furniture-mobile','.b-product-images .media-popup .slick-dots li.slick-active','color','$color-font-1','','','.b-product-images'),(475032,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','color','$color-font-3','','','.b-product-images'),(475033,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','color','$color-font-1','1','','.b-product-images'),(475034,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2','color','$color-font-7','','','.b-menu-style-1'),(475035,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','color','$color-font-1','','','.b-menu-style-2'),(475036,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','color','$color-font-7','','','.b-menu-style-2'),(475037,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','color','$color-font-1','','','.b-menu-style-2'),(475038,'furniture-mobile','.b-personal-catalog-popup #personal_catalog_popup .show-all-lists','color','$color-font-7','','','.b-personal-catalog-popup'),(475039,'furniture-mobile','.b-trade-approval .steps-bar li.current a','color','$color-font-1','','','.b-trade-approval'),(475040,'furniture-mobile','.b-trade-approval .middle-form label','color','$color-font-8','','','.b-trade-approval'),(475041,'furniture-mobile','.batchPr .checkbox input:checked + span:before','color','$color-font-1','','','.batchPr'),(475042,'furniture-mobile','.batchPr .btn-batch-remove','color','$color-font-1','','','.batchPr'),(475043,'furniture-mobile','.w-account-personal-catalog .list-switcher a','color','$color-font-7','2','','.w-account-personal-catalog'),(475044,'furniture-mobile','.w-catalog-compare .checkbox input:checked + span:before','color','$color-font-9','','','.w-catalog-compare'),(475045,'furniture-mobile','.w-catalog-compare span.btn-preloader','color','$color-font-7','3','','.w-catalog-compare'),(475046,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','color','$color-font-7','2','','.w-catalog-compare'),(475047,'furniture-mobile','.w-catalog-compare .cross-box .return','color','$color-font-7','','','.w-catalog-compare'),(475048,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','color','$color-font-7','3','','.w-catalog-compare'),(475049,'furniture-mobile','.w-delivery-day .ends','color','$attention-color','','','.w-delivery-day'),(475050,'furniture-mobile','.w-delivery-day .left-count-days-text, .w-delivery-day .left-count-hours-text, .w-delivery-day .left-count-minutes-text, .w-delivery-day .left-count-seconds-text','color','$color-font-1','','','.w-delivery-day'),(475051,'furniture-mobile','.w-cart .cart-box-link','color','$color-font-7','3','','.w-cart'),(475052,'furniture-mobile','.w-account .my-acc-link','color','$color-font-7','3','','.w-account'),(475053,'furniture-mobile','.w-account .password-forgotten-link a','color','$color-font-7','','','.w-account'),(475054,'furniture-mobile','.w-account .heading-2','color','$color-font-7','','','.w-account'),(475055,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','color','$color-font-4','','','.b-menu-style-1'),(475056,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','color','$color-font-7','','','.b-slick'),(475057,'furniture-mobile','.w-search .search-ico','color','$color-font-7','2885,3','','.w-search'),(475058,'furniture-mobile','.menu-header .burger-icon','color','$color-font-7','2885','','.menu-header'),(475059,'furniture-mobile','.menu-header .burger-icon','color','$color-font-7','2885,3','','.menu-header'),(475060,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li','color','$color-font-4','3','','.b-menu-style-3'),(475061,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .no-link','color','$color-font-3','','','.b-menu-style-3'),(475062,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','color','$color-font-9','2885,3','','.b-menu-style-3'),(475063,'furniture-mobile','.b-products-listing .del-from-personal-catalog','color','$message-color','3','','.b-products-listing'),(475064,'furniture-mobile','.price .old','color','$color-font-9','','',''),(475065,'furniture-mobile','.w-filters .head-filter-widget','color','$color-font-7','','','.w-filters'),(475066,'furniture-mobile','.w-subscribers .btn-submit','color','$color-font-7','','','.w-subscribers'),(475067,'furniture-mobile','.w-quote .cart-box-link','color','$color-font-7','3','','.w-quote'),(475068,'furniture-mobile','.w-quote .multicart .count','color','$color-font-9','','','.w-quote'),(475069,'furniture-mobile','.w-quote .multicart .item.current-multi-cart .switch-cart','color','$color-font-7','3','','.w-quote'),(475070,'furniture-mobile','.w-quote .multicart .switch-cart','color','$color-font-3','','','.w-quote'),(475071,'furniture-mobile','.w-quote .multicart a.switch-cart','color','$attention-color','1','','.w-quote'),(475072,'furniture-mobile','.w-cart .cart-content','color','$color-font-7','','','.w-cart'),(475073,'furniture-mobile','.w-account .account-dropdown','color','$color-font-7','','','.w-account'),(475074,'furniture-mobile','.b-quantity .qty-box .bigger','color','$color-font-7','','','.b-quantity'),(475075,'furniture-mobile','.b-quantity .qty-box .smaller','color','$color-font-7','','','.b-quantity'),(475076,'furniture-mobile','.rating-0, .rating-1, .rating-2, .rating-3, .rating-4, .rating-5','color','$color-font-7','','',''),(475077,'furniture-mobile','.w-product-sale-ends .ends','color','$attention-color','','','.w-product-sale-ends'),(475078,'furniture-mobile','.w-product-sale-ends .left-count-days-text','color','$color-font-7','','','.w-product-sale-ends'),(475079,'furniture-mobile','.w-product-sale-ends .left-count-hours-text','color','$color-font-7','','','.w-product-sale-ends'),(475080,'furniture-mobile','.w-product-quantity .qty_packs .price_1','color','$color-font-3','4','','.w-product-quantity'),(475081,'furniture-mobile','.w-product-quantity .qty-input input[type=\'text\']','color','$color-font-7','','','.w-product-quantity'),(475082,'furniture-mobile','.w-product-bonus-points > div > div','color','$color-font-7','','','.w-product-bonus-points'),(475083,'furniture-mobile','.warrantyProduct div','color','$color-font-7','','','.warrantyProduct'),(475084,'furniture-mobile','.w-files-catalog-widgets-files-catalog .name a','color','$color-font-1','','','.w-files-catalog-widgets-files-catalog'),(475085,'furniture-mobile','.w-files-catalog-widgets-files-list .file','color','$color-font-7','3','','.w-files-catalog-widgets-files-list'),(475086,'furniture-mobile','.w-sample .cart-box-link','color','$color-font-7','3','','.w-sample'),(475087,'furniture-mobile','.w-sample .cart-content','color','$color-font-7','','','.w-sample'),(475088,'furniture-mobile','.w-sample .multicart .count','color','$color-font-9','','','.w-sample'),(475089,'furniture-mobile','.w-sample .multicart .item.current-multi-cart .switch-cart','color','$color-font-7','3','','.w-sample'),(475090,'furniture-mobile','.w-sample .multicart .switch-cart','color','$color-font-3','','','.w-sample'),(475091,'furniture-mobile','.w-sample .multicart a.switch-cart','color','$attention-color','1','','.w-sample'),(475092,'furniture-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','color','$color-font-7','3','','.w-cart-gift-certificate'),(475093,'furniture-mobile','.w-account-address-book .add_item a','color','$color-font-3','3','','.w-account-address-book'),(475094,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','color','inherit','','','.b-products-listing'),(475095,'furniture-mobile','.b-pagination .pagination span','color','$color-font-1','2','','.b-pagination'),(475096,'furniture-mobile','.b-products-listing .products-listing.list-rows .stock','color','$message-color','','','.b-products-listing'),(475097,'furniture-mobile','.b-products-listing .products-listing.list-b2b .stock','color','$message-color','','','.b-products-listing'),(475098,'furniture-mobile','.w-product-collection .save','color','$message-color','','','.w-product-collection'),(475099,'furniture-mobile','.w-product-collection .right-area .separate-text, .w-product-collection .right-area .separate','color','$color-font-9','','','.w-product-collection'),(475100,'furniture-mobile','.w-product-collection .together','color','$color-font-7','','','.w-product-collection'),(475101,'furniture-mobile','.w-product-collection .choose-products .heading-3','color','$color-font-7','','','.w-product-collection'),(475102,'furniture-mobile','.price .special-promote','color','$message-color','','',''),(475103,'furniture-mobile','.w-product-in-bundles .bundle_price .old','color','$color-font-9','','','.w-product-in-bundles'),(475104,'furniture-mobile','.w-product-in-bundles .bundle_price .specials','color','$attention-color','','','.w-product-in-bundles'),(475105,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','color','$color-font-3','','','.w-questionnaire-widgets-questionnaire'),(475106,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','color','$attention-color','','','.w-questionnaire-widgets-questionnaire'),(475107,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','color','$message-color','','','.w-questionnaire-widgets-questionnaire'),(475108,'furniture-mobile','.w-product-groups .radioBox label input:checked + div .val1','color','$color-font-7','','','.w-product-groups'),(475109,'furniture-mobile','.w-product-groups .val1','color','$color-font-7','','','.w-product-groups'),(475110,'furniture-mobile','.w-product-groups .val2','color','$color-font-7','','','.w-product-groups'),(475111,'furniture-mobile','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(475112,'furniture-mobile','.w-product-custom-bundle .right-area .separate','color','$attention-color','','','.w-product-custom-bundle'),(475113,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','color','$color-font-7','1','','.w-delivery-location-location-list'),(475114,'furniture-mobile','.w-sale-category .badge','color','$color-font-1','','','.w-sale-category'),(475115,'furniture-mobile','.w-sale-category .ends','color','$attention-color','','','.w-sale-category'),(475116,'furniture-mobile','.w-sale-category .left-count-days-text','color','$color-font-1','','','.w-sale-category'),(475117,'furniture-mobile','.w-sale-category .left-count-hours-text','color','$color-font-1','','','.w-sale-category'),(475118,'furniture-mobile','.w-sale-category .special-price','color','$attention-color','','','.w-sale-category'),(475119,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','color','$color-font-7','','','.w-product-properties-icons'),(475120,'furniture-mobile','.w-product-properties-icons .hover-box-content','color','transparent','','','.w-product-properties-icons'),(475121,'furniture-mobile','.w-delivery-location-product-categories .name','color','$color-font-7','','','.w-delivery-location-product-categories'),(475122,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','color','$color-font-1','','','.w-wedding-registry-widgets-search-paging'),(475123,'furniture-mobile','.w-product-designer-designer .grnamebox .title-sortable','color','$color-font-7','','','.w-product-designer-designer'),(475124,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','color','$color-font-7','','','.w-product-designer-designer'),(475125,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','color','$color-font-10','','','.w-press-reviews-widgets-press-reviews-small'),(475126,'furniture-mobile','.w-press-reviews-widgets-press-reviews .date','color','$color-font-9','','','.w-press-reviews-widgets-press-reviews'),(475127,'furniture-mobile','.w-press-reviews-widgets-press-reviews .full-review a','color','$color-font-10','','','.w-press-reviews-widgets-press-reviews'),(475128,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .date-added','color','$color-font-3','','','.w-press-reviews-widgets-press-reviews-list'),(475129,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .out-link a','color','$color-font-10','','','.w-press-reviews-widgets-press-reviews-list'),(475130,'furniture-mobile','.b-products-listing .productGroup label a','color','$color-font-7','','','.b-products-listing'),(475131,'furniture-mobile','.w-gift-wrap-message-checkout .error','color','$attention-color','','','.w-gift-wrap-message-checkout'),(475132,'furniture-mobile','.w-support-system-listing .support-head','color','$color-font-10','','','.w-support-system-listing'),(475133,'furniture-mobile','.w-rma-returns-history .column .title','color','$color-font-1','','','.w-rma-returns-history'),(475134,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','color','transparent','','','.w-rma-returns-history'),(475135,'furniture-mobile','.w-rma-returns-history .icons .excel','color','$message-color','3','','.w-rma-returns-history'),(475136,'furniture-mobile','.w-rma-returns-history .icons .print','color','$color-font-7','','','.w-rma-returns-history'),(475137,'furniture-mobile','.w-rma-returns-history .linkButton','color','$color-font-10','','','.w-rma-returns-history'),(475138,'furniture-mobile','.w-rma-returns-history .linkButton','color','$color-font-10','1','','.w-rma-returns-history'),(475139,'furniture-mobile','.w-rma-returns-history thead tr','color','$color-font-1','','','.w-rma-returns-history'),(475140,'furniture-mobile','.w-rma-returns-history thead tr td','color','$color-font-1','','','.w-rma-returns-history'),(475141,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .goto-button a','color','$color-font-7','','','.b-menu-style-1'),(475142,'furniture-mobile','.b-products-listing .promos-info .promo-name-span','color','$attention-color','','','.b-products-listing'),(475143,'furniture-mobile','.w-predefined-promotion .cart_discount .heading-3','color','$warning-color','','','.w-predefined-promotion'),(475144,'furniture-mobile','.w-predefined-promotion .cart_discount .promo-date','color','$warning-color','3','','.w-predefined-promotion'),(475145,'furniture-mobile','.w-predefined-promotion .multidiscount .promo-date, .w-predefined-promotion .multidiscount .heading-3','color','$attention-color','','','.w-predefined-promotion'),(475146,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','color','$color-font-8','','','.w-predefined-promotion'),(475147,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','color','$attention-color','','','.w-predefined-promotion'),(475148,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range, .w-predefined-promotion .prom-multi-discount > .heading','color','$attention-color','3','','.w-predefined-promotion'),(475149,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .item a','color','$color-font-8','','','.w-predefined-promotion'),(475150,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','color','$warning-color','3','','.w-predefined-promotion'),(475151,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','color','$attention-color','','','.w-predefined-promotion'),(475152,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','color','$attention-color','','','.w-predefined-promotion'),(475153,'furniture-mobile','.w-predefined-promotion .promo-salemaker .content a','color','$color-font-8','','','.w-predefined-promotion'),(475154,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','color','$warning-color','','','.w-predefined-promotion'),(475155,'furniture-mobile','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .specials_category .promo-conditions','color','$warning-color','3','','.w-predefined-promotion'),(475156,'furniture-mobile','.w-predefined-promotion .specials_category .heading-3','color','$warning-color','','','.w-predefined-promotion'),(475157,'furniture-mobile','.w-predefined-promotion .specials_category .promo-salemaker .content a, .w-predefined-promotion .specials_category .promo-date','color','$warning-color','3','','.w-predefined-promotion'),(475158,'furniture-mobile','.w-supplier-purchase-supplier-products .active .select_item > div:before','color','$message-color','','','.w-supplier-purchase-supplier-products'),(475159,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','color','$color-font-3','','','.w-filters'),(475160,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','color','$color-font-7','','','.w-filters'),(475161,'furniture-mobile','.account-address-book .leftMes div','color','$attention-color','','','.account-address-book'),(475162,'furniture-mobile','.account-address-book .leftMes ul','color','$attention-color','','','.account-address-book'),(475163,'furniture-mobile','.account-address-book .rightMes ul','color','$attention-color','','','.account-address-book'),(475164,'furniture-mobile','.account-order-history .moduleRowDue td','color','$color-font-3','','','.account-order-history'),(475165,'furniture-mobile','.account-order-history .not_fully_paid_td','color','$attention-color','','','.account-order-history'),(475166,'furniture-mobile','.account-order-history .view_link','color','$color-font-7','','','.account-order-history'),(475167,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','color','$color-font-7','3','','.account-order-history-info'),(475168,'furniture-mobile','.account-order-history-info .not_fully_paid_td','color','$attention-color','','','.account-order-history-info'),(475169,'furniture-mobile','.account-index .account_info .info .info_span','color','$color-font-8','','','.account-index'),(475170,'furniture-mobile','.account-index .date_title','color','$color-font-8','','','.account-index'),(475171,'furniture-mobile','.account-index .date_value','color','$attention-color','','','.account-index'),(475172,'furniture-mobile','.account-index .date_value strong','color','$color-font-8','','','.account-index'),(475173,'furniture-mobile','.account-index .leftMes div','color','$attention-color','','','.account-index'),(475174,'furniture-mobile','.account-index .leftMes ul','color','$attention-color','','','.account-index'),(475175,'furniture-mobile','.account-index .moduleRowDue td','color','$color-font-3','','','.account-index'),(475176,'furniture-mobile','.account-index .not_fully_paid_td','color','$attention-color','','','.account-index'),(475177,'furniture-mobile','.account-index .remove-btn','color','$color-font-9','','','.account-index'),(475178,'furniture-mobile','.account-index .rightMes ul','color','$attention-color','','','.account-index'),(475179,'furniture-mobile','.account-index .topAccount > li > div','color','$attention-color','3','','.account-index'),(475180,'furniture-mobile','.account-index .view_history','color','$color-font-7','','','.account-index'),(475181,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','color','$color-font-7','3','','.account-order-pay'),(475182,'furniture-mobile','.account-order-pay .not_fully_paid_td','color','$attention-color','','','.account-order-pay'),(475183,'furniture-mobile','.account-samples .moduleRowDue td','color','$color-font-3','','','.account-samples'),(475184,'furniture-mobile','.account-samples .not_fully_paid_td','color','$attention-color','','','.account-samples'),(475185,'furniture-mobile','.account-samples .view_link','color','$color-font-7','','','.account-samples'),(475186,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','color','$color-font-7','3','','.account-sample-info'),(475187,'furniture-mobile','.account-sample-info .not_fully_paid_td','color','$attention-color','','','.account-sample-info'),(475188,'furniture-mobile','.catalog-product-wrap .pn-direction','color','$color-font-7','','','.catalog-product-wrap'),(475189,'furniture-mobile','.catalog-product-wrap .pn-image','color','$color-font-3','3','','.catalog-product-wrap'),(475190,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','color','$color-font-7','','','.checkout-index-wrap'),(475191,'furniture-mobile','.checkout-index-wrap .edit-address-popup .edit-ab','color','$color-font-7','','','.checkout-index-wrap'),(475192,'furniture-mobile','.checkout-index-wrap .order-ico','color','$color-font-7','3','','.checkout-index-wrap'),(475193,'furniture-mobile','.checkout-index-wrap .pay-ico','color','$color-font-7','3','','.checkout-index-wrap'),(475194,'furniture-mobile','.checkout-index-wrap .ship-ico','color','$color-font-7','3','','.checkout-index-wrap'),(475195,'furniture-mobile','.checkout-order-confirmation .comment-ico','color','$color-font-7','3','','.checkout-order-confirmation'),(475196,'furniture-mobile','.checkout-order-confirmation .discount-ico','color','$color-font-7','3','','.checkout-order-confirmation'),(475197,'furniture-mobile','.checkout-order-confirmation .order-ico','color','$color-font-7','3','','.checkout-order-confirmation'),(475198,'furniture-mobile','.checkout-order-confirmation .ship-ico','color','$color-font-7','3','','.checkout-order-confirmation'),(475199,'furniture-mobile','.checkout-success-wrap .page-success .text-1','color','$color-font-7','3','','.checkout-success-wrap'),(475200,'furniture-mobile','.checkout-success-wrap .page-success .text-3','color','$attention-color','','','.checkout-success-wrap'),(475201,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.p-quick-order-index'),(475202,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.p-quick-order-index'),(475203,'furniture-mobile','a.btn-2','color_important','important','','',''),(475204,'furniture-mobile','a.btn-3','color_important','important','','',''),(475205,'furniture-mobile','a.btn-1','color_important','important','','',''),(475206,'furniture-mobile','a.btn','color_important','important','','',''),(475207,'furniture-mobile','.b-select-suggest .select2-default','color_important','important','','','.b-select-suggest'),(475208,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.b-data-table'),(475209,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.b-data-table'),(475210,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','color_important','important','','','.w-rma-returns-history'),(475211,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','content','\\f003','3','','.w-checkout-contact-information'),(475212,'furniture-mobile','.heading-4 .edit, h4 .edit','content','\\e917','4','',''),(475214,'furniture-mobile','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(475216,'furniture-mobile','.message.success','content','\\e918','3','',''),(475217,'furniture-mobile','.p-wedding-registry-view h1','content','\\f004','4','','.p-wedding-registry-view'),(475218,'furniture-mobile','.w-cart a.item','content','\\_','4','','.w-cart'),(475219,'furniture-mobile','.p-quick-order-index .paginate_button.next','content','\\f105','3','','.p-quick-order-index'),(475220,'furniture-mobile','.p-quick-order-index .paginate_button.previous','content','\\f104','3','','.p-quick-order-index'),(475221,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range .promo-prod-qty','content',',','4','','.w-promotions'),(475222,'furniture-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','content','\\_','3','','.w-promotions'),(475223,'furniture-mobile','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(475224,'furniture-mobile','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(475225,'furniture-mobile','.p-blog-index .nav-next a','content','\\f138','3','','.p-blog-index'),(475226,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(475227,'furniture-mobile','.w-account .account-dropdown','content','\\_','4','','.w-account'),(475228,'furniture-mobile','.w-account .my-acc-link','content','\\f007','3','','.w-account'),(475229,'furniture-mobile','.p-wedding-registry-view h1','content','\\f004','4','','.p-wedding-registry-view'),(475230,'furniture-mobile','.p-wedding-registry-view h1','content','\\f004','3','','.p-wedding-registry-view'),(475231,'furniture-mobile','.w-wedding-registry-widgets-share-link a','content','|','4','','.w-wedding-registry-widgets-share-link'),(475232,'furniture-mobile','.w-wedding-registry-widgets-share-link a','content','\\f045','3','','.w-wedding-registry-widgets-share-link'),(475233,'furniture-mobile','.w-wedding-registry-widgets-manage-names .names-separator','content','\\f004','3','','.w-wedding-registry-widgets-manage-names'),(475234,'furniture-mobile','.w-wedding-registry-widgets-search-registry-button a','content','\\f002','3','','.w-wedding-registry-widgets-search-registry-button'),(475235,'furniture-mobile','.w-wedding-registry-widgets-products .remove-btn','content','\\f00d','3','','.w-wedding-registry-widgets-products'),(475236,'furniture-mobile','.p-sample-checkout-success .page-success','content','\\_','0,3','','.p-sample-checkout-success'),(475237,'furniture-mobile','.p-sample-checkout-success .page-success .text-1','content','\\e916','3','','.p-sample-checkout-success'),(475238,'furniture-mobile','.p-reviews-info .review-info-text','content','\\_','4','','.p-reviews-info'),(475239,'furniture-mobile','.w-promotions .prom-multi-discount','content','\\_','4','','.w-promotions'),(475240,'furniture-mobile','.p-blog-index .nav-previous a','content','\\f137','3','','.p-blog-index'),(475241,'furniture-mobile','.p-blog-index .nav-next a','content','\\f138','3','','.p-blog-index'),(475242,'furniture-mobile','.p-blog-index .entry-content','content','\\_','4','','.p-blog-index'),(475243,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(475244,'furniture-mobile','.testimonials .review','content','\\_','3','',''),(475245,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(475246,'furniture-mobile','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(475247,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','content','\\_','','','.w-compare-box-item'),(475248,'furniture-mobile','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(475249,'furniture-mobile','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(475250,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','content','\\f00c','','','.w-compare-box-item'),(475251,'furniture-mobile','.w-promotions .prom-multi-discount > .heading','content','\\_','3','','.w-promotions'),(475252,'furniture-mobile','.w-promotions .nextdiscount .heading','content','\\f07a','3','','.w-promotions'),(475253,'furniture-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','content','\\_','3','','.w-promotions'),(475254,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','content','\\f041','3','','.b-warehouses-popup'),(475255,'furniture-mobile','.b-warehouses-popup .warehouses-popup-link','content','\\f041','3','','.b-warehouses-popup'),(475256,'furniture-mobile','.b-preloader .preloader','content','\\f110','3','','.b-preloader'),(475257,'furniture-mobile','.w-product-available-in-warehouses .content','content','\\_','4','','.w-product-available-in-warehouses'),(475258,'furniture-mobile','.b-products-listing .products-listing .mix-attributes','content','\\_','4','','.b-products-listing'),(475259,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','content','\\f00c','','','.w-compare-box-item'),(475260,'furniture-mobile','.w-menu-slider .close','content','\\f00d','3','','.w-menu-slider'),(475261,'furniture-mobile','.w-cart .cart-box-link','content','\\e90d','3','','.w-cart'),(475262,'furniture-mobile','.order-summary .price-row.ot_gv .title','content','\\e99f','3','','.order-summary'),(475263,'furniture-mobile','.p-wedding-registry-view h1','content','\\f004','4','','.p-wedding-registry-view'),(475264,'furniture-mobile','.p-blog-index .comment-meta','content','\\_','4','','.p-blog-index'),(475265,'furniture-mobile','.p-blog-index .entry-content','content','\\_','4','','.p-blog-index'),(475266,'furniture-mobile','.p-blog-index .nav-previous a','content','\\f137','3','','.p-blog-index'),(475267,'furniture-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(475268,'furniture-mobile','.b-messages .messBtnMenuUnread','content','\\f097','3','','.b-messages'),(475269,'furniture-mobile','.b-messages .messBtnMenuDelete','content','\\e913','3','','.b-messages'),(475270,'furniture-mobile','.b-messages span.starred::before','content','\\e90e','','','.b-messages'),(475271,'furniture-mobile','.b-messages .dataTables_wrapper > .top','content','\\_','4','','.b-messages'),(475272,'furniture-mobile','.b-messages .messBtnMenuStarred','content','\\e90e','3','','.b-messages'),(475273,'furniture-mobile','.b-messages .icon-circle-with-cross::before','content','×','','','.b-messages'),(475274,'furniture-mobile','.w-languages .current','content','\\e902','3','','.w-languages'),(475275,'furniture-mobile','.b-messages .dataTables_wrapper > .bottom','content','\\_','4','','.b-messages'),(475276,'furniture-mobile','.w-text .customer-service','content','\\e907','3','','.w-text'),(475277,'furniture-mobile','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(475278,'furniture-mobile','.p-blog-index .wp-widget li','content','\\f111','3','','.p-blog-index'),(475279,'furniture-mobile','.p-blog-index .nav-previous a','content','\\f137','3','','.p-blog-index'),(475280,'furniture-mobile','.p-blog-index .comment-meta','content','\\_','4','','.p-blog-index'),(475281,'furniture-mobile','.p-account-trade-form .wd-line-row-2','content','\\_','4','','.p-account-trade-form'),(475282,'furniture-mobile','.b-info .info','content','\\e918','3','','.b-info'),(475283,'furniture-mobile','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(475284,'furniture-mobile','.w-menu-slider .close','content','\\f00d','3','','.w-menu-slider'),(475285,'furniture-mobile','.p-payer-order-confirmation .ship-ico','content','\\e94e','3','','.p-payer-order-confirmation'),(475286,'furniture-mobile','.p-payer-order-confirmation .order-ico','content','\\e922','3','','.p-payer-order-confirmation'),(475287,'furniture-mobile','.p-payer-order-confirmation .pay-ico','content','\\e99e','3','','.p-payer-order-confirmation'),(475288,'furniture-mobile','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(475289,'furniture-mobile','.p-payer-order-confirmation .discount-ico','content','\\e95e','3','','.p-payer-order-confirmation'),(475290,'furniture-mobile','.p-payer-order-confirmation .comment-ico','content','\\e99d','3','','.p-payer-order-confirmation'),(475291,'furniture-mobile','.p-payer-order-pay .ship-ico','content','\\e94e','3','','.p-payer-order-pay'),(475292,'furniture-mobile','.p-payer-order-pay .pay-ico','content','\\e99e','3','','.p-payer-order-pay'),(475293,'furniture-mobile','.p-payer-order-pay .order-ico','content','\\e922','3','','.p-payer-order-pay'),(475294,'furniture-mobile','.p-payer-order-pay .discount-ico','content','\\e95e','3','','.p-payer-order-pay'),(475295,'furniture-mobile','.p-payer-order-pay .comment-ico','content','\\e99d','3','','.p-payer-order-pay'),(475296,'furniture-mobile','.b-fancybox .fancybox-close','content','\\f00d','3','','.b-fancybox'),(475297,'furniture-mobile','.b-messages .select2-search-choice-close','content','\\e913','3','','.b-messages'),(475298,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','content','\\f095','3','','.w-checkout-contact-information'),(475299,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','content','ttr(data-content','4','','.b-switch'),(475300,'furniture-mobile','.b-rating .glyphicon-chevron-left','content','\\f104','3','','.b-rating'),(475301,'furniture-mobile','.w-product-reviews .reviews-list .review','content','\\_','3','','.w-product-reviews'),(475302,'furniture-mobile','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(475303,'furniture-mobile','.bell-ico .heading-2','content','\\e9a7','3','','.bell-ico'),(475304,'furniture-mobile','.p-account-trade-form .wd-line-row-2','content','\\_','4','','.p-account-trade-form'),(475306,'furniture-mobile','.b-rating .glyphicon-chevron-right','content','\\f105','3','','.b-rating'),(475307,'furniture-mobile','.p-blog-index .comment-meta','content','\\_','4','','.p-blog-index'),(475308,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','content','\\f1f8','3','','.w-upload-customer-id-upload-customer-id-form'),(475309,'furniture-mobile','.b-info .info','content','\\e918','3','','.b-info'),(475310,'furniture-mobile','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(475311,'furniture-mobile','.w-coupons-and-vauchers-checkout .btn-remove','content','\\e913','3','','.w-coupons-and-vauchers-checkout'),(475312,'furniture-mobile','.w-login-block .cols','content','\\_','4','','.w-login-block'),(475313,'furniture-mobile','.w-menu-slider .close','content','\\f00d','3','','.w-menu-slider'),(475314,'furniture-mobile','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(475315,'furniture-mobile','.heading-settings .heading-4','content','\\e99a','3','','.heading-settings'),(475316,'furniture-mobile','.order-summary .price-row.ot_bonus_points .title','content','\\e9a9','3','','.order-summary'),(475318,'furniture-mobile','.b-info .info','content','\\e918','3','','.b-info'),(475319,'furniture-mobile','.b-bottom .closeable-heading','content','\\f068','3','','.b-bottom'),(475320,'furniture-mobile','.b-bottom .closeable-heading.closed','content','\\f067','3','','.b-bottom'),(475321,'furniture-mobile','.p-blog-index .entry-content','content','\\_','4','','.p-blog-index'),(475322,'furniture-mobile','.p-blog-index .comment-meta','content','\\_','4','','.p-blog-index'),(475323,'furniture-mobile','.p-account-trade-form .wd-line-row-2','content','\\_','4','','.p-account-trade-form'),(475324,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','content','\\f00c','3','','.b-form'),(475325,'furniture-mobile','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(475326,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','content',' ','3','','.b-switch'),(475327,'furniture-mobile','.p-account-trade-form .wd-line-row-2','content','\\_','4','','.p-account-trade-form'),(475328,'furniture-mobile','.p-blog-index .comment-meta','content','\\_','4','','.p-blog-index'),(475329,'furniture-mobile','.w-social-links .stumbleupon','content','\\f1a4','3','','.w-social-links'),(475330,'furniture-mobile','.p-reviews-info .review-info-text','content','\\_','4','','.p-reviews-info'),(475331,'furniture-mobile','.p-wedding-registry-view h1','content','\\f004','3','','.p-wedding-registry-view'),(475332,'furniture-mobile','.buttons','content','\\_','4','',''),(475333,'furniture-mobile','.out-stock-icon','content','\\f10c','3','',''),(475334,'furniture-mobile','.in-stock-icon','content','\\f00c','3','',''),(475335,'furniture-mobile','.transit-icon','content','\\f133','3','',''),(475336,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','content','\\f067','3','','.w-menu'),(475337,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','content','\\f00c','','','.w-compare-box-item'),(475338,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','content','\\f068','3','','.w-menu'),(475339,'furniture-mobile','.w-cart-compare .atr-col','content','\\f070','3','','.w-cart-compare'),(475340,'furniture-mobile','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(475341,'furniture-mobile','.b-rating .glyphicon-chevron-up','content','\\f106','3','','.b-rating'),(475342,'furniture-mobile','.w-menu .menu .menu-ico','content','\\e91b','3','','.w-menu'),(475343,'furniture-mobile','.w-tabs .tab-li.tab-sample a','content','\\e984','3','','.w-tabs'),(475344,'furniture-mobile','.b-upload-file .upload-file-wrap .upload-remove','content','\\e913','3','','.b-upload-file'),(475345,'furniture-mobile','.p-account-trade-form .wd-line-row-2','content','\\_','4','','.p-account-trade-form'),(475346,'furniture-mobile','.w-catalog-paging .prev','content','\\f104','3','','.w-catalog-paging'),(475347,'furniture-mobile','.w-chat .w-chat-box a','content','\\f075','3','','.w-chat'),(475348,'furniture-mobile','.b-bottom .footerTitle','content','\\f067','2876,4','','.b-bottom'),(475349,'furniture-mobile','.closeable-heading','content','\\f067','3','',''),(475350,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','content','\\25be','3','','.b-select-suggest'),(475351,'furniture-mobile','.w-menu .menu .menu-ico','content','\\e91b','3','','.w-menu'),(475352,'furniture-mobile','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(475353,'furniture-mobile','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(475354,'furniture-mobile','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(475355,'furniture-mobile','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(475356,'furniture-mobile','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(475357,'furniture-mobile','.w-search .button-search','content','\\e90a','3','','.w-search'),(475358,'furniture-mobile','.w-top-categories .categories','content','\\_','4','','.w-top-categories'),(475359,'furniture-mobile','.w-checkout-billing-address .addresses','content','\\_','4','','.w-checkout-billing-address'),(475360,'furniture-mobile','.w-text .customer-service','content','\\e907','3','','.w-text'),(475361,'furniture-mobile','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(475362,'furniture-mobile','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(475363,'furniture-mobile','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(475365,'furniture-mobile','.heading-ordered-items .heading-4','content','\\e99b','3','','.heading-ordered-items'),(475366,'furniture-mobile','.view-all .btn','content','\\f054','4','',''),(475367,'furniture-mobile','.view-all','content','\\_','3','',''),(475368,'furniture-mobile','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(475369,'furniture-mobile','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(475370,'furniture-mobile','.b-form .newsletter-row','content','\\_','4','','.b-form'),(475371,'furniture-mobile','.b-info .info','content','\\e918','3','','.b-info'),(475372,'furniture-mobile','.w-checkout-shipping-address .addresses','content','\\_','4','','.w-checkout-shipping-address'),(475374,'furniture-mobile','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(475375,'furniture-mobile','.p-wedding-registry-view h1','content','\\f004','4','','.p-wedding-registry-view'),(475377,'furniture-mobile','.w-quote .cart-box-link','content','\\e90d','3','','.w-quote'),(475378,'furniture-mobile','.w-tabs .tab-li.tab-wishlist a','content','\\e992','3','','.w-tabs'),(475379,'furniture-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','content','\\f013','3','','.w-multi-cart-actions'),(475380,'furniture-mobile','.w-text .customer-service','content','\\e907','3','','.w-text'),(475381,'furniture-mobile','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(475382,'furniture-mobile','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(475383,'furniture-mobile','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(475384,'furniture-mobile','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(475385,'furniture-mobile','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(475386,'furniture-mobile','.btn-edit','content','\\e917','3','',''),(475387,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(475388,'furniture-mobile','.w-login-block .cols','content','\\_','4','','.w-login-block'),(475389,'furniture-mobile','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(475390,'furniture-mobile','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(475391,'furniture-mobile','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(475392,'furniture-mobile','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(475393,'furniture-mobile','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(475394,'furniture-mobile','.p-blog-index .entry-content','content','\\_','4','','.p-blog-index'),(475395,'furniture-mobile','.p-blog-index .wp-widget li','content','\\f111','3','','.p-blog-index'),(475396,'furniture-mobile','.b-rating .glyphicon-time','content','\\f017','3','','.b-rating'),(475397,'furniture-mobile','.w-menu-slider .close','content','\\f00d','3','','.w-menu-slider'),(475398,'furniture-mobile','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(475399,'furniture-mobile','.heading-saved-lists .heading-4','content','\\e99c','3','','.heading-saved-lists'),(475400,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(475401,'furniture-mobile','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(475402,'furniture-mobile','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(475403,'furniture-mobile','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(475404,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','content','\\f067','3','','.w-menu'),(475405,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','content','\\f068','3','','.w-menu'),(475406,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','content','\\_','','','.w-checkout-shipping-choice'),(475407,'furniture-mobile','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(475408,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(475409,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(475410,'furniture-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','content','\\f058','','','.w-filters'),(475411,'furniture-mobile','.heading-3 .edit, h3 .edit','content','\\e917','4','',''),(475412,'furniture-mobile','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(475413,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(475414,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','content','ttr(data-content','4','','.b-switch'),(475415,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','content',' ','3','','.b-switch'),(475416,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','content','ttr(data-content','4','','.b-switch'),(475418,'furniture-mobile','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(475419,'furniture-mobile','.w-cart-bonus-points .btn-remove','content','\\e913','3','','.w-cart-bonus-points'),(475420,'furniture-mobile','.savings-ico .heading-2','content','\\e95e','3','','.savings-ico'),(475421,'furniture-mobile','.w-cart-compare .product-actions .dropdown-toggle','content','\\f013','3','','.w-cart-compare'),(475422,'furniture-mobile','.w-text .customer-service','content','\\e907','3','','.w-text'),(475423,'furniture-mobile','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(475424,'furniture-mobile','.w-text .customer-service','content','\\e907','3','','.w-text'),(475425,'furniture-mobile','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(475426,'furniture-mobile','.w-reviews .review','content','\\_','3','','.w-reviews'),(475427,'furniture-mobile','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(475428,'furniture-mobile','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(475429,'furniture-mobile','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(475430,'furniture-mobile','.js-stock-icon','content','\\f00c','3','',''),(475431,'furniture-mobile','.testimonials .heading-3','content','\\e908','3','',''),(475432,'furniture-mobile','.b-switch .candlestick-wrapper .fa-check','content','\\f00c','3','','.b-switch'),(475433,'furniture-mobile','.b-switch .candlestick-wrapper .fa-times','content','\\f00d','3','','.b-switch'),(475434,'furniture-mobile','.b-fancybox .fancybox-prev span','content','\\e900','3','','.b-fancybox'),(475435,'furniture-mobile','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(475436,'furniture-mobile','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(475437,'furniture-mobile','.w-list-b2b .attributes','content','\\_','4','','.w-list-b2b'),(475438,'furniture-mobile','.w-personal-gift-status-bar .inform','content','\\e6a0','4','','.w-personal-gift-status-bar'),(475439,'furniture-mobile','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(475440,'furniture-mobile','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(475441,'furniture-mobile','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(475442,'furniture-mobile','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(475443,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(475444,'furniture-mobile','.p-wedding-registry-view h1','content','\\f004','3','','.p-wedding-registry-view'),(475445,'furniture-mobile','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(475446,'furniture-mobile','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(475447,'furniture-mobile','.b-info .info','content','\\e918','3','','.b-info'),(475448,'furniture-mobile','.w-reviews .heading-3','content','\\e908','3','','.w-reviews'),(475449,'furniture-mobile','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(475450,'furniture-mobile','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(475451,'furniture-mobile','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(475453,'furniture-mobile','.w-social-links .instagram','content','\\f16d','3','','.w-social-links'),(475454,'furniture-mobile','.w-social-links .linkedin','content','\\f0e1','3','','.w-social-links'),(475455,'furniture-mobile','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(475456,'furniture-mobile','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(475457,'furniture-mobile','.w-login-block .cols','content','\\_','4','','.w-login-block'),(475458,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','content','\\f1db','','','.b-form'),(475459,'furniture-mobile','.b-info .info','content','\\e918','3','','.b-info'),(475460,'furniture-mobile','.w-cart-compare .product','content','\\_','4','','.w-cart-compare'),(475461,'furniture-mobile','.btn-del','content','\\f1f8','4','',''),(475462,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','content','\\f00c','','','.w-compare-box-item'),(475463,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','content','\\_','','','.w-compare-box-item'),(475464,'furniture-mobile','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(475465,'furniture-mobile','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(475466,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','content','\\f067','3','','.w-menu'),(475467,'furniture-mobile','.w-checkout-bonus-points .btn-remove','content','\\e913','3','','.w-checkout-bonus-points'),(475468,'furniture-mobile','.b-rating .glyphicon-star.coloron','content','\\f005','3','','.b-rating'),(475469,'furniture-mobile','.w-cart-compare .delete-cart','content','\\2573','3','','.w-cart-compare'),(475470,'furniture-mobile','.w-cart-shipping-estimator .shipping-estimator','content','\\_','4','','.w-cart-shipping-estimator'),(475471,'furniture-mobile','.p-reviews-info .review-info-text','content','\\_','4','','.p-reviews-info'),(475472,'furniture-mobile','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(475473,'furniture-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','content','\\f058','','','.b-form'),(475474,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(475475,'furniture-mobile','.b-form .addresses','content','\\_','4','','.b-form'),(475476,'furniture-mobile','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(475478,'furniture-mobile','.w-cart-credit-amount .btn-remove','content','\\e913','3','','.w-cart-credit-amount'),(475479,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','content','\\f068','3','','.w-menu'),(475480,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','content','\\f00c','','','.w-compare-box-item'),(475481,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(475482,'furniture-mobile','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(475483,'furniture-mobile','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(475484,'furniture-mobile','.p-wedding-registry-view h1','content','\\f004','4','','.p-wedding-registry-view'),(475485,'furniture-mobile','.p-reviews-info .review-info-text','content','\\_','4','','.p-reviews-info'),(475486,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','content','\\f068','3','','.w-menu'),(475487,'furniture-mobile','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(475488,'furniture-mobile','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(475489,'furniture-mobile','.b-info-popup .info-popup','content','\\e918','3','','.b-info-popup'),(475490,'furniture-mobile','.w-tabs .tab-li.tab-cart a','content','\\e90d','3','','.w-tabs'),(475491,'furniture-mobile','.p-blog-index .wp-widget li','content','\\f111','3','','.p-blog-index'),(475492,'furniture-mobile','.p-blog-index .nav-previous a','content','\\f137','3','','.p-blog-index'),(475493,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(475495,'furniture-mobile','.b-upload-file .snapshot','content','\\f030','3','','.b-upload-file'),(475496,'furniture-mobile','.b-form .columns','content','\\_','4','','.b-form'),(475497,'furniture-mobile','.b-bottom .footerTitle','content','\\f068','2876,2,4','','.b-bottom'),(475498,'furniture-mobile','.b-bottom .pop-up-close','content','\\f00d','3','','.b-bottom'),(475499,'furniture-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','content','\\f004','','','.b-products-listing'),(475500,'furniture-mobile','.w-cart-shipping-estimator .address-item .lastname','content','\\_','4','','.w-cart-shipping-estimator'),(475501,'furniture-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','content','\\f08a','','','.b-products-listing'),(475502,'furniture-mobile','.b-upload-files .remove-file','content','\\f014','3','','.b-upload-files'),(475503,'furniture-mobile','.w-reviews-content .review','content','\\_','3','','.w-reviews-content'),(475504,'furniture-mobile','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(475505,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(475506,'furniture-mobile','.w-social-links .facebook','content','\\f09a','3','','.w-social-links'),(475507,'furniture-mobile','.b-fancybox .fancybox-next span','content','\\e901','3','','.b-fancybox'),(475509,'furniture-mobile','.w-product-customers-activity .close','content','\\2715','3','','.w-product-customers-activity'),(475510,'furniture-mobile','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(475511,'furniture-mobile','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(475512,'furniture-mobile','.w-categories .categories','content','\\_','4','','.w-categories'),(475513,'furniture-mobile','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(475514,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(475516,'furniture-mobile','.w-login-block .cols','content','\\_','4','','.w-login-block'),(475517,'furniture-mobile','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(475518,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','content','\\f00c','','','.w-compare-box-item'),(475519,'furniture-mobile','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(475520,'furniture-mobile','.w-cart-shipping-estimator .item .row: after','content','\\_','','','.w-cart-shipping-estimator'),(475521,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','content','\\f068','3','','.w-menu'),(475522,'furniture-mobile','.w-text .customer-service','content','\\e907','3','','.w-text'),(475523,'furniture-mobile','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(475524,'furniture-mobile','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(475525,'furniture-mobile','.p-account-trade-form .wd-line-row-2','content','\\_','4','','.p-account-trade-form'),(475527,'furniture-mobile','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(475528,'furniture-mobile','.w-cart .multicart .count','content',')','4','','.w-cart'),(475529,'furniture-mobile','.w-cart .multicart .count','content','(','3','','.w-cart'),(475530,'furniture-mobile','.w-social-links .pinterest','content','\\f0d2','3','','.w-social-links'),(475531,'furniture-mobile','.w-social-links .google-plus','content','\\f2b3','3','','.w-social-links'),(475532,'furniture-mobile','.w-wedding-registry-widgets-delete-link a','content','|','4','','.w-wedding-registry-widgets-delete-link'),(475533,'furniture-mobile','.p-reviews-info .review-info-text','content','\\_','4','','.p-reviews-info'),(475534,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(475535,'furniture-mobile','.p-blog-index .wp-widget li','content','\\f111','3','','.p-blog-index'),(475536,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(475537,'furniture-mobile','.p-blog-index .wp-widget li','content','\\f111','3','','.p-blog-index'),(475538,'furniture-mobile','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(475539,'furniture-mobile','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(475540,'furniture-mobile','.w-menu .menu .menu-ico','content','\\e91b','3','','.w-menu'),(475541,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','content','\\f067','3','','.w-menu'),(475542,'furniture-mobile','.p-wedding-registry-view h1','content','\\f004','3','','.p-wedding-registry-view'),(475543,'furniture-mobile','.p-wedding-registry-view h1','content','\\f004','4','','.p-wedding-registry-view'),(475544,'furniture-mobile','.p-blog-index .nav-next a','content','\\f138','3','','.p-blog-index'),(475545,'furniture-mobile','.p-blog-index .nav-previous a','content','\\f137','3','','.p-blog-index'),(475546,'furniture-mobile','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(475547,'furniture-mobile','.b-rating .glyphicon-chevron-down','content','\\f107','3','','.b-rating'),(475548,'furniture-mobile','.w-social-links .twitter','content','\\f099','3','','.w-social-links'),(475549,'furniture-mobile','.w-checkout-create-account .account-benefits strong','content','\\e918','3','','.w-checkout-create-account'),(475550,'furniture-mobile','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(475551,'furniture-mobile','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(475552,'furniture-mobile','.w-menu .menu .menu-ico','content','\\e91b','3','','.w-menu'),(475553,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','content','\\f219','3','','.b-products-listing'),(475554,'furniture-mobile','.b-products-listing .products-listing .bonus-points-price','content','\\f219','3','','.b-products-listing'),(475555,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','content','\\e991','3','','.b-products-listing'),(475556,'furniture-mobile','.b-products-listing .BlockBox','content','\\_','4','','.b-products-listing'),(475557,'furniture-mobile','.b-products-listing .btn-preloader','content','\\f110','3','','.b-products-listing'),(475558,'furniture-mobile','.b-products-listing .hover-box-content','content','\\_','3','','.b-products-listing'),(475559,'furniture-mobile','.b-products-listing .loader','content','\\f110','4','','.b-products-listing'),(475560,'furniture-mobile','.b-products-listing .products-listing','content','\\_','4','','.b-products-listing'),(475561,'furniture-mobile','.b-products-listing .loader','content','\\_','3','','.b-products-listing'),(475562,'furniture-mobile','.b-products-listing .products-listing .btn-buy','content','\\e977','3','','.b-products-listing'),(475563,'furniture-mobile','.b-products-listing .products-listing .qty-input.hidden','content','\\_','3','','.b-products-listing'),(475564,'furniture-mobile','.checkbox input:not(checked) + span:before','content','\\_','','',''),(475565,'furniture-mobile','.w-blog-widget-post-share .mailto','content','\\e75a','3','','.w-blog-widget-post-share'),(475566,'furniture-mobile','.w-blog-widget-post-share .pinterest-btn','content','\\f231','3','','.w-blog-widget-post-share'),(475567,'furniture-mobile','.w-blog-widget-post-share .printto','content','\\e681','3','','.w-blog-widget-post-share'),(475568,'furniture-mobile','.w-blog-widget-post-share .twitter-btn','content','\\f099','3','','.w-blog-widget-post-share'),(475569,'furniture-mobile','.w-blog-widget-post-share .facebook-btn','content','\\f09a','3','','.w-blog-widget-post-share'),(475570,'furniture-mobile','.w-blog-widget-post-share ','content','\\_','4','','.w-blog-widget-post-share'),(475571,'furniture-mobile','.w-blog-widget-post-listing .products','content','\\_','4','','.w-blog-widget-post-listing'),(475572,'furniture-mobile','.w-blog-widget-post-listing .post_date span + span','content','\\2022','3','','.w-blog-widget-post-listing'),(475573,'furniture-mobile','.w-blog-widget-post-listing .post_comment','content','\\e645','3','','.w-blog-widget-post-listing'),(475574,'furniture-mobile','.w-blog-widget-post-comments-count span','content','\\e645','3','','.w-blog-widget-post-comments-count'),(475575,'furniture-mobile','.w-blog-widget-most-popular-posts a','content','\\2022','3','','.w-blog-widget-most-popular-posts'),(475576,'furniture-mobile','.w-blog-widget-categories-list a','content','\\2022','3','','.w-blog-widget-categories-list'),(475577,'furniture-mobile','.w-currencies .current','content','\\e902','3','','.w-currencies'),(475578,'furniture-mobile','.w-account .acc-top','content','\\_','4','','.w-account'),(475579,'furniture-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(475580,'furniture-mobile','.b-rating .glyphicon-star','content','\\f006','3','','.b-rating'),(475581,'furniture-mobile','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(475582,'furniture-mobile','.b-form .hide-box','content','\\_','3','','.b-form'),(475583,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','content','\\_','3','','.b-switch'),(475584,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','content','\\f10b','3','','.w-checkout-contact-information'),(475585,'furniture-mobile','.b-info-popup .info-popup div','content','\\_','3','','.b-info-popup'),(475586,'furniture-mobile','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(475587,'furniture-mobile','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(475588,'furniture-mobile','.w-menu-slider .close','content','\\f00d','3','','.w-menu-slider'),(475589,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','content','\\_','','','.w-compare-box-item'),(475590,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(475591,'furniture-mobile','.w-catalog-paging .next','content','\\f105','3','','.w-catalog-paging'),(475592,'furniture-mobile','.p-wedding-registry-view h1','content','\\f004','3','','.p-wedding-registry-view'),(475593,'furniture-mobile','.order-summary .price-row.ot_coupon .title','content','%','3','','.order-summary'),(475594,'furniture-mobile','.p-reviews-info .review-info-text','content','\\_','4','','.p-reviews-info'),(475595,'furniture-mobile','.p-blog-index .nav-next a','content','\\f138','3','','.p-blog-index'),(475596,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(475597,'furniture-mobile','.b-form .eye-password.eye-password-showed','content','\\f070','3','','.b-form'),(475598,'furniture-mobile','.b-form .eye-password','content','\\f06e','3','','.b-form'),(475600,'furniture-mobile','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(475601,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(475602,'furniture-mobile','.w-tabs .tab-li.tab-quote a','content','\\e9aa','3','','.w-tabs'),(475603,'furniture-mobile','.w-login-block .cols','content','\\_','4','','.w-login-block'),(475604,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','content','\\f067','3','','.w-menu'),(475605,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','content','\\_','','','.w-compare-box-item'),(475606,'furniture-mobile','.w-personal-gift-status-bar .end-date','content','\\e72b','3','','.w-personal-gift-status-bar'),(475607,'furniture-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','content','\\e913','3','','.order-summary'),(475608,'furniture-mobile','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(475609,'furniture-mobile','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(475610,'furniture-mobile','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(475611,'furniture-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(475612,'furniture-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(475613,'furniture-mobile','.w-product-cross-sell .buy-all-checker','content','\\f14a','3','','.w-product-cross-sell'),(475614,'furniture-mobile','.w-catalog-listing-look .b2b','content','\\f0c9','3','','.w-catalog-listing-look'),(475615,'furniture-mobile','.w-catalog-listing-look .grid','content','\\f009','3','','.w-catalog-listing-look'),(475616,'furniture-mobile','.checkbox input:checked + span:before','content','\\f00c','','',''),(475617,'furniture-mobile','.w-cart-listing .multi-product-copy','content','\\e922','3','','.w-cart-listing'),(475618,'furniture-mobile','.w-cart-listing .multi-product-delete','content','\\e913','3','','.w-cart-listing'),(475619,'furniture-mobile','.w-cart-listing .multi-product-move','content','\\e975','3','','.w-cart-listing'),(475620,'furniture-mobile','.w-cart-listing .points-redeem','content','\\f219','3','','.w-cart-listing'),(475621,'furniture-mobile','.w-cart-listing .item .gift-wrap .value','content',')','4','','.w-cart-listing'),(475622,'furniture-mobile','.w-cart-listing .item .gift-wrap .value','content','(','3','','.w-cart-listing'),(475623,'furniture-mobile','.w-cart-listing .remove-btn','content','\\f00d','3','','.w-cart-listing'),(475624,'furniture-mobile','.w-cart-give-away .ga_name','content','\\_','4','','.w-cart-give-away'),(475625,'furniture-mobile','.w-cart .qty','content','\\f00d ','4','','.w-cart'),(475626,'furniture-mobile','.w-cart .multicart .switch-cart','content','\\f111','3','','.w-cart'),(475627,'furniture-mobile','.w-cart .multicart .item.current-multi-cart .switch-cart','content','\\f058','3','','.w-cart'),(475628,'furniture-mobile','.w-cart-discount-coupon .btn-remove','content','\\e913','3','','.w-cart-discount-coupon'),(475630,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(475631,'furniture-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(475632,'furniture-mobile','.b-compare .clear_all','content','\\f00d','4','','.b-compare'),(475633,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','content','\\_','','','.w-compare-box-item'),(475634,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(475635,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','content','\\_','','','.w-compare-box-item'),(475636,'furniture-mobile','.w-filters .open','content','\\f056','3','','.w-filters'),(475637,'furniture-mobile','.w-menu .menu .menu-ico','content','\\e91b','3','','.w-menu'),(475638,'furniture-mobile','.w-checkout-credit-amount .btn-remove','content','\\e913','3','','.w-checkout-credit-amount'),(475639,'furniture-mobile','.w-filters .fsl_handle','content','\\_','4','','.w-filters'),(475640,'furniture-mobile','.w-filters .view_more','content','\\f061','4','','.w-filters'),(475641,'furniture-mobile','.w-filters span.close','content','\\f055','3','','.w-filters'),(475642,'furniture-mobile','.p-blog-index .entry-content','content','\\_','4','','.p-blog-index'),(475643,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(475644,'furniture-mobile','.p-wedding-registry-view h1','content','\\f004','3','','.p-wedding-registry-view'),(475645,'furniture-mobile','.w-catalog-listing-look .list','content','\\f00b','3','','.w-catalog-listing-look'),(475646,'furniture-mobile','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(475648,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(475649,'furniture-mobile','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(475650,'furniture-mobile','.w-menu-slider .close','content','\\f00d','3','','.w-menu-slider'),(475651,'furniture-mobile','.w-login-block .cols','content','\\_','4','','.w-login-block'),(475652,'furniture-mobile','.p-blog-index .wp-widget li','content','\\f111','3','','.p-blog-index'),(475653,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(475654,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','content','\\f067','3','','.w-menu'),(475655,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','content','\\f068','3','','.w-menu'),(475656,'furniture-mobile','.w-menu .menu .menu-ico','content','\\e91b','3','','.w-menu'),(475657,'furniture-mobile','.b-rating .glyphicon-calendar','content','\\f073','3','','.b-rating'),(475659,'furniture-mobile','.p-blog-index .comment-meta','content','\\_','4','','.p-blog-index'),(475660,'furniture-mobile','.p-blog-index .nav-next a','content','\\f138','3','','.p-blog-index'),(475661,'furniture-mobile','.p-blog-index .entry-content','content','\\_','4','','.p-blog-index'),(475662,'furniture-mobile','.w-filters .mobileCollapse','content','\\f056','2,4','','.w-filters'),(475663,'furniture-mobile','.w-filters .mobileCollapse','content','\\f055','4','','.w-filters'),(475664,'furniture-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','content','\\f1db','','','.w-filters'),(475665,'furniture-mobile','.p-blog-index .nav-previous a','content','\\f137','3','','.p-blog-index'),(475666,'furniture-mobile','.p-blog-index .nav-next a','content','\\f138','3','','.p-blog-index'),(475667,'furniture-mobile','.b-product-images .media-popup .mp-close','content','\\f00d','3','','.b-product-images'),(475668,'furniture-mobile','.b-product-images .media-popup .slick-dots li','content','\\2022','3','','.b-product-images'),(475669,'furniture-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','content','\\f0c9','3','','.b-menu-burger_icon'),(475670,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(475671,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(475672,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(475673,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(475674,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(475675,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(475676,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(475677,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(475678,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(475679,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(475680,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','content','\\f107','4','','.b-menu-style-1'),(475681,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','content','\\f00d','3','','.b-menu-style-2'),(475682,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','content','\\_','3','','.b-menu-style-2'),(475683,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','content','\\f105','3','','.b-menu-style-2'),(475684,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','content','\\_','3','','.b-menu-style-2'),(475685,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','content','\\f104','3','','.b-menu-style-2'),(475686,'furniture-mobile','.b-trade-approval .columns','content','\\_','4','','.b-trade-approval'),(475687,'furniture-mobile','.batchPr .btn-batch-remove','content','x','3','','.batchPr'),(475688,'furniture-mobile','.batchPr .checkbox input:not(checked) + span:before','content','\\002B','','','.batchPr'),(475689,'furniture-mobile','.batchPr .checkbox input:checked + span:before','content','\\f00c','','','.batchPr'),(475690,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','content','\\e90d','3','','.w-catalog-compare'),(475691,'furniture-mobile','.w-catalog-compare td span + span','content','| ','3','','.w-catalog-compare'),(475692,'furniture-mobile','.w-catalog-compare .checkbox input:checked + span:before','content','\\f014','','','.w-catalog-compare'),(475693,'furniture-mobile','.w-cart .cart-box-link','content','\\_','4','','.w-cart'),(475694,'furniture-mobile','.w-account .my-acc-link','content','\\_','4','','.w-account'),(475695,'furniture-mobile','.w-account .account-dropdown','content','\\f007','3','','.w-account'),(475696,'furniture-mobile','.tripleBanner .w-html_box','content','\\_','3','','.tripleBanner'),(475697,'furniture-mobile','.b-slick .slick-track, .b-slick .slick-track:after','content','\\_','3','','.b-slick'),(475698,'furniture-mobile','.b-slick .slick-vertical button.slick-next','content','\\f078','3','','.b-slick'),(475699,'furniture-mobile','.b-slick .slick-vertical button.slick-prev','content','\\f077','3','','.b-slick'),(475700,'furniture-mobile','.b-slick button.slick-next','content','\\f054','3','','.b-slick'),(475701,'furniture-mobile','.b-slick button.slick-prev','content','\\f053','3','','.b-slick'),(475702,'furniture-mobile','.w-search .search-ico','content','\\e90a','2885,3','','.w-search'),(475703,'furniture-mobile','.w-search .search-ico.open','content','\\f00d','2885,3','','.w-search'),(475704,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li','content','\\2022','3','','.b-menu-style-3'),(475705,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li.component-item','content','\\_','3','','.b-menu-style-3'),(475706,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','content','+','2885,3','','.b-menu-style-3'),(475707,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li.vis-show','content','-','2885,3','','.b-menu-style-3'),(475708,'furniture-mobile','.b-products-listing .add-to-personal-catalog','content','\\f08a','3','','.b-products-listing'),(475709,'furniture-mobile','.b-products-listing .del-from-personal-catalog','content','\\f004','3','','.b-products-listing'),(475710,'furniture-mobile','.w-bestsellers .products-listing .item','content','\\_','3','','.w-bestsellers'),(475711,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-content','content','\\_','4','','.b-products-listing'),(475712,'furniture-mobile','.w-breadcrumb .breadcrumb-li + .breadcrumb-li','content','/','3','','.w-breadcrumb'),(475713,'furniture-mobile','.w-quote .multicart .count','content','(','3','','.w-quote'),(475714,'furniture-mobile','.w-quote .multicart .count','content',')','4','','.w-quote'),(475715,'furniture-mobile','.w-quote .multicart .item.current-multi-cart .switch-cart','content','\\f058','3','','.w-quote'),(475716,'furniture-mobile','.w-quote .multicart .switch-cart','content','\\f111','3','','.w-quote'),(475717,'furniture-mobile','.w-quote .qty','content','\\274c','4','','.w-quote'),(475718,'furniture-mobile','.w-quote a.item','content','\\_','4','','.w-quote'),(475719,'furniture-mobile','.w-product-personal-catalog-button .del_to_personal_catalog','content','\\f004','3','','.w-product-personal-catalog-button'),(475720,'furniture-mobile','.w-product-personal-catalog-button .add_to_personal_catalog','content','\\f08a','3','','.w-product-personal-catalog-button'),(475721,'furniture-mobile','.b-quantity .qty-box .bigger','content','+','3','','.b-quantity'),(475722,'furniture-mobile','.b-quantity .qty-box .smaller','content','-','3','','.b-quantity'),(475723,'furniture-mobile','h1, .heading-1','content','\\_','3','',''),(475724,'furniture-mobile','h1, .heading-1','content','\\_','4','',''),(475725,'furniture-mobile','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','content','\\e90d','3','','.w-product-buttons'),(475726,'furniture-mobile','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(475727,'furniture-mobile','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(475728,'furniture-mobile','.w-product-bonus-points > div','content','\\_','4','','.w-product-bonus-points'),(475729,'furniture-mobile','.w-product-bonus-points > div > div','content','\\f219','3','','.w-product-bonus-points'),(475730,'furniture-mobile','.warrantyProduct .warranty','content','\\_','3','','.warrantyProduct'),(475731,'furniture-mobile','.warrantyProduct .delivery','content','\\_','3','','.warrantyProduct'),(475732,'furniture-mobile','.w-compare .remove','content','\\f014','3','','.w-compare'),(475733,'furniture-mobile','.w-files-catalog-widgets-files-list .file','content','\\f1c1','3','','.w-files-catalog-widgets-files-list'),(475734,'furniture-mobile','.w-sample .cart-box-link','content','\\_','4','','.w-sample'),(475735,'furniture-mobile','.w-sample .cart-box-link','content','\\e90d','3','','.w-sample'),(475736,'furniture-mobile','.w-sample .multicart .count','content','(','3','','.w-sample'),(475737,'furniture-mobile','.w-sample .multicart .count','content',')','4','','.w-sample'),(475738,'furniture-mobile','.w-sample .multicart .item.current-multi-cart .switch-cart','content','\\f058','3','','.w-sample'),(475739,'furniture-mobile','.w-sample .multicart .switch-cart','content','\\f111','3','','.w-sample'),(475740,'furniture-mobile','.w-sample .qty','content','\\f00d ','4','','.w-sample'),(475741,'furniture-mobile','.w-sample a.item','content','\\_','4','','.w-sample'),(475742,'furniture-mobile','.w-cart-listing .points-earn','content','\\_','4','','.w-cart-listing'),(475743,'furniture-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(475744,'furniture-mobile','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(475745,'furniture-mobile','.w-account-address-book .add_item a','content','+','3','','.w-account-address-book'),(475746,'furniture-mobile','.heading-2','content','\\_','3','',''),(475747,'furniture-mobile','.heading-2','content','\\_','4','',''),(475748,'furniture-mobile','.b-products-listing .products-listing .radio-attributes','content','\\_','4','','.b-products-listing'),(475749,'furniture-mobile','.b-pagination .pagination','content','\\_','4','','.b-pagination'),(475750,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','content','\\f105','3','','.b-pagination'),(475751,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','content','\\f104','3','','.b-pagination'),(475752,'furniture-mobile','.w-product-multi-inventory .select-box:last-of-type:after','content','\\_','','','.w-product-multi-inventory'),(475753,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .remove','content','\\2716','3','','.w-product-properties-filters-widgets-chosen-filters'),(475754,'furniture-mobile','.w-product-multi-inventory #product-attributes','content','\\_','4','','.w-product-multi-inventory'),(475755,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','content','\\_','3','','.p-quote-checkout-index'),(475756,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','content','\\_','4','','.p-quote-checkout-index'),(475757,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','content','\\_','3','','.p-sample-checkout-index'),(475758,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','content','\\_','4','','.p-sample-checkout-index'),(475759,'furniture-mobile','.w-product-multi-inventory .radio-attributes','content','\\_','4','','.w-product-multi-inventory'),(475760,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','content','\\f107','4','','.w-account-personal-catalog'),(475761,'furniture-mobile','.w-product-quantity-discounts .quantity-discounts','content','\\_','4','','.w-product-quantity-discounts'),(475762,'furniture-mobile','.w-product-collection .right-area .btn','content','\\e90d','3','','.w-product-collection'),(475763,'furniture-mobile','.w-product-collection .right-area .btn-2','content','\\e90d','3','','.w-product-collection'),(475764,'furniture-mobile','.w-product-attributes #product-attributes','content','\\_','4','','.w-product-attributes'),(475765,'furniture-mobile','.w-product-attributes .radio-attributes','content','\\_','4','','.w-product-attributes'),(475766,'furniture-mobile','.w-product-attributes .select-box:last-of-type:after','content','\\_','','','.w-product-attributes'),(475767,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','content','\\2714','3','','.w-questionnaire-widgets-questionnaire'),(475768,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','content','\\2718','3','','.w-questionnaire-widgets-questionnaire'),(475769,'furniture-mobile','.w-product-groups .prop-group-swatch','content','\\_','4','','.w-product-groups'),(475770,'furniture-mobile','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','content','\\e90d','3','','.w-product-custom-bundle'),(475771,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list'),(475772,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list-block'),(475773,'furniture-mobile','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(475774,'furniture-mobile','.w-delivery-location-featured-list .deliveryList ul','content','\\_','4','','.w-delivery-location-featured-list'),(475775,'furniture-mobile','.w-wedding-registry-widgets-delete-link .delete-registry','content','\\f1f8','3','','.w-wedding-registry-widgets-delete-link'),(475776,'furniture-mobile','.w-wedding-registry-widgets-edit-link .edit-registry','content','\\f085','3','','.w-wedding-registry-widgets-edit-link'),(475777,'furniture-mobile','.w-product-wedding-registry-button .btn','content','\\_','3','','.w-product-wedding-registry-button'),(475778,'furniture-mobile','.w-product-wedding-registry-button .btn','content','\\_','4','','.w-product-wedding-registry-button'),(475779,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list-by-catalog'),(475780,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(475781,'furniture-mobile','.w-delivery-location-list-by-page .page-list','content','\\_','4','','.w-delivery-location-list-by-page'),(475782,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList','content','\\_','4','','.w-delivery-location-top-location-list'),(475783,'furniture-mobile','.w-delivery-location-cross-pages .page-list','content','\\_','4','','.w-delivery-location-cross-pages'),(475784,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination','content','\\_','4','','.w-wedding-registry-widgets-search-paging'),(475785,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination a.next, .w-wedding-registry-widgets-search-paging .pagination span.next, .w-wedding-registry-widgets-search-paging .pagination .next a, .w-wedding-registry-widgets-search-paging .pagination .next span','content','\\f105','3','','.w-wedding-registry-widgets-search-paging'),(475786,'furniture-mobile','.delivery-options-popup','content','\\_','4','',''),(475787,'furniture-mobile','.w-support-system-filter .dd3-content .collapse_span','content','\\f056','3','','.w-support-system-filter'),(475788,'furniture-mobile','.w-support-system-filter .dd3-content .collapse_span.clouse','content','\\f055','3','','.w-support-system-filter'),(475789,'furniture-mobile','.w-communication-post .btn.refresh','content','\\21bb','3','','.w-communication-post'),(475790,'furniture-mobile','.w-rma-returns-history .icons .excel','content','\\f1c3','3','','.w-rma-returns-history'),(475791,'furniture-mobile','.w-rma-returns-history .icons .print','content','\\f02f','3','','.w-rma-returns-history'),(475792,'furniture-mobile','.w-rma-returns-history .linkButton','content','\\f105','4','','.w-rma-returns-history'),(475793,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .parent > .no-link','content','\\f105','4','','.b-menu-style-1'),(475794,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .goto-button a','content','\\f105 \\f105','4','','.b-menu-style-1'),(475795,'furniture-mobile','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(475796,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-list'),(475797,'furniture-mobile','.w-predefined-promotion .nextdiscount .heading','content','\\f07a','3','','.w-predefined-promotion'),(475798,'furniture-mobile','.w-predefined-promotion .prom-multi-discount','content','\\_','4','','.w-predefined-promotion'),(475799,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range .promo-prod-qty','content',',','4','','.w-predefined-promotion'),(475800,'furniture-mobile','.w-predefined-promotion .prom-multi-discount > .heading','content','\\_','3','','.w-predefined-promotion'),(475801,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','content','\\_','3','','.w-predefined-promotion'),(475802,'furniture-mobile','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','content','\\_','3','','.w-predefined-promotion'),(475803,'furniture-mobile','.w-supplier-purchase-supplier-products .active .select_item > div:before','content','\\f00c','','','.w-supplier-purchase-supplier-products'),(475804,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','content','\\f1db','','','.w-filters'),(475805,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','content','\\f058','','','.w-filters'),(475806,'furniture-mobile','.mainBanner .buttonBox','content','\\_','4','','.mainBanner'),(475807,'furniture-mobile','.mainBanner .title','content','\\_','3','','.mainBanner'),(475808,'furniture-mobile','.mainBanner .topBox > .right','content','\\_','3','','.mainBanner'),(475809,'furniture-mobile','.mainBanner .topBox > .right','content','\\_','4','','.mainBanner'),(475810,'furniture-mobile','.lowestPricedBox .w-banner .ybg','content','\\_','3','','.lowestPricedBox'),(475811,'furniture-mobile','.shopByCollectionBox .content','content','\\_','4','','.shopByCollectionBox'),(475812,'furniture-mobile','.order-summary .icon','content','\\f068','','','.order-summary'),(475813,'furniture-mobile','.order-summary .icon','content','\\f067','3','','.order-summary'),(475814,'furniture-mobile','.order-summary .icon.opened','content','\\f068','3','','.order-summary'),(475815,'furniture-mobile','.w-cart-shipping-estimator .estimate-shipping','content','\\_','4','','.w-cart-shipping-estimator'),(475816,'furniture-mobile','.w-search .extra','content','\\f115','3','','.w-search'),(475817,'furniture-mobile','.w-search .wrap .image','content','\\f115','3','','.w-search'),(475818,'furniture-mobile','.w-search .wrap .info-suggest .image','content','\\f219','3','','.w-search'),(475819,'furniture-mobile','.account-address-book .btn-edit','content','\\e917','4','','.account-address-book'),(475820,'furniture-mobile','.account-order-history .view_link','content','\\e901','4','','.account-order-history'),(475821,'furniture-mobile','.account-order-history-info .historyInfoColumn h2.title-delivery-address, .account-order-history-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-order-history-info'),(475822,'furniture-mobile','.account-order-history-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-order-history-info'),(475823,'furniture-mobile','.account-order-history-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-order-history-info'),(475824,'furniture-mobile','.account-index .account_page .icon-address','content','\\e905','3','','.account-index'),(475825,'furniture-mobile','.account-index .account_page h4.icon-mail','content','\\e927','3','','.account-index'),(475826,'furniture-mobile','.account-index .account_page h4.icon-password','content','\\e906','3','','.account-index'),(475827,'furniture-mobile','.account-index .account_page h4.icon-user','content','\\e921','3','','.account-index'),(475828,'furniture-mobile','.account-index .remove-btn','content','\\e913','3','','.account-index'),(475829,'furniture-mobile','.account-index .topAccount > li > div.credit_amount_ac','content','\\e994','3','','.account-index'),(475830,'furniture-mobile','.account-index .topAccount > li > div.dateLast','content','\\e920','3','','.account-index'),(475831,'furniture-mobile','.account-index .topAccount > li > div.order_count','content','\\e928','3','','.account-index'),(475832,'furniture-mobile','.account-index .topAccount > li > div.points_earnt','content','\\e990','3','','.account-index'),(475833,'furniture-mobile','.account-index .topAccount > li > div.total_count','content','\\e922','3','','.account-index'),(475834,'furniture-mobile','.account-index .topInfo','content','\\_','4','','.account-index'),(475835,'furniture-mobile','.account-index .view_history','content','\\e991','3','','.account-index'),(475836,'furniture-mobile','.account-index .view_link','content','\\e901','4','','.account-index'),(475837,'furniture-mobile','.account-order-pay .historyInfoColumn h2.title-delivery-address, .account-order-pay .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-order-pay'),(475838,'furniture-mobile','.account-order-pay .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-order-pay'),(475839,'furniture-mobile','.account-order-pay .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-order-pay'),(475840,'furniture-mobile','.account-samples .view_link','content','\\e901','4','','.account-samples'),(475841,'furniture-mobile','.account-sample-info .historyInfoColumn h2.title-delivery-address, .account-sample-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-sample-info'),(475842,'furniture-mobile','.account-sample-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-sample-info'),(475843,'furniture-mobile','.account-sample-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-sample-info'),(475844,'furniture-mobile','.catalog-product-wrap .next-product .pn-image','content','\\f054','3','','.catalog-product-wrap'),(475845,'furniture-mobile','.catalog-product-wrap .prev-product .pn-image','content','\\f053','3','','.catalog-product-wrap'),(475846,'furniture-mobile','.shopping-cart-index .gift-code .heading-4','content','\\f068','2,4','','.shopping-cart-index'),(475847,'furniture-mobile','.shopping-cart-index .gift-code .heading-4','content','\\f067','4','','.shopping-cart-index'),(475848,'furniture-mobile','.checkout-index-wrap .order-ico','content','\\e922','3','','.checkout-index-wrap'),(475849,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','content','\\_','3','','.checkout-index-wrap'),(475850,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','content','\\_','4','','.checkout-index-wrap'),(475851,'furniture-mobile','.checkout-index-wrap .pay-ico','content','\\e99e','3','','.checkout-index-wrap'),(475852,'furniture-mobile','.checkout-index-wrap .ship-ico','content','\\e94e','3','','.checkout-index-wrap'),(475853,'furniture-mobile','.checkout-order-confirmation .comment-ico','content','\\e99d','3','','.checkout-order-confirmation'),(475854,'furniture-mobile','.checkout-order-confirmation .discount-ico','content','\\e95e','3','','.checkout-order-confirmation'),(475855,'furniture-mobile','.checkout-order-confirmation .order-ico','content','\\e922','3','','.checkout-order-confirmation'),(475856,'furniture-mobile','.checkout-order-confirmation .ship-ico','content','\\e94e','3','','.checkout-order-confirmation'),(475857,'furniture-mobile','.checkout-success-wrap .page-success','content','\\_','3','','.checkout-success-wrap'),(475858,'furniture-mobile','.checkout-success-wrap .page-success .text-1','content','\\e916','3','','.checkout-success-wrap'),(475859,'furniture-mobile','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(475860,'furniture-mobile','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(475861,'furniture-mobile','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(475862,'furniture-mobile','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(475863,'furniture-mobile','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(475864,'furniture-mobile','.b-rating .glyphicon-chevron-left','content_important','important','3','','.b-rating'),(475865,'furniture-mobile','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(475866,'furniture-mobile','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(475867,'furniture-mobile','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(475868,'furniture-mobile','.b-rating .glyphicon-chevron-right','content_important','important','3','','.b-rating'),(475869,'furniture-mobile','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(475870,'furniture-mobile','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(475871,'furniture-mobile','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(475872,'furniture-mobile','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(475873,'furniture-mobile','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(475874,'furniture-mobile','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(475875,'furniture-mobile','.b-rating .glyphicon-chevron-up','content_important','important','3','','.b-rating'),(475876,'furniture-mobile','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(475877,'furniture-mobile','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(475878,'furniture-mobile','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(475879,'furniture-mobile','.b-rating .glyphicon-chevron-down','content_important','important','3','','.b-rating'),(475880,'furniture-mobile','.b-rating .glyphicon-calendar','content_important','important','3','','.b-rating'),(475881,'furniture-mobile','.b-rating .glyphicon-time','content_important','important','3','','.b-rating'),(475882,'furniture-mobile','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(475883,'furniture-mobile','.heading-2','content_important','important','3','',''),(475885,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor','default','','','.b-switch'),(475886,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','cursor','pointer','','','.b-switch'),(475887,'furniture-mobile','.p-quick-order-index .filters .clear','cursor','pointer','','','.p-quick-order-index'),(475888,'furniture-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','cursor','pointer','3','','.order-summary'),(475889,'furniture-mobile','.b-messages .messMenuButton span','cursor','pointer','','','.b-messages'),(475891,'furniture-mobile','.b-fancybox #fancybox-loading','cursor','pointer','','','.b-fancybox'),(475892,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','cursor','pointer','','','.w-upload-customer-id-upload-customer-id-form'),(475893,'furniture-mobile','.b-switch .bootstrap-switch','cursor','pointer','','','.b-switch'),(475895,'furniture-mobile','.w-coupons-and-vauchers-checkout .btn-remove','cursor','pointer','','','.w-coupons-and-vauchers-checkout'),(475896,'furniture-mobile','.w-menu-slider .close','cursor','pointer','','','.w-menu-slider'),(475898,'furniture-mobile','.w-menu-slider .close','cursor','pointer','','','.w-menu-slider'),(475899,'furniture-mobile','.b-autocomplete .ui-autocomplete li','cursor','pointer','','','.b-autocomplete'),(475900,'furniture-mobile','.w-menu .menu .menu-ico','cursor','pointer','','','.w-menu'),(475901,'furniture-mobile','.w-menu-slider .close','cursor','pointer','','','.w-menu-slider'),(475902,'furniture-mobile','.w-filters .open, .w-filters .close','cursor','pointer','','','.w-filters'),(475903,'furniture-mobile','.w-checkout-shipping-choice span','cursor','pointer','','','.w-checkout-shipping-choice'),(475904,'furniture-mobile','.w-cart-compare .atr-col','cursor','pointer','','','.w-cart-compare'),(475905,'furniture-mobile','.w-tabs .tab-a','cursor','pointer','','','.w-tabs'),(475906,'furniture-mobile','.w-tabs .tab-a','cursor','default','2','','.w-tabs'),(475907,'furniture-mobile','.disabled-area','cursor','not-allowed','','',''),(475908,'furniture-mobile','.disabled-area *','cursor','not-allowed','','',''),(475909,'furniture-mobile','.w-menu-slider .close','cursor','pointer','','','.w-menu-slider'),(475910,'furniture-mobile','.w-menu .menu .menu-ico','cursor','pointer','','','.w-menu'),(475911,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','cursor','pointer','3','','.b-form'),(475912,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','cursor','pointer','','','.b-switch'),(475913,'furniture-mobile','.w-cart-bonus-points .btn-remove','cursor','pointer','','','.w-cart-bonus-points'),(475914,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','','','.b-select-suggest'),(475915,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','1','','.b-select-suggest'),(475916,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg.grab:not(.candlestick-disabled ) .candlestick-toggle','cursor','grab','','','.b-switch'),(475917,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled','cursor','not-allowed','','','.b-switch'),(475918,'furniture-mobile','.b-fancybox .fancybox-close','cursor','pointer','','','.b-fancybox'),(475919,'furniture-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','cursor','default','','','.b-select-suggest'),(475922,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor','default','','','.b-switch'),(475923,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor','default','','','.b-switch'),(475924,'furniture-mobile','.w-checkout-bonus-points .btn-remove','cursor','pointer','','','.w-checkout-bonus-points'),(475925,'furniture-mobile','.w-checkout-credit-amount .btn-remove','cursor','pointer','','','.w-checkout-credit-amount'),(475926,'furniture-mobile','.b-upload-file .snapshot','cursor','pointer','','','.b-upload-file'),(475927,'furniture-mobile','.b-form .item-radio label','cursor','pointer','','','.b-form'),(475928,'furniture-mobile','.b-bottom .footerTitle','cursor','pointer','2876','','.b-bottom'),(475929,'furniture-mobile','.b-products-listing .products-listing .wishlistButton .checkbox','cursor','pointer','','','.b-products-listing'),(475930,'furniture-mobile','.w-cart-credit-amount .btn-remove','cursor','pointer','','','.w-cart-credit-amount'),(475931,'furniture-mobile','.w-product-customers-activity .close','cursor','pointer','','','.w-product-customers-activity'),(475932,'furniture-mobile','.b-form .item-radio.active label','cursor','default','','','.b-form'),(475933,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor','default','','','.b-switch'),(475934,'furniture-mobile','.b-fancybox .fancybox-nav','cursor','pointer','','','.b-fancybox'),(475935,'furniture-mobile','.w-menu .menu .menu-ico','cursor','pointer','','','.w-menu'),(475936,'furniture-mobile','.closeable-event','cursor','pointer','','',''),(475937,'furniture-mobile','.b-form .addresses.address-main .address-item label','cursor','default','','','.b-form'),(475938,'furniture-mobile','.w-checkout-shipping-choice input:checked + span','cursor','default','','','.w-checkout-shipping-choice'),(475939,'furniture-mobile','.w-tabs .accordion-heading','cursor','default','2','','.w-tabs'),(475940,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','cursor','default','','','.b-select-suggest'),(475941,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-chosen','cursor','default','','','.b-select-suggest'),(475942,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','cursor','default','','','.b-select-suggest'),(475943,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','cursor','text','','','.b-select-suggest'),(475944,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','cursor','default','','','.b-select-suggest'),(475945,'furniture-mobile','.b-select-suggest .select2-results .select2-disabled','cursor','default','','','.b-select-suggest'),(475946,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','cursor','pointer','','','.b-select-suggest'),(475947,'furniture-mobile','.w-menu .menu .menu-ico','cursor','pointer','','','.w-menu'),(475948,'furniture-mobile','.w-menu .menu .menu-ico','cursor','pointer','','','.w-menu'),(475949,'furniture-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','cursor','pointer','','','.w-blog-widget-post-share'),(475950,'furniture-mobile','.b-form .eye-password','cursor','pointer','','','.b-form'),(475951,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','cursor','pointer','','','.w-communication-new-topic'),(475952,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','cursor','pointer','','','.w-communication-new-topic'),(475953,'furniture-mobile','.w-menu-slider .close','cursor','pointer','','','.w-menu-slider'),(475954,'furniture-mobile','.w-filters .ui-slider-handle','cursor','pointer','','','.w-filters'),(475955,'furniture-mobile','.w-cart-discount-coupon .btn-remove','cursor','pointer','','','.w-cart-discount-coupon'),(475956,'furniture-mobile','.b-fancybox .fancybox-nav span','cursor','pointer','','','.b-fancybox'),(475957,'furniture-mobile','.w-tabs .accordion-heading','cursor','pointer','','','.w-tabs'),(475958,'furniture-mobile','.w-menu-slider .close','cursor','pointer','','','.w-menu-slider'),(475959,'furniture-mobile','.w-filters .filter-box-content ul li.view_items','cursor','pointer','','','.w-filters'),(475960,'furniture-mobile','.b-bottom .pop-up-close','cursor','pointer','','','.b-bottom'),(475961,'furniture-mobile','.b-upload-files .remove-file','cursor','pointer','','','.b-upload-files'),(475962,'furniture-mobile','.w-menu .menu .menu-ico','cursor','pointer','','','.w-menu'),(475963,'furniture-mobile','.w-menu-big .show-all','cursor','pointer','','','.w-menu-big'),(475964,'furniture-mobile','.b-form .addresses .address-item label','cursor','pointer','','','.b-form'),(475965,'furniture-mobile','.w-filters .mobileCollapse','cursor','pointer','4','','.w-filters'),(475966,'furniture-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','cursor','pointer','','','.b-product-images'),(475967,'furniture-mobile','.b-product-images .media-popup .mp-close','cursor','pointer','','','.b-product-images'),(475968,'furniture-mobile','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','cursor','pointer','','','.b-product-images'),(475969,'furniture-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','cursor','pointer','','','.b-menu-burger_icon'),(475970,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(475971,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(475972,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(475973,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(475974,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(475975,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','cursor','pointer','','','.b-menu-style-2'),(475976,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','cursor','pointer','','','.b-menu-style-2'),(475977,'furniture-mobile','.batchPr .batchSelect .checkbox','cursor','pointer','','','.batchPr'),(475978,'furniture-mobile','.batchPr .btn-batch-remove','cursor','pointer','','','.batchPr'),(475979,'furniture-mobile','.batchPr .batchSelect .checkbox','cursor','pointer','','','.batchPr'),(475980,'furniture-mobile','.w-account-personal-catalog .list-switcher a','cursor','pointer','','','.w-account-personal-catalog'),(475981,'furniture-mobile','.w-account-personal-catalog .list-switcher a','cursor','default','2','','.w-account-personal-catalog'),(475982,'furniture-mobile','.w-catalog-compare .compare label','cursor','pointer','','','.w-catalog-compare'),(475983,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','cursor','pointer','','','.w-catalog-compare'),(475984,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','cursor','default','2','','.w-catalog-compare'),(475985,'furniture-mobile','.w-catalog-compare .cross-box .return','cursor','pointer','','','.w-catalog-compare'),(475986,'furniture-mobile','.b-slick button.slick-disabled','cursor','default','','','.b-slick'),(475987,'furniture-mobile','.w-subscribers .btn-submit','cursor','pointer','','','.w-subscribers'),(475988,'furniture-mobile','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(475989,'furniture-mobile','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(475990,'furniture-mobile','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(475991,'furniture-mobile','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(475992,'furniture-mobile','.w-compare .clear-compare-button','cursor','pointer','','','.w-compare'),(475993,'furniture-mobile','.w-compare .remove','cursor','pointer','','','.w-compare'),(475994,'furniture-mobile','.w-product-video .item img, .w-product-video .item video','cursor','pointer','','','.w-product-video'),(475995,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .remove','cursor','pointer','','','.w-product-properties-filters-widgets-chosen-filters'),(475996,'furniture-mobile','.w-product-multi-inventory .radio-attributes input:checked + .option-item','cursor','default','','','.w-product-multi-inventory'),(475997,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','cursor','pointer','','','.w-product-multi-inventory'),(475998,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','cursor','pointer','','','.b-products-listing'),(475999,'furniture-mobile','.b-products-listing .products-listing .radio-attributes input:checked + .option','cursor','default','','','.b-products-listing'),(476000,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','cursor','pointer','','','.w-product-attributes'),(476001,'furniture-mobile','.w-product-attributes .radio-attributes input:checked + .option-item','cursor','default','','','.w-product-attributes'),(476002,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','cursor','pointer','','','.w-questionnaire-widgets-questionnaire'),(476003,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','cursor','pointer','','','.w-product-designer-designer'),(476004,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','cursor','pointer','','','.w-press-reviews-widgets-press-reviews-small'),(476005,'furniture-mobile','.w-support-system-filter .dd3-content .collapse_span','cursor','pointer','3','','.w-support-system-filter'),(476006,'furniture-mobile','.w-support-system-listing .pm-head-2','cursor','pointer','','','.w-support-system-listing'),(476007,'furniture-mobile','.order-summary .icon','cursor','pointer','','','.order-summary'),(476008,'furniture-mobile','.account-order-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-order-history-info'),(476009,'furniture-mobile','.account-order-history-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-order-history-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-order-history-info'),(476010,'furniture-mobile','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-order-pay'),(476011,'furniture-mobile','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-order-pay'),(476012,'furniture-mobile','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-sample-info'),(476013,'furniture-mobile','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-sample-info'),(476014,'furniture-mobile','.shopping-cart-index .gift-code .heading-4','cursor','pointer','2876','','.shopping-cart-index'),(476015,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor_important','important','','','.b-switch'),(476016,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor_important','important','','','.b-switch'),(476017,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor_important','important','','','.b-switch'),(476018,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor_important','important','','','.b-switch'),(476019,'furniture-mobile','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(476020,'furniture-mobile','.b-switch .bootstrap-switch','direction','ltr','','','.b-switch'),(476021,'furniture-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(476023,'furniture-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(476024,'furniture-mobile','.w-compare-box-item .checkbox + span','display','inline-block','','','.w-compare-box-item'),(476025,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(476026,'furniture-mobile','.b-info .info','display','inline-block','3','','.b-info'),(476027,'furniture-mobile','.message.success','display','inline-block','3','',''),(476028,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(476029,'furniture-mobile','.w-catalog-paging .page-number','display','inline-block','','','.w-catalog-paging'),(476030,'furniture-mobile','.w-cart a.item','display','block','','','.w-cart'),(476031,'furniture-mobile','.w-cart a.item','display','block','4','','.w-cart'),(476032,'furniture-mobile','.w-filters .mobileCollapse','display','inline-block','2885','','.w-filters'),(476033,'furniture-mobile','.p-quick-order-index ul.token-input-list','display','inline-block','','','.p-quick-order-index'),(476034,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.p-quick-order-index'),(476035,'furniture-mobile','.w-promotions .promo-salemaker .content a.name','display','block','','','.w-promotions'),(476036,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.p-quick-order-index'),(476037,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range > div','display','inline-block','','','.w-promotions'),(476038,'furniture-mobile','.w-promotions .promo-salemaker','display','flex','','','.w-promotions'),(476039,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','display','inline-block','','','.w-promotions'),(476040,'furniture-mobile','.w-promotions .promo-date > div','display','inline-block','','','.w-promotions'),(476041,'furniture-mobile','.w-promotions .promo-cart-discount','display','flex','','','.w-promotions'),(476042,'furniture-mobile','.w-sale .special-price','display','block','','','.w-sale'),(476043,'furniture-mobile','.w-sale .left-text-right','display','block','','','.w-sale'),(476044,'furniture-mobile','.p-account-trade-form .wl-td label','display','inline-block','','','.p-account-trade-form'),(476045,'furniture-mobile','.p-blog-index .entry-content','display','block','4','','.p-blog-index'),(476046,'furniture-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','display','table-cell','','','.w-banner'),(476047,'furniture-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(476048,'furniture-mobile','.w-account .account-dropdown','display','none','','','.w-account'),(476049,'furniture-mobile','.w-account .account-dropdown','display','block','4','','.w-account'),(476050,'furniture-mobile','.w-account .account-top','display','inline-block','','','.w-account'),(476051,'furniture-mobile','.w-account .f-pass','display','inline-block','','','.w-account'),(476052,'furniture-mobile','.w-account .my-acc-link','display','flex','','','.w-account'),(476053,'furniture-mobile','.w-account .my-acc-link','display','inline-block','3','','.w-account'),(476054,'furniture-mobile','.w-account .no-text','display','inline-block','','','.w-account'),(476055,'furniture-mobile','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(476056,'furniture-mobile','.w-wedding-registry-widgets-share-link a','display','inline-block','3','','.w-wedding-registry-widgets-share-link'),(476057,'furniture-mobile','.w-wedding-registry-widgets-search-registry-button a','display','inline-block','3','','.w-wedding-registry-widgets-search-registry-button'),(476058,'furniture-mobile','.p-sample-checkout-success .page-success .text-1','display','block','3','','.p-sample-checkout-success'),(476059,'furniture-mobile','.p-reviews-info .review_by span','display','inline-block','','','.p-reviews-info'),(476060,'furniture-mobile','.p-reviews-info .review-info-text','display','block','4','','.p-reviews-info'),(476061,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(476062,'furniture-mobile','.w-promotions .prom-multi-discount','display','block','4','','.w-promotions'),(476063,'furniture-mobile','.p-blog-index .post-title','display','block','','','.p-blog-index'),(476064,'furniture-mobile','.p-blog-index .post-list .comments-link','display','none','','','.p-blog-index'),(476065,'furniture-mobile','.p-blog-index .nav-links .screen-reader-text','display','block','','','.p-blog-index'),(476066,'furniture-mobile','.p-blog-index .entry-content','display','block','4','','.p-blog-index'),(476067,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(476068,'furniture-mobile','.testimonials .review','display','block','3','',''),(476069,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(476070,'furniture-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(476071,'furniture-mobile','.w-compare-box-item .checkbox + span','display','inline-block','','','.w-compare-box-item'),(476072,'furniture-mobile','.w-categories .image','display','block','','','.w-categories'),(476073,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','display','inline-block','','','.w-promotions'),(476074,'furniture-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','display','block','','','.w-promotions'),(476075,'furniture-mobile','.w-promotions .prom-multi-discount .products','display','grid','','','.w-promotions'),(476076,'furniture-mobile','.w-promotions .prom-multi-discount .list','display','grid','','','.w-promotions'),(476077,'furniture-mobile','.w-promotions .nextdiscount .promo-for-each','display','inline-block','','','.w-promotions'),(476078,'furniture-mobile','.w-promotions .nextdiscount .item-holder','display','flex','','','.w-promotions'),(476079,'furniture-mobile','.w-promotions .nextdiscount .content','display','grid','','','.w-promotions'),(476080,'furniture-mobile','.w-promotions .heading-3','display','inline-block','','','.w-promotions'),(476081,'furniture-mobile','.w-promotions .icon','display','inline-block','','','.w-promotions'),(476082,'furniture-mobile','.w-promotions .promo-salemaker .discount','display','inline-block','','','.w-promotions'),(476083,'furniture-mobile','.w-promotions .promo-salemaker .content','display','flex','','','.w-promotions'),(476084,'furniture-mobile','.w-promotions .promo-content > .personalgift','display','none','','','.w-promotions'),(476085,'furniture-mobile','.w-promotions .promo-cart-discount .slave','display','flex','','','.w-promotions'),(476086,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','display','inline-block','','','.w-promotions'),(476087,'furniture-mobile','.w-promotions .promo-cart-discount .item a','display','block','','','.w-promotions'),(476088,'furniture-mobile','.w-promotions .promo-cart-discount .content','display','flex','','','.w-promotions'),(476089,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','display','inline-block','','','.b-warehouses-popup'),(476090,'furniture-mobile','.w-product-available-in-warehouses .content','display','block','4','','.w-product-available-in-warehouses'),(476091,'furniture-mobile','.b-preloader .preloader','display','inline-block','3','','.b-preloader'),(476092,'furniture-mobile','.w-product-available-in-warehouses .warehouse-item','display','inline-block','','','.w-product-available-in-warehouses'),(476093,'furniture-mobile','.b-products-listing .products-listing .mix-attributes','display','block','4','','.b-products-listing'),(476094,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-blocks','display','flex','','','.b-products-listing'),(476095,'furniture-mobile','.w-catalog-paging .prev','display','inline-block','','','.w-catalog-paging'),(476096,'furniture-mobile','.w-cart .cart-box-link','display','inline-block','3','','.w-cart'),(476097,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(476098,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(476099,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(476100,'furniture-mobile','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(476101,'furniture-mobile','.w-menu-style-1 ul ul','display','none','','','.w-menu-style-1'),(476102,'furniture-mobile','.p-blog-index .post-list .comments-link','display','none','','','.p-blog-index'),(476103,'furniture-mobile','.p-blog-index .nav-links .screen-reader-text','display','block','','','.p-blog-index'),(476104,'furniture-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(476105,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(476106,'furniture-mobile','.b-messages .messBtnMenuDelete','display','inline-block','3','','.b-messages'),(476107,'furniture-mobile','.b-messages .messMenuButton span','display','inline-block','','','.b-messages'),(476108,'furniture-mobile','.b-messages .msv_to_cc div span','display','inline-block','','','.b-messages'),(476109,'furniture-mobile','.b-messages span.starred::before','display','inline-block','','','.b-messages'),(476110,'furniture-mobile','.b-messages .dataTables_wrapper > .top','display','block','4','','.b-messages'),(476111,'furniture-mobile','.b-messages .messBtnMenuStarred','display','inline-block','3','','.b-messages'),(476112,'furniture-mobile','.b-messages .messBtnMenuUnread','display','inline-block','3','','.b-messages'),(476113,'furniture-mobile','.b-messages .messages-menu li a','display','block','','','.b-messages'),(476114,'furniture-mobile','.b-messages .content_management_attach button','display','inline-block','','','.b-messages'),(476115,'furniture-mobile','.b-messages .email-line','display','flex','','','.b-messages'),(476116,'furniture-mobile','.b-messages .dataTables_wrapper > .bottom','display','block','4','','.b-messages'),(476117,'furniture-mobile','.w-sale .left-count','display','block','','','.w-sale'),(476118,'furniture-mobile','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(476119,'furniture-mobile','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(476120,'furniture-mobile','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(476121,'furniture-mobile','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(476122,'furniture-mobile','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(476123,'furniture-mobile','.order-summary .price-row.ot_gv .title','display','inline-block','3','','.order-summary'),(476124,'furniture-mobile','.p-blog-index .post-list .comments-link','display','none','','','.p-blog-index'),(476125,'furniture-mobile','.p-blog-index .post-title','display','block','','','.p-blog-index'),(476126,'furniture-mobile','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(476127,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul','display','flex','','','.w-sitemap-delivery-location'),(476128,'furniture-mobile','.w-checkout-terms .required-message-wrap','display','inline-block','','','.w-checkout-terms'),(476129,'furniture-mobile','.p-blog-index .comment-author .says','display','none','','','.p-blog-index'),(476130,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(476131,'furniture-mobile','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(476132,'furniture-mobile','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(476133,'furniture-mobile','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(476135,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(476136,'furniture-mobile','.p-blog-index .post-title','display','block','','','.p-blog-index'),(476137,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','display','inline-block','','','.b-switch'),(476138,'furniture-mobile','.w-menu-slider a, .w-menu-slider .no-link','display','inline-block','','','.w-menu-slider'),(476139,'furniture-mobile','.w-menu-style-1 li','display','inline-block','','','.w-menu-style-1'),(476140,'furniture-mobile','.w-product-reviews .reviews-list .review','display','block','3','','.w-product-reviews'),(476141,'furniture-mobile','.b-info-popup .info-popup','display','inline-block','','','.b-info-popup'),(476144,'furniture-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(476145,'furniture-mobile','.p-account-trade-form .wl-td label','display','inline-block','','','.p-account-trade-form'),(476146,'furniture-mobile','.p-account-trade-form .wd-line-row-2','display','block','4','','.p-account-trade-form'),(476147,'furniture-mobile','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(476148,'furniture-mobile','.w-sale .left-count-hours','display','block','','','.w-sale'),(476149,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(476150,'furniture-mobile','.p-reviews-info .review_by span','display','inline-block','','','.p-reviews-info'),(476154,'furniture-mobile','.p-blog-index .comment-meta','display','block','4','','.p-blog-index'),(476155,'furniture-mobile','.p-blog-index .comment-form p label','display','inline-block','','','.p-blog-index'),(476156,'furniture-mobile','.p-quick-order-index .quick-order-total','display','flex','','','.p-quick-order-index'),(476157,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details ~ div','display','none','','','.w-upload-customer-id-upload-customer-id-form'),(476158,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','display','flex','','','.w-upload-customer-id-upload-customer-id-form'),(476159,'furniture-mobile','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(476162,'furniture-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(476163,'furniture-mobile','.w-compare-box-item .checkbox + span','display','inline-block','','','.w-compare-box-item'),(476164,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(476165,'furniture-mobile','.w-checkout-bonus-points .btn-remove','display','inline-block','','','.w-checkout-bonus-points'),(476166,'furniture-mobile','.w-login-block .cols','display','block','4','','.w-login-block'),(476167,'furniture-mobile','.w-login-block .label','display','block','','','.w-login-block'),(476168,'furniture-mobile','.w-menu-horizontal li','display','inline-block','','','.w-menu-horizontal'),(476169,'furniture-mobile','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','display','inline-block','','','.w-menu-horizontal'),(476170,'furniture-mobile','.w-menu-horizontal li li a, .w-menu-horizontal li li .no-link','display','block','','','.w-menu-horizontal'),(476171,'furniture-mobile','.w-menu-slider > ul > li > ul > li','display','inline-block','','','.w-menu-slider'),(476172,'furniture-mobile','.w-menu-slider > ul > li > ul','display','none','','','.w-menu-slider'),(476173,'furniture-mobile','.w-menu-slider > ul > li','display','inline-block','','','.w-menu-slider'),(476174,'furniture-mobile','.w-tabs .tab-navigation','display','table','','','.w-tabs'),(476175,'furniture-mobile','.w-sale .left-text-right','display','block','','','.w-sale'),(476176,'furniture-mobile','.p-blog-index .comment-meta','display','block','4','','.p-blog-index'),(476177,'furniture-mobile','.p-account-trade-form .wd-line-row-2','display','block','4','','.p-account-trade-form'),(476178,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(476179,'furniture-mobile','.b-form .payment-method .item-radio label','display','block','','','.b-form'),(476180,'furniture-mobile','.w-quote .cart-box-link','display','flex','','','.w-quote'),(476181,'furniture-mobile','.w-sale .left-text-left','display','block','','','.w-sale'),(476182,'furniture-mobile','.w-sale .left-count-hours','display','block','','','.w-sale'),(476183,'furniture-mobile','.w-sale .btn','display','block','','','.w-sale'),(476184,'furniture-mobile','.w-personal-gift-status-bar .inform','display','inline-block','4','','.w-personal-gift-status-bar'),(476185,'furniture-mobile','.p-account-trade-form .wl-td label','display','inline-block','','','.p-account-trade-form'),(476186,'furniture-mobile','.p-account-trade-form .wd-line-row-2','display','block','4','','.p-account-trade-form'),(476187,'furniture-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(476190,'furniture-mobile','.w-menu .hided.menu .menu-ico','display','block','','','.w-menu'),(476191,'furniture-mobile','.w-menu .menu .menu-ico','display','none','','','.w-menu'),(476192,'furniture-mobile','.w-menu-slider > ul > li','display','inline-block','','','.w-menu-slider'),(476193,'furniture-mobile','.w-menu-style-1 ul li:hover > ul','display','block','','','.w-menu-style-1'),(476194,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(476195,'furniture-mobile','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(476196,'furniture-mobile','.w-promo-code .promo-text-2','display','none','2885','','.w-promo-code'),(476197,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(476198,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(476199,'furniture-mobile','.b-switch .bootstrap-switch','display','inline-block','','','.b-switch'),(476200,'furniture-mobile','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(476201,'furniture-mobile','.w-menu-slider > ul > li','display','inline-block','','','.w-menu-slider'),(476202,'furniture-mobile','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(476203,'furniture-mobile','.w-social-links .name, .w-social-links .image','display','none','','','.w-social-links'),(476204,'furniture-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(476205,'furniture-mobile','.buttons','display','block','4','',''),(476206,'furniture-mobile','.w-menu-slider > ul > li','display','inline-block','','','.w-menu-slider'),(476207,'furniture-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','display','inline-block','','','.w-menu-style-1'),(476208,'furniture-mobile','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(476209,'furniture-mobile','.w-login-block .label','display','block','','','.w-login-block'),(476210,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(476211,'furniture-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(476212,'furniture-mobile','.w-text .customer-service b','display','block','','','.w-text'),(476213,'furniture-mobile','.w-sale .special-price-text','display','none','','','.w-sale'),(476214,'furniture-mobile','.w-sale .text','display','block','','','.w-sale'),(476215,'furniture-mobile','.w-sale .btn','display','block','','','.w-sale'),(476216,'furniture-mobile','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(476217,'furniture-mobile','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(476218,'furniture-mobile','.w-login-block .cols','display','block','4','','.w-login-block'),(476219,'furniture-mobile','.w-menu-slider > ul > li > ul','display','none','','','.w-menu-slider'),(476220,'furniture-mobile','.w-menu .menu .menu-ico','display','none','','','.w-menu'),(476221,'furniture-mobile','.w-menu .hided.menu .menu-ico','display','block','','','.w-menu'),(476222,'furniture-mobile','.w-filters .input-checkbox:checked + .checkbox-span','display','inline-block','','','.w-filters'),(476223,'furniture-mobile','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(476224,'furniture-mobile','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(476225,'furniture-mobile','.b-switch .candlestick-wrapper','display','inline-block','','','.b-switch'),(476226,'furniture-mobile','.p-blog-index .comment-meta','display','block','4','','.p-blog-index'),(476227,'furniture-mobile','.p-blog-index .comment-author .says','display','none','','','.p-blog-index'),(476228,'furniture-mobile','.w-catalog-listing-look .listing-look-title','display','inline-block','','','.w-catalog-listing-look'),(476229,'furniture-mobile','.b-bottom .footerTitle ~ div','display','none','2876','','.b-bottom'),(476230,'furniture-mobile','.b-info .info','display','inline-block','3','','.b-info'),(476231,'furniture-mobile','.w-checkout-billing-address .genders-title > div','display','inline-block','','','.w-checkout-billing-address'),(476234,'furniture-mobile','.b-select-suggest .select2-display-none','display','none','','','.b-select-suggest'),(476235,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(476236,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','3','','.b-select-suggest'),(476237,'furniture-mobile','.w-menu .menu .menu-ico','display','none','','','.w-menu'),(476238,'furniture-mobile','.w-menu div.hided.menu .active + ul, .w-menu div.hided.menu .opened + ul','display','block','','','.w-menu'),(476239,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','display','none','','','.b-select-suggest'),(476240,'furniture-mobile','.w-checkout-shipping-choice span','display','flex','','','.w-checkout-shipping-choice'),(476241,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','display','none','','','.w-menu'),(476242,'furniture-mobile','.w-menu-big li a, .w-menu-big li .no-link','display','inline-block','','','.w-menu-big'),(476243,'furniture-mobile','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(476244,'furniture-mobile','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(476245,'furniture-mobile','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(476246,'furniture-mobile','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(476247,'furniture-mobile','.w-sale .text','display','block','','','.w-sale'),(476248,'furniture-mobile','.w-sale .special-price-text','display','none','','','.w-sale'),(476249,'furniture-mobile','.w-sale .special-price','display','block','','','.w-sale'),(476250,'furniture-mobile','.w-cart-compare .product','display','block','4','','.w-cart-compare'),(476251,'furniture-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(476252,'furniture-mobile','.w-top-categories .categories','display','block','4','','.w-top-categories'),(476253,'furniture-mobile','.w-top-categories .categories','display','flex','','','.w-top-categories'),(476254,'furniture-mobile','.b-info-popup .info-popup div','display','none','','','.b-info-popup'),(476255,'furniture-mobile','.w-checkout-billing-address .addresses','display','block','4','','.w-checkout-billing-address'),(476256,'furniture-mobile','.w-promo-code .promo-text-2','display','none','2885','','.w-promo-code'),(476257,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(476258,'furniture-mobile','.w-search .name','display','block','','','.w-search'),(476259,'furniture-mobile','.w-image-maps .default-links .item .description','display','block','','','.w-image-maps'),(476260,'furniture-mobile','.w-image-maps .float-items .item','display','block','1','','.w-image-maps'),(476261,'furniture-mobile','.w-image-maps .default-links .item .title','display','block','','','.w-image-maps'),(476262,'furniture-mobile','.w-sale .left-count-hours','display','block','','','.w-sale'),(476263,'furniture-mobile','.w-sale .special-price','display','block','','','.w-sale'),(476266,'furniture-mobile','.b-upload-file .upload-file-template','display','inline-block','','','.b-upload-file'),(476267,'furniture-mobile','.w-menu-slider a, .w-menu-slider .no-link','display','inline-block','','','.w-menu-slider'),(476268,'furniture-mobile','.p-blog-index .comment-author .says','display','none','','','.p-blog-index'),(476269,'furniture-mobile','.b-info .info','display','inline-block','3','','.b-info'),(476271,'furniture-mobile','.w-checkout-shipping-address .addresses','display','block','4','','.w-checkout-shipping-address'),(476275,'furniture-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(476277,'furniture-mobile','.w-sale .left-text-left','display','block','','','.w-sale'),(476278,'furniture-mobile','.w-quote .cart-box-link','display','inline-block','3','','.w-quote'),(476279,'furniture-mobile','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(476280,'furniture-mobile','.w-menu-slider a, .w-menu-slider .no-link','display','inline-block','','','.w-menu-slider'),(476281,'furniture-mobile','.w-menu-style-1 li','display','inline-block','','','.w-menu-style-1'),(476282,'furniture-mobile','.w-menu-style-1 ul li:hover > ul','display','block','','','.w-menu-style-1'),(476283,'furniture-mobile','.w-menu-style-1 ul ul li','display','block','','','.w-menu-style-1'),(476284,'furniture-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','display','inline-block','','','.w-multi-cart-actions'),(476285,'furniture-mobile','.w-tabs .tab-li.tab-wishlist a','display','block','3','','.w-tabs'),(476286,'furniture-mobile','.w-top-categories .item','display','inline-block','','','.w-top-categories'),(476287,'furniture-mobile','.w-text .customer-service b','display','block','','','.w-text'),(476288,'furniture-mobile','.w-tabs .tab-a','display','block','','','.w-tabs'),(476289,'furniture-mobile','.w-tabs > .block > .box .heading-2, .w-tabs > .block > .box .heading-3, .w-tabs > .block > .box .heading-4','display','none','','','.w-tabs'),(476290,'furniture-mobile','.w-tabs .tab-li','display','table-cell','','','.w-tabs'),(476291,'furniture-mobile','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(476292,'furniture-mobile','.w-search .item','display','block','','','.w-search'),(476293,'furniture-mobile','.w-sale .text','display','block','','','.w-sale'),(476294,'furniture-mobile','.w-sale .special-price-text','display','none','','','.w-sale'),(476295,'furniture-mobile','.w-sale .special-price','display','block','','','.w-sale'),(476296,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(476297,'furniture-mobile','.w-menu-style-1 li li a, .w-menu-style-1 li li .no-link','display','block','','','.w-menu-style-1'),(476298,'furniture-mobile','.p-wedding-registry-search .search-form','display','flex','','','.p-wedding-registry-search'),(476299,'furniture-mobile','.w-languages .languages:hover .select','display','block','','','.w-languages'),(476300,'furniture-mobile','.w-languages .languages','display','inline-block','','','.w-languages'),(476301,'furniture-mobile','.b-form .payment-method .item-radio label span','display','block','','','.b-form'),(476302,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(476303,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','display','block','3','','.b-switch'),(476304,'furniture-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(476305,'furniture-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(476306,'furniture-mobile','.w-login-block .cols','display','block','4','','.w-login-block'),(476307,'furniture-mobile','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(476308,'furniture-mobile','.w-sale .btn','display','block','','','.w-sale'),(476309,'furniture-mobile','.p-reviews-info .review-info-text','display','block','4','','.p-reviews-info'),(476310,'furniture-mobile','.p-reviews-info .review_by span','display','inline-block','','','.p-reviews-info'),(476311,'furniture-mobile','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(476312,'furniture-mobile','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(476313,'furniture-mobile','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(476314,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(476315,'furniture-mobile','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(476317,'furniture-mobile','.p-blog-index .entry-content','display','block','4','','.p-blog-index'),(476318,'furniture-mobile','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(476319,'furniture-mobile','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(476320,'furniture-mobile','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(476321,'furniture-mobile','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(476322,'furniture-mobile','.w-menu-slider > ul > li > ul','display','none','','','.w-menu-slider'),(476323,'furniture-mobile','.w-menu-slider a, .w-menu-slider .no-link','display','inline-block','','','.w-menu-slider'),(476324,'furniture-mobile','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(476325,'furniture-mobile','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(476326,'furniture-mobile','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(476327,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','display','inline-block','','','.b-switch'),(476328,'furniture-mobile','.w-sale .text','display','block','','','.w-sale'),(476329,'furniture-mobile','.w-login-block .label','display','block','','','.w-login-block'),(476330,'furniture-mobile','.w-menu div.hided.menu .active + ul, .w-menu div.hided.menu .opened + ul','display','block','','','.w-menu'),(476331,'furniture-mobile','.w-menu-style-1 li','display','inline-block','','','.w-menu-style-1'),(476333,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(476334,'furniture-mobile','.w-filters .filter-widget-horizontal .content-filter-widget','display','table','','','.w-filters'),(476335,'furniture-mobile','.w-filters .filter-widget-horizontal .filter-box','display','table-cell','','','.w-filters'),(476336,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(476337,'furniture-mobile','.b-products-listing .products-listing .bonus-points','display','flex','','','.b-products-listing'),(476338,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','display','inline-block','','','.b-switch'),(476342,'furniture-mobile','.w-checkout-shipping-address .genders-title label','display','inline-block','','','.w-checkout-shipping-address'),(476343,'furniture-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(476344,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','display','inline-block','3','','.w-checkout-contact-information'),(476345,'furniture-mobile','.order-summary .price-row','display','none','','','.order-summary'),(476346,'furniture-mobile','.w-cart-bonus-points .btn-remove','display','inline-block','','','.w-cart-bonus-points'),(476347,'furniture-mobile','.w-cart-listing .points-earn','display','inline-block','','','.w-cart-listing'),(476348,'furniture-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(476349,'furniture-mobile','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(476350,'furniture-mobile','.w-text .customer-service b','display','block','','','.w-text'),(476351,'furniture-mobile','.w-sale .btn','display','block','','','.w-sale'),(476352,'furniture-mobile','.w-multi-cart-actions .cart-actions','display','inline-block','','','.w-multi-cart-actions'),(476353,'furniture-mobile','.w-menu-style-1 ul li:hover > ul','display','block','','','.w-menu-style-1'),(476354,'furniture-mobile','.w-menu-style-1 ul ul li','display','block','','','.w-menu-style-1'),(476355,'furniture-mobile','.w-sale .left-count-days','display','block','','','.w-sale'),(476356,'furniture-mobile','.w-sale .special-price-text','display','none','','','.w-sale'),(476357,'furniture-mobile','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(476358,'furniture-mobile','.b-select-suggest .select2-container.select2-allowclear .select2-choice abbr','display','inline-block','','','.b-select-suggest'),(476359,'furniture-mobile','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(476360,'furniture-mobile','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(476361,'furniture-mobile','.w-search .items-title','display','block','','','.w-search'),(476362,'furniture-mobile','.w-sale .text','display','block','','','.w-sale'),(476363,'furniture-mobile','.w-sale .special-price-text','display','none','','','.w-sale'),(476364,'furniture-mobile','.w-sale .special-price','display','block','','','.w-sale'),(476365,'furniture-mobile','.w-sale .left-text-right','display','block','','','.w-sale'),(476366,'furniture-mobile','.w-sale .left-count-days','display','block','','','.w-sale'),(476367,'furniture-mobile','.w-reviews .item','display','grid','','','.w-reviews'),(476368,'furniture-mobile','.w-promo-code .holder','display','block','4','','.w-promo-code'),(476369,'furniture-mobile','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(476370,'furniture-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(476371,'furniture-mobile','.w-image-maps .default-links .item','display','block','1','','.w-image-maps'),(476372,'furniture-mobile','.w-menu .hided.menu a, .w-menu .hided.menu .no-link','display','block','','','.w-menu'),(476373,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','display','block','','','.w-checkout-shipping-choice'),(476374,'furniture-mobile','.w-menu .hided.menu .menu-ico','display','block','','','.w-menu'),(476375,'furniture-mobile','.w-checkout-create-account .columns .col-2:nth-child(2n)','display','none','2885','','.w-checkout-create-account'),(476376,'furniture-mobile','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(476377,'furniture-mobile','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(476378,'furniture-mobile','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(476379,'furniture-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(476380,'furniture-mobile','.w-top-categories .image','display','block','','','.w-top-categories'),(476381,'furniture-mobile','.w-cart-compare .delete-cart','display','inline-block','','','.w-cart-compare'),(476382,'furniture-mobile','.b-fancybox .fancybox-overlay','display','none','','','.b-fancybox'),(476383,'furniture-mobile','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(476384,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(476385,'furniture-mobile','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(476386,'furniture-mobile','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(476387,'furniture-mobile','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(476388,'furniture-mobile','.w-list-b2b .attributes','display','block','4','','.w-list-b2b'),(476389,'furniture-mobile','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(476390,'furniture-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(476391,'furniture-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(476392,'furniture-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(476393,'furniture-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(476394,'furniture-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(476395,'furniture-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(476396,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(476397,'furniture-mobile','.b-form .columns','display','block','4','','.b-form'),(476398,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(476399,'furniture-mobile','.w-promo-code .holder','display','block','4','','.w-promo-code'),(476400,'furniture-mobile','.w-catalog-sorting .sorting','display','flex','','','.w-catalog-sorting'),(476401,'furniture-mobile','.w-promo-code .promo-text-2','display','none','2885','','.w-promo-code'),(476402,'furniture-mobile','.b-info .info','display','inline-block','3','','.b-info'),(476403,'furniture-mobile','.p-reviews-info .review-info-text','display','block','4','','.p-reviews-info'),(476404,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','display','none','','','.b-select-suggest'),(476405,'furniture-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','display','block','','','.b-select-suggest'),(476406,'furniture-mobile','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(476407,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','display','block','','','.b-select-suggest'),(476408,'furniture-mobile','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','display','list-item','','','.b-select-suggest'),(476409,'furniture-mobile','.b-select-suggest .select2-container','display','inline-block','','','.b-select-suggest'),(476411,'furniture-mobile','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(476412,'furniture-mobile','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(476413,'furniture-mobile','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(476415,'furniture-mobile','.w-banner .carousel-text','display','flex','','','.w-banner'),(476416,'furniture-mobile','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','display','table','','','.w-banner'),(476417,'furniture-mobile','.w-checkout-shipping .sub-item','display','block','','','.w-checkout-shipping'),(476418,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','display','inline-block','','','.b-switch'),(476419,'furniture-mobile','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(476420,'furniture-mobile','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(476421,'furniture-mobile','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(476422,'furniture-mobile','.w-languages .select','display','none','','','.w-languages'),(476423,'furniture-mobile','.w-menu-style-1 ul ul','display','none','','','.w-menu-style-1'),(476424,'furniture-mobile','.w-menu-style-1 ul ul li','display','block','','','.w-menu-style-1'),(476425,'furniture-mobile','.w-menu-style-1 ul li:hover > ul','display','block','','','.w-menu-style-1'),(476426,'furniture-mobile','.w-menu-style-1 li','display','inline-block','','','.w-menu-style-1'),(476427,'furniture-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','display','inline-block','','','.w-menu-style-1'),(476428,'furniture-mobile','.w-menu-style-1 li li a, .w-menu-style-1 li li .no-link','display','block','','','.w-menu-style-1'),(476429,'furniture-mobile','.w-sale .left-count-hours','display','block','','','.w-sale'),(476430,'furniture-mobile','.w-sale .special-price','display','block','','','.w-sale'),(476431,'furniture-mobile','.w-sale .left-count-days','display','block','','','.w-sale'),(476432,'furniture-mobile','.w-sale .left-text-left','display','block','','','.w-sale'),(476433,'furniture-mobile','.w-sale .left-count','display','block','','','.w-sale'),(476434,'furniture-mobile','.w-sale .left-text-right','display','block','','','.w-sale'),(476435,'furniture-mobile','.w-login-block .label','display','block','','','.w-login-block'),(476436,'furniture-mobile','.w-sale .btn','display','block','','','.w-sale'),(476437,'furniture-mobile','.w-login-block .cols','display','block','4','','.w-login-block'),(476438,'furniture-mobile','.w-cart-shipping-estimator .item .row: after','display','block','','','.w-cart-shipping-estimator'),(476439,'furniture-mobile','.w-categories h2.name','display','block','','','.w-categories'),(476440,'furniture-mobile','.b-info .info','display','inline-block','3','','.b-info'),(476441,'furniture-mobile','.w-languages .lang-link','display','block','2885','','.w-languages'),(476442,'furniture-mobile','.w-cart-compare .js-cart_totals_container b','display','block','','','.w-cart-compare'),(476443,'furniture-mobile','.b-form .middle-form .col-gender label','display','inline-block','','','.b-form'),(476444,'furniture-mobile','.b-form .login-cols','display','flex','','','.b-form'),(476445,'furniture-mobile','.b-form .payment-method .sub-item span','display','block','','','.b-form'),(476447,'furniture-mobile','.b-form .checkbox-style:checked + .checkbox-span','display','inline-block','','','.b-form'),(476448,'furniture-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(476449,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','display','none','','','.w-menu'),(476450,'furniture-mobile','.w-menu .hided.menu a, .w-menu .hided.menu .no-link','display','block','','','.w-menu'),(476451,'furniture-mobile','.w-compare-box-item .checkbox + span','display','inline-block','','','.w-compare-box-item'),(476452,'furniture-mobile','.w-cart-shipping-estimator .shipping-estimator','display','block','4','','.w-cart-shipping-estimator'),(476453,'furniture-mobile','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(476454,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','display','inline-block','','','.b-fancybox'),(476455,'furniture-mobile','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(476456,'furniture-mobile','.w-menu-style-1 li','display','inline-block','','','.w-menu-style-1'),(476457,'furniture-mobile','.w-checkout-credit-amount .btn-remove','display','inline-block','','','.w-checkout-credit-amount'),(476458,'furniture-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(476459,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(476460,'furniture-mobile','.w-sale .left-count-days','display','block','','','.w-sale'),(476461,'furniture-mobile','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(476462,'furniture-mobile','.price .old','display','inline-block','','',''),(476463,'furniture-mobile','.p-reviews-info .review_by span','display','inline-block','','','.p-reviews-info'),(476464,'furniture-mobile','.p-reviews-info .review-info-text','display','block','4','','.p-reviews-info'),(476465,'furniture-mobile','.w-tabs .tab-li.tab-cart a','display','block','3','','.w-tabs'),(476466,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(476469,'furniture-mobile','.w-checkout-billing-address .genders-title label','display','inline-block','','','.w-checkout-billing-address'),(476470,'furniture-mobile','.w-personal-gift-status-bar .end-date','display','inline-block','3','','.w-personal-gift-status-bar'),(476471,'furniture-mobile','.w-top-categories h2.name','display','block','','','.w-top-categories'),(476472,'furniture-mobile','.w-sale .special-price-text','display','none','','','.w-sale'),(476474,'furniture-mobile','.w-promo-code .holder','display','block','4','','.w-promo-code'),(476475,'furniture-mobile','.w-menu-style-1 ul ul li','display','block','','','.w-menu-style-1'),(476476,'furniture-mobile','.w-menu-slider > ul > li > ul','display','none','','','.w-menu-slider'),(476477,'furniture-mobile','.w-image-maps .categories-items .item .description','display','block','','','.w-image-maps'),(476478,'furniture-mobile','.w-image-maps .categories-items .item .title','display','block','','','.w-image-maps'),(476479,'furniture-mobile','.w-menu-slider > ul > li > ul','display','none','','','.w-menu-slider'),(476480,'furniture-mobile','.w-sale .left-text-right','display','block','','','.w-sale'),(476481,'furniture-mobile','.w-quote .no-text','display','none','2885','','.w-quote'),(476482,'furniture-mobile','.b-info-popup .info-popup','display','inline-block','3','','.b-info-popup'),(476483,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(476484,'furniture-mobile','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(476485,'furniture-mobile','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(476486,'furniture-mobile','.w-menu-style-1 ul ul li','display','block','','','.w-menu-style-1'),(476487,'furniture-mobile','.w-menu-style-1 li','display','inline-block','','','.w-menu-style-1'),(476488,'furniture-mobile','.w-menu-style-1 li li a, .w-menu-style-1 li li .no-link','display','block','','','.w-menu-style-1'),(476489,'furniture-mobile','.w-catalog-paging .prev-pages','display','inline-block','','','.w-catalog-paging'),(476491,'furniture-mobile','.p-blog-index .post-list .comments-link','display','none','','','.p-blog-index'),(476492,'furniture-mobile','.p-blog-index .comment-form p label','display','inline-block','','','.p-blog-index'),(476493,'furniture-mobile','.b-upload-files .attach-active-holder','display','block','','','.b-upload-files'),(476495,'furniture-mobile','.b-compare .compare_select_items','display','inline-block','','','.b-compare'),(476496,'furniture-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(476497,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display','inline-block','','','.b-switch'),(476498,'furniture-mobile','.b-form .middle-form label','display','block','','','.b-form'),(476499,'furniture-mobile','.b-form .form-inputs label > span','display','inline-block','','','.b-form'),(476500,'furniture-mobile','.w-checkout-shipping-address .edit-ab','display','inline-block','','','.w-checkout-shipping-address'),(476501,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(476502,'furniture-mobile','.w-cart-shipping-estimator .address-item .lastname','display','block','4','','.w-cart-shipping-estimator'),(476503,'furniture-mobile','.w-menu .hided.menu ul li','display','block','','','.w-menu'),(476504,'furniture-mobile','.w-menu .menu .menu-ico','display','none','','','.w-menu'),(476505,'furniture-mobile','.w-menu-slider > ul > li > ul > li','display','inline-block','','','.w-menu-slider'),(476506,'furniture-mobile','.w-menu-style-1 ul ul li','display','block','','','.w-menu-style-1'),(476507,'furniture-mobile','.w-menu-style-1 ul li:hover > ul','display','block','','','.w-menu-style-1'),(476508,'furniture-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','display','inline-block','','','.w-menu-style-1'),(476509,'furniture-mobile','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(476510,'furniture-mobile','.w-sale .left-text-left','display','block','','','.w-sale'),(476511,'furniture-mobile','.w-sale .left-count-hours','display','block','','','.w-sale'),(476512,'furniture-mobile','.w-promo-code .promo-text-2','display','none','2885','','.w-promo-code'),(476513,'furniture-mobile','.b-form .addresses','display','block','4','','.b-form'),(476514,'furniture-mobile','.b-datepicker .picker-switch','display','none','','','.b-datepicker'),(476515,'furniture-mobile','.b-info .info','display','inline-block','3','','.b-info'),(476516,'furniture-mobile','.w-personal-gift-status-bar .timeline','display','flex','','','.w-personal-gift-status-bar'),(476518,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','display','block','','','.b-switch'),(476519,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','display','inline-block','3','','.w-checkout-contact-information'),(476520,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','display','inline-block','3','','.w-checkout-contact-information'),(476521,'furniture-mobile','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(476522,'furniture-mobile','.w-checkout-shipping-address .genders-title > div','display','inline-block','','','.w-checkout-shipping-address'),(476523,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','display','inline-block','','','.b-form'),(476524,'furniture-mobile','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(476525,'furniture-mobile','.w-text .customer-service b','display','block','','','.w-text'),(476526,'furniture-mobile','.w-categories .categories','display','block','4','','.w-categories'),(476527,'furniture-mobile','.w-promo-code .holder','display','block','4','','.w-promo-code'),(476528,'furniture-mobile','.w-compare-box-item .checkbox + span','display','inline-block','','','.w-compare-box-item'),(476529,'furniture-mobile','.w-text .customer-service b','display','block','','','.w-text'),(476530,'furniture-mobile','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(476531,'furniture-mobile','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(476533,'furniture-mobile','.w-menu-style-1 ul ul','display','none','','','.w-menu-style-1'),(476535,'furniture-mobile','.w-menu-slider > ul > li > ul > li','display','inline-block','','','.w-menu-slider'),(476536,'furniture-mobile','.w-menu-big .hide-more.hide-more-disable, .w-menu-big .hide-more.hide-more-disable ~ li:not(.show-all)','display','block','','','.w-menu-big'),(476537,'furniture-mobile','.w-menu .hided.menu ul li','display','block','','','.w-menu'),(476538,'furniture-mobile','.w-image-maps .categories-items .item','display','block','1','','.w-image-maps'),(476539,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(476540,'furniture-mobile','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(476541,'furniture-mobile','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(476542,'furniture-mobile','.w-checkout-billing-address .edit-ab','display','inline-block','','','.w-checkout-billing-address'),(476543,'furniture-mobile','.w-checkout-billing-address .addresses .address-item label','display','block','','','.w-checkout-billing-address'),(476544,'furniture-mobile','.w-checkout-shipping-choice #shippingchoice-choice','display','flex','','','.w-checkout-shipping-choice'),(476545,'furniture-mobile','.w-checkout-shipping-choice input','display','none','','','.w-checkout-shipping-choice'),(476546,'furniture-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','display','inline-block','','','.w-menu-style-1'),(476547,'furniture-mobile','.w-cart-give-away h2','display','none','','','.w-cart-give-away'),(476548,'furniture-mobile','.w-promo-code .promo-text-2','display','none','2885','','.w-promo-code'),(476549,'furniture-mobile','.w-menu .hided.menu a, .w-menu .hided.menu .no-link','display','block','','','.w-menu'),(476550,'furniture-mobile','.w-wedding-registry-widgets-share-registry label','display','block','','','.w-wedding-registry-widgets-share-registry'),(476551,'furniture-mobile','.p-account-trade-form .wd-line-row-2','display','block','4','','.p-account-trade-form'),(476554,'furniture-mobile','.b-pass-strength .pass-strength','display','block','','','.b-pass-strength'),(476555,'furniture-mobile','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(476556,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display','inline-block','','','.b-switch'),(476557,'furniture-mobile','.w-quote .strong','display','block','','','.w-quote'),(476558,'furniture-mobile','.w-cart-up-sell h3','display','none','','','.w-cart-up-sell'),(476559,'furniture-mobile','.w-cart-compare .product-actions .dropdown-toggle','display','none','4','','.w-cart-compare'),(476560,'furniture-mobile','.p-blog-index .comment-author .says','display','none','','','.p-blog-index'),(476561,'furniture-mobile','.p-blog-index .comment-form p label','display','inline-block','','','.p-blog-index'),(476562,'furniture-mobile','.p-blog-index .comment-author .says','display','none','','','.p-blog-index'),(476563,'furniture-mobile','.b-select-suggest .select2-results li','display','list-item','','','.b-select-suggest'),(476564,'furniture-mobile','.p-blog-index .post-title','display','block','','','.p-blog-index'),(476565,'furniture-mobile','.p-account-trade-form .wl-td label','display','inline-block','','','.p-account-trade-form'),(476568,'furniture-mobile','.b-select-suggest .select2-search-choice-close','display','block','','','.b-select-suggest'),(476569,'furniture-mobile','.b-select-suggest .select2-container.select2-container-disabled .select2-choice abbr','display','none','','','.b-select-suggest'),(476570,'furniture-mobile','.b-select-suggest .select2-more-results','display','list-item','','','.b-select-suggest'),(476571,'furniture-mobile','.b-select-suggest .select2-results .select2-selected','display','none','','','.b-select-suggest'),(476572,'furniture-mobile','.b-select-suggest .select2-results .select2-disabled','display','list-item','','','.b-select-suggest'),(476573,'furniture-mobile','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','display','list-item','','','.b-select-suggest'),(476574,'furniture-mobile','.w-menu-big .hide-more, .w-menu-big .hide-more ~ li:not(.show-all)','display','none','','','.w-menu-big'),(476575,'furniture-mobile','.w-menu-slider > ul > li','display','inline-block','','','.w-menu-slider'),(476576,'furniture-mobile','.w-checkout-shipping-address .change-ab','display','inline-block','','','.w-checkout-shipping-address'),(476577,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item label','display','block','','','.w-checkout-shipping-address'),(476578,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','','','.b-select-suggest'),(476579,'furniture-mobile','.b-select-suggest .select2-search','display','inline-block','','','.b-select-suggest'),(476580,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','display','inline-block','','','.b-select-suggest'),(476581,'furniture-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','display','inline-block','','','.w-menu-style-1'),(476582,'furniture-mobile','.w-neighbour-checkout .text','display','inline-block','','','.w-neighbour-checkout'),(476583,'furniture-mobile','.w-text .customer-service b','display','block','','','.w-text'),(476584,'furniture-mobile','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(476585,'furniture-mobile','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(476586,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(476587,'furniture-mobile','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(476588,'furniture-mobile','.w-menu-style-1 li li a, .w-menu-style-1 li li .no-link','display','block','','','.w-menu-style-1'),(476589,'furniture-mobile','.w-menu-style-1 ul ul','display','none','','','.w-menu-style-1'),(476590,'furniture-mobile','.w-menu-slider a, .w-menu-slider .no-link','display','inline-block','','','.w-menu-slider'),(476591,'furniture-mobile','.w-menu .hided.menu ul li','display','block','','','.w-menu'),(476592,'furniture-mobile','.w-menu-big > ul > li:hover > ul','display','block','','','.w-menu-big'),(476593,'furniture-mobile','.w-menu-big li li a, .w-menu-big li li .no-link','display','block','','','.w-menu-big'),(476594,'furniture-mobile','.w-menu div.hided.menu .active + ul, .w-menu div.hided.menu .opened + ul','display','block','','','.w-menu'),(476595,'furniture-mobile','.w-menu-big li li li','display','block','','','.w-menu-big'),(476596,'furniture-mobile','.w-menu .menu .menu-ico','display','none','','','.w-menu'),(476597,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','display','none','','','.w-menu'),(476598,'furniture-mobile','.w-menu .hided.menu ul li','display','block','','','.w-menu'),(476599,'furniture-mobile','.w-menu .hided.menu .menu-ico','display','block','','','.w-menu'),(476600,'furniture-mobile','.w-menu .hided.menu .menu-ico','display','block','','','.w-menu'),(476601,'furniture-mobile','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(476602,'furniture-mobile','.p-blog-index .nav-links .screen-reader-text','display','block','','','.p-blog-index'),(476603,'furniture-mobile','.p-blog-index .post-title','display','block','','','.p-blog-index'),(476604,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(476605,'furniture-mobile','.p-reviews-info .review_by span','display','inline-block','','','.p-reviews-info'),(476606,'furniture-mobile','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(476607,'furniture-mobile','.w-menu-horizontal ul li:hover > ul','display','block','','','.w-menu-horizontal'),(476608,'furniture-mobile','.p-reviews-info .review_by span','display','inline-block','','','.p-reviews-info'),(476609,'furniture-mobile','.w-menu-big li','display','inline-block','','','.w-menu-big'),(476610,'furniture-mobile','.w-menu-slider > ul > li > ul > li','display','inline-block','','','.w-menu-slider'),(476611,'furniture-mobile','.w-menu div.hided.menu .active + ul, .w-menu div.hided.menu .opened + ul','display','block','','','.w-menu'),(476612,'furniture-mobile','.w-cart-listing .points-redeem','display','inline-block','','','.w-cart-listing'),(476613,'furniture-mobile','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(476614,'furniture-mobile','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(476615,'furniture-mobile','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(476616,'furniture-mobile','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(476617,'furniture-mobile','.w-promo-code .holder','display','block','4','','.w-promo-code'),(476618,'furniture-mobile','.w-sale .left-count','display','block','','','.w-sale'),(476619,'furniture-mobile','.w-login-block .label','display','block','','','.w-login-block'),(476620,'furniture-mobile','.w-categories .item','display','inline-block','','','.w-categories'),(476621,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(476622,'furniture-mobile','.w-account-customer-additional-field .field-type-checkbox label','display','inline-block','','','.w-account-customer-additional-field'),(476623,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.b-data-table'),(476624,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.b-data-table'),(476625,'furniture-mobile','.w-account .account-title a.my-acc-link.active + .account-dropdown','display','block','','','.w-account'),(476626,'furniture-mobile','.w-communication-post .communication-post-author','display','flex','','','.w-communication-post'),(476627,'furniture-mobile','.b-products-listing .products-listing .compare label','display','inline','','','.b-products-listing'),(476628,'furniture-mobile','.b-products-listing .products-listing .compare','display','inline-block','','','.b-products-listing'),(476629,'furniture-mobile','.b-products-listing .BlockBox','display','block','4','','.b-products-listing'),(476630,'furniture-mobile','.b-products-listing .btn-preloader','display','inline-block','3','','.b-products-listing'),(476631,'furniture-mobile','.b-products-listing .hide','display','none','','','.b-products-listing'),(476632,'furniture-mobile','.b-products-listing .hover-box-content','display','none','','','.b-products-listing'),(476633,'furniture-mobile','.b-products-listing .hover-box:hover .hover-box-content','display','block','','','.b-products-listing'),(476634,'furniture-mobile','.b-products-listing .loader','display','inline-block','4','','.b-products-listing'),(476635,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block','display','flex','','','.b-products-listing'),(476636,'furniture-mobile','.b-products-listing .products-listing','display','block','4','','.b-products-listing'),(476637,'furniture-mobile','.b-products-listing .products-listing .btn-buy','display','inline-block','3','','.b-products-listing'),(476638,'furniture-mobile','.w-catalog-b2b-add-button ','display','none','','','.w-catalog-b2b-add-button'),(476639,'furniture-mobile','.b-products-listing .products-listing .item','display','inline-block','','','.b-products-listing'),(476640,'furniture-mobile','.b-products-listing .products-listing.align-left .item','display','block','','','.b-products-listing'),(476641,'furniture-mobile','.b-products-listing .products-listing.align-right .item','display','block','','','.b-products-listing'),(476642,'furniture-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','display','block','','','.b-products-listing'),(476643,'furniture-mobile','.b-products-listing .show-ofstock-products .headerStock','display','inline-block','','','.b-products-listing'),(476644,'furniture-mobile','.w-blog-widget-tag-cloud a','display','inline-block','','','.w-blog-widget-tag-cloud'),(476645,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_img img','display','inline-block','','','.w-blog-widget-related-posts-by-category'),(476646,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_content a','display','block','','','.w-blog-widget-related-posts-by-category'),(476647,'furniture-mobile','.w-blog-widget-related-posts .post_content a','display','block','','','.w-blog-widget-related-posts'),(476648,'furniture-mobile','.w-blog-widget-post-title h1','display','none','4','','.w-blog-widget-post-title'),(476649,'furniture-mobile','.w-blog-widget-post-title h1','display','none','3','','.w-blog-widget-post-title'),(476650,'furniture-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','display','inline-block','','','.w-blog-widget-post-share'),(476651,'furniture-mobile','.w-blog-widget-post-listing .products','display','block','4','','.w-blog-widget-post-listing'),(476652,'furniture-mobile','.w-blog-widget-post-listing .post_date span + span','display','inline-block','3','','.w-blog-widget-post-listing'),(476653,'furniture-mobile','.w-blog-widget-post-listing .post_comment','display','none','','','.w-blog-widget-post-listing'),(476654,'furniture-mobile','.w-blog-widget-most-popular-posts a','display','inline-block','3','','.w-blog-widget-most-popular-posts'),(476655,'furniture-mobile','.w-blog-widget-post-comments-count span','display','inline-block','','','.w-blog-widget-post-comments-count'),(476656,'furniture-mobile','.w-blog-widget-most-popular-posts a','display','block','','','.w-blog-widget-most-popular-posts'),(476657,'furniture-mobile','.w-blog-widget-categories-list a','display','inline-block','3','','.w-blog-widget-categories-list'),(476658,'furniture-mobile','.w-blog-widget-categories-list a','display','block','','','.w-blog-widget-categories-list'),(476659,'furniture-mobile','.checkbox input','display','none','','',''),(476660,'furniture-mobile','.checkbox input + span','display','inline-block','','',''),(476661,'furniture-mobile','.w-currencies .select-link','display','block','2885','','.w-currencies'),(476662,'furniture-mobile','.w-currencies .select','display','none','','','.w-currencies'),(476663,'furniture-mobile','.w-currencies .currencies:hover .select','display','block','','','.w-currencies'),(476664,'furniture-mobile','.w-currencies .currencies','display','inline-block','','','.w-currencies'),(476665,'furniture-mobile','.w-account .acc-top','display','block','4','','.w-account'),(476666,'furniture-mobile','.w-currencies .currencies-title','display','block','','','.w-currencies'),(476667,'furniture-mobile','.p-reviews-info .review-info-text','display','block','4','','.p-reviews-info'),(476668,'furniture-mobile','.w-sale .left-count','display','block','','','.w-sale'),(476669,'furniture-mobile','.b-rating .glyphicon','display','inline-block','','','.b-rating'),(476672,'furniture-mobile','.b-form .newsletter-row','display','block','4','','.b-form'),(476673,'furniture-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','display','block','','','.b-fancybox'),(476674,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(476675,'furniture-mobile','.p-account-trade-form .wl-td label','display','inline-block','','','.p-account-trade-form'),(476676,'furniture-mobile','.w-sale .left-text-left','display','block','','','.w-sale'),(476677,'furniture-mobile','.w-menu-style-1 li li a, .w-menu-style-1 li li .no-link','display','block','','','.w-menu-style-1'),(476678,'furniture-mobile','.w-cart-credit-amount .btn-remove','display','inline-block','','','.w-cart-credit-amount'),(476679,'furniture-mobile','.w-menu-slider a, .w-menu-slider .no-link','display','inline-block','','','.w-menu-slider'),(476680,'furniture-mobile','.w-menu div.hided.menu .active + ul, .w-menu div.hided.menu .opened + ul','display','block','','','.w-menu'),(476681,'furniture-mobile','.w-login-block .label','display','block','','','.w-login-block'),(476682,'furniture-mobile','.w-coupons-and-vauchers-checkout .btn-remove','display','inline-block','','','.w-coupons-and-vauchers-checkout'),(476683,'furniture-mobile','.order-summary .price-row.ot_coupon .title','display','inline-block','3','','.order-summary'),(476684,'furniture-mobile','.p-blog-index .comment-form p label','display','inline-block','','','.p-blog-index'),(476685,'furniture-mobile','.p-blog-index .entry-content','display','block','4','','.p-blog-index'),(476686,'furniture-mobile','.p-account-trade-form .wd-line-row-2','display','block','4','','.p-account-trade-form'),(476687,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(476688,'furniture-mobile','.b-form .eye-password-wrap','display','block','','','.b-form'),(476689,'furniture-mobile','.w-taxable form','display','flex','','','.w-taxable'),(476690,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','display','inline-block','','',''),(476691,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','','','.w-communication-new-topic'),(476692,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','3','','.w-communication-new-topic'),(476693,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','display','inline-block','','','.w-communication-new-topic'),(476694,'furniture-mobile','.w-communication-new-topic .middle-form .col-2 label > span','display','block','','','.w-communication-new-topic'),(476697,'furniture-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(476700,'furniture-mobile','.w-menu-style-1 ul ul','display','none','','','.w-menu-style-1'),(476701,'furniture-mobile','.w-tabs .tab-li.tab-quote a','display','block','3','','.w-tabs'),(476702,'furniture-mobile','.w-login-block .cols','display','block','4','','.w-login-block'),(476703,'furniture-mobile','.w-menu .hided.menu a, .w-menu .hided.menu .no-link','display','block','','','.w-menu'),(476704,'furniture-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(476705,'furniture-mobile','.w-compare-box-item .checkbox + span','display','inline-block','','','.w-compare-box-item'),(476706,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(476707,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(476708,'furniture-mobile','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','display','inline-block','','','.b-form'),(476709,'furniture-mobile','.w-wedding-registry-widgets-photos .upload-file-wrap','display','flex','','','.w-wedding-registry-widgets-photos'),(476710,'furniture-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(476711,'furniture-mobile','.w-sale .left-text-left','display','block','','','.w-sale'),(476712,'furniture-mobile','.w-sale .left-text-right','display','block','','','.w-sale'),(476713,'furniture-mobile','.w-sale .left-count-hours','display','block','','','.w-sale'),(476714,'furniture-mobile','.w-sale .btn','display','block','','','.w-sale'),(476715,'furniture-mobile','.w-sale .left-count-days','display','block','','','.w-sale'),(476716,'furniture-mobile','.w-sale .left-count','display','block','','','.w-sale'),(476717,'furniture-mobile','.w-promo-code .holder','display','block','4','','.w-promo-code'),(476718,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(476719,'furniture-mobile','.w-menu-horizontal ul ul','display','none','','','.w-menu-horizontal'),(476720,'furniture-mobile','.w-menu-horizontal ul ul li','display','block','','','.w-menu-horizontal'),(476721,'furniture-mobile','.p-blog-index .comment-form p label','display','inline-block','','','.p-blog-index'),(476722,'furniture-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','display','inline-block','','','.w-menu-style-1'),(476723,'furniture-mobile','.w-catalog-paging .next-pages','display','inline-block','','','.w-catalog-paging'),(476724,'furniture-mobile','.w-catalog-listing-look .grid','display','inline-block','','','.w-catalog-listing-look'),(476725,'furniture-mobile','.w-catalog-listing-look .b2b','display','inline-block','','','.w-catalog-listing-look'),(476726,'furniture-mobile','.w-catalog-listing-look .list','display','inline-block','','','.w-catalog-listing-look'),(476727,'furniture-mobile','.w-catalog-items-on-page .items-on-page','display','flex','','','.w-catalog-items-on-page'),(476728,'furniture-mobile','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(476729,'furniture-mobile','.w-cart-listing .item .attributes > div','display','table-row','','','.w-cart-listing'),(476730,'furniture-mobile','.w-cart-listing .item .attributes span','display','table-cell','','','.w-cart-listing'),(476731,'furniture-mobile','.w-cart-listing .item .attributes','display','table','','','.w-cart-listing'),(476732,'furniture-mobile','.w-cart-listing .item .attributes strong','display','table-cell','','','.w-cart-listing'),(476733,'furniture-mobile','.w-cart-listing .item .gift-wrap label','display','flex','','','.w-cart-listing'),(476734,'furniture-mobile','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','display','block','','','.w-cart-listing'),(476735,'furniture-mobile','.w-cart-listing .headings','display','none','2885','','.w-cart-listing'),(476736,'furniture-mobile','.w-cart-listing .item .price *','display','inline-block','2885','','.w-cart-listing'),(476737,'furniture-mobile','.w-cart-listing .remove-btn span','display','inline-block','2885','','.w-cart-listing'),(476738,'furniture-mobile','.w-cart-give-away .ga_name','display','block','4','','.w-cart-give-away'),(476739,'furniture-mobile','.w-cart-discount-coupon .btn-remove','display','inline-block','','','.w-cart-discount-coupon'),(476740,'furniture-mobile','.w-cart .cart-box-link','display','flex','','','.w-cart'),(476741,'furniture-mobile','.w-cart .cart-box.hover-box:hover .cart-content','display','block','','','.w-cart'),(476742,'furniture-mobile','.w-cart .cart-box.hover-box .cart-content','display','none','','','.w-cart'),(476743,'furniture-mobile','.w-cart .strong','display','block','','','.w-cart'),(476744,'furniture-mobile','.w-cart .price','display','block','','','.w-cart'),(476745,'furniture-mobile','.w-cart .name','display','block','','','.w-cart'),(476746,'furniture-mobile','.w-cart .multicart .title','display','inline-block','','','.w-cart'),(476747,'furniture-mobile','.w-cart .no-text','display','inline-block','','','.w-cart'),(476748,'furniture-mobile','.w-cart .multicart .sub-total-row','display','block','','','.w-cart'),(476749,'furniture-mobile','.w-cart .multicart .name','display','block','','','.w-cart'),(476750,'furniture-mobile','.w-cart .multicart .item','display','block','','','.w-cart'),(476751,'furniture-mobile','.w-cart .multicart .current-text','display','block','','','.w-cart'),(476752,'furniture-mobile','.w-image-maps .float-items .item .title','display','block','','','.w-image-maps'),(476753,'furniture-mobile','.w-image-maps .float-items .item .description','display','block','','','.w-image-maps'),(476754,'furniture-mobile','.w-image-maps .products-items .item-holder','display','block','1','','.w-image-maps'),(476755,'furniture-mobile','.w-image-maps .svg-wrap','display','inline-block','','','.w-image-maps'),(476756,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','display','none','','','.w-image-maps'),(476757,'furniture-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','display','inline-block','','','.b-compare'),(476758,'furniture-mobile','.p-wedding-registry-search #searchform-status','display','flex','','','.p-wedding-registry-search'),(476759,'furniture-mobile','.w-tabs .accordion-heading','display','block','','','.w-tabs'),(476761,'furniture-mobile','.w-sale .left-count-days','display','block','','','.w-sale'),(476762,'furniture-mobile','.w-sale .left-count','display','block','','','.w-sale'),(476763,'furniture-mobile','.w-sale .text','display','block','','','.w-sale'),(476764,'furniture-mobile','.w-menu-style-1 ul ul','display','none','','','.w-menu-style-1'),(476765,'furniture-mobile','.w-cart-shipping-estimator .item .row','display','block','','','.w-cart-shipping-estimator'),(476766,'furniture-mobile','.w-menu-slider > ul > li > ul > li','display','inline-block','','','.w-menu-slider'),(476767,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','display','none','','','.w-menu'),(476768,'furniture-mobile','.w-menu .hided.menu ul li','display','block','','','.w-menu'),(476769,'furniture-mobile','.w-login-block .cols','display','block','4','','.w-login-block'),(476770,'furniture-mobile','.w-menu .hided.menu .menu-ico','display','block','','','.w-menu'),(476771,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(476772,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(476773,'furniture-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(476774,'furniture-mobile','.w-catalog-paging .paging-holder','display','inline-block','','','.w-catalog-paging'),(476775,'furniture-mobile','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(476776,'furniture-mobile','.w-catalog-paging .paging-item','display','inline-block','','','.w-catalog-paging'),(476777,'furniture-mobile','.w-catalog-paging .next','display','inline-block','','','.w-catalog-paging'),(476778,'furniture-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(476779,'furniture-mobile','.order-summary .price-row.ot_bonus_points .title','display','inline-block','3','','.order-summary'),(476780,'furniture-mobile','.p-blog-index .post-list .comments-link','display','none','','','.p-blog-index'),(476781,'furniture-mobile','.p-blog-index .entry-content','display','block','4','','.p-blog-index'),(476782,'furniture-mobile','.p-blog-index .comment-meta','display','block','4','','.p-blog-index'),(476783,'furniture-mobile','.p-account-trade-form .wl-td label','display','inline-block','','','.p-account-trade-form'),(476784,'furniture-mobile','.w-cart-shipping-estimator .shipping-estimator .heading-2','display','none','','','.w-cart-shipping-estimator'),(476785,'furniture-mobile','.p-reviews-info .review-info-text','display','block','4','','.p-reviews-info'),(476786,'furniture-mobile','.w-catalog-paging .paging','display','inline-block','','','.w-catalog-paging'),(476787,'furniture-mobile','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(476788,'furniture-mobile','.w-menu .hided.menu a, .w-menu .hided.menu .no-link','display','block','','','.w-menu'),(476789,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','display','none','','','.w-menu'),(476790,'furniture-mobile','.w-menu-slider > ul > li > ul','display','none','','','.w-menu-slider'),(476791,'furniture-mobile','.w-reviews-content .item','display','grid','','','.w-reviews-content'),(476792,'furniture-mobile','.b-info-popup .info-popup:hover div','display','block','','','.b-info-popup'),(476793,'furniture-mobile','.w-filters .content-filter-widget','display','none','2885','','.w-filters'),(476794,'furniture-mobile','.w-filters .fsl_handle','display','block','4','','.w-filters'),(476795,'furniture-mobile','.w-filters .filter-box-content ul li.view_items','display','block','','','.w-filters'),(476796,'furniture-mobile','.p-blog-index .nav-links .screen-reader-text','display','block','','','.p-blog-index'),(476797,'furniture-mobile','.w-account-last-order .last-order-days','display','block','','','.w-account-last-order'),(476798,'furniture-mobile','.w-banner .sliderItems a + a, .w-banner .sliderItems a + img, .w-banner .sliderItems img + a, .w-banner .sliderItems img + img','display','none','','','.w-banner'),(476799,'furniture-mobile','.w-catalog-paging ','display','inline-block','2','','.w-catalog-paging'),(476800,'furniture-mobile','.w-promo-code .promo-text-2','display','none','2885','','.w-promo-code'),(476802,'furniture-mobile','.w-taxable select','display','inline-block','','','.w-taxable'),(476803,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container','display','inline-block','','','.b-switch'),(476804,'furniture-mobile','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(476805,'furniture-mobile','.w-menu-style-1 ul li:hover > ul','display','block','','','.w-menu-style-1'),(476806,'furniture-mobile','.w-tabs .tab-li.tab-sample a','display','block','3','','.w-tabs'),(476807,'furniture-mobile','.w-menu .hided.menu a, .w-menu .hided.menu .no-link','display','block','','','.w-menu'),(476808,'furniture-mobile','.p-blog-index .post-list .comments-link','display','none','','','.p-blog-index'),(476809,'furniture-mobile','.w-menu-style-1 li li a, .w-menu-style-1 li li .no-link','display','block','','','.w-menu-style-1'),(476810,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','display','none','','','.w-menu'),(476811,'furniture-mobile','.w-menu .menu .menu-ico','display','none','','','.w-menu'),(476812,'furniture-mobile','.w-menu div.hided.menu .active + ul, .w-menu div.hided.menu .opened + ul','display','block','','','.w-menu'),(476813,'furniture-mobile','.w-menu-big > ul > li > ul','display','none','','','.w-menu-big'),(476814,'furniture-mobile','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(476815,'furniture-mobile','.w-menu-slider > ul > li > ul > li','display','inline-block','','','.w-menu-slider'),(476816,'furniture-mobile','.w-menu-slider > ul > li','display','inline-block','','','.w-menu-slider'),(476817,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','display','inline','','','.b-h-inline'),(476818,'furniture-mobile','.w-quote .no-text','display','inline-block','','','.w-quote'),(476819,'furniture-mobile','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(476820,'furniture-mobile','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(476821,'furniture-mobile','.w-menu .hided.menu ul li','display','block','','','.w-menu'),(476822,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(476823,'furniture-mobile','.p-blog-index .nav-links .screen-reader-text','display','block','','','.p-blog-index'),(476824,'furniture-mobile','.p-blog-index .comment-meta','display','block','4','','.p-blog-index'),(476825,'furniture-mobile','.p-blog-index .entry-content','display','block','4','','.p-blog-index'),(476826,'furniture-mobile','.w-filters .mobileCollapse','display','none','','','.w-filters'),(476827,'furniture-mobile','.p-account-trade-form .wd-line-row-2','display','block','4','','.p-account-trade-form'),(476828,'furniture-mobile','.p-blog-index .comment-meta','display','block','4','','.p-blog-index'),(476829,'furniture-mobile','.p-blog-index .comment-form p label','display','inline-block','','','.p-blog-index'),(476830,'furniture-mobile','.p-blog-index .comment-author .says','display','none','','','.p-blog-index'),(476831,'furniture-mobile','.p-blog-index .nav-links .screen-reader-text','display','block','','','.p-blog-index'),(476832,'furniture-mobile','.p-blog-index .post-title','display','block','','','.p-blog-index'),(476833,'furniture-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','display','inline-block','','','.w-filters'),(476834,'furniture-mobile','.b-product-images .media-popup .mp-big-images .item','display','flex','','','.b-product-images'),(476835,'furniture-mobile','.b-product-images .media-popup .mp-big-images .item + .item:not(.slick-slide)','display','none','','','.b-product-images'),(476836,'furniture-mobile','.b-product-images .media-popup .mp-small-images .item','display','inline-block','','','.b-product-images'),(476837,'furniture-mobile','.b-product-images .media-popup .mp-small-images img','display','inline-block','','','.b-product-images'),(476838,'furniture-mobile','.b-product-images .media-popup .slick-dots button','display','none','','','.b-product-images'),(476839,'furniture-mobile','.b-product-images .media-popup .slick-dots li','display','inline-block','','','.b-product-images'),(476840,'furniture-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .menu-content','display','none','','','.b-menu-burger_icon'),(476841,'furniture-mobile','.b-menu-burger_icon .bi-opened .menu-style[data-burger_icon] .menu-content','display','block','','','.b-menu-burger_icon'),(476842,'furniture-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','display','block','','','.b-menu-burger_icon'),(476843,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','display','block','','','.b-menu-lev_display-slide'),(476844,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','display','block','','','.b-menu-lev_display-slide'),(476845,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','display','block','','','.b-menu-lev_display-slide'),(476846,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','display','block','','','.b-menu-lev_display-slide'),(476847,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','display','block','','','.b-menu-lev_display-slide'),(476848,'furniture-mobile','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(476849,'furniture-mobile','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(476850,'furniture-mobile','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(476851,'furniture-mobile','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(476852,'furniture-mobile','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(476853,'furniture-mobile','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(476854,'furniture-mobile','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(476855,'furniture-mobile','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(476856,'furniture-mobile','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(476857,'furniture-mobile','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(476858,'furniture-mobile','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(476859,'furniture-mobile','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(476860,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-2','display','none','','','.b-menu-lev_vis'),(476861,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(476862,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-3','display','none','','','.b-menu-lev_vis'),(476863,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(476864,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-4','display','none','','','.b-menu-lev_vis'),(476865,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(476866,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-5','display','none','','','.b-menu-lev_vis'),(476867,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(476868,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-6','display','none','','','.b-menu-lev_vis'),(476869,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(476870,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(476871,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-2','display','none','','','.b-menu-lev_vis'),(476872,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(476873,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-3','display','none','','','.b-menu-lev_vis'),(476874,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(476875,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-4','display','none','','','.b-menu-lev_vis'),(476876,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(476877,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-5','display','none','','','.b-menu-lev_vis'),(476878,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(476879,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-6','display','none','','','.b-menu-lev_vis'),(476880,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(476881,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(476882,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-3','display','none','','','.b-menu-lev_vis-click_icon'),(476883,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(476884,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-4','display','none','','','.b-menu-lev_vis-click_icon'),(476885,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(476886,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-5','display','none','','','.b-menu-lev_vis-click_icon'),(476887,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(476888,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-6','display','none','','','.b-menu-lev_vis-click_icon'),(476889,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display','block','','','.b-menu-open_from-left'),(476890,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul','display','flex','','','.b-menu-position'),(476891,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(476892,'furniture-mobile','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display','none','','','.b-menu-style'),(476893,'furniture-mobile','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display','none','','','.b-menu-style'),(476894,'furniture-mobile','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display','none','','','.b-menu-style'),(476895,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .component-item','display','none','','','.b-menu-style-1'),(476896,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','display','block','','','.b-menu-style-2'),(476897,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','display','block','','','.b-menu-style-2'),(476898,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','display','flex','','','.b-menu-style-2'),(476899,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .languages','display','flex','','','.b-menu-style-2'),(476900,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','display','block','','','.b-menu-style-2'),(476901,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies','display','flex','','','.b-menu-style-2'),(476902,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','display','flex','','','.b-menu-style-2'),(476903,'furniture-mobile','.b-trade-approval .steps-bar','display','table','','','.b-trade-approval'),(476904,'furniture-mobile','.b-trade-approval .steps-bar li','display','table-cell','','','.b-trade-approval'),(476905,'furniture-mobile','.b-trade-approval .steps-bar li a','display','block','','','.b-trade-approval'),(476906,'furniture-mobile','.b-trade-approval .middle-form label','display','block','','','.b-trade-approval'),(476907,'furniture-mobile','.b-trade-approval .columns','display','block','4','','.b-trade-approval'),(476908,'furniture-mobile','.batchPr .checkbox input:not(checked) + span:before','display','none','','','.batchPr'),(476909,'furniture-mobile','.batchPr .checkbox input:checked + span:before','display','inline-block','','','.batchPr'),(476910,'furniture-mobile','.batchPr .batchSelect .checkbox','display','inline-block','','','.batchPr'),(476911,'furniture-mobile','.batchPr .btn-batch-remove','display','block','3','','.batchPr'),(476912,'furniture-mobile','.batchPr .checkbox input + span','display','block','','','.batchPr'),(476913,'furniture-mobile','.batchPr .batch-selected-products-list','display','none','','','.batchPr'),(476914,'furniture-mobile','.batchPr .checkbox input','display','none','','','.batchPr'),(476915,'furniture-mobile','.batchPr .w-batch-selected-products .item:hover .btn-batch-remove','display','block','','','.batchPr'),(476916,'furniture-mobile','.batchPr .btn-batch-remove','display','none','','','.batchPr'),(476917,'furniture-mobile','.batchPr .w-batch-products .radio-attributes .option-color, .batchPr .w-batch-products .radio-attributes span[itemprop=\"price\"]','display','none','','','.batchPr'),(476918,'furniture-mobile','.batchPr .products-listing .radio-attributes label','display','inline-block','','','.batchPr'),(476919,'furniture-mobile','.w-account-personal-catalog .list-switcher','display','flex','','','.w-account-personal-catalog'),(476920,'furniture-mobile','.w-account-subscription .send-email','display','block','','','.w-account-subscription'),(476921,'furniture-mobile','.w-account-subscription .subscription-variant','display','flex','','','.w-account-subscription'),(476922,'furniture-mobile','.w-catalog-additional-images li','display','inline-block','','','.w-catalog-additional-images'),(476923,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','display','inline-block','3','','.w-catalog-compare'),(476924,'furniture-mobile','.w-catalog-compare td span','display','inline','','','.w-catalog-compare'),(476925,'furniture-mobile','.w-catalog-compare .product-listing','display','flex','','','.w-catalog-compare'),(476926,'furniture-mobile','.w-catalog-compare .promos-info','display','none','','','.w-catalog-compare'),(476927,'furniture-mobile','.w-catalog-compare .item .compare a','display','none','','','.w-catalog-compare'),(476928,'furniture-mobile','.w-catalog-compare .cross-box .different-all','display','flex','','','.w-catalog-compare'),(476929,'furniture-mobile','.w-catalog-compare .cross-box','display','flex','','','.w-catalog-compare'),(476930,'furniture-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','display','block','','','.w-delivery-day'),(476931,'furniture-mobile','.w-delivery-day .time-left','display','flex','','','.w-delivery-day'),(476932,'furniture-mobile','.w-delivery-day .left-count','display','block','','','.w-delivery-day'),(476933,'furniture-mobile','.w-delivery-day .left-text-left','display','block','','','.w-delivery-day'),(476934,'furniture-mobile','.w-delivery-day .left-text-right','display','block','','','.w-delivery-day'),(476935,'furniture-mobile','.w-product-images .img-holder','display','flex','','','.w-product-images'),(476936,'furniture-mobile','.w-product-images .additional-vertical','display','flex','','','.w-product-images'),(476937,'furniture-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','display','inline-block','','','.b-cookie-notice'),(476938,'furniture-mobile','.w-cart .cart-box-link','display','inline-block','4','','.w-cart'),(476939,'furniture-mobile','.w-account .my-acc-link','display','inline-block','4','','.w-account'),(476940,'furniture-mobile','.w-account .account-dropdown','display','block','3','','.w-account'),(476941,'furniture-mobile','.tripleBanner .w-html_box','display','inline-block','3','','.tripleBanner'),(476942,'furniture-mobile','.b-products-listing .products-listing .item picture','display','block','','','.b-products-listing'),(476943,'furniture-mobile','.preFooter .w-banner .single_banner','display','inline-block','','','.preFooter'),(476944,'furniture-mobile','.b-slick .slick-slide','display','none','','','.b-slick'),(476945,'furniture-mobile','.b-slick .slick-arrow.slick-hidden','display','none','','','.b-slick'),(476946,'furniture-mobile','.b-slick .slick-initialized .slick-slide','display','block','','','.b-slick'),(476947,'furniture-mobile','.b-slick .slick-list','display','block','','','.b-slick'),(476948,'furniture-mobile','.b-slick .slick-slide img','display','block','','','.b-slick'),(476949,'furniture-mobile','.b-slick .slick-slide.slick-loading img','display','none','','','.b-slick'),(476950,'furniture-mobile','.b-slick .slick-slider','display','block','','','.b-slick'),(476951,'furniture-mobile','.b-slick .slick-track','display','block','','','.b-slick'),(476952,'furniture-mobile','.b-slick .slick-track, .b-slick .slick-track:after','display','table','3','','.b-slick'),(476953,'furniture-mobile','.b-slick .slick-vertical .slick-slide','display','block','','','.b-slick'),(476954,'furniture-mobile','.w-account .no-text span','display','block','','','.w-account'),(476955,'furniture-mobile','.w-account .my-acc-link','display','none','2885,4','','.w-account'),(476956,'furniture-mobile','.w-account .no-text','display','none','2885','','.w-account'),(476957,'furniture-mobile','.w-cart .cart-box-link','display','none','2885,4','','.w-cart'),(476958,'furniture-mobile','.w-cart .no-text','display','none','2885','','.w-cart'),(476959,'furniture-mobile','.w-search .search-ico','display','inline-block','2885,3','','.w-search'),(476960,'furniture-mobile','.w-search .suggest-js','display','none','2885','','.w-search'),(476961,'furniture-mobile','.w-search .suggest-js.opened','display','block','2885','','.w-search'),(476962,'furniture-mobile','.menu-header .burger-icon','display','inline-block','2885','','.menu-header'),(476963,'furniture-mobile','.tripleBanner ','display','flex','','','.tripleBanner'),(476964,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1','display','flex','2945','','.b-menu-style-3'),(476965,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2','display','flex','2945','','.b-menu-style-3'),(476966,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','display','block','2885','','.b-menu-style-3'),(476967,'furniture-mobile','.w-cart-listing .item, .w-cart-listing .headings','display','grid','','','.w-cart-listing'),(476968,'furniture-mobile','.b-products-listing .save-price-box','display','none','','','.b-products-listing'),(476969,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','display','block','3','','.b-products-listing'),(476970,'furniture-mobile','.b-products-listing .add-to-personal-catalog','display','block','3','','.b-products-listing'),(476971,'furniture-mobile','.b-products-listing .products-listing .compare input + span','display','block','','','.b-products-listing'),(476972,'furniture-mobile','.b-products-listing .products-listing .item:hover .item-nav','display','block','','','.b-products-listing'),(476973,'furniture-mobile','.LeftCategories .level-2','display','none','','','.LeftCategories'),(476974,'furniture-mobile','.LeftCategories .w-menu-simple ul li a','display','block','','','.LeftCategories'),(476975,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-content','display','block','4','','.b-products-listing'),(476976,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','display','none','','','.b-products-listing'),(476977,'furniture-mobile','.b-products-listing .products-listing.slick-slider .item-nav','display','none','','','.b-products-listing'),(476978,'furniture-mobile','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','display','none','4','','.b-products-listing'),(476979,'furniture-mobile','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(476980,'furniture-mobile','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(476981,'furniture-mobile','.w-subscribers .sb_ta','display','flex','','','.w-subscribers'),(476982,'furniture-mobile','.w-subscribers .btn-submit','display','block','','','.w-subscribers'),(476983,'furniture-mobile','.w-quote .multicart .current-text','display','block','','','.w-quote'),(476984,'furniture-mobile','.w-quote .multicart .item','display','block','','','.w-quote'),(476985,'furniture-mobile','.w-quote .multicart .name','display','block','','','.w-quote'),(476986,'furniture-mobile','.w-quote .multicart .sub-total-row','display','block','','','.w-quote'),(476987,'furniture-mobile','.w-quote .multicart .title','display','inline-block','','','.w-quote'),(476988,'furniture-mobile','.w-quote .name','display','block','','','.w-quote'),(476989,'furniture-mobile','.w-quote .price','display','block','','','.w-quote'),(476990,'furniture-mobile','.w-quote a.item','display','block','4','','.w-quote'),(476991,'furniture-mobile','.w-quote a.item','display','block','','','.w-quote'),(476992,'furniture-mobile','.w-quote .cart-box-link','display','none','2885,4','','.w-quote'),(476993,'furniture-mobile','.w-social-links a','display','inline-block','','','.w-social-links'),(476994,'furniture-mobile','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(476995,'furniture-mobile','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(476996,'furniture-mobile','.b-products-listing .rating, .b-products-listing .ratingCounts','display','inline-block','','','.b-products-listing'),(476997,'furniture-mobile','.rating, .ratingCounts','display','inline-block','','',''),(476998,'furniture-mobile','.b-products-listing .promos-info .promo-item','display','flex','','','.b-products-listing'),(476999,'furniture-mobile','.w-product-sale-ends .left-count','display','block','','','.w-product-sale-ends'),(477000,'furniture-mobile','.w-product-sale-ends .left-count-days','display','block','','','.w-product-sale-ends'),(477001,'furniture-mobile','.w-product-sale-ends .left-count-hours','display','block','','','.w-product-sale-ends'),(477002,'furniture-mobile','.w-product-sale-ends .left-text-left','display','block','','','.w-product-sale-ends'),(477003,'furniture-mobile','.w-product-sale-ends .left-text-right','display','block','','','.w-product-sale-ends'),(477004,'furniture-mobile','h1, .heading-1','display','inline-block','3','',''),(477005,'furniture-mobile','h1, .heading-1','display','inline-block','4','',''),(477006,'furniture-mobile','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','display','inline-block','3','','.w-product-buttons'),(477007,'furniture-mobile','.w-product-quantity .product-quantity-label','display','none','','','.w-product-quantity'),(477008,'furniture-mobile','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(477009,'furniture-mobile','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(477010,'furniture-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(477011,'furniture-mobile','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(477012,'furniture-mobile','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(477013,'furniture-mobile','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(477014,'furniture-mobile','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(477015,'furniture-mobile','.w-product-bonus-points > div','display','block','4','','.w-product-bonus-points'),(477016,'furniture-mobile','.w-product-personal-catalog-button .btn','display','block','3','','.w-product-personal-catalog-button'),(477017,'furniture-mobile','.warrantyProduct .warranty','display','inline-block','3','','.warrantyProduct'),(477018,'furniture-mobile','.warrantyProduct .delivery','display','inline-block','3','','.warrantyProduct'),(477019,'furniture-mobile','.w-compare .compare-button','display','block','','','.w-compare'),(477020,'furniture-mobile','.w-files-catalog-widgets-files-catalog ','display','flex','','','.w-files-catalog-widgets-files-catalog'),(477021,'furniture-mobile','.w-files-catalog-widgets-files-catalog .image','display','flex','','','.w-files-catalog-widgets-files-catalog'),(477022,'furniture-mobile','.w-files-catalog-widgets-files-catalog .item','display','flex','','','.w-files-catalog-widgets-files-catalog'),(477023,'furniture-mobile','.w-files-catalog-widgets-files-catalog picture','display','inline-block','','','.w-files-catalog-widgets-files-catalog'),(477024,'furniture-mobile','.w-sample .cart-box-link','display','inline-block','4','','.w-sample'),(477025,'furniture-mobile','.w-sample .cart-box-link','display','flex','','','.w-sample'),(477026,'furniture-mobile','.w-sample .cart-box-link','display','inline-block','3','','.w-sample'),(477027,'furniture-mobile','.w-sample .cart-box-link .strong','display','none','','','.w-sample'),(477028,'furniture-mobile','.w-sample .multicart .current-text','display','block','','','.w-sample'),(477029,'furniture-mobile','.w-sample .multicart .item','display','block','','','.w-sample'),(477030,'furniture-mobile','.w-sample .multicart .name','display','block','','','.w-sample'),(477031,'furniture-mobile','.w-sample .multicart .sub-total-row','display','block','','','.w-sample'),(477032,'furniture-mobile','.w-sample .multicart .title','display','inline-block','','','.w-sample'),(477033,'furniture-mobile','.w-sample .name','display','block','','','.w-sample'),(477034,'furniture-mobile','.w-sample .no-text','display','inline-block','','','.w-sample'),(477035,'furniture-mobile','.w-sample .price','display','block','','','.w-sample'),(477036,'furniture-mobile','.w-sample .strong','display','block','','','.w-sample'),(477037,'furniture-mobile','.w-sample a.item','display','block','4','','.w-sample'),(477038,'furniture-mobile','.w-sample a.item','display','block','','','.w-sample'),(477039,'furniture-mobile','.w-sample .cart-box-link','display','none','2885,4','','.w-sample'),(477040,'furniture-mobile','.w-sample .no-text','display','none','2885','','.w-sample'),(477041,'furniture-mobile','.w-quote .cart-box.hover-box .cart-content','display','none','','','.w-quote'),(477042,'furniture-mobile','.w-quote .cart-box.hover-box:hover .cart-content','display','block','','','.w-quote'),(477043,'furniture-mobile','.w-sample .cart-box .cart-content','display','none','','','.w-sample'),(477044,'furniture-mobile','.w-sample .cart-box:hover .cart-content','display','block','','','.w-sample'),(477045,'furniture-mobile','.w-filters-simple .filter-row','display','flex','','','.w-filters-simple'),(477046,'furniture-mobile','.w-filters-simple .integrate-price-holder > div','display','inline-block','','','.w-filters-simple'),(477047,'furniture-mobile','.w-cart-listing .points-earn','display','inline-block','4','','.w-cart-listing'),(477048,'furniture-mobile','.w-cart-discount-coupon .inp','display','flex','','','.w-cart-discount-coupon'),(477049,'furniture-mobile','.w-cart-sub-total .price-row','display','flex','','','.w-cart-sub-total'),(477050,'furniture-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(477051,'furniture-mobile','.w-cart-gift-certificate .input-apple','display','flex','','','.w-cart-gift-certificate'),(477052,'furniture-mobile','.w-cart-order-reference .input-apple','display','flex','','','.w-cart-order-reference'),(477053,'furniture-mobile','.w-product-attributes .radio-attributes > span','display','block','','','.w-product-attributes'),(477054,'furniture-mobile','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(477055,'furniture-mobile','.w-product-bundle .bundle-products','display','flex','','','.w-product-bundle'),(477056,'furniture-mobile','.w-product-bundle .bundle-total-price .title, .w-product-bundle .bundle-total-price .price','display','inline-block','','','.w-product-bundle'),(477057,'furniture-mobile','.w-product-in-bundles .bundle-products','display','flex','','','.w-product-in-bundles'),(477058,'furniture-mobile','.w-product-in-bundles .bundle-total-price .title, .w-product-in-bundles .bundle-total-price .price','display','inline-block','','','.w-product-in-bundles'),(477059,'furniture-mobile','.w-product-quantity-discounts .count','display','inline-block','','','.w-product-quantity-discounts'),(477060,'furniture-mobile','.b-bottom .cart-options .buttons','display','block','','','.b-bottom'),(477061,'furniture-mobile','.w-catalog-additional-images picture','display','flex','','','.w-catalog-additional-images'),(477062,'furniture-mobile','.w-sample-products .price','display','none','','','.w-sample-products'),(477063,'furniture-mobile','.w-account-address-book .address-book','display','flex','','','.w-account-address-book'),(477064,'furniture-mobile','.w-account-address-book .add_item a','display','inline-block','3','','.w-account-address-book'),(477065,'furniture-mobile','.heading-2','display','inline-block','3','',''),(477066,'furniture-mobile','.heading-2','display','inline-block','4','',''),(477067,'furniture-mobile','.b-products-listing .products-listing .radio-attributes','display','block','4','','.b-products-listing'),(477068,'furniture-mobile','.b-pagination .pagination','display','block','4','','.b-pagination'),(477069,'furniture-mobile','.b-pagination .pagination .next-pages','display','inline-block','','','.b-pagination'),(477070,'furniture-mobile','.b-pagination .pagination .page-number','display','inline-block','','','.b-pagination'),(477071,'furniture-mobile','.b-pagination .pagination .paging','display','inline-block','','','.b-pagination'),(477072,'furniture-mobile','.b-pagination .pagination .prev-pages','display','inline-block','','','.b-pagination'),(477073,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','display','inline-block','','','.b-pagination'),(477074,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','display','inline-block','','','.b-pagination'),(477075,'furniture-mobile','.b-pagination .pagination span','display','inline-block','2','','.b-pagination'),(477076,'furniture-mobile','.b-pagination ul.pagination li','display','inline-block','','','.b-pagination'),(477077,'furniture-mobile','.w-product-multi-inventory .select-box:last-of-type:after','display','block','','','.w-product-multi-inventory'),(477078,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .item','display','inline-block','','','.w-product-properties-filters-widgets-chosen-filters'),(477079,'furniture-mobile','.w-product-multi-inventory .radio-attributes > label','display','block','','','.w-product-multi-inventory'),(477080,'furniture-mobile','.w-cart-listing .no-price .price','display','none','','','.w-cart-listing'),(477081,'furniture-mobile','.w-product-multi-inventory #product-attributes','display','block','4','','.w-product-multi-inventory'),(477082,'furniture-mobile','.p-quote-checkout-index .heading-2','display','none','3','','.p-quote-checkout-index'),(477083,'furniture-mobile','.p-quote-checkout-index .heading-2','display','none','4','','.p-quote-checkout-index'),(477084,'furniture-mobile','.p-sample-checkout-index .heading-2','display','none','3','','.p-sample-checkout-index'),(477085,'furniture-mobile','.p-sample-checkout-index .heading-2','display','none','4','','.p-sample-checkout-index'),(477086,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','display','inline-block','3','','.p-quote-checkout-index'),(477087,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','display','inline-block','4','','.p-quote-checkout-index'),(477088,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','display','inline-block','3','','.p-sample-checkout-index'),(477089,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','display','inline-block','4','','.p-sample-checkout-index'),(477090,'furniture-mobile','.w-account-order-download td','display','block','2876','','.w-account-order-download'),(477091,'furniture-mobile','.w-account-order-download tr','display','block','2876','','.w-account-order-download'),(477092,'furniture-mobile','.w-product-multi-inventory .radio-attributes > span','display','block','','','.w-product-multi-inventory'),(477093,'furniture-mobile','.w-quote-products .cart-listing .price','display','none','','','.w-quote-products'),(477094,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','display','inline-block','','','.w-product-multi-inventory'),(477095,'furniture-mobile','.w-product-multi-inventory .radio-attributes > label input','display','none','','','.w-product-multi-inventory'),(477096,'furniture-mobile','.w-product-multi-inventory .radio-attributes','display','block','4','','.w-product-multi-inventory'),(477097,'furniture-mobile','.w-account-personal-catalog .headings','display','none','','','.w-account-personal-catalog'),(477098,'furniture-mobile','.w-account-personal-catalog .list-row-action','display','flex','','','.w-account-personal-catalog'),(477099,'furniture-mobile','.w-account-personal-catalog .list-row-action a','display','block','','','.w-account-personal-catalog'),(477100,'furniture-mobile','.w-product-quantity-discounts .quantity-discounts','display','block','4','','.w-product-quantity-discounts'),(477101,'furniture-mobile','h1, .heading-1','display','none','2885,3','',''),(477102,'furniture-mobile','h1, .heading-1','display','none','2885,4','',''),(477103,'furniture-mobile','.w-account-personal-catalog .buy-box','display','flex','2876','','.w-account-personal-catalog'),(477104,'furniture-mobile','.w-filters .handle_tit','display','block','2890','','.w-filters'),(477105,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','display','inline-block','','','.b-products-listing'),(477106,'furniture-mobile','.b-products-listing .products-listing .radio-attributes > label','display','block','','','.b-products-listing'),(477107,'furniture-mobile','.b-products-listing .products-listing .radio-attributes > label input','display','none','','','.b-products-listing'),(477108,'furniture-mobile','.b-products-listing .products-listing .radio-attributes > span','display','block','','','.b-products-listing'),(477109,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .item-title','display','block','','','.b-products-listing'),(477110,'furniture-mobile','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(477111,'furniture-mobile','.w-product-collection .together','display','block','','','.w-product-collection'),(477112,'furniture-mobile','.w-product-collection .right-area .btn','display','inline-block','3','','.w-product-collection'),(477113,'furniture-mobile','.w-account-customer-additional-field .field-type-text, .w-account-customer-additional-field .field-type-file','display','flex','','','.w-account-customer-additional-field'),(477114,'furniture-mobile','.w-product-collection .right-area .btn-2','display','inline-block','3','','.w-product-collection'),(477115,'furniture-mobile','.price .special-promote','display','block','','',''),(477116,'furniture-mobile','.w-product-attributes #product-attributes','display','block','4','','.w-product-attributes'),(477117,'furniture-mobile','.w-product-attributes .radio-attributes','display','block','4','','.w-product-attributes'),(477118,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','display','inline-block','','','.w-product-attributes'),(477119,'furniture-mobile','.w-product-attributes .radio-attributes > label','display','block','','','.w-product-attributes'),(477120,'furniture-mobile','.w-product-attributes .radio-attributes > label input','display','none','','','.w-product-attributes'),(477121,'furniture-mobile','.w-product-attributes .select-box:last-of-type:after','display','block','','','.w-product-attributes'),(477122,'furniture-mobile','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(477123,'furniture-mobile','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(477124,'furniture-mobile','.w-product-properties li','display','table-cell','','','.w-product-properties'),(477125,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','display','block','','','.w-questionnaire-widgets-questionnaire'),(477126,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no label','display','inline','','','.w-questionnaire-widgets-questionnaire'),(477127,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no','display','flex','','','.w-questionnaire-widgets-questionnaire'),(477128,'furniture-mobile','.w-product-groups .property-category-heading','display','none','','','.w-product-groups'),(477129,'furniture-mobile','.w-product-groups .radioBox label','display','block','','','.w-product-groups'),(477130,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','display','block','','','.w-product-groups'),(477131,'furniture-mobile','.w-product-groups .prop-group-swatch','display','block','4','','.w-product-groups'),(477132,'furniture-mobile','.b-products-listing .mix-attributes .mult-qty-input .qty-box','display','block','','','.b-products-listing'),(477133,'furniture-mobile','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(477134,'furniture-mobile','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(477135,'furniture-mobile','.w-product-custom-bundle .right-area .separate-text','display','block','','','.w-product-custom-bundle'),(477136,'furniture-mobile','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','display','inline-block','3','','.w-product-custom-bundle'),(477137,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list'),(477138,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list-block'),(477139,'furniture-mobile','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(477140,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent a','display','inline-block','','','.w-delivery-location-location-list'),(477141,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','display','block','','','.w-delivery-location-location-list'),(477142,'furniture-mobile','.w-blog-widget-recent-posts > div a','display','block','','','.w-blog-widget-recent-posts'),(477143,'furniture-mobile','.w-delivery-location-featured-list .deliveryList ul','display','block','4','','.w-delivery-location-featured-list'),(477144,'furniture-mobile','.w-wedding-registry-widgets-shipping-details .addresses .address-item label.radio-button > span','display','inline','','','.w-wedding-registry-widgets-shipping-details'),(477145,'furniture-mobile','.w-sale-category .btn','display','block','','','.w-sale-category'),(477146,'furniture-mobile','.w-sale-category .left-count','display','block','','','.w-sale-category'),(477147,'furniture-mobile','.w-sale-category .left-count-days','display','block','','','.w-sale-category'),(477148,'furniture-mobile','.w-sale-category .left-count-hours','display','block','','','.w-sale-category'),(477149,'furniture-mobile','.w-sale-category .left-text-left','display','block','','','.w-sale-category'),(477150,'furniture-mobile','.w-sale-category .left-text-right','display','block','','','.w-sale-category'),(477151,'furniture-mobile','.w-sale-category .special-price','display','block','','','.w-sale-category'),(477152,'furniture-mobile','.w-sale-category .special-price-text','display','none','','','.w-sale-category'),(477153,'furniture-mobile','.w-sale-category .text','display','block','','','.w-sale-category'),(477154,'furniture-mobile','.w-wedding-registry-widgets-delete-link .delete-registry','display','inline-block','3','','.w-wedding-registry-widgets-delete-link'),(477155,'furniture-mobile','.w-wedding-registry-widgets-edit-link .edit-registry','display','inline-block','3','','.w-wedding-registry-widgets-edit-link'),(477156,'furniture-mobile','.w-success-download table td','display','block','2906','','.w-success-download'),(477157,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list-by-catalog'),(477158,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(477159,'furniture-mobile','.w-delivery-location-list-by-page .page-list','display','block','4','','.w-delivery-location-list-by-page'),(477160,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList','display','block','4','','.w-delivery-location-top-location-list'),(477161,'furniture-mobile','.w-product-properties-icons ','display','flex','','','.w-product-properties-icons'),(477162,'furniture-mobile','.w-product-properties-icons .hover-box-content','display','inline-block','','','.w-product-properties-icons'),(477163,'furniture-mobile','.w-product-properties-icons .hover-box','display','block','','','.w-product-properties-icons'),(477164,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','display','inline-block','','','.w-product-properties-icons'),(477165,'furniture-mobile','.w-delivery-location-cross-pages .page-list','display','block','4','','.w-delivery-location-cross-pages'),(477166,'furniture-mobile','.w-cart-listing .price br','display','none','','','.w-cart-listing'),(477167,'furniture-mobile','.w-delivery-location-product-categories .categories','display','flex','','','.w-delivery-location-product-categories'),(477168,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','display','block','','','.w-delivery-location-product-categories'),(477169,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination','display','block','4','','.w-wedding-registry-widgets-search-paging'),(477170,'furniture-mobile','.w-wedding-registry-widgets-search-paging ul.pagination li','display','inline-block','','','.w-wedding-registry-widgets-search-paging'),(477171,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','display','inline-block','','','.w-wedding-registry-widgets-search-paging'),(477172,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','display','inline-block','','','.w-wedding-registry-widgets-search-paging'),(477173,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','display','inline-block','','','.w-wedding-registry-widgets-search-paging'),(477174,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','display','inline-block','','','.w-wedding-registry-widgets-search-paging'),(477175,'furniture-mobile','.delivery-options-popup','display','block','4','',''),(477176,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','display','inline-block','','','.w-product-bonus-points'),(477177,'furniture-mobile','.w-product-designer-designer .groupNamePrDes','display','none','','','.w-product-designer-designer'),(477178,'furniture-mobile','.w-product-designer-designer .grnamebox .title-sortable','display','block','','','.w-product-designer-designer'),(477179,'furniture-mobile','.w-product-designer-designer .prodDesignerType','display','flex','','','.w-product-designer-designer'),(477180,'furniture-mobile','.w-press-reviews-widgets-press-reviews .image a','display','block','','','.w-press-reviews-widgets-press-reviews'),(477181,'furniture-mobile','.w-press-reviews-widgets-press-reviews .item','display','block','','','.w-press-reviews-widgets-press-reviews'),(477182,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review-box','display','flex','','','.w-press-reviews-widgets-press-reviews'),(477183,'furniture-mobile','.w-press-reviews-widgets-press-reviews .title a','display','block','','','.w-press-reviews-widgets-press-reviews'),(477184,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .item','display','flex','','','.w-press-reviews-widgets-press-reviews-list'),(477185,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .review-box','display','flex','','','.w-press-reviews-widgets-press-reviews-list'),(477186,'furniture-mobile','.b-products-listing .productGroup label','display','inline-block','','','.b-products-listing'),(477187,'furniture-mobile','.b-products-listing .productGroup label a','display','block','','','.b-products-listing'),(477188,'furniture-mobile','.w-gift-wrap-message-checkout .max-counter, .w-gift-wrap-message-checkout .max-words','display','inline-block','','','.w-gift-wrap-message-checkout'),(477189,'furniture-mobile','.w-communication-post .btn.refresh input','display','none','','','.w-communication-post'),(477190,'furniture-mobile','.w-rma-returns-history .column','display','flex','','','.w-rma-returns-history'),(477191,'furniture-mobile','.w-rma-returns-history .column .fromTo','display','flex','','','.w-rma-returns-history'),(477192,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','display','inline-block','','','.w-rma-returns-history'),(477193,'furniture-mobile','.w-rma-returns-history .filterMessages','display','flex','','','.w-rma-returns-history'),(477194,'furniture-mobile','.w-rma-returns-history .fromTo label','display','inline-block','','','.w-rma-returns-history'),(477195,'furniture-mobile','.w-rma-returns-history .fromTo label >span','display','block','','','.w-rma-returns-history'),(477196,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','display','flex','','','.b-menu-style-1'),(477197,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul','display','flex','','','.b-menu-position'),(477198,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(477199,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul','display','flex','','','.b-menu-position'),(477200,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(477201,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul','display','flex','','','.b-menu-position'),(477202,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(477203,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > ul','display','none','','','.b-menu-lev_vis-click_icon'),(477204,'furniture-mobile','.w-show-inactive-show-inactive .out_stock_wrap','display','flex','','','.w-show-inactive-show-inactive'),(477205,'furniture-mobile','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(477206,'furniture-mobile','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(477207,'furniture-mobile','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(477208,'furniture-mobile','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(477209,'furniture-mobile','.w-product-configurator .item-content','display','block','2876','','.w-product-configurator'),(477210,'furniture-mobile','.w-product-configurator .item-content > div','display','block','2876','','.w-product-configurator'),(477211,'furniture-mobile','.w-product-configurator .pc-item label','display','block','','','.w-product-configurator'),(477212,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','display','inline-block','','','.b-products-listing'),(477213,'furniture-mobile','.b-products-listing .promo-icon','display','inline-block','','','.b-products-listing'),(477214,'furniture-mobile','.b-products-listing .promos-info .promo-name','display','inline-block','','','.b-products-listing'),(477215,'furniture-mobile','.b-products-listing .promos-info .promo-name-span','display','block','','','.b-products-listing'),(477216,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-list'),(477217,'furniture-mobile','.w-predefined-promotion .heading-3','display','inline-block','','','.w-predefined-promotion'),(477218,'furniture-mobile','.w-predefined-promotion .icon','display','inline-block','','','.w-predefined-promotion'),(477219,'furniture-mobile','.w-predefined-promotion .nextdiscount .content','display','grid','','','.w-predefined-promotion'),(477220,'furniture-mobile','.w-predefined-promotion .nextdiscount .item-holder','display','flex','','','.w-predefined-promotion'),(477221,'furniture-mobile','.w-predefined-promotion .nextdiscount .promo-for-each','display','inline-block','','','.w-predefined-promotion'),(477222,'furniture-mobile','.w-predefined-promotion .prom-multi-discount','display','block','4','','.w-predefined-promotion'),(477223,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .list','display','grid','','','.w-predefined-promotion'),(477224,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .products','display','grid','','','.w-predefined-promotion'),(477225,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','display','block','','','.w-predefined-promotion'),(477226,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','display','inline-block','','','.w-predefined-promotion'),(477227,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range > div','display','inline-block','','','.w-predefined-promotion'),(477228,'furniture-mobile','.w-predefined-promotion .promo-cart-discount','display','flex','','','.w-predefined-promotion'),(477229,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .content','display','flex','','','.w-predefined-promotion'),(477230,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .item a','display','block','','','.w-predefined-promotion'),(477231,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','display','inline-block','','','.w-predefined-promotion'),(477232,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave','display','flex','','','.w-predefined-promotion'),(477233,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','display','inline-block','','','.w-predefined-promotion'),(477234,'furniture-mobile','.w-predefined-promotion .promo-content > .personalgift','display','none','','','.w-predefined-promotion'),(477235,'furniture-mobile','.w-predefined-promotion .promo-date > div','display','inline-block','','','.w-predefined-promotion'),(477236,'furniture-mobile','.w-predefined-promotion .promo-salemaker','display','flex','','','.w-predefined-promotion'),(477237,'furniture-mobile','.w-predefined-promotion .promo-salemaker .content','display','flex','','','.w-predefined-promotion'),(477238,'furniture-mobile','.w-predefined-promotion .promo-salemaker .content a.name','display','block','','','.w-predefined-promotion'),(477239,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','display','inline-block','','','.w-predefined-promotion'),(477240,'furniture-mobile','.w-supplier-purchase-supplier-products .item','display','flex','','','.w-supplier-purchase-supplier-products'),(477241,'furniture-mobile','.w-supplier-purchase-supplier-products .qty_col','display','flex','','','.w-supplier-purchase-supplier-products'),(477242,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','display','inline-block','','','.w-filters'),(477243,'furniture-mobile','.mainBanner .bottomBox .elf','display','block','','','.mainBanner'),(477244,'furniture-mobile','.mainBanner .buttonBox','display','block','4','','.mainBanner'),(477245,'furniture-mobile','.mainBanner .title','display','inline-block','3','','.mainBanner'),(477246,'furniture-mobile','.mainBanner .title','display','inline-block','','','.mainBanner'),(477247,'furniture-mobile','.mainBanner .title > span','display','block','','','.mainBanner'),(477248,'furniture-mobile','.mainBanner .topBox > .left','display','inline-block','','','.mainBanner'),(477249,'furniture-mobile','.mainBanner .topBox > .right','display','inline-block','','','.mainBanner'),(477250,'furniture-mobile','.mainBanner .topBox > .right','display','inline-block','3','','.mainBanner'),(477251,'furniture-mobile','.mainBanner .topBox > .left','display','block','2876','','.mainBanner'),(477252,'furniture-mobile','.lowestPricedBox .w-banner .banner','display','flex','','','.lowestPricedBox'),(477253,'furniture-mobile','.lowestPricedBox .w-banner .ybg','display','block','3','','.lowestPricedBox'),(477254,'furniture-mobile','.lowestPricedBox .w-banner .ybg','display','flex','2876','','.lowestPricedBox'),(477255,'furniture-mobile','.lowestPricedBox .w-banner .ybg','display','none','2876,3','','.lowestPricedBox'),(477256,'furniture-mobile','.shopByCollectionBox .bannerButton a','display','inline-block','','','.shopByCollectionBox'),(477257,'furniture-mobile','.shopByCollectionBox .content','display','block','4','','.shopByCollectionBox'),(477258,'furniture-mobile','.shopByCollectionBox .content .title span','display','block','','','.shopByCollectionBox'),(477259,'furniture-mobile','.shopByCollectionBox .w-banner .banner','display','flex','','','.shopByCollectionBox'),(477260,'furniture-mobile','.shopByCollectionBox .bannerButton a','display','inline-block','2890','','.shopByCollectionBox'),(477261,'furniture-mobile','.w-checkout-continue-btn .button-hide','display','none','','','.w-checkout-continue-btn'),(477262,'furniture-mobile','.w-checkout-continue-btn .or-text','display','none','','','.w-checkout-continue-btn'),(477263,'furniture-mobile','.order-summary .icon','display','block','','','.order-summary'),(477264,'furniture-mobile','.order-summary .price-box .price-row.total','display','flex','','','.order-summary'),(477265,'furniture-mobile','.order-summary .price-row','display','flex','2','','.order-summary'),(477266,'furniture-mobile','.w-cart-shipping-estimator .estimate-shipping','display','block','4','','.w-cart-shipping-estimator'),(477267,'furniture-mobile','.w-cart-shipping-estimator .estimate-shipping .col-right > span:first-of-type, .w-cart-shipping-estimator .estimate-shipping .col-right > br','display','none','2876','','.w-cart-shipping-estimator'),(477268,'furniture-mobile','.cartTitle >div','display','none','2885,3','','.cartTitle'),(477269,'furniture-mobile','.p-quote-checkout-index .order-summary .icon','display','none','','','.p-quote-checkout-index'),(477270,'furniture-mobile','.w-search .background','display','none','','','.w-search'),(477271,'furniture-mobile','.w-search .background.show','display','block','','','.w-search'),(477272,'furniture-mobile','.w-search .opened','display','block','3','','.w-search'),(477273,'furniture-mobile','.w-search .suggest','display','flex','','','.w-search'),(477274,'furniture-mobile','.w-search .image','display','flex','','','.w-search'),(477275,'furniture-mobile','.w-search .item a','display','flex','','','.w-search'),(477276,'furniture-mobile','.w-search .products','display','block','','','.w-search'),(477277,'furniture-mobile','.w-search .type-block.history .image','display','none','3','','.w-search'),(477278,'furniture-mobile','.account-order-history .orders-table .hidden','display','none','','','.account-order-history'),(477279,'furniture-mobile','.account-order-history .short-date','display','none','','','.account-order-history'),(477280,'furniture-mobile','.account-order-history .view_link','display','inline-block','4','','.account-order-history'),(477281,'furniture-mobile','.account-order-history .orders-table .headings','display','none','2885','','.account-order-history'),(477282,'furniture-mobile','.account-order-history .orders-table .hidden','display','inline-block','2885','','.account-order-history'),(477283,'furniture-mobile','.account-order-history .orders-table .item','display','block','2885','','.account-order-history'),(477284,'furniture-mobile','.account-order-history .orders-table .item td','display','block','2885','','.account-order-history'),(477285,'furniture-mobile','.account-order-history .orders-table td.name','display','none','2885','','.account-order-history'),(477286,'furniture-mobile','.account-order-history .orders-table, .account-order-history .orders-table tbody','display','block','2885','','.account-order-history'),(477287,'furniture-mobile','.account-order-history-info .history_attr','display','table','','','.account-order-history-info'),(477288,'furniture-mobile','.account-order-history-info .history_attr div','display','table-row','','','.account-order-history-info'),(477289,'furniture-mobile','.account-order-history-info .history_attr div strong, .account-order-history-info .history_attr div span','display','table-cell','','','.account-order-history-info'),(477290,'furniture-mobile','.account-order-history-info .popup-tracking-number a','display','block','','','.account-order-history-info'),(477291,'furniture-mobile','.account-order-history-info .popup-tracking-number-link','display','block','','','.account-order-history-info'),(477292,'furniture-mobile','.account-index .account_info .info','display','none','3','','.account-index'),(477293,'furniture-mobile','.account-index .date_value, .account-index .date_title','display','block','','','.account-index'),(477294,'furniture-mobile','.account-index .orders-table .hidden','display','none','','','.account-index'),(477295,'furniture-mobile','.account-index .topAccount > li > div','display','block','3','','.account-index'),(477296,'furniture-mobile','.account-index .topInfo','display','block','4','','.account-index'),(477297,'furniture-mobile','.account-index .view_history','display','inline-block','3','','.account-index'),(477298,'furniture-mobile','.account-index .view_link','display','inline-block','4','','.account-index'),(477299,'furniture-mobile','.account-index .orders-table .headings','display','none','2885','','.account-index'),(477300,'furniture-mobile','.account-index .orders-table .hidden','display','inline-block','2885','','.account-index'),(477301,'furniture-mobile','.account-index .orders-table .item','display','block','2885','','.account-index'),(477302,'furniture-mobile','.account-index .orders-table .item td','display','block','2885','','.account-index'),(477303,'furniture-mobile','.account-index .orders-table td.name','display','none','2885','','.account-index'),(477304,'furniture-mobile','.account-index .orders-table, .account-index .orders-table tbody','display','block','2885','','.account-index'),(477305,'furniture-mobile','.account-order-pay .history_attr','display','table','','','.account-order-pay'),(477306,'furniture-mobile','.account-order-pay .history_attr div','display','table-row','','','.account-order-pay'),(477307,'furniture-mobile','.account-order-pay .history_attr div strong, .account-order-pay .history_attr div span','display','table-cell','','','.account-order-pay'),(477308,'furniture-mobile','.account-samples .orders-table .hidden','display','none','','','.account-samples'),(477309,'furniture-mobile','.account-samples .short-date','display','none','','','.account-samples'),(477310,'furniture-mobile','.account-samples .view_link','display','inline-block','4','','.account-samples'),(477311,'furniture-mobile','.account-samples .orders-table .headings','display','none','2885','','.account-samples'),(477312,'furniture-mobile','.account-samples .orders-table .hidden','display','inline-block','2885','','.account-samples'),(477313,'furniture-mobile','.account-samples .orders-table .item','display','block','2885','','.account-samples'),(477314,'furniture-mobile','.account-samples .orders-table .item td','display','block','2885','','.account-samples'),(477315,'furniture-mobile','.account-samples .orders-table td.name','display','none','2885','','.account-samples'),(477316,'furniture-mobile','.account-samples .orders-table, .account-samples .orders-table tbody','display','block','2885','','.account-samples'),(477317,'furniture-mobile','.account-sample-info .history_attr','display','table','','','.account-sample-info'),(477318,'furniture-mobile','.account-sample-info .history_attr div','display','table-row','','','.account-sample-info'),(477319,'furniture-mobile','.account-sample-info .history_attr div strong, .account-sample-info .history_attr div span','display','table-cell','','','.account-sample-info'),(477320,'furniture-mobile','.account-sample-info .popup-tracking-number a','display','block','','','.account-sample-info'),(477321,'furniture-mobile','.account-sample-info .popup-tracking-number-link','display','block','','','.account-sample-info'),(477322,'furniture-mobile','.catalog-product-wrap .pn-image','display','inline-block','3','','.catalog-product-wrap'),(477323,'furniture-mobile','.catalog-product-wrap .pn-price','display','none','','','.catalog-product-wrap'),(477324,'furniture-mobile','.catalog-product-wrap .prev-next-product','display','none','','','.catalog-product-wrap'),(477325,'furniture-mobile','.catalog-product-wrap .prev-next-product > span','display','block','','','.catalog-product-wrap'),(477326,'furniture-mobile','.catalog-product-wrap .pn-image img','display','none','2885','','.catalog-product-wrap'),(477327,'furniture-mobile','.catalog-product-wrap .pn-name','display','none','2885','','.catalog-product-wrap'),(477328,'furniture-mobile','.shopping-cart-index .cart-popup .gift-wrap','display','none','','','.shopping-cart-index'),(477329,'furniture-mobile','.shopping-cart-index .gift-code .heading-4 ~ *','display','none','2876','','.shopping-cart-index'),(477330,'furniture-mobile','.checkout-index-wrap .edit-address-popup .address-item > label','display','block','','','.checkout-index-wrap'),(477331,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses','display','flex','','','.checkout-index-wrap'),(477332,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons','display','flex','','','.checkout-index-wrap'),(477333,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons','display','none','4','','.checkout-index-wrap'),(477334,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','display','inline-block','','','.checkout-index-wrap'),(477335,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','display','block','','','.checkout-index-wrap'),(477336,'furniture-mobile','.checkout-index-wrap .heading-2','display','none','3','','.checkout-index-wrap'),(477337,'furniture-mobile','.checkout-index-wrap .heading-2','display','none','4','','.checkout-index-wrap'),(477338,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','display','inline-block','3','','.checkout-index-wrap'),(477339,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','display','inline-block','4','','.checkout-index-wrap'),(477340,'furniture-mobile','.checkout-order-confirmation .heading-2.prod-ico','display','none','3','','.checkout-order-confirmation'),(477341,'furniture-mobile','.checkout-order-confirmation .heading-2.prod-ico','display','none','4','','.checkout-order-confirmation'),(477342,'furniture-mobile','.checkout-order-confirmation .price-row','display','flex','','','.checkout-order-confirmation'),(477343,'furniture-mobile','.checkout-success-wrap .page-success .text-1','display','block','3','','.checkout-success-wrap'),(477344,'furniture-mobile','.w-menu-style-1 ul ul li','display_important','important','','','.w-menu-style-1'),(477345,'furniture-mobile','.w-menu-style-1 ul ul li','display_important','important','','','.w-menu-style-1'),(477346,'furniture-mobile','.w-cart-listing .remove-btn span','display_important','important','2885','','.w-cart-listing'),(477347,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display_important','important','','','.b-switch'),(477348,'furniture-mobile','.w-menu-horizontal ul ul li','display_important','important','','','.w-menu-horizontal'),(477349,'furniture-mobile','.w-menu-style-1 ul ul li','display_important','important','','','.w-menu-style-1'),(477350,'furniture-mobile','.w-menu-style-1 ul ul li','display_important','important','','','.w-menu-style-1'),(477351,'furniture-mobile','.w-menu-style-1 ul ul li','display_important','important','','','.w-menu-style-1'),(477352,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display_important','important','','','.b-switch'),(477353,'furniture-mobile','.w-account .account-title a.my-acc-link.active + .account-dropdown','display_important','important','','','.w-account'),(477354,'furniture-mobile','.w-cart .cart-box.hover-box:hover .cart-content','display_important','important','','','.w-cart'),(477355,'furniture-mobile','.w-menu-style-1 ul ul li','display_important','important','','','.w-menu-style-1'),(477356,'furniture-mobile','.w-filters .filter-box-content ul li.view_items','display_important','important','','','.w-filters'),(477357,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display_important','important','','','.b-menu-open_from-left'),(477358,'furniture-mobile','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display_important','important','','','.b-menu-style'),(477359,'furniture-mobile','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display_important','important','','','.b-menu-style'),(477360,'furniture-mobile','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display_important','important','','','.b-menu-style'),(477361,'furniture-mobile','.b-products-listing .products-listing.slick-slider .item-nav','display_important','important','','','.b-products-listing'),(477362,'furniture-mobile','.w-quote .cart-box.hover-box:hover .cart-content','display_important','important','','','.w-quote'),(477363,'furniture-mobile','.w-sample .cart-box:hover .cart-content','display_important','important','','','.w-sample'),(477364,'furniture-mobile','.order-summary .icon','display_important','important','','','.order-summary'),(477365,'furniture-mobile','.p-quote-checkout-index .order-summary .icon','display_important','important','','','.p-quote-checkout-index'),(477366,'furniture-mobile','.catalog-product-wrap .pn-price','display_important','important','','','.catalog-product-wrap'),(477367,'furniture-mobile','.catalog-product-wrap .pn-name','display_important','important','2885','','.catalog-product-wrap'),(477368,'furniture-mobile','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','fill','rgba(255, 255, 255, 0)','','','.w-image-maps'),(477369,'furniture-mobile','.w-image-maps polygon:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(477370,'furniture-mobile','.w-image-maps rect:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(477371,'furniture-mobile','.w-image-maps circle:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(477372,'furniture-mobile','.w-image-maps rect.no-items, .w-image-maps circle.no-items, .w-image-maps polygon.no-items','fill','rgba(150, 150, 150, 0.7)','','','.w-image-maps'),(477373,'furniture-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','filter','alpha(opacity=0)','','','.b-switch'),(477374,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','filter','progid','','','.b-select-suggest'),(477375,'furniture-mobile','.b-select-suggest .select2-container.select2-drop-above .select2-choice','filter','progid','','','.b-select-suggest'),(477376,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','filter','alpha(opacity=50)','','','.b-switch'),(477377,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','filter','alpha(opacity=50)','','','.b-switch'),(477378,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','filter','progid','','','.b-select-suggest'),(477379,'furniture-mobile','.b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choice, .b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choices','filter','progid','','','.b-select-suggest'),(477380,'furniture-mobile','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','filter','none','','','.b-select-suggest'),(477381,'furniture-mobile','.b-select-suggest .select2-dropdown-open .select2-choice','filter','progid','','','.b-select-suggest'),(477382,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','filter','progid','','','.b-select-suggest'),(477383,'furniture-mobile','.b-select-suggest .select2-drop-mask','filter','alpha(opacity=0)','','','.b-select-suggest'),(477384,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','filter','alpha(opacity=50)','','','.b-switch'),(477385,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-basis','0','','','.b-menu-position'),(477386,'furniture-mobile','.w-promotions .promo-cart-discount .slave','flex-direction','column','','','.w-promotions'),(477387,'furniture-mobile','.w-catalog-compare .cross-box','flex-direction','column','','','.w-catalog-compare'),(477388,'furniture-mobile','.tripleBanner ','flex-direction','column','2885','','.tripleBanner'),(477389,'furniture-mobile','.w-files-catalog-widgets-files-catalog .item','flex-direction','column','','','.w-files-catalog-widgets-files-catalog'),(477390,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block','flex-direction','column','','','.b-products-listing'),(477391,'furniture-mobile','.w-product-designer-designer .prodDesignerType','flex-direction','row','','','.w-product-designer-designer'),(477392,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .item','flex-direction','column','','','.w-press-reviews-widgets-press-reviews-list'),(477393,'furniture-mobile','.w-rma-returns-history .column','flex-direction','column','','','.w-rma-returns-history'),(477394,'furniture-mobile','.w-rma-returns-history .filterMessages','flex-direction','column','','screen and (max-width: 768px)','.w-rma-returns-history'),(477395,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave','flex-direction','column','','','.w-predefined-promotion'),(477396,'furniture-mobile','.lowestPricedBox .w-banner .banner','flex-direction','column','2876','','.lowestPricedBox'),(477397,'furniture-mobile','.lowestPricedBox .w-banner .ybg','flex-direction','column','2876','','.lowestPricedBox'),(477398,'furniture-mobile','.w-search .suggest','flex-direction','column','','','.w-search'),(477399,'furniture-mobile','.p-wedding-registry-search .search-form > div','flex-grow','2','','','.p-wedding-registry-search'),(477400,'furniture-mobile','.b-messages .email-line > div','flex-grow','1','','','.b-messages'),(477401,'furniture-mobile','.w-promotions .prom-multi-discount .promo-product, .w-promotions .prom-multi-discount .promo-category-item','flex-grow','1','','','.w-promotions'),(477402,'furniture-mobile','.p-wedding-registry-search #searchform-status label','flex-grow','1','','','.p-wedding-registry-search'),(477403,'furniture-mobile','.w-cart-listing .item .gift-wrap .value','flex-grow','1','','','.w-cart-listing'),(477404,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-grow','1','','','.b-menu-position'),(477405,'furniture-mobile','.w-account-personal-catalog .list-switcher a','flex-grow','1','','','.w-account-personal-catalog'),(477406,'furniture-mobile','.w-account-subscription .title','flex-grow','1','','','.w-account-subscription'),(477407,'furniture-mobile','.w-catalog-compare .product-listing > div','flex-grow','1','','','.w-catalog-compare'),(477408,'furniture-mobile','.w-delivery-day .time-left > span','flex-grow','1','','','.w-delivery-day'),(477409,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','flex-grow','1','','','.b-menu-style-3'),(477410,'furniture-mobile','.w-files-catalog-widgets-files-catalog .image','flex-grow','1','','','.w-files-catalog-widgets-files-catalog'),(477411,'furniture-mobile','.w-filters-simple .system-1','flex-grow','1','','','.w-filters-simple'),(477412,'furniture-mobile','.w-account-customer-additional-field .field-type-text label, .w-account-customer-additional-field .field-type-file label','flex-grow','1','','','.w-account-customer-additional-field'),(477413,'furniture-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select, .w-account-customer-additional-field .files','flex-grow','1','','','.w-account-customer-additional-field'),(477414,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-product, .w-predefined-promotion .prom-multi-discount .promo-category-item','flex-grow','1','','','.w-predefined-promotion'),(477415,'furniture-mobile','.w-search .products','flex-grow','1','','','.w-search'),(477416,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','flex-shrink','0','','','.w-upload-customer-id-upload-customer-id-form'),(477417,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-shrink','1','','','.b-menu-position'),(477418,'furniture-mobile','.w-catalog-compare .cross-box','flex-shrink','0','','','.w-catalog-compare'),(477419,'furniture-mobile','.w-account-customer-additional-field .field-type-text label, .w-account-customer-additional-field .field-type-file label','flex-shrink','0','','','.w-account-customer-additional-field'),(477420,'furniture-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select, .w-account-customer-additional-field .files','flex-shrink','0','','','.w-account-customer-additional-field'),(477421,'furniture-mobile','.w-promotions .promo-cart-discount .content','flex-wrap','wrap','','','.w-promotions'),(477422,'furniture-mobile','.w-promotions .promo-salemaker .content','flex-wrap','wrap','','','.w-promotions'),(477423,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-blocks','flex-wrap','wrap','','','.b-products-listing'),(477424,'furniture-mobile','.w-top-categories .categories','flex-wrap','wrap','','','.w-top-categories'),(477425,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2','flex-wrap','wrap','2945','','.b-menu-style-3'),(477426,'furniture-mobile','.w-files-catalog-widgets-files-catalog ','flex-wrap','wrap','','','.w-files-catalog-widgets-files-catalog'),(477427,'furniture-mobile','.w-product-bundle .bundle-products','flex-wrap','wrap','','','.w-product-bundle'),(477428,'furniture-mobile','.w-product-in-bundles .bundle-products','flex-wrap','wrap','','','.w-product-in-bundles'),(477429,'furniture-mobile','.w-account-address-book .address-book','flex-wrap','wrap','','','.w-account-address-book'),(477430,'furniture-mobile','.w-product-properties-icons ','flex-wrap','wrap','','','.w-product-properties-icons'),(477431,'furniture-mobile','.w-delivery-location-product-categories .categories','flex-wrap','wrap','','','.w-delivery-location-product-categories'),(477432,'furniture-mobile','.w-product-designer-designer .prodDesignerType','flex-wrap','wrap','','','.w-product-designer-designer'),(477433,'furniture-mobile','.w-press-reviews-widgets-press-reviews .sub-box','flex-wrap','wrap','','','.w-press-reviews-widgets-press-reviews'),(477434,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .review-box > *','flex-wrap','wrap','','','.w-press-reviews-widgets-press-reviews-list'),(477435,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .review-box','flex-wrap','wrap','2906','','.w-press-reviews-widgets-press-reviews-list'),(477436,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .content','flex-wrap','wrap','','','.w-predefined-promotion'),(477437,'furniture-mobile','.w-predefined-promotion .promo-salemaker .content','flex-wrap','wrap','','','.w-predefined-promotion'),(477438,'furniture-mobile','.shopByCollectionBox .w-banner .banner','flex-wrap','wrap','2885','','.shopByCollectionBox'),(477439,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses','flex-wrap','wrap','','','.checkout-index-wrap'),(477440,'furniture-mobile','.heading-4 .right-text, h4 .right-text','float','right','','',''),(477441,'furniture-mobile','.w-checkout-billing-address .btn-cancel','float','left','','','.w-checkout-billing-address'),(477442,'furniture-mobile','.w-compare-box-item .cb_check','float','right','','','.w-compare-box-item'),(477443,'furniture-mobile','.w-compare-box-item .cb_title','float','left','','','.w-compare-box-item'),(477444,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(477445,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(477446,'furniture-mobile','.p-blog-index .comment-metadata','float','right','','','.p-blog-index'),(477447,'furniture-mobile','.p-blog-index .nav-next','float','right','','','.p-blog-index'),(477448,'furniture-mobile','.w-cart .image','float','left','','','.w-cart'),(477449,'furniture-mobile','.w-socials .post_item_img','float','left','','','.w-socials'),(477450,'furniture-mobile','.w-sale .left-count','float','left','','','.w-sale'),(477451,'furniture-mobile','.p-blog-index .nav-next','float','right','','','.p-blog-index'),(477452,'furniture-mobile','.w-account-address-book .item:nth-child(2n)','float','right','','','.w-account-address-book'),(477453,'furniture-mobile','.w-account .btn-1','float','right','','','.w-account'),(477454,'furniture-mobile','.w-wedding-registry-widgets-search-form .button','float','right','','','.w-wedding-registry-widgets-search-form'),(477455,'furniture-mobile','.p-reviews-info .review-info-image','float','left','','','.p-reviews-info'),(477456,'furniture-mobile','.p-blog-index .post-thumbnail','float','left','','','.p-blog-index'),(477457,'furniture-mobile','.p-blog-index .nav-previous a','float','left','3','','.p-blog-index'),(477458,'furniture-mobile','.p-blog-index .nav-previous','float','left','','','.p-blog-index'),(477459,'furniture-mobile','.p-blog-index .nav-next a','float','right','3','','.p-blog-index'),(477460,'furniture-mobile','.p-blog-index .nav-next','float','right','','','.p-blog-index'),(477461,'furniture-mobile','.w-compare-box-item .cb_title','float','left','','','.w-compare-box-item'),(477462,'furniture-mobile','.w-compare-box-item .cb_check','float','right','','','.w-compare-box-item'),(477463,'furniture-mobile','.w-brands .brands-listing > div','float','left','','','.w-brands'),(477464,'furniture-mobile','.w-cart-shipping-estimator .left-area','float','left','','','.w-cart-shipping-estimator'),(477465,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(477466,'furniture-mobile','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(477467,'furniture-mobile','.p-blog-index .comment-author','float','left','','','.p-blog-index'),(477468,'furniture-mobile','.b-messages .msv_btn .btn','float','right','','','.b-messages'),(477469,'furniture-mobile','.b-messages .messages-menu li span','float','right','','','.b-messages'),(477470,'furniture-mobile','.w-checkout-shipping-address .btn-cancel','float','left','','','.w-checkout-shipping-address'),(477471,'furniture-mobile','.p-blog-index .nav-previous','float','left','','','.p-blog-index'),(477472,'furniture-mobile','.p-blog-index .nav-previous a','float','left','3','','.p-blog-index'),(477473,'furniture-mobile','.w-login-block .guest','float','right','','','.w-login-block'),(477474,'furniture-mobile','.p-payer-order-confirmation .dob-hide > div','float','right','','','.p-payer-order-confirmation'),(477475,'furniture-mobile','.p-payer-order-confirmation .dob-hide label','float','left','','','.p-payer-order-confirmation'),(477476,'furniture-mobile','.p-payer-order-pay .dob-hide label','float','left','','','.p-payer-order-pay'),(477477,'furniture-mobile','.p-payer-order-pay .dob-hide > div','float','right','','','.p-payer-order-pay'),(477478,'furniture-mobile','.p-blog-index .comment-author','float','left','','','.p-blog-index'),(477479,'furniture-mobile','.b-compare .col-two label, .b-compare .col-two select','float','left','','','.b-compare'),(477480,'furniture-mobile','.w-menu-style-1 .box','float','none','','','.w-menu-style-1'),(477481,'furniture-mobile','.w-sale .holder-2','float','left','','','.w-sale'),(477482,'furniture-mobile','.w-sale .holder-1','float','right','','','.w-sale'),(477483,'furniture-mobile','.w-compare-box-item .cb_title','float','left','','','.w-compare-box-item'),(477484,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(477485,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(477486,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(477487,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(477488,'furniture-mobile','.p-blog-index .comment-metadata','float','right','','','.p-blog-index'),(477489,'furniture-mobile','.b-info .info','float','left','3','','.b-info'),(477490,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(477491,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(477492,'furniture-mobile','.w-login-block .guest','float','right','','','.w-login-block'),(477493,'furniture-mobile','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(477494,'furniture-mobile','.w-login-block .returning','float','left','','','.w-login-block'),(477495,'furniture-mobile','.w-login-block .new','float','right','','','.w-login-block'),(477496,'furniture-mobile','.w-menu-horizontal li','float','none','','','.w-menu-horizontal'),(477497,'furniture-mobile','.w-sale .left-text-right','float','left','','','.w-sale'),(477498,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(477499,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(477500,'furniture-mobile','.b-info .info','float','left','3','','.b-info'),(477501,'furniture-mobile','.b-bottom .closeable-heading','float','right','3','','.b-bottom'),(477502,'furniture-mobile','.b-form .col-3','float','left','','','.b-form'),(477503,'furniture-mobile','.w-checkout-contact-information .btn-save','float','right','','','.w-checkout-contact-information'),(477504,'furniture-mobile','.b-form .terms-login .bootstrap-switch','float','right','','','.b-form'),(477505,'furniture-mobile','.w-sale .left-text-left','float','left','','','.w-sale'),(477506,'furniture-mobile','.p-blog-index .nav-previous','float','left','','','.p-blog-index'),(477507,'furniture-mobile','.p-blog-index .nav-next','float','right','','','.p-blog-index'),(477508,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(477509,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','float','none','','','.w-menu'),(477510,'furniture-mobile','.w-menu .hided.menu ul li','float','none','','','.w-menu'),(477511,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(477512,'furniture-mobile','.p-blog-index .comment-author','float','left','','','.p-blog-index'),(477513,'furniture-mobile','.p-blog-index .nav-previous a','float','left','3','','.p-blog-index'),(477514,'furniture-mobile','.p-blog-index .post-thumbnail','float','left','','','.p-blog-index'),(477515,'furniture-mobile','.buttons .right-buttons','float','right','','',''),(477516,'furniture-mobile','.buttons .left-buttons','float','left','','',''),(477517,'furniture-mobile','.w-login-block .returning','float','left','','','.w-login-block'),(477518,'furniture-mobile','.w-brands .brands-listing > div','float','left','','','.w-brands'),(477519,'furniture-mobile','.w-sale .left-text-left','float','left','','','.w-sale'),(477520,'furniture-mobile','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(477521,'furniture-mobile','.w-sale .left-count','float','left','','','.w-sale'),(477522,'furniture-mobile','.w-sale .image','float','left','','','.w-sale'),(477523,'furniture-mobile','.w-sale .holder-1','float','right','','','.w-sale'),(477524,'furniture-mobile','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(477525,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','float','right','3','','.w-menu'),(477526,'furniture-mobile','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(477527,'furniture-mobile','.message.success','float','left','3','',''),(477528,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(477529,'furniture-mobile','.p-blog-index .nav-next','float','right','','','.p-blog-index'),(477530,'furniture-mobile','.p-blog-index .nav-previous','float','left','','','.p-blog-index'),(477531,'furniture-mobile','.p-blog-index .nav-previous a','float','left','3','','.p-blog-index'),(477532,'furniture-mobile','.p-blog-index .wp-widget li','float','left','3','','.p-blog-index'),(477533,'furniture-mobile','.p-blog-index .post-thumbnail','float','left','','','.p-blog-index'),(477535,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','float','left','2885','','.p-blog-index'),(477536,'furniture-mobile','.w-compare-box-item .cb_title','float','left','','','.w-compare-box-item'),(477537,'furniture-mobile','.w-socials > li','float','left','','','.w-socials'),(477538,'furniture-mobile','.w-socials .post_item_img','float','left','','','.w-socials'),(477539,'furniture-mobile','.w-checkout-billing-address .add-ab','float','left','','','.w-checkout-billing-address'),(477540,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(477541,'furniture-mobile','.p-blog-index .comment-author','float','left','','','.p-blog-index'),(477542,'furniture-mobile','.p-blog-index .nav-next a','float','right','3','','.p-blog-index'),(477543,'furniture-mobile','.p-blog-index .nav-previous a','float','left','3','','.p-blog-index'),(477544,'furniture-mobile','.p-blog-index .wp-widget li','float','left','3','','.p-blog-index'),(477545,'furniture-mobile','.w-cart-listing .right-area','float','none','2885','','.w-cart-listing'),(477546,'furniture-mobile','.w-sale .holder-2','float','left','','','.w-sale'),(477548,'furniture-mobile','.w-checkout-shipping-address .add-ab','float','left','','','.w-checkout-shipping-address'),(477549,'furniture-mobile','.p-blog-index .comment-author','float','left','','','.p-blog-index'),(477550,'furniture-mobile','.w-socials > li','float','left','','','.w-socials'),(477551,'furniture-mobile','.w-menu-style-1 .box','float','none','','','.w-menu-style-1'),(477552,'furniture-mobile','.w-menu-style-1 li','float','none','','','.w-menu-style-1'),(477553,'furniture-mobile','.w-socials .post_item_img','float','left','','','.w-socials'),(477554,'furniture-mobile','.w-socials > li','float','left','','','.w-socials'),(477555,'furniture-mobile','.b-info .info','float','left','3','','.b-info'),(477556,'furniture-mobile','.b-form .addresses .address-item input[type=\"radio\"]','float','left','','','.b-form'),(477557,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(477558,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(477559,'furniture-mobile','.w-sale .holder-2','float','left','','','.w-sale'),(477560,'furniture-mobile','.w-socials > li','float','left','','','.w-socials'),(477561,'furniture-mobile','.w-sale .left-text-right','float','left','','','.w-sale'),(477562,'furniture-mobile','.w-sale .holder-1','float','right','','','.w-sale'),(477563,'furniture-mobile','.p-blog-index .wp-widget li','float','left','3','','.p-blog-index'),(477564,'furniture-mobile','.heading-4 .edit, h4 .edit','float','right','','',''),(477565,'furniture-mobile','.w-menu-style-1 li','float','none','','','.w-menu-style-1'),(477566,'furniture-mobile','.w-login-block .returning','float','left','','','.w-login-block'),(477567,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','float','none','','','.w-menu'),(477568,'furniture-mobile','.b-info-popup .password-info .info-popup','float','right','','','.b-info-popup'),(477569,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(477570,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(477571,'furniture-mobile','.heading-3 .right-text, h3 .right-text','float','right','','',''),(477572,'furniture-mobile','.heading-3 .edit, h3 .edit','float','right','','',''),(477573,'furniture-mobile','.b-info .info','float','left','3','','.b-info'),(477574,'furniture-mobile','.w-socials .post_item_img','float','left','','','.w-socials'),(477575,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','float','left','2885','','.p-blog-index'),(477576,'furniture-mobile','.w-sale .image','float','left','','','.w-sale'),(477577,'furniture-mobile','.w-sale .left-text-right','float','left','','','.w-sale'),(477578,'furniture-mobile','.w-sale .left-text-left','float','left','','','.w-sale'),(477579,'furniture-mobile','.w-sale .holder-2','float','left','','','.w-sale'),(477580,'furniture-mobile','.w-menu .hided.menu ul li','float','none','','','.w-menu'),(477581,'furniture-mobile','.w-checkout-billing-address .addresses .address-item','float','left','','','.w-checkout-billing-address'),(477582,'furniture-mobile','.w-list-b2b .select-attributes','float','left','','','.w-list-b2b'),(477583,'furniture-mobile','.w-sale .holder-2','float','left','','','.w-sale'),(477584,'furniture-mobile','.w-sale .holder-1','float','right','','','.w-sale'),(477585,'furniture-mobile','.w-sale .image','float','left','','','.w-sale'),(477586,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(477587,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(477588,'furniture-mobile','.w-socials .post_item_img','float','left','','','.w-socials'),(477589,'furniture-mobile','.edit-link','float','right','','',''),(477590,'furniture-mobile','.w-account-address-book .default-address','float','right','','','.w-account-address-book'),(477591,'furniture-mobile','.w-account-address-book .item','float','left','','','.w-account-address-book'),(477592,'furniture-mobile','.w-socials > li','float','left','','','.w-socials'),(477593,'furniture-mobile','.p-reviews-info .review-info-image','float','left','','','.p-reviews-info'),(477594,'furniture-mobile','.b-info .info','float','left','3','','.b-info'),(477595,'furniture-mobile','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(477596,'furniture-mobile','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(477597,'furniture-mobile','.w-promo-code .btn','float','right','','','.w-promo-code'),(477598,'furniture-mobile','.b-form .shipping-method .cost','float','right','','','.b-form'),(477599,'furniture-mobile','.b-form .shipping-method .input','float','left','','','.b-form'),(477600,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(477601,'furniture-mobile','.p-blog-index .wp-widget li','float','left','3','','.p-blog-index'),(477602,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(477603,'furniture-mobile','.b-sub-totals .historyTotal table','float','right','','','.b-sub-totals'),(477605,'furniture-mobile','.b-info .info','float','left','3','','.b-info'),(477606,'furniture-mobile','.w-sale .left-text-right','float','left','','','.w-sale'),(477607,'furniture-mobile','.w-login-block .returning','float','left','','','.w-login-block'),(477608,'furniture-mobile','.w-login-block .guest','float','right','','','.w-login-block'),(477609,'furniture-mobile','.w-sale .left-count','float','left','','','.w-sale'),(477610,'furniture-mobile','.w-login-block .new','float','right','','','.w-login-block'),(477611,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(477612,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(477613,'furniture-mobile','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(477614,'furniture-mobile','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(477615,'furniture-mobile','.b-form .col-right','float','right','','','.b-form'),(477616,'furniture-mobile','.b-form .payment-method .item-radio input','float','left','','','.b-form'),(477617,'furniture-mobile','.w-cart-listing .actions > div','float','left','','','.w-cart-listing'),(477618,'furniture-mobile','.w-login-block .guest','float','right','','','.w-login-block'),(477619,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(477620,'furniture-mobile','.w-login-block .new','float','right','','','.w-login-block'),(477621,'furniture-mobile','.w-compare-box-item .cb_check','float','right','','','.w-compare-box-item'),(477622,'furniture-mobile','.w-menu .hided.menu ul li','float','none','','','.w-menu'),(477623,'furniture-mobile','.w-brands .brands-listing > div','float','left','','','.w-brands'),(477624,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','float','right','3','','.w-menu'),(477625,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(477626,'furniture-mobile','.w-cart-shipping-estimator .right-area','float','right','','','.w-cart-shipping-estimator'),(477627,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(477628,'furniture-mobile','.w-cart-give-away .ga_attributes > div','float','left','','','.w-cart-give-away'),(477629,'furniture-mobile','.b-bottom .cart-options .option-item','float','left','','','.b-bottom'),(477630,'furniture-mobile','.w-sale .left-text-right','float','left','','','.w-sale'),(477631,'furniture-mobile','.w-sale .image','float','left','','','.w-sale'),(477632,'furniture-mobile','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(477633,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(477634,'furniture-mobile','.p-reviews-info .review-info-image','float','left','','','.p-reviews-info'),(477635,'furniture-mobile','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(477636,'furniture-mobile','.w-sale .left-count','float','left','','','.w-sale'),(477637,'furniture-mobile','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(477638,'furniture-mobile','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(477639,'furniture-mobile','.p-blog-index .post-thumbnail','float','left','','','.p-blog-index'),(477640,'furniture-mobile','.p-blog-index .wp-widget li','float','left','3','','.p-blog-index'),(477642,'furniture-mobile','.w-list-b2b .select-attributes:nth-child(2n)','float','right','','','.w-list-b2b'),(477643,'furniture-mobile','.b-upload-files .remove-file','float','right','','','.b-upload-files'),(477644,'furniture-mobile','.w-login-block .new','float','right','','','.w-login-block'),(477645,'furniture-mobile','.w-menu-style-1 li','float','none','','','.w-menu-style-1'),(477646,'furniture-mobile','.w-sale .left-text-left','float','left','','','.w-sale'),(477647,'furniture-mobile','.w-cart-compare .product .image','float','left','','','.w-cart-compare'),(477648,'furniture-mobile','.b-form .col-left','float','left','','','.b-form'),(477649,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(477650,'furniture-mobile','.p-blog-index .nav-previous','float','left','','','.p-blog-index'),(477651,'furniture-mobile','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(477652,'furniture-mobile','.w-compare-box-item .cb_check','float','right','','','.w-compare-box-item'),(477653,'furniture-mobile','.w-compare-box-item .cb_title','float','left','','','.w-compare-box-item'),(477654,'furniture-mobile','.w-menu-style-1 .box','float','none','','','.w-menu-style-1'),(477655,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(477656,'furniture-mobile','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(477657,'furniture-mobile','.b-form .addresses .address-item','float','left','','','.b-form'),(477658,'furniture-mobile','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(477659,'furniture-mobile','.w-socials > li','float','left','','','.w-socials'),(477660,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(477661,'furniture-mobile','.w-cart-give-away .ga_column','float','left','','','.w-cart-give-away'),(477662,'furniture-mobile','.w-wedding-registry-widgets-products .rating','float','none','','','.w-wedding-registry-widgets-products'),(477663,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(477664,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(477665,'furniture-mobile','.p-blog-index .nav-next a','float','right','3','','.p-blog-index'),(477666,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices li','float','left','','','.b-select-suggest'),(477667,'furniture-mobile','.w-neighbour-checkout .bootstrap-switch','float','right','','','.w-neighbour-checkout'),(477668,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','float','left','3','','.b-warehouses-popup'),(477669,'furniture-mobile','.w-sale .image','float','left','','','.w-sale'),(477670,'furniture-mobile','.w-menu-style-1 .box','float','none','','','.w-menu-style-1'),(477671,'furniture-mobile','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(477672,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','float','right','3','','.w-menu'),(477673,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(477674,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','float','left','2885','','.p-blog-index'),(477675,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','float','none','','','.w-menu'),(477676,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','float','right','3','','.w-menu'),(477677,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','float','right','3','','.w-menu'),(477678,'furniture-mobile','.w-menu .hided.menu ul li','float','none','','','.w-menu'),(477679,'furniture-mobile','.w-menu-horizontal .box','float','none','','','.w-menu-horizontal'),(477680,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','float','none','','','.w-menu'),(477681,'furniture-mobile','.w-login-block .new','float','right','','','.w-login-block'),(477682,'furniture-mobile','.w-login-block .guest','float','right','','','.w-login-block'),(477683,'furniture-mobile','.w-brands .brands-listing > div','float','left','','','.w-brands'),(477684,'furniture-mobile','.w-account .acc-new','float','left','','','.w-account'),(477685,'furniture-mobile','.w-login-block .guest','float','right','','','.w-login-block'),(477686,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','float','right','3','','.w-menu'),(477687,'furniture-mobile','.w-menu-big li','float','none','','','.w-menu-big'),(477688,'furniture-mobile','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(477689,'furniture-mobile','.w-promo-code .btn','float','right','','','.w-promo-code'),(477690,'furniture-mobile','.w-sale .left-count','float','left','','','.w-sale'),(477691,'furniture-mobile','.w-compare-box-item .cb_title','float','left','','','.w-compare-box-item'),(477692,'furniture-mobile','.w-login-block .new','float','right','','','.w-login-block'),(477693,'furniture-mobile','.p-blog-index .post-thumbnail','float','left','','','.p-blog-index'),(477694,'furniture-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','float','left','','','.w-account-addresses-list'),(477695,'furniture-mobile','.w-account-addresses-list .addsess-suggestion-item','float','left','','','.w-account-addresses-list'),(477696,'furniture-mobile','.b-products-listing .products-listing .bonus-points-price','float','left','3','','.b-products-listing'),(477697,'furniture-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','float','right','','','.b-products-listing'),(477698,'furniture-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','float','right','','','.b-products-listing'),(477699,'furniture-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','float','right','','','.b-products-listing'),(477700,'furniture-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','float','right','','','.b-products-listing'),(477701,'furniture-mobile','.b-products-listing .BlockBox.type-7 > .col, .b-products-listing .BlockBox.type-8 > .col, .b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col','float','left','','','.b-products-listing'),(477702,'furniture-mobile','.b-products-listing .BlockBox.type-2 > .col, .b-products-listing .BlockBox.type-3 > .col, .b-products-listing .BlockBox.type-4 > .col, .b-products-listing .BlockBox.type-5 > .col, .b-products-listing .BlockBox.type-6 > .col','float','left','','','.b-products-listing'),(477703,'furniture-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','float','right','','','.b-products-listing'),(477704,'furniture-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','float','right','','','.b-products-listing'),(477705,'furniture-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','float','right','','','.b-products-listing'),(477706,'furniture-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','float','right','','','.b-products-listing'),(477707,'furniture-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','float','right','','','.b-products-listing'),(477708,'furniture-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','float','right','','','.b-products-listing'),(477709,'furniture-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','float','right','','','.b-products-listing'),(477710,'furniture-mobile','.b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col, .b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockB','float','left','','','.b-products-listing'),(477711,'furniture-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','float','right','','','.b-products-listing'),(477712,'furniture-mobile','.b-products-listing .products-listing .item','float','none','','','.b-products-listing'),(477713,'furniture-mobile','.b-products-listing .products-listing.align-left .item','float','left','','','.b-products-listing'),(477714,'furniture-mobile','.b-products-listing .products-listing.align-right .item','float','right','','','.b-products-listing'),(477715,'furniture-mobile','.b-products-listing .wedding-registry-count','float','right','','','.b-products-listing'),(477716,'furniture-mobile','.w-blog-widget-related-posts-by-category .post','float','left','','','.w-blog-widget-related-posts-by-category'),(477717,'furniture-mobile','.w-blog-widget-related-posts .post','float','left','','','.w-blog-widget-related-posts'),(477718,'furniture-mobile','.w-blog-widget-post-title ','float','none','2876','','.w-blog-widget-post-title'),(477719,'furniture-mobile','.w-blog-widget-post-share ','float','none','2906','','.w-blog-widget-post-share'),(477720,'furniture-mobile','.w-blog-widget-post-listing .post','float','left','','','.w-blog-widget-post-listing'),(477721,'furniture-mobile','.w-blog-widget-post-image ','float','none','2876','','.w-blog-widget-post-image'),(477722,'furniture-mobile','.w-blog-widget-post-date ','float','none','2876','','.w-blog-widget-post-date'),(477723,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(477724,'furniture-mobile','.w-checkout-gdpr .candlestick-wrapper','float','right','','','.w-checkout-gdpr'),(477725,'furniture-mobile','.b-compare .compare-box-btn','float','right','','','.b-compare'),(477726,'furniture-mobile','.w-cart-give-away .ga_img','float','left','','','.w-cart-give-away'),(477727,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(477728,'furniture-mobile','.w-cart-compare .product-actions','float','right','','','.w-cart-compare'),(477729,'furniture-mobile','.w-socials .post_item_img','float','left','','','.w-socials'),(477730,'furniture-mobile','.w-promo-code .btn','float','right','','','.w-promo-code'),(477731,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','float','none','','','.w-menu'),(477732,'furniture-mobile','.w-login-block .returning','float','left','','','.w-login-block'),(477733,'furniture-mobile','.p-blog-index .comment-metadata','float','right','','','.p-blog-index'),(477734,'furniture-mobile','.p-reviews-info .review-info-image','float','left','','','.p-reviews-info'),(477735,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(477736,'furniture-mobile','.w-menu-style-1 li','float','none','','','.w-menu-style-1'),(477737,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(477738,'furniture-mobile','.w-checkout-create-account .newsletter-switcher .bootstrap-switch','float','right','','','.w-checkout-create-account'),(477739,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item','float','left','','','.w-checkout-shipping-address'),(477740,'furniture-mobile','.w-checkout-create-account .create-account-switcher','float','right','','','.w-checkout-create-account'),(477741,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(477743,'furniture-mobile','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(477744,'furniture-mobile','.w-menu-style-1 li','float','none','','','.w-menu-style-1'),(477745,'furniture-mobile','.w-login-block .returning','float','left','','','.w-login-block'),(477746,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','float','right','3','','.w-menu'),(477747,'furniture-mobile','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(477748,'furniture-mobile','.w-compare-box-item .cb_check','float','right','','','.w-compare-box-item'),(477749,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','float','left','2885','','.p-blog-index'),(477750,'furniture-mobile','.w-sale .left-text-right','float','left','','','.w-sale'),(477751,'furniture-mobile','.w-sale .left-text-left','float','left','','','.w-sale'),(477752,'furniture-mobile','.w-sale .holder-1','float','right','','','.w-sale'),(477753,'furniture-mobile','.w-sale .left-count','float','left','','','.w-sale'),(477754,'furniture-mobile','.w-sale .image','float','left','','','.w-sale'),(477755,'furniture-mobile','.w-sale .holder-2','float','left','','','.w-sale'),(477756,'furniture-mobile','.w-promo-code .btn','float','right','','','.w-promo-code'),(477757,'furniture-mobile','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(477758,'furniture-mobile','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(477759,'furniture-mobile','.b-form .columns .col-2','float','left','','','.b-form'),(477760,'furniture-mobile','.p-blog-index .nav-next a','float','right','3','','.p-blog-index'),(477761,'furniture-mobile','.p-blog-index .comment-metadata','float','right','','','.p-blog-index'),(477762,'furniture-mobile','.p-blog-index .comment-author','float','left','','','.p-blog-index'),(477763,'furniture-mobile','.w-product-cross-sell .buy-all-checker','float','left','','','.w-product-cross-sell'),(477765,'furniture-mobile','.w-cart-listing .item > div','float','left','','','.w-cart-listing'),(477766,'furniture-mobile','.w-cart-listing .points-redeem','float','left','3','','.w-cart-listing'),(477767,'furniture-mobile','.w-cart-listing .right-area','float','left','','','.w-cart-listing'),(477768,'furniture-mobile','.w-cart-listing .item .qty','float','right','2885','','.w-cart-listing'),(477769,'furniture-mobile','.w-cart-listing .links','float','left','','','.w-cart-listing'),(477770,'furniture-mobile','.w-cart-give-away .ga_price .checkBoxWrap','float','right','','','.w-cart-give-away'),(477771,'furniture-mobile','.w-cart .sub-total-text','float','left','','','.w-cart'),(477772,'furniture-mobile','.w-cart .sub-total','float','right','','','.w-cart'),(477773,'furniture-mobile','.w-brands .brands-listing > div','float','left','','','.w-brands'),(477774,'furniture-mobile','.order-summary .btn-2','float','none','2885','','.order-summary'),(477775,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','float','left','2885','','.p-blog-index'),(477776,'furniture-mobile','.w-sale .left-text-left','float','left','','','.w-sale'),(477777,'furniture-mobile','.w-sale .holder-1','float','right','','','.w-sale'),(477778,'furniture-mobile','.w-promo-code .btn','float','right','','','.w-promo-code'),(477779,'furniture-mobile','.w-menu-style-1 li','float','none','','','.w-menu-style-1'),(477780,'furniture-mobile','.w-menu-style-1 .box','float','none','','','.w-menu-style-1'),(477781,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','float','right','3','','.w-menu'),(477782,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','float','right','3','','.w-menu'),(477783,'furniture-mobile','.w-menu .hided.menu ul li','float','none','','','.w-menu'),(477784,'furniture-mobile','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(477785,'furniture-mobile','.w-checkout-billing-address .bootstrap-switch','float','right','','','.w-checkout-billing-address'),(477786,'furniture-mobile','.w-brands .brands-listing > div','float','left','','','.w-brands'),(477787,'furniture-mobile','.p-reviews-info .review-info-image','float','left','','','.p-reviews-info'),(477788,'furniture-mobile','.p-blog-index .post-thumbnail','float','left','','','.p-blog-index'),(477789,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(477790,'furniture-mobile','.p-blog-index .comment-metadata','float','right','','','.p-blog-index'),(477791,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(477792,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','float','right','','','.p-account-trade-form'),(477793,'furniture-mobile','.p-blog-index .wp-widget li','float','left','3','','.p-blog-index'),(477794,'furniture-mobile','.p-blog-index .nav-next a','float','right','3','','.p-blog-index'),(477795,'furniture-mobile','.w-compare-box-item .cb_check','float','right','','','.w-compare-box-item'),(477796,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','float','right','3','','.w-menu'),(477797,'furniture-mobile','.w-menu .hided.menu ul li','float','none','','','.w-menu'),(477798,'furniture-mobile','.b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockBox.type-14 > .col, .b-products-listing .BlockBox.type-15 > .col, .b-products-listing .BlockBox.type-16 > .col','float','left','','','.b-products-listing'),(477799,'furniture-mobile','.w-product-reviews .write-review-button','float','right','','','.w-product-reviews'),(477800,'furniture-mobile','.w-promo-code .btn','float','right','','','.w-promo-code'),(477801,'furniture-mobile','.w-filters .handle-to','float','right','','','.w-filters'),(477802,'furniture-mobile','.w-filters .handle-from','float','left','','','.w-filters'),(477803,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(477804,'furniture-mobile','.w-cart-compare .js-cart_totals_container','float','left','','','.w-cart-compare'),(477805,'furniture-mobile','.w-cart-compare .buttons','float','right','','','.w-cart-compare'),(477806,'furniture-mobile','.w-menu-style-1 .box','float','none','','','.w-menu-style-1'),(477807,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(477808,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(477809,'furniture-mobile','.p-reviews-info .review-info-image','float','left','','','.p-reviews-info'),(477810,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','float','right','3','','.w-menu'),(477811,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','float','right','3','','.w-menu'),(477812,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','float','none','','','.w-menu'),(477813,'furniture-mobile','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(477814,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','float','left','2885','','.p-blog-index'),(477815,'furniture-mobile','.p-blog-index .nav-previous','float','left','','','.p-blog-index'),(477816,'furniture-mobile','.p-blog-index .nav-next a','float','right','3','','.p-blog-index'),(477817,'furniture-mobile','.p-blog-index .comment-metadata','float','right','','','.p-blog-index'),(477818,'furniture-mobile','.p-blog-index .nav-next','float','right','','','.p-blog-index'),(477819,'furniture-mobile','.p-blog-index .nav-previous a','float','left','3','','.p-blog-index'),(477820,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(477821,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','float','left','','','.p-account-trade-form'),(477822,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(477823,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(477824,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(477825,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(477826,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(477827,'furniture-mobile','.b-trade-approval .col-right','float','right','','','.b-trade-approval'),(477828,'furniture-mobile','.b-trade-approval .col-left','float','left','','','.b-trade-approval'),(477829,'furniture-mobile','.b-trade-approval .col-3','float','left','','','.b-trade-approval'),(477830,'furniture-mobile','.batchPr .w-batch-products .products-listing .image','float','left','','','.batchPr'),(477831,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(2)','float','none','','','.batchPr'),(477832,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','float','left','','','.batchPr'),(477833,'furniture-mobile','.w-catalog-compare .compare label','float','right','','','.w-catalog-compare'),(477834,'furniture-mobile','.w-catalog-compare .buyButton','float','right','','','.w-catalog-compare'),(477835,'furniture-mobile','.w-delivery-day .left-count','float','left','','','.w-delivery-day'),(477836,'furniture-mobile','.w-delivery-day .left-text-left','float','left','','','.w-delivery-day'),(477837,'furniture-mobile','.w-delivery-day .left-text-right','float','left','','','.w-delivery-day'),(477838,'furniture-mobile','.w-account .col-left, .w-account .col-right','float','none','','','.w-account'),(477839,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .stock','float','none','','','.b-products-listing'),(477840,'furniture-mobile','.b-slick .slick-slide','float','left','','','.b-slick'),(477841,'furniture-mobile','.b-slick [dir=\'rtl\'] .slick-slide','float','right','','','.b-slick'),(477842,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li','float','left','3','','.b-menu-style-3'),(477843,'furniture-mobile','.b-products-listing .item-nav > div','float','left','','','.b-products-listing'),(477844,'furniture-mobile','.w-quote .image','float','left','','','.w-quote'),(477845,'furniture-mobile','.w-quote .sub-total','float','right','','','.w-quote'),(477846,'furniture-mobile','.w-quote .sub-total-text','float','left','','','.w-quote'),(477847,'furniture-mobile','.b-quantity .qty-input label','float','left','','','.b-quantity'),(477848,'furniture-mobile','.w-product-sale-ends .left-count','float','left','','','.w-product-sale-ends'),(477849,'furniture-mobile','.w-product-sale-ends .left-text-left','float','left','','','.w-product-sale-ends'),(477850,'furniture-mobile','.w-product-sale-ends .left-text-right','float','left','','','.w-product-sale-ends'),(477851,'furniture-mobile','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(477852,'furniture-mobile','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(477853,'furniture-mobile','.w-product-bonus-points > div > div','float','left','','','.w-product-bonus-points'),(477854,'furniture-mobile','.w-compare .compare-list-buttons','float','right','','','.w-compare'),(477855,'furniture-mobile','.w-compare .clear-compare-button','float','right','','','.w-compare'),(477856,'furniture-mobile','.w-compare .image','float','left','','','.w-compare'),(477857,'furniture-mobile','.w-files-catalog-widgets-files-list .file','float','left','3','','.w-files-catalog-widgets-files-list'),(477858,'furniture-mobile','.w-sample .image','float','left','','','.w-sample'),(477859,'furniture-mobile','.w-sample .sub-total','float','right','','','.w-sample'),(477860,'furniture-mobile','.w-sample .sub-total-text','float','left','','','.w-sample'),(477861,'furniture-mobile','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(477862,'furniture-mobile','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(477863,'furniture-mobile','.w-product-bundle .bundle_qty','float','left','','','.w-product-bundle'),(477864,'furniture-mobile','.w-product-bundle .bundle_price','float','right','','','.w-product-bundle'),(477865,'furniture-mobile','.w-product-in-bundles .attributes-item','float','left','','','.w-product-in-bundles'),(477866,'furniture-mobile','.w-product-in-bundles .bundle_qty','float','left','','','.w-product-in-bundles'),(477867,'furniture-mobile','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(477868,'furniture-mobile','.w-cart-listing .item div.price','float','left','2885','','.w-cart-listing'),(477869,'furniture-mobile','.b-pagination .pagination .left-area','float','left','','','.b-pagination'),(477870,'furniture-mobile','.b-pagination .pagination .right-area','float','right','','','.b-pagination'),(477871,'furniture-mobile','.w-product-quantity-discounts .item','float','left','','','.w-product-quantity-discounts'),(477872,'furniture-mobile','.w-product-quantity-discounts .item','float','none','2885','','.w-product-quantity-discounts'),(477873,'furniture-mobile','.w-product-multi-inventory .select-box:nth-child(2n)','float','left','','','.w-product-multi-inventory'),(477874,'furniture-mobile','.w-product-multi-inventory .select-box:nth-child(2n+1)','float','left','','','.w-product-multi-inventory'),(477875,'furniture-mobile','.w-product-multi-inventory .radio-attributes > label','float','left','','','.w-product-multi-inventory'),(477876,'furniture-mobile','.b-products-listing .products-listing .radio-attributes > label','float','left','','','.b-products-listing'),(477877,'furniture-mobile','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(477878,'furniture-mobile','.w-product-collection .current-product','float','left','','','.w-product-collection'),(477879,'furniture-mobile','.w-product-collection .right-area','float','left','','','.w-product-collection'),(477880,'furniture-mobile','.w-product-collection .current-product, .w-product-collection .chosen-products','float','none','2885','','.w-product-collection'),(477881,'furniture-mobile','.w-product-collection .right-area','float','none','2885','','.w-product-collection'),(477882,'furniture-mobile','.w-product-attributes .radio-attributes > label','float','left','','','.w-product-attributes'),(477883,'furniture-mobile','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(477884,'furniture-mobile','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(477885,'furniture-mobile','.w-product-groups .radioBox label','float','left','','','.w-product-groups'),(477886,'furniture-mobile','.w-product-groups .radioBox label .containerBlock img','float','left','','','.w-product-groups'),(477887,'furniture-mobile','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img','float','none','','','.w-product-groups'),(477888,'furniture-mobile','.b-products-listing .products-listing .attribute-color','float','left','','','.b-products-listing'),(477889,'furniture-mobile','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(477890,'furniture-mobile','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(477891,'furniture-mobile','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(477892,'furniture-mobile','.w-product-custom-bundle .chosen-products','float','none','2885','','.w-product-custom-bundle'),(477893,'furniture-mobile','.w-product-custom-bundle .right-area','float','none','2885','','.w-product-custom-bundle'),(477894,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','float','left','','','.w-catalog-pages-category-pages-last-list'),(477895,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','float','left','','','.w-catalog-pages-category-pages-last-list-block'),(477896,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(477897,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(477898,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li','float','left','','','.w-delivery-location-featured-list'),(477899,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li','float','none','2906','','.w-delivery-location-featured-list'),(477900,'furniture-mobile','.w-sale-category .holder-1','float','right','','','.w-sale-category'),(477901,'furniture-mobile','.w-sale-category .holder-2','float','left','','','.w-sale-category'),(477902,'furniture-mobile','.w-sale-category .image','float','left','','','.w-sale-category'),(477903,'furniture-mobile','.w-sale-category .left-count','float','left','','','.w-sale-category'),(477904,'furniture-mobile','.w-sale-category .left-text-left','float','left','','','.w-sale-category'),(477905,'furniture-mobile','.w-sale-category .left-text-right','float','left','','','.w-sale-category'),(477906,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','float','left','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(477907,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','float','left','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(477908,'furniture-mobile','.w-delivery-location-list-by-page .item','float','left','','','.w-delivery-location-list-by-page'),(477909,'furniture-mobile','.w-delivery-location-cross-pages .item','float','left','','','.w-delivery-location-cross-pages'),(477910,'furniture-mobile','.w-catalog-delivery-locations .item','float','left','','','.w-catalog-delivery-locations'),(477911,'furniture-mobile','.w-catalog-delivery-locations .item','float','none','2876','','.w-catalog-delivery-locations'),(477912,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .left-area','float','left','','','.w-wedding-registry-widgets-search-paging'),(477913,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','float','left','','','.w-product-designer-designer'),(477914,'furniture-mobile','.w-product-designer-designer .prodDesignerType','float','none','','','.w-product-designer-designer'),(477915,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','float','right','','','.w-press-reviews-widgets-press-reviews-small'),(477916,'furniture-mobile','.w-gift-wrap-message-checkout .text','float','left','','','.w-gift-wrap-message-checkout'),(477917,'furniture-mobile','.w-support-system-filter .filter-categories','float','none','','','.w-support-system-filter'),(477918,'furniture-mobile','.w-support-system-filter .dd3-content .collapse_span','float','right','','','.w-support-system-filter'),(477919,'furniture-mobile','.w-support-system-listing .product_icon','float','left','','','.w-support-system-listing'),(477920,'furniture-mobile','.w-rma-returns-history .topRow .icons','float','right','','','.w-rma-returns-history'),(477921,'furniture-mobile','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(477922,'furniture-mobile','.w-product-configurator .item-content > div','float','left','2876','','.w-product-configurator'),(477923,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','float','left','','','.w-catalog-pages-category-pages-list'),(477924,'furniture-mobile','.w-filters .fsl_handle > div','float','left','','','.w-filters'),(477925,'furniture-mobile','.mainBanner .bottomBox .btn','float','right','','','.mainBanner'),(477926,'furniture-mobile','.shopByCollectionBox .bannerButton','float','right','','','.shopByCollectionBox'),(477927,'furniture-mobile','.shopByCollectionBox .content .title','float','left','','','.shopByCollectionBox'),(477928,'furniture-mobile','.shopByCollectionBox .bannerButton','float','right','2890','','.shopByCollectionBox'),(477929,'furniture-mobile','.w-cart-shipping-estimator .left-area','float','none','2876','','.w-cart-shipping-estimator'),(477930,'furniture-mobile','.w-cart-shipping-estimator .right-area','float','none','2876','','.w-cart-shipping-estimator'),(477931,'furniture-mobile','.account-address-book .address_book h2 strong','float','left','','','.account-address-book'),(477932,'furniture-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','float','left','','','.account-address-book'),(477933,'furniture-mobile','.account-address-book .button1','float','right','','','.account-address-book'),(477934,'furniture-mobile','.account-address-book .button2','float','left','','','.account-address-book'),(477935,'furniture-mobile','.account-address-book .address_book_row .column','float','none','2876','','.account-address-book'),(477936,'furniture-mobile','.account-address-book .address_book_row .column + .column','float','none','2876','','.account-address-book'),(477937,'furniture-mobile','.account-address-book .topInfo > div','float','none','2876','','.account-address-book'),(477938,'furniture-mobile','.account-address-book .topInfo > div + div','float','none','2876','','.account-address-book'),(477939,'furniture-mobile','.account-order-history-info .history_info > div','float','left','','','.account-order-history-info'),(477940,'furniture-mobile','.account-index .account_info li','float','left','','','.account-index'),(477941,'furniture-mobile','.account-index .ai_title, .account-index .ai_value','float','left','','','.account-index'),(477942,'furniture-mobile','.account-index .topAccount > li','float','left','','','.account-index'),(477943,'furniture-mobile','.account-index .topInfo > div','float','left','','','.account-index'),(477944,'furniture-mobile','.account-index .orders-table .products','float','right','2885','','.account-index'),(477945,'furniture-mobile','.account-index .account_info li','float','none','2876','','.account-index'),(477946,'furniture-mobile','.account-index .topAccount > li','float','none','2876','','.account-index'),(477947,'furniture-mobile','.account-order-pay .history_info > div','float','left','','','.account-order-pay'),(477948,'furniture-mobile','.account-sample-info .history_info > div','float','left','','','.account-sample-info'),(477949,'furniture-mobile','.checkout-index-wrap .dob-hide > div','float','right','','','.checkout-index-wrap'),(477950,'furniture-mobile','.checkout-index-wrap .dob-hide label','float','left','','','.checkout-index-wrap'),(477951,'furniture-mobile','.w-blog-widget-post-share ','float_important','important','2906','','.w-blog-widget-post-share'),(477952,'furniture-mobile','.b-slick .slick-slide','float_important','important','','','.b-slick'),(477953,'furniture-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-family','$font-1','','','.w-communication-new-topic'),(477954,'furniture-mobile','.b-upload-file .snapshot','font-family','$font-icons-1','3','','.b-upload-file'),(477955,'furniture-mobile','.heading-4 .edit, h4 .edit','font-family','trueloaded','4','',''),(477956,'furniture-mobile','.heading-4 .edit, h4 .edit','font-family','$font-1','','',''),(477957,'furniture-mobile','.message.success','font-family','trueloaded','3','',''),(477958,'furniture-mobile','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(477959,'furniture-mobile','.p-blog-index .wp-widget li','font-family','$font-icons-1','3','','.p-blog-index'),(477960,'furniture-mobile','.p-blog-index .nav-previous a','font-family','$font-icons-1','3','','.p-blog-index'),(477961,'furniture-mobile','.p-blog-index .nav-next a','font-family','$font-icons-1','3','','.p-blog-index'),(477962,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(477963,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(477964,'furniture-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','font-family','$font-icons-1','','','.b-form'),(477965,'furniture-mobile','.w-filters .filter-box-head','font-family','$font-1','','','.w-filters'),(477966,'furniture-mobile','.p-quick-order-index .paginate_button.previous','font-family','$font-icons-1','3','','.p-quick-order-index'),(477967,'furniture-mobile','.p-quick-order-index .paginate_button.next','font-family','$font-icons-1','3','','.p-quick-order-index'),(477968,'furniture-mobile','.p-blog-index .post-title','font-family','$font-1','','','.p-blog-index'),(477969,'furniture-mobile','.p-blog-index .nav-previous a','font-family','$font-icons-1','3','','.p-blog-index'),(477970,'furniture-mobile','.w-cart-compare .cart-name a','font-family','$font-1','','','.w-cart-compare'),(477971,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(477972,'furniture-mobile','.w-account .my-acc-link','font-family','$font-icons-1','3','','.w-account'),(477973,'furniture-mobile','.p-wedding-registry-view h1','font-family','$font-icons-1','3','','.p-wedding-registry-view'),(477974,'furniture-mobile','.p-wedding-registry-view h1','font-family','$font-icons-1','4','','.p-wedding-registry-view'),(477975,'furniture-mobile','.w-wedding-registry-widgets-manage-names .names-separator','font-family','$font-icons-1','3','','.w-wedding-registry-widgets-manage-names'),(477976,'furniture-mobile','.w-wedding-registry-widgets-share-link a','font-family','$font-icons-1','3','','.w-wedding-registry-widgets-share-link'),(477977,'furniture-mobile','.w-wedding-registry-widgets-search-registry-button a','font-family','$font-icons-1','3','','.w-wedding-registry-widgets-search-registry-button'),(477978,'furniture-mobile','.w-wedding-registry-widgets-products .remove-btn','font-family','$font-icons-1','3','','.w-wedding-registry-widgets-products'),(477979,'furniture-mobile','.p-sample-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-sample-checkout-success'),(477980,'furniture-mobile','.p-sample-checkout-success .page-success .text-1, .p-sample-checkout-success .page-success .text-2, .p-sample-checkout-success .page-success .text-3','font-family','$font-1','','','.p-sample-checkout-success'),(477981,'furniture-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(477982,'furniture-mobile','.p-blog-index .nav-previous a','font-family','$font-icons-1','3','','.p-blog-index'),(477983,'furniture-mobile','.p-blog-index .post-title','font-family','$font-1','','','.p-blog-index'),(477984,'furniture-mobile','.p-blog-index .nav-next a','font-family','$font-icons-1','3','','.p-blog-index'),(477985,'furniture-mobile','.testimonials .heading-3','font-family','trueloaded','3','',''),(477986,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(477987,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(477988,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','font-family','$font-icons-1','','','.w-compare-box-item'),(477989,'furniture-mobile','.w-promotions .nextdiscount .heading','font-family','$font-icons-1','3','','.w-promotions'),(477990,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','font-family','$font-icons-1','3','','.b-warehouses-popup'),(477991,'furniture-mobile','.b-warehouses-popup .warehouses-popup-link','font-family','$font-icons-1','3','','.b-warehouses-popup'),(477992,'furniture-mobile','.b-preloader .preloader','font-family','$font-icons-1','3','','.b-preloader'),(477993,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','font-family','$font-icons-1','','','.w-compare-box-item'),(477994,'furniture-mobile','.w-social-links a','font-family','$font-icons-1','','','.w-social-links'),(477995,'furniture-mobile','.b-bottom .closeable-heading','font-family','$font-icons-1','3','','.b-bottom'),(477996,'furniture-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(477997,'furniture-mobile','.b-messages .messBtnMenuUnread','font-family','$font-icons-1','3','','.b-messages'),(477998,'furniture-mobile','.b-messages .messBtnMenuDelete','font-family','trueloaded','3','','.b-messages'),(477999,'furniture-mobile','.b-messages span.starred::before','font-family','trueloaded','','','.b-messages'),(478000,'furniture-mobile','.b-messages .messBtnMenuStarred','font-family','trueloaded','3','','.b-messages'),(478001,'furniture-mobile','.b-messages .content_management_attach span','font-family','$font-1','','','.b-messages'),(478003,'furniture-mobile','.p-wedding-registry-view h1','font-family','$font-icons-1','3','','.p-wedding-registry-view'),(478004,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(478005,'furniture-mobile','.p-payer-order-confirmation .ship-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(478006,'furniture-mobile','.p-payer-order-confirmation .pay-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(478007,'furniture-mobile','.p-payer-order-confirmation .order-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(478008,'furniture-mobile','.p-payer-order-confirmation .discount-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(478009,'furniture-mobile','.p-payer-order-confirmation .comment-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(478010,'furniture-mobile','.p-payer-order-pay .ship-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(478011,'furniture-mobile','.p-payer-order-pay .order-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(478012,'furniture-mobile','.p-payer-order-pay .pay-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(478013,'furniture-mobile','.p-payer-order-pay .discount-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(478014,'furniture-mobile','.p-payer-order-pay .comment-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(478015,'furniture-mobile','.p-blog-index .author','font-family','$font-1','','','.p-blog-index'),(478016,'furniture-mobile','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(478017,'furniture-mobile','.b-info .info strong','font-family','$font-1','','','.b-info'),(478018,'furniture-mobile','.b-fancybox .fancybox-close','font-family','$font-icons-1','3','','.b-fancybox'),(478019,'furniture-mobile','.b-messages .select2-search-choice-close','font-family','trueloaded','3','','.b-messages'),(478021,'furniture-mobile','.w-cart .cart-box-link','font-family','trueloaded','3','','.w-cart'),(478022,'furniture-mobile','.bell-ico .heading-2','font-family','trueloaded','3','','.bell-ico'),(478023,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(478024,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-family','$font-icons-1','3','','.w-upload-customer-id-upload-customer-id-form'),(478025,'furniture-mobile','.w-coupons-and-vauchers-checkout .btn-remove','font-family','trueloaded','3','','.w-coupons-and-vauchers-checkout'),(478026,'furniture-mobile','.w-menu-slider .close','font-family','$font-icons-1','3','','.w-menu-slider'),(478027,'furniture-mobile','.w-filters .open','font-family','$font-icons-1','3','','.w-filters'),(478028,'furniture-mobile','.w-categories h2.name','font-family','$font-1','','','.w-categories'),(478029,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(478030,'furniture-mobile','.b-fancybox .fancybox-nav span','font-family','trueloaded','','','.b-fancybox'),(478031,'furniture-mobile','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(478032,'furniture-mobile','.p-blog-index .nav-previous a','font-family','$font-icons-1','3','','.p-blog-index'),(478034,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','font-family','$font-icons-1','3','','.w-checkout-contact-information'),(478035,'furniture-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(478036,'furniture-mobile','.no-found','font-family','$font-1','','',''),(478037,'furniture-mobile','.view-all .btn','font-family','$font-icons-1','4','',''),(478038,'furniture-mobile','.w-catalog-listing-look .list','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(478039,'furniture-mobile','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(478040,'furniture-mobile','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(478041,'furniture-mobile','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(478042,'furniture-mobile','.w-cart-compare .price-cell','font-family','$font-1','','','.w-cart-compare'),(478043,'furniture-mobile','.p-wedding-registry-view h1','font-family','$font-icons-1','4','','.p-wedding-registry-view'),(478044,'furniture-mobile','.w-catalog-paging .prev','font-family','$font-icons-1','3','','.w-catalog-paging'),(478045,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','font-family','$font-icons-1','','','.w-compare-box-item'),(478046,'furniture-mobile','.b-bottom .footerTitle','font-family','$font-icons-1','2876,4','','.b-bottom'),(478047,'furniture-mobile','.w-menu .menu .menu-ico','font-family','trueloaded','3','','.w-menu'),(478048,'furniture-mobile','.b-rating .glyphicon-star','font-family','$font-icons-1','3','','.b-rating'),(478049,'furniture-mobile','.w-chat .w-chat-box a','font-family','$font-icons-1','3','','.w-chat'),(478050,'furniture-mobile','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(478051,'furniture-mobile','.w-search .button-search','font-family','trueloaded','3','','.w-search'),(478052,'furniture-mobile','.w-cart-compare .product-actions .dropdown-toggle','font-family','$font-icons-1','3','','.w-cart-compare'),(478053,'furniture-mobile','.w-cart-compare .atr-col','font-family','$font-icons-1','3','','.w-cart-compare'),(478054,'furniture-mobile','.p-blog-index .author','font-family','$font-1','','','.p-blog-index'),(478055,'furniture-mobile','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(478056,'furniture-mobile','.b-rating .glyphicon','font-family','$font-icons-1','','','.b-rating'),(478057,'furniture-mobile','.order-summary .price-row.ot_gv .title','font-family','trueloaded','3','','.order-summary'),(478058,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(478059,'furniture-mobile','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(478060,'furniture-mobile','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(478061,'furniture-mobile','.p-blog-index .author','font-family','$font-1','','','.p-blog-index'),(478062,'furniture-mobile','.b-info .info','font-family','trueloaded','3','','.b-info'),(478063,'furniture-mobile','.w-tabs .tab-li.tab-wishlist a','font-family','trueloaded','3','','.w-tabs'),(478064,'furniture-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','font-family','$font-icons-1','3','','.w-multi-cart-actions'),(478065,'furniture-mobile','.w-top-categories h2.name','font-family','$font-1','','','.w-top-categories'),(478066,'furniture-mobile','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(478067,'furniture-mobile','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(478068,'furniture-mobile','.w-tabs .tab-a','font-family','$font-1','','','.w-tabs'),(478069,'furniture-mobile','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(478070,'furniture-mobile','.btn-edit','font-family','trueloaded','3','',''),(478071,'furniture-mobile','.w-tabs .tab-li.tab-cart a','font-family','trueloaded','3','','.w-tabs'),(478072,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(478073,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(478074,'furniture-mobile','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(478075,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(478076,'furniture-mobile','.w-languages .current','font-family','trueloaded','3','','.w-languages'),(478077,'furniture-mobile','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(478078,'furniture-mobile','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(478079,'furniture-mobile','.p-blog-index .wp-widget li','font-family','$font-icons-1','3','','.p-blog-index'),(478080,'furniture-mobile','.btn-2','font-family','$font-1','','',''),(478081,'furniture-mobile','.btn-1','font-family','$font-1','','',''),(478082,'furniture-mobile','.heading-5, h5, .h-block h5','font-family','$font-1','','',''),(478083,'furniture-mobile','.w-menu-slider .close','font-family','$font-icons-1','3','','.w-menu-slider'),(478084,'furniture-mobile','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(478085,'furniture-mobile','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(478086,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(478087,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(478088,'furniture-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','font-family','$font-icons-1','','','.w-filters'),(478089,'furniture-mobile','.in-stock-icon','font-family','$font-icons-1','3','',''),(478090,'furniture-mobile','.out-stock-icon','font-family','$font-icons-1','3','',''),(478091,'furniture-mobile','.transit-icon','font-family','$font-icons-1','3','',''),(478092,'furniture-mobile','.heading-3 .edit, h3 .edit','font-family','trueloaded','4','',''),(478093,'furniture-mobile','.heading-3 .edit, h3 .edit','font-family','$font-1','','',''),(478094,'furniture-mobile','.b-info .info','font-family','trueloaded','3','','.b-info'),(478095,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(478096,'furniture-mobile','.w-checkout-create-account .account-benefits strong','font-family','trueloaded','3','','.w-checkout-create-account'),(478097,'furniture-mobile','.b-info .info strong','font-family','$font-1','','','.b-info'),(478098,'furniture-mobile','.savings-ico .heading-2','font-family','trueloaded','3','','.savings-ico'),(478099,'furniture-mobile','.w-cart-bonus-points .btn-remove','font-family','trueloaded','3','','.w-cart-bonus-points'),(478100,'furniture-mobile','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(478101,'furniture-mobile','.heading-saved-lists .heading-4','font-family','trueloaded','3','','.heading-saved-lists'),(478102,'furniture-mobile','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(478103,'furniture-mobile','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-family','$font-1','','','.w-multi-cart-cart-switcher'),(478104,'furniture-mobile','.js-stock-icon','font-family','$font-icons-1','3','',''),(478105,'furniture-mobile','.b-switch .candlestick-wrapper .fa-check','font-family','$font-icons-1','3','','.b-switch'),(478106,'furniture-mobile','.b-switch .candlestick-wrapper .fa-times','font-family','$font-icons-1','3','','.b-switch'),(478107,'furniture-mobile','.b-info .info strong','font-family','$font-1','','','.b-info'),(478108,'furniture-mobile','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(478109,'furniture-mobile','.w-top-categories .categories h2','font-family','inherit','','','.w-top-categories'),(478110,'furniture-mobile','.btn','font-family','$font-1','','',''),(478111,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(478112,'furniture-mobile','.heading-4, h4, .h-block h4','font-family','$font-1','','',''),(478113,'furniture-mobile','.b-upload-file .upload-file-wrap .upload-remove','font-family','trueloaded','3','','.b-upload-file'),(478114,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-family','$font-icons-1','','','.b-form'),(478115,'furniture-mobile','.p-wedding-registry-view h1','font-family','$font-icons-1','3','','.p-wedding-registry-view'),(478116,'furniture-mobile','.p-wedding-registry-view h1','font-family','$font-icons-1','4','','.p-wedding-registry-view'),(478117,'furniture-mobile','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(478118,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(478119,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(478120,'furniture-mobile','.w-reviews .heading-3','font-family','trueloaded','3','','.w-reviews'),(478122,'furniture-mobile','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(478123,'furniture-mobile','.b-info .info','font-family','trueloaded','3','','.b-info'),(478124,'furniture-mobile','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(478125,'furniture-mobile','.b-info .info strong','font-family','$font-1','','','.b-info'),(478126,'furniture-mobile','.btn-del','font-family','$font-icons-1','4','',''),(478127,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','font-family','$font-icons-1','','','.w-compare-box-item'),(478128,'furniture-mobile','.b-rating .glyphicon-star.coloron','font-family','$font-icons-1','3','','.b-rating'),(478129,'furniture-mobile','.p-blog-index .wp-widget li','font-family','$font-icons-1','3','','.p-blog-index'),(478130,'furniture-mobile','.p-blog-index .post-title','font-family','$font-1','','','.p-blog-index'),(478131,'furniture-mobile','.p-blog-index .author','font-family','$font-1','','','.p-blog-index'),(478133,'furniture-mobile','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(478135,'furniture-mobile','.w-cart-credit-amount .btn-remove','font-family','trueloaded','3','','.w-cart-credit-amount'),(478136,'furniture-mobile','.w-menu-slider .close','font-family','$font-icons-1','3','','.w-menu-slider'),(478137,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','font-family','$font-icons-1','3','','.w-menu'),(478138,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(478139,'furniture-mobile','.p-wedding-registry-view h1','font-family','$font-icons-1','4','','.p-wedding-registry-view'),(478140,'furniture-mobile','.w-catalog-paging .next','font-family','$font-icons-1','3','','.w-catalog-paging'),(478141,'furniture-mobile','.p-blog-index .nav-previous a','font-family','$font-icons-1','3','','.p-blog-index'),(478142,'furniture-mobile','.p-blog-index .wp-widget li','font-family','$font-icons-1','3','','.p-blog-index'),(478143,'furniture-mobile','.heading-6, h6, .h-block h6','font-family','$font-1','','',''),(478145,'furniture-mobile','.closeable-heading','font-family','$font-icons-1','3','',''),(478146,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(478148,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(478149,'furniture-mobile','.b-bottom .pop-up-close','font-family','$font-icons-1','3','','.b-bottom'),(478150,'furniture-mobile','.b-info-popup .info-popup','font-family','trueloaded','3','','.b-info-popup'),(478152,'furniture-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-family','$font-icons-1','','','.b-products-listing'),(478153,'furniture-mobile','.b-upload-files .remove-file','font-family','$font-icons-1','3','','.b-upload-files'),(478154,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','font-family','$font-icons-1','3','','.w-menu'),(478155,'furniture-mobile','.w-menu-slider .close','font-family','$font-icons-1','3','','.w-menu-slider'),(478156,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','font-family','$font-icons-1','3','','.w-menu'),(478157,'furniture-mobile','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(478158,'furniture-mobile','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(478160,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(478161,'furniture-mobile','.b-info .info','font-family','trueloaded','3','','.b-info'),(478162,'furniture-mobile','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(478163,'furniture-mobile','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(478164,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(478165,'furniture-mobile','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(478166,'furniture-mobile','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(478167,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','font-family','$font-icons-1','','','.w-compare-box-item'),(478169,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','font-family','$font-icons-1','3','','.w-menu'),(478170,'furniture-mobile','.heading-3, h3, .h-block h3','font-family','$font-1','','',''),(478171,'furniture-mobile','.p-blog-index .nav-next a','font-family','$font-icons-1','3','','.p-blog-index'),(478172,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-family','$font-1','','','.b-select-suggest'),(478173,'furniture-mobile','.b-select-suggest .select2-search input','font-family','$font-1','','','.b-select-suggest'),(478174,'furniture-mobile','.w-menu .menu .menu-ico','font-family','trueloaded','3','','.w-menu'),(478175,'furniture-mobile','.w-menu-slider .close','font-family','$font-icons-1','3','','.w-menu-slider'),(478176,'furniture-mobile','.w-menu .menu .menu-ico','font-family','trueloaded','3','','.w-menu'),(478177,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','font-family','$font-icons-1','3','','.w-menu'),(478178,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','font-family','$font-icons-1','3','','.w-menu'),(478179,'furniture-mobile','.p-blog-index .nav-next a','font-family','$font-icons-1','3','','.p-blog-index'),(478180,'furniture-mobile','.p-blog-index .post-title','font-family','$font-1','','','.p-blog-index'),(478181,'furniture-mobile','.p-blog-index .wp-widget li','font-family','$font-icons-1','3','','.p-blog-index'),(478182,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(478183,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','font-family','$font-icons-1','3','','.w-menu'),(478184,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','font-family','$font-icons-1','3','','.w-menu'),(478185,'furniture-mobile','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(478186,'furniture-mobile','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(478187,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','font-family','$font-icons-1','3','','.w-menu'),(478188,'furniture-mobile','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(478189,'furniture-mobile','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(478190,'furniture-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(478191,'furniture-mobile','.p-blog-index .wp-widget li','font-family','$font-icons-1','3','','.p-blog-index'),(478192,'furniture-mobile','.b-products-listing .products-listing .bonus-points-price','font-family','$font-icons-1','3','','.b-products-listing'),(478193,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','font-family','$font-icons-1','3','','.b-products-listing'),(478194,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','font-family','trueloaded','3','','.b-products-listing'),(478195,'furniture-mobile','.b-products-listing .btn-preloader','font-family','$font-icons-1','3','','.b-products-listing'),(478196,'furniture-mobile','.b-products-listing .loader','font-family','$font-icons-1','4','','.b-products-listing'),(478197,'furniture-mobile','.b-products-listing .products-listing .btn-buy','font-family','trueloaded','3','','.b-products-listing'),(478198,'furniture-mobile','.w-blog-widget-post-share .pinterest-btn','font-family','$font-icons-1','3','','.w-blog-widget-post-share'),(478199,'furniture-mobile','.w-blog-widget-post-share .twitter-btn','font-family','$font-icons-1','3','','.w-blog-widget-post-share'),(478200,'furniture-mobile','.w-blog-widget-post-share .facebook-btn','font-family','$font-icons-1','3','','.w-blog-widget-post-share'),(478201,'furniture-mobile','.w-blog-widget-post-listing .post_name','font-family','$font-1','','','.w-blog-widget-post-listing'),(478202,'furniture-mobile','.p-blog-index .author','font-family','$font-1','','','.p-blog-index'),(478203,'furniture-mobile','.w-currencies .current','font-family','trueloaded','3','','.w-currencies'),(478204,'furniture-mobile','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(478205,'furniture-mobile','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(478206,'furniture-mobile','.p-wedding-registry-view h1','font-family','$font-icons-1','3','','.p-wedding-registry-view'),(478207,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(478208,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','font-family','$font-icons-1','3','','.w-checkout-contact-information'),(478209,'furniture-mobile','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(478210,'furniture-mobile','.w-menu .menu .menu-ico','font-family','trueloaded','3','','.w-menu'),(478211,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','font-family','$font-icons-1','3','','.w-menu'),(478212,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(478213,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(478214,'furniture-mobile','.p-blog-index .nav-previous a','font-family','$font-icons-1','3','','.p-blog-index'),(478215,'furniture-mobile','.b-form .eye-password','font-family','$font-icons-1','3','','.b-form'),(478216,'furniture-mobile','.heading-4 .right-text, h4 .right-text','font-family','$font-1','','',''),(478217,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-family','inherit','','',''),(478218,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-family','inherit','','','.b-h-inline'),(478219,'furniture-mobile','h1, .heading-1','font-family','$font-1','','',''),(478220,'furniture-mobile','.heading-settings .heading-4','font-family','trueloaded','3','','.heading-settings'),(478221,'furniture-mobile','.b-info .info strong','font-family','$font-1','','','.b-info'),(478222,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','font-family','$font-icons-1','3','','.b-form'),(478223,'furniture-mobile','.b-info .info','font-family','trueloaded','3','','.b-info'),(478224,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','font-family','$font-icons-1','3','','.w-checkout-contact-information'),(478225,'furniture-mobile','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(478226,'furniture-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(478227,'furniture-mobile','.w-tabs .tab-li.tab-quote a','font-family','trueloaded','3','','.w-tabs'),(478228,'furniture-mobile','.w-menu .menu .menu-ico','font-family','trueloaded','3','','.w-menu'),(478229,'furniture-mobile','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(478230,'furniture-mobile','.b-info .info','font-family','trueloaded','3','','.b-info'),(478231,'furniture-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','font-family','$font-icons-2','3','','.order-summary'),(478232,'furniture-mobile','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(478233,'furniture-mobile','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(478235,'furniture-mobile','.w-product-cross-sell .buy-all-checker','font-family','$font-icons-1','3','','.w-product-cross-sell'),(478236,'furniture-mobile','.w-catalog-listing-look .b2b','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(478237,'furniture-mobile','.w-catalog-listing-look .grid','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(478238,'furniture-mobile','.checkbox input:checked + span:before','font-family','$font-icons-1','','',''),(478240,'furniture-mobile','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-family','trueloaded','3','','.w-cart-listing'),(478241,'furniture-mobile','.w-cart-listing .points-redeem','font-family','$font-1','','','.w-cart-listing'),(478242,'furniture-mobile','.w-cart-listing .points-redeem','font-family','$font-icons-1','3','','.w-cart-listing'),(478243,'furniture-mobile','.w-cart-listing .remove-btn','font-family','$font-icons-1','3','','.w-cart-listing'),(478244,'furniture-mobile','.w-cart-give-away .ga_qty','font-family','$font-1','','','.w-cart-give-away'),(478245,'furniture-mobile','.w-cart-discount-coupon .btn-remove','font-family','trueloaded','3','','.w-cart-discount-coupon'),(478246,'furniture-mobile','.w-cart .multicart .title','font-family','$font-1','','','.w-cart'),(478247,'furniture-mobile','.w-cart .multicart .switch-cart','font-family','$font-icons-1','3','','.w-cart'),(478248,'furniture-mobile','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(478249,'furniture-mobile','.w-tabs .accordion-heading','font-family','$font-1','','','.w-tabs'),(478250,'furniture-mobile','.b-compare .clear_all','font-family','$font-icons-1','4','','.b-compare'),(478251,'furniture-mobile','.w-menu-slider .close','font-family','$font-icons-1','3','','.w-menu-slider'),(478253,'furniture-mobile','.order-summary .price-row.ot_bonus_points .title','font-family','$font-icons-2','3','','.order-summary'),(478254,'furniture-mobile','.p-wedding-registry-view h1','font-family','$font-icons-1','4','','.p-wedding-registry-view'),(478255,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(478256,'furniture-mobile','.w-checkout-credit-amount .btn-remove','font-family','trueloaded','3','','.w-checkout-credit-amount'),(478257,'furniture-mobile','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(478258,'furniture-mobile','.w-filters .view_more','font-family','$font-icons-1','4','','.w-filters'),(478259,'furniture-mobile','.w-filters span.close','font-family','$font-icons-1','3','','.w-filters'),(478260,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','font-family','$font-icons-1','','','.w-compare-box-item'),(478261,'furniture-mobile','.w-filters .head-filter-widget','font-family','$font-1','','','.w-filters'),(478262,'furniture-mobile','.w-quote .cart-box-link','font-family','trueloaded','3','','.w-quote'),(478263,'furniture-mobile','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(478264,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(478265,'furniture-mobile','.b-info .info strong','font-family','$font-1','','','.b-info'),(478268,'furniture-mobile','.p-blog-index .post-title','font-family','$font-1','','','.p-blog-index'),(478269,'furniture-mobile','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(478270,'furniture-mobile','.p-blog-index .nav-next a','font-family','$font-icons-1','3','','.p-blog-index'),(478271,'furniture-mobile','.heading-2, h2, .h-block h2','font-family','$font-1','','',''),(478272,'furniture-mobile','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(478273,'furniture-mobile','body','font-family','$font-1','','',''),(478274,'furniture-mobile','.p-wedding-registry-view h1','font-family','$font-icons-1','3','','.p-wedding-registry-view'),(478275,'furniture-mobile','.p-wedding-registry-view h1','font-family','$font-icons-1','4','','.p-wedding-registry-view'),(478276,'furniture-mobile','.w-tabs .tab-li.tab-sample a','font-family','trueloaded','3','','.w-tabs'),(478277,'furniture-mobile','.w-checkout-bonus-points .btn-remove','font-family','trueloaded','3','','.w-checkout-bonus-points'),(478278,'furniture-mobile','.b-data-table table.dataTable thead td','font-family','$font-1','','','.b-data-table'),(478279,'furniture-mobile','.p-blog-index .post-title','font-family','$font-1','','','.p-blog-index'),(478280,'furniture-mobile','.w-menu .menu .menu-ico','font-family','trueloaded','3','','.w-menu'),(478281,'furniture-mobile','.w-menu .hided.menu a.parent, .w-menu .hided.menu .no-link.parent','font-family','$font-icons-1','3','','.w-menu'),(478282,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(478283,'furniture-mobile','.w-menu .hided.menu a.parent.opened, .w-menu .hided.menu .no-link.parent.opened','font-family','$font-icons-1','3','','.w-menu'),(478284,'furniture-mobile','.btn-3','font-family','$font-1','','',''),(478285,'furniture-mobile','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(478286,'furniture-mobile','.heading-ordered-items .heading-4','font-family','trueloaded','3','','.heading-ordered-items'),(478289,'furniture-mobile','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(478290,'furniture-mobile','.p-blog-index .nav-next a','font-family','$font-icons-1','3','','.p-blog-index'),(478291,'furniture-mobile','.w-filters .mobileCollapse','font-family','$font-icons-1','4','','.w-filters'),(478292,'furniture-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-family','$font-icons-1','','','.w-filters'),(478293,'furniture-mobile','.p-blog-index .author','font-family','$font-1','','','.p-blog-index'),(478294,'furniture-mobile','.p-wedding-registry-view h1','font-family','$font-icons-1','3','','.p-wedding-registry-view'),(478295,'furniture-mobile','.b-product-images .media-popup .mp-close','font-family','$font-icons-1','3','','.b-product-images'),(478296,'furniture-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','font-family','$font-icons-1','3','','.b-menu-burger_icon'),(478297,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','font-family','$font-icons-1','4','','.b-menu-style-1'),(478298,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','font-family','$font-icons-1','3','','.b-menu-style-2'),(478299,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','font-family','$font-icons-1','3','','.b-menu-style-2'),(478300,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-family','$font-icons-1','3','','.b-menu-style-2'),(478301,'furniture-mobile','.batchPr .checkbox input:checked + span:before','font-family','$font-icons-1','','','.batchPr'),(478302,'furniture-mobile','.w-account-personal-catalog .list-switcher a','font-family','$font-1','','','.w-account-personal-catalog'),(478303,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-family','trueloaded','3','','.w-catalog-compare'),(478304,'furniture-mobile','.w-account .account-dropdown','font-family','$font-icons-1','3','','.w-account'),(478305,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','font-family','$font-icons-1','3','','.b-slick'),(478306,'furniture-mobile','.w-search .search-ico','font-family','$font-icons-2','2885,3','','.w-search'),(478307,'furniture-mobile','.w-search .search-ico.open','font-family','$font-icons-1','2885,3','','.w-search'),(478308,'furniture-mobile','.b-products-listing .add-to-personal-catalog','font-family','$font-icons-1','3','','.b-products-listing'),(478309,'furniture-mobile','.b-products-listing .del-from-personal-catalog','font-family','$font-icons-1','3','','.b-products-listing'),(478310,'furniture-mobile','.w-subscribers .btn-submit','font-family','$font-1','','','.w-subscribers'),(478311,'furniture-mobile','.w-quote .multicart .switch-cart','font-family','$font-icons-1','3','','.w-quote'),(478312,'furniture-mobile','.w-quote .multicart .title','font-family','$font-1','','','.w-quote'),(478313,'furniture-mobile','.w-cart .qty','font-family','$font-icons-1','4','','.w-cart'),(478314,'furniture-mobile','.w-product-personal-catalog-button .btn','font-family','$font-icons-1','3','','.w-product-personal-catalog-button'),(478315,'furniture-mobile','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','font-family','trueloaded','3','','.w-product-buttons'),(478316,'furniture-mobile','.w-product-bonus-points > div > div','font-family','$font-icons-1','3','','.w-product-bonus-points'),(478317,'furniture-mobile','.w-compare .remove','font-family','$font-icons-1','3','','.w-compare'),(478318,'furniture-mobile','.w-files-catalog-widgets-files-list .file','font-family','$font-icons-1','3','','.w-files-catalog-widgets-files-list'),(478319,'furniture-mobile','.w-sample .cart-box-link','font-family','trueloaded','3','','.w-sample'),(478320,'furniture-mobile','.w-sample .multicart .switch-cart','font-family','$font-icons-1','3','','.w-sample'),(478321,'furniture-mobile','.w-sample .multicart .title','font-family','$font-1','','','.w-sample'),(478322,'furniture-mobile','.w-sample .qty','font-family','$font-icons-1','4','','.w-sample'),(478323,'furniture-mobile','.w-cart-discount-coupon .title','font-family','$font-1','','','.w-cart-discount-coupon'),(478324,'furniture-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','trueloaded','3','','.w-cart-gift-certificate'),(478325,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','font-family','inherit','','','.b-products-listing'),(478326,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','font-family','$font-icons-1','3','','.b-pagination'),(478327,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','font-family','$font-icons-1','3','','.b-pagination'),(478328,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','font-family','$font-icons-1','4','','.w-account-personal-catalog'),(478329,'furniture-mobile','.w-product-collection .right-area .btn','font-family','$font-icons-2','3','','.w-product-collection'),(478330,'furniture-mobile','.w-product-collection .right-area .btn-2','font-family','$font-icons-2','3','','.w-product-collection'),(478331,'furniture-mobile','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','font-family','$font-icons-2','3','','.w-product-custom-bundle'),(478332,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent','font-family','$font-1','','','.w-delivery-location-location-list'),(478333,'furniture-mobile','.w-wedding-registry-widgets-delete-link .delete-registry','font-family','$font-icons-1','3','','.w-wedding-registry-widgets-delete-link'),(478334,'furniture-mobile','.w-wedding-registry-widgets-edit-link .edit-registry','font-family','$font-icons-1','3','','.w-wedding-registry-widgets-edit-link'),(478335,'furniture-mobile','.w-product-wedding-registry-button .btn','font-family','$font-1','','','.w-product-wedding-registry-button'),(478336,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination a.next, .w-wedding-registry-widgets-search-paging .pagination span.next, .w-wedding-registry-widgets-search-paging .pagination .next a, .w-wedding-registry-widgets-search-paging .pagination .next span','font-family','$font-icons-1','3','','.w-wedding-registry-widgets-search-paging'),(478337,'furniture-mobile','.w-support-system-filter .dd3-content .collapse_span','font-family','$font-icons-1','3','','.w-support-system-filter'),(478338,'furniture-mobile','.w-rma-returns-history .column .title','font-family','inherit','','','.w-rma-returns-history'),(478339,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .parent > .no-link','font-family','$font-icons-1','4','','.b-menu-style-1'),(478340,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .goto-button a','font-family','$font-icons-1','4','','.b-menu-style-1'),(478341,'furniture-mobile','.w-predefined-promotion .nextdiscount .heading','font-family','$font-icons-1','3','','.w-predefined-promotion'),(478342,'furniture-mobile','.w-supplier-purchase-supplier-products .active .select_item > div:before','font-family','$font-icons-1','','','.w-supplier-purchase-supplier-products'),(478343,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','font-family','$font-icons-1','','','.w-filters'),(478344,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','font-family','$font-icons-1','','','.w-filters'),(478345,'furniture-mobile','.order-summary .icon','font-family','$font-icons-1','3','','.order-summary'),(478346,'furniture-mobile','.w-search .extra','font-family','fontAwesome','3','','.w-search'),(478347,'furniture-mobile','.w-search .wrap .image','font-family','fontAwesome','3','','.w-search'),(478348,'furniture-mobile','.w-search .wrap .info-suggest .image','font-family','fontAwesome','3','','.w-search'),(478349,'furniture-mobile','.account-address-book .btn-edit','font-family','trueloaded','4','','.account-address-book'),(478350,'furniture-mobile','.account-address-book .leftMes div','font-family','$font-1','','','.account-address-book'),(478351,'furniture-mobile','.account-order-history .orders-table th','font-family','$font-1','','','.account-order-history'),(478352,'furniture-mobile','.account-order-history .view_link','font-family','trueloaded','4','','.account-order-history'),(478353,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','font-family','trueloaded','3','','.account-order-history-info'),(478354,'furniture-mobile','.account-index .account_page h4','font-family','trueloaded','3','','.account-index'),(478355,'furniture-mobile','.account-index .date_value strong','font-family','$font-1','','','.account-index'),(478356,'furniture-mobile','.account-index .date_value, .account-index .date_title','font-family','$font-1','','','.account-index'),(478357,'furniture-mobile','.account-index .leftMes div','font-family','$font-1','','','.account-index'),(478358,'furniture-mobile','.account-index .remove-btn','font-family','trueloaded','3','','.account-index'),(478359,'furniture-mobile','.account-index .topAccount > li > div','font-family','trueloaded','3','','.account-index'),(478360,'furniture-mobile','.account-index .view_history','font-family','trueloaded','3','','.account-index'),(478361,'furniture-mobile','.account-index .view_link','font-family','trueloaded','4','','.account-index'),(478362,'furniture-mobile','.account-index .view_link','font-family','$font-1','','','.account-index'),(478363,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-family','trueloaded','3','','.account-order-pay'),(478364,'furniture-mobile','.account-samples .orders-table th','font-family','$font-1','','','.account-samples'),(478365,'furniture-mobile','.account-samples .view_link','font-family','trueloaded','4','','.account-samples'),(478366,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-family','trueloaded','3','','.account-sample-info'),(478367,'furniture-mobile','.catalog-product-wrap .pn-direction','font-family','$font-1','','','.catalog-product-wrap'),(478368,'furniture-mobile','.catalog-product-wrap .pn-image','font-family','$font-icons-1','3','','.catalog-product-wrap'),(478369,'furniture-mobile','.shopping-cart-index .gift-code .heading-4','font-family','$font-icons-1','4','','.shopping-cart-index'),(478370,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','font-family','$font-1','','','.checkout-index-wrap'),(478371,'furniture-mobile','.checkout-index-wrap .order-ico','font-family','trueloaded','3','','.checkout-index-wrap'),(478372,'furniture-mobile','.checkout-index-wrap .pay-ico','font-family','trueloaded','3','','.checkout-index-wrap'),(478373,'furniture-mobile','.checkout-index-wrap .ship-ico','font-family','trueloaded','3','','.checkout-index-wrap'),(478374,'furniture-mobile','.checkout-order-confirmation .comment-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(478375,'furniture-mobile','.checkout-order-confirmation .discount-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(478376,'furniture-mobile','.checkout-order-confirmation .order-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(478377,'furniture-mobile','.checkout-order-confirmation .ship-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(478378,'furniture-mobile','.checkout-success-wrap .page-success .text-1','font-family','trueloaded','3','','.checkout-success-wrap'),(478379,'furniture-mobile','.checkout-success-wrap .page-success .text-1, .checkout-success-wrap .page-success .text-2, .checkout-success-wrap .page-success .text-3','font-family','$font-1','','','.checkout-success-wrap'),(478380,'furniture-mobile','.b-rating .glyphicon','font-family_important','important','','','.b-rating'),(478381,'furniture-mobile','.w-communication-new-topic td.date-purchased','font-size','14','','','.w-communication-new-topic'),(478382,'furniture-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-size','14','','','.w-communication-new-topic'),(478384,'furniture-mobile','.b-email .price','font-size','14','','','.b-email'),(478385,'furniture-mobile','.heading-4 .right-text, h4 .right-text','font-size','16','','',''),(478386,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(478387,'furniture-mobile','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(478388,'furniture-mobile','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(478389,'furniture-mobile','.p-account-trade-form .address-wrapp','font-size','14','','','.p-account-trade-form'),(478390,'furniture-mobile','.w-compare-box-item .cb_title','font-size','16','','','.w-compare-box-item'),(478391,'furniture-mobile','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(478392,'furniture-mobile','.p-reviews-info .review-info-reviewed_by, .review-info-date','font-size','14','','','.p-reviews-info'),(478393,'furniture-mobile','.p-wedding-registry-view h1','font-size','22','3','','.p-wedding-registry-view'),(478394,'furniture-mobile','.w-cart .multicart .count','font-size','14','','','.w-cart'),(478395,'furniture-mobile','.w-compare-box-item .cb_title','font-size','16','','','.w-compare-box-item'),(478396,'furniture-mobile','.b-form .middle-form label','font-size','16','','','.b-form'),(478397,'furniture-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(478398,'furniture-mobile','.p-quick-order-index .paginate_button.previous','font-size','20','3','','.p-quick-order-index'),(478399,'furniture-mobile','.b-email .qty','font-size','14','','','.b-email'),(478400,'furniture-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','font-size','13','','','.p-quick-order-index'),(478401,'furniture-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-size','14','','','.p-quick-order-index'),(478402,'furniture-mobile','.p-quick-order-index .paginate_button.next','font-size','20','3','','.p-quick-order-index'),(478403,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.next','font-size','0','','','.p-quick-order-index'),(478404,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.previous','font-size','0','','','.p-quick-order-index'),(478405,'furniture-mobile','.w-promotions .promo-item','font-size','24','','','.w-promotions'),(478406,'furniture-mobile','.w-text .customer-service','font-size','13','','','.w-text'),(478407,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','font-size','13','','','.w-promotions'),(478408,'furniture-mobile','.w-text .customer-service','font-size','21','3','','.w-text'),(478409,'furniture-mobile','.w-sale .percents','font-size','30','','','.w-sale'),(478410,'furniture-mobile','.w-sale .left-text-left','font-size','24','','','.w-sale'),(478411,'furniture-mobile','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(478412,'furniture-mobile','.p-blog-index .author','font-size','20','','','.p-blog-index'),(478413,'furniture-mobile','.p-blog-index .nav-previous a','font-size','40','3','','.p-blog-index'),(478414,'furniture-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(478415,'furniture-mobile','.w-cart-compare .attributes-label','font-size','14','','','.w-cart-compare'),(478416,'furniture-mobile','.w-account .my-acc-link','font-size','30','3','','.w-account'),(478417,'furniture-mobile','.p-wedding-registry-view h1','font-size','22','3','','.p-wedding-registry-view'),(478418,'furniture-mobile','.p-wedding-registry-view h1','font-size','22','4','','.p-wedding-registry-view'),(478419,'furniture-mobile','.w-personal-gift-status-bar .end-label','font-size','14','','','.w-personal-gift-status-bar'),(478420,'furniture-mobile','.p-sample-checkout-success .page-success .text-1','font-size','60','','','.p-sample-checkout-success'),(478421,'furniture-mobile','.p-sample-checkout-success .page-success .text-3','font-size','27','','','.p-sample-checkout-success'),(478422,'furniture-mobile','.p-sample-checkout-success .page-success .text-2','font-size','34','','','.p-sample-checkout-success'),(478423,'furniture-mobile','.p-reviews-info .reviews-info h1','font-size','30','','','.p-reviews-info'),(478424,'furniture-mobile','.p-reviews-info .review_by .rating-1, .p-reviews-info .review_by .rating-2, .p-reviews-info .review_by .rating-3, .p-reviews-info .review_by .rating-4, .p-reviews-info .review_by .rating-5','font-size','20','','','.p-reviews-info'),(478425,'furniture-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(478426,'furniture-mobile','.p-reviews-info .review-info-reviewed_by, .review-info-date','font-size','14','','','.p-reviews-info'),(478427,'furniture-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(478428,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(478429,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(478430,'furniture-mobile','.w-promotions .prom-multi-discount .heading','font-size','26','','','.w-promotions'),(478431,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(478432,'furniture-mobile','.p-blog-index .post-title','font-size','20','','','.p-blog-index'),(478433,'furniture-mobile','.p-blog-index .nav-previous a','font-size','40','3','','.p-blog-index'),(478434,'furniture-mobile','.p-blog-index .nav-next a','font-size','40','3','','.p-blog-index'),(478435,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(478436,'furniture-mobile','.p-blog-index .nav-previous a','font-size','40','3','','.p-blog-index'),(478437,'furniture-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(478438,'furniture-mobile','.testimonials .reviews-list span','font-size','22','','',''),(478439,'furniture-mobile','.testimonials .rating','font-size','22','','',''),(478440,'furniture-mobile','.testimonials .reviews-list .date','font-size','14','','',''),(478441,'furniture-mobile','.testimonials .date','font-size','14','','',''),(478442,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','font-size','18','','','.w-compare-box-item'),(478443,'furniture-mobile','.w-compare-box-item .cb_title','font-size','16','','','.w-compare-box-item'),(478444,'furniture-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','font-size','14','','','.w-promotions'),(478445,'furniture-mobile','.w-promotions .prom-multi-discount .promo-group','font-size','16','','','.w-promotions'),(478446,'furniture-mobile','.w-catalog-paging .next','font-size','20','3','','.w-catalog-paging'),(478447,'furniture-mobile','.w-promotions .nextdiscount .heading','font-size','26','','','.w-promotions'),(478448,'furniture-mobile','.w-promotions .nextdiscount .heading','font-size','18','3','','.w-promotions'),(478449,'furniture-mobile','.w-promotions .nextdiscount .promo-for-each','font-size','14','','','.w-promotions'),(478450,'furniture-mobile','.w-promotions .nextdiscount .item-holder .name','font-size','14','','','.w-promotions'),(478451,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.p-quick-order-index'),(478452,'furniture-mobile','.w-promotions .heading-3','font-size','48','','','.w-promotions'),(478453,'furniture-mobile','.w-promotions .promo-salemaker .discount','font-size','13','','','.w-promotions'),(478454,'furniture-mobile','.w-promotions .promo-salemaker .content a','font-size','14','','','.w-promotions'),(478455,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','font-size','16','','','.w-promotions'),(478456,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','font-size','13','','','.w-promotions'),(478457,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-name','font-size','16','','','.b-warehouses-popup'),(478458,'furniture-mobile','.w-promotions .promo-cart-discount .item a','font-size','14','','','.w-promotions'),(478459,'furniture-mobile','.b-warehouses-popup a.warehouses-popup-link','font-size','14','','','.b-warehouses-popup'),(478460,'furniture-mobile','.b-warehouses-popup .warehouses-popup .heading','font-size','18','','','.b-warehouses-popup'),(478461,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','font-size','14','','','.b-warehouses-popup'),(478462,'furniture-mobile','.b-preloader .preloader','font-size','40','3','','.b-preloader'),(478463,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-size','24','','','.p-account-subscription-historyinfo'),(478464,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','font-size','18','','','.w-compare-box-item'),(478465,'furniture-mobile','.w-chat .w-chat-box a','font-size','20','3','','.w-chat'),(478466,'furniture-mobile','.w-cart-compare .dropdown li','font-size','14','','','.w-cart-compare'),(478467,'furniture-mobile','.w-cart-compare .attributes-cell','font-size','14','','','.w-cart-compare'),(478468,'furniture-mobile','.p-account-trade-form .address-wrapp','font-size','14','','','.p-account-trade-form'),(478469,'furniture-mobile','.p-wedding-registry-view h1','font-size','22','4','','.p-wedding-registry-view'),(478470,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(478471,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(478472,'furniture-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','font-size','12','3','','.order-summary'),(478473,'furniture-mobile','.b-compare .compare-head','font-size','22','','','.b-compare'),(478474,'furniture-mobile','.b-bottom .closeable-heading','font-size','20','3','','.b-bottom'),(478475,'furniture-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(478476,'furniture-mobile','.b-messages .messBtnMenuDelete','font-size','22','3','','.b-messages'),(478477,'furniture-mobile','.b-messages .content-messages .heading-2','font-size','26','','','.b-messages'),(478478,'furniture-mobile','.b-messages span.starred::before','font-size','16','','','.b-messages'),(478479,'furniture-mobile','.b-messages .messBtnMenuStarred','font-size','22','3','','.b-messages'),(478480,'furniture-mobile','.b-messages .messBtnMenuUnread','font-size','22','3','','.b-messages'),(478481,'furniture-mobile','.b-messages .messMenuButton span','font-size','14','','','.b-messages'),(478482,'furniture-mobile','.b-messages .content_management_attach','font-size','14','','','.b-messages'),(478483,'furniture-mobile','.b-messages .content_management_attach span','font-size','16','','','.b-messages'),(478484,'furniture-mobile','.b-messages .content_management_attach button','font-size','14','','','.b-messages'),(478485,'furniture-mobile','.b-messages .select2-search-choice-close','font-size','11','3','','.b-messages'),(478486,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','font-size','14','','',''),(478487,'furniture-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(478488,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(478489,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(478490,'furniture-mobile','.p-reviews-info .review-info-reviewed_by, .review-info-date','font-size','14','','','.p-reviews-info'),(478491,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','font-size','14','','','.p-blog-index'),(478492,'furniture-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(478493,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-size','24','','','.p-account-subscription-historyinfo'),(478494,'furniture-mobile','.b-info .info strong','font-size','18','','','.b-info'),(478495,'furniture-mobile','.w-text .customer-service','font-size','21','3','','.w-text'),(478496,'furniture-mobile','.w-menu-slider .menu-ico','font-size','23','','','.w-menu-slider'),(478497,'furniture-mobile','.p-payer-order-confirmation .ship-ico','font-size','30','3','','.p-payer-order-confirmation'),(478498,'furniture-mobile','.p-payer-order-confirmation .pay-ico','font-size','30','3','','.p-payer-order-confirmation'),(478499,'furniture-mobile','.p-payer-order-confirmation .order-ico','font-size','36','3','','.p-payer-order-confirmation'),(478500,'furniture-mobile','.b-data-table table.dataTable thead td','font-size','16','','','.b-data-table'),(478501,'furniture-mobile','.p-payer-order-confirmation .discount-ico','font-size','30','3','','.p-payer-order-confirmation'),(478502,'furniture-mobile','.p-payer-order-pay .ship-ico','font-size','30','3','','.p-payer-order-pay'),(478503,'furniture-mobile','.p-payer-order-confirmation .comment-ico','font-size','30','3','','.p-payer-order-confirmation'),(478504,'furniture-mobile','.p-payer-order-pay .pay-ico','font-size','30','3','','.p-payer-order-pay'),(478505,'furniture-mobile','.p-payer-order-pay .order-ico','font-size','36','3','','.p-payer-order-pay'),(478506,'furniture-mobile','.p-payer-order-pay .comment-ico','font-size','30','3','','.p-payer-order-pay'),(478507,'furniture-mobile','.p-payer-order-pay .discount-ico','font-size','30','3','','.p-payer-order-pay'),(478508,'furniture-mobile','.w-checkout-terms .terms-box','font-size','13','','','.w-checkout-terms'),(478509,'furniture-mobile','.w-cart-cart-tabs .w-tabs .tab-a','font-size','12','2876','','.w-cart-cart-tabs'),(478510,'furniture-mobile','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(478511,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','font-size','14','','','.p-blog-index'),(478512,'furniture-mobile','.p-blog-index .author','font-size','20','','','.p-blog-index'),(478513,'furniture-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(478514,'furniture-mobile','.order-summary .price-box .title','font-size','15','','','.order-summary'),(478516,'furniture-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(478517,'furniture-mobile','.b-email .model','font-size','14','','','.b-email'),(478518,'furniture-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(478519,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','2876','','.p-quote-checkout-success'),(478520,'furniture-mobile','.b-page-name .page-name','font-size','20','','','.b-page-name'),(478521,'furniture-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(478522,'furniture-mobile','.p-account-trade-form .widget h3','font-size','24','','','.p-account-trade-form'),(478523,'furniture-mobile','.p-account-trade-form .address-wrapp','font-size','14','','','.p-account-trade-form'),(478524,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-size','24','','','.p-account-subscription-historyinfo'),(478525,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','font-size','16','','','.p-account-subscription-historyinfo'),(478526,'furniture-mobile','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(478527,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','font-size','10','','','.b-switch'),(478529,'furniture-mobile','.p-quick-order-index .value','font-size','20','','','.p-quick-order-index'),(478530,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-size','20','','','.w-upload-customer-id-upload-customer-id-form'),(478531,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-template','font-size','18','','','.w-upload-customer-id-upload-customer-id-form'),(478532,'furniture-mobile','.b-switch .bootstrap-switch','font-size','16','','','.b-switch'),(478533,'furniture-mobile','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(478534,'furniture-mobile','.b-info .info strong','font-size','18','','','.b-info'),(478535,'furniture-mobile','.b-email .qty','font-size','14','','','.b-email'),(478536,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(478537,'furniture-mobile','.w-coupons-and-vauchers-checkout .btn-remove','font-size','12','','','.w-coupons-and-vauchers-checkout'),(478538,'furniture-mobile','.w-checkout-bonus-points .btn-remove','font-size','12','','','.w-checkout-bonus-points'),(478539,'furniture-mobile','.w-menu-slider .menu-ico','font-size','23','','','.w-menu-slider'),(478540,'furniture-mobile','.w-sale .left-text-left','font-size','24','','','.w-sale'),(478541,'furniture-mobile','.w-sale .old','font-size','45','','','.w-sale'),(478542,'furniture-mobile','.w-sale .left-count-days','font-size','40','','','.w-sale'),(478543,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','font-size','7','','','.b-switch'),(478544,'furniture-mobile','.heading-settings .heading-4','font-size','28','3','','.heading-settings'),(478545,'furniture-mobile','.b-form .required-message','font-size','14','','','.b-form'),(478546,'furniture-mobile','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(478547,'furniture-mobile','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(478548,'furniture-mobile','.w-text .customer-service','font-size','21','3','','.w-text'),(478549,'furniture-mobile','.w-text .customer-service b','font-size','18','','','.w-text'),(478550,'furniture-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(478552,'furniture-mobile','.b-info-popup .info-popup div','font-size','14','','','.b-info-popup'),(478553,'furniture-mobile','.w-menu-style-1 .menu-ico','font-size','23','','','.w-menu-style-1'),(478554,'furniture-mobile','.w-menu-slider .menu-ico','font-size','23','','','.w-menu-slider'),(478555,'furniture-mobile','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-size','24','','','.w-multi-cart-cart-switcher'),(478556,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','2876','','.p-quote-checkout-success'),(478557,'furniture-mobile','.w-personal-gift-status-bar .inform','font-size','24','4','','.w-personal-gift-status-bar'),(478558,'furniture-mobile','.w-promo-code .holder','font-size','30','2906,3','','.w-promo-code'),(478559,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-size','24','','','.p-account-subscription-historyinfo'),(478560,'furniture-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(478561,'furniture-mobile','.p-blog-index .author','font-size','20','','','.p-blog-index'),(478562,'furniture-mobile','.p-blog-index .post-title','font-size','20','','','.p-blog-index'),(478563,'furniture-mobile','.p-reviews-info .review_by .rating-1, .p-reviews-info .review_by .rating-2, .p-reviews-info .review_by .rating-3, .p-reviews-info .review_by .rating-4, .p-reviews-info .review_by .rating-5','font-size','20','','','.p-reviews-info'),(478564,'furniture-mobile','.no-found','font-size','1.4','','',''),(478565,'furniture-mobile','.p-blog-index .author','font-size','20','','','.p-blog-index'),(478566,'furniture-mobile','.price','font-size','30','','',''),(478567,'furniture-mobile','.w-text .customer-service','font-size','13','','','.w-text'),(478568,'furniture-mobile','.w-sale .special-price','font-size','70','','','.w-sale'),(478569,'furniture-mobile','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(478570,'furniture-mobile','.w-sale .ends','font-size','26','','','.w-sale'),(478571,'furniture-mobile','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(478572,'furniture-mobile','.w-sale .special-price','font-size','70','','','.w-sale'),(478573,'furniture-mobile','.w-sale .name','font-size','20','','','.w-sale'),(478574,'furniture-mobile','.w-menu-slider .menu-ico','font-size','23','','','.w-menu-slider'),(478575,'furniture-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','font-size','21','','','.w-filters'),(478576,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','font-size','14','','','.b-switch'),(478577,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','font-size','14','','','.b-switch'),(478578,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(478579,'furniture-mobile','.w-catalog-paging .prev','font-size','20','3','','.w-catalog-paging'),(478580,'furniture-mobile','.w-personal-gift-status-bar .end-date','font-size','22','3','','.w-personal-gift-status-bar'),(478581,'furniture-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(478582,'furniture-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(478583,'furniture-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(478584,'furniture-mobile','.b-info .info','font-size','30','3','','.b-info'),(478586,'furniture-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(478587,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-size','18','','','.b-form'),(478588,'furniture-mobile','.w-compare-box-item .cb_title','font-size','16','','','.w-compare-box-item'),(478589,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','font-size','18','','','.w-compare-box-item'),(478590,'furniture-mobile','.w-reviews-content .rating','font-size','18','','','.w-reviews-content'),(478591,'furniture-mobile','.w-reviews-content .date','font-size','13','','','.w-reviews-content'),(478592,'furniture-mobile','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(478593,'furniture-mobile','.w-sale .badge','font-size','20','','','.w-sale'),(478594,'furniture-mobile','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(478595,'furniture-mobile','.w-reviews .date','font-size','13','','','.w-reviews'),(478596,'furniture-mobile','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(478597,'furniture-mobile','.w-search .button-search','font-size','23','3','','.w-search'),(478598,'furniture-mobile','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(478599,'furniture-mobile','h1','font-size','24','2885','',''),(478600,'furniture-mobile','.p-blog-index .comment-metadata','font-size','14','','','.p-blog-index'),(478601,'furniture-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(478602,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','font-size','16','','','.p-account-subscription-historyinfo'),(478603,'furniture-mobile','.p-blog-index .nav-next a','font-size','40','3','','.p-blog-index'),(478604,'furniture-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(478605,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(478606,'furniture-mobile','.p-reviews-info .review_by .rating-1, .p-reviews-info .review_by .rating-2, .p-reviews-info .review_by .rating-3, .p-reviews-info .review_by .rating-4, .p-reviews-info .review_by .rating-5','font-size','20','','','.p-reviews-info'),(478607,'furniture-mobile','.p-reviews-info .review-info-reviewed_by, .review-info-date','font-size','14','','','.p-reviews-info'),(478608,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(478609,'furniture-mobile','.bell-ico .heading-2','font-size','32','3','','.bell-ico'),(478610,'furniture-mobile','.w-personal-gift-status-bar .end-date','font-size','14','','','.w-personal-gift-status-bar'),(478611,'furniture-mobile','.w-cart-compare .price-cell','font-size','18','','','.w-cart-compare'),(478612,'furniture-mobile','.w-cart-compare .price-label','font-size','14','','','.w-cart-compare'),(478613,'furniture-mobile','.w-checkout-create-account .account-benefits','font-size','0.8','','','.w-checkout-create-account'),(478614,'furniture-mobile','.w-cart-listing .price','font-size','24','','','.w-cart-listing'),(478615,'furniture-mobile','.w-cart-compare .js-cart_totals_container b','font-size','16','','','.w-cart-compare'),(478616,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','2876','','.p-quote-checkout-success'),(478617,'furniture-mobile','.w-sale .badge','font-size','20','','','.w-sale'),(478618,'furniture-mobile','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(478619,'furniture-mobile','.w-sale .ends','font-size','26','','','.w-sale'),(478620,'furniture-mobile','.w-sale .special-price','font-size','70','','','.w-sale'),(478621,'furniture-mobile','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(478622,'furniture-mobile','.view-all .btn','font-size','0.8','4','',''),(478623,'furniture-mobile','.btn-1','font-size','16','','',''),(478624,'furniture-mobile','.b-form .privacy-row','font-size','16','','','.b-form'),(478625,'furniture-mobile','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(478626,'furniture-mobile','.b-email .name','font-size','14','','','.b-email'),(478627,'furniture-mobile','.w-sale .left-count-hours','font-size','40','','','.w-sale'),(478628,'furniture-mobile','.w-menu-style-1 .menu-ico','font-size','23','','','.w-menu-style-1'),(478629,'furniture-mobile','.w-menu-style-1 > ul','font-size','16','','','.w-menu-style-1'),(478630,'furniture-mobile','.w-tabs .tab-li.tab-quote a','font-size','29','3','','.w-tabs'),(478631,'furniture-mobile','.w-text .customer-service b','font-size','18','','','.w-text'),(478632,'furniture-mobile','.w-text .customer-service','font-size','21','3','','.w-text'),(478633,'furniture-mobile','.w-text .customer-service','font-size','13','','','.w-text'),(478634,'furniture-mobile','.w-tabs .tab-a','font-size','16','2885','','.w-tabs'),(478635,'furniture-mobile','.w-tabs .tab-a','font-size','24','','','.w-tabs'),(478636,'furniture-mobile','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(478637,'furniture-mobile','.w-search .search-input','font-size','14','','','.w-search'),(478638,'furniture-mobile','.w-sale .special-price','font-size','70','','','.w-sale'),(478639,'furniture-mobile','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(478640,'furniture-mobile','.btn-edit','font-size','0.8','3','',''),(478641,'furniture-mobile','.w-promo-code .holder','font-size','30','2906,3','','.w-promo-code'),(478642,'furniture-mobile','.w-tabs .tab-li.tab-wishlist a','font-size','25','3','','.w-tabs'),(478643,'furniture-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(478644,'furniture-mobile','.w-sale .left-text-right','font-size','24','','','.w-sale'),(478645,'furniture-mobile','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(478646,'furniture-mobile','.w-sale .ends','font-size','26','','','.w-sale'),(478647,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(478648,'furniture-mobile','.w-personal-gift-status-bar .start-label','font-size','14','','','.w-personal-gift-status-bar'),(478649,'furniture-mobile','.w-wedding-registry-widgets-products .remove','font-size','24','','','.w-wedding-registry-widgets-products'),(478650,'furniture-mobile','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(478651,'furniture-mobile','.p-reviews-info .reviews-info h1','font-size','30','','','.p-reviews-info'),(478652,'furniture-mobile','.heading-4 .edit, h4 .edit','font-size','16','','',''),(478653,'furniture-mobile','.p-blog-index .wp-widget li','font-size','8','3','','.p-blog-index'),(478654,'furniture-mobile','.heading-6, h6, .h-block h6','font-size','16','','',''),(478655,'furniture-mobile','.btn-2','font-size','24','','',''),(478656,'furniture-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(478657,'furniture-mobile','.w-cart-compare .cart-name a','font-size','17','','','.w-cart-compare'),(478658,'furniture-mobile','.w-cart-compare .delete-cart','font-size','12','','','.w-cart-compare'),(478659,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(478660,'furniture-mobile','.w-sale .special-price','font-size','70','','','.w-sale'),(478661,'furniture-mobile','.p-sample-checkout-success .page-success .text-2','font-size','30','2876','','.p-sample-checkout-success'),(478662,'furniture-mobile','.w-top-categories .categories h2','font-size','inherit','','','.w-top-categories'),(478663,'furniture-mobile','.out-stock','font-size','14','','',''),(478664,'furniture-mobile','.transit','font-size','14','','',''),(478665,'furniture-mobile','.in-stock','font-size','14','','',''),(478666,'furniture-mobile','.heading-3 .right-text, h3 .right-text','font-size','16','','',''),(478667,'furniture-mobile','.heading-3 .edit, h3 .edit','font-size','14','4','',''),(478668,'furniture-mobile','.heading-3 .edit, h3 .edit','font-size','16','','',''),(478669,'furniture-mobile','.heading-5, h5, .h-block h5','font-size','17','','',''),(478670,'furniture-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(478671,'furniture-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(478672,'furniture-mobile','.b-page-name .page-name','font-size','20','','','.b-page-name'),(478673,'furniture-mobile','.b-info .info','font-size','30','3','','.b-info'),(478674,'furniture-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(478675,'furniture-mobile','.w-cart-credit-amount .text','font-size','14','','','.w-cart-credit-amount'),(478676,'furniture-mobile','.w-cart-bonus-points .btn-remove','font-size','12','','','.w-cart-bonus-points'),(478677,'furniture-mobile','.w-cart-discount-coupon .text','font-size','14','','','.w-cart-discount-coupon'),(478678,'furniture-mobile','.order-summary .price-box .price-row.total','font-size','22','','','.order-summary'),(478679,'furniture-mobile','.order-summary .price','font-size','18','','','.order-summary'),(478680,'furniture-mobile','.savings-ico .heading-2','font-size','32','3','','.savings-ico'),(478681,'furniture-mobile','.w-cart-bonus-points .text','font-size','14','','','.w-cart-bonus-points'),(478682,'furniture-mobile','.b-email .model','font-size','14','','','.b-email'),(478683,'furniture-mobile','.b-email .name','font-size','14','','','.b-email'),(478684,'furniture-mobile','.p-blog-index .nav-next a','font-size','40','3','','.p-blog-index'),(478685,'furniture-mobile','.w-sale .badge','font-size','20','','','.w-sale'),(478686,'furniture-mobile','.w-sale .left-count-hours','font-size','40','','','.w-sale'),(478687,'furniture-mobile','.w-sale .old','font-size','45','','','.w-sale'),(478688,'furniture-mobile','.w-sale .ends','font-size','26','','','.w-sale'),(478689,'furniture-mobile','.w-text .customer-service b','font-size','18','','','.w-text'),(478690,'furniture-mobile','.testimonials .heading-3','font-size','37','3','',''),(478691,'furniture-mobile','.js-stock','font-size','14','','',''),(478692,'furniture-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(478693,'furniture-mobile','.w-checkout-shipping-choice span','font-size','14','2906','','.w-checkout-shipping-choice'),(478694,'furniture-mobile','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(478695,'furniture-mobile','.w-product-reviews .reviews-list .date','font-size','14','','','.w-product-reviews'),(478696,'furniture-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(478697,'furniture-mobile','.b-email .model','font-size','14','','','.b-email'),(478698,'furniture-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(478699,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(478700,'furniture-mobile','.w-sale .badge','font-size','20','','','.w-sale'),(478701,'furniture-mobile','.heading-4, h4, .h-block h4','font-size','18','','',''),(478702,'furniture-mobile','.w-sale .name','font-size','20','','','.w-sale'),(478703,'furniture-mobile','.w-sale .percents','font-size','30','','','.w-sale'),(478704,'furniture-mobile','.w-menu-slider .menu-ico','font-size','23','','','.w-menu-slider'),(478705,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(478706,'furniture-mobile','.b-email .price','font-size','14','','','.b-email'),(478707,'furniture-mobile','.heading-saved-lists .heading-4','font-size','28','3','','.heading-saved-lists'),(478708,'furniture-mobile','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(478709,'furniture-mobile','.b-email .name','font-size','14','','','.b-email'),(478710,'furniture-mobile','.btn','font-size','16','','',''),(478711,'furniture-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(478712,'furniture-mobile','.b-email .price','font-size','14','','','.b-email'),(478713,'furniture-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(478714,'furniture-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(478715,'furniture-mobile','.heading-ordered-items .heading-4','font-size','28','3','','.heading-ordered-items'),(478716,'furniture-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(478717,'furniture-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(478718,'furniture-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(478719,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(478720,'furniture-mobile','.b-email .qty','font-size','14','','','.b-email'),(478721,'furniture-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(478722,'furniture-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(478723,'furniture-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(478724,'furniture-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(478725,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(478726,'furniture-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(478727,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(478728,'furniture-mobile','.w-text .customer-service','font-size','13','','','.w-text'),(478729,'furniture-mobile','.b-info .info','font-size','30','3','','.b-info'),(478730,'furniture-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(478731,'furniture-mobile','.p-wedding-registry-view h1','font-size','22','4','','.p-wedding-registry-view'),(478732,'furniture-mobile','.p-wedding-registry-view h1','font-size','22','3','','.p-wedding-registry-view'),(478733,'furniture-mobile','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(478734,'furniture-mobile','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(478735,'furniture-mobile','.w-promo-code .holder','font-size','30','2906,3','','.w-promo-code'),(478736,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(478737,'furniture-mobile','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(478738,'furniture-mobile','.message.success','font-size','30','3','',''),(478739,'furniture-mobile','.w-reviews .heading-3','font-size','37','3','','.w-reviews'),(478740,'furniture-mobile','.b-sub-totals .historyTotal table td','font-size','18','','','.b-sub-totals'),(478741,'furniture-mobile','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(478743,'furniture-mobile','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(478745,'furniture-mobile','.b-info .info','font-size','30','3','','.b-info'),(478746,'furniture-mobile','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(478747,'furniture-mobile','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(478748,'furniture-mobile','.w-sale .old','font-size','45','','','.w-sale'),(478749,'furniture-mobile','.w-sale .left-text-left','font-size','24','','','.w-sale'),(478750,'furniture-mobile','.w-sale .left-text-right','font-size','24','','','.w-sale'),(478751,'furniture-mobile','.w-sale .left-count-days','font-size','40','','','.w-sale'),(478752,'furniture-mobile','.w-sale .left-count-hours','font-size','40','','','.w-sale'),(478753,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','2876','','.p-quote-checkout-success'),(478754,'furniture-mobile','.w-text .customer-service b','font-size','18','','','.w-text'),(478755,'furniture-mobile','.b-info .info strong','font-size','18','','','.b-info'),(478756,'furniture-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','font-size','18','','','.b-form'),(478757,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','font-size','18','','','.w-compare-box-item'),(478758,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','font-size','18','','','.w-compare-box-item'),(478759,'furniture-mobile','.p-reviews-info .review-info-reviewed_by, .review-info-date','font-size','14','','','.p-reviews-info'),(478760,'furniture-mobile','.w-menu-style-1 > ul','font-size','16','','','.w-menu-style-1'),(478761,'furniture-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(478762,'furniture-mobile','.p-blog-index .nav-next a','font-size','40','3','','.p-blog-index'),(478763,'furniture-mobile','.p-account-trade-form .widget h3','font-size','24','','','.p-account-trade-form'),(478764,'furniture-mobile','.w-sale .left-count-hours','font-size','40','','','.w-sale'),(478765,'furniture-mobile','.w-social-links a','font-size','30','2876','','.w-social-links'),(478766,'furniture-mobile','.p-reviews-info .review_by .rating-1, .p-reviews-info .review_by .rating-2, .p-reviews-info .review_by .rating-3, .p-reviews-info .review_by .rating-4, .p-reviews-info .review_by .rating-5','font-size','20','','','.p-reviews-info'),(478767,'furniture-mobile','.p-reviews-info .reviews-info h1','font-size','30','','','.p-reviews-info'),(478768,'furniture-mobile','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(478769,'furniture-mobile','.b-info .info strong','font-size','18','','','.b-info'),(478770,'furniture-mobile','.b-email .name','font-size','14','','','.b-email'),(478771,'furniture-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(478772,'furniture-mobile','.p-quick-order-index .stock','font-size','12','','','.p-quick-order-index'),(478773,'furniture-mobile','.b-email .price','font-size','14','','','.b-email'),(478774,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','2876','','.p-quote-checkout-success'),(478775,'furniture-mobile','.w-cart-compare .js-cart_totals_container','font-size','14','','','.w-cart-compare'),(478776,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','2876','','.p-quote-checkout-success'),(478777,'furniture-mobile','.w-sale .name','font-size','20','','','.w-sale'),(478778,'furniture-mobile','.w-sale .left-count-days','font-size','40','','','.w-sale'),(478779,'furniture-mobile','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(478780,'furniture-mobile','.b-bottom .alert-message','font-size','18','','','.b-bottom'),(478781,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(478782,'furniture-mobile','.w-cart-compare .product .name a','font-size','14','','','.w-cart-compare'),(478783,'furniture-mobile','.p-reviews-info .review_by .rating-1, .p-reviews-info .review_by .rating-2, .p-reviews-info .review_by .rating-3, .p-reviews-info .review_by .rating-4, .p-reviews-info .review_by .rating-5','font-size','20','','','.p-reviews-info'),(478784,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(478785,'furniture-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(478786,'furniture-mobile','.w-checkout-credit-amount .btn-remove','font-size','12','','','.w-checkout-credit-amount'),(478787,'furniture-mobile','.w-sale .old','font-size','45','','','.w-sale'),(478788,'furniture-mobile','.w-sale .left-text-left','font-size','24','','','.w-sale'),(478789,'furniture-mobile','.w-languages .current','font-size','26','3','','.w-languages'),(478790,'furniture-mobile','.b-info-popup .info-popup','font-size','20','3','','.b-info-popup'),(478791,'furniture-mobile','.b-info .info','font-size','30','3','','.b-info'),(478792,'furniture-mobile','.p-blog-index .post-title','font-size','20','','','.p-blog-index'),(478793,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','font-size','14','','','.p-blog-index'),(478794,'furniture-mobile','.p-blog-index .wp-widget li','font-size','8','3','','.p-blog-index'),(478796,'furniture-mobile','.b-email .name','font-size','14','','','.b-email'),(478797,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(478798,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','2876','','.p-quote-checkout-success'),(478799,'furniture-mobile','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(478801,'furniture-mobile','.b-info .info strong','font-size','18','','','.b-info'),(478802,'furniture-mobile','.b-email .price','font-size','14','','','.b-email'),(478803,'furniture-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(478804,'furniture-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(478805,'furniture-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(478806,'furniture-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(478807,'furniture-mobile','.b-email .model','font-size','14','','','.b-email'),(478808,'furniture-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(478809,'furniture-mobile','.order-summary .price-row.ot_coupon .title','font-size','18','3','','.order-summary'),(478810,'furniture-mobile','.w-cart-shipping-estimator .address-item','font-size','14','','','.w-cart-shipping-estimator'),(478811,'furniture-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','font-size','20','','','.b-products-listing'),(478812,'furniture-mobile','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-size','20','','','.b-products-listing'),(478813,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','font-size','16','','','.p-account-subscription-historyinfo'),(478814,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block','font-size','14','','','.b-products-listing'),(478815,'furniture-mobile','.p-account-trade-form .address-wrapp','font-size','14','','','.p-account-trade-form'),(478816,'furniture-mobile','.w-cart-credit-amount .btn-remove','font-size','12','','','.w-cart-credit-amount'),(478817,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(478818,'furniture-mobile','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(478819,'furniture-mobile','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(478820,'furniture-mobile','.w-sale .left-count-days','font-size','40','','','.w-sale'),(478821,'furniture-mobile','.w-sale .name','font-size','20','','','.w-sale'),(478822,'furniture-mobile','.w-text .customer-service b','font-size','18','','','.w-text'),(478823,'furniture-mobile','.p-quick-order-index .in-stock, .p-quick-order-index .out-stock','font-size','12','','','.p-quick-order-index'),(478824,'furniture-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(478825,'furniture-mobile','.b-email .name','font-size','14','','','.b-email'),(478826,'furniture-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(478827,'furniture-mobile','.b-form .middle-form .middle-rating span','font-size','26','','','.b-form'),(478828,'furniture-mobile','.b-info .info','font-size','30','3','','.b-info'),(478829,'furniture-mobile','.w-menu-style-1 > ul','font-size','16','','','.w-menu-style-1'),(478830,'furniture-mobile','.w-menu-style-1 .menu-ico','font-size','23','','','.w-menu-style-1'),(478831,'furniture-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(478832,'furniture-mobile','.p-wedding-registry-view h1','font-size','22','4','','.p-wedding-registry-view'),(478833,'furniture-mobile','.p-wedding-registry-view h1','font-size','22','3','','.p-wedding-registry-view'),(478835,'furniture-mobile','.w-product-customers-activity .customers-activity','font-size','16','','','.w-product-customers-activity'),(478836,'furniture-mobile','.w-product-available-in-warehouses .heading','font-size','18','','','.w-product-available-in-warehouses'),(478837,'furniture-mobile','.b-bottom .confirm-popup .confirm-text','font-size','20','','','.b-bottom'),(478838,'furniture-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(478839,'furniture-mobile','.b-email .qty','font-size','14','','','.b-email'),(478840,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','font-size','16','','','.p-account-subscription-historyinfo'),(478841,'furniture-mobile','.b-page-name .page-name','font-size','20','','','.b-page-name'),(478842,'furniture-mobile','.w-text .customer-service','font-size','13','','','.w-text'),(478843,'furniture-mobile','.w-text .customer-service','font-size','21','3','','.w-text'),(478844,'furniture-mobile','.w-text .customer-service b','font-size','18','','','.w-text'),(478845,'furniture-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(478846,'furniture-mobile','.p-reviews-info .reviews-info h1','font-size','30','','','.p-reviews-info'),(478847,'furniture-mobile','.p-sample-checkout-success .page-success .text-1','font-size','80','3','','.p-sample-checkout-success'),(478848,'furniture-mobile','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-size','22','','','.order-summary'),(478849,'furniture-mobile','.w-account-last-order .last-order-days','font-size','12','','','.w-account-last-order'),(478850,'furniture-mobile','.w-sale .old','font-size','45','','','.w-sale'),(478851,'furniture-mobile','.w-sale .left-count-hours','font-size','40','','','.w-sale'),(478852,'furniture-mobile','.w-compare-box-item .cb_title','font-size','16','','','.w-compare-box-item'),(478853,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(478854,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(478855,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(478856,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(478858,'furniture-mobile','.w-menu-style-1 .menu-ico','font-size','23','','','.w-menu-style-1'),(478859,'furniture-mobile','.w-menu-horizontal .menu-ico','font-size','23','','','.w-menu-horizontal'),(478860,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(478861,'furniture-mobile','.w-compare-box-item .cb_title','font-size','16','','','.w-compare-box-item'),(478862,'furniture-mobile','.w-promo-code .holder','font-size','30','2906,3','','.w-promo-code'),(478863,'furniture-mobile','.w-categories h2.name','font-size','18','','','.w-categories'),(478864,'furniture-mobile','.w-cart-checkout-btn a','font-size','17','2876','','.w-cart-checkout-btn'),(478865,'furniture-mobile','.w-sale .left-text-right','font-size','24','','','.w-sale'),(478866,'furniture-mobile','.w-sale .percents','font-size','30','','','.w-sale'),(478867,'furniture-mobile','.w-sale .left-text-left','font-size','24','','','.w-sale'),(478868,'furniture-mobile','.p-account-trade-form .widget h3','font-size','24','','','.p-account-trade-form'),(478869,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-size','24','','','.p-account-subscription-historyinfo'),(478870,'furniture-mobile','.price .old','font-size','0.6','','',''),(478871,'furniture-mobile','.w-cart-compare .product-actions .dropdown-toggle','font-size','18','3','','.w-cart-compare'),(478872,'furniture-mobile','.p-wedding-registry-view h1','font-size','22','4','','.p-wedding-registry-view'),(478873,'furniture-mobile','.p-wedding-registry-view h1','font-size','22','3','','.p-wedding-registry-view'),(478874,'furniture-mobile','.w-social-links a','font-size','20','','','.w-social-links'),(478875,'furniture-mobile','.p-blog-index .nav-previous a','font-size','40','3','','.p-blog-index'),(478876,'furniture-mobile','.p-account-trade-form .widget h3','font-size','24','','','.p-account-trade-form'),(478877,'furniture-mobile','.p-blog-index .wp-widget li','font-size','8','3','','.p-blog-index'),(478878,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-size','24','','','.p-account-subscription-historyinfo'),(478879,'furniture-mobile','.b-fancybox .fancybox-close','font-size','26','','','.b-fancybox'),(478880,'furniture-mobile','.p-blog-index .comment-metadata','font-size','14','','','.p-blog-index'),(478881,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','font-size','14','','','.p-blog-index'),(478882,'furniture-mobile','.b-select-suggest .select2-search-choice-close','font-size','1','','','.b-select-suggest'),(478883,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-size','100','','','.b-select-suggest'),(478884,'furniture-mobile','.b-select-suggest .select2-search input','font-size','1','','','.b-select-suggest'),(478885,'furniture-mobile','.w-sale .percents','font-size','30','','','.w-sale'),(478886,'furniture-mobile','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(478887,'furniture-mobile','.w-menu-style-1 > ul','font-size','16','','','.w-menu-style-1'),(478888,'furniture-mobile','.p-sample-checkout-success .page-success .text-1','font-size','40','2876','','.p-sample-checkout-success'),(478889,'furniture-mobile','.w-cart-compare .product-actions','font-size','12','','','.w-cart-compare'),(478890,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','font-size','16','','','.p-account-subscription-historyinfo'),(478891,'furniture-mobile','.p-blog-index .author','font-size','20','','','.p-blog-index'),(478892,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','font-size','14','','','.p-blog-index'),(478893,'furniture-mobile','.p-blog-index .post-title','font-size','20','','','.p-blog-index'),(478894,'furniture-mobile','.w-menu-style-1 .menu-ico','font-size','23','','','.w-menu-style-1'),(478895,'furniture-mobile','.p-blog-index .post-title','font-size','20','','','.p-blog-index'),(478896,'furniture-mobile','.p-account-trade-form .widget h3','font-size','24','','','.p-account-trade-form'),(478897,'furniture-mobile','.b-sub-totals .historyTotal table tr:last-child td','font-size','24','','','.b-sub-totals'),(478898,'furniture-mobile','.w-menu-style-1 > ul','font-size','16','','','.w-menu-style-1'),(478899,'furniture-mobile','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(478900,'furniture-mobile','.w-sale .name','font-size','20','','','.w-sale'),(478901,'furniture-mobile','.w-personal-gift-status-bar .inform','font-size','14','','','.w-personal-gift-status-bar'),(478902,'furniture-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(478903,'furniture-mobile','.w-quote-products .empty','font-size','24','','','.w-quote-products'),(478904,'furniture-mobile','.b-bottom .footerTitle','font-size','24','','','.b-bottom'),(478905,'furniture-mobile','.w-account-addresses-list .addsess-suggestion-item','font-size','14','','','.w-account-addresses-list'),(478906,'furniture-mobile','.w-communication-post .communication-post-date','font-size','14','','','.w-communication-post'),(478907,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.b-data-table'),(478908,'furniture-mobile','.w-communication-post .communication-post-attach','font-size','14','','','.w-communication-post'),(478909,'furniture-mobile','.b-products-listing .products-listing .bonusPoints','font-size','13','','','.b-products-listing'),(478910,'furniture-mobile','.b-products-listing .products-listing .model','font-size','14','','','.b-products-listing'),(478911,'furniture-mobile','.b-products-listing .btn-preloader','font-size','24','3','','.b-products-listing'),(478912,'furniture-mobile','.b-products-listing .loader','font-size','30','4','','.b-products-listing'),(478913,'furniture-mobile','.b-products-listing .promos-info .promo-name','font-size','14','','','.b-products-listing'),(478914,'furniture-mobile','.b-products-listing .wedding-registry-count','font-size','14','','','.b-products-listing'),(478915,'furniture-mobile','.w-blog-widget-tag-cloud a','font-size','12','','','.w-blog-widget-tag-cloud'),(478916,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_content a','font-size','18','','','.w-blog-widget-related-posts-by-category'),(478917,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','font-size','18','3','','.w-blog-widget-related-posts'),(478918,'furniture-mobile','.w-blog-widget-related-posts .post_content a','font-size','20','','','.w-blog-widget-related-posts'),(478919,'furniture-mobile','.w-blog-widget-post-title h1','font-size','24','2876','','.w-blog-widget-post-title'),(478920,'furniture-mobile','.w-blog-widget-post-title ','font-size','24','2885','','.w-blog-widget-post-title'),(478921,'furniture-mobile','.w-blog-widget-post-title h1','font-size','32','','','.w-blog-widget-post-title'),(478922,'furniture-mobile','.w-blog-widget-post-share .mailto','font-size','26','3','','.w-blog-widget-post-share'),(478923,'furniture-mobile','.w-blog-widget-post-share .pinterest-btn','font-size','22','3','','.w-blog-widget-post-share'),(478924,'furniture-mobile','.w-blog-widget-post-share .printto','font-size','26','3','','.w-blog-widget-post-share'),(478925,'furniture-mobile','.w-blog-widget-post-share .twitter-btn','font-size','22','3','','.w-blog-widget-post-share'),(478926,'furniture-mobile','.w-blog-widget-post-share .facebook-btn','font-size','22','3','','.w-blog-widget-post-share'),(478927,'furniture-mobile','.w-blog-widget-post-listing .post_name a','font-size','22','','','.w-blog-widget-post-listing'),(478928,'furniture-mobile','.w-blog-widget-post-listing .post_date','font-size','14','','','.w-blog-widget-post-listing'),(478929,'furniture-mobile','.w-blog-widget-post-linked-products .heading-2','font-size','22','','','.w-blog-widget-post-linked-products'),(478930,'furniture-mobile','.w-blog-widget-post-date ','font-size','14','','','.w-blog-widget-post-date'),(478931,'furniture-mobile','.w-blog-widget-most-popular-posts a','font-size','14','','','.w-blog-widget-most-popular-posts'),(478932,'furniture-mobile','.w-blog-widget-post-comments-count span','font-size','14','3','','.w-blog-widget-post-comments-count'),(478933,'furniture-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','font-size','15','','','.w-blog-widget-most-popular-posts'),(478934,'furniture-mobile','.w-blog-widget-categories-list a','font-size','14','','','.w-blog-widget-categories-list'),(478935,'furniture-mobile','.w-currencies .current','font-size','26','3','','.w-currencies'),(478936,'furniture-mobile','.w-quote .cart-box-link','font-size','30','3','','.w-quote'),(478937,'furniture-mobile','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(478938,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','2876','','.p-quote-checkout-success'),(478939,'furniture-mobile','.p-reviews-info .review-info-reviewed_by, .review-info-date','font-size','14','','','.p-reviews-info'),(478940,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','2876','','.p-quote-checkout-success'),(478941,'furniture-mobile','.p-wedding-registry-view h1','font-size','22','3','','.p-wedding-registry-view'),(478942,'furniture-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(478943,'furniture-mobile','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(478944,'furniture-mobile','.b-form .cart-popup .price','font-size','18','','','.b-form'),(478945,'furniture-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(478946,'furniture-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(478947,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','40','2876','','.p-quote-checkout-success'),(478948,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','font-size','16','','','.p-account-subscription-historyinfo'),(478949,'furniture-mobile','.w-text .customer-service','font-size','21','3','','.w-text'),(478950,'furniture-mobile','.w-top-categories h2.name','font-size','18','','','.w-top-categories'),(478951,'furniture-mobile','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(478952,'furniture-mobile','.w-sale .badge','font-size','20','','','.w-sale'),(478953,'furniture-mobile','.w-sale .left-count-days','font-size','40','','','.w-sale'),(478954,'furniture-mobile','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(478955,'furniture-mobile','.w-product-reviews .reviews-list span','font-size','22','','','.w-product-reviews'),(478956,'furniture-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(478957,'furniture-mobile','.p-reviews-info .review_by .rating-1, .p-reviews-info .review_by .rating-2, .p-reviews-info .review_by .rating-3, .p-reviews-info .review_by .rating-4, .p-reviews-info .review_by .rating-5','font-size','20','','','.p-reviews-info'),(478958,'furniture-mobile','.p-reviews-info .reviews-info h1','font-size','30','','','.p-reviews-info'),(478959,'furniture-mobile','.p-blog-index .nav-previous a','font-size','40','3','','.p-blog-index'),(478960,'furniture-mobile','.p-blog-index .post-title','font-size','20','','','.p-blog-index'),(478961,'furniture-mobile','.p-blog-index .wp-widget li','font-size','8','3','','.p-blog-index'),(478962,'furniture-mobile','.p-account-update .main-text','font-size','16','','','.p-account-update'),(478963,'furniture-mobile','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(478964,'furniture-mobile','.w-taxable .bootstrap-switch .bootstrap-switch-label','font-size','0','','','.w-taxable'),(478965,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-size','inherit','','',''),(478966,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-size','inherit','','','.b-h-inline'),(478967,'furniture-mobile','h1, .heading-1','font-size','36','','',''),(478968,'furniture-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(478969,'furniture-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(478970,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','font-size','31','','','.w-communication-new-topic'),(478971,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','font-size','31','','','.w-communication-new-topic'),(478972,'furniture-mobile','.b-page-name .page-name','font-size','20','','','.b-page-name'),(478974,'furniture-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(478975,'furniture-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(478976,'furniture-mobile','.b-email .price','font-size','14','','','.b-email'),(478977,'furniture-mobile','.b-email .heading-name','font-size','14','','','.b-email'),(478978,'furniture-mobile','.b-bottom .popup-heading','font-size','16','','','.b-bottom'),(478979,'furniture-mobile','.w-promo-code .holder','font-size','30','2906,3','','.w-promo-code'),(478980,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','2876','','.p-quote-checkout-success'),(478981,'furniture-mobile','.w-sale .left-text-right','font-size','24','','','.w-sale'),(478982,'furniture-mobile','.w-sale .special-price','font-size','70','','','.w-sale'),(478983,'furniture-mobile','.w-sale .ends','font-size','26','','','.w-sale'),(478984,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(478985,'furniture-mobile','.w-tabs .tab-li.tab-sample a','font-size','29','3','','.w-tabs'),(478986,'furniture-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(478987,'furniture-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(478988,'furniture-mobile','.b-email .model','font-size','14','','','.b-email'),(478989,'furniture-mobile','.w-cart-compare .atr-col','font-size','20','3','','.w-cart-compare'),(478990,'furniture-mobile','.w-quote .cart-box-link','font-size','25','2885,3','','.w-quote'),(478991,'furniture-mobile','.w-sale .left-text-right','font-size','24','','','.w-sale'),(478992,'furniture-mobile','.w-sale .left-count-hours','font-size','40','','','.w-sale'),(478993,'furniture-mobile','.w-sale .left-text-left','font-size','24','','','.w-sale'),(478994,'furniture-mobile','.w-sale .ends','font-size','26','','','.w-sale'),(478995,'furniture-mobile','.w-sale .left-count-days','font-size','40','','','.w-sale'),(478996,'furniture-mobile','.w-sale .badge','font-size','20','','','.w-sale'),(478997,'furniture-mobile','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(478998,'furniture-mobile','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(478999,'furniture-mobile','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(479000,'furniture-mobile','.w-sale .name','font-size','20','','','.w-sale'),(479001,'furniture-mobile','.w-sale .percents','font-size','30','','','.w-sale'),(479002,'furniture-mobile','.w-sale .old','font-size','45','','','.w-sale'),(479003,'furniture-mobile','.b-email .qty','font-size','14','','','.b-email'),(479004,'furniture-mobile','.b-email .model','font-size','14','','','.b-email'),(479005,'furniture-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(479006,'furniture-mobile','.checkbox input:checked + span:before','font-size','18','','',''),(479007,'furniture-mobile','.p-quick-order-index .dataTables_info','font-size','14','','','.p-quick-order-index'),(479008,'furniture-mobile','.w-cart-listing .item .gift-wrap label','font-size','14','','','.w-cart-listing'),(479009,'furniture-mobile','.w-cart-listing .item .attributes','font-size','14','','','.w-cart-listing'),(479010,'furniture-mobile','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-size','12','','','.w-cart-listing'),(479011,'furniture-mobile','.w-cart-listing .points-earn','font-size','12','','','.w-cart-listing'),(479012,'furniture-mobile','.w-cart-listing .points-redeem','font-size','14','','','.w-cart-listing'),(479013,'furniture-mobile','.w-cart-listing .points-redeem','font-size','14','3','','.w-cart-listing'),(479014,'furniture-mobile','.w-cart-listing .remove-btn','font-size','28','','','.w-cart-listing'),(479015,'furniture-mobile','.w-cart-listing .remove-btn span','font-size','16','2885','','.w-cart-listing'),(479016,'furniture-mobile','.w-cart-give-away .ga_name','font-size','16','','','.w-cart-give-away'),(479017,'furniture-mobile','.w-cart-give-away .ga_qty','font-size','20','','','.w-cart-give-away'),(479018,'furniture-mobile','.w-cart-give-away .ga_qty','font-size','17','2876','','.w-cart-give-away'),(479019,'furniture-mobile','.w-cart-discount-coupon .btn-remove','font-size','12','','','.w-cart-discount-coupon'),(479020,'furniture-mobile','.w-cart .cart-box-link','font-size','30','3','','.w-cart'),(479021,'furniture-mobile','.w-cart .buttons .btn','font-size','14','','','.w-cart'),(479022,'furniture-mobile','.w-cart .sub-total-row','font-size','18','','','.w-cart'),(479023,'furniture-mobile','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(479024,'furniture-mobile','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(479025,'furniture-mobile','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(479026,'furniture-mobile','.b-upload-file .snapshot','font-size','18','','','.b-upload-file'),(479027,'furniture-mobile','.b-fancybox .fancybox-nav span','font-size','34','','','.b-fancybox'),(479028,'furniture-mobile','.b-email-editor .price','font-size','18','','','.b-email-editor'),(479029,'furniture-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(479030,'furniture-mobile','.w-promo-code .holder','font-size','30','2906,3','','.w-promo-code'),(479031,'furniture-mobile','.w-text .customer-service','font-size','13','','','.w-text'),(479032,'furniture-mobile','.w-tabs .accordion-heading','font-size','24','','','.w-tabs'),(479033,'furniture-mobile','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(479034,'furniture-mobile','.w-tabs .tab-li.tab-cart a','font-size','29','3','','.w-tabs'),(479035,'furniture-mobile','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(479036,'furniture-mobile','.b-compare .clear_all','font-size','16','4','','.b-compare'),(479037,'furniture-mobile','.w-sale .left-text-right','font-size','24','','','.w-sale'),(479038,'furniture-mobile','.w-sale .percents','font-size','30','','','.w-sale'),(479039,'furniture-mobile','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(479040,'furniture-mobile','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(479041,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(479042,'furniture-mobile','.w-cart .cart-total','font-size','1.2','','','.w-cart'),(479043,'furniture-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(479044,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(479045,'furniture-mobile','.p-blog-index .author','font-size','20','','','.p-blog-index'),(479046,'furniture-mobile','.p-account-trade-form .address-wrapp','font-size','14','','','.p-account-trade-form'),(479047,'furniture-mobile','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(479048,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(479049,'furniture-mobile','.p-account-trade-form .widget h3','font-size','24','','','.p-account-trade-form'),(479050,'furniture-mobile','.p-blog-index .comment-metadata','font-size','14','','','.p-blog-index'),(479051,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','font-size','14','','','.p-blog-index'),(479052,'furniture-mobile','.p-wedding-registry-view h1','font-size','22','4','','.p-wedding-registry-view'),(479053,'furniture-mobile','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(479054,'furniture-mobile','.w-checkout-create-account .account-benefits strong','font-size','18','3','','.w-checkout-create-account'),(479055,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','font-size','18','','','.w-compare-box-item'),(479056,'furniture-mobile','.p-blog-index .comment-metadata','font-size','14','','','.p-blog-index'),(479057,'furniture-mobile','.w-menu-style-1 .menu-ico','font-size','23','','','.w-menu-style-1'),(479058,'furniture-mobile','.w-filters .head-filter-widget > span','font-size','18','2885','','.w-filters'),(479059,'furniture-mobile','.w-filters .head-filter-widget','font-size','21','2890','','.w-filters'),(479060,'furniture-mobile','.w-filters .filter-box-head','font-size','20','','','.w-filters'),(479061,'furniture-mobile','.w-filters .view_more','font-size','16','4','','.w-filters'),(479062,'furniture-mobile','.p-reviews-info .reviews-info h1','font-size','30','','','.p-reviews-info'),(479063,'furniture-mobile','.p-blog-index .wp-widget li','font-size','8','3','','.p-blog-index'),(479064,'furniture-mobile','.w-chat .w-chat-box a','font-size','30','2885,3','','.w-chat'),(479065,'furniture-mobile','.p-blog-index .comment-metadata','font-size','14','','','.p-blog-index'),(479066,'furniture-mobile','.b-products-listing .products-listing .btn-buy','font-size','20','3','','.b-products-listing'),(479067,'furniture-mobile','.b-bottom .pop-up-close','font-size','25','','','.b-bottom'),(479068,'furniture-mobile','.w-filters .head-filter-widget','font-size','24','','','.w-filters'),(479069,'furniture-mobile','.order-summary .price-row.ot_bonus_points .title','font-size','12','3','','.order-summary'),(479070,'furniture-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(479071,'furniture-mobile','.b-form #payment_method .title','font-size','16','','','.b-form'),(479072,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','font-size','30','2876','','.p-quote-checkout-success'),(479073,'furniture-mobile','.b-email .heading-model','font-size','14','','','.b-email'),(479074,'furniture-mobile','.b-email .heading-qty','font-size','14','','','.b-email'),(479075,'furniture-mobile','.b-page-name .page-name','font-size','20','','','.b-page-name'),(479076,'furniture-mobile','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(479077,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(479078,'furniture-mobile','.blogsidebar .heading-title','font-size','18','','','.blogsidebar'),(479079,'furniture-mobile','.heading-3, h3, .h-block h3','font-size','20','','',''),(479080,'furniture-mobile','.heading-2, h2, .h-block h2','font-size','30','','',''),(479081,'furniture-mobile','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(479082,'furniture-mobile','.w-menu-style-1 > ul','font-size','16','','','.w-menu-style-1'),(479083,'furniture-mobile','.w-menu-slider .menu-ico','font-size','23','','','.w-menu-slider'),(479084,'furniture-mobile','.btn-3','font-size','24','','',''),(479085,'furniture-mobile','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(479086,'furniture-mobile','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(479087,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','font-size','20','','','.b-switch'),(479088,'furniture-mobile','.b-page-name .page-name','font-size','20','','','.b-page-name'),(479089,'furniture-mobile','.b-info .info strong','font-size','18','','','.b-info'),(479090,'furniture-mobile','.b-form .middle-form label.slim','font-size','14','','','.b-form'),(479091,'furniture-mobile','.b-email .heading-price','font-size','14','','','.b-email'),(479092,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','font-size','1','','','.b-select-suggest'),(479093,'furniture-mobile','.b-email .qty','font-size','14','','','.b-email'),(479094,'furniture-mobile','.b-email .totals-label','font-size','18','','','.b-email'),(479095,'furniture-mobile','.p-blog-index .comment-metadata','font-size','14','','','.p-blog-index'),(479096,'furniture-mobile','.p-blog-index .nav-next a','font-size','40','3','','.p-blog-index'),(479097,'furniture-mobile','.w-filters .mobileCollapse','font-size','20','4','','.w-filters'),(479098,'furniture-mobile','.p-account-trade-form .address-wrapp','font-size','14','','','.p-account-trade-form'),(479099,'furniture-mobile','.p-blog-index .nav-next a','font-size','40','3','','.p-blog-index'),(479100,'furniture-mobile','.p-blog-index .wp-widget li','font-size','8','3','','.p-blog-index'),(479101,'furniture-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-size','21','','','.w-filters'),(479102,'furniture-mobile','.p-blog-index .nav-previous a','font-size','40','3','','.p-blog-index'),(479103,'furniture-mobile','.b-product-images .media-popup .mp-close','font-size','50','','','.b-product-images'),(479104,'furniture-mobile','.b-product-images .media-popup .slick-dots li','font-size','30','','','.b-product-images'),(479105,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','font-size','50','3','','.b-product-images'),(479106,'furniture-mobile','.w-product-name h1','font-size','36','','','.w-product-name'),(479107,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(479108,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(479109,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(479110,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(479111,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(479112,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(479113,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(479114,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(479115,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(479116,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev63_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(479117,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','font-size','14','','','.b-menu-style-2'),(479118,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','font-size','14','','','.b-menu-style-2'),(479119,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','font-size','26','','','.b-menu-style-2'),(479120,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','font-size','20','3','','.b-menu-style-2'),(479121,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-size','20','3','','.b-menu-style-2'),(479122,'furniture-mobile','.b-trade-approval .middle-form label','font-size','16','','','.b-trade-approval'),(479123,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','font-size','14','','','.b-trade-approval'),(479124,'furniture-mobile','.batchPr .w-batch-products .products-listing .name a','font-size','16','','','.batchPr'),(479125,'furniture-mobile','.batchPr .w-batch-products .products-listing .price','font-size','16','','','.batchPr'),(479126,'furniture-mobile','.batchPr .btn-batch-remove','font-size','17','3','','.batchPr'),(479127,'furniture-mobile','.batchPr .batchSelect .checkbox','font-size','18','','','.batchPr'),(479128,'furniture-mobile','.batchPr .batchSelect','font-size','12','','','.batchPr'),(479129,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .name a, .batchPr .w-batch-selected-products .products-listing .price','font-size','14','','','.batchPr'),(479130,'furniture-mobile','.batchPr .checkbox input:checked + span:before','font-size','18','','','.batchPr'),(479131,'furniture-mobile','.batchPr .batch-selected-products-empty','font-size','20','','','.batchPr'),(479132,'furniture-mobile','.batchPr .checkbox input:not(checked) + span:before','font-size','32','','','.batchPr'),(479133,'furniture-mobile','.batchPr .batch-selected-products-total','font-size','20','','','.batchPr'),(479134,'furniture-mobile','.batchPr .btn-batch-remove','font-size','0','','','.batchPr'),(479135,'furniture-mobile','.w-account-personal-catalog .list-switcher a','font-size','20','','','.w-account-personal-catalog'),(479136,'furniture-mobile','.w-catalog-compare .checkbox input:checked + span:before','font-size','24','','','.w-catalog-compare'),(479137,'furniture-mobile','.w-catalog-compare .model','font-size','14','','','.w-catalog-compare'),(479138,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-size','26','3','','.w-catalog-compare'),(479139,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','font-size','0','','','.w-catalog-compare'),(479140,'furniture-mobile','.w-catalog-compare .item .compare','font-size','0','','','.w-catalog-compare'),(479141,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','font-size','15','','','.w-catalog-compare'),(479142,'furniture-mobile','.w-catalog-compare .name','font-size','12','','','.w-catalog-compare'),(479143,'furniture-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-size','40','','','.w-delivery-day'),(479144,'furniture-mobile','.w-delivery-day .ends','font-size','26','','','.w-delivery-day'),(479145,'furniture-mobile','.w-delivery-day .left-text-left','font-size','24','','','.w-delivery-day'),(479146,'furniture-mobile','.w-delivery-day .left-text-right','font-size','24','','','.w-delivery-day'),(479147,'furniture-mobile','.w-delivery-day .title','font-size','18','','','.w-delivery-day'),(479148,'furniture-mobile','.w-cart .cart-box-link','font-size','18','','','.w-cart'),(479149,'furniture-mobile','.w-account .account-dropdown','font-size','28','3','','.w-account'),(479150,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','font-size','20','','','.b-menu-style-1'),(479151,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','font-size','16','2890','','.b-menu-style-1'),(479152,'furniture-mobile','.tripleBanner .w-html_box > div:nth-child(1)','font-size','16','','','.tripleBanner'),(479153,'furniture-mobile','.tripleBanner .w-html_box > div:nth-child(2)','font-size','16','','','.tripleBanner'),(479154,'furniture-mobile','.b-products-listing .products-listing .name a','font-size','18','','','.b-products-listing'),(479155,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','0','','','.b-slick'),(479156,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','20','3','','.b-slick'),(479157,'furniture-mobile','.w-account .my-acc-link','font-size','25','2885,3','','.w-account'),(479158,'furniture-mobile','.w-cart .cart-box-link','font-size','25','2885,3','','.w-cart'),(479159,'furniture-mobile','.w-search .search-ico','font-size','25','2885,3','','.w-search'),(479160,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > a, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','font-size','24','','','.b-menu-style-3'),(479161,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','font-size','44','2885,3','','.b-menu-style-3'),(479162,'furniture-mobile','.b-products-listing .add-to-personal-catalog','font-size','22','3','','.b-products-listing'),(479163,'furniture-mobile','.b-products-listing .del-from-personal-catalog','font-size','20','3','','.b-products-listing'),(479164,'furniture-mobile','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','font-size','16','','','.b-products-listing'),(479165,'furniture-mobile','.w-cart-listing .headings .head','font-size','14','','','.w-cart-listing'),(479166,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','font-size','22','3','','.b-products-listing'),(479167,'furniture-mobile','.LeftCategories .w-menu-simple ul li a','font-size','18','','','.LeftCategories'),(479168,'furniture-mobile','.w-subscribers .btn-submit','font-size','16','','','.w-subscribers'),(479169,'furniture-mobile','.w-quote .buttons .btn','font-size','14','','','.w-quote'),(479170,'furniture-mobile','.w-quote .cart-box-link','font-size','18','','','.w-quote'),(479171,'furniture-mobile','.w-quote .cart-total','font-size','1.2','','','.w-quote'),(479172,'furniture-mobile','.w-quote .multicart .count','font-size','14','','','.w-quote'),(479173,'furniture-mobile','.w-quote .qty','font-size','0.6','4','','.w-quote'),(479174,'furniture-mobile','.w-quote .sub-total-row','font-size','18','','','.w-quote'),(479175,'furniture-mobile','.w-cart .qty','font-size','0.7','4','','.w-cart'),(479176,'furniture-mobile','.w-product-personal-catalog-button .btn','font-size','16','','','.w-product-personal-catalog-button'),(479177,'furniture-mobile','.w-product-personal-catalog-button .btn','font-size','20','3','','.w-product-personal-catalog-button'),(479178,'furniture-mobile','.b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(479179,'furniture-mobile','.b-quantity .qty-box .smaller','font-size','31','','','.b-quantity'),(479180,'furniture-mobile','.rating, .ratingCounts','font-size','14','','',''),(479181,'furniture-mobile','.w-product-sale-ends .ends','font-size','24','','','.w-product-sale-ends'),(479182,'furniture-mobile','.w-product-sale-ends .left-count-days','font-size','30','','','.w-product-sale-ends'),(479183,'furniture-mobile','.w-product-sale-ends .left-count-hours','font-size','30','','','.w-product-sale-ends'),(479184,'furniture-mobile','.w-product-sale-ends .left-text-left','font-size','24','','','.w-product-sale-ends'),(479185,'furniture-mobile','.w-product-sale-ends .left-text-right','font-size','24','','','.w-product-sale-ends'),(479186,'furniture-mobile','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(479187,'furniture-mobile','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(479188,'furniture-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(479189,'furniture-mobile','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(479190,'furniture-mobile','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(479191,'furniture-mobile','.w-product-quantity .qty-box .smaller, .w-product-quantity .qty-box .bigger','font-size','40','','','.w-product-quantity'),(479192,'furniture-mobile','.w-product-quantity .qty-input input[type=\'text\']','font-size','18','','','.w-product-quantity'),(479193,'furniture-mobile','.w-product-bonus-points > div','font-size','14','','','.w-product-bonus-points'),(479194,'furniture-mobile','.warrantyProduct .title','font-size','18','','','.warrantyProduct'),(479195,'furniture-mobile','.warrantyProduct .seeDetails a','font-size','14','','','.warrantyProduct'),(479196,'furniture-mobile','.w-compare .price','font-size','18','','','.w-compare'),(479197,'furniture-mobile','.w-compare .name','font-size','14','','','.w-compare'),(479198,'furniture-mobile','.w-compare .clear-compare-button','font-size','14','','','.w-compare'),(479199,'furniture-mobile','.w-files-catalog-widgets-files-catalog .name','font-size','16','','','.w-files-catalog-widgets-files-catalog'),(479200,'furniture-mobile','.w-files-catalog-widgets-files-list .name','font-size','18','','','.w-files-catalog-widgets-files-list'),(479201,'furniture-mobile','.w-sample .buttons .btn','font-size','14','','','.w-sample'),(479202,'furniture-mobile','.w-sample .cart-box-link','font-size','18','','','.w-sample'),(479203,'furniture-mobile','.w-sample .cart-box-link','font-size','30','3','','.w-sample'),(479204,'furniture-mobile','.w-sample .cart-total','font-size','1.2','','','.w-sample'),(479205,'furniture-mobile','.w-sample .multicart .count','font-size','14','','','.w-sample'),(479206,'furniture-mobile','.w-sample .qty','font-size','0.7','4','','.w-sample'),(479207,'furniture-mobile','.w-sample .sub-total-row','font-size','18','','','.w-sample'),(479208,'furniture-mobile','.w-sample .cart-box-link','font-size','25','2885,3','','.w-sample'),(479209,'furniture-mobile','.w-filters-simple .integrate-price-holder','font-size','20','','','.w-filters-simple'),(479210,'furniture-mobile','.w-filters-simple .integrate-price','font-size','30','','','.w-filters-simple'),(479211,'furniture-mobile','.w-cart-discount-coupon .title','font-size','20','','','.w-cart-discount-coupon'),(479212,'furniture-mobile','.w-cart-sub-total .title','font-size','24','','','.w-cart-sub-total'),(479213,'furniture-mobile','.w-cart-sub-total .price','font-size','30','','','.w-cart-sub-total'),(479214,'furniture-mobile','.w-cart-bonus-points .title','font-size','20','','','.w-cart-bonus-points'),(479215,'furniture-mobile','.shipping-ico .heading-3','font-size','24','','','.shipping-ico'),(479216,'furniture-mobile','.w-cart-up-sell .products-listing .price','font-size','18','','','.w-cart-up-sell'),(479217,'furniture-mobile','.w-cart-up-sell .products-listing .name a','font-size','16','','','.w-cart-up-sell'),(479218,'furniture-mobile','.w-cart-gift-certificate .heading-4','font-size','20','','','.w-cart-gift-certificate'),(479219,'furniture-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(479220,'furniture-mobile','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(479221,'furniture-mobile','.w-cart-order-reference .heading-4','font-size','20','','','.w-cart-order-reference'),(479222,'furniture-mobile','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(479223,'furniture-mobile','.w-product-bundle .bundle_price .old','font-size','0.8','','','.w-product-bundle'),(479224,'furniture-mobile','.w-product-in-bundles .bundle_price .old','font-size','0.6','','','.w-product-in-bundles'),(479225,'furniture-mobile','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(479226,'furniture-mobile','.w-product-quantity-discounts .count','font-size','18','','','.w-product-quantity-discounts'),(479227,'furniture-mobile','.w-account-address-book .add_item a','font-size','50','3','','.w-account-address-book'),(479228,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','font-size','inherit','','','.b-products-listing'),(479229,'furniture-mobile','.b-pagination .pagination .next a, .b-pagination .pagination .next span','font-size','0','','','.b-pagination'),(479230,'furniture-mobile','.b-pagination .pagination .prev a, .b-pagination .pagination .prev span','font-size','0','','','.b-pagination'),(479231,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','font-size','20','3','','.b-pagination'),(479232,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','font-size','20','3','','.b-pagination'),(479233,'furniture-mobile','.w-catalog-compare .price','font-size','20','','','.w-catalog-compare'),(479234,'furniture-mobile','.w-catalog-compare .out-stock','font-size','12','','','.w-catalog-compare'),(479235,'furniture-mobile','.w-product-quantity-discounts .item .price','font-size','24','2890','','.w-product-quantity-discounts'),(479236,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .remove','font-size','0','','','.w-product-properties-filters-widgets-chosen-filters'),(479237,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .remove','font-size','20','3','','.w-product-properties-filters-widgets-chosen-filters'),(479238,'furniture-mobile','.w-product-multi-inventory .radio-attributes > span','font-size','18','','','.w-product-multi-inventory'),(479239,'furniture-mobile','.w-product-sale-ends .left-text-right, .w-product-sale-ends .left-text-left','font-size','18','2890','','.w-product-sale-ends'),(479240,'furniture-mobile','.w-product-sale-ends .left-count-days, .w-product-sale-ends .left-count-hours','font-size','24','2890','','.w-product-sale-ends'),(479241,'furniture-mobile','.w-product-sale-ends .ends','font-size','21','2890','','.w-product-sale-ends'),(479242,'furniture-mobile','.heading-2, h2, .h-block h2','font-size','21','2885','',''),(479243,'furniture-mobile','.heading-3, h3, .h-block h3','font-size','19','2885','',''),(479244,'furniture-mobile','.heading-4, h4, .h-block h4','font-size','17','2885','',''),(479245,'furniture-mobile','.w-product-name h1','font-size','24','2885','','.w-product-name'),(479246,'furniture-mobile','.b-products-listing .products-listing.list-rows .stock','font-size','14','','','.b-products-listing'),(479247,'furniture-mobile','.b-products-listing .products-listing.list-b2b .stock','font-size','14','','','.b-products-listing'),(479248,'furniture-mobile','.b-products-listing .products-listing .radio-attributes > span','font-size','18','','','.b-products-listing'),(479249,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','font-size','14','','','.b-products-listing'),(479250,'furniture-mobile','.w-product-collection .stock > span','font-size','14','','','.w-product-collection'),(479251,'furniture-mobile','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(479252,'furniture-mobile','.w-product-collection .right-area .special','font-size','36','','','.w-product-collection'),(479253,'furniture-mobile','.w-product-collection .right-area .separate-text, .w-product-collection .right-area .separate','font-size','16','','','.w-product-collection'),(479254,'furniture-mobile','.w-product-collection .together','font-size','16','','','.w-product-collection'),(479255,'furniture-mobile','.w-product-collection .right-area .btn','font-size','24','','','.w-product-collection'),(479256,'furniture-mobile','.price .special-promote','font-size','16','','',''),(479257,'furniture-mobile','.w-breadcrumb .catalog-breadcrumb','font-size','14','2876','','.w-breadcrumb'),(479258,'furniture-mobile','.w-product-attributes .radio-attributes > span','font-size','18','','','.w-product-attributes'),(479259,'furniture-mobile','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(479260,'furniture-mobile','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(479261,'furniture-mobile','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(479262,'furniture-mobile','.w-product-properties li','font-size','14','','','.w-product-properties'),(479263,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','font-size','0','','','.w-questionnaire-widgets-questionnaire'),(479264,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','font-size','30','3','','.w-questionnaire-widgets-questionnaire'),(479265,'furniture-mobile','.w-product-groups .radioBoxHead','font-size','16','','','.w-product-groups'),(479266,'furniture-mobile','.w-product-groups .val1','font-size','16','','','.w-product-groups'),(479267,'furniture-mobile','.w-product-groups .val2','font-size','16','','','.w-product-groups'),(479268,'furniture-mobile','.w-product-groups .radioBox label .containerBlock img + .name + .val2','font-size','16','','','.w-product-groups'),(479269,'furniture-mobile','.b-products-listing .mix-attributes .attribute-qty-block > span','font-size','13','','','.b-products-listing'),(479270,'furniture-mobile','.w-product-custom-bundle .heading-3','font-size','16','','','.w-product-custom-bundle'),(479271,'furniture-mobile','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(479272,'furniture-mobile','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(479273,'furniture-mobile','.w-product-custom-bundle .right-area .separate-text','font-size','16','','','.w-product-custom-bundle'),(479274,'furniture-mobile','.w-product-custom-bundle .right-area .separate','font-size','36','','','.w-product-custom-bundle'),(479275,'furniture-mobile','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','font-size','24','','','.w-product-custom-bundle'),(479276,'furniture-mobile','.w-delivery-location-top-location-list .deliveryName','font-size','18','','','.w-delivery-location-top-location-list'),(479277,'furniture-mobile','.w-delivery-location-location-list .deliveryName','font-size','18','','','.w-delivery-location-location-list'),(479278,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(479279,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent a','font-size','24','','','.w-delivery-location-location-list'),(479280,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent a','font-size','18','2885','','.w-delivery-location-location-list'),(479281,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','font-size','14','2885','','.w-delivery-location-location-list'),(479282,'furniture-mobile','.w-delivery-location-featured-list .deliveryName','font-size','18','','','.w-delivery-location-featured-list'),(479283,'furniture-mobile','.w-wedding-registry-widgets-search-form .closeable-heading','font-size','20','','','.w-wedding-registry-widgets-search-form'),(479284,'furniture-mobile','.btn-2','font-size','16','2876','',''),(479285,'furniture-mobile','.w-sale-category .badge','font-size','20','','','.w-sale-category'),(479286,'furniture-mobile','.w-sale-category .ends','font-size','26','','','.w-sale-category'),(479287,'furniture-mobile','.w-sale-category .left-count-days','font-size','40','','','.w-sale-category'),(479288,'furniture-mobile','.w-sale-category .left-count-hours','font-size','40','','','.w-sale-category'),(479289,'furniture-mobile','.w-sale-category .left-text-left','font-size','24','','','.w-sale-category'),(479290,'furniture-mobile','.w-sale-category .left-text-right','font-size','24','','','.w-sale-category'),(479291,'furniture-mobile','.w-sale-category .name','font-size','20','','','.w-sale-category'),(479292,'furniture-mobile','.w-sale-category .old','font-size','45','','','.w-sale-category'),(479293,'furniture-mobile','.w-sale-category .percents','font-size','30','','','.w-sale-category'),(479294,'furniture-mobile','.w-sale-category .special-price','font-size','70','','','.w-sale-category'),(479295,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-name','font-size','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(479296,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-name','font-size','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(479297,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description + div','font-size','18','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(479298,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description + div','font-size','18','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(479299,'furniture-mobile','.w-delivery-location-list-by-page .name','font-size','18','','','.w-delivery-location-list-by-page'),(479300,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','font-size','14','','','.w-product-properties-icons'),(479301,'furniture-mobile','.w-delivery-location-cross-pages .name','font-size','18','','','.w-delivery-location-cross-pages'),(479302,'furniture-mobile','.w-cart-credit-amount .amount-title','font-size','20','','','.w-cart-credit-amount'),(479303,'furniture-mobile','.w-catalog-delivery-locations .name','font-size','18','','','.w-catalog-delivery-locations'),(479304,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next a, .w-wedding-registry-widgets-search-paging .pagination .next span','font-size','0','','','.w-wedding-registry-widgets-search-paging'),(479305,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','font-size','0','','','.w-wedding-registry-widgets-search-paging'),(479306,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination a.next, .w-wedding-registry-widgets-search-paging .pagination span.next, .w-wedding-registry-widgets-search-paging .pagination .next a, .w-wedding-registry-widgets-search-paging .pagination .next span','font-size','20','3','','.w-wedding-registry-widgets-search-paging'),(479307,'furniture-mobile','.w-wedding-registry-widgets-manage-names > span','font-size','24','2890','','.w-wedding-registry-widgets-manage-names'),(479308,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','font-size','16','','','.w-product-bonus-points'),(479309,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','font-size','14','2906','','.w-product-bonus-points'),(479310,'furniture-mobile','.w-product-designer-designer .grnamebox .title-sortable','font-size','16','','','.w-product-designer-designer'),(479311,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','font-size','14','','','.w-product-designer-designer'),(479312,'furniture-mobile','.w-press-reviews-widgets-press-reviews .date','font-size','13','','','.w-press-reviews-widgets-press-reviews'),(479313,'furniture-mobile','.w-press-reviews-widgets-press-reviews .heading-3','font-size','30','','','.w-press-reviews-widgets-press-reviews'),(479314,'furniture-mobile','.w-press-reviews-widgets-press-reviews .rating','font-size','18','','','.w-press-reviews-widgets-press-reviews'),(479315,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .product-name','font-size','20','','','.w-press-reviews-widgets-press-reviews-list'),(479316,'furniture-mobile','.b-products-listing .productGroup label a','font-size','12','','','.b-products-listing'),(479317,'furniture-mobile','.w-support-system-filter .filter_cats.level-0 > li > a','font-size','18','','','.w-support-system-filter'),(479318,'furniture-mobile','.w-communication-post .btn.refresh','font-size','30','','','.w-communication-post'),(479319,'furniture-mobile','.w-rma-returns-history .btn','font-size','13','','','.w-rma-returns-history'),(479320,'furniture-mobile','.w-rma-returns-history .column .title','font-size','14','','','.w-rma-returns-history'),(479321,'furniture-mobile','.w-rma-returns-history .fromTo label >span','font-size','12','','','.w-rma-returns-history'),(479322,'furniture-mobile','.w-rma-returns-history .icons .excel','font-size','20','3','','.w-rma-returns-history'),(479323,'furniture-mobile','.w-rma-returns-history .icons .print','font-size','20','3','','.w-rma-returns-history'),(479324,'furniture-mobile','.w-rma-returns-history .icons a','font-size','0','','','.w-rma-returns-history'),(479325,'furniture-mobile','.w-rma-returns-history .sorting_1','font-size','13','','','.w-rma-returns-history'),(479326,'furniture-mobile','.w-rma-returns-history .tableTitle','font-size','18','','','.w-rma-returns-history'),(479327,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','font-size','16','','','.b-menu-style-1'),(479328,'furniture-mobile','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(479329,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','font-size','13','','','.b-products-listing'),(479330,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-name','font-size','20','','','.w-catalog-pages-category-pages-list'),(479331,'furniture-mobile','.w-predefined-promotion .heading-3','font-size','48','','','.w-predefined-promotion'),(479332,'furniture-mobile','.w-predefined-promotion .nextdiscount .heading','font-size','18','3','','.w-predefined-promotion'),(479333,'furniture-mobile','.w-predefined-promotion .nextdiscount .heading','font-size','26','','','.w-predefined-promotion'),(479334,'furniture-mobile','.w-predefined-promotion .nextdiscount .item-holder .name','font-size','14','','','.w-predefined-promotion'),(479335,'furniture-mobile','.w-predefined-promotion .nextdiscount .promo-for-each','font-size','14','','','.w-predefined-promotion'),(479336,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .heading','font-size','26','','','.w-predefined-promotion'),(479337,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-group','font-size','16','','','.w-predefined-promotion'),(479338,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','font-size','14','','','.w-predefined-promotion'),(479339,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','font-size','13','','','.w-predefined-promotion'),(479340,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .item a','font-size','14','','','.w-predefined-promotion'),(479341,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','font-size','13','','','.w-predefined-promotion');
INSERT INTO `themes_styles` VALUES (479342,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','font-size','16','','','.w-predefined-promotion'),(479343,'furniture-mobile','.w-predefined-promotion .promo-item','font-size','24','','','.w-predefined-promotion'),(479344,'furniture-mobile','.w-predefined-promotion .promo-salemaker .content a','font-size','14','','','.w-predefined-promotion'),(479345,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','font-size','13','','','.w-predefined-promotion'),(479346,'furniture-mobile','.w-supplier-purchase-supplier-products .active .select_item > div:before','font-size','20','','','.w-supplier-purchase-supplier-products'),(479347,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','font-size','28','','','.w-filters'),(479348,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','font-size','28','','','.w-filters'),(479349,'furniture-mobile','.mainBanner .bottomBox .btn','font-size','1.56','','','.mainBanner'),(479350,'furniture-mobile','.mainBanner .title','font-size','2.2','','','.mainBanner'),(479351,'furniture-mobile','.mainBanner .title > span','font-size','1.6','','','.mainBanner'),(479352,'furniture-mobile','.mainBanner .topBox > .left','font-size','3.13','','','.mainBanner'),(479353,'furniture-mobile','.mainBanner .topBox > .right','font-size','24','','','.mainBanner'),(479354,'furniture-mobile','.mainBanner .topBox > .right','font-size','20','2890','','.mainBanner'),(479355,'furniture-mobile','.mainBanner .bottomBox .btn','font-size','2.848','2876','','.mainBanner'),(479356,'furniture-mobile','.mainBanner .title','font-size','4.177','2876','','.mainBanner'),(479357,'furniture-mobile','.mainBanner .title > span','font-size','3.038','2876','','.mainBanner'),(479358,'furniture-mobile','.mainBanner .topBox > .left','font-size','5.697','2876','','.mainBanner'),(479359,'furniture-mobile','.mainBanner .topBox > .right','font-size','14','2876','','.mainBanner'),(479360,'furniture-mobile','.mainBanner .bottomBox .btn','font-size','14','2906','','.mainBanner'),(479361,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','font-size','18','','','.lowestPricedBox'),(479362,'furniture-mobile','.lowestPricedBox .w-banner .ybg .descr','font-size','1.1','','','.lowestPricedBox'),(479363,'furniture-mobile','.lowestPricedBox .w-banner .ybg .title','font-size','1.5','','','.lowestPricedBox'),(479364,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','font-size','1.2','2890','','.lowestPricedBox'),(479365,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','font-size','16','2876','','.lowestPricedBox'),(479366,'furniture-mobile','.lowestPricedBox .w-banner .ybg .descr','font-size','16','2876','','.lowestPricedBox'),(479367,'furniture-mobile','.lowestPricedBox .w-banner .ybg .title','font-size','21','2876','','.lowestPricedBox'),(479368,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','font-size','14','2906','','.lowestPricedBox'),(479369,'furniture-mobile','.lowestPricedBox .w-banner .ybg .descr','font-size','14','2906','','.lowestPricedBox'),(479370,'furniture-mobile','.lowestPricedBox .w-banner .ybg .title','font-size','18','2906','','.lowestPricedBox'),(479371,'furniture-mobile','.shopByCollectionBox .bannerButton a','font-size','18','','','.shopByCollectionBox'),(479372,'furniture-mobile','.shopByCollectionBox .content .title','font-size','18','','','.shopByCollectionBox'),(479373,'furniture-mobile','.shopByCollectionBox .content .title span','font-size','36','','','.shopByCollectionBox'),(479374,'furniture-mobile','.shopByCollectionBox .bannerButton a','font-size','16','2890','','.shopByCollectionBox'),(479375,'furniture-mobile','.shopByCollectionBox .content .title','font-size','16','2890','','.shopByCollectionBox'),(479376,'furniture-mobile','.shopByCollectionBox .content .title span','font-size','24','2890','','.shopByCollectionBox'),(479377,'furniture-mobile','.w-product-reviews .no-reviews','font-size','14','','','.w-product-reviews'),(479378,'furniture-mobile','.order-summary .icon','font-size','18','3','','.order-summary'),(479379,'furniture-mobile','.cartTitle span','font-size','24','2885','','.cartTitle'),(479380,'furniture-mobile','.w-search .extra','font-size','16','3','','.w-search'),(479381,'furniture-mobile','.w-search .extra','font-size','12','','','.w-search'),(479382,'furniture-mobile','.w-search .name','font-size','12','','','.w-search'),(479383,'furniture-mobile','.w-search .wrap .info-suggest .image','font-size','12','3','','.w-search'),(479384,'furniture-mobile','.account-address-book .address_book .btn-edit, .account-address-book .address_book .btn-delete','font-size','16','4','','.account-address-book'),(479385,'furniture-mobile','.account-address-book .address_book h2','font-size','18','','','.account-address-book'),(479386,'furniture-mobile','.account-address-book .btn-edit','font-size','16','4','','.account-address-book'),(479387,'furniture-mobile','.account-address-book .leftMes div','font-size','18','','','.account-address-book'),(479388,'furniture-mobile','.account-order-history .not_fully_paid_td','font-size','30','','','.account-order-history'),(479389,'furniture-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','font-size','16','','','.account-order-history'),(479390,'furniture-mobile','.account-order-history .order_history_table h2','font-size','24','','','.account-order-history'),(479391,'furniture-mobile','.account-order-history .order_history_table th','font-size','16','','','.account-order-history'),(479392,'furniture-mobile','.account-order-history .view_link','font-size','18','4','','.account-order-history'),(479393,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','font-size','18','','','.account-order-history-info'),(479394,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','font-size','22','3','','.account-order-history-info'),(479395,'furniture-mobile','.account-order-history-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-order-history-info'),(479396,'furniture-mobile','.account-order-history-info .history_attr','font-size','14','','','.account-order-history-info'),(479397,'furniture-mobile','.account-order-history-info .not_fully_paid_td','font-size','30','','','.account-order-history-info'),(479398,'furniture-mobile','.account-order-history-info .popup-tracking-number-link','font-size','18','','','.account-order-history-info'),(479399,'furniture-mobile','.account-order-history-info .trackings-nambers-label','font-size','20','','','.account-order-history-info'),(479400,'furniture-mobile','.account-index .account_page h1','font-size','30','','','.account-index'),(479401,'furniture-mobile','.account-index .account_page h4','font-size','22','3','','.account-index'),(479402,'furniture-mobile','.account-index .date_title','font-size','14','','','.account-index'),(479403,'furniture-mobile','.account-index .date_value','font-size','18','','','.account-index'),(479404,'furniture-mobile','.account-index .date_value strong','font-size','16','','','.account-index'),(479405,'furniture-mobile','.account-index .date_value, .account-index .date_title','font-size','18','','','.account-index'),(479406,'furniture-mobile','.account-index .leftMes div','font-size','18','','','.account-index'),(479407,'furniture-mobile','.account-index .not_fully_paid_td','font-size','30','','','.account-index'),(479408,'furniture-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','font-size','16','','','.account-index'),(479409,'furniture-mobile','.account-index .remove-btn','font-size','28','','','.account-index'),(479410,'furniture-mobile','.account-index .topAccount > li > div','font-size','42','3','','.account-index'),(479411,'furniture-mobile','.account-index .view_history','font-size','16','','','.account-index'),(479412,'furniture-mobile','.account-index .view_history','font-size','14','3','','.account-index'),(479413,'furniture-mobile','.account-index .view_link','font-size','18','4','','.account-index'),(479414,'furniture-mobile','.account-index .view_link','font-size','16','','','.account-index'),(479415,'furniture-mobile','.account-index h1, .account-index .reviews-info h1','font-size','21','2876','','.account-index'),(479416,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-size','18','','','.account-order-pay'),(479417,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-size','22','3','','.account-order-pay'),(479418,'furniture-mobile','.account-order-pay .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-order-pay'),(479419,'furniture-mobile','.account-order-pay .history_attr','font-size','14','','','.account-order-pay'),(479420,'furniture-mobile','.account-order-pay .not_fully_paid_td','font-size','30','','','.account-order-pay'),(479421,'furniture-mobile','.account-samples .not_fully_paid_td','font-size','30','','','.account-samples'),(479422,'furniture-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','font-size','16','','','.account-samples'),(479423,'furniture-mobile','.account-samples .order_history_table h2','font-size','24','','','.account-samples'),(479424,'furniture-mobile','.account-samples .order_history_table th','font-size','16','','','.account-samples'),(479425,'furniture-mobile','.account-samples .view_link','font-size','18','4','','.account-samples'),(479426,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-size','18','','','.account-sample-info'),(479427,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-size','22','3','','.account-sample-info'),(479428,'furniture-mobile','.account-sample-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-sample-info'),(479429,'furniture-mobile','.account-sample-info .history_attr','font-size','14','','','.account-sample-info'),(479430,'furniture-mobile','.account-sample-info .not_fully_paid_td','font-size','30','','','.account-sample-info'),(479431,'furniture-mobile','.account-sample-info .popup-tracking-number-link','font-size','18','','','.account-sample-info'),(479432,'furniture-mobile','.account-sample-info .trackings-nambers-label','font-size','20','','','.account-sample-info'),(479433,'furniture-mobile','.catalog-product-wrap .pn-direction','font-size','14','','','.catalog-product-wrap'),(479434,'furniture-mobile','.catalog-product-wrap .pn-image','font-size','14','3','','.catalog-product-wrap'),(479435,'furniture-mobile','.catalog-product-wrap .pn-name','font-size','14','','','.catalog-product-wrap'),(479436,'furniture-mobile','.catalog-product-wrap .pn-direction','font-size','10','2885','','.catalog-product-wrap'),(479437,'furniture-mobile','.shopping-cart-index .cart-page .empty','font-size','24','','','.shopping-cart-index'),(479438,'furniture-mobile','.shopping-cart-index .gift-code .heading-4','font-size','20','2876','','.shopping-cart-index'),(479439,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','font-size','16','','','.checkout-index-wrap'),(479440,'furniture-mobile','.checkout-index-wrap .order-ico','font-size','36','3','','.checkout-index-wrap'),(479441,'furniture-mobile','.checkout-index-wrap .pay-ico','font-size','30','3','','.checkout-index-wrap'),(479442,'furniture-mobile','.checkout-index-wrap .ship-ico','font-size','30','3','','.checkout-index-wrap'),(479443,'furniture-mobile','.checkout-order-confirmation .comment-ico','font-size','30','3','','.checkout-order-confirmation'),(479444,'furniture-mobile','.checkout-order-confirmation .discount-ico','font-size','30','3','','.checkout-order-confirmation'),(479445,'furniture-mobile','.checkout-order-confirmation .order-ico','font-size','36','3','','.checkout-order-confirmation'),(479446,'furniture-mobile','.checkout-order-confirmation .price-box','font-size','16','','','.checkout-order-confirmation'),(479447,'furniture-mobile','.checkout-order-confirmation .price-box .price','font-size','16','','','.checkout-order-confirmation'),(479448,'furniture-mobile','.checkout-order-confirmation .price-box .price-row.total','font-size','22','','','.checkout-order-confirmation'),(479449,'furniture-mobile','.checkout-order-confirmation .ship-ico','font-size','30','3','','.checkout-order-confirmation'),(479450,'furniture-mobile','.checkout-login-wrap .password-forgotten-link','font-size','14','','','.checkout-login-wrap'),(479451,'furniture-mobile','.checkout-success-wrap .page-success .text-1','font-size','80','3','','.checkout-success-wrap'),(479452,'furniture-mobile','.checkout-success-wrap .page-success .text-1','font-size','60','','','.checkout-success-wrap'),(479453,'furniture-mobile','.checkout-success-wrap .page-success .text-2','font-size','34','','','.checkout-success-wrap'),(479454,'furniture-mobile','.checkout-success-wrap .page-success .text-3','font-size','27','','','.checkout-success-wrap'),(479455,'furniture-mobile','.checkout-success-wrap .page-success .text-1','font-size','40','2876','','.checkout-success-wrap'),(479456,'furniture-mobile','.checkout-success-wrap .page-success .text-2','font-size','30','2876','','.checkout-success-wrap'),(479457,'furniture-mobile','.account-index .view_link','font-size_important','important','','','.account-index'),(479458,'furniture-mobile','.b-rating .glyphicon','font-style','normal','','','.b-rating'),(479459,'furniture-mobile','.b-switch .candlestick-wrapper .fa-times','font-style','normal','3','','.b-switch'),(479460,'furniture-mobile','.b-switch .candlestick-wrapper .fa-check','font-style','normal','3','','.b-switch'),(479461,'furniture-mobile','.b-select-suggest .select2-results li em','font-style','normal','','','.b-select-suggest'),(479462,'furniture-mobile','.heading-4 .right-text, h4 .right-text','font-weight','400','','',''),(479463,'furniture-mobile','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(479464,'furniture-mobile','.b-info .info strong','font-weight','400','','','.b-info'),(479465,'furniture-mobile','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(479466,'furniture-mobile','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(479467,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','font-weight','600','','','.b-switch'),(479468,'furniture-mobile','.w-multi-cart-cart-switcher .dropdown-menu a','font-weight','bold','','','.w-multi-cart-cart-switcher'),(479469,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','font-weight','bold','','','.p-reviews-info'),(479470,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(479471,'furniture-mobile','.p-quick-order-index .filters label','font-weight','700','','','.p-quick-order-index'),(479472,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.p-quick-order-index'),(479473,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range .value','font-weight','bold','','','.w-promotions'),(479474,'furniture-mobile','.w-promotions .promo-date','font-weight','500','','','.w-promotions'),(479475,'furniture-mobile','.w-sale .left-count-days','font-weight','600','','','.w-sale'),(479476,'furniture-mobile','.w-wedding-registry-widgets-share-link a','font-weight','normal','4','','.w-wedding-registry-widgets-share-link'),(479477,'furniture-mobile','.w-personal-gift-status-bar .end-label','font-weight','bold','','','.w-personal-gift-status-bar'),(479478,'furniture-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(479479,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','font-weight','bold','','','.p-reviews-info'),(479480,'furniture-mobile','.p-blog-index .nav-links .screen-reader-text','font-weight','700','','','.p-blog-index'),(479481,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(479482,'furniture-mobile','.testimonials .reviews-list span','font-weight','400','','',''),(479483,'furniture-mobile','.testimonials .rating','font-weight','400','','',''),(479484,'furniture-mobile','.testimonials .name','font-weight','700','','',''),(479485,'furniture-mobile','.testimonials .heading-3','font-weight','400','3','',''),(479486,'furniture-mobile','.testimonials .reviews-list .name','font-weight','700','','',''),(479487,'furniture-mobile','.w-promotions .prom-multi-discount .heading','font-weight','300','','','.w-promotions'),(479488,'furniture-mobile','.w-promotions .heading-3','font-weight','bold','','','.w-promotions'),(479489,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.p-quick-order-index'),(479490,'furniture-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading','font-weight','300','','','.w-promotions'),(479491,'furniture-mobile','.w-promotions .promo-salemaker .promo-conditions','font-weight','300','','','.w-promotions'),(479492,'furniture-mobile','.w-promotions .promo-salemaker .discount .value','font-weight','700','','','.w-promotions'),(479493,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder .value','font-weight','bold','','','.w-promotions'),(479494,'furniture-mobile','.w-promotions .promo-cart-discount .slave .heading','font-weight','300','','','.w-promotions'),(479495,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty .value','font-weight','bold','','','.w-promotions'),(479496,'furniture-mobile','.w-promotions .promo-cart-discount .master .heading','font-weight','300','','','.w-promotions'),(479497,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','font-weight','bold','','','.b-warehouses-popup'),(479498,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-name','font-weight','bold','','','.b-warehouses-popup'),(479499,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','font-weight','bold','','','.b-warehouses-popup'),(479500,'furniture-mobile','.b-warehouses-popup .warehouses-popup .heading','font-weight','bold','','','.b-warehouses-popup'),(479501,'furniture-mobile','.b-warehouses-popup a.warehouses-popup-link','font-weight','bold','','','.b-warehouses-popup'),(479502,'furniture-mobile','.w-product-available-in-warehouses .warehouse-name','font-weight','bold','','','.w-product-available-in-warehouses'),(479503,'furniture-mobile','.w-checkout-create-account .account-benefits strong','font-weight','normal','','','.w-checkout-create-account'),(479504,'furniture-mobile','.p-account-trade-form .address-wrapp b','font-weight','600','','','.p-account-trade-form'),(479505,'furniture-mobile','.w-cart-listing .name a','font-weight','bold','','','.w-cart-listing'),(479506,'furniture-mobile','.w-menu-slider > ul > li > ul > li > a','font-weight','700','','','.w-menu-slider'),(479507,'furniture-mobile','.b-messages .messBtnMenuDelete','font-weight','normal','3','','.b-messages'),(479508,'furniture-mobile','.b-messages span.starred::before','font-weight','normal','','','.b-messages'),(479509,'furniture-mobile','.b-messages .messBtnMenuStarred','font-weight','normal','3','','.b-messages'),(479510,'furniture-mobile','.b-messages .messMenuButton span','font-weight','600','','','.b-messages'),(479511,'furniture-mobile','.b-messages .messBtnMenuUnread','font-weight','normal','3','','.b-messages'),(479512,'furniture-mobile','.b-messages .messages-menu li a','font-weight','bold','2','','.b-messages'),(479513,'furniture-mobile','.b-messages .content_management_attach','font-weight','600','','','.b-messages'),(479514,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','font-weight','600','','','.b-messages'),(479515,'furniture-mobile','.w-sale .special-price','font-weight','600','','','.w-sale'),(479516,'furniture-mobile','.w-reviews .author','font-weight','bold','','','.w-reviews'),(479517,'furniture-mobile','.w-sale .left-count-hours','font-weight','600','','','.w-sale'),(479518,'furniture-mobile','.order-summary .price-box .price-row.total','font-weight','600','','','.order-summary'),(479519,'furniture-mobile','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(479520,'furniture-mobile','.w-menu-slider > ul > li > ul > li > a','font-weight','700','','','.w-menu-slider'),(479521,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(479522,'furniture-mobile','.p-payer-order-confirmation .cardinfo-label','font-weight','bold','','','.p-payer-order-confirmation'),(479523,'furniture-mobile','.p-payer-order-pay .cardinfo-label','font-weight','bold','','','.p-payer-order-pay'),(479524,'furniture-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(479526,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','font-weight','bold','4','','.b-switch'),(479528,'furniture-mobile','.p-account-trade-form .address-wrapp b','font-weight','600','','','.p-account-trade-form'),(479529,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','font-weight','normal','','','.p-account-trade-form'),(479530,'furniture-mobile','.p-account-trade-form .widget h3','font-weight','normal','','','.p-account-trade-form'),(479531,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-weight','normal','','','.p-account-subscription-historyinfo'),(479532,'furniture-mobile','.b-rating .glyphicon','font-weight','400','','','.b-rating'),(479533,'furniture-mobile','.p-quick-order-index .value','font-weight','bold','','','.p-quick-order-index'),(479534,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(479535,'furniture-mobile','.b-table .table .headings td','font-weight','600','','','.b-table'),(479536,'furniture-mobile','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(479537,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-weight','normal','','','.p-account-subscription-historyinfo'),(479538,'furniture-mobile','.p-account-trade-form .address-wrapp b','font-weight','600','','','.p-account-trade-form'),(479539,'furniture-mobile','.b-info .info strong','font-weight','400','','','.b-info'),(479540,'furniture-mobile','.b-form .shipping-method .cost','font-weight','bold','','','.b-form'),(479541,'furniture-mobile','.w-sale .ends-date','font-weight','600','','','.w-sale'),(479542,'furniture-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-weight','600','','','.p-quick-order-index'),(479543,'furniture-mobile','.p-account-trade-form .address-wrapp b','font-weight','600','','','.p-account-trade-form'),(479544,'furniture-mobile','.btn-1','font-weight','600','','',''),(479545,'furniture-mobile','.w-checkout-totals .ot_code_ot_subtotal','font-weight','bold','','','.w-checkout-totals'),(479546,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(479547,'furniture-mobile','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(479548,'furniture-mobile','.w-sale .special-price','font-weight','600','','','.w-sale'),(479549,'furniture-mobile','.w-sale .ends-date','font-weight','600','','','.w-sale'),(479550,'furniture-mobile','.w-sale .left-text-right','font-weight','600','','','.w-sale'),(479551,'furniture-mobile','.w-sale .name','font-weight','bold','','','.w-sale'),(479552,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-weight','normal','','','.p-account-subscription-historyinfo'),(479553,'furniture-mobile','.p-account-trade-form .widget h3','font-weight','normal','','','.p-account-trade-form'),(479554,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(479555,'furniture-mobile','.b-bottom .popup-heading','font-weight','bold','','','.b-bottom'),(479556,'furniture-mobile','.b-form .middle-form label.slim','font-weight','400','','','.b-form'),(479557,'furniture-mobile','.w-checkout-shipping-choice span','font-weight','600','','','.w-checkout-shipping-choice'),(479558,'furniture-mobile','.btn-3','font-weight','600','','',''),(479559,'furniture-mobile','.w-reviews-content .author','font-weight','bold','','','.w-reviews-content'),(479560,'furniture-mobile','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(479561,'furniture-mobile','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(479562,'furniture-mobile','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(479563,'furniture-mobile','.w-cart-compare .js-cart_totals_container b','font-weight','600','','','.w-cart-compare'),(479564,'furniture-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(479565,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(479566,'furniture-mobile','.w-image-maps .default-links .item .title','font-weight','700','','','.w-image-maps'),(479567,'furniture-mobile','.heading-4 .edit, h4 .edit','font-weight','400','','',''),(479568,'furniture-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(479569,'furniture-mobile','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(479570,'furniture-mobile','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(479571,'furniture-mobile','.w-sale .left-text-left','font-weight','600','','','.w-sale'),(479572,'furniture-mobile','.w-sale .left-count-days','font-weight','600','','','.w-sale'),(479573,'furniture-mobile','.w-menu-slider > ul > li > ul > li > a','font-weight','700','','','.w-menu-slider'),(479574,'furniture-mobile','.w-tabs .tab-li.tab-wishlist a','font-weight','normal','3','','.w-tabs'),(479575,'furniture-mobile','.w-multi-cart-cart-switcher .cart-label','font-weight','600','','','.w-multi-cart-cart-switcher'),(479576,'furniture-mobile','.w-multi-cart-actions .cart-actions','font-weight','600','','','.w-multi-cart-actions'),(479577,'furniture-mobile','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(479578,'furniture-mobile','.w-sale .special-price','font-weight','600','','','.w-sale'),(479579,'furniture-mobile','.b-form .middle-form label','font-weight','600','','','.b-form'),(479580,'furniture-mobile','.w-cart-credit-amount .amount-title','font-weight','bold','','','.w-cart-credit-amount'),(479581,'furniture-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(479582,'furniture-mobile','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(479583,'furniture-mobile','.w-sale .ends-date','font-weight','600','','','.w-sale'),(479584,'furniture-mobile','.w-wedding-registry-widgets-products .rating','font-weight','bold','','','.w-wedding-registry-widgets-products'),(479585,'furniture-mobile','.w-personal-gift-status-bar .end-date b','font-weight','bold','','','.w-personal-gift-status-bar'),(479586,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(479587,'furniture-mobile','.p-blog-index .nav-links .screen-reader-text','font-weight','700','','','.p-blog-index'),(479588,'furniture-mobile','.btn-2','font-weight','600','','',''),(479589,'furniture-mobile','.heading-5, h5, .h-block h5','font-weight','600','','',''),(479590,'furniture-mobile','.w-cart-compare .cart-name a','font-weight','600','','','.w-cart-compare'),(479591,'furniture-mobile','.w-product-reviews .reviews-list span','font-weight','400','','','.w-product-reviews'),(479592,'furniture-mobile','.b-table .table .headings td','font-weight','600','','','.b-table'),(479593,'furniture-mobile','.w-delayed-despatch-checkout .heading','font-weight','bold','','','.w-delayed-despatch-checkout'),(479594,'furniture-mobile','.w-top-categories .categories h2','font-weight','inherit','','','.w-top-categories'),(479595,'furniture-mobile','.transit','font-weight','700','','',''),(479596,'furniture-mobile','.out-stock','font-weight','700','','',''),(479597,'furniture-mobile','.in-stock','font-weight','700','','',''),(479598,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','font-weight','bold','4','','.b-switch'),(479599,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','font-weight','bold','4','','.b-switch'),(479600,'furniture-mobile','.b-delete-account .delete-box .delete-message','font-weight','normal','','','.b-delete-account'),(479602,'furniture-mobile','.w-checkout-shipping-address .genders-title > div','font-weight','bold','','','.w-checkout-shipping-address'),(479603,'furniture-mobile','.w-cart-bonus-points .title','font-weight','bold','','','.w-cart-bonus-points'),(479604,'furniture-mobile','.w-sale .ends-date','font-weight','600','','','.w-sale'),(479605,'furniture-mobile','.p-blog-index .nav-links .screen-reader-text','font-weight','700','','','.p-blog-index'),(479606,'furniture-mobile','.w-menu-slider > ul > li > ul > li > a','font-weight','700','','','.w-menu-slider'),(479607,'furniture-mobile','.w-sale .left-text-right','font-weight','600','','','.w-sale'),(479608,'furniture-mobile','.w-sale .left-text-left','font-weight','600','','','.w-sale'),(479609,'furniture-mobile','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(479610,'furniture-mobile','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(479611,'furniture-mobile','.w-checkout-billing-address .btn-cancel','font-weight','500','','','.w-checkout-billing-address'),(479612,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','font-weight','normal','','','.p-account-trade-form'),(479613,'furniture-mobile','.js-stock','font-weight','700','','',''),(479614,'furniture-mobile','.b-form #payment_method .title','font-weight','bold','','','.b-form'),(479615,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','font-weight','bold','','','.b-fancybox'),(479616,'furniture-mobile','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(479617,'furniture-mobile','.w-reviews-content .product-name a','font-weight','bold','','','.w-reviews-content'),(479618,'furniture-mobile','.w-product-reviews .reviews-list .name','font-weight','700','','','.w-product-reviews'),(479619,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(479620,'furniture-mobile','.w-sale .name','font-weight','bold','','','.w-sale'),(479621,'furniture-mobile','.p-account-trade-form .address-wrapp b','font-weight','600','','','.p-account-trade-form'),(479622,'furniture-mobile','.b-table .table .headings td','font-weight','600','','','.b-table'),(479623,'furniture-mobile','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(479624,'furniture-mobile','.w-tabs .tab-li.tab-cart a','font-weight','normal','3','','.w-tabs'),(479625,'furniture-mobile','.btn','font-weight','600','','',''),(479626,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','font-weight','bold','','','.p-reviews-info'),(479627,'furniture-mobile','.w-personal-gift-status-bar .inform b','font-weight','bold','','','.w-personal-gift-status-bar'),(479628,'furniture-mobile','.b-table .table .headings td','font-weight','600','','','.b-table'),(479629,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(479630,'furniture-mobile','.w-reviews .heading-3','font-weight','400','3','','.w-reviews'),(479631,'furniture-mobile','.w-reviews .product-name a','font-weight','bold','','','.w-reviews'),(479632,'furniture-mobile','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(479633,'furniture-mobile','.w-checkout-billing-address .genders-title > div','font-weight','bold','','','.w-checkout-billing-address'),(479634,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','font-weight','600','','','.b-switch'),(479635,'furniture-mobile','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(479636,'furniture-mobile','.w-cart-compare .atr-col','font-weight','600','','','.w-cart-compare'),(479637,'furniture-mobile','.w-sale .left-text-right','font-weight','600','','','.w-sale'),(479638,'furniture-mobile','.w-sale .ends-date','font-weight','600','','','.w-sale'),(479639,'furniture-mobile','.w-sale .left-text-left','font-weight','600','','','.w-sale'),(479640,'furniture-mobile','.w-sale .left-count-hours','font-weight','600','','','.w-sale'),(479641,'furniture-mobile','.w-sale .left-count-days','font-weight','600','','','.w-sale'),(479642,'furniture-mobile','.b-info .info strong','font-weight','400','','','.b-info'),(479643,'furniture-mobile','.p-blog-index .nav-links .screen-reader-text','font-weight','700','','','.p-blog-index'),(479644,'furniture-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(479645,'furniture-mobile','.w-sale .special-price','font-weight','600','','','.w-sale'),(479646,'furniture-mobile','.w-sale .left-count-hours','font-weight','600','','','.w-sale'),(479648,'furniture-mobile','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(479649,'furniture-mobile','.b-bottom .alert-message','font-weight','bold','','','.b-bottom'),(479650,'furniture-mobile','.w-image-maps .categories-items .item .title','font-weight','700','','','.w-image-maps'),(479651,'furniture-mobile','.w-neighbour-checkout .text','font-weight','bold','','','.w-neighbour-checkout'),(479652,'furniture-mobile','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-weight','600','','','.order-summary'),(479653,'furniture-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(479654,'furniture-mobile','.w-sale .left-text-right','font-weight','600','','','.w-sale'),(479655,'furniture-mobile','.w-sale .special-price','font-weight','600','','','.w-sale'),(479656,'furniture-mobile','.b-info .info strong','font-weight','400','','','.b-info'),(479657,'furniture-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(479658,'furniture-mobile','.w-cart-compare .atr-col','font-weight','normal','3','','.w-cart-compare'),(479659,'furniture-mobile','.w-tabs .tab-li.tab-quote a','font-weight','normal','3','','.w-tabs'),(479660,'furniture-mobile','.w-sale .name','font-weight','bold','','','.w-sale'),(479661,'furniture-mobile','.b-info .info strong','font-weight','400','','','.b-info'),(479662,'furniture-mobile','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(479663,'furniture-mobile','.w-product-available-in-warehouses .heading','font-weight','bold','','','.w-product-available-in-warehouses'),(479664,'furniture-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(479665,'furniture-mobile','.p-account-trade-form .widget h3','font-weight','normal','','','.p-account-trade-form'),(479666,'furniture-mobile','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(479667,'furniture-mobile','.p-quick-order-index .dataTables_info','font-weight','500','','','.p-quick-order-index'),(479668,'furniture-mobile','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(479669,'furniture-mobile','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(479670,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(479671,'furniture-mobile','.w-delayed-despatch-checkout-confirm .heading','font-weight','600','','','.w-delayed-despatch-checkout-confirm'),(479672,'furniture-mobile','.w-delayed-despatch-checkout-confirm .heading','font-weight','bold','','','.w-delayed-despatch-checkout-confirm'),(479673,'furniture-mobile','.w-checkout-bonus-points .title','font-weight','bold','','','.w-checkout-bonus-points'),(479674,'furniture-mobile','.w-coupons-and-vauchers-checkout .title','font-weight','bold','','','.w-coupons-and-vauchers-checkout'),(479675,'furniture-mobile','.w-checkout-credit-amount .amount-title','font-weight','bold','','','.w-checkout-credit-amount'),(479676,'furniture-mobile','.w-sale .left-text-left','font-weight','600','','','.w-sale'),(479677,'furniture-mobile','.w-sale .left-count-hours','font-weight','600','','','.w-sale'),(479679,'furniture-mobile','.b-pass-strength .pass-strength span','font-weight','bold','','','.b-pass-strength'),(479680,'furniture-mobile','.b-table .table .headings td','font-weight','600','','','.b-table'),(479681,'furniture-mobile','.w-quote .strong','font-weight','400','','','.w-quote'),(479682,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-weight','normal','','','.p-account-subscription-historyinfo'),(479683,'furniture-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(479684,'furniture-mobile','.p-account-trade-form .widget h3','font-weight','normal','','','.p-account-trade-form'),(479685,'furniture-mobile','.b-select-suggest .select2-results li.select2-result-with-children > .select2-result-label','font-weight','bold','','','.b-select-suggest'),(479686,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','font-weight','bold','','','.b-warehouses-popup'),(479687,'furniture-mobile','.w-sale .left-text-right','font-weight','600','','','.w-sale'),(479688,'furniture-mobile','.w-wedding-registry-widgets-delete-link a','font-weight','normal','4','','.w-wedding-registry-widgets-delete-link'),(479689,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-weight','normal','','','.p-account-subscription-historyinfo'),(479690,'furniture-mobile','.p-blog-index .nav-links .screen-reader-text','font-weight','700','','','.p-blog-index'),(479691,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','font-weight','bold','','','.p-reviews-info'),(479692,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','font-weight','normal','','','.p-account-trade-form'),(479693,'furniture-mobile','.b-table .table .headings td','font-weight','600','','','.b-table'),(479694,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','font-weight','bold','','','.p-reviews-info'),(479695,'furniture-mobile','.w-menu-slider > ul > li > ul > li > a','font-weight','700','','','.w-menu-slider'),(479696,'furniture-mobile','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(479697,'furniture-mobile','.w-sale .name','font-weight','bold','','','.w-sale'),(479698,'furniture-mobile','.w-quote-products .empty','font-weight','700','','','.w-quote-products'),(479699,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.b-data-table'),(479700,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.b-data-table'),(479701,'furniture-mobile','.w-communication-post .communication-post-author-name','font-weight','bold','','','.w-communication-post'),(479702,'furniture-mobile','.b-products-listing .products-listing .name a','font-weight','bold','','','.b-products-listing'),(479703,'furniture-mobile','.b-products-listing .products-listing .bonus-points span:first-child','font-weight','bold','','','.b-products-listing'),(479704,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','font-weight','400','','','.b-products-listing'),(479705,'furniture-mobile','.b-products-listing .products-listing .btn-buy','font-weight','400','3','','.b-products-listing'),(479706,'furniture-mobile','.b-products-listing .promos-info .promo-name','font-weight','500','','','.b-products-listing'),(479707,'furniture-mobile','.b-products-listing .wedding-registry-count','font-weight','bold','','','.b-products-listing'),(479708,'furniture-mobile','.w-blog-widget-tag-cloud a','font-weight','700','','','.w-blog-widget-tag-cloud'),(479709,'furniture-mobile','.w-blog-widget-post-listing .post_name','font-weight','400','','','.w-blog-widget-post-listing'),(479710,'furniture-mobile','.w-currencies .select-link','font-weight','700','','','.w-currencies'),(479711,'furniture-mobile','.w-currencies .currencies-title','font-weight','700','','','.w-currencies'),(479712,'furniture-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(479713,'furniture-mobile','.b-form .form-inputs label > span','font-weight','bold','','','.b-form'),(479714,'furniture-mobile','.p-account-trade-form .widget h3','font-weight','normal','','','.p-account-trade-form'),(479715,'furniture-mobile','.w-sale .special-price','font-weight','600','','','.w-sale'),(479716,'furniture-mobile','.w-sale .left-count-days','font-weight','600','','','.w-sale'),(479717,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','font-weight','normal','','','.p-account-trade-form'),(479718,'furniture-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','font-weight','normal','','','.w-taxable'),(479719,'furniture-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','font-weight','normal','','','.w-taxable'),(479720,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-weight','inherit','','',''),(479721,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-weight','inherit','','','.b-h-inline'),(479722,'furniture-mobile','h1, .heading-1','font-weight','700','','',''),(479723,'furniture-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(479724,'furniture-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(479726,'furniture-mobile','.w-sale .left-text-left','font-weight','600','','','.w-sale'),(479727,'furniture-mobile','.w-sale .left-count-days','font-weight','600','','','.w-sale'),(479728,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','font-weight','bold','','','.p-reviews-info'),(479729,'furniture-mobile','.w-tabs .tab-li.tab-sample a','font-weight','normal','3','','.w-tabs'),(479730,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(479731,'furniture-mobile','.w-sale .left-text-left','font-weight','600','','','.w-sale'),(479732,'furniture-mobile','.w-sale .left-count-days','font-weight','600','','','.w-sale'),(479733,'furniture-mobile','.w-sale .left-count-hours','font-weight','600','','','.w-sale'),(479734,'furniture-mobile','.w-sale .ends-date','font-weight','600','','','.w-sale'),(479735,'furniture-mobile','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(479736,'furniture-mobile','.w-sale .left-text-right','font-weight','600','','','.w-sale'),(479737,'furniture-mobile','.w-sale .name','font-weight','bold','','','.w-sale'),(479738,'furniture-mobile','.b-form .shipping-method .title','font-weight','bold','','','.b-form'),(479739,'furniture-mobile','.p-account-update .main-text a','font-weight','bold','','','.p-account-update'),(479740,'furniture-mobile','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(479741,'furniture-mobile','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(479742,'furniture-mobile','.w-cart-listing .item .gift-wrap label','font-weight','700','','','.w-cart-listing'),(479743,'furniture-mobile','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-weight','600','','','.w-cart-listing'),(479744,'furniture-mobile','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-weight','normal','3','','.w-cart-listing'),(479745,'furniture-mobile','.w-cart-listing .remove-btn span','font-weight','bold','2885','','.w-cart-listing'),(479746,'furniture-mobile','.w-cart-give-away .ga_price','font-weight','700','','','.w-cart-give-away'),(479747,'furniture-mobile','.w-cart-discount-coupon .title','font-weight','bold','','','.w-cart-discount-coupon'),(479748,'furniture-mobile','.w-cart .sub-total-row','font-weight','600','','','.w-cart'),(479749,'furniture-mobile','.w-cart .strong','font-weight','400','','','.w-cart'),(479750,'furniture-mobile','.w-cart .price','font-weight','600','','','.w-cart'),(479751,'furniture-mobile','.w-cart .multicart .title','font-weight','600','','','.w-cart'),(479752,'furniture-mobile','.w-image-maps .float-items .item .title','font-weight','700','','','.w-image-maps'),(479753,'furniture-mobile','.b-sub-totals .historyTotal table tr:last-child td','font-weight','bold','','','.b-sub-totals'),(479754,'furniture-mobile','.w-sale .name','font-weight','bold','','','.w-sale'),(479755,'furniture-mobile','.w-sale .left-count-hours','font-weight','600','','','.w-sale'),(479756,'furniture-mobile','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(479757,'furniture-mobile','.b-form .address-item .firstname, .b-form .address-item .lastname','font-weight','bold','','','.b-form'),(479758,'furniture-mobile','.w-cart .cart-total','font-weight','600','','','.w-cart'),(479759,'furniture-mobile','.w-account-address-book .name','font-weight','bold','','','.w-account-address-book'),(479760,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','font-weight','normal','','','.p-account-trade-form'),(479761,'furniture-mobile','.p-account-trade-form .address-wrapp b','font-weight','600','','','.p-account-trade-form'),(479762,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','font-weight','normal','','','.p-account-trade-form'),(479763,'furniture-mobile','.w-checkout-contact-information .contact-info-buttons a','font-weight','500','','','.w-checkout-contact-information'),(479764,'furniture-mobile','.w-checkout-shipping-address .change-ab','font-weight','500','','','.w-checkout-shipping-address'),(479765,'furniture-mobile','.w-checkout-billing-address .edit-ab','font-weight','500','','','.w-checkout-billing-address'),(479766,'furniture-mobile','.w-checkout-billing-address .add-ab','font-weight','500','','','.w-checkout-billing-address'),(479767,'furniture-mobile','.w-filters .view_more','font-weight','400','4','','.w-filters'),(479768,'furniture-mobile','.blogsidebar .heading-title','font-weight','400','','','.blogsidebar'),(479769,'furniture-mobile','.w-catalog-paging ','font-weight','700','2','','.w-catalog-paging'),(479770,'furniture-mobile','.p-account-trade-form .widget h3','font-weight','normal','','','.p-account-trade-form'),(479771,'furniture-mobile','.b-bottom .footerTitle','font-weight','700','','','.b-bottom'),(479772,'furniture-mobile','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(479773,'furniture-mobile','.heading-2, h2, .h-block h2','font-weight','700','','',''),(479774,'furniture-mobile','.w-menu-slider > ul > li > ul > li > a','font-weight','700','','','.w-menu-slider'),(479775,'furniture-mobile','.b-data-table table.dataTable thead td','font-weight','700','','','.b-data-table'),(479776,'furniture-mobile','.heading-6, h6, .h-block h6','font-weight','600','','',''),(479777,'furniture-mobile','.b-info .info strong','font-weight','400','','','.b-info'),(479778,'furniture-mobile','.p-blog-index .nav-links .screen-reader-text','font-weight','700','','','.p-blog-index'),(479779,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','font-weight','normal','','','.p-account-subscription-historyinfo'),(479780,'furniture-mobile','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(479781,'furniture-mobile','.order-summary .price-row.ot_coupon .title','font-weight','bold','3','','.order-summary'),(479782,'furniture-mobile','.w-personal-gift-status-bar .start-label','font-weight','bold','','','.w-personal-gift-status-bar'),(479783,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','font-weight','600','','','.b-menu-style-2'),(479784,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','font-weight','600','','','.b-menu-style-2'),(479785,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-weight','600','','','.b-menu-style-2'),(479786,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-weight','300','3','','.b-menu-style-2'),(479787,'furniture-mobile','.b-personal-catalog-popup #personal_catalog_popup','font-weight','normal','','','.b-personal-catalog-popup'),(479788,'furniture-mobile','.b-trade-approval .middle-form label','font-weight','600','','','.b-trade-approval'),(479789,'furniture-mobile','.batchPr .batch-selected-products-empty','font-weight','600','','','.batchPr'),(479790,'furniture-mobile','.batchPr .batch-selected-products-total','font-weight','600','','','.batchPr'),(479791,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-weight','normal','3','','.w-catalog-compare'),(479792,'furniture-mobile','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-weight','600','','','.w-delivery-day'),(479793,'furniture-mobile','.w-delivery-day .ends-date','font-weight','600','','','.w-delivery-day'),(479794,'furniture-mobile','.w-delivery-day .title','font-weight','bold','','','.w-delivery-day'),(479795,'furniture-mobile','.w-delivery-day .left-text-left','font-weight','600','','','.w-delivery-day'),(479796,'furniture-mobile','.w-delivery-day .left-text-right','font-weight','600','','','.w-delivery-day'),(479797,'furniture-mobile','.w-cart .cart-box-link','font-weight','normal','3','','.w-cart'),(479798,'furniture-mobile','.w-cart .cart-box-link','font-weight','bold','','','.w-cart'),(479799,'furniture-mobile','.w-account .my-acc-link','font-weight','normal','3','','.w-account'),(479800,'furniture-mobile','.tripleBanner .w-html_box > div:nth-child(2)','font-weight','700','','','.tripleBanner'),(479801,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .price','font-weight','700','','','.b-products-listing'),(479802,'furniture-mobile','.w-search .search-ico','font-weight','normal','2885,3','','.w-search'),(479803,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','font-weight','normal','2885,3','','.b-menu-style-3'),(479804,'furniture-mobile','.w-cart-listing .item div.price','font-weight','bold','','','.w-cart-listing'),(479805,'furniture-mobile','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','font-weight','400','','','.b-products-listing'),(479806,'furniture-mobile','.w-filters .head-filter-widget','font-weight','700','','','.w-filters'),(479807,'furniture-mobile','.w-filters .filter-box-head','font-weight','700','','','.w-filters'),(479808,'furniture-mobile','.w-subscribers .btn-submit','font-weight','600','','','.w-subscribers'),(479809,'furniture-mobile','.w-quote .cart-box-link','font-weight','bold','','','.w-quote'),(479810,'furniture-mobile','.w-quote .cart-box-link','font-weight','normal','3','','.w-quote'),(479811,'furniture-mobile','.w-quote .cart-total','font-weight','600','','','.w-quote'),(479812,'furniture-mobile','.w-quote .multicart .title','font-weight','600','','','.w-quote'),(479813,'furniture-mobile','.w-quote .price','font-weight','600','','','.w-quote'),(479814,'furniture-mobile','.w-quote .sub-total-row','font-weight','600','','','.w-quote'),(479815,'furniture-mobile','.w-product-personal-catalog-button .btn','font-weight','400','','','.w-product-personal-catalog-button'),(479816,'furniture-mobile','.w-product-sale-ends .ends-date','font-weight','600','','','.w-product-sale-ends'),(479817,'furniture-mobile','.w-product-sale-ends .left-count-days','font-weight','600','','','.w-product-sale-ends'),(479818,'furniture-mobile','.w-product-sale-ends .left-count-hours','font-weight','600','','','.w-product-sale-ends'),(479819,'furniture-mobile','.w-product-sale-ends .left-text-left','font-weight','600','','','.w-product-sale-ends'),(479820,'furniture-mobile','.w-product-sale-ends .left-text-right','font-weight','600','','','.w-product-sale-ends'),(479821,'furniture-mobile','.w-tabs .tab-a','font-weight','700','','','.w-tabs'),(479822,'furniture-mobile','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','font-weight','400','3','','.w-product-buttons'),(479823,'furniture-mobile','.w-product-bonus-points > div','font-weight','bold','','','.w-product-bonus-points'),(479824,'furniture-mobile','.warrantyProduct .title','font-weight','700','','','.warrantyProduct'),(479825,'furniture-mobile','.w-files-catalog-widgets-files-catalog .name','font-weight','600','','','.w-files-catalog-widgets-files-catalog'),(479826,'furniture-mobile','.w-files-catalog-widgets-files-list .name','font-weight','600','','','.w-files-catalog-widgets-files-list'),(479827,'furniture-mobile','.w-sample .cart-box-link','font-weight','bold','','','.w-sample'),(479828,'furniture-mobile','.w-sample .cart-box-link','font-weight','normal','3','','.w-sample'),(479829,'furniture-mobile','.w-sample .cart-total','font-weight','600','','','.w-sample'),(479830,'furniture-mobile','.w-sample .multicart .title','font-weight','600','','','.w-sample'),(479831,'furniture-mobile','.w-sample .price','font-weight','600','','','.w-sample'),(479832,'furniture-mobile','.w-sample .strong','font-weight','400','','','.w-sample'),(479833,'furniture-mobile','.w-sample .sub-total-row','font-weight','600','','','.w-sample'),(479834,'furniture-mobile','.w-filters-simple .integrate-price','font-weight','bold','','','.w-filters-simple'),(479835,'furniture-mobile','.w-cart-sub-total .title','font-weight','700','','','.w-cart-sub-total'),(479836,'furniture-mobile','.w-cart-sub-total .price','font-weight','700','','','.w-cart-sub-total'),(479837,'furniture-mobile','.w-cart-gift-certificate .heading-4','font-weight','700','','','.w-cart-gift-certificate'),(479838,'furniture-mobile','.w-cart-order-reference .heading-4','font-weight','700','','','.w-cart-order-reference'),(479839,'furniture-mobile','.w-product-attributes .radio-attributes > span','font-weight','700','','','.w-product-attributes'),(479840,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','font-weight','inherit','','','.b-products-listing'),(479841,'furniture-mobile','.b-pagination .pagination .active a, .b-pagination .pagination .active span','font-weight','bold','','','.b-pagination'),(479842,'furniture-mobile','.b-pagination .pagination span','font-weight','700','2','','.b-pagination'),(479843,'furniture-mobile','.w-product-multi-inventory .radio-attributes > span','font-weight','700','','','.w-product-multi-inventory'),(479844,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','font-weight','700','','','.w-product-multi-inventory'),(479845,'furniture-mobile','.b-products-listing .products-listing.list-rows .stock','font-weight','700','','','.b-products-listing'),(479846,'furniture-mobile','.b-products-listing .products-listing.list-b2b .stock','font-weight','700','','','.b-products-listing'),(479847,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','font-weight','700','','','.b-products-listing'),(479848,'furniture-mobile','.b-products-listing .products-listing .radio-attributes > span','font-weight','700','','','.b-products-listing'),(479849,'furniture-mobile','.b-products-listing .products-listing .attributes .item-title','font-weight','700','','','.b-products-listing'),(479850,'furniture-mobile','.w-product-collection .stock > span','font-weight','700','','','.w-product-collection'),(479851,'furniture-mobile','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(479852,'furniture-mobile','.w-product-collection .title','font-weight','bold','','','.w-product-collection'),(479853,'furniture-mobile','.w-product-collection .together','font-weight','700','','','.w-product-collection'),(479854,'furniture-mobile','.w-product-collection .right-area .btn','font-weight','400','3','','.w-product-collection'),(479855,'furniture-mobile','.w-product-collection .right-area .btn-2','font-weight','400','3','','.w-product-collection'),(479856,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','font-weight','700','','','.w-product-attributes'),(479857,'furniture-mobile','.w-product-in-bundles .bundle_name','font-weight','700','','','.w-product-in-bundles'),(479858,'furniture-mobile','.w-product-groups .radioBoxHead','font-weight','700','','','.w-product-groups'),(479859,'furniture-mobile','.w-product-groups .val1','font-weight','500','','','.w-product-groups'),(479860,'furniture-mobile','.w-product-groups .radioBox label .containerBlock img + .name + .val2','font-weight','700','','','.w-product-groups'),(479861,'furniture-mobile','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(479862,'furniture-mobile','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(479863,'furniture-mobile','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(479864,'furniture-mobile','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','font-weight','400','3','','.w-product-custom-bundle'),(479865,'furniture-mobile','.w-delivery-location-top-location-list .deliveryName','font-weight','700','','','.w-delivery-location-top-location-list'),(479866,'furniture-mobile','.w-delivery-location-location-list .deliveryName','font-weight','700','','','.w-delivery-location-location-list'),(479867,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(479868,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','font-weight','600','','','.w-delivery-location-location-list'),(479869,'furniture-mobile','.w-blog-widget-recent-posts > div a','font-weight','700','','','.w-blog-widget-recent-posts'),(479870,'furniture-mobile','.w-delivery-location-featured-list .deliveryName','font-weight','700','','','.w-delivery-location-featured-list'),(479871,'furniture-mobile','.w-wedding-registry-widgets-search-form .closeable-heading','font-weight','700','','','.w-wedding-registry-widgets-search-form'),(479872,'furniture-mobile','.w-wedding-registry-widgets-search-form .closeable-heading','font-weight','400','3','','.w-wedding-registry-widgets-search-form'),(479873,'furniture-mobile','.w-sale-category .ends-date','font-weight','600','','','.w-sale-category'),(479874,'furniture-mobile','.w-sale-category .left-count-days','font-weight','600','','','.w-sale-category'),(479875,'furniture-mobile','.w-sale-category .left-count-hours','font-weight','600','','','.w-sale-category'),(479876,'furniture-mobile','.w-sale-category .left-text-left','font-weight','600','','','.w-sale-category'),(479877,'furniture-mobile','.w-sale-category .left-text-right','font-weight','600','','','.w-sale-category'),(479878,'furniture-mobile','.w-sale-category .name','font-weight','bold','','','.w-sale-category'),(479879,'furniture-mobile','.w-sale-category .special-price','font-weight','600','','','.w-sale-category'),(479880,'furniture-mobile','.w-wedding-registry-widgets-delete-link .delete-registry','font-weight','400','3','','.w-wedding-registry-widgets-delete-link'),(479881,'furniture-mobile','.w-wedding-registry-widgets-edit-link .edit-registry','font-weight','400','3','','.w-wedding-registry-widgets-edit-link'),(479882,'furniture-mobile','.w-wedding-registry-widgets-share-link a','font-weight','400','3','','.w-wedding-registry-widgets-share-link'),(479883,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description + div','font-weight','700','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(479884,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description + div','font-weight','700','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(479885,'furniture-mobile','.w-delivery-location-list-by-page .name','font-weight','700','','','.w-delivery-location-list-by-page'),(479886,'furniture-mobile','.w-delivery-location-cross-pages .name','font-weight','700','','','.w-delivery-location-cross-pages'),(479887,'furniture-mobile','.w-catalog-delivery-locations .name','font-weight','700','','','.w-catalog-delivery-locations'),(479888,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','font-weight','700','','','.w-wedding-registry-widgets-search-paging'),(479889,'furniture-mobile','.w-wedding-registry-widgets-search-registry-button .edit-registry','font-weight','700','','','.w-wedding-registry-widgets-search-registry-button'),(479890,'furniture-mobile','.w-wedding-registry-widgets-search-registry-button a','font-weight','400','3','','.w-wedding-registry-widgets-search-registry-button'),(479891,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','font-weight','700','','','.w-product-bonus-points'),(479892,'furniture-mobile','.w-product-designer-designer .grnamebox .title-sortable','font-weight','700','','','.w-product-designer-designer'),(479893,'furniture-mobile','.w-press-reviews-widgets-press-reviews .author','font-weight','bold','','','.w-press-reviews-widgets-press-reviews'),(479894,'furniture-mobile','.w-press-reviews-widgets-press-reviews .title a','font-weight','bold','','','.w-press-reviews-widgets-press-reviews'),(479895,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .product-name','font-weight','600','','','.w-press-reviews-widgets-press-reviews-list'),(479896,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .short-description','font-weight','700','','','.w-press-reviews-widgets-press-reviews-list'),(479897,'furniture-mobile','.w-support-system-filter .filter_cats.level-0 > li > a','font-weight','700','','','.w-support-system-filter'),(479898,'furniture-mobile','.w-rma-returns-history .column .title','font-weight','normal','','','.w-rma-returns-history'),(479899,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','font-weight','600','','','.b-menu-style-1'),(479900,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','font-weight','700','','','.b-products-listing'),(479901,'furniture-mobile','.w-predefined-promotion .heading-3','font-weight','bold','','','.w-predefined-promotion'),(479902,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .heading','font-weight','300','','','.w-predefined-promotion'),(479903,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range .value','font-weight','bold','','','.w-predefined-promotion'),(479904,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .heading','font-weight','300','','','.w-predefined-promotion'),(479905,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty .value','font-weight','bold','','','.w-predefined-promotion'),(479906,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder .value','font-weight','bold','','','.w-predefined-promotion'),(479907,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .heading','font-weight','300','','','.w-predefined-promotion'),(479908,'furniture-mobile','.w-predefined-promotion .promo-date','font-weight','500','','','.w-predefined-promotion'),(479909,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount .value','font-weight','700','','','.w-predefined-promotion'),(479910,'furniture-mobile','.w-predefined-promotion .promo-salemaker .promo-conditions','font-weight','300','','','.w-predefined-promotion'),(479911,'furniture-mobile','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading','font-weight','300','','','.w-predefined-promotion'),(479912,'furniture-mobile','.mainBanner .title','font-weight','700','','','.mainBanner'),(479913,'furniture-mobile','.mainBanner .title > span','font-weight','700','','','.mainBanner'),(479914,'furniture-mobile','.mainBanner .topBox > .left','font-weight','700','','','.mainBanner'),(479915,'furniture-mobile','.lowestPricedBox .w-banner .ybg .descr','font-weight','700','','','.lowestPricedBox'),(479916,'furniture-mobile','.lowestPricedBox .w-banner .ybg .title','font-weight','700','','','.lowestPricedBox'),(479917,'furniture-mobile','.shopByCollectionBox .content .title','font-weight','700','','','.shopByCollectionBox'),(479918,'furniture-mobile','.shopByCollectionBox .content .title span','font-weight','700','','','.shopByCollectionBox'),(479919,'furniture-mobile','.account-address-book .address_book h2','font-weight','normal','','','.account-address-book'),(479920,'furniture-mobile','.account-order-history .not_fully_paid_td','font-weight','700','','','.account-order-history'),(479921,'furniture-mobile','.account-order-history .order_history_table h2','font-weight','normal','','','.account-order-history'),(479922,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','font-weight','normal','3','','.account-order-history-info'),(479923,'furniture-mobile','.account-order-history-info .not_fully_paid_td','font-weight','700','','','.account-order-history-info'),(479924,'furniture-mobile','.account-order-history-info .popup-tracking-number-link','font-weight','600','','','.account-order-history-info'),(479925,'furniture-mobile','.account-order-history-info .trackings-nambers-label','font-weight','600','','','.account-order-history-info'),(479926,'furniture-mobile','.account-index .account_info .info .info_span','font-weight','bold','','','.account-index'),(479927,'furniture-mobile','.account-index .account_page h4','font-weight','normal','3','','.account-index'),(479928,'furniture-mobile','.account-index .ai_title','font-weight','bold','','','.account-index'),(479929,'furniture-mobile','.account-index .date_value strong','font-weight','normal','','','.account-index'),(479930,'furniture-mobile','.account-index .not_fully_paid_td','font-weight','700','','','.account-index'),(479931,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-weight','normal','3','','.account-order-pay'),(479932,'furniture-mobile','.account-order-pay .not_fully_paid_td','font-weight','700','','','.account-order-pay'),(479933,'furniture-mobile','.account-samples .not_fully_paid_td','font-weight','700','','','.account-samples'),(479934,'furniture-mobile','.account-samples .order_history_table h2','font-weight','normal','','','.account-samples'),(479935,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-weight','normal','3','','.account-sample-info'),(479936,'furniture-mobile','.account-sample-info .not_fully_paid_td','font-weight','700','','','.account-sample-info'),(479937,'furniture-mobile','.account-sample-info .popup-tracking-number-link','font-weight','600','','','.account-sample-info'),(479938,'furniture-mobile','.account-sample-info .trackings-nambers-label','font-weight','600','','','.account-sample-info'),(479939,'furniture-mobile','.catalog-product-wrap .pn-direction','font-weight','600','','','.catalog-product-wrap'),(479940,'furniture-mobile','.shopping-cart-index .cart-page .empty','font-weight','700','','','.shopping-cart-index'),(479941,'furniture-mobile','.checkout-index-wrap .cardinfo-label','font-weight','bold','','','.checkout-index-wrap'),(479942,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','font-weight','600','','','.checkout-index-wrap'),(479943,'furniture-mobile','.checkout-index-wrap .edit-address-popup .edit-ab','font-weight','500','','','.checkout-index-wrap'),(479944,'furniture-mobile','.no-found','font_size_measure','em','','',''),(479945,'furniture-mobile','.w-checkout-create-account .account-benefits','font_size_measure','em','','','.w-checkout-create-account'),(479946,'furniture-mobile','.view-all .btn','font_size_measure','em','4','',''),(479947,'furniture-mobile','.price .old','font_size_measure','em','','',''),(479948,'furniture-mobile','.btn-edit','font_size_measure','em','3','',''),(479952,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font_size_measure','%','','','.b-select-suggest'),(479953,'furniture-mobile','.b-select-suggest .select2-search input','font_size_measure','em','','','.b-select-suggest'),(479956,'furniture-mobile','.w-cart .cart-total','font_size_measure','em','','','.w-cart'),(479958,'furniture-mobile','.w-quote .cart-total','font_size_measure','em','','','.w-quote'),(479959,'furniture-mobile','.w-quote .qty','font_size_measure','em','4','','.w-quote'),(479960,'furniture-mobile','.w-cart .qty','font_size_measure','em','4','','.w-cart'),(479961,'furniture-mobile','.w-sample .cart-total','font_size_measure','em','','','.w-sample'),(479962,'furniture-mobile','.w-sample .qty','font_size_measure','em','4','','.w-sample'),(479963,'furniture-mobile','.w-product-bundle .bundle_price .old','font_size_measure','em','','','.w-product-bundle'),(479964,'furniture-mobile','.w-product-in-bundles .bundle_price .old','font_size_measure','em','','','.w-product-in-bundles'),(479965,'furniture-mobile','.mainBanner .bottomBox .btn','font_size_measure','vw','','','.mainBanner'),(479966,'furniture-mobile','.mainBanner .title','font_size_measure','vw','','','.mainBanner'),(479967,'furniture-mobile','.mainBanner .title > span','font_size_measure','vw','','','.mainBanner'),(479968,'furniture-mobile','.mainBanner .topBox > .left','font_size_measure','vw','','','.mainBanner'),(479969,'furniture-mobile','.mainBanner .bottomBox .btn','font_size_measure','vw','2876','','.mainBanner'),(479970,'furniture-mobile','.mainBanner .title','font_size_measure','vw','2876','','.mainBanner'),(479971,'furniture-mobile','.mainBanner .title > span','font_size_measure','vw','2876','','.mainBanner'),(479972,'furniture-mobile','.mainBanner .topBox > .left','font_size_measure','vw','2876','','.mainBanner'),(479973,'furniture-mobile','.lowestPricedBox .w-banner .ybg .descr','font_size_measure','vw','','','.lowestPricedBox'),(479974,'furniture-mobile','.lowestPricedBox .w-banner .ybg .title','font_size_measure','vw','','','.lowestPricedBox'),(479975,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','font_size_measure','vw','2890','','.lowestPricedBox'),(479976,'furniture-mobile','.w-promotions .prom-multi-discount .list','grid-auto-flow','dense','','','.w-promotions'),(479977,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .list','grid-auto-flow','dense','','','.w-predefined-promotion'),(479978,'furniture-mobile','.w-promotions .prom-multi-discount .promo-group-4','grid-column','span 4','','','.w-promotions'),(479979,'furniture-mobile','.w-promotions .prom-multi-discount .promo-group-2','grid-column','span 2','','','.w-promotions'),(479980,'furniture-mobile','.w-promotions .prom-multi-discount .promo-group-3','grid-column','span 3','','','.w-promotions'),(479981,'furniture-mobile','.w-cart-listing .points','grid-column','2 / 5','2876','','.w-cart-listing'),(479982,'furniture-mobile','.w-cart-listing .qty','grid-column','1 / 3','2876','','.w-cart-listing'),(479983,'furniture-mobile','.w-cart-listing .item .gift-wrap','grid-column','3 / 4','2876','','.w-cart-listing'),(479984,'furniture-mobile','.w-cart-listing .name','grid-column','2 / 4','2876','','.w-cart-listing'),(479985,'furniture-mobile','.w-cart-listing .price','grid-column','3 / 5','2876','','.w-cart-listing'),(479986,'furniture-mobile','.w-reviews .author','grid-column','2/4','','','.w-reviews'),(479987,'furniture-mobile','.w-cart-listing .promos-info','grid-column','1 / 2','2876','','.w-cart-listing'),(479988,'furniture-mobile','.w-reviews-content .rating','grid-column','2','','','.w-reviews-content'),(479989,'furniture-mobile','.w-reviews-content .date','grid-column','3','','','.w-reviews-content'),(479990,'furniture-mobile','.w-reviews-content .review','grid-column','2/4','','','.w-reviews-content'),(479991,'furniture-mobile','.w-reviews .date','grid-column','3','','','.w-reviews'),(479992,'furniture-mobile','.w-reviews-content .author','grid-column','2/4','','','.w-reviews-content'),(479993,'furniture-mobile','.w-reviews .product-name','grid-column','2/4','','','.w-reviews'),(479994,'furniture-mobile','.w-reviews .product-image','grid-column','1','','','.w-reviews'),(479995,'furniture-mobile','.w-reviews .rating','grid-column','2','','','.w-reviews'),(479996,'furniture-mobile','.w-reviews .review','grid-column','2/4','','','.w-reviews'),(479997,'furniture-mobile','.w-reviews-content .product-image','grid-column','1','','','.w-reviews-content'),(479998,'furniture-mobile','.w-cart-listing .promos-info','grid-column','2 / 3','','','.w-cart-listing'),(479999,'furniture-mobile','.w-cart-listing .qty','grid-column','4 / 5','','','.w-cart-listing'),(480000,'furniture-mobile','.w-cart-listing .price','grid-column','5 / 6','','','.w-cart-listing'),(480001,'furniture-mobile','.w-cart-listing .name','grid-column','3 / 4','','','.w-cart-listing'),(480002,'furniture-mobile','.w-cart-listing .image','grid-column','2 / 3','','','.w-cart-listing'),(480003,'furniture-mobile','.w-cart-listing .points','grid-column','4 / 6','','','.w-cart-listing'),(480004,'furniture-mobile','.w-cart-listing .item .gift-wrap','grid-column','4 / 6','','','.w-cart-listing'),(480005,'furniture-mobile','.w-cart-listing .actions','grid-column','3 / 6','','','.w-cart-listing'),(480006,'furniture-mobile','.w-cart-listing .no-price .qty','grid-column','4 / 6','','','.w-cart-listing'),(480007,'furniture-mobile','.w-reviews-content .product-name','grid-column','2/4','','','.w-reviews-content'),(480008,'furniture-mobile','.w-cart-listing .image','grid-column','1 / 2','2876','','.w-cart-listing'),(480009,'furniture-mobile','.w-cart-listing .remove','grid-column','1 / 2','','','.w-cart-listing'),(480010,'furniture-mobile','.w-cart-listing .item > div.actions','grid-column','1 / 4','2876','','.w-cart-listing'),(480011,'furniture-mobile','.w-cart-listing .no-price .qty','grid-column','2/4','2885','','.w-cart-listing'),(480012,'furniture-mobile','.w-sample-products .w-cart-listing .item .qty','grid-column','2 / 4','2876','','.w-sample-products'),(480013,'furniture-mobile','.w-quote-products .cart-listing .qty','grid-column','4 / 6','','','.w-quote-products'),(480014,'furniture-mobile','.w-account-personal-catalog .check-box','grid-column','1 / 2','','','.w-account-personal-catalog'),(480015,'furniture-mobile','.w-account-personal-catalog .remove','grid-column','1 / 2','','','.w-account-personal-catalog'),(480016,'furniture-mobile','.w-account-personal-catalog .price','grid-column','4 / 5','','','.w-account-personal-catalog'),(480017,'furniture-mobile','.w-account-personal-catalog .list-row-action','grid-column','3 / 4','','','.w-account-personal-catalog'),(480018,'furniture-mobile','.w-account-personal-catalog .image','grid-column','2 / 3','','','.w-account-personal-catalog'),(480019,'furniture-mobile','.w-account-personal-catalog .name','grid-column','3 / 4','','','.w-account-personal-catalog'),(480020,'furniture-mobile','.w-account-personal-catalog .buy-box','grid-column','5 / 6','','','.w-account-personal-catalog'),(480021,'furniture-mobile','.w-account-personal-catalog .qty-input','grid-column','4 / 5','','','.w-account-personal-catalog'),(480022,'furniture-mobile','.w-account-personal-catalog .w-cart-listing .item .remove','grid-column','1 / 2','2885','','.w-account-personal-catalog'),(480023,'furniture-mobile','.w-account-personal-catalog .price','grid-column','2 / 3','2876','','.w-account-personal-catalog'),(480024,'furniture-mobile','.w-account-personal-catalog .remove','grid-column','1 / 2','2876','','.w-account-personal-catalog'),(480025,'furniture-mobile','.w-account-personal-catalog .list-row-action','grid-column','2 / 4','2876','','.w-account-personal-catalog'),(480026,'furniture-mobile','.w-account-personal-catalog .image','grid-column','2 / 3','2876','','.w-account-personal-catalog'),(480027,'furniture-mobile','.w-account-personal-catalog .name','grid-column','3 / 4','2876','','.w-account-personal-catalog'),(480028,'furniture-mobile','.w-account-personal-catalog .buy-box','grid-column','2 / 4','2876','','.w-account-personal-catalog'),(480029,'furniture-mobile','.w-account-personal-catalog .qty-input','grid-column','3 / 4','2876','','.w-account-personal-catalog'),(480030,'furniture-mobile','.w-press-reviews-widgets-press-reviews .author','grid-column','2/4','','','.w-press-reviews-widgets-press-reviews'),(480031,'furniture-mobile','.w-press-reviews-widgets-press-reviews .date','grid-column','3','','','.w-press-reviews-widgets-press-reviews'),(480032,'furniture-mobile','.w-press-reviews-widgets-press-reviews .image','grid-column','1','','','.w-press-reviews-widgets-press-reviews'),(480033,'furniture-mobile','.w-press-reviews-widgets-press-reviews .rating','grid-column','2','','','.w-press-reviews-widgets-press-reviews'),(480034,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','grid-column','2/4','','','.w-press-reviews-widgets-press-reviews'),(480035,'furniture-mobile','.w-press-reviews-widgets-press-reviews .title','grid-column','2/4','','','.w-press-reviews-widgets-press-reviews'),(480036,'furniture-mobile','.w-press-reviews-widgets-press-reviews .author','grid-column','1/2','2876','','.w-press-reviews-widgets-press-reviews'),(480037,'furniture-mobile','.w-press-reviews-widgets-press-reviews .date','grid-column','1/2','2876','','.w-press-reviews-widgets-press-reviews'),(480038,'furniture-mobile','.w-press-reviews-widgets-press-reviews .image','grid-column','1/2','2876','','.w-press-reviews-widgets-press-reviews'),(480039,'furniture-mobile','.w-press-reviews-widgets-press-reviews .rating','grid-column','1/2','2876','','.w-press-reviews-widgets-press-reviews'),(480040,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','grid-column','1/2','2876','','.w-press-reviews-widgets-press-reviews'),(480041,'furniture-mobile','.w-press-reviews-widgets-press-reviews .title','grid-column','1/2','2876','','.w-press-reviews-widgets-press-reviews'),(480042,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-group-2','grid-column','span 2','','','.w-predefined-promotion'),(480043,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-group-3','grid-column','span 3','','','.w-predefined-promotion'),(480044,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-group-4','grid-column','span 4','','','.w-predefined-promotion'),(480045,'furniture-mobile','.w-quote-products .w-cart-listing .name','grid-column','3 / 5','','','.w-quote-products'),(480046,'furniture-mobile','.w-quote-products .cart-listing .qty','grid-column','2 / 6','2885','','.w-quote-products'),(480047,'furniture-mobile','.w-quote-products .w-cart-listing .name','grid-column','2 / 6','2885','','.w-quote-products'),(480048,'furniture-mobile','.w-promotions .content','grid-column-end','3','','','.w-promotions'),(480049,'furniture-mobile','.w-predefined-promotion .content','grid-column-end','3','','','.w-predefined-promotion'),(480050,'furniture-mobile','.w-promotions .heading','grid-column-start','1','','','.w-promotions'),(480051,'furniture-mobile','.w-promotions .condition','grid-column-start','2','','','.w-promotions'),(480052,'furniture-mobile','.w-promotions .content','grid-column-start','1','','','.w-promotions'),(480053,'furniture-mobile','.w-predefined-promotion .condition','grid-column-start','2','','','.w-predefined-promotion'),(480054,'furniture-mobile','.w-predefined-promotion .content','grid-column-start','1','','','.w-predefined-promotion'),(480055,'furniture-mobile','.w-predefined-promotion .heading','grid-column-start','1','','','.w-predefined-promotion'),(480056,'furniture-mobile','.w-account-personal-catalog .remove','grid-column_important','important','2876','','.w-account-personal-catalog'),(480057,'furniture-mobile','.w-promotions .prom-multi-discount .products','grid-gap','4px','','','.w-promotions'),(480058,'furniture-mobile','.w-promotions .prom-multi-discount .list','grid-gap','20px','','','.w-promotions'),(480059,'furniture-mobile','.w-promotions .nextdiscount .content','grid-gap','3px','','','.w-promotions'),(480060,'furniture-mobile','.w-predefined-promotion .nextdiscount .content','grid-gap','3px','','','.w-predefined-promotion'),(480061,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .list','grid-gap','20px','','','.w-predefined-promotion'),(480062,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .products','grid-gap','4px','','','.w-predefined-promotion'),(480063,'furniture-mobile','.w-cart-listing .name','grid-row','1 / 2','2876','','.w-cart-listing'),(480064,'furniture-mobile','.w-cart-listing .promos-info','grid-row','1 / 5','2876','','.w-cart-listing'),(480065,'furniture-mobile','.w-cart-listing .qty','grid-row','5 / 6','2876','','.w-cart-listing'),(480066,'furniture-mobile','.w-cart-listing .price','grid-row','5 / 6','2876','','.w-cart-listing'),(480067,'furniture-mobile','.w-reviews-content .product-name','grid-row','2','','','.w-reviews-content'),(480068,'furniture-mobile','.w-reviews-content .date','grid-row','1','','','.w-reviews-content'),(480069,'furniture-mobile','.w-reviews .author','grid-row','4','','','.w-reviews'),(480070,'furniture-mobile','.w-reviews .date','grid-row','1','','','.w-reviews'),(480071,'furniture-mobile','.w-reviews-content .author','grid-row','4','','','.w-reviews-content'),(480072,'furniture-mobile','.w-reviews-content .review','grid-row','3','','','.w-reviews-content'),(480073,'furniture-mobile','.w-reviews .product-image','grid-row','1/6','','','.w-reviews'),(480074,'furniture-mobile','.w-reviews .product-name','grid-row','2','','','.w-reviews'),(480075,'furniture-mobile','.w-reviews .rating','grid-row','1','','','.w-reviews'),(480076,'furniture-mobile','.w-reviews .review','grid-row','3','','','.w-reviews'),(480077,'furniture-mobile','.w-reviews-content .rating','grid-row','1','','','.w-reviews-content'),(480078,'furniture-mobile','.w-reviews-content .product-image','grid-row','1/6','','','.w-reviews-content'),(480079,'furniture-mobile','.w-cart-listing .remove','grid-row','1 / 6','','','.w-cart-listing'),(480080,'furniture-mobile','.w-cart-listing .promos-info','grid-row','1 / 6','','','.w-cart-listing'),(480081,'furniture-mobile','.w-cart-listing .image','grid-row','1 / 6','','','.w-cart-listing'),(480082,'furniture-mobile','.w-cart-listing .name','grid-row','1 / 5','','','.w-cart-listing'),(480083,'furniture-mobile','.w-cart-listing .price','grid-row','1 / 2','','','.w-cart-listing'),(480084,'furniture-mobile','.w-cart-listing .actions','grid-row','5 / 6','','','.w-cart-listing'),(480085,'furniture-mobile','.w-cart-listing .qty','grid-row','1 / 2','','','.w-cart-listing'),(480086,'furniture-mobile','.w-cart-listing .image','grid-row','1 / 4','2876','','.w-cart-listing'),(480087,'furniture-mobile','.w-cart-listing .points','grid-row','2 / 3','2876','','.w-cart-listing'),(480088,'furniture-mobile','.w-cart-listing .item .remove','grid-row','2/3','2885','','.w-cart-listing'),(480089,'furniture-mobile','.w-cart-listing .item > div.actions','grid-row','6 / 7','2876','','.w-cart-listing'),(480090,'furniture-mobile','.w-cart-listing .no-price .qty','grid-row','2/3','2885','','.w-cart-listing'),(480091,'furniture-mobile','.w-sample-products .w-cart-listing .item .qty','grid-row','2 / 3','2876','','.w-sample-products'),(480092,'furniture-mobile','.w-account-personal-catalog .check-box','grid-row','1 / 2','','','.w-account-personal-catalog'),(480093,'furniture-mobile','.w-account-personal-catalog .remove','grid-row','3 / 4','','','.w-account-personal-catalog'),(480094,'furniture-mobile','.w-account-personal-catalog .price','grid-row','2 / 4','','','.w-account-personal-catalog'),(480095,'furniture-mobile','.w-account-personal-catalog .list-row-action','grid-row','3 / 4','','','.w-account-personal-catalog'),(480096,'furniture-mobile','.w-account-personal-catalog .image','grid-row','1 / 4','','','.w-account-personal-catalog'),(480097,'furniture-mobile','.w-account-personal-catalog .name','grid-row','1 / 3','','','.w-account-personal-catalog'),(480098,'furniture-mobile','.w-account-personal-catalog .buy-box','grid-row','1 / 4','','','.w-account-personal-catalog'),(480099,'furniture-mobile','.w-account-personal-catalog .qty-input','grid-row','1 / 2','','','.w-account-personal-catalog'),(480100,'furniture-mobile','.w-account-personal-catalog .w-cart-listing .item .remove','grid-row','3 / 4','2885','','.w-account-personal-catalog'),(480101,'furniture-mobile','.w-account-personal-catalog .price','grid-row','2 / 3','2876','','.w-account-personal-catalog'),(480102,'furniture-mobile','.w-account-personal-catalog .remove','grid-row','4 / 5','2876','','.w-account-personal-catalog'),(480103,'furniture-mobile','.w-account-personal-catalog .list-row-action','grid-row','4 / 5','2876','','.w-account-personal-catalog'),(480104,'furniture-mobile','.w-account-personal-catalog .image','grid-row','1 / 2','2876','','.w-account-personal-catalog'),(480105,'furniture-mobile','.w-account-personal-catalog .name','grid-row','1 / 2','2876','','.w-account-personal-catalog'),(480106,'furniture-mobile','.w-account-personal-catalog .buy-box','grid-row','3 / 4','2876','','.w-account-personal-catalog'),(480107,'furniture-mobile','.w-account-personal-catalog .qty-input','grid-row','2 / 3','2876','','.w-account-personal-catalog'),(480108,'furniture-mobile','.w-press-reviews-widgets-press-reviews .author','grid-row','4','','','.w-press-reviews-widgets-press-reviews'),(480109,'furniture-mobile','.w-press-reviews-widgets-press-reviews .date','grid-row','1','','','.w-press-reviews-widgets-press-reviews'),(480110,'furniture-mobile','.w-press-reviews-widgets-press-reviews .image','grid-row','1/6','','','.w-press-reviews-widgets-press-reviews'),(480111,'furniture-mobile','.w-press-reviews-widgets-press-reviews .rating','grid-row','1','','','.w-press-reviews-widgets-press-reviews'),(480112,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','grid-row','3','','','.w-press-reviews-widgets-press-reviews'),(480113,'furniture-mobile','.w-press-reviews-widgets-press-reviews .title','grid-row','2','','','.w-press-reviews-widgets-press-reviews'),(480114,'furniture-mobile','.w-press-reviews-widgets-press-reviews .author','grid-row','6/7','2876','','.w-press-reviews-widgets-press-reviews'),(480115,'furniture-mobile','.w-press-reviews-widgets-press-reviews .date','grid-row','2/3','2876','','.w-press-reviews-widgets-press-reviews'),(480116,'furniture-mobile','.w-press-reviews-widgets-press-reviews .image','grid-row','1/2','2876','','.w-press-reviews-widgets-press-reviews'),(480117,'furniture-mobile','.w-press-reviews-widgets-press-reviews .rating','grid-row','3/4','2876','','.w-press-reviews-widgets-press-reviews'),(480118,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','grid-row','5/6','2876','','.w-press-reviews-widgets-press-reviews'),(480119,'furniture-mobile','.w-press-reviews-widgets-press-reviews .title','grid-row','4/5','2876','','.w-press-reviews-widgets-press-reviews'),(480120,'furniture-mobile','.w-quote-products .cart-listing .qty','grid-row','2 / 6','2885','','.w-quote-products'),(480121,'furniture-mobile','.w-promotions .content','grid-row-start','2','','','.w-promotions'),(480122,'furniture-mobile','.w-promotions .condition','grid-row-start','1','','','.w-promotions'),(480123,'furniture-mobile','.w-promotions .heading','grid-row-start','1','','','.w-promotions'),(480124,'furniture-mobile','.w-predefined-promotion .condition','grid-row-start','1','','','.w-predefined-promotion'),(480125,'furniture-mobile','.w-predefined-promotion .content','grid-row-start','2','','','.w-predefined-promotion'),(480126,'furniture-mobile','.w-predefined-promotion .heading','grid-row-start','1','','','.w-predefined-promotion'),(480127,'furniture-mobile','.w-account-personal-catalog .remove','grid-row_important','important','2876','','.w-account-personal-catalog'),(480128,'furniture-mobile','.w-promotions .prom-multi-discount .list','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(480129,'furniture-mobile','.w-promotions .prom-multi-discount .promo-group-4 .products','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(480130,'furniture-mobile','.w-promotions .prom-multi-discount .promo-group-3 .products','grid-template-columns','1fr 1fr 1fr','','','.w-promotions'),(480131,'furniture-mobile','.w-promotions .prom-multi-discount .products','grid-template-columns','1fr','','','.w-promotions'),(480132,'furniture-mobile','.w-promotions .prom-multi-discount .promo-group-2 .products','grid-template-columns','1fr 1fr','','','.w-promotions'),(480133,'furniture-mobile','.w-promotions .nextdiscount .content','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(480134,'furniture-mobile','.w-reviews-content .item','grid-template-columns','170px 1fr 1fr','','','.w-reviews-content'),(480135,'furniture-mobile','.w-reviews .item','grid-template-columns','140px 1fr 1fr','','','.w-reviews'),(480136,'furniture-mobile','.w-cart-listing .item','grid-template-columns','80px 1fr 150px 130px','2885','','.w-cart-listing'),(480137,'furniture-mobile','.w-cart-listing .item','grid-template-columns','80px 70px 1fr','2876','','.w-cart-listing'),(480138,'furniture-mobile','.w-cart-listing .item, .w-cart-listing .headings','grid-template-columns','50px 120px 1fr 150px 200px','','','.w-cart-listing'),(480139,'furniture-mobile','.w-sample-products .w-cart-listing .item, .w-sample-products .w-cart-listing .headings','grid-template-columns','50px 120px 1fr 150px','','','.w-sample-products'),(480140,'furniture-mobile','.w-sample-products .w-cart-listing .item, .w-sample-products .w-cart-listing .headings','grid-template-columns','80px 70px 1fr','2876','','.w-sample-products'),(480141,'furniture-mobile','.w-account-personal-catalog .w-cart-listing .item','grid-template-columns','50px 120px 1fr 150px 200px','2885','','.w-account-personal-catalog'),(480142,'furniture-mobile','.w-account-personal-catalog .w-cart-listing .item','grid-template-columns','50px 120px 1fr','2876','','.w-account-personal-catalog'),(480143,'furniture-mobile','.w-press-reviews-widgets-press-reviews .item','grid-template-columns','170px 1fr 1fr','','','.w-press-reviews-widgets-press-reviews'),(480144,'furniture-mobile','.w-press-reviews-widgets-press-reviews .item','grid-template-columns','1fr','2876','','.w-press-reviews-widgets-press-reviews'),(480145,'furniture-mobile','.w-predefined-promotion .nextdiscount .content','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-predefined-promotion'),(480146,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .list','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-predefined-promotion'),(480147,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .products','grid-template-columns','1fr','','','.w-predefined-promotion'),(480148,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-group-2 .products','grid-template-columns','1fr 1fr','','','.w-predefined-promotion'),(480149,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-group-3 .products','grid-template-columns','1fr 1fr 1fr','','','.w-predefined-promotion'),(480150,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-group-4 .products','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-predefined-promotion'),(480151,'furniture-mobile','.w-cart-listing .item','grid-template-rows','1fr','2876','','.w-cart-listing'),(480152,'furniture-mobile','.w-cart-listing .item','grid-template-rows','53px 1fr','','','.w-cart-listing'),(480153,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','height','28','','','.b-switch'),(480155,'furniture-mobile','.w-product-promotions select','height','29','','','.w-product-promotions'),(480156,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','height','20','3','','.b-switch'),(480157,'furniture-mobile','.w-compare-box-item .checkbox + span','height','24','','','.w-compare-box-item'),(480158,'furniture-mobile','.w-compare-box-item .checkbox','height','22','','','.w-compare-box-item'),(480159,'furniture-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(480160,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.p-quick-order-index'),(480161,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.p-quick-order-index'),(480162,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','height','35','','','.p-blog-index'),(480163,'furniture-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height','100','','','.w-banner'),(480164,'furniture-mobile','.w-product-images-additional .item-div','height','80','2906','','.w-product-images-additional'),(480165,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','height','22','','','.w-compare-box-item'),(480166,'furniture-mobile','.w-compare-box-item .checkbox + span','height','24','','','.w-compare-box-item'),(480167,'furniture-mobile','.w-compare-box-item .checkbox','height','22','','','.w-compare-box-item'),(480168,'furniture-mobile','.w-promotions .prom-multi-discount .products','height','calc(100% - 25px)','','','.w-promotions'),(480169,'furniture-mobile','.w-promotions .prom-multi-discount .image img','height','auto','','','.w-promotions'),(480170,'furniture-mobile','.w-promotions .promo-salemaker .image img','height','auto','','','.w-promotions'),(480171,'furniture-mobile','.w-promotions .promo-cart-discount .image img','height','auto','','','.w-promotions'),(480172,'furniture-mobile','.b-preloader .preloader','height','40','3','','.b-preloader'),(480173,'furniture-mobile','.b-preloader .preloader','height','100','','','.b-preloader'),(480174,'furniture-mobile','.w-catalog-paging .prev','height','35','','','.w-catalog-paging'),(480175,'furniture-mobile','.w-compare-box-item .checkbox','height','22','','','.w-compare-box-item'),(480176,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','height','22','','','.w-compare-box-item'),(480177,'furniture-mobile','.b-messages .select2-container-multi input.select2-input','height','31','','','.b-messages'),(480178,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','height','35','','',''),(480179,'furniture-mobile','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(480180,'furniture-mobile','.w-product-promotions select','height','29','','','.w-product-promotions'),(480181,'furniture-mobile','.p-payer-order-confirmation .input-wrapper','height','35','','','.p-payer-order-confirmation'),(480182,'furniture-mobile','.p-payer-order-pay .input-wrapper','height','35','','','.p-payer-order-pay'),(480183,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','height','15','3','','.b-switch'),(480184,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','height','15','','','.b-switch'),(480185,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','height','15','','','.b-switch'),(480186,'furniture-mobile','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(480187,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','height','15','','','.b-switch'),(480188,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','height','30','4','','.b-switch'),(480189,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg','height','15','','','.b-switch'),(480190,'furniture-mobile','.b-fancybox #fancybox-loading div','height','44','','','.b-fancybox'),(480191,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','height','60','','','.b-switch'),(480192,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height','100','3','','.b-switch'),(480193,'furniture-mobile','.w-menu-style-1 .menu-ico','height','54','','','.w-menu-style-1'),(480194,'furniture-mobile','.w-menu-slider .menu-ico','height','54','','','.w-menu-slider'),(480195,'furniture-mobile','.w-compare-box-item .checkbox','height','22','','','.w-compare-box-item'),(480196,'furniture-mobile','.w-compare-box-item .checkbox + span','height','24','','','.w-compare-box-item'),(480197,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-toggle','height','40','','','.b-switch'),(480198,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','height','35','','','.p-blog-index'),(480199,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','height','10','','','.w-checkout-shipping-choice'),(480200,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','height','150','','','.w-upload-customer-id-upload-customer-id-form'),(480201,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','height','100','','','.w-upload-customer-id-upload-customer-id-form'),(480202,'furniture-mobile','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(480203,'furniture-mobile','.b-switch .bootstrap-switch','height','28','','','.b-switch'),(480204,'furniture-mobile','.w-menu-slider .menu-ico','height','54','','','.w-menu-slider'),(480205,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','height','10','3','','.b-switch'),(480206,'furniture-mobile','.w-personal-gift-status-bar .progress-bar','height','8','','','.w-personal-gift-status-bar'),(480207,'furniture-mobile','.w-filters .input-checkbox:checked + .checkbox-span','height','24','','','.w-filters'),(480208,'furniture-mobile','.b-info-popup .info-popup div','height','20','3','','.b-info-popup'),(480210,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','height','35','','','.p-blog-index'),(480211,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','height','10','','','.b-switch'),(480212,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','height','10','','','.b-switch'),(480213,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','height','15','4','','.b-switch'),(480214,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-toggle','height','15','','','.b-switch'),(480215,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg','height','10','','','.b-switch'),(480217,'furniture-mobile','.b-form .hide-billing-address','height','100','','','.b-form'),(480219,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','height','16','3','','.b-switch'),(480220,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','height','12','','','.b-select-suggest'),(480221,'furniture-mobile','.w-filters .ui-slider-handle','height','18','','','.w-filters'),(480222,'furniture-mobile','.w-search .button-search','height','50','','','.w-search'),(480223,'furniture-mobile','.w-filters .ui-slider','height','6','','','.w-filters'),(480224,'furniture-mobile','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(480225,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','height','16','','','.b-switch'),(480226,'furniture-mobile','.b-switch .candlestick-wrapper','height','auto','','','.b-switch'),(480227,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg','height','28','','','.b-switch'),(480228,'furniture-mobile','.w-catalog-paging .prev-pages','height','35','','','.w-catalog-paging'),(480229,'furniture-mobile','.w-product-images-additional .item','height','80','2906','','.w-product-images-additional'),(480230,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"text\"]','height','33','','','.b-bottom'),(480231,'furniture-mobile','.b-select-suggest .select2-measure-scrollbar','height','100','','','.b-select-suggest'),(480232,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','height','30','3','','.b-form'),(480233,'furniture-mobile','.b-fancybox .fancybox-close','height','40','','','.b-fancybox'),(480234,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height','1','','','.b-select-suggest'),(480235,'furniture-mobile','.w-sale .badge','height','80','','','.w-sale'),(480236,'furniture-mobile','.w-product-images-additional .item','height','80','2906','','.w-product-images-additional'),(480237,'furniture-mobile','.w-product-images-additional .item-div','height','80','2906','','.w-product-images-additional'),(480238,'furniture-mobile','.w-product-images-additional .item-div','height','80','2906','','.w-product-images-additional'),(480240,'furniture-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(480241,'furniture-mobile','.w-menu-style-1 .menu-ico','height','54','','','.w-menu-style-1'),(480242,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','height','144','','','.w-wedding-registry-widgets-photos'),(480243,'furniture-mobile','.w-product-images-additional .item-div','height','80','2906','','.w-product-images-additional'),(480244,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','height','20','','','.b-switch'),(480245,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','height','18','','','.b-form'),(480246,'furniture-mobile','.w-product-promotions select','height','29','','','.w-product-promotions'),(480247,'furniture-mobile','.w-product-promotions select','height','29','','','.w-product-promotions'),(480248,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height','60','','','.b-switch'),(480249,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','height','56','','','.b-switch'),(480250,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height','100','4','','.b-switch'),(480251,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','','','.b-switch'),(480252,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height','60','','','.b-switch'),(480253,'furniture-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(480255,'furniture-mobile','.w-sale .badge','height','80','','','.w-sale'),(480256,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','height','100','','','.b-switch'),(480257,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents','height','56','','','.b-switch'),(480258,'furniture-mobile','.w-product-promotions select','height','29','','','.w-product-promotions'),(480259,'furniture-mobile','.w-sale .badge','height','80','','','.w-sale'),(480260,'furniture-mobile','.w-menu-slider .menu-ico','height','54','','','.w-menu-slider'),(480261,'furniture-mobile','.b-fancybox .fancybox-nav','height','100','','','.b-fancybox'),(480262,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','height','35','','','.b-select-suggest'),(480263,'furniture-mobile','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(480264,'furniture-mobile','.w-personal-gift-status-bar .progress-bar-content','height','8','','','.w-personal-gift-status-bar'),(480265,'furniture-mobile','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(480266,'furniture-mobile','.w-banner .carousel-text','height','100','','','.w-banner'),(480267,'furniture-mobile','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height','100','','','.w-banner'),(480268,'furniture-mobile','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height','100','','','.w-banner'),(480269,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','height','20','3','','.b-switch'),(480270,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','4','','.b-switch'),(480271,'furniture-mobile','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(480272,'furniture-mobile','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(480273,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','height','22','','','.w-compare-box-item'),(480274,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','height','35','','','.p-blog-index'),(480276,'furniture-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(480277,'furniture-mobile','.w-product-images-additional .item-div','height','80','2906','','.w-product-images-additional'),(480278,'furniture-mobile','.w-sale .badge','height','80','','','.w-sale'),(480279,'furniture-mobile','.w-catalog-paging .next-pages','height','35','','','.w-catalog-paging'),(480280,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','height','35','','','.p-blog-index'),(480282,'furniture-mobile','.b-autocomplete .ui-autocomplete','height','300','','','.b-autocomplete'),(480283,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','','','.b-switch'),(480284,'furniture-mobile','.b-form .checkbox-style:checked + .checkbox-span','height','18','','','.b-form'),(480285,'furniture-mobile','.b-info-popup .info-popup','height','2','','','.b-info-popup'),(480286,'furniture-mobile','.w-menu-slider .menu-ico','height','54','','','.w-menu-slider'),(480287,'furniture-mobile','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(480290,'furniture-mobile','.w-product-customers-activity .close','height','30','','','.w-product-customers-activity'),(480291,'furniture-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(480292,'furniture-mobile','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(480293,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','height','35','','','.p-blog-index'),(480294,'furniture-mobile','.w-sale .badge','height','80','','','.w-sale'),(480295,'furniture-mobile','.w-compare-box-item .checkbox','height','22','','','.w-compare-box-item'),(480296,'furniture-mobile','.w-compare-box-item .checkbox + span','height','24','','','.w-compare-box-item'),(480298,'furniture-mobile','.w-menu-horizontal .menu-ico','height','54','','','.w-menu-horizontal'),(480299,'furniture-mobile','.w-compare-box-item .checkbox + span','height','24','','','.w-compare-box-item'),(480300,'furniture-mobile','.w-product-images-additional .item','height','80','2906','','.w-product-images-additional'),(480301,'furniture-mobile','.w-product-images-additional .item-div','height','80','2906','','.w-product-images-additional'),(480302,'furniture-mobile','.w-product-images-additional .item','height','80','2906','','.w-product-images-additional'),(480303,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','height','16','','','.b-switch'),(480304,'furniture-mobile','.b-select-suggest .select2-search-choice-close','height','13','','','.b-select-suggest'),(480305,'furniture-mobile','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','height','25','','','.b-datepicker'),(480306,'furniture-mobile','.w-menu-style-1 .menu-ico','height','54','','','.w-menu-style-1'),(480307,'furniture-mobile','.b-select-suggest .select2-search input','height','auto','','','.b-select-suggest'),(480308,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height','100','','','.b-select-suggest'),(480309,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','height','100','','','.b-select-suggest'),(480310,'furniture-mobile','.b-select-suggest .select2-drop-mask','height','auto','','','.b-select-suggest'),(480311,'furniture-mobile','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(480312,'furniture-mobile','.w-compare-box-item .checkbox','height','22','','','.w-compare-box-item'),(480313,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.b-data-table'),(480314,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.b-data-table'),(480315,'furniture-mobile','.b-products-listing .btn-preloader','height','24','3','','.b-products-listing'),(480316,'furniture-mobile','.b-products-listing .hover-box-content','height','20','3','','.b-products-listing'),(480317,'furniture-mobile','.b-products-listing .loader','height','30','4','','.b-products-listing'),(480318,'furniture-mobile','.b-products-listing .loader','height','100','3','','.b-products-listing'),(480319,'furniture-mobile','.b-products-listing .products-listing .qty-input.hidden','height','100','3','','.b-products-listing'),(480320,'furniture-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','height','auto','','','.b-products-listing'),(480321,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','height','35','','','.w-blog-widget-related-posts'),(480322,'furniture-mobile','.w-blog-widget-post-share ','height','26','4','','.w-blog-widget-post-share'),(480323,'furniture-mobile','.checkbox input + span','height','24','','',''),(480324,'furniture-mobile','.checkbox input:not(checked) + span:before','height','22','','',''),(480325,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','height','20','3','','.b-switch'),(480326,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','height','10','4','','.b-switch'),(480327,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-toggle','height','10','','','.b-switch'),(480328,'furniture-mobile','.b-email-editor img','height','auto','','','.b-email-editor'),(480329,'furniture-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height','100','','','.b-fancybox'),(480330,'furniture-mobile','.w-product-promotions select','height','29','','','.w-product-promotions'),(480331,'furniture-mobile','.w-menu-slider .menu-ico','height','54','','','.w-menu-slider'),(480332,'furniture-mobile','.w-menu-style-1 .menu-ico','height','54','','','.w-menu-style-1'),(480333,'furniture-mobile','.w-catalog-paging .next','height','35','','','.w-catalog-paging'),(480334,'furniture-mobile','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(480335,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','height','36','','','.w-communication-new-topic'),(480336,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','height','36','','','.w-communication-new-topic'),(480337,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','height','30','','','.w-communication-new-topic'),(480338,'furniture-mobile','.w-communication-new-topic #communication_group_holder select','height','35','','','.w-communication-new-topic'),(480339,'furniture-mobile','.w-wedding-registry-widgets-photos .upload-file-template','height','144','','','.w-wedding-registry-widgets-photos'),(480340,'furniture-mobile','.w-compare-box-item .checkbox + span','height','24','','','.w-compare-box-item'),(480341,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height','35','','','.w-catalog-paging'),(480342,'furniture-mobile','.w-sale .badge','height','80','','','.w-sale'),(480343,'furniture-mobile','.w-catalog-paging .page-number','height','35','','','.w-catalog-paging'),(480344,'furniture-mobile','.w-catalog-listing-look .grid','height','35','','','.w-catalog-listing-look'),(480345,'furniture-mobile','.w-catalog-listing-look .b2b','height','35','','','.w-catalog-listing-look'),(480346,'furniture-mobile','.w-catalog-listing-look .list','height','35','','','.w-catalog-listing-look'),(480348,'furniture-mobile','.w-cart-listing .remove-btn','height','30','','','.w-cart-listing'),(480349,'furniture-mobile','.w-cart-listing .item .remove','height','45','2885','','.w-cart-listing'),(480350,'furniture-mobile','.b-upload-file .snapshot','height','38','','','.b-upload-file'),(480351,'furniture-mobile','.w-menu-style-1 .menu-ico','height','54','','','.w-menu-style-1'),(480352,'furniture-mobile','.w-image-maps .svg-wrap svg','height','100','','','.w-image-maps'),(480353,'furniture-mobile','.b-fancybox .fancybox-nav span','height','40','','','.b-fancybox'),(480354,'furniture-mobile','.w-catalog-paging .paging-holder','height','35','','','.w-catalog-paging'),(480355,'furniture-mobile','.b-upload-file .upload-file-template','height','150','','','.b-upload-file'),(480356,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','height','22','','','.w-compare-box-item'),(480357,'furniture-mobile','.w-filters .ui-slider-range','height','6','','','.w-filters'),(480358,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','height','10','','','.b-switch'),(480359,'furniture-mobile','.w-catalog-paging ','height','35','2','','.w-catalog-paging'),(480360,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','height','22','','','.w-compare-box-item'),(480361,'furniture-mobile','.b-bottom .pop-up-close','height','31','','','.b-bottom'),(480362,'furniture-mobile','.w-product-images-additional .item','height','80','2906','','.w-product-images-additional'),(480363,'furniture-mobile','.w-product-images-additional .item','height','80','2906','','.w-product-images-additional'),(480364,'furniture-mobile','.w-menu-style-1 .menu-ico','height','54','','','.w-menu-style-1'),(480365,'furniture-mobile','.w-menu-slider .menu-ico','height','54','','','.w-menu-slider'),(480366,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','height','22','','','.w-compare-box-item'),(480367,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg','height','30','','','.b-switch'),(480368,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','height','30','','','.b-switch'),(480369,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','height','30','','','.b-switch'),(480370,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','height','30','3','','.b-switch'),(480371,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','height','30','','','.b-switch'),(480372,'furniture-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','height','24','','','.w-filters'),(480373,'furniture-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','height','auto','','','.b-product-images'),(480374,'furniture-mobile','.b-product-images .media-popup .mp-big-images','height','calc(100vh - 150px)','','','.b-product-images'),(480375,'furniture-mobile','.b-product-images .media-popup .mp-big-images .item','height','calc(100vh - 150px)','','','.b-product-images'),(480376,'furniture-mobile','.b-product-images .media-popup .mp-close','height','100','','','.b-product-images'),(480377,'furniture-mobile','.b-product-images .media-popup .mp-content','height','100','','','.b-product-images'),(480378,'furniture-mobile','.b-product-images .media-popup .mp-small-images','height','100','','','.b-product-images'),(480379,'furniture-mobile','.b-product-images .media-popup .mp-small-images .item','height','100','','','.b-product-images'),(480380,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','height','100','','','.b-product-images'),(480381,'furniture-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','height','30','','','.b-menu-burger_icon'),(480382,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(480383,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(480384,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(480385,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(480386,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(480387,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height','100','','','.b-menu-open_from-left'),(480388,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(480389,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','height','28','','','.b-menu-style-2'),(480390,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','height','50','','','.b-menu-style-2'),(480391,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','height','24','','','.b-menu-style-2'),(480392,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','height','16','3','','.b-menu-style-2'),(480393,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','height','28','','','.b-menu-style-2'),(480394,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','height','16','3','','.b-menu-style-2'),(480395,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','height','24','','','.b-menu-style-2'),(480396,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','height','35','','','.b-trade-approval'),(480397,'furniture-mobile','.batchPr .checkbox input + span','height','36','','','.batchPr'),(480398,'furniture-mobile','.batchPr .batchSelect .checkbox','height','36','','','.batchPr'),(480399,'furniture-mobile','.batchPr .checkbox input + span','height','32','','','.batchPr'),(480400,'furniture-mobile','.batchPr .batch-selected-products-list','height','304','','','.batchPr'),(480401,'furniture-mobile','.batchPr .checkbox input:not(checked) + span:before','height','30','','','.batchPr'),(480402,'furniture-mobile','.batchPr .btn-batch-remove','height','20','','','.batchPr'),(480403,'furniture-mobile','.w-account-subscription .info-popup','height','15','','','.w-account-subscription'),(480404,'furniture-mobile','.w-catalog-compare span.btn-preloader','height','24','','','.w-catalog-compare'),(480405,'furniture-mobile','.w-cart .cart-box-link','height','48','3','','.w-cart'),(480406,'furniture-mobile','.w-cart .cart-box-link','height','10','4','','.w-cart'),(480407,'furniture-mobile','.w-search .search-input','height','50','','','.w-search'),(480408,'furniture-mobile','.w-account .my-acc-link','height','10','4','','.w-account'),(480409,'furniture-mobile','.w-account .my-acc-link','height','48','3','','.w-account'),(480410,'furniture-mobile','.w-account .account-dropdown','height','50','3','','.w-account'),(480411,'furniture-mobile','.tripleBanner .w-html_box','height','100','3','','.tripleBanner'),(480412,'furniture-mobile','.b-slick .slick-slide','height','100','','','.b-slick'),(480413,'furniture-mobile','.b-slick .slick-vertical .slick-slide','height','auto','','','.b-slick'),(480414,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','height','40','','','.b-slick'),(480415,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','height','45','2885','','.b-slick'),(480416,'furniture-mobile','.w-account .my-acc-link','height','40','2885,3','','.w-account'),(480417,'furniture-mobile','.w-cart .cart-box-link','height','40','2885,3','','.w-cart'),(480418,'furniture-mobile','.w-search .search-ico','height','40','2885,3','','.w-search'),(480419,'furniture-mobile','.menu-header .burger-icon','height','40','2885','','.menu-header'),(480420,'furniture-mobile','.tripleBanner > .block > .box','height','100','','','.tripleBanner'),(480421,'furniture-mobile','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','height','18','','','.w-filters'),(480422,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-content','height','1','4','','.b-products-listing'),(480423,'furniture-mobile','.w-quote .cart-box-link','height','48','3','','.w-quote'),(480424,'furniture-mobile','.w-quote .cart-box-link','height','40','2885,3','','.w-quote'),(480425,'furniture-mobile','.w-product-images .additional-vertical','height','400','','','.w-product-images'),(480426,'furniture-mobile','.w-product-images .img-holder','height','100','','','.w-product-images'),(480427,'furniture-mobile','.b-quantity .qty-box .bigger','height','35','','','.b-quantity'),(480428,'furniture-mobile','.b-quantity .qty-box .smaller','height','35','','','.b-quantity'),(480429,'furniture-mobile','.b-quantity .qty-box input','height','35','','','.b-quantity'),(480430,'furniture-mobile','h1, .heading-1','height','1','3','',''),(480431,'furniture-mobile','h1, .heading-1','height','1','4','',''),(480432,'furniture-mobile','.w-product-quantity .qty-box .smaller, .w-product-quantity .qty-box .bigger','height','46','','','.w-product-quantity'),(480433,'furniture-mobile','.w-product-quantity .qty-input input[type=\'text\']','height','46','','','.w-product-quantity'),(480434,'furniture-mobile','.warrantyProduct .warranty','height','32','3','','.warrantyProduct'),(480435,'furniture-mobile','.warrantyProduct .delivery','height','30','3','','.warrantyProduct'),(480436,'furniture-mobile','.w-sample .cart-box-link','height','10','4','','.w-sample'),(480437,'furniture-mobile','.w-sample .cart-box-link','height','48','3','','.w-sample'),(480438,'furniture-mobile','.w-sample .cart-box-link','height','40','2885,3','','.w-sample'),(480439,'furniture-mobile','.w-cart-listing .points-earn','height','0','4','','.w-cart-listing'),(480440,'furniture-mobile','.w-catalog-additional-images img','height','auto','','','.w-catalog-additional-images'),(480441,'furniture-mobile','.w-catalog-additional-images picture','height','150','','','.w-catalog-additional-images'),(480442,'furniture-mobile','.heading-2','height','1','3','',''),(480443,'furniture-mobile','.heading-2','height','1','4','',''),(480444,'furniture-mobile','.b-pagination .pagination .next-pages','height','30','','','.b-pagination'),(480445,'furniture-mobile','.b-pagination .pagination .page-number','height','30','','','.b-pagination'),(480446,'furniture-mobile','.b-pagination .pagination .prev-pages','height','30','','','.b-pagination'),(480447,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','height','30','','','.b-pagination'),(480448,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','height','30','','','.b-pagination'),(480449,'furniture-mobile','.b-pagination .pagination span','height','30','2','','.b-pagination'),(480450,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','height','1','3','','.p-quote-checkout-index'),(480451,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','height','1','4','','.p-quote-checkout-index'),(480452,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','height','1','3','','.p-sample-checkout-index'),(480453,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','height','1','4','','.p-sample-checkout-index'),(480454,'furniture-mobile','.w-account-order-download td:nth-child(4)','height','0','2876','','.w-account-order-download'),(480455,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','height','36','','','.w-account-personal-catalog'),(480456,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','height','40','','','.w-questionnaire-widgets-questionnaire'),(480457,'furniture-mobile','.w-sale-category .badge','height','80','','','.w-sale-category'),(480458,'furniture-mobile','.w-product-wedding-registry-button .btn','height','18','3','','.w-product-wedding-registry-button'),(480459,'furniture-mobile','.w-product-wedding-registry-button .btn','height','18','4','','.w-product-wedding-registry-button'),(480460,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','height','30','','','.w-wedding-registry-widgets-search-paging'),(480461,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','height','30','','','.w-wedding-registry-widgets-search-paging'),(480462,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','height','30','','','.w-wedding-registry-widgets-search-paging'),(480463,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','height','30','','','.w-wedding-registry-widgets-search-paging'),(480464,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','height','120','2890','','.w-wedding-registry-widgets-photos'),(480465,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','height','78','','','.w-product-designer-designer'),(480466,'furniture-mobile','.w-product-designer-designer .productDesignerBox input','height','100','','','.w-product-designer-designer'),(480467,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','height','35','','','.w-rma-returns-history'),(480468,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(480469,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(480470,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(480471,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .image img','height','auto','','','.w-predefined-promotion'),(480472,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .products','height','calc(100% - 25px)','','','.w-predefined-promotion'),(480473,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .image img','height','auto','','','.w-predefined-promotion'),(480474,'furniture-mobile','.w-predefined-promotion .promo-salemaker .image img','height','auto','','','.w-predefined-promotion'),(480475,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','height','24','','','.w-filters'),(480476,'furniture-mobile','.mainBanner .title','height','6','3','','.mainBanner'),(480477,'furniture-mobile','.mainBanner .topBox > .right','height','18','3','','.mainBanner'),(480478,'furniture-mobile','.mainBanner .title','height','9','2876,3','','.mainBanner'),(480479,'furniture-mobile','.mainBanner .topBox > .right','height','15','2876,3','','.mainBanner'),(480480,'furniture-mobile','.mainBanner .w-banner .banner-text','height','100','','','.mainBanner'),(480481,'furniture-mobile','.lowestPricedBox .w-banner .ybg','height','20','3','','.lowestPricedBox'),(480482,'furniture-mobile','.lowestPricedBox .w-banner .ybg','height','100','','','.lowestPricedBox'),(480483,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner:nth-child(1) .ybg:before','height','15','2890','','.lowestPricedBox'),(480484,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner:nth-child(2) .ybg:before','height','15','2890','','.lowestPricedBox'),(480485,'furniture-mobile','.order-summary .icon','height','30','','','.order-summary'),(480486,'furniture-mobile','.w-search .wrap','height','100','','','.w-search'),(480487,'furniture-mobile','.account-order-history .orders-table .td-alignright','height','45','2885','','.account-order-history'),(480488,'furniture-mobile','.account-index .remove-btn','height','30','','','.account-index'),(480489,'furniture-mobile','.account-index .orders-table .links','height','45','2885','','.account-index'),(480490,'furniture-mobile','.account-samples .orders-table .td-alignright','height','45','2885','','.account-samples'),(480491,'furniture-mobile','.catalog-product-wrap .pn-image','height','24','3','','.catalog-product-wrap'),(480492,'furniture-mobile','.checkout-index-wrap .input-wrapper','height','35','','','.checkout-index-wrap'),(480493,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','height','1','3','','.checkout-index-wrap'),(480494,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','height','1','4','','.checkout-index-wrap'),(480495,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height_important','important','','','.b-select-suggest'),(480496,'furniture-mobile','.b-select-suggest .select2-search input','height_important','important','','','.b-select-suggest'),(480497,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height_important','important','','','.w-catalog-paging'),(480498,'furniture-mobile','.menu-header .burger-icon','height_important','important','2885','','.menu-header'),(480499,'furniture-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height_measure','%','','','.w-banner'),(480500,'furniture-mobile','.b-preloader .preloader','height_measure','%','','','.b-preloader'),(480501,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height_measure','%','3','','.b-switch'),(480502,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(480503,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height_measure','%','4','','.b-switch'),(480504,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','height_measure','%','','','.b-switch'),(480505,'furniture-mobile','.b-fancybox .fancybox-nav','height_measure','%','','','.b-fancybox'),(480506,'furniture-mobile','.w-banner .carousel-text','height_measure','%','','','.w-banner'),(480507,'furniture-mobile','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height_measure','%','','','.w-banner'),(480508,'furniture-mobile','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height_measure','%','','','.w-banner'),(480509,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height_measure','%','','','.b-select-suggest'),(480510,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','height_measure','%','','','.b-select-suggest'),(480511,'furniture-mobile','.b-products-listing .loader','height_measure','%','3','','.b-products-listing'),(480512,'furniture-mobile','.b-products-listing .products-listing .qty-input.hidden','height_measure','%','3','','.b-products-listing'),(480513,'furniture-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height_measure','%','','','.b-fancybox'),(480514,'furniture-mobile','.b-form .hide-billing-address','height_measure','%','','','.b-form'),(480515,'furniture-mobile','.w-image-maps .svg-wrap svg','height_measure','%','','','.w-image-maps'),(480516,'furniture-mobile','.b-product-images .media-popup .mp-content','height_measure','vh','','','.b-product-images'),(480517,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height_measure','vh','','','.b-menu-open_from-left'),(480518,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(480519,'furniture-mobile','.tripleBanner .w-html_box','height_measure','%','3','','.tripleBanner'),(480520,'furniture-mobile','.b-slick .slick-slide','height_measure','%','','','.b-slick'),(480521,'furniture-mobile','.tripleBanner > .block > .box','height_measure','%','','','.tripleBanner'),(480522,'furniture-mobile','.w-catalog-listing-look .b2b','height_measure','x','','','.w-catalog-listing-look'),(480523,'furniture-mobile','.w-product-images .img-holder','height_measure','%','','','.w-product-images'),(480524,'furniture-mobile','.w-product-designer-designer .productDesignerBox input','height_measure','%','','','.w-product-designer-designer'),(480525,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(480526,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(480527,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(480528,'furniture-mobile','.mainBanner .title','height_measure','vw','3','','.mainBanner'),(480529,'furniture-mobile','.mainBanner .title','height_measure','vw','2876,3','','.mainBanner'),(480530,'furniture-mobile','.mainBanner .w-banner .banner-text','height_measure','%','','','.mainBanner'),(480531,'furniture-mobile','.lowestPricedBox .w-banner .ybg','height_measure','%','','','.lowestPricedBox'),(480532,'furniture-mobile','.w-search .wrap','height_measure','%','','','.w-search'),(480533,'furniture-mobile','.w-promotions .promo-cart-discount .content','justify-content','center','','','.w-promotions'),(480534,'furniture-mobile','.w-promotions .prom-multi-discount .products','justify-content','space-between','','','.w-promotions'),(480535,'furniture-mobile','.w-promotions .promo-salemaker .content','justify-content','center','','','.w-promotions'),(480536,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-blocks','justify-content','space-between','','','.b-products-listing'),(480537,'furniture-mobile','.p-quick-order-index .quick-order-total','justify-content','space-between','','','.p-quick-order-index'),(480538,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(480539,'furniture-mobile','.w-personal-gift-status-bar .timeline','justify-content','center','','','.w-personal-gift-status-bar'),(480540,'furniture-mobile','.w-checkout-shipping-choice span','justify-content','center','','','.w-checkout-shipping-choice'),(480541,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(480542,'furniture-mobile','.order-summary .price-row','justify-content','space-between','','','.order-summary'),(480543,'furniture-mobile','.w-banner .carousel .top-center','justify-content','center','','','.w-banner'),(480544,'furniture-mobile','.w-banner .carousel .top-left','justify-content','flex-start','','','.w-banner'),(480545,'furniture-mobile','.w-banner .carousel .top-right','justify-content','flex-end','','','.w-banner'),(480546,'furniture-mobile','.w-banner .carousel .middle-right','justify-content','flex-end','','','.w-banner'),(480547,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(480548,'furniture-mobile','.w-communication-post .communication-post-author','justify-content','space-between','','','.w-communication-post'),(480549,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(480550,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(480551,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(480552,'furniture-mobile','.w-banner .carousel .middle-center','justify-content','center','','','.w-banner'),(480553,'furniture-mobile','.w-banner .carousel .middle-left','justify-content','flex-start','','','.w-banner'),(480554,'furniture-mobile','.w-banner .carousel .bottom-left','justify-content','flex-start','','','.w-banner'),(480555,'furniture-mobile','.w-banner .carousel .bottom-right','justify-content','flex-end','','','.w-banner'),(480556,'furniture-mobile','.w-banner .carousel .bottom-center','justify-content','center','','','.w-banner'),(480557,'furniture-mobile','.b-product-images .media-popup .mp-big-images .item','justify-content','center','','','.b-product-images'),(480558,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(480559,'furniture-mobile','.w-catalog-compare .cross-box','justify-content','flex-end','','','.w-catalog-compare'),(480560,'furniture-mobile','.w-product-images .img-holder','justify-content','center','','','.w-product-images'),(480561,'furniture-mobile','.w-files-catalog-widgets-files-catalog ','justify-content','space-between','','','.w-files-catalog-widgets-files-catalog'),(480562,'furniture-mobile','.w-files-catalog-widgets-files-catalog .image','justify-content','center','','','.w-files-catalog-widgets-files-catalog'),(480563,'furniture-mobile','.w-product-bundle .bundle-products','justify-content','space-between','','','.w-product-bundle'),(480564,'furniture-mobile','.w-product-in-bundles .bundle-products','justify-content','space-between','','','.w-product-in-bundles'),(480565,'furniture-mobile','.w-account-address-book .address-book','justify-content','space-between','','','.w-account-address-book'),(480566,'furniture-mobile','.w-delivery-location-product-categories .categories','justify-content','center','','','.w-delivery-location-product-categories'),(480567,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review-box','justify-content','center','','','.w-press-reviews-widgets-press-reviews'),(480568,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .review-box','justify-content','center','','','.w-press-reviews-widgets-press-reviews-list'),(480569,'furniture-mobile','.w-rma-returns-history .column','justify-content','space-between','','','.w-rma-returns-history'),(480570,'furniture-mobile','.w-rma-returns-history .filterMessages','justify-content','space-between','','','.w-rma-returns-history'),(480571,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','justify-content','space-between','','','.b-menu-style-1'),(480572,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul','justify-content','flex-start','','','.b-menu-position'),(480573,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(480574,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul','justify-content','center','','','.b-menu-position'),(480575,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(480576,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul','justify-content','flex-end','','','.b-menu-position'),(480577,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(480578,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .products','justify-content','space-between','','','.w-predefined-promotion'),(480579,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .content','justify-content','center','','','.w-predefined-promotion'),(480580,'furniture-mobile','.w-predefined-promotion .promo-salemaker .content','justify-content','center','','','.w-predefined-promotion'),(480581,'furniture-mobile','.w-supplier-purchase-supplier-products .item','justify-content','space-between','','','.w-supplier-purchase-supplier-products'),(480582,'furniture-mobile','.lowestPricedBox .w-banner .ybg','justify-content','center','2876','','.lowestPricedBox'),(480583,'furniture-mobile','.shopByCollectionBox .w-banner .banner','justify-content','center','2885','','.shopByCollectionBox'),(480584,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons','justify-content','space-between','','','.checkout-index-wrap'),(480585,'furniture-mobile','.checkout-order-confirmation .price-row','justify-content','space-between','','','.checkout-order-confirmation'),(480586,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(480587,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','left','2','3','','.b-switch'),(480588,'furniture-mobile','.w-promo-code .holder','left','12','2906,3','','.w-promo-code'),(480589,'furniture-mobile','.p-quick-order-index .all-scroll-div','left','0','','','.p-quick-order-index'),(480590,'furniture-mobile','.w-promo-code .holder','left','20','3','','.w-promo-code'),(480591,'furniture-mobile','.p-wedding-registry-view h1','left','-10','3','','.p-wedding-registry-view'),(480592,'furniture-mobile','.w-wedding-registry-widgets-share-link a','left','-3','4','','.w-wedding-registry-widgets-share-link'),(480593,'furniture-mobile','.p-reviews-info .review-info-text','left','11','4','','.p-reviews-info'),(480594,'furniture-mobile','.testimonials .heading-3','left','0','3','',''),(480595,'furniture-mobile','.testimonials .review','left','10','3','',''),(480596,'furniture-mobile','.b-preloader .preloader','left','calc(50% - 20px)','3','','.b-preloader'),(480597,'furniture-mobile','.b-preloader .preloader','left','0','','','.b-preloader'),(480598,'furniture-mobile','.p-reviews-info .review-info-text','left','11','4','','.p-reviews-info'),(480599,'furniture-mobile','.w-sale .badge','left','10','','','.w-sale'),(480600,'furniture-mobile','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(480601,'furniture-mobile','.p-wedding-registry-view h1','left','-10','3','','.p-wedding-registry-view'),(480602,'furniture-mobile','.w-checkout-terms .required-message','left','0','','','.w-checkout-terms'),(480603,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','left','15','','','.b-switch'),(480604,'furniture-mobile','.b-fancybox #fancybox-loading','left','50','','','.b-fancybox'),(480605,'furniture-mobile','.b-fancybox .fancybox-wrap','left','0','','','.b-fancybox'),(480606,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','left','100','','','.b-switch'),(480607,'furniture-mobile','.w-menu-slider > ul > li > ul','left','0','','','.w-menu-slider'),(480608,'furniture-mobile','.w-promo-code .holder','left','20','3','','.w-promo-code'),(480609,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','left','50','','','.w-checkout-shipping-choice'),(480610,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(480611,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(480612,'furniture-mobile','.w-menu-slider > ul > li > ul','left','0','','','.w-menu-slider'),(480613,'furniture-mobile','.b-info-popup .info-popup div','left','-11','3','','.b-info-popup'),(480614,'furniture-mobile','.b-fancybox .fancybox-title-over-wrap','left','0','','','.b-fancybox'),(480615,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','left','10','','','.b-switch'),(480616,'furniture-mobile','.w-menu-slider > ul > li > ul','left','0','','','.w-menu-slider'),(480617,'furniture-mobile','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(480618,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','left','20','','','.b-switch'),(480619,'furniture-mobile','.w-cart-compare .dropdown .dropdown-menu','left','auto','','','.w-cart-compare'),(480620,'furniture-mobile','.b-select-suggest .select2-measure-scrollbar','left','-10000','','','.b-select-suggest'),(480621,'furniture-mobile','.b-fancybox .fancybox-tmp','left','-99999','','','.b-fancybox'),(480622,'furniture-mobile','.w-search .suggest','left','0','','','.w-search'),(480623,'furniture-mobile','.b-info-popup .info-popup.top-left div','left','auto','','','.b-info-popup'),(480624,'furniture-mobile','.b-info-popup .info-popup.top-left div','left','auto','3','','.b-info-popup'),(480625,'furniture-mobile','.w-promo-code .holder','left','12','2906,3','','.w-promo-code'),(480626,'furniture-mobile','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(480627,'furniture-mobile','.w-promo-code .holder','left','20','3','','.w-promo-code'),(480628,'furniture-mobile','.view-all','left','0','3','',''),(480629,'furniture-mobile','.w-menu-style-1 > ul > li > ul','left','0','','','.w-menu-style-1'),(480630,'furniture-mobile','.w-text .customer-service','left','0','3','','.w-text'),(480631,'furniture-mobile','.b-fancybox .fancybox-overlay','left','0','','','.b-fancybox'),(480632,'furniture-mobile','.w-languages .select','left','-1','','','.w-languages'),(480633,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left','25','','','.b-switch'),(480634,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(480635,'furniture-mobile','.w-multi-cart-actions .dropdown .dropdown-menu','left','0','','','.w-multi-cart-actions'),(480636,'furniture-mobile','.p-reviews-info .review-info-text','left','11','4','','.p-reviews-info'),(480637,'furniture-mobile','.w-menu-slider > ul > li > ul','left','0','','','.w-menu-slider'),(480638,'furniture-mobile','.w-menu-style-1 > ul > li > ul','left','0','','','.w-menu-style-1'),(480639,'furniture-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','left','0','','','.b-switch'),(480640,'furniture-mobile','.w-text .customer-service','left','0','3','','.w-text'),(480641,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(480642,'furniture-mobile','.w-menu-slider > ul > li > ul','left','0','','','.w-menu-slider'),(480643,'furniture-mobile','.b-select-suggest .select2-drop-mask','left','0','','','.b-select-suggest'),(480644,'furniture-mobile','.w-reviews .review','left','15','3','','.w-reviews'),(480645,'furniture-mobile','.w-text .customer-service','left','0','3','','.w-text'),(480646,'furniture-mobile','.b-fancybox .fancybox-prev','left','0','','','.b-fancybox'),(480647,'furniture-mobile','.b-fancybox .fancybox-prev span','left','10','','','.b-fancybox'),(480648,'furniture-mobile','.w-sale .badge','left','10','','','.w-sale'),(480649,'furniture-mobile','.p-reviews-info .review-info-text','left','11','4','','.p-reviews-info'),(480650,'furniture-mobile','.w-text .customer-service','left','0','3','','.w-text'),(480651,'furniture-mobile','.p-wedding-registry-view h1','left','-10','3','','.p-wedding-registry-view'),(480652,'furniture-mobile','.w-promo-code .holder','left','12','2906,3','','.w-promo-code'),(480653,'furniture-mobile','.w-promo-code .holder','left','20','3','','.w-promo-code'),(480654,'furniture-mobile','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(480655,'furniture-mobile','.w-reviews .heading-3','left','0','3','','.w-reviews'),(480656,'furniture-mobile','.w-banner .carousel-text','left','0','','','.w-banner'),(480657,'furniture-mobile','.w-banner .image-text-banner.bottom-left .text-banner','left','0','','','.w-banner'),(480658,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','left','2','3','','.b-switch'),(480659,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left','4','3','','.b-switch'),(480660,'furniture-mobile','.w-menu-style-1 > ul > li > ul','left','0','','','.w-menu-style-1'),(480661,'furniture-mobile','.p-wedding-registry-view h1','left','-10','3','','.p-wedding-registry-view'),(480662,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(480663,'furniture-mobile','.w-sale .badge','left','10','','','.w-sale'),(480664,'furniture-mobile','.w-sale .badge','left','10','','','.w-sale'),(480665,'furniture-mobile','.w-reviews-content .review','left','15','3','','.w-reviews-content'),(480666,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(480667,'furniture-mobile','.w-promo-code .holder','left','12','2906,3','','.w-promo-code'),(480668,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no','left','-100','','','.b-form'),(480669,'furniture-mobile','.w-text .customer-service','left','0','3','','.w-text'),(480670,'furniture-mobile','.p-reviews-info .review-info-text','left','11','4','','.p-reviews-info'),(480671,'furniture-mobile','.w-checkout-billing-address .addresses .address-item label input','left','0','','','.w-checkout-billing-address'),(480672,'furniture-mobile','.w-promo-code .holder','left','12','2906,3','','.w-promo-code'),(480673,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','left','0','','','.b-switch'),(480674,'furniture-mobile','.w-banner .image-text-banner.top-left .text-banner','left','0','','','.w-banner'),(480675,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-search-choice-close','left','3','','','.b-select-suggest'),(480676,'furniture-mobile','.w-menu-horizontal > ul > li > ul','left','0','','','.w-menu-horizontal'),(480677,'furniture-mobile','.w-menu-slider > ul > li > ul','left','0','','','.w-menu-slider'),(480678,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item label input','left','0','','','.w-checkout-shipping-address'),(480679,'furniture-mobile','.w-text .customer-service','left','0','3','','.w-text'),(480680,'furniture-mobile','.p-wedding-registry-view h1','left','-10','3','','.p-wedding-registry-view'),(480681,'furniture-mobile','.w-image-maps .svg-wrap svg','left','0','','','.w-image-maps'),(480682,'furniture-mobile','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(480683,'furniture-mobile','.b-products-listing .products-listing .promos-info','left','0','','','.b-products-listing'),(480684,'furniture-mobile','.b-products-listing .hover-box-content','left','0','','','.b-products-listing'),(480685,'furniture-mobile','.b-products-listing .hover-box-content','left','20','3','','.b-products-listing'),(480686,'furniture-mobile','.b-products-listing .loader','left','calc(50% - 15px)','4','','.b-products-listing'),(480687,'furniture-mobile','.b-products-listing .loader','left','0','3','','.b-products-listing'),(480688,'furniture-mobile','.w-catalog-b2b-add-button ','left','0','','','.w-catalog-b2b-add-button'),(480689,'furniture-mobile','.b-products-listing .products-listing .qty-input.hidden','left','0','3','','.b-products-listing'),(480690,'furniture-mobile','.b-products-listing .promo','left','0','','','.b-products-listing'),(480691,'furniture-mobile','.w-blog-widget-related-posts-by-category button.slick-prev','left','13','','','.w-blog-widget-related-posts-by-category'),(480692,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev','left','13','','','.w-blog-widget-related-posts'),(480693,'furniture-mobile','.w-blog-widget-post-share','left','112','2906,4','','.w-blog-widget-post-share'),(480694,'furniture-mobile','.w-blog-widget-post-listing .post_comment','left','0','3','','.w-blog-widget-post-listing'),(480695,'furniture-mobile','.w-blog-widget-post-linked-products button.slick-prev','left','10','','','.w-blog-widget-post-linked-products'),(480696,'furniture-mobile','.w-blog-widget-post-comments-count span','left','0','3','','.w-blog-widget-post-comments-count'),(480697,'furniture-mobile','.w-blog-widget-most-popular-posts a','left','0','3','','.w-blog-widget-most-popular-posts'),(480698,'furniture-mobile','.w-blog-widget-categories-list a','left','0','3','','.w-blog-widget-categories-list'),(480699,'furniture-mobile','.checkbox input','left','-20','','',''),(480700,'furniture-mobile','.w-currencies .select','left','0','','','.w-currencies'),(480701,'furniture-mobile','.w-sale .badge','left','10','','','.w-sale'),(480702,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left','0','','','.b-select-suggest'),(480703,'furniture-mobile','.w-promo-code .holder','left','20','3','','.w-promo-code'),(480704,'furniture-mobile','.w-menu-style-1 > ul > li > ul','left','0','','','.w-menu-style-1'),(480705,'furniture-mobile','.w-sale .badge','left','10','','','.w-sale'),(480706,'furniture-mobile','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(480707,'furniture-mobile','.w-promo-code .holder','left','20','3','','.w-promo-code'),(480708,'furniture-mobile','.w-promo-code .holder','left','12','2906,3','','.w-promo-code'),(480709,'furniture-mobile','.w-cart-listing .item .remove','left','0','2885','','.w-cart-listing'),(480710,'furniture-mobile','.w-cart-listing .remove-btn','left','10','2885','','.w-cart-listing'),(480711,'furniture-mobile','.w-cart-listing .remove-btn span','left','5','2885','','.w-cart-listing'),(480712,'furniture-mobile','.w-cart .multicart .switch-cart','left','15','','','.w-cart'),(480713,'furniture-mobile','.w-wedding-registry-widgets-delete-link a','left','-3','4','','.w-wedding-registry-widgets-delete-link'),(480714,'furniture-mobile','.p-wedding-registry-view h1','left','-10','3','','.p-wedding-registry-view'),(480715,'furniture-mobile','.b-info-popup .info-popup div','left','40','','','.b-info-popup'),(480716,'furniture-mobile','.w-menu-style-1 > ul > li > ul','left','0','','','.w-menu-style-1'),(480717,'furniture-mobile','.w-product-reviews .reviews-list .review','left','10','3','','.w-product-reviews'),(480718,'furniture-mobile','.p-reviews-info .review-info-text','left','11','4','','.p-reviews-info'),(480719,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(480720,'furniture-mobile','.b-form .hide-billing-address','left','0','','','.b-form'),(480721,'furniture-mobile','.w-menu-style-1 > ul > li > ul','left','0','','','.w-menu-style-1'),(480722,'furniture-mobile','.w-menu-big > ul > li > ul','left','0','','','.w-menu-big'),(480723,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','left','40','','','.b-switch'),(480724,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','left','0','','','.w-image-maps'),(480725,'furniture-mobile','.w-banner .banner img + img','left','0','','','.w-banner'),(480726,'furniture-mobile','.b-product-images .mp-shadow, .b-product-images .media-popup','left','0','','','.b-product-images'),(480727,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','left','0','','','.b-menu-lev_display-down'),(480728,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','left','0','','','.b-menu-lev_display-down'),(480729,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','left','0','','','.b-menu-lev_display-down'),(480730,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','left','0','','','.b-menu-lev_display-down'),(480731,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','left','0','','','.b-menu-lev_display-down'),(480732,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left','100','','','.b-menu-lev_display-lra'),(480733,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left','100','','','.b-menu-lev_display-lra'),(480734,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left','100','','','.b-menu-lev_display-lra'),(480735,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left','100','','','.b-menu-lev_display-lra'),(480736,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left','100','','','.b-menu-lev_display-lra'),(480737,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','left','auto','','','.b-menu-lev_display-lra'),(480738,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','left','auto','','','.b-menu-lev_display-lra'),(480739,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','left','auto','','','.b-menu-lev_display-lra'),(480740,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','left','auto','','','.b-menu-lev_display-lra'),(480741,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','left','auto','','','.b-menu-lev_display-lra'),(480742,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left','100','','','.b-menu-lev_display-right'),(480743,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left','100','','','.b-menu-lev_display-right'),(480744,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left','100','','','.b-menu-lev_display-right'),(480745,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left','100','','','.b-menu-lev_display-right'),(480746,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left','100','','','.b-menu-lev_display-right'),(480747,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left','100','','','.b-menu-lev_display-slide'),(480748,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left','100','','','.b-menu-lev_display-slide'),(480749,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left','100','','','.b-menu-lev_display-slide'),(480750,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left','100','','','.b-menu-lev_display-slide'),(480751,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left','100','','','.b-menu-lev_display-slide'),(480752,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left','-110','','','.b-menu-open_from-left'),(480753,'furniture-mobile','.b-menu-open_from-left .bi-opened .menu-style[data-open_from=\"left\"] .menu-content','left','0','','','.b-menu-open_from-left'),(480754,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','left','0','','','.b-menu-style-2'),(480755,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','left','0','','','.b-menu-style-2'),(480756,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','left','20','3','','.b-menu-style-2'),(480757,'furniture-mobile','.batchPr .checkbox input:checked + span:before','left','0','','','.batchPr'),(480758,'furniture-mobile','.batchPr .w-batch-products .products-listing .slick-prev','left','-10','','','.batchPr'),(480759,'furniture-mobile','.batchPr .checkbox input:not(checked) + span:before','left','1','','','.batchPr'),(480760,'furniture-mobile','.tripleBanner .w-html_box','left','0','3','','.tripleBanner'),(480761,'furniture-mobile','.b-slick .slick-track','left','0','','','.b-slick'),(480762,'furniture-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left','50','','','.b-slick'),(480763,'furniture-mobile','.b-slick button.slick-next','left','auto','','','.b-slick'),(480764,'furniture-mobile','.b-slick button.slick-prev','left','0','','','.b-slick'),(480765,'furniture-mobile','.header','left','0','2885','',''),(480766,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','left','0','','','.b-products-listing'),(480767,'furniture-mobile','.w-quote .multicart .switch-cart','left','15','','','.w-quote'),(480768,'furniture-mobile','h1, .heading-1','left','-14','3','',''),(480769,'furniture-mobile','.warrantyProduct .warranty','left','0','3','','.warrantyProduct'),(480770,'furniture-mobile','.warrantyProduct .delivery','left','0','3','','.warrantyProduct'),(480771,'furniture-mobile','.w-compare ','left','0','','','.w-compare'),(480772,'furniture-mobile','.w-sample .multicart .switch-cart','left','15','','','.w-sample'),(480773,'furniture-mobile','.heading-2','left','-14','3','',''),(480774,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','left','-14','3','','.p-quote-checkout-index'),(480775,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','left','-14','3','','.p-sample-checkout-index'),(480776,'furniture-mobile','.w-account-personal-catalog .w-cart-listing .remove-btn','left','0','2885','','.w-account-personal-catalog'),(480777,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input','left','-50','','','.w-questionnaire-widgets-questionnaire'),(480778,'furniture-mobile','.w-sale-category .badge','left','10','','','.w-sale-category'),(480779,'furniture-mobile','.w-product-wedding-registry-button .btn','left','20','3','','.w-product-wedding-registry-button'),(480780,'furniture-mobile','.w-product-wedding-registry-button .btn','left','33','4','','.w-product-wedding-registry-button'),(480781,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content:before','left','25','','','.w-product-properties-icons'),(480782,'furniture-mobile','.w-product-bonus-points > div > div','left','10','3','','.w-product-bonus-points'),(480783,'furniture-mobile','.w-product-designer-designer .productDesignerBox input','left','0','','','.w-product-designer-designer'),(480784,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .goto-button','left','0','','','.b-menu-style-1'),(480785,'furniture-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner','left','0','','','.w-banner'),(480786,'furniture-mobile','.w-product-configurator .pc-item label input','left','0','','','.w-product-configurator'),(480787,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','left','10','3','','.b-products-listing'),(480788,'furniture-mobile','.mainBanner .title','left','40','3','','.mainBanner'),(480789,'furniture-mobile','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','left','0','','','.mainBanner'),(480790,'furniture-mobile','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','left','50','','','.mainBanner'),(480791,'furniture-mobile','.w-search .background','left','0','','','.w-search'),(480792,'furniture-mobile','.w-search .opened','left','0','3','','.w-search'),(480793,'furniture-mobile','.w-search .suggest','left','50','4','','.w-search'),(480794,'furniture-mobile','.account-address-book .buttonBox .info','left','-6','3','','.account-address-book'),(480795,'furniture-mobile','.account-order-history .not_fully_paid_td','left','15','','','.account-order-history'),(480796,'furniture-mobile','.account-order-history .orders-table .status-name','left','0','2885','','.account-order-history'),(480797,'furniture-mobile','.account-order-history .orders-table .td-alignright','left','0','2885','','.account-order-history'),(480798,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','left','1','3','','.account-order-history-info'),(480799,'furniture-mobile','.account-order-history-info .historyInfoColumn h2.title-delivery-address, .account-order-history-info .historyInfoColumn h2.title-billing-address','left','10','3','','.account-order-history-info'),(480800,'furniture-mobile','.account-order-history-info .historyInfoColumn h2.title-payment','left','10','3','','.account-order-history-info'),(480801,'furniture-mobile','.account-order-history-info .not_fully_paid_td','left','15','','','.account-order-history-info'),(480802,'furniture-mobile','.account-index .account_page h4','left','9','3','','.account-index'),(480803,'furniture-mobile','.account-index .not_fully_paid_td','left','15','','','.account-index'),(480804,'furniture-mobile','.account-index .topAccount > li > div','left','0','3','','.account-index'),(480805,'furniture-mobile','.account-index .orders-table .links','left','0','2885','','.account-index'),(480806,'furniture-mobile','.account-index .orders-table .price','left','0','2885','','.account-index'),(480807,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','left','1','3','','.account-order-pay'),(480808,'furniture-mobile','.account-order-pay .historyInfoColumn h2.title-delivery-address, .account-order-pay .historyInfoColumn h2.title-billing-address','left','10','3','','.account-order-pay'),(480809,'furniture-mobile','.account-order-pay .historyInfoColumn h2.title-payment','left','10','3','','.account-order-pay'),(480810,'furniture-mobile','.account-order-pay .not_fully_paid_td','left','15','','','.account-order-pay'),(480811,'furniture-mobile','.account-samples .not_fully_paid_td','left','15','','','.account-samples'),(480812,'furniture-mobile','.account-samples .orders-table .status-name','left','0','2885','','.account-samples'),(480813,'furniture-mobile','.account-samples .orders-table .td-alignright','left','0','2885','','.account-samples'),(480814,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','left','1','3','','.account-sample-info'),(480815,'furniture-mobile','.account-sample-info .historyInfoColumn h2.title-delivery-address, .account-sample-info .historyInfoColumn h2.title-billing-address','left','10','3','','.account-sample-info'),(480816,'furniture-mobile','.account-sample-info .historyInfoColumn h2.title-payment','left','10','3','','.account-sample-info'),(480817,'furniture-mobile','.account-sample-info .not_fully_paid_td','left','15','','','.account-sample-info'),(480818,'furniture-mobile','.catalog-product-wrap .prev-product','left','0','','','.catalog-product-wrap'),(480819,'furniture-mobile','.catalog-product-wrap .prev-product .pn-image','left','20','3','','.catalog-product-wrap'),(480820,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','left','-14','3','','.checkout-index-wrap'),(480821,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left_important','important','','','.b-select-suggest'),(480822,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no','left_measure','vw','','','.b-form'),(480823,'furniture-mobile','.b-fancybox #fancybox-loading','left_measure','%','','','.b-fancybox'),(480824,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','left_measure','%','','','.w-checkout-shipping-choice'),(480825,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left_measure','%','','','.b-switch'),(480826,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left_measure','%','','','.b-menu-lev_display-lra'),(480827,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left_measure','%','','','.b-menu-lev_display-lra'),(480828,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left_measure','%','','','.b-menu-lev_display-lra'),(480829,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left_measure','%','','','.b-menu-lev_display-lra'),(480830,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left_measure','%','','','.b-menu-lev_display-lra'),(480831,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left_measure','%','','','.b-menu-lev_display-right'),(480832,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left_measure','%','','','.b-menu-lev_display-right'),(480833,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left_measure','%','','','.b-menu-lev_display-right'),(480834,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left_measure','%','','','.b-menu-lev_display-right'),(480835,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left_measure','%','','','.b-menu-lev_display-right'),(480836,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left_measure','vw','','','.b-menu-lev_display-slide'),(480837,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left_measure','vw','','','.b-menu-lev_display-slide'),(480838,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left_measure','vw','','','.b-menu-lev_display-slide'),(480839,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left_measure','vw','','','.b-menu-lev_display-slide'),(480840,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left_measure','vw','','','.b-menu-lev_display-slide'),(480841,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left_measure','vw','','','.b-menu-open_from-left'),(480842,'furniture-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left_measure','%','','','.b-slick'),(480843,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content:before','left_measure','%','','','.w-product-properties-icons'),(480844,'furniture-mobile','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','left_measure','%','','','.mainBanner'),(480845,'furniture-mobile','.w-search .suggest','left_measure','%','4','','.w-search'),(480846,'furniture-mobile','.rating-0, .rating-1, .rating-2, .rating-3, .rating-4, .rating-5','letter-spacing','2px','','',''),(480847,'furniture-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','line-height','1.2','','','.w-communication-new-topic'),(480848,'furniture-mobile','.b-info-popup .info-popup div','line-height','30','3','','.b-info-popup'),(480849,'furniture-mobile','.b-form .shipping-method .sub-title','line-height','1.3','','','.b-form'),(480850,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','line-height','12','','','.b-switch'),(480851,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line-height','30','','','.b-switch'),(480852,'furniture-mobile','.w-tabs .tab-li.tab-cart a','line-height','0.75','3','','.w-tabs'),(480853,'furniture-mobile','.message.success','line-height','1','3','',''),(480854,'furniture-mobile','.heading-4 .edit, h4 .edit','line-height','20','','',''),(480855,'furniture-mobile','.p-blog-index .nav-next a','line-height','50','3','','.p-blog-index'),(480856,'furniture-mobile','.w-socials .post_item > div','line-height','19','','','.w-socials'),(480857,'furniture-mobile','.p-quick-order-index .paginate_button.previous','line-height','26','3','','.p-quick-order-index'),(480858,'furniture-mobile','.p-quick-order-index .paginate_button.next','line-height','26','3','','.p-quick-order-index'),(480859,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.p-quick-order-index'),(480860,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.p-quick-order-index'),(480861,'furniture-mobile','.w-text .customer-service b','line-height','18','','','.w-text'),(480862,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','line-height','23','','','.w-promotions'),(480863,'furniture-mobile','.w-sale .name','line-height','1.2','','','.w-sale'),(480864,'furniture-mobile','.w-quote .cart-box-link','line-height','40','2885,3','','.w-quote'),(480865,'furniture-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(480866,'furniture-mobile','.w-account .my-acc-link','line-height','48','3','','.w-account'),(480867,'furniture-mobile','.p-blog-index .nav-previous a','line-height','50','3','','.p-blog-index'),(480868,'furniture-mobile','.p-blog-index .nav-next a','line-height','50','3','','.p-blog-index'),(480869,'furniture-mobile','.testimonials .heading-3','line-height','1','3','',''),(480870,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line-height','24','','','.w-compare-box-item'),(480871,'furniture-mobile','.w-catalog-paging .next','line-height','26','3','','.w-catalog-paging'),(480872,'furniture-mobile','.w-promotions .heading-3','line-height','1','','','.w-promotions'),(480873,'furniture-mobile','.w-promotions .promo-salemaker .discount','line-height','23','','','.w-promotions'),(480874,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','line-height','23','','','.w-promotions'),(480875,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','line-height','23','','','.w-promotions'),(480876,'furniture-mobile','.b-preloader .preloader','line-height','40','3','','.b-preloader'),(480877,'furniture-mobile','.w-cart-compare .attributes-cell','line-height','22','','','.w-cart-compare'),(480878,'furniture-mobile','.w-cart .cart-box-link','line-height','48','3','','.w-cart'),(480879,'furniture-mobile','.p-blog-index .nav-next a','line-height','50','3','','.p-blog-index'),(480880,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(480881,'furniture-mobile','.b-bottom .closeable-heading','line-height','45','3','','.b-bottom'),(480882,'furniture-mobile','.w-menu-style-1 .menu-ico','line-height','54','','','.w-menu-style-1'),(480883,'furniture-mobile','.b-messages .messBtnMenuDelete','line-height','10','3','','.b-messages'),(480884,'furniture-mobile','.b-messages span.starred::before','line-height','10','','','.b-messages'),(480885,'furniture-mobile','.b-messages .messBtnMenuStarred','line-height','10','3','','.b-messages'),(480886,'furniture-mobile','.b-messages .messBtnMenuUnread','line-height','10','3','','.b-messages'),(480887,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line-height','14','','','.b-messages'),(480888,'furniture-mobile','.w-sale .badge','line-height','27','','','.w-sale'),(480889,'furniture-mobile','.w-quote .cart-box-link','line-height','48','3','','.w-quote'),(480890,'furniture-mobile','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(480891,'furniture-mobile','.w-socials .post_item > div','line-height','19','','','.w-socials'),(480892,'furniture-mobile','.p-payer-order-confirmation .ship-ico','line-height','20','3','','.p-payer-order-confirmation'),(480893,'furniture-mobile','.p-payer-order-confirmation .order-ico','line-height','20','3','','.p-payer-order-confirmation'),(480894,'furniture-mobile','.p-payer-order-confirmation .pay-ico','line-height','20','3','','.p-payer-order-confirmation'),(480895,'furniture-mobile','.p-payer-order-confirmation .discount-ico','line-height','20','3','','.p-payer-order-confirmation'),(480896,'furniture-mobile','.p-payer-order-confirmation .comment-ico','line-height','20','3','','.p-payer-order-confirmation'),(480897,'furniture-mobile','.p-payer-order-pay .ship-ico','line-height','20','3','','.p-payer-order-pay'),(480898,'furniture-mobile','.p-payer-order-pay .pay-ico','line-height','20','3','','.p-payer-order-pay'),(480899,'furniture-mobile','.p-payer-order-pay .order-ico','line-height','20','3','','.p-payer-order-pay'),(480900,'furniture-mobile','.p-payer-order-pay .discount-ico','line-height','20','3','','.p-payer-order-pay'),(480901,'furniture-mobile','.p-payer-order-pay .comment-ico','line-height','20','3','','.p-payer-order-pay'),(480902,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','line-height','15','','','.b-switch'),(480903,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','line-height','15','','','.b-switch'),(480904,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','line-height','15','','','.b-switch'),(480905,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','line-height','56','4','','.b-switch'),(480906,'furniture-mobile','.w-menu-slider .close','line-height','10','','','.w-menu-slider'),(480907,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line-height','24','','','.w-compare-box-item'),(480908,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line-height','35','','','.w-catalog-paging'),(480909,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','line-height','16','','','.p-account-subscription-historyinfo'),(480910,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','line-height','16','','','.b-switch'),(480912,'furniture-mobile','.w-menu-slider .menu-ico','line-height','54','','','.w-menu-slider'),(480913,'furniture-mobile','.w-menu-slider .close','line-height','10','','','.w-menu-slider'),(480914,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','line-height','10','','','.b-switch'),(480915,'furniture-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','line-height','1.2','','','.p-quick-order-index'),(480916,'furniture-mobile','.b-info .info','line-height','1','3','','.b-info'),(480917,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','line-height','15','','','.b-switch'),(480918,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','line-height','10','','','.b-switch'),(480919,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','line-height','10','','','.b-switch'),(480920,'furniture-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(480921,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','line-height','12','','','.b-switch'),(480922,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','line-height','16','','','.p-account-subscription-historyinfo'),(480923,'furniture-mobile','.w-menu-slider .menu-ico','line-height','54','','','.w-menu-slider'),(480924,'furniture-mobile','.w-menu-slider .close','line-height','10','','','.w-menu-slider'),(480925,'furniture-mobile','.w-menu-style-1 .menu-ico','line-height','54','','','.w-menu-style-1'),(480926,'furniture-mobile','.bell-ico .heading-2','line-height','10','3','','.bell-ico'),(480927,'furniture-mobile','.w-sale .special-price','line-height','0.8','','','.w-sale'),(480928,'furniture-mobile','.w-sale .ends','line-height','1','','','.w-sale'),(480929,'furniture-mobile','.w-sale .old','line-height','0.8','','','.w-sale'),(480930,'furniture-mobile','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(480931,'furniture-mobile','.w-languages .current','line-height','1','3','','.w-languages'),(480932,'furniture-mobile','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(480933,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','line-height','16','','','.p-account-subscription-historyinfo'),(480934,'furniture-mobile','.w-tabs .tab-li.tab-sample a','line-height','0.75','3','','.w-tabs'),(480935,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','line-height','16','','','.p-account-subscription-historyinfo'),(480936,'furniture-mobile','.w-cart-compare .compare-table','line-height','1.3','','','.w-cart-compare'),(480937,'furniture-mobile','.w-catalog-paging .prev','line-height','26','3','','.w-catalog-paging'),(480938,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line-height','18','','','.b-form'),(480939,'furniture-mobile','.w-checkout-shipping-choice span','line-height','19','','','.w-checkout-shipping-choice'),(480940,'furniture-mobile','.w-catalog-paging .prev-pages','line-height','35','','','.w-catalog-paging'),(480941,'furniture-mobile','.w-catalog-paging .prev','line-height','35','','','.w-catalog-paging'),(480942,'furniture-mobile','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(480943,'furniture-mobile','.w-socials .post_item > div','line-height','19','','','.w-socials'),(480944,'furniture-mobile','.w-sale .special-price','line-height','0.8','','','.w-sale'),(480945,'furniture-mobile','.b-info-popup .info-popup div','line-height','1.7','','','.b-info-popup'),(480946,'furniture-mobile','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(480947,'furniture-mobile','.w-sale .name','line-height','1.2','','','.w-sale'),(480948,'furniture-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(480949,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item label','line-height','1.3','','','.w-checkout-shipping-address'),(480952,'furniture-mobile','.w-sale .old','line-height','0.8','','','.w-sale'),(480953,'furniture-mobile','.w-menu-style-1 .menu-ico','line-height','54','','','.w-menu-style-1'),(480954,'furniture-mobile','.w-tabs .tab-li.tab-wishlist a','line-height','0.75','3','','.w-tabs'),(480955,'furniture-mobile','.w-text .customer-service b','line-height','18','','','.w-text'),(480956,'furniture-mobile','.w-socials .post_item > div','line-height','19','','','.w-socials'),(480957,'furniture-mobile','.w-sale .special-price','line-height','0.8','','','.w-sale'),(480958,'furniture-mobile','.b-info .info','line-height','1','3','','.b-info'),(480959,'furniture-mobile','.b-info-popup .info-popup','line-height','2','','','.b-info-popup'),(480960,'furniture-mobile','.w-text .customer-service b','line-height','18','','','.w-text'),(480961,'furniture-mobile','.w-sale .ends','line-height','1','','','.w-sale'),(480962,'furniture-mobile','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(480963,'furniture-mobile','.btn-2','line-height','20','','',''),(480964,'furniture-mobile','.w-cart-compare .delete-cart','line-height','1','','','.w-cart-compare'),(480965,'furniture-mobile','.w-menu-slider .close','line-height','10','','','.w-menu-slider'),(480966,'furniture-mobile','.w-search .button-search','line-height','1.3','3','','.w-search'),(480967,'furniture-mobile','.w-menu-style-1 .menu-ico','line-height','54','','','.w-menu-style-1'),(480969,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','line-height','22','','','.b-form'),(480970,'furniture-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','line-height','22','','','.w-filters'),(480971,'furniture-mobile','.heading-3 .right-text, h3 .right-text','line-height','20','','',''),(480972,'furniture-mobile','.heading-3 .edit, h3 .edit','line-height','20','','',''),(480973,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','line-height','56','4','','.b-switch'),(480974,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','line-height','56','4','','.b-switch'),(480975,'furniture-mobile','.w-text .customer-service b','line-height','18','','','.w-text'),(480976,'furniture-mobile','.savings-ico .heading-2','line-height','10','3','','.savings-ico'),(480977,'furniture-mobile','.w-sale .special-price','line-height','0.8','','','.w-sale'),(480978,'furniture-mobile','.w-sale .old','line-height','0.8','','','.w-sale'),(480979,'furniture-mobile','.w-sale .ends','line-height','1','','','.w-sale'),(480980,'furniture-mobile','.w-sale .badge','line-height','27','','','.w-sale'),(480981,'furniture-mobile','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(480982,'furniture-mobile','.p-blog-index .nav-previous a','line-height','50','3','','.p-blog-index'),(480983,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','line-height','24','','','.b-fancybox'),(480984,'furniture-mobile','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(480985,'furniture-mobile','.w-sale .badge','line-height','27','','','.w-sale'),(480986,'furniture-mobile','.w-sale .name','line-height','1.2','','','.w-sale'),(480987,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','line-height','16','','','.p-account-subscription-historyinfo'),(480988,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(480989,'furniture-mobile','.p-blog-index .nav-previous a','line-height','50','3','','.p-blog-index'),(480990,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(480991,'furniture-mobile','.w-socials .post_item > div','line-height','19','','','.w-socials'),(480992,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(480993,'furniture-mobile','.btn','line-height','20','','',''),(480994,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(480995,'furniture-mobile','.w-text .customer-service b','line-height','18','','','.w-text'),(480996,'furniture-mobile','.b-info .info','line-height','1','3','','.b-info'),(480997,'furniture-mobile','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(480998,'furniture-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(480999,'furniture-mobile','.w-reviews .heading-3','line-height','1','3','','.w-reviews'),(481000,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(481001,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(481003,'furniture-mobile','.w-menu-slider .menu-ico','line-height','54','','','.w-menu-slider'),(481004,'furniture-mobile','.p-quick-order-index .stock','line-height','1.2','','','.p-quick-order-index'),(481005,'furniture-mobile','.b-info .info','line-height','1','3','','.b-info'),(481006,'furniture-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','line-height','18','','','.b-form'),(481007,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line-height','24','','','.w-compare-box-item'),(481008,'furniture-mobile','.w-cart-listing .links','line-height','35','','','.w-cart-listing'),(481009,'furniture-mobile','.price .old','line-height','0.6','','',''),(481010,'furniture-mobile','.w-cart-compare .price-cell','line-height','22','','','.w-cart-compare'),(481011,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(481012,'furniture-mobile','.b-info .info','line-height','1','3','','.b-info'),(481013,'furniture-mobile','.w-sale .name','line-height','1.2','','','.w-sale'),(481014,'furniture-mobile','.w-sale .badge','line-height','27','','','.w-sale'),(481015,'furniture-mobile','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(481016,'furniture-mobile','.w-sale .badge','line-height','27','','','.w-sale'),(481017,'furniture-mobile','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(481019,'furniture-mobile','.w-menu-style-1 .menu-ico','line-height','54','','','.w-menu-style-1'),(481020,'furniture-mobile','.w-sale .ends','line-height','1','','','.w-sale'),(481022,'furniture-mobile','.w-multi-cart-cart-switcher .cart-label','line-height','20','','','.w-multi-cart-cart-switcher'),(481024,'furniture-mobile','.b-bottom .pop-up-close','line-height','25','','','.b-bottom'),(481025,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(481026,'furniture-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(481027,'furniture-mobile','.w-personal-gift-status-bar .inform','line-height','14','4','','.w-personal-gift-status-bar'),(481028,'furniture-mobile','.w-menu-slider .close','line-height','10','','','.w-menu-slider'),(481029,'furniture-mobile','.w-tabs .tab-li.tab-quote a','line-height','0.75','3','','.w-tabs'),(481030,'furniture-mobile','.w-sale .special-price','line-height','0.8','','','.w-sale'),(481031,'furniture-mobile','.w-sale .old','line-height','0.8','','','.w-sale'),(481032,'furniture-mobile','.b-fancybox .fancybox-close','line-height','40','','','.b-fancybox'),(481033,'furniture-mobile','.b-form .form-inputs div.required-message','line-height','1.3','','','.b-form'),(481034,'furniture-mobile','.b-info .info','line-height','1','3','','.b-info'),(481035,'furniture-mobile','.w-product-customers-activity .close','line-height','32','','','.w-product-customers-activity'),(481036,'furniture-mobile','.p-blog-index .nav-previous a','line-height','50','3','','.p-blog-index'),(481037,'furniture-mobile','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(481038,'furniture-mobile','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(481039,'furniture-mobile','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(481041,'furniture-mobile','.w-menu-style-1 .menu-ico','line-height','54','','','.w-menu-style-1'),(481042,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line-height','24','','','.w-compare-box-item'),(481043,'furniture-mobile','.w-checkout-billing-address .addresses .address-item label','line-height','1.3','','','.w-checkout-billing-address'),(481044,'furniture-mobile','.w-text .customer-service b','line-height','18','','','.w-text'),(481045,'furniture-mobile','.w-cart-compare .cart-name a','line-height','1.2','','','.w-cart-compare'),(481046,'furniture-mobile','.w-personal-gift-status-bar .end-date','line-height','14','3','','.w-personal-gift-status-bar'),(481047,'furniture-mobile','.p-blog-index .nav-previous a','line-height','50','3','','.p-blog-index'),(481048,'furniture-mobile','.p-blog-index .nav-next a','line-height','50','3','','.p-blog-index'),(481049,'furniture-mobile','.p-blog-index .nav-previous a','line-height','50','3','','.p-blog-index'),(481050,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line-height','13','','','.b-select-suggest'),(481051,'furniture-mobile','.w-menu-slider .menu-ico','line-height','54','','','.w-menu-slider'),(481052,'furniture-mobile','.w-sale .ends','line-height','1','','','.w-sale'),(481053,'furniture-mobile','.b-switch .bootstrap-switch','line-height','28','','','.b-switch'),(481054,'furniture-mobile','.w-menu-slider .menu-ico','line-height','54','','','.w-menu-slider'),(481055,'furniture-mobile','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(481056,'furniture-mobile','.w-sale .old','line-height','0.8','','','.w-sale'),(481057,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line-height','24','','','.w-compare-box-item'),(481058,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.b-data-table'),(481059,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.b-data-table'),(481060,'furniture-mobile','.b-products-listing .products-listing .name a','line-height','1.5','','','.b-products-listing'),(481061,'furniture-mobile','.b-products-listing .btn-preloader','line-height','24','3','','.b-products-listing'),(481062,'furniture-mobile','.b-products-listing .loader','line-height','30','4','','.b-products-listing'),(481063,'furniture-mobile','.b-products-listing .products-listing .btn-buy','line-height','10','3','','.b-products-listing'),(481064,'furniture-mobile','.checkbox input:not(checked) + span:before','line-height','24','','',''),(481065,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','line-height','35','','','.w-blog-widget-related-posts'),(481066,'furniture-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','line-height','1','','','.w-blog-widget-post-share'),(481067,'furniture-mobile','.w-blog-widget-post-listing .post_name','line-height','1.2','','','.w-blog-widget-post-listing'),(481068,'furniture-mobile','.w-blog-widget-post-listing .post_date span + span','line-height','1','3','','.w-blog-widget-post-listing'),(481069,'furniture-mobile','.w-blog-widget-most-popular-posts a','line-height','1','3','','.w-blog-widget-most-popular-posts'),(481070,'furniture-mobile','.w-blog-widget-categories-list a','line-height','1','3','','.w-blog-widget-categories-list'),(481071,'furniture-mobile','.w-currencies .current','line-height','1','3','','.w-currencies'),(481072,'furniture-mobile','.w-currencies .currencies-title','line-height','15','','','.w-currencies'),(481073,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','line-height','26','','','.b-select-suggest'),(481074,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','line-height','10','','','.b-switch'),(481075,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(481076,'furniture-mobile','.w-socials .post_item > div','line-height','19','','','.w-socials'),(481077,'furniture-mobile','.w-sale .name','line-height','1.2','','','.w-sale'),(481078,'furniture-mobile','.w-sale .special-price','line-height','0.8','','','.w-sale'),(481079,'furniture-mobile','.order-summary .price-row.ot_coupon .title','line-height','22','3','','.order-summary'),(481080,'furniture-mobile','.heading-4 .right-text, h4 .right-text','line-height','20','','',''),(481081,'furniture-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(481082,'furniture-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(481083,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','40','','','.w-communication-new-topic'),(481084,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','35','3','','.w-communication-new-topic'),(481085,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line-height','36','','','.w-communication-new-topic'),(481087,'furniture-mobile','.btn-3','line-height','20','','',''),(481088,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(481089,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','line-height','30','3','','.b-form'),(481090,'furniture-mobile','.w-sale .ends','line-height','1','','','.w-sale'),(481091,'furniture-mobile','.w-sale .badge','line-height','27','','','.w-sale'),(481092,'furniture-mobile','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(481093,'furniture-mobile','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(481094,'furniture-mobile','.w-sale .name','line-height','1.2','','','.w-sale'),(481095,'furniture-mobile','.w-sale .old','line-height','0.8','','','.w-sale'),(481096,'furniture-mobile','.b-form .cart-popup .price','line-height','35','','','.b-form'),(481097,'furniture-mobile','.w-menu-horizontal .menu-ico','line-height','54','','','.w-menu-horizontal'),(481098,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','line-height','16','','','.p-account-subscription-historyinfo'),(481099,'furniture-mobile','.w-catalog-paging .page-number','line-height','35','','','.w-catalog-paging'),(481100,'furniture-mobile','.w-catalog-paging .next-pages','line-height','35','','','.w-catalog-paging'),(481101,'furniture-mobile','.w-catalog-listing-look .grid','line-height','35','','','.w-catalog-listing-look'),(481102,'furniture-mobile','.w-catalog-listing-look .b2b','line-height','35','','','.w-catalog-listing-look'),(481103,'furniture-mobile','.w-catalog-listing-look .list','line-height','35','','','.w-catalog-listing-look'),(481104,'furniture-mobile','.blogsidebar .heading-title','line-height','1','','','.blogsidebar'),(481105,'furniture-mobile','.w-cart-listing .item .attributes','line-height','1.7','','','.w-cart-listing'),(481106,'furniture-mobile','.w-cart-listing .points-earn','line-height','1','','','.w-cart-listing'),(481107,'furniture-mobile','.w-cart-listing .points-redeem','line-height','1','','','.w-cart-listing'),(481108,'furniture-mobile','.w-cart-listing .remove-btn','line-height','30','','','.w-cart-listing'),(481109,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(481110,'furniture-mobile','.b-fancybox .fancybox-nav span','line-height','40','','','.b-fancybox'),(481112,'furniture-mobile','.w-catalog-paging .next','line-height','35','','','.w-catalog-paging'),(481113,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','line-height','30','','','.b-switch'),(481114,'furniture-mobile','.w-checkout-create-account .account-benefits strong','line-height','16','3','','.w-checkout-create-account'),(481115,'furniture-mobile','.p-blog-index .nav-next a','line-height','50','3','','.p-blog-index'),(481116,'furniture-mobile','.w-catalog-paging ','line-height','35','2','','.w-catalog-paging'),(481118,'furniture-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(481119,'furniture-mobile','.w-cart-compare .js-cart_totals_container','line-height','1.2','','','.w-cart-compare'),(481120,'furniture-mobile','.btn-1','line-height','24','','',''),(481121,'furniture-mobile','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(481122,'furniture-mobile','.b-products-listing .products-listing .btn-preloader','line-height','8','','','.b-products-listing'),(481123,'furniture-mobile','.price .special','line-height','0.8','','',''),(481124,'furniture-mobile','.b-data-table table.dataTable thead td','line-height','1.5','','','.b-data-table'),(481125,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line-height','24','','','.w-compare-box-item'),(481126,'furniture-mobile','.w-menu-slider .close','line-height','10','','','.w-menu-slider'),(481127,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','line-height','30','','','.b-switch'),(481128,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','line-height','30','','','.b-switch'),(481129,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','line-height','30','','','.b-switch'),(481130,'furniture-mobile','.w-menu-slider .menu-ico','line-height','54','','','.w-menu-slider'),(481131,'furniture-mobile','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(481132,'furniture-mobile','.p-blog-index .nav-next a','line-height','50','3','','.p-blog-index'),(481133,'furniture-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','line-height','22','','','.w-filters'),(481134,'furniture-mobile','.b-upload-file .snapshot','line-height','38','','','.b-upload-file'),(481135,'furniture-mobile','.b-product-images .media-popup .mp-close','line-height','100','','','.b-product-images'),(481136,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','line-height','100','','','.b-product-images'),(481137,'furniture-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line-height','30','','','.b-menu-burger_icon'),(481138,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(481139,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(481140,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(481141,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(481142,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(481143,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','line-height','1.2','','','.b-menu-style-1'),(481144,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','line-height','24','','','.b-menu-style-2'),(481145,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','line-height','24','','','.b-menu-style-2'),(481146,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','line-height','42','','','.b-menu-style-2'),(481147,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','line-height','16','3','','.b-menu-style-2'),(481148,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','line-height','16','3','','.b-menu-style-2'),(481149,'furniture-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','line-height','1.3','','','.b-trade-approval'),(481150,'furniture-mobile','.batchPr .btn-batch-remove','line-height','1','3','','.batchPr'),(481151,'furniture-mobile','.batchPr .batchSelect .checkbox','line-height','36','','','.batchPr'),(481152,'furniture-mobile','.batchPr .checkbox input:not(checked) + span:before','line-height','33','','','.batchPr'),(481153,'furniture-mobile','.batchPr .btn-batch-remove','line-height','0','','','.batchPr'),(481154,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line-height','24','3','','.w-catalog-compare'),(481155,'furniture-mobile','.w-catalog-compare td','line-height','1.5','','','.w-catalog-compare'),(481156,'furniture-mobile','.w-catalog-compare span.btn-preloader','line-height','24','3','','.w-catalog-compare'),(481157,'furniture-mobile','.w-delivery-day .ends','line-height','1','','','.w-delivery-day'),(481158,'furniture-mobile','.w-account .account-dropdown','line-height','50','3','','.w-account'),(481159,'furniture-mobile','.tripleBanner .w-html_box','line-height','1.25','','','.tripleBanner'),(481160,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','40','','','.b-slick'),(481161,'furniture-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line-height','36','','','.b-slick'),(481162,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','48','2885','','.b-slick'),(481163,'furniture-mobile','.w-account .my-acc-link','line-height','40','2885,3','','.w-account'),(481164,'furniture-mobile','.w-cart .cart-box-link','line-height','40','2885,3','','.w-cart'),(481165,'furniture-mobile','.w-search .search-ico','line-height','40','2885,3','','.w-search'),(481166,'furniture-mobile','.menu-header .burger-icon','line-height','40','2885','','.menu-header'),(481167,'furniture-mobile','.menu-header .burger-icon','line-height','40','2885,3','','.menu-header'),(481168,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','line-height','10','2885,3','','.b-menu-style-3'),(481169,'furniture-mobile','.w-subscribers .btn-submit','line-height','24','','','.w-subscribers'),(481170,'furniture-mobile','.w-social-links a','line-height','1','','','.w-social-links'),(481171,'furniture-mobile','.b-quantity .qty-box .bigger','line-height','27','','','.b-quantity'),(481172,'furniture-mobile','.b-quantity .qty-box .smaller','line-height','31','','','.b-quantity'),(481173,'furniture-mobile','.w-product-sale-ends .ends','line-height','1','','','.w-product-sale-ends'),(481174,'furniture-mobile','.w-product-quantity .qty-box .smaller, .w-product-quantity .qty-box .bigger','line-height','38','','','.w-product-quantity'),(481175,'furniture-mobile','.warrantyProduct .title','line-height','1.2','','','.warrantyProduct'),(481176,'furniture-mobile','.warrantyProduct .seeDetails','line-height','1.2','','','.warrantyProduct'),(481177,'furniture-mobile','.w-sample .cart-box-link','line-height','48','3','','.w-sample'),(481178,'furniture-mobile','.w-sample .cart-box-link','line-height','40','2885,3','','.w-sample'),(481179,'furniture-mobile','.w-cart-discount-coupon .title','line-height','1','','','.w-cart-discount-coupon'),(481180,'furniture-mobile','.w-cart-bonus-points .title','line-height','1','','','.w-cart-bonus-points'),(481181,'furniture-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(481182,'furniture-mobile','.w-account-address-book .add_item a','line-height','20','3','','.w-account-address-book'),(481183,'furniture-mobile','.b-pagination .pagination .next-pages','line-height','30','','','.b-pagination'),(481184,'furniture-mobile','.b-pagination .pagination .page-number','line-height','30','','','.b-pagination'),(481185,'furniture-mobile','.b-pagination .pagination .prev-pages','line-height','30','','','.b-pagination'),(481186,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','line-height','30','','','.b-pagination'),(481187,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','line-height','26','3','','.b-pagination'),(481188,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','line-height','30','','','.b-pagination'),(481189,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','line-height','26','3','','.b-pagination'),(481190,'furniture-mobile','.b-pagination .pagination span','line-height','30','2','','.b-pagination'),(481191,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .remove','line-height','10','3','','.w-product-properties-filters-widgets-chosen-filters'),(481192,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','line-height','36','','','.w-questionnaire-widgets-questionnaire'),(481193,'furniture-mobile','.w-product-groups .val1','line-height','1','','','.w-product-groups'),(481194,'furniture-mobile','.w-product-custom-bundle .right-area .price','line-height','1.2','','','.w-product-custom-bundle'),(481195,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .attribute-qty-block > span','line-height','1.15','','','.b-products-listing'),(481196,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent a','line-height','1.5','','','.w-delivery-location-location-list'),(481197,'furniture-mobile','.w-wedding-registry-widgets-search-form .closeable-heading','line-height','1.5','3','','.w-wedding-registry-widgets-search-form'),(481198,'furniture-mobile','.w-sale-category .badge','line-height','27','','','.w-sale-category'),(481199,'furniture-mobile','.w-sale-category .ends','line-height','1','','','.w-sale-category'),(481200,'furniture-mobile','.w-sale-category .name','line-height','1.2','','','.w-sale-category'),(481201,'furniture-mobile','.w-sale-category .old','line-height','0.8','','','.w-sale-category'),(481202,'furniture-mobile','.w-sale-category .special-price','line-height','0.8','','','.w-sale-category'),(481203,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination a.next, .w-wedding-registry-widgets-search-paging .pagination span.next, .w-wedding-registry-widgets-search-paging .pagination .next a, .w-wedding-registry-widgets-search-paging .pagination .next span','line-height','26','3','','.w-wedding-registry-widgets-search-paging'),(481204,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','line-height','30','','','.w-wedding-registry-widgets-search-paging'),(481205,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','line-height','30','','','.w-wedding-registry-widgets-search-paging'),(481206,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','line-height','30','','','.w-wedding-registry-widgets-search-paging'),(481207,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','line-height','30','','','.w-wedding-registry-widgets-search-paging'),(481208,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','line-height','1.2','','','.w-product-bonus-points'),(481209,'furniture-mobile','.b-products-listing .productGroup label a','line-height','1','','','.b-products-listing'),(481210,'furniture-mobile','.w-rma-returns-history .column .title','line-height','16','','','.w-rma-returns-history'),(481211,'furniture-mobile','.w-rma-returns-history tbody tr td','line-height','1.3','','','.w-rma-returns-history'),(481212,'furniture-mobile','.w-rma-returns-history thead tr td','line-height','1.3','','','.w-rma-returns-history'),(481213,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','line-height','1.2','','','.b-products-listing'),(481214,'furniture-mobile','.w-predefined-promotion .heading-3','line-height','1','','','.w-predefined-promotion'),(481215,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','line-height','23','','','.w-predefined-promotion'),(481216,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','line-height','23','','','.w-predefined-promotion'),(481217,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','line-height','23','','','.w-predefined-promotion'),(481218,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','line-height','23','','','.w-predefined-promotion'),(481219,'furniture-mobile','.w-supplier-purchase-supplier-products .active .select_item > div','line-height','28','','','.w-supplier-purchase-supplier-products'),(481220,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','line-height','22','','','.w-filters'),(481221,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','line-height','22','','','.w-filters'),(481222,'furniture-mobile','.mainBanner .title > span','line-height','1','','','.mainBanner'),(481223,'furniture-mobile','.mainBanner .topBox > .left','line-height','1','','','.mainBanner'),(481224,'furniture-mobile','.lowestPricedBox .w-banner .ybg .title','line-height','1','','','.lowestPricedBox'),(481225,'furniture-mobile','.shopByCollectionBox .content .title span','line-height','1','','','.shopByCollectionBox'),(481226,'furniture-mobile','.order-summary .icon','line-height','30','','','.order-summary'),(481227,'furniture-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','line-height','20','','','.account-order-history'),(481228,'furniture-mobile','.account-order-history .order_history_table th','line-height','16','','','.account-order-history'),(481229,'furniture-mobile','.account-order-history .view_link','line-height','17','4','','.account-order-history'),(481230,'furniture-mobile','.account-order-history .orders-table .td-alignright','line-height','35','2885','','.account-order-history'),(481231,'furniture-mobile','.account-index .account_page h4','line-height','30','3','','.account-index'),(481232,'furniture-mobile','.account-index .date_value, .account-index .date_title','line-height','22','','','.account-index'),(481233,'furniture-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','line-height','20','','','.account-index'),(481234,'furniture-mobile','.account-index .remove-btn','line-height','30','','','.account-index'),(481235,'furniture-mobile','.account-index .topAccount > li > div','line-height','40','3','','.account-index'),(481236,'furniture-mobile','.account-index .view_link','line-height','17','4','','.account-index'),(481237,'furniture-mobile','.account-index .orders-table .links','line-height','35','2885','','.account-index'),(481238,'furniture-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','line-height','20','','','.account-samples'),(481239,'furniture-mobile','.account-samples .order_history_table th','line-height','16','','','.account-samples'),(481240,'furniture-mobile','.account-samples .view_link','line-height','17','4','','.account-samples'),(481241,'furniture-mobile','.account-samples .orders-table .td-alignright','line-height','35','2885','','.account-samples'),(481242,'furniture-mobile','.catalog-product-wrap .pn-direction','line-height','1.2','','','.catalog-product-wrap'),(481243,'furniture-mobile','.catalog-product-wrap .pn-image','line-height','24','3','','.catalog-product-wrap'),(481244,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','line-height','20','','','.checkout-index-wrap'),(481245,'furniture-mobile','.checkout-index-wrap .order-ico','line-height','20','3','','.checkout-index-wrap'),(481246,'furniture-mobile','.checkout-index-wrap .pay-ico','line-height','20','3','','.checkout-index-wrap'),(481247,'furniture-mobile','.checkout-index-wrap .ship-ico','line-height','20','3','','.checkout-index-wrap'),(481248,'furniture-mobile','.checkout-order-confirmation .comment-ico','line-height','20','3','','.checkout-order-confirmation'),(481249,'furniture-mobile','.checkout-order-confirmation .discount-ico','line-height','20','3','','.checkout-order-confirmation'),(481250,'furniture-mobile','.checkout-order-confirmation .order-ico','line-height','20','3','','.checkout-order-confirmation'),(481251,'furniture-mobile','.checkout-order-confirmation .ship-ico','line-height','20','3','','.checkout-order-confirmation'),(481252,'furniture-mobile','.b-info-popup .info-popup div','line_height_measure','px','3','','.b-info-popup'),(481254,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(481255,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line_height_measure','px','','','.b-switch'),(481256,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','line_height_measure','px','3','','.b-form'),(481257,'furniture-mobile','.heading-4 .edit, h4 .edit','line_height_measure','px','','',''),(481258,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line_height_measure','px','','','.w-compare-box-item'),(481259,'furniture-mobile','.p-quick-order-index .paginate_button.next','line_height_measure','px','3','','.p-quick-order-index'),(481260,'furniture-mobile','.p-quick-order-index .paginate_button.previous','line_height_measure','px','3','','.p-quick-order-index'),(481261,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.p-quick-order-index'),(481262,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.p-quick-order-index'),(481263,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','line_height_measure','px','','','.w-promotions'),(481264,'furniture-mobile','.p-blog-index .nav-previous a','line_height_measure','px','3','','.p-blog-index'),(481265,'furniture-mobile','.p-blog-index .nav-next a','line_height_measure','px','3','','.p-blog-index'),(481266,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line_height_measure','px','','','.w-compare-box-item'),(481267,'furniture-mobile','.w-promotions .promo-salemaker .discount','line_height_measure','px','','','.w-promotions'),(481268,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','line_height_measure','px','','','.w-promotions'),(481269,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','line_height_measure','px','','','.w-promotions'),(481270,'furniture-mobile','.b-preloader .preloader','line_height_measure','px','3','','.b-preloader'),(481271,'furniture-mobile','.w-cart-compare .attributes-cell','line_height_measure','px','','','.w-cart-compare'),(481272,'furniture-mobile','.w-catalog-paging .prev','line_height_measure','px','','','.w-catalog-paging'),(481273,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-messages'),(481274,'furniture-mobile','.b-bottom .closeable-heading','line_height_measure','px','3','','.b-bottom'),(481275,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line_height_measure','px','','','.w-compare-box-item'),(481276,'furniture-mobile','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(481277,'furniture-mobile','.w-menu-style-1 .menu-ico','line_height_measure','px','','','.w-menu-style-1'),(481278,'furniture-mobile','.b-messages .messBtnMenuDelete','line_height_measure','px','3','','.b-messages'),(481279,'furniture-mobile','.b-messages .messBtnMenuStarred','line_height_measure','px','3','','.b-messages'),(481280,'furniture-mobile','.b-messages span.starred::before','line_height_measure','px','','','.b-messages'),(481281,'furniture-mobile','.b-messages .messBtnMenuUnread','line_height_measure','px','3','','.b-messages'),(481282,'furniture-mobile','.p-blog-index .nav-next a','line_height_measure','px','3','','.p-blog-index'),(481283,'furniture-mobile','.w-menu-style-1 .menu-ico','line_height_measure','px','','','.w-menu-style-1'),(481284,'furniture-mobile','.p-payer-order-confirmation .ship-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(481285,'furniture-mobile','.p-payer-order-confirmation .pay-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(481286,'furniture-mobile','.p-payer-order-confirmation .order-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(481287,'furniture-mobile','.p-payer-order-confirmation .discount-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(481288,'furniture-mobile','.p-payer-order-confirmation .comment-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(481289,'furniture-mobile','.p-payer-order-pay .ship-ico','line_height_measure','px','3','','.p-payer-order-pay'),(481290,'furniture-mobile','.p-payer-order-pay .pay-ico','line_height_measure','px','3','','.p-payer-order-pay'),(481291,'furniture-mobile','.p-payer-order-pay .order-ico','line_height_measure','px','3','','.p-payer-order-pay'),(481292,'furniture-mobile','.p-payer-order-pay .discount-ico','line_height_measure','px','3','','.p-payer-order-pay'),(481293,'furniture-mobile','.p-payer-order-pay .comment-ico','line_height_measure','px','3','','.p-payer-order-pay'),(481294,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(481295,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(481296,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(481297,'furniture-mobile','.b-fancybox .fancybox-close','line_height_measure','px','','','.b-fancybox'),(481298,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','line_height_measure','px','4','','.b-switch'),(481299,'furniture-mobile','.b-info-popup .info-popup','line_height_measure','px','','','.b-info-popup'),(481301,'furniture-mobile','.bell-ico .heading-2','line_height_measure','px','3','','.bell-ico'),(481302,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line_height_measure','px','','','.w-catalog-paging'),(481303,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','line_height_measure','px','','','.p-account-subscription-historyinfo'),(481304,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(481305,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(481306,'furniture-mobile','.w-menu-slider .menu-ico','line_height_measure','px','','','.w-menu-slider'),(481307,'furniture-mobile','.w-menu-slider .close','line_height_measure','px','','','.w-menu-slider'),(481309,'furniture-mobile','.w-sale .badge','line_height_measure','px','','','.w-sale'),(481310,'furniture-mobile','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(481311,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(481312,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(481313,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(481314,'furniture-mobile','.w-menu-style-1 .menu-ico','line_height_measure','px','','','.w-menu-style-1'),(481315,'furniture-mobile','.b-switch .bootstrap-switch','line_height_measure','px','','','.b-switch'),(481316,'furniture-mobile','.w-menu-slider .menu-ico','line_height_measure','px','','','.w-menu-slider'),(481317,'furniture-mobile','.p-blog-index .nav-previous a','line_height_measure','px','3','','.p-blog-index'),(481318,'furniture-mobile','.p-blog-index .nav-next a','line_height_measure','px','3','','.p-blog-index'),(481319,'furniture-mobile','.w-menu-slider .close','line_height_measure','px','','','.w-menu-slider'),(481320,'furniture-mobile','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(481321,'furniture-mobile','.w-menu-style-1 .menu-ico','line_height_measure','px','','','.w-menu-style-1'),(481322,'furniture-mobile','.p-blog-index .nav-next a','line_height_measure','px','3','','.p-blog-index'),(481323,'furniture-mobile','.w-catalog-paging .prev','line_height_measure','px','3','','.w-catalog-paging'),(481324,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line_height_measure','px','','','.w-compare-box-item'),(481325,'furniture-mobile','.w-checkout-shipping-choice span','line_height_measure','px','','','.w-checkout-shipping-choice'),(481326,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line_height_measure','px','','','.w-compare-box-item'),(481327,'furniture-mobile','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(481328,'furniture-mobile','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(481329,'furniture-mobile','.b-form .checkbox-style:checked + .checkbox-span:before','line_height_measure','px','','','.b-form'),(481330,'furniture-mobile','.w-menu-style-1 .menu-ico','line_height_measure','px','','','.w-menu-style-1'),(481331,'furniture-mobile','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(481332,'furniture-mobile','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(481333,'furniture-mobile','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(481334,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','line_height_measure','px','','','.b-form'),(481336,'furniture-mobile','.btn-2','line_height_measure','px','','',''),(481337,'furniture-mobile','.w-menu-slider .close','line_height_measure','px','','','.w-menu-slider'),(481338,'furniture-mobile','.w-filters .input-checkbox:checked + .checkbox-span:before','line_height_measure','px','','','.w-filters'),(481339,'furniture-mobile','.w-personal-gift-status-bar .inform','line_height_measure','px','4','','.w-personal-gift-status-bar'),(481340,'furniture-mobile','.heading-3 .right-text, h3 .right-text','line_height_measure','px','','',''),(481341,'furniture-mobile','.heading-3 .edit, h3 .edit','line_height_measure','px','','',''),(481342,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','line_height_measure','px','4','','.b-switch'),(481343,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','line_height_measure','px','4','','.b-switch'),(481345,'furniture-mobile','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(481346,'furniture-mobile','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(481347,'furniture-mobile','.savings-ico .heading-2','line_height_measure','px','3','','.savings-ico'),(481348,'furniture-mobile','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(481349,'furniture-mobile','.w-sale .badge','line_height_measure','px','','','.w-sale'),(481350,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','line_height_measure','px','','','.b-fancybox'),(481351,'furniture-mobile','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(481352,'furniture-mobile','.w-sale .badge','line_height_measure','px','','','.w-sale'),(481353,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','line_height_measure','px','','','.p-account-subscription-historyinfo'),(481354,'furniture-mobile','.btn','line_height_measure','px','','',''),(481355,'furniture-mobile','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(481356,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','line_height_measure','px','','','.b-select-suggest'),(481358,'furniture-mobile','.w-cart-listing .links','line_height_measure','px','','','.w-cart-listing'),(481359,'furniture-mobile','.w-menu-slider .close','line_height_measure','px','','','.w-menu-slider'),(481360,'furniture-mobile','.p-blog-index .nav-previous a','line_height_measure','px','3','','.p-blog-index'),(481362,'furniture-mobile','.w-menu-slider .menu-ico','line_height_measure','px','','','.w-menu-slider'),(481363,'furniture-mobile','.w-menu-slider .menu-ico','line_height_measure','px','','','.w-menu-slider'),(481364,'furniture-mobile','.w-menu-style-1 .menu-ico','line_height_measure','px','','','.w-menu-style-1'),(481365,'furniture-mobile','.w-catalog-paging .prev-pages','line_height_measure','px','','','.w-catalog-paging'),(481367,'furniture-mobile','.b-bottom .pop-up-close','line_height_measure','px','','','.b-bottom'),(481368,'furniture-mobile','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(481369,'furniture-mobile','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(481370,'furniture-mobile','.w-sale .badge','line_height_measure','px','','','.w-sale'),(481371,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line_height_measure','px','','','.b-form'),(481373,'furniture-mobile','.w-product-customers-activity .close','line_height_measure','px','','','.w-product-customers-activity'),(481374,'furniture-mobile','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(481376,'furniture-mobile','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(481378,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(481379,'furniture-mobile','.p-blog-index .nav-next a','line_height_measure','px','3','','.p-blog-index'),(481380,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-select-suggest'),(481381,'furniture-mobile','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(481382,'furniture-mobile','.w-menu-slider .menu-ico','line_height_measure','px','','','.w-menu-slider'),(481383,'furniture-mobile','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(481384,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','line_height_measure','px','','','.p-account-subscription-historyinfo'),(481385,'furniture-mobile','.p-blog-index .nav-previous a','line_height_measure','px','3','','.p-blog-index'),(481386,'furniture-mobile','.p-blog-index .nav-previous a','line_height_measure','px','3','','.p-blog-index'),(481387,'furniture-mobile','.w-cart-compare .price-cell','line_height_measure','px','','','.w-cart-compare'),(481388,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.b-data-table'),(481389,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.b-data-table'),(481390,'furniture-mobile','.b-products-listing .btn-preloader','line_height_measure','px','3','','.b-products-listing'),(481391,'furniture-mobile','.b-products-listing .loader','line_height_measure','px','4','','.b-products-listing'),(481392,'furniture-mobile','.b-products-listing .products-listing .btn-buy','line_height_measure','px','3','','.b-products-listing'),(481393,'furniture-mobile','.checkbox input:not(checked) + span:before','line_height_measure','px','','',''),(481394,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','line_height_measure','px','','','.w-blog-widget-related-posts'),(481395,'furniture-mobile','.w-currencies .currencies-title','line_height_measure','px','','','.w-currencies'),(481396,'furniture-mobile','.w-sale .badge','line_height_measure','px','','','.w-sale'),(481397,'furniture-mobile','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(481398,'furniture-mobile','.w-quote .cart-box-link','line_height_measure','px','2885,3','','.w-quote'),(481399,'furniture-mobile','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(481400,'furniture-mobile','.w-catalog-paging .next','line_height_measure','px','3','','.w-catalog-paging'),(481401,'furniture-mobile','.order-summary .price-row.ot_coupon .title','line_height_measure','px','3','','.order-summary'),(481402,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','line_height_measure','px','','','.p-account-subscription-historyinfo'),(481403,'furniture-mobile','.w-checkout-create-account .account-benefits strong','line_height_measure','px','3','','.w-checkout-create-account'),(481404,'furniture-mobile','.heading-4 .right-text, h4 .right-text','line_height_measure','px','','',''),(481405,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','','','.w-communication-new-topic'),(481406,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','3','','.w-communication-new-topic'),(481407,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line_height_measure','px','','','.w-communication-new-topic'),(481408,'furniture-mobile','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(481409,'furniture-mobile','.w-menu-slider .close','line_height_measure','px','','','.w-menu-slider'),(481410,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(481411,'furniture-mobile','.w-personal-gift-status-bar .end-date','line_height_measure','px','3','','.w-personal-gift-status-bar'),(481412,'furniture-mobile','.w-sale .badge','line_height_measure','px','','','.w-sale'),(481413,'furniture-mobile','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(481414,'furniture-mobile','.w-menu-horizontal .menu-ico','line_height_measure','px','','','.w-menu-horizontal'),(481415,'furniture-mobile','.w-catalog-paging .page-number','line_height_measure','px','','','.w-catalog-paging'),(481416,'furniture-mobile','.w-catalog-paging .next-pages','line_height_measure','px','','','.w-catalog-paging'),(481417,'furniture-mobile','.w-catalog-listing-look .grid','line_height_measure','px','','','.w-catalog-listing-look'),(481418,'furniture-mobile','.w-catalog-listing-look .b2b','line_height_measure','px','','','.w-catalog-listing-look'),(481419,'furniture-mobile','.w-catalog-listing-look .list','line_height_measure','px','','','.w-catalog-listing-look'),(481420,'furniture-mobile','.w-cart-listing .remove-btn','line_height_measure','px','','','.w-cart-listing'),(481421,'furniture-mobile','.b-fancybox .fancybox-nav span','line_height_measure','px','','','.b-fancybox'),(481422,'furniture-mobile','.w-multi-cart-cart-switcher .cart-label','line_height_measure','px','','','.w-multi-cart-cart-switcher'),(481423,'furniture-mobile','.w-catalog-paging .next','line_height_measure','px','','','.w-catalog-paging'),(481424,'furniture-mobile','.w-menu-slider .close','line_height_measure','px','','','.w-menu-slider'),(481426,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(481427,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','line_height_measure','px','','','.p-account-subscription-historyinfo'),(481428,'furniture-mobile','.w-catalog-paging ','line_height_measure','px','2','','.w-catalog-paging'),(481429,'furniture-mobile','.b-form .cart-popup .price','line_height_measure','px','','','.b-form'),(481430,'furniture-mobile','.w-menu-slider .menu-ico','line_height_measure','px','','','.w-menu-slider'),(481431,'furniture-mobile','.btn-1','line_height_measure','px','','',''),(481432,'furniture-mobile','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(481433,'furniture-mobile','.b-products-listing .products-listing .btn-preloader','line_height_measure','px','','','.b-products-listing'),(481434,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','line_height_measure','px','','','.w-compare-box-item'),(481435,'furniture-mobile','.btn-3','line_height_measure','px','','',''),(481436,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(481437,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(481438,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(481439,'furniture-mobile','.p-blog-index .nav-next a','line_height_measure','px','3','','.p-blog-index'),(481440,'furniture-mobile','.p-blog-index .nav-previous a','line_height_measure','px','3','','.p-blog-index'),(481441,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','line_height_measure','px','','','.p-account-subscription-historyinfo'),(481442,'furniture-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','line_height_measure','px','','','.w-filters'),(481443,'furniture-mobile','.b-upload-file .snapshot','line_height_measure','px','','','.b-upload-file'),(481444,'furniture-mobile','.b-product-images .media-popup .mp-close','line_height_measure','px','','','.b-product-images'),(481445,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','line_height_measure','px','','','.b-product-images'),(481446,'furniture-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line_height_measure','px','','','.b-menu-burger_icon'),(481447,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(481448,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(481449,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(481450,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(481451,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(481452,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','line_height_measure','px','','','.b-menu-style-2'),(481453,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','line_height_measure','px','','','.b-menu-style-2'),(481454,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','line_height_measure','px','','','.b-menu-style-2'),(481455,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','line_height_measure','px','3','','.b-menu-style-2'),(481456,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','line_height_measure','px','3','','.b-menu-style-2'),(481457,'furniture-mobile','.batchPr .batchSelect .checkbox','line_height_measure','px','','','.batchPr'),(481458,'furniture-mobile','.batchPr .checkbox input:not(checked) + span:before','line_height_measure','px','','','.batchPr'),(481459,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line_height_measure','px','3','','.w-catalog-compare'),(481460,'furniture-mobile','.w-catalog-compare span.btn-preloader','line_height_measure','px','3','','.w-catalog-compare'),(481461,'furniture-mobile','.w-cart .cart-box-link','line_height_measure','px','3','','.w-cart'),(481462,'furniture-mobile','.w-account .my-acc-link','line_height_measure','px','3','','.w-account'),(481463,'furniture-mobile','.w-account .account-dropdown','line_height_measure','px','3','','.w-account'),(481464,'furniture-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line_height_measure','px','','','.b-slick'),(481465,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','','','.b-slick'),(481466,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','2885','','.b-slick'),(481467,'furniture-mobile','.w-account .my-acc-link','line_height_measure','px','2885,3','','.w-account'),(481468,'furniture-mobile','.w-cart .cart-box-link','line_height_measure','px','2885,3','','.w-cart'),(481469,'furniture-mobile','.w-search .search-ico','line_height_measure','px','2885,3','','.w-search'),(481470,'furniture-mobile','.menu-header .burger-icon','line_height_measure','px','2885','','.menu-header'),(481471,'furniture-mobile','.menu-header .burger-icon','line_height_measure','px','2885,3','','.menu-header'),(481472,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','line_height_measure','px','2885,3','','.b-menu-style-3'),(481473,'furniture-mobile','.w-subscribers .btn-submit','line_height_measure','px','','','.w-subscribers'),(481474,'furniture-mobile','.w-quote .cart-box-link','line_height_measure','px','3','','.w-quote'),(481475,'furniture-mobile','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(481476,'furniture-mobile','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(481477,'furniture-mobile','.w-product-quantity .qty-box .smaller, .w-product-quantity .qty-box .bigger','line_height_measure','px','','','.w-product-quantity'),(481478,'furniture-mobile','.w-sample .cart-box-link','line_height_measure','px','3','','.w-sample'),(481479,'furniture-mobile','.w-sample .cart-box-link','line_height_measure','px','2885,3','','.w-sample'),(481480,'furniture-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(481481,'furniture-mobile','.w-account-address-book .add_item a','line_height_measure','px','3','','.w-account-address-book'),(481482,'furniture-mobile','.b-pagination .pagination .next-pages','line_height_measure','px','','','.b-pagination'),(481483,'furniture-mobile','.b-pagination .pagination .page-number','line_height_measure','px','','','.b-pagination'),(481484,'furniture-mobile','.b-pagination .pagination .prev-pages','line_height_measure','px','','','.b-pagination'),(481485,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','line_height_measure','px','','','.b-pagination'),(481486,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','line_height_measure','px','3','','.b-pagination'),(481487,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','line_height_measure','px','','','.b-pagination'),(481488,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','line_height_measure','px','3','','.b-pagination'),(481489,'furniture-mobile','.b-pagination .pagination span','line_height_measure','px','2','','.b-pagination'),(481490,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .remove','line_height_measure','px','3','','.w-product-properties-filters-widgets-chosen-filters'),(481491,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','line_height_measure','px','','','.w-questionnaire-widgets-questionnaire'),(481492,'furniture-mobile','.w-sale-category .badge','line_height_measure','px','','','.w-sale-category'),(481493,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination a.next, .w-wedding-registry-widgets-search-paging .pagination span.next, .w-wedding-registry-widgets-search-paging .pagination .next a, .w-wedding-registry-widgets-search-paging .pagination .next span','line_height_measure','px','3','','.w-wedding-registry-widgets-search-paging'),(481494,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','line_height_measure','px','','','.w-wedding-registry-widgets-search-paging'),(481495,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','line_height_measure','px','','','.w-wedding-registry-widgets-search-paging'),(481496,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','line_height_measure','px','','','.w-wedding-registry-widgets-search-paging'),(481497,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','line_height_measure','px','','','.w-wedding-registry-widgets-search-paging'),(481498,'furniture-mobile','.w-rma-returns-history .column .title','line_height_measure','px','','','.w-rma-returns-history'),(481499,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','line_height_measure','px','','','.w-predefined-promotion'),(481500,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','line_height_measure','px','','','.w-predefined-promotion'),(481501,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','line_height_measure','px','','','.w-predefined-promotion'),(481502,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','line_height_measure','px','','','.w-predefined-promotion'),(481503,'furniture-mobile','.w-supplier-purchase-supplier-products .active .select_item > div','line_height_measure','px','','','.w-supplier-purchase-supplier-products'),(481504,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','line_height_measure','px','','','.w-filters'),(481505,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','line_height_measure','px','','','.w-filters'),(481506,'furniture-mobile','.order-summary .icon','line_height_measure','px','','','.order-summary'),(481507,'furniture-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','line_height_measure','px','','','.account-order-history'),(481508,'furniture-mobile','.account-order-history .order_history_table th','line_height_measure','px','','','.account-order-history'),(481509,'furniture-mobile','.account-order-history .view_link','line_height_measure','px','4','','.account-order-history'),(481510,'furniture-mobile','.account-order-history .orders-table .td-alignright','line_height_measure','px','2885','','.account-order-history'),(481511,'furniture-mobile','.account-index .account_page h4','line_height_measure','px','3','','.account-index'),(481512,'furniture-mobile','.account-index .date_value, .account-index .date_title','line_height_measure','px','','','.account-index'),(481513,'furniture-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','line_height_measure','px','','','.account-index'),(481514,'furniture-mobile','.account-index .remove-btn','line_height_measure','px','','','.account-index'),(481515,'furniture-mobile','.account-index .topAccount > li > div','line_height_measure','px','3','','.account-index'),(481516,'furniture-mobile','.account-index .view_link','line_height_measure','px','4','','.account-index'),(481517,'furniture-mobile','.account-index .orders-table .links','line_height_measure','px','2885','','.account-index'),(481518,'furniture-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','line_height_measure','px','','','.account-samples'),(481519,'furniture-mobile','.account-samples .order_history_table th','line_height_measure','px','','','.account-samples'),(481520,'furniture-mobile','.account-samples .view_link','line_height_measure','px','4','','.account-samples'),(481521,'furniture-mobile','.account-samples .orders-table .td-alignright','line_height_measure','px','2885','','.account-samples'),(481522,'furniture-mobile','.catalog-product-wrap .pn-image','line_height_measure','px','3','','.catalog-product-wrap'),(481523,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','line_height_measure','px','','','.checkout-index-wrap'),(481524,'furniture-mobile','.checkout-index-wrap .order-ico','line_height_measure','px','3','','.checkout-index-wrap'),(481525,'furniture-mobile','.checkout-index-wrap .pay-ico','line_height_measure','px','3','','.checkout-index-wrap'),(481526,'furniture-mobile','.checkout-index-wrap .ship-ico','line_height_measure','px','3','','.checkout-index-wrap'),(481527,'furniture-mobile','.checkout-order-confirmation .comment-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(481528,'furniture-mobile','.checkout-order-confirmation .discount-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(481529,'furniture-mobile','.checkout-order-confirmation .order-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(481530,'furniture-mobile','.checkout-order-confirmation .ship-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(481531,'furniture-mobile','.p-quick-order-index ul.token-input-list','list-style','none','','','.p-quick-order-index'),(481532,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','list-style','none','','','.p-blog-index'),(481533,'furniture-mobile','.w-account .account-dropdown','list-style','none','','','.w-account'),(481534,'furniture-mobile','.w-account .account-top','list-style','none','','','.w-account'),(481535,'furniture-mobile','.w-account .account-title','list-style','none','','','.w-account'),(481536,'furniture-mobile','.b-messages .messages-menu ul','list-style','none','','','.b-messages'),(481537,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul','list-style','none','','','.w-sitemap-delivery-location'),(481538,'furniture-mobile','.w-menu-style-1 ul','list-style','none','','','.w-menu-style-1'),(481539,'furniture-mobile','.b-info .info ul','list-style','disc inside','','','.b-info'),(481540,'furniture-mobile','.w-sitemap-delivery-location > ul','list-style','none','','','.w-sitemap-delivery-location'),(481541,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(481542,'furniture-mobile','.w-menu-style-1 ul','list-style','none','','','.w-menu-style-1'),(481543,'furniture-mobile','.b-info .info ul','list-style','disc inside','','','.b-info'),(481544,'furniture-mobile','.w-filters .filter-ul-content','list-style','none','','','.w-filters'),(481545,'furniture-mobile','.w-menu-horizontal ul','list-style','none','','','.w-menu-horizontal'),(481546,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(481547,'furniture-mobile','.b-info .info ul','list-style','disc inside','','','.b-info'),(481548,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','list-style','none','','','.p-blog-index'),(481549,'furniture-mobile','.b-info .info ul','list-style','disc inside','','','.b-info'),(481550,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(481551,'furniture-mobile','.products-quick-index ul','list-style','none','','',''),(481552,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','list-style','none','','','.p-blog-index'),(481553,'furniture-mobile','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(481554,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','list-style','none','','','.w-menu-slider'),(481555,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(481556,'furniture-mobile','.w-tabs .tab-navigation','list-style','none','','','.w-tabs'),(481557,'furniture-mobile','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(481558,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(481559,'furniture-mobile','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(481560,'furniture-mobile','.p-blog-index .wp-widget ul','list-style','none','','','.p-blog-index'),(481561,'furniture-mobile','.p-blog-index .wp-widget li','list-style','none','','','.p-blog-index'),(481562,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','list-style','none','','','.w-menu-slider'),(481563,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','list-style','none','','','.w-menu-slider'),(481564,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(481565,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','list-style','none','','','.p-blog-index'),(481566,'furniture-mobile','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(481567,'furniture-mobile','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(481568,'furniture-mobile','.b-info .info ul','list-style','disc inside','','','.b-info'),(481569,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(481570,'furniture-mobile','.w-menu-style-1 ul','list-style','none','','','.w-menu-style-1'),(481571,'furniture-mobile','.w-menu-style-1 ul','list-style','none','','','.w-menu-style-1'),(481572,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','list-style','none','','','.w-menu-slider'),(481573,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','list-style','none','','','.w-menu-slider'),(481574,'furniture-mobile','.p-blog-index .wp-widget ul','list-style','none','','','.p-blog-index'),(481575,'furniture-mobile','.p-blog-index .wp-widget li','list-style','none','','','.p-blog-index'),(481576,'furniture-mobile','.b-autocomplete .ui-autocomplete','list-style','none','','','.b-autocomplete'),(481577,'furniture-mobile','.w-account .acc-returning','list-style','none','','','.w-account'),(481578,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices li','list-style','none','','','.b-select-suggest'),(481579,'furniture-mobile','.b-select-suggest .select2-results li','list-style','none','','','.b-select-suggest'),(481580,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(481581,'furniture-mobile','.w-menu-big ul','list-style','none','','','.w-menu-big'),(481582,'furniture-mobile','.p-blog-index .wp-widget ul','list-style','none','','','.p-blog-index'),(481583,'furniture-mobile','.w-menu-style-1 ul','list-style','none','','','.w-menu-style-1'),(481584,'furniture-mobile','.p-blog-index .wp-widget ul','list-style','none','','','.p-blog-index'),(481585,'furniture-mobile','.w-account .acc-new','list-style','none','','','.w-account'),(481586,'furniture-mobile','.p-blog-index .wp-widget li','list-style','none','','','.p-blog-index'),(481587,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(481588,'furniture-mobile','.p-blog-index .wp-widget ul','list-style','none','','','.p-blog-index'),(481589,'furniture-mobile','.p-blog-index .wp-widget li','list-style','none','','','.p-blog-index'),(481590,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(481591,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','list-style','none','','','.w-menu-slider'),(481592,'furniture-mobile','.products-quick-index .token-input-list','list-style','none','','',''),(481593,'furniture-mobile','.b-info .info ul','list-style','disc inside','','','.b-info'),(481594,'furniture-mobile','.w-menu-style-1 ul','list-style','none','','','.w-menu-style-1'),(481595,'furniture-mobile','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(481596,'furniture-mobile','.p-blog-index .wp-widget ul','list-style','none','','','.p-blog-index'),(481597,'furniture-mobile','.p-blog-index .wp-widget li','list-style','none','','','.p-blog-index'),(481598,'furniture-mobile','.products-quick-index ul.token-input-list','list-style','none','','',''),(481599,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(481600,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(481601,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','list-style','none','','','.p-blog-index'),(481602,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','list-style','none','','','.p-blog-index'),(481603,'furniture-mobile','.p-blog-index .wp-widget li','list-style','none','','','.p-blog-index'),(481604,'furniture-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','list-style','none','','','.b-menu-style'),(481605,'furniture-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','list-style','none','','','.w-catalog-additional-images'),(481606,'furniture-mobile','.LeftCategories .w-menu-simple ul','list-style','none','','','.LeftCategories'),(481607,'furniture-mobile','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(481608,'furniture-mobile','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(481609,'furniture-mobile','.b-pagination ul.pagination','list-style','none','','','.b-pagination'),(481610,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','list-style','none','','','.w-account-personal-catalog'),(481611,'furniture-mobile','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(481612,'furniture-mobile','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(481613,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list'),(481614,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(481615,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list-block'),(481616,'furniture-mobile','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(481617,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li','list-style','none','','','.w-delivery-location-featured-list'),(481618,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(481619,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(481620,'furniture-mobile','.w-delivery-location-list-by-page .description ul','list-style','circle','','','.w-delivery-location-list-by-page'),(481621,'furniture-mobile','.w-delivery-location-cross-pages .description ul','list-style','circle','','','.w-delivery-location-cross-pages'),(481622,'furniture-mobile','.w-catalog-delivery-locations .description ul','list-style','circle','','','.w-catalog-delivery-locations'),(481623,'furniture-mobile','.w-wedding-registry-widgets-search-paging ul.pagination','list-style','none','','','.w-wedding-registry-widgets-search-paging'),(481624,'furniture-mobile','.w-support-system-filter .filter_cats','list-style','none','','','.w-support-system-filter'),(481625,'furniture-mobile','.w-product-configurator .pc-item','list-style','none','','','.w-product-configurator'),(481626,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-list'),(481627,'furniture-mobile','.w-filters .filter-box-content ul','list-style','none','','','.w-filters'),(481628,'furniture-mobile','.account-address-book .leftMes ul','list-style','disc inside','','','.account-address-book'),(481629,'furniture-mobile','.account-address-book .rightMes ul','list-style','disc inside','','','.account-address-book'),(481630,'furniture-mobile','.account-index .account_info','list-style','none','','','.account-index'),(481631,'furniture-mobile','.account-index .leftMes ul','list-style','disc inside','','','.account-index'),(481632,'furniture-mobile','.account-index .rightMes ul','list-style','disc inside','','','.account-index'),(481633,'furniture-mobile','.account-index .topAccount','list-style','none','','','.account-index'),(481634,'furniture-mobile','.w-delivery-location-featured-list .deliveryList ul','list-style-type','circle','','','.w-delivery-location-featured-list'),(481635,'furniture-mobile','.b-form .middle-form','margin','0 auto','','','.b-form'),(481636,'furniture-mobile','.p-reviews-info .review-info-image','margin','0px auto 0px','','','.p-reviews-info'),(481637,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','margin','0px auto 0px','','','.p-reviews-info'),(481638,'furniture-mobile','.p-reviews-info .review-info-image','margin','0px auto 0px','','','.p-reviews-info'),(481639,'furniture-mobile','.p-blog-index .post-thumbnail','margin','0px auto 20px','','','.p-blog-index'),(481640,'furniture-mobile','.p-blog-index .nav-previous a','margin','0px auto 0px','3','','.p-blog-index'),(481641,'furniture-mobile','.p-blog-index .nav-next a','margin','0px auto 0px','3','','.p-blog-index'),(481642,'furniture-mobile','.p-reviews-info .review-info-image','margin','0px auto 0px','','','.p-reviews-info'),(481643,'furniture-mobile','.p-blog-index .wp-widget li','margin','5px auto 0px','3','','.p-blog-index'),(481644,'furniture-mobile','.p-blog-index .nav-next a','margin','0px auto 0px','3','','.p-blog-index'),(481645,'furniture-mobile','.b-messages .msv_btn .btn','margin','0px auto 0px','','','.b-messages'),(481646,'furniture-mobile','.p-reviews-info .review-info-image','margin','0px auto 0px','','','.p-reviews-info'),(481647,'furniture-mobile','.p-blog-index .nav-previous a','margin','0px auto 0px','3','','.p-blog-index'),(481648,'furniture-mobile','.p-blog-index .nav-next a','margin','0px auto 0px','3','','.p-blog-index'),(481649,'furniture-mobile','.p-blog-index .post-thumbnail','margin','0px auto 20px','','','.p-blog-index'),(481650,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','margin','3px auto 3px','','','.b-select-suggest'),(481651,'furniture-mobile','.b-select-suggest .select2-results','margin','4px auto 4px','','','.b-select-suggest'),(481652,'furniture-mobile','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(481653,'furniture-mobile','.p-reviews-info .review-info-image','margin','0px auto 0px','','','.p-reviews-info'),(481654,'furniture-mobile','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(481655,'furniture-mobile','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(481656,'furniture-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin','0px auto 10px','','','.b-form'),(481657,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','margin','0px auto 0px','','','.p-reviews-info'),(481658,'furniture-mobile','.p-blog-index .wp-widget li','margin','5px auto 0px','3','','.p-blog-index'),(481659,'furniture-mobile','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(481660,'furniture-mobile','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(481661,'furniture-mobile','.p-blog-index .post-thumbnail','margin','0px auto 20px','','','.p-blog-index'),(481662,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','margin','0px auto 0px','','','.p-reviews-info'),(481663,'furniture-mobile','.p-blog-index .nav-previous a','margin','0px auto 0px','3','','.p-blog-index'),(481664,'furniture-mobile','.p-blog-index .post-thumbnail','margin','0px auto 20px','','','.p-blog-index'),(481665,'furniture-mobile','.p-blog-index .wp-widget li','margin','5px auto 0px','3','','.p-blog-index'),(481666,'furniture-mobile','.p-blog-index .nav-previous a','margin','0px auto 0px','3','','.p-blog-index'),(481667,'furniture-mobile','.p-blog-index .wp-widget li','margin','5px auto 0px','3','','.p-blog-index'),(481668,'furniture-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','margin','0 auto','','','.w-catalog-b2b-add-button'),(481669,'furniture-mobile','.w-blog-widget-tag-cloud a','margin','0px auto 4px','','','.w-blog-widget-tag-cloud'),(481670,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','margin','0px auto 0px','','','.p-reviews-info'),(481671,'furniture-mobile','.b-form .terms-login .bootstrap-switch','margin','9px auto 0px','','','.b-form'),(481672,'furniture-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin','0px auto 0px','','','.b-compare'),(481673,'furniture-mobile','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','margin','0 0 0 auto','','','.w-cart-listing'),(481674,'furniture-mobile','.b-compare .clear_all','margin','0px auto 0px','4','','.b-compare'),(481675,'furniture-mobile','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin','0px auto 0px','','','.b-compare'),(481676,'furniture-mobile','.b-compare .clear_all','margin','0px auto 0px','4','','.b-compare'),(481677,'furniture-mobile','.p-blog-index .nav-next a','margin','0px auto 0px','3','','.p-blog-index'),(481678,'furniture-mobile','.p-blog-index .nav-previous a','margin','0px auto 0px','3','','.p-blog-index'),(481679,'furniture-mobile','.p-blog-index .wp-widget li','margin','5px auto 0px','3','','.p-blog-index'),(481680,'furniture-mobile','.p-blog-index .nav-next a','margin','0px auto 0px','3','','.p-blog-index'),(481681,'furniture-mobile','.p-blog-index .post-thumbnail','margin','0px auto 20px','','','.p-blog-index'),(481682,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','margin','0px auto 0px','','','.p-reviews-info'),(481683,'furniture-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','margin','0 auto','','','.b-product-images'),(481684,'furniture-mobile','.b-trade-approval .middle-form','margin','0 auto','','','.b-trade-approval'),(481685,'furniture-mobile','.w-account .account-dropdown','margin','0 auto 10px','3','','.w-account'),(481686,'furniture-mobile','.b-products-listing .products-listing .slick-slide img','margin','auto','','','.b-products-listing'),(481687,'furniture-mobile','.b-products-listing .products-listing .compare input + span','margin','auto','','','.b-products-listing'),(481688,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-content','margin','5px auto','4','','.b-products-listing'),(481689,'furniture-mobile','.w-product-quantity .qty_packs .price_1','margin','0px auto 0px','4','','.w-product-quantity'),(481690,'furniture-mobile','.p-quote-checkout-index .datepicker-inline','margin','0 auto','','','.p-quote-checkout-index'),(481691,'furniture-mobile','.p-sample-checkout-index .datepicker-inline','margin','0 auto','','','.p-sample-checkout-index'),(481692,'furniture-mobile','.b-slick .slick-slide img','margin','auto','','','.b-slick'),(481693,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','margin','auto','2876','','.w-wedding-registry-widgets-photos'),(481694,'furniture-mobile','.lowestPricedBox .w-banner .ybg','margin','auto','3','','.lowestPricedBox'),(481695,'furniture-mobile','.account-address-book .address_book .row-buttons a','margin','0px auto 0px','','','.account-address-book'),(481696,'furniture-mobile','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin','0px auto 15px','','','.account-address-book'),(481697,'furniture-mobile','.account-address-book .address_book_row h2 a','margin','0px auto 0px','','','.account-address-book'),(481698,'furniture-mobile','.account-address-book .buttonBox .info','margin','0px auto 0px','','','.account-address-book'),(481699,'furniture-mobile','.account-index .account_info li','margin','0px auto 20px','','','.account-index'),(481700,'furniture-mobile','.account-index .view_history','margin','0px auto 0px','3','','.account-index'),(481701,'furniture-mobile','.checkout-index-wrap .datepicker-inline','margin','0 auto','','','.checkout-index-wrap'),(481702,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','margin','0 auto','','','.checkout-index-wrap'),(481703,'furniture-mobile','.w-communication-new-topic #communication_group_holder input, .w-communication-new-topic select','margin-bottom','0','','','.w-communication-new-topic'),(481705,'furniture-mobile','.w-checkout-billing-address .genders-title','margin-bottom','5','','','.w-checkout-billing-address'),(481706,'furniture-mobile','.b-form .col-full-margin','margin-bottom','10','','','.b-form'),(481707,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','margin-bottom','10','','','.p-account-trade-form'),(481708,'furniture-mobile','.w-tabs .tab-li.tab-cart a','margin-bottom','7','3','','.w-tabs'),(481709,'furniture-mobile','.p-reviews-info .review-info-content','margin-bottom','20','','','.p-reviews-info'),(481710,'furniture-mobile','.p-blog-index .comment-form p','margin-bottom','20','','','.p-blog-index'),(481711,'furniture-mobile','.p-blog-index .autor_name_data','margin-bottom','10','','','.p-blog-index'),(481712,'furniture-mobile','.p-account-trade-form .widget h3','margin-bottom','10','','','.p-account-trade-form'),(481713,'furniture-mobile','.p-account-trade-form .trade-form-area','margin-bottom','20','','','.p-account-trade-form'),(481714,'furniture-mobile','.w-account-address-book .name','margin-bottom','5','','','.w-account-address-book'),(481715,'furniture-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(481716,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(481717,'furniture-mobile','.w-catalog-items-on-page select','margin-bottom','0','','','.w-catalog-items-on-page'),(481718,'furniture-mobile','.b-form .message.error','margin-bottom','10','','','.b-form'),(481719,'furniture-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-bottom','0','','','.b-fancybox'),(481720,'furniture-mobile','.p-quick-order-index .filters','margin-bottom','20','','','.p-quick-order-index'),(481721,'furniture-mobile','.w-promotions .promo-date','margin-bottom','10','','','.w-promotions'),(481722,'furniture-mobile','.w-promotions .promo-item','margin-bottom','30','','','.w-promotions'),(481723,'furniture-mobile','.w-socials > li','margin-bottom','10','','','.w-socials'),(481724,'furniture-mobile','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(481725,'furniture-mobile','.p-blog-index .autor_name_data','margin-bottom','10','','','.p-blog-index'),(481726,'furniture-mobile','.p-blog-index .wp-widget ul','margin-bottom','0','','','.p-blog-index'),(481727,'furniture-mobile','.p-blog-index .comments-area article','margin-bottom','10','','','.p-blog-index'),(481728,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(481729,'furniture-mobile','.w-account .acc-returning','margin-bottom','0','','','.w-account'),(481730,'furniture-mobile','.w-account .account-dropdown','margin-bottom','0','','','.w-account'),(481731,'furniture-mobile','.w-account .account-top','margin-bottom','0','','','.w-account'),(481732,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-bottom','10','','','.p-reviews-info'),(481733,'furniture-mobile','.p-reviews-info .review-info-text','margin-bottom','20','','','.p-reviews-info'),(481734,'furniture-mobile','.p-reviews-info .review-info-content','margin-bottom','20','','','.p-reviews-info'),(481735,'furniture-mobile','.w-promotions .prom-multi-discount .heading','margin-bottom','10','','','.w-promotions'),(481736,'furniture-mobile','.p-blog-index .wp-widget ul','margin-bottom','0','','','.p-blog-index'),(481737,'furniture-mobile','.p-blog-index .post_body','margin-bottom','30','','','.p-blog-index'),(481738,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-bottom','0','','','.p-blog-index'),(481739,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(481740,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(481741,'furniture-mobile','.testimonials .reviews-list .name','margin-bottom','20','','',''),(481742,'furniture-mobile','.testimonials .heading-3','margin-bottom','10','','',''),(481743,'furniture-mobile','.testimonials .name','margin-bottom','20','','',''),(481744,'furniture-mobile','.b-products-listing .select-attributes','margin-bottom','10','','','.b-products-listing'),(481745,'furniture-mobile','.b-products-listing .select-attributes select','margin-bottom','0','','','.b-products-listing'),(481746,'furniture-mobile','.w-promotions .nextdiscount .promo-for-each','margin-bottom','10','','','.w-promotions'),(481747,'furniture-mobile','.w-promotions .nextdiscount .heading','margin-bottom','20','','','.w-promotions'),(481748,'furniture-mobile','.w-promotions .heading-3','margin-bottom','20','','','.w-promotions'),(481749,'furniture-mobile','.w-promotions .promo-salemaker .item','margin-bottom','2','','','.w-promotions'),(481750,'furniture-mobile','.w-promotions .promo-cart-discount .slave .item','margin-bottom','2','','','.w-promotions'),(481751,'furniture-mobile','.w-promotions .promo-cart-discount .master .item','margin-bottom','12','','','.w-promotions'),(481752,'furniture-mobile','.w-promotions .promo-cart-discount .master .heading','margin-bottom','10','','','.w-promotions'),(481753,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-bottom','20','','','.b-warehouses-popup'),(481754,'furniture-mobile','.b-warehouses-popup .warehouses-popup .heading','margin-bottom','20','','','.b-warehouses-popup'),(481755,'furniture-mobile','.w-info-content p','margin-bottom','10','','','.w-info-content'),(481756,'furniture-mobile','.p-account-trade-form .trade-form-area','margin-bottom','20','','','.p-account-trade-form'),(481757,'furniture-mobile','.w-account .acc-new','margin-bottom','0','','','.w-account'),(481758,'furniture-mobile','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(481759,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(481760,'furniture-mobile','.p-account-trade-form .widget','margin-bottom','20','','','.p-account-trade-form'),(481761,'furniture-mobile','.p-account-trade-form .widget h3','margin-bottom','10','','','.p-account-trade-form'),(481762,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-bottom','10','','','.p-reviews-info'),(481763,'furniture-mobile','.w-menu-style-1 ul','margin-bottom','0','','','.w-menu-style-1'),(481764,'furniture-mobile','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(481765,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-bottom','0','','','.w-menu'),(481766,'furniture-mobile','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(481767,'furniture-mobile','.w-top-categories .categories','margin-bottom','0','2876','','.w-top-categories'),(481768,'furniture-mobile','.b-messages .messages-menu ul','margin-bottom','0','','','.b-messages'),(481769,'furniture-mobile','.b-messages .messMenuButtonTop','margin-bottom','-39','','','.b-messages'),(481770,'furniture-mobile','.b-messages .dataTables_wrapper > .top','margin-bottom','8','','','.b-messages'),(481771,'furniture-mobile','.b-messages .messages-sidebar .heading-2','margin-bottom','20','','','.b-messages'),(481772,'furniture-mobile','.b-messages .messages-menu li','margin-bottom','0','','','.b-messages'),(481773,'furniture-mobile','.b-messages .messages-sidebar .btn-2','margin-bottom','20','','','.b-messages'),(481774,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-bottom','5','','','.b-messages'),(481775,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(481776,'furniture-mobile','.w-sale .left','margin-bottom','30','','','.w-sale'),(481777,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(481778,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(481779,'furniture-mobile','.p-reviews-info .review-info-content','margin-bottom','20','','','.p-reviews-info'),(481780,'furniture-mobile','.p-account-trade-form .wl-td','margin-bottom','10','','','.p-account-trade-form'),(481781,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-bottom','0','','','.p-blog-index'),(481782,'furniture-mobile','.p-blog-index .wp-widget li','margin-bottom','0','','','.p-blog-index'),(481783,'furniture-mobile','.p-blog-index .comments-area article','margin-bottom','10','','','.p-blog-index'),(481784,'furniture-mobile','.p-account-trade-form .widget','margin-bottom','20','','','.p-account-trade-form'),(481785,'furniture-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(481786,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','margin-bottom','10','','','.p-account-trade-form'),(481787,'furniture-mobile','.b-form .middle-form .bootstrap-switch','margin-bottom','15','','','.b-form'),(481788,'furniture-mobile','.w-sitemap-delivery-location > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(481789,'furniture-mobile','.p-payer-order-confirmation .input-wrapper','margin-bottom','10','','','.p-payer-order-confirmation'),(481790,'furniture-mobile','.p-payer-order-confirmation .dob-hide','margin-bottom','-10','','','.p-payer-order-confirmation'),(481791,'furniture-mobile','.p-payer-order-pay .input-wrapper','margin-bottom','10','','','.p-payer-order-pay'),(481792,'furniture-mobile','.p-payer-order-pay .dob-hide','margin-bottom','-10','','','.p-payer-order-pay'),(481793,'furniture-mobile','.p-blog-index .autor_name_data','margin-bottom','10','','','.p-blog-index'),(481794,'furniture-mobile','.p-blog-index .comment-form p','margin-bottom','20','','','.p-blog-index'),(481795,'furniture-mobile','.p-quick-order-index ul.token-input-list','margin-bottom','0','','','.p-quick-order-index'),(481796,'furniture-mobile','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(481797,'furniture-mobile','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(481799,'furniture-mobile','.b-info .info li','margin-bottom','0','','','.b-info'),(481800,'furniture-mobile','.b-info .info ul','margin-bottom','0','','','.b-info'),(481801,'furniture-mobile','.w-checkout-shipping-address .genders-title','margin-bottom','5','','','.w-checkout-shipping-address'),(481802,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(481803,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(481804,'furniture-mobile','.p-account-trade-form .wl-td','margin-bottom','10','','','.p-account-trade-form'),(481805,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','margin-bottom','10','','','.p-account-trade-form'),(481806,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','margin-bottom','10','','','.p-account-trade-form'),(481807,'furniture-mobile','.p-account-trade-form .trade-form-area','margin-bottom','20','','','.p-account-trade-form'),(481808,'furniture-mobile','.p-account-trade-form .widget','margin-bottom','20','','','.p-account-trade-form'),(481809,'furniture-mobile','.p-account-trade-form .widget h3','margin-bottom','10','','','.p-account-trade-form'),(481810,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-bottom','8','','','.p-account-subscription-historyinfo'),(481811,'furniture-mobile','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(481812,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(481813,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','margin-bottom','20','','','.w-upload-customer-id-upload-customer-id-form'),(481814,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(481817,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(481818,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(481819,'furniture-mobile','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(481820,'furniture-mobile','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(481821,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(481822,'furniture-mobile','.w-filters .filter-box-head','margin-bottom','15','','','.w-filters'),(481823,'furniture-mobile','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(481825,'furniture-mobile','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(481826,'furniture-mobile','.w-menu-horizontal li','margin-bottom','0','','','.w-menu-horizontal'),(481827,'furniture-mobile','.w-menu-horizontal ul','margin-bottom','0','','','.w-menu-horizontal'),(481828,'furniture-mobile','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(481829,'furniture-mobile','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(481830,'furniture-mobile','.p-account-trade-form .trade-form-area','margin-bottom','20','','','.p-account-trade-form'),(481831,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-bottom','8','','','.p-account-subscription-historyinfo'),(481832,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(481833,'furniture-mobile','.b-delete-account .delete-box > div','margin-bottom','10','','','.b-delete-account'),(481834,'furniture-mobile','.w-info-content p','margin-bottom','10','','','.w-info-content'),(481835,'furniture-mobile','.w-filters .input-checkbox','margin-bottom','0','','','.w-filters'),(481836,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(481837,'furniture-mobile','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(481838,'furniture-mobile','.b-form .newsletter-row','margin-bottom','10','','','.b-form'),(481839,'furniture-mobile','.w-sale .name','margin-bottom','20','','','.w-sale'),(481840,'furniture-mobile','.p-blog-index .autor_name_data','margin-bottom','10','','','.p-blog-index'),(481841,'furniture-mobile','.w-cart-give-away .ga_attributes > div','margin-bottom','1','','','.w-cart-give-away'),(481842,'furniture-mobile','.w-cart-checkout-btn + .w-image','margin-bottom','0','','','.w-cart-checkout-btn'),(481843,'furniture-mobile','.p-account-trade-form .widget','margin-bottom','20','','','.p-account-trade-form'),(481844,'furniture-mobile','.b-info .info li','margin-bottom','0','','','.b-info'),(481845,'furniture-mobile','.p-account-trade-form .trade-form-area','margin-bottom','20','','','.p-account-trade-form'),(481846,'furniture-mobile','.heading-6, h6, .h-block h6','margin-bottom','5','','',''),(481847,'furniture-mobile','.p-blog-index .comments-area article','margin-bottom','10','','','.p-blog-index'),(481848,'furniture-mobile','.p-reviews-info .review-info-text','margin-bottom','20','','','.p-reviews-info'),(481849,'furniture-mobile','.pop-up-content .buttons .left-buttons','margin-bottom','15','2885','',''),(481850,'furniture-mobile','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(481851,'furniture-mobile','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(481852,'furniture-mobile','.w-communication-post .text-container','margin-bottom','20','','','.w-communication-post'),(481853,'furniture-mobile','.w-sale .ends','margin-bottom','20','','','.w-sale'),(481854,'furniture-mobile','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(481855,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(481856,'furniture-mobile','.w-menu-style-1 ul','margin-bottom','0','','','.w-menu-style-1'),(481857,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(481858,'furniture-mobile','.p-blog-index .post-thumbnail','margin-bottom','20','','','.p-blog-index'),(481859,'furniture-mobile','.p-blog-index .nav-next a','margin-bottom','0','3','','.p-blog-index'),(481860,'furniture-mobile','.p-blog-index .wp-widget ul','margin-bottom','0','','','.p-blog-index'),(481861,'furniture-mobile','.p-reviews-info .review-info-image','margin-bottom','0','','','.p-reviews-info'),(481862,'furniture-mobile','.p-reviews-info .review-info-text','margin-bottom','20','','','.p-reviews-info'),(481863,'furniture-mobile','.p-reviews-info .review-info-content','margin-bottom','20','','','.p-reviews-info'),(481864,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','margin-bottom','0','','','.p-reviews-info'),(481865,'furniture-mobile','.p-account-trade-form .wl-td','margin-bottom','10','','','.p-account-trade-form'),(481866,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-bottom','0','','','.p-blog-index'),(481867,'furniture-mobile','.p-blog-index .post_body','margin-bottom','30','','','.p-blog-index'),(481868,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(481869,'furniture-mobile','.b-info .info ul','margin-bottom','0','','','.b-info'),(481872,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(481873,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-bottom','0','','','.b-select-suggest'),(481874,'furniture-mobile','.b-form .password-forgotten-link','margin-bottom','0','','','.b-form'),(481875,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(481876,'furniture-mobile','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(481877,'furniture-mobile','.w-socials > li','margin-bottom','10','','','.w-socials'),(481878,'furniture-mobile','.w-search .search-input','margin-bottom','0','','','.w-search'),(481879,'furniture-mobile','.b-delete-account .delete-box span','margin-bottom','0','','','.b-delete-account'),(481880,'furniture-mobile','.w-socials > li','margin-bottom','10','','','.w-socials'),(481881,'furniture-mobile','.p-blog-index .comments-area article','margin-bottom','10','','','.p-blog-index'),(481882,'furniture-mobile','.p-blog-index .wp-widget ul','margin-bottom','0','','','.p-blog-index'),(481883,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(481884,'furniture-mobile','.w-image-maps .default-links .item .title','margin-bottom','10','','','.w-image-maps'),(481885,'furniture-mobile','.p-blog-index .nav-previous','margin-bottom','20','2906','','.p-blog-index'),(481886,'furniture-mobile','.w-reviews .heading-3','margin-bottom','10','','','.w-reviews'),(481887,'furniture-mobile','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(481888,'furniture-mobile','.w-socials > li','margin-bottom','10','','','.w-socials'),(481889,'furniture-mobile','.p-blog-index .comment-form p','margin-bottom','20','','','.p-blog-index'),(481890,'furniture-mobile','.p-blog-index .comments-area article','margin-bottom','10','','','.p-blog-index'),(481891,'furniture-mobile','.b-info .info li','margin-bottom','0','','','.b-info'),(481892,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item','margin-bottom','10','','','.w-checkout-shipping-address'),(481893,'furniture-mobile','.w-checkout-billing-address .same-address','margin-bottom','10','','','.w-checkout-billing-address'),(481894,'furniture-mobile','.b-form .required-message-wrap','margin-bottom','0','','','.b-form'),(481895,'furniture-mobile','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(481896,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-bottom','0','','','.w-menu-slider'),(481897,'furniture-mobile','.w-menu-style-1 li','margin-bottom','0','','','.w-menu-style-1'),(481898,'furniture-mobile','.w-tabs .tab-li.tab-wishlist a','margin-bottom','7','3','','.w-tabs'),(481899,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(481900,'furniture-mobile','.w-tabs > .block','margin-bottom','20','','','.w-tabs'),(481901,'furniture-mobile','.w-cart-cart-tabs .w-tabs .tab-navigation','margin-bottom','25','','','.w-cart-cart-tabs'),(481902,'furniture-mobile','.w-tabs .tab-li','margin-bottom','0','','','.w-tabs'),(481903,'furniture-mobile','.w-socials > li','margin-bottom','10','','','.w-socials'),(481904,'furniture-mobile','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(481905,'furniture-mobile','.w-account-address-book .item','margin-bottom','20','','','.w-account-address-book'),(481906,'furniture-mobile','.p-account-trade-form .widget','margin-bottom','20','','','.p-account-trade-form'),(481907,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(481908,'furniture-mobile','.w-tabs .tab-li.tab-sample a','margin-bottom','7','3','','.w-tabs'),(481909,'furniture-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(481910,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(481911,'furniture-mobile','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(481912,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(481913,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(481914,'furniture-mobile','.w-sale .ends','margin-bottom','20','','','.w-sale'),(481915,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(481916,'furniture-mobile','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(481917,'furniture-mobile','.p-reviews-info .review-info-text','margin-bottom','20','','','.p-reviews-info'),(481918,'furniture-mobile','.p-blog-index .wp-widget li','margin-bottom','0','','','.p-blog-index'),(481919,'furniture-mobile','.p-blog-index .wp-widget','margin-bottom','20','','','.p-blog-index'),(481920,'furniture-mobile','.p-blog-index .post_body','margin-bottom','30','','','.p-blog-index'),(481921,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-bottom','0','','','.w-menu-slider'),(481922,'furniture-mobile','.heading-5, h5, .h-block h5','margin-bottom','5','','',''),(481923,'furniture-mobile','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(481924,'furniture-mobile','.w-filters .filter-ul-content','margin-bottom','0','','','.w-filters'),(481925,'furniture-mobile','.heading-4, h4, .h-block h4','margin-bottom','5','','',''),(481926,'furniture-mobile','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(481927,'furniture-mobile','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(481928,'furniture-mobile','.b-info .info ul','margin-bottom','0','','','.b-info'),(481929,'furniture-mobile','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','margin-bottom','10','','','.b-form'),(481930,'furniture-mobile','.order-summary .price-box','margin-bottom','20','','','.order-summary'),(481931,'furniture-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-bottom','0','','','.b-form'),(481932,'furniture-mobile','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(481933,'furniture-mobile','.w-sale .name','margin-bottom','20','','','.w-sale'),(481934,'furniture-mobile','.w-image-maps .categories-items .item .title','margin-bottom','10','','','.w-image-maps'),(481935,'furniture-mobile','.b-select-suggest .select2-drop-mask','margin-bottom','0','','','.b-select-suggest'),(481936,'furniture-mobile','.w-sale .left','margin-bottom','30','','','.w-sale'),(481937,'furniture-mobile','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(481938,'furniture-mobile','.w-top-categories .categories','margin-bottom','0','2890','','.w-top-categories'),(481939,'furniture-mobile','.p-account-trade-form .wl-td','margin-bottom','10','','','.p-account-trade-form'),(481940,'furniture-mobile','.p-account-trade-form .widget h3','margin-bottom','10','','','.p-account-trade-form'),(481941,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-bottom','0','','','.p-blog-index'),(481942,'furniture-mobile','.products-quick-index ul','margin-bottom','0','','',''),(481943,'furniture-mobile','.w-checkout-gdpr .col-left','margin-bottom','20','2885','','.w-checkout-gdpr'),(481944,'furniture-mobile','.w-top-categories .categories h2','margin-bottom','0','','','.w-top-categories'),(481945,'furniture-mobile','.w-product-reviews .reviews-list .name','margin-bottom','20','','','.w-product-reviews'),(481946,'furniture-mobile','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(481947,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(481948,'furniture-mobile','.w-sale .name','margin-bottom','20','','','.w-sale'),(481949,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-bottom','8','','','.p-account-subscription-historyinfo'),(481950,'furniture-mobile','.p-blog-index .wp-widget li','margin-bottom','0','3','','.p-blog-index'),(481951,'furniture-mobile','.p-blog-index .wp-widget li','margin-bottom','0','','','.p-blog-index'),(481952,'furniture-mobile','.p-blog-index .nav-previous a','margin-bottom','0','3','','.p-blog-index'),(481953,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(481954,'furniture-mobile','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(481955,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(481956,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(481957,'furniture-mobile','.b-form .required-message','margin-bottom','0','','','.b-form'),(481958,'furniture-mobile','.w-socials .post_item_img','margin-bottom','0','','','.w-socials'),(481959,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(481960,'furniture-mobile','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(481961,'furniture-mobile','.w-product-quantity .qty_packs .price_1','margin-bottom','0','4','','.w-product-quantity'),(481962,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','margin-bottom','10','','','.p-account-trade-form'),(481963,'furniture-mobile','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(481964,'furniture-mobile','.w-reviews .reviews-list','margin-bottom','20','','','.w-reviews'),(481965,'furniture-mobile','.b-select-suggest .select2-container','margin-bottom','0','','','.b-select-suggest'),(481966,'furniture-mobile','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(481967,'furniture-mobile','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(481968,'furniture-mobile','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(481969,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-bottom','10','','','.p-reviews-info'),(481970,'furniture-mobile','.w-checkout-create-account .heading-2','margin-bottom','0','','','.w-checkout-create-account'),(481971,'furniture-mobile','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(481972,'furniture-mobile','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(481973,'furniture-mobile','.w-menu-style-1 li','margin-bottom','0','','','.w-menu-style-1'),(481974,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(481975,'furniture-mobile','.w-menu-style-1 ul','margin-bottom','0','','','.w-menu-style-1'),(481976,'furniture-mobile','.w-sale .left','margin-bottom','30','','','.w-sale'),(481977,'furniture-mobile','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(481978,'furniture-mobile','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(481979,'furniture-mobile','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(481980,'furniture-mobile','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(481981,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(481982,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(481983,'furniture-mobile','.b-form .col-full-padding','margin-bottom','10','','','.b-form'),(481984,'furniture-mobile','.b-info .info li','margin-bottom','0','','','.b-info'),(481985,'furniture-mobile','.b-info .info ul','margin-bottom','0','','','.b-info'),(481986,'furniture-mobile','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','margin-bottom','15','','','.b-form'),(481987,'furniture-mobile','.heading-3, h3, .h-block h3','margin-bottom','10','','',''),(481988,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(481989,'furniture-mobile','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(481990,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(481991,'furniture-mobile','.w-menu .hided.menu ul li','margin-bottom','0','','','.w-menu'),(481992,'furniture-mobile','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(481993,'furniture-mobile','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(481994,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(481995,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(481996,'furniture-mobile','.p-blog-index .wp-widget li','margin-bottom','0','','','.p-blog-index'),(481997,'furniture-mobile','.p-blog-index .wp-widget','margin-bottom','20','','','.p-blog-index'),(481998,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','margin-bottom','10','','','.p-account-trade-form'),(481999,'furniture-mobile','.b-form .form-inputs label > span','margin-bottom','1','','','.b-form'),(482000,'furniture-mobile','.b-autocomplete .ui-autocomplete','margin-bottom','0','','','.b-autocomplete'),(482001,'furniture-mobile','.b-bottom .cart-options .js-carts','margin-bottom','10','','','.b-bottom'),(482002,'furniture-mobile','.b-bottom .cart-options .option-item','margin-bottom','5','','','.b-bottom'),(482003,'furniture-mobile','.w-sale .ends','margin-bottom','20','','','.w-sale'),(482004,'furniture-mobile','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(482005,'furniture-mobile','.w-sale .ends','margin-bottom','20','','','.w-sale'),(482006,'furniture-mobile','.w-menu-style-1 li','margin-bottom','0','','','.w-menu-style-1'),(482007,'furniture-mobile','.b-bottom .cart-options .cart-item','margin-bottom','5','','','.b-bottom'),(482008,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-bottom','0','','','.w-menu-slider'),(482009,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-bottom','0','','','.w-menu'),(482010,'furniture-mobile','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(482011,'furniture-mobile','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(482012,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','margin-bottom','0','','','.b-select-suggest'),(482013,'furniture-mobile','.w-menu .hided.menu ul li','margin-bottom','0','','','.w-menu'),(482014,'furniture-mobile','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(482015,'furniture-mobile','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(482016,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(482017,'furniture-mobile','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(482018,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(482019,'furniture-mobile','.w-sale .name','margin-bottom','20','','','.w-sale'),(482020,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(482021,'furniture-mobile','.p-blog-index .autor_name_data','margin-bottom','10','','','.p-blog-index'),(482022,'furniture-mobile','.p-blog-index .nav-previous','margin-bottom','20','2906','','.p-blog-index'),(482024,'furniture-mobile','.p-blog-index .post_body','margin-bottom','30','','','.p-blog-index'),(482025,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','margin-bottom','10','','','.p-account-trade-form'),(482026,'furniture-mobile','.b-bottom .pop-up-content .buttons','margin-bottom','0','','','.b-bottom'),(482027,'furniture-mobile','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(482028,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-bottom','0','','','.w-menu-slider'),(482029,'furniture-mobile','.w-menu-big li','margin-bottom','0','','','.w-menu-big'),(482030,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(482031,'furniture-mobile','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(482032,'furniture-mobile','.b-fancybox .fancybox-error','margin-bottom','0','','','.b-fancybox'),(482033,'furniture-mobile','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(482034,'furniture-mobile','.w-cart-compare .product .image','margin-bottom','10','','','.w-cart-compare'),(482035,'furniture-mobile','.w-checkout-billing-address .addresses .address-item','margin-bottom','10','','','.w-checkout-billing-address'),(482036,'furniture-mobile','.b-bottom .confirm-popup .buttons .btn','margin-bottom','0','','','.b-bottom'),(482037,'furniture-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-bottom','0','','','.b-switch'),(482038,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-bottom','8','','','.p-account-subscription-historyinfo'),(482039,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','margin-bottom','10','','','.p-account-trade-form'),(482040,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-bottom','0','','','.p-blog-index'),(482041,'furniture-mobile','.w-reviews-content .reviews-list','margin-bottom','20','','','.w-reviews-content'),(482042,'furniture-mobile','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(482043,'furniture-mobile','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(482044,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(482046,'furniture-mobile','.b-form #shipping-address .radio-buttons','margin-bottom','10','','','.b-form'),(482047,'furniture-mobile','.p-blog-index .nav-previous','margin-bottom','20','2906','','.p-blog-index'),(482048,'furniture-mobile','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(482049,'furniture-mobile','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(482050,'furniture-mobile','.w-tabs .tab-navigation','margin-bottom','0','','','.w-tabs'),(482051,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','margin-bottom','10','','','.p-account-trade-form'),(482052,'furniture-mobile','.b-info .info ul','margin-bottom','0','','','.b-info'),(482053,'furniture-mobile','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(482054,'furniture-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(482055,'furniture-mobile','.w-social-links a','margin-bottom','0','','','.w-social-links'),(482056,'furniture-mobile','.p-blog-index .wp-widget li','margin-bottom','0','','','.p-blog-index'),(482057,'furniture-mobile','.p-reviews-info .review-info-content','margin-bottom','20','','','.p-reviews-info'),(482058,'furniture-mobile','.p-blog-index .autor_name_data','margin-bottom','10','','','.p-blog-index'),(482059,'furniture-mobile','.p-blog-index .comments-area article','margin-bottom','10','','','.p-blog-index'),(482060,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-bottom','1','','','.b-select-suggest'),(482061,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-bottom','0','','','.b-select-suggest'),(482062,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-bottom','0','','','.b-select-suggest'),(482063,'furniture-mobile','.w-info-content p','margin-bottom','10','','','.w-info-content'),(482064,'furniture-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-bottom','0','','','.b-select-suggest'),(482065,'furniture-mobile','.b-select-suggest .select2-search input','margin-bottom','0','','','.b-select-suggest'),(482066,'furniture-mobile','.b-select-suggest .select2-search','margin-bottom','0','','','.b-select-suggest'),(482067,'furniture-mobile','.w-menu-style-1 ul','margin-bottom','0','','','.w-menu-style-1'),(482068,'furniture-mobile','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(482069,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-bottom','0','','','.w-menu'),(482070,'furniture-mobile','.w-menu .hided.menu ul li','margin-bottom','0','','','.w-menu'),(482071,'furniture-mobile','.w-menu .hided.menu ul li','margin-bottom','0','','','.w-menu'),(482072,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-bottom','8','','','.p-account-subscription-historyinfo'),(482073,'furniture-mobile','.p-account-trade-form .trade-form-area','margin-bottom','20','','','.p-account-trade-form'),(482074,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-bottom','0','','','.p-blog-index'),(482075,'furniture-mobile','.p-blog-index .comment-form p','margin-bottom','20','','','.p-blog-index'),(482076,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-bottom','10','','','.p-reviews-info'),(482077,'furniture-mobile','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(482078,'furniture-mobile','.w-menu-style-1 ul','margin-bottom','0','','','.w-menu-style-1'),(482079,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-bottom','0','','','.w-menu-slider'),(482080,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-bottom','0','','','.w-menu'),(482081,'furniture-mobile','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(482082,'furniture-mobile','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(482083,'furniture-mobile','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(482084,'furniture-mobile','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(482085,'furniture-mobile','.order-summary .btn-2, .order-summary .btn-3','margin-bottom','15','','','.order-summary'),(482086,'furniture-mobile','.w-menu .hided.menu ul li','margin-bottom','0','','','.w-menu'),(482087,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(482088,'furniture-mobile','.w-menu-style-1 ul','margin-bottom','0','','','.w-menu-style-1'),(482089,'furniture-mobile','.w-sale .left','margin-bottom','30','','','.w-sale'),(482090,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(482091,'furniture-mobile','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(482092,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(482093,'furniture-mobile','.b-bottom .content-item','margin-bottom','20','','','.b-bottom'),(482094,'furniture-mobile','.b-form .middle-form .checkbox-holder','margin-bottom','15','','','.b-form'),(482095,'furniture-mobile','.w-account-customer-additional-field .field-type-checkbox','margin-bottom','10','','','.w-account-customer-additional-field'),(482096,'furniture-mobile','.w-communication-new-topic .privacy-row','margin-bottom','10','','','.w-communication-new-topic'),(482097,'furniture-mobile','.w-communication-post .communication-post-message','margin-bottom','20','','','.w-communication-post'),(482098,'furniture-mobile','.w-communication-post .communication-post','margin-bottom','5','','','.w-communication-post'),(482099,'furniture-mobile','.b-products-listing .products-listing .name','margin-bottom','5','','','.b-products-listing'),(482100,'furniture-mobile','.b-products-listing .products-listing .model','margin-bottom','5','','','.b-products-listing'),(482101,'furniture-mobile','.b-products-listing .products-listing .description','margin-bottom','5','','','.b-products-listing'),(482102,'furniture-mobile','.b-products-listing .products-listing .bonusPoints','margin-bottom','7','','','.b-products-listing'),(482103,'furniture-mobile','.b-products-listing .products-listing .description ul','margin-bottom','0','','','.b-products-listing'),(482104,'furniture-mobile','.b-products-listing .products-listing .mult-qty-input','margin-bottom','3','','','.b-products-listing'),(482105,'furniture-mobile','.b-products-listing .promos-info','margin-bottom','-30','','','.b-products-listing'),(482106,'furniture-mobile','.b-products-listing .wedding-registry-count','margin-bottom','10','','','.b-products-listing'),(482107,'furniture-mobile','.w-blog-widget-post-title h1','margin-bottom','0','','','.w-blog-widget-post-title'),(482108,'furniture-mobile','.w-blog-widget-post-title ','margin-bottom','20','','','.w-blog-widget-post-title'),(482109,'furniture-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-bottom','0','','','.w-blog-widget-post-share'),(482110,'furniture-mobile','.w-blog-widget-post-listing ','margin-bottom','0','2885','','.w-blog-widget-post-listing'),(482111,'furniture-mobile','.w-blog-widget-post-listing .post_name','margin-bottom','10','','','.w-blog-widget-post-listing'),(482112,'furniture-mobile','.w-blog-widget-post-listing .post_date span + span','margin-bottom','0','3','','.w-blog-widget-post-listing'),(482113,'furniture-mobile','.w-blog-widget-post-listing .post_content','margin-bottom','40','','','.w-blog-widget-post-listing'),(482114,'furniture-mobile','.w-blog-widget-post-linked-products .heading-2','margin-bottom','25','','','.w-blog-widget-post-linked-products'),(482115,'furniture-mobile','.w-blog-widget-post-image ','margin-bottom','20','','','.w-blog-widget-post-image'),(482116,'furniture-mobile','.p-account-trade-form .widget h3','margin-bottom','10','','','.p-account-trade-form'),(482117,'furniture-mobile','.w-sale .ends','margin-bottom','20','','','.w-sale'),(482118,'furniture-mobile','.p-blog-index .wp-widget','margin-bottom','20','','','.p-blog-index'),(482119,'furniture-mobile','.w-info-content p','margin-bottom','10','','','.w-info-content'),(482120,'furniture-mobile','.w-checkout-gdpr .privacy-row','margin-bottom','0','','','.w-checkout-gdpr'),(482121,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(482123,'furniture-mobile','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(482124,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap','margin-bottom','-35','','','.b-fancybox'),(482125,'furniture-mobile','.p-blog-index .nav-previous','margin-bottom','20','2906','','.p-blog-index'),(482126,'furniture-mobile','.p-account-trade-form .widget','margin-bottom','20','','','.p-account-trade-form'),(482127,'furniture-mobile','.w-socials > li','margin-bottom','10','','','.w-socials'),(482128,'furniture-mobile','.w-sale .name','margin-bottom','20','','','.w-sale'),(482129,'furniture-mobile','.w-product-reviews .reviews-list','margin-bottom','10','','','.w-product-reviews'),(482130,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(482131,'furniture-mobile','.w-menu-style-1 li','margin-bottom','0','','','.w-menu-style-1'),(482132,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-bottom','0','','','.w-menu-slider'),(482133,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-bottom','0','','','.w-menu'),(482134,'furniture-mobile','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(482135,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(482136,'furniture-mobile','.w-info-content p','margin-bottom','10','','','.w-info-content'),(482137,'furniture-mobile','.p-blog-index .comment-form p','margin-bottom','20','','','.p-blog-index'),(482138,'furniture-mobile','.p-reviews-info .review-info-text','margin-bottom','20','','','.p-reviews-info'),(482139,'furniture-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(482140,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','margin-bottom','10','','','.p-account-trade-form'),(482141,'furniture-mobile','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(482142,'furniture-mobile','.w-taxable label','margin-bottom','0','','','.w-taxable'),(482143,'furniture-mobile','.w-taxable select','margin-bottom','0','','','.w-taxable'),(482144,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-bottom','0','','',''),(482145,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-bottom','0','','','.b-h-inline'),(482146,'furniture-mobile','h1, .heading-1','margin-bottom','18','','',''),(482147,'furniture-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(482148,'furniture-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(482149,'furniture-mobile','.blogsidebar .heading-title','margin-bottom','12','','','.blogsidebar'),(482150,'furniture-mobile','.w-communication-new-topic #rmaProductReturnButtonFilterHolder','margin-bottom','30','','','.w-communication-new-topic'),(482151,'furniture-mobile','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(482152,'furniture-mobile','.w-checkout-shipping-address #shippingchoice-choice','margin-bottom','10','','','.w-checkout-shipping-address'),(482153,'furniture-mobile','.b-info .info li','margin-bottom','0','','','.b-info'),(482154,'furniture-mobile','.p-blog-index .nav-previous','margin-bottom','20','2906','','.p-blog-index'),(482155,'furniture-mobile','.w-product-reviews .write-review-button','margin-bottom','20','','','.w-product-reviews'),(482156,'furniture-mobile','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(482157,'furniture-mobile','.p-blog-index .wp-widget ul','margin-bottom','0','','','.p-blog-index'),(482158,'furniture-mobile','.w-tabs .tab-li.tab-quote a','margin-bottom','7','3','','.w-tabs'),(482159,'furniture-mobile','.b-form .checkbox-style','margin-bottom','0','','','.b-form'),(482160,'furniture-mobile','.b-info .info ul','margin-bottom','0','','','.b-info'),(482161,'furniture-mobile','.products-quick-index .token-input-list','margin-bottom','0','','',''),(482162,'furniture-mobile','.products-quick-index ul.token-input-list','margin-bottom','0','','',''),(482163,'furniture-mobile','.w-sale .ends','margin-bottom','20','','','.w-sale'),(482164,'furniture-mobile','.w-sale .left','margin-bottom','30','','','.w-sale'),(482165,'furniture-mobile','.w-sale .name','margin-bottom','20','','','.w-sale'),(482166,'furniture-mobile','.w-cart-checkout-btn .or-text','margin-bottom','5','','','.w-cart-checkout-btn'),(482167,'furniture-mobile','.b-compare .col-two','margin-bottom','15','','','.b-compare'),(482168,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(482170,'furniture-mobile','.w-cart-listing .item','margin-bottom','10','2885','','.w-cart-listing'),(482171,'furniture-mobile','.w-cart-give-away .ga_wrapper','margin-bottom','25','','','.w-cart-give-away'),(482172,'furniture-mobile','.w-cart .multicart .name','margin-bottom','0','','','.w-cart'),(482173,'furniture-mobile','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(482174,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(482175,'furniture-mobile','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(482176,'furniture-mobile','.w-image-maps .float-items .item .title','margin-bottom','10','','','.w-image-maps'),(482177,'furniture-mobile','.w-info-content p','margin-bottom','10','','','.w-info-content'),(482178,'furniture-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-bottom','0','','','.b-fancybox'),(482179,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(482180,'furniture-mobile','.w-sale .left','margin-bottom','30','','','.w-sale'),(482181,'furniture-mobile','.w-filters .ui-slider','margin-bottom','0','','','.w-filters'),(482182,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(482183,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(482184,'furniture-mobile','.w-wedding-registry-widgets-products .select-box, .w-wedding-registry-widgets-products .name','margin-bottom','10','','','.w-wedding-registry-widgets-products'),(482185,'furniture-mobile','.p-reviews-info .review-info-content','margin-bottom','20','','','.p-reviews-info'),(482186,'furniture-mobile','.p-blog-index .wp-widget','margin-bottom','20','','','.p-blog-index'),(482187,'furniture-mobile','.p-account-trade-form .wl-td','margin-bottom','10','','','.p-account-trade-form'),(482188,'furniture-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(482189,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','margin-bottom','10','','','.p-account-trade-form'),(482190,'furniture-mobile','.p-account-trade-form .widget h3','margin-bottom','10','','','.p-account-trade-form'),(482191,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-bottom','8','','','.p-account-subscription-historyinfo'),(482192,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(482193,'furniture-mobile','.p-account-trade-form .wl-td','margin-bottom','10','','','.p-account-trade-form'),(482194,'furniture-mobile','.p-blog-index .post_body','margin-bottom','30','','','.p-blog-index'),(482195,'furniture-mobile','.p-blog-index .wp-widget ul','margin-bottom','0','','','.p-blog-index'),(482196,'furniture-mobile','.w-menu-style-1 li','margin-bottom','0','','','.w-menu-style-1'),(482197,'furniture-mobile','.p-blog-index .comment-form p','margin-bottom','20','','','.p-blog-index'),(482198,'furniture-mobile','.p-reviews-info .review-info-text','margin-bottom','20','','','.p-reviews-info'),(482199,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-bottom','10','','','.p-reviews-info'),(482200,'furniture-mobile','.w-catalog-sorting select','margin-bottom','0','','','.w-catalog-sorting'),(482201,'furniture-mobile','.p-blog-index .post_body','margin-bottom','30','','','.p-blog-index'),(482202,'furniture-mobile','.p-blog-index .nav-previous','margin-bottom','20','2906','','.p-blog-index'),(482203,'furniture-mobile','.b-info .info li','margin-bottom','0','','','.b-info'),(482204,'furniture-mobile','.b-form .radio-buttons','margin-bottom','10','','','.b-form'),(482205,'furniture-mobile','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(482207,'furniture-mobile','.p-blog-index .wp-widget','margin-bottom','20','','','.p-blog-index'),(482208,'furniture-mobile','.heading-2, h2, .h-block h2','margin-bottom','10','','',''),(482209,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(482210,'furniture-mobile','.w-menu-style-1 li','margin-bottom','0','','','.w-menu-style-1'),(482211,'furniture-mobile','.b-upload-files .upload-files','margin-bottom','20','','','.b-upload-files'),(482212,'furniture-mobile','.w-communication-new-topic .text-container','margin-bottom','20','','','.w-communication-new-topic'),(482213,'furniture-mobile','.p-blog-index .wp-widget','margin-bottom','20','','','.p-blog-index'),(482214,'furniture-mobile','.p-blog-index .wp-widget li','margin-bottom','0','','','.p-blog-index'),(482215,'furniture-mobile','.b-form .addresses','margin-bottom','20','','','.b-form'),(482216,'furniture-mobile','.w-menu .hided.menu ul li','margin-bottom','0','','','.w-menu'),(482217,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-bottom','0','','','.w-menu'),(482218,'furniture-mobile','.w-menu-big ul','margin-bottom','0','','','.w-menu-big'),(482219,'furniture-mobile','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(482220,'furniture-mobile','.p-account-update .privacy-row','margin-bottom','20','','','.p-account-update'),(482221,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','margin-bottom','10','','','.p-account-trade-form'),(482222,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-bottom','10','','','.p-reviews-info'),(482223,'furniture-mobile','.b-product-images .media-popup .slick-dots','margin-bottom','0','','','.b-product-images'),(482224,'furniture-mobile','.b-product-images .media-popup .slick-dots li','margin-bottom','0','','','.b-product-images'),(482225,'furniture-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-bottom','0','','','.b-menu-style'),(482226,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages','margin-bottom','10','','','.b-menu-style-2'),(482227,'furniture-mobile','.b-personal-catalog-popup #personal_catalog_popup .lists-message-box','margin-bottom','20','','','.b-personal-catalog-popup'),(482228,'furniture-mobile','.b-trade-approval .steps-bar','margin-bottom','25','','','.b-trade-approval'),(482229,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','margin-bottom','15','','','.b-trade-approval'),(482230,'furniture-mobile','.b-trade-approval .middle-form textarea','margin-bottom','15','','','.b-trade-approval'),(482231,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing','margin-bottom','0','','','.batchPr'),(482232,'furniture-mobile','.w-account-personal-catalog .list-switcher','margin-bottom','20','','','.w-account-personal-catalog'),(482233,'furniture-mobile','.w-account-subscription .send-email','margin-bottom','20','','','.w-account-subscription'),(482234,'furniture-mobile','.w-account-subscription .subscription-list','margin-bottom','20','','','.w-account-subscription'),(482235,'furniture-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-bottom','0','','','.w-catalog-additional-images'),(482236,'furniture-mobile','.w-catalog-compare .cross-box .return','margin-bottom','30','','','.w-catalog-compare'),(482237,'furniture-mobile','.w-delivery-day .time-left','margin-bottom','30','','','.w-delivery-day'),(482238,'furniture-mobile','.w-delivery-day .ends','margin-bottom','20','','','.w-delivery-day'),(482239,'furniture-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-bottom','0','','','.b-cookie-notice'),(482240,'furniture-mobile','.tripleBanner ','margin-bottom','0','','','.tripleBanner'),(482241,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .price','margin-bottom','0','','','.b-products-listing'),(482242,'furniture-mobile','.preFooter .w-banner .single_banner','margin-bottom','0','','','.preFooter'),(482243,'furniture-mobile','.b-slick .slick-list','margin-bottom','0','','','.b-slick'),(482244,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li','margin-bottom','5','','','.b-menu-style-3'),(482245,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','margin-bottom','4','3','','.b-products-listing'),(482246,'furniture-mobile','.b-products-listing .add-to-personal-catalog','margin-bottom','4','3','','.b-products-listing'),(482247,'furniture-mobile','.LeftCategories .w-menu-simple ul','margin-bottom','0','','','.LeftCategories'),(482248,'furniture-mobile','.w-breadcrumb .breadcrumb-li','margin-bottom','0','','','.w-breadcrumb'),(482249,'furniture-mobile','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(482250,'furniture-mobile','.w-quote .multicart .name','margin-bottom','0','','','.w-quote'),(482251,'furniture-mobile','.b-products-listing .rating, .b-products-listing .ratingCounts','margin-bottom','5','','','.b-products-listing'),(482252,'furniture-mobile','.w-product-name h1','margin-bottom','5','','','.w-product-name'),(482253,'furniture-mobile','.w-product-sale-ends .ends','margin-bottom','20','','','.w-product-sale-ends'),(482254,'furniture-mobile','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(482255,'furniture-mobile','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(482256,'furniture-mobile','.w-compare .clear-compare-button','margin-bottom','15','','','.w-compare'),(482257,'furniture-mobile','.w-files-catalog-widgets-files-catalog ','margin-bottom','50','','','.w-files-catalog-widgets-files-catalog'),(482258,'furniture-mobile','.w-files-catalog-widgets-files-list .files','margin-bottom','50','','','.w-files-catalog-widgets-files-list'),(482259,'furniture-mobile','.w-files-catalog-widgets-files-list .name','margin-bottom','10','','','.w-files-catalog-widgets-files-list'),(482260,'furniture-mobile','.w-sample .multicart .name','margin-bottom','0','','','.w-sample'),(482261,'furniture-mobile','.w-filters-simple select','margin-bottom','0','','','.w-filters-simple'),(482262,'furniture-mobile','.w-cart-discount-coupon .title','margin-bottom','10','','','.w-cart-discount-coupon'),(482263,'furniture-mobile','.w-cart-sub-total ','margin-bottom','20','','','.w-cart-sub-total'),(482264,'furniture-mobile','.shipping-ico .heading-3','margin-bottom','10','','','.shipping-ico'),(482265,'furniture-mobile','.order-summary .heading-2','margin-bottom','0','','','.order-summary'),(482266,'furniture-mobile','.w-cart-gift-certificate .heading-4','margin-bottom','0','','','.w-cart-gift-certificate'),(482267,'furniture-mobile','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(482268,'furniture-mobile','.w-product-bundle .bundle-total-price','margin-bottom','20','','','.w-product-bundle'),(482269,'furniture-mobile','.w-product-in-bundles .bundle-total-price','margin-bottom','20','','','.w-product-in-bundles'),(482270,'furniture-mobile','.b-bottom .cart-options .buttons','margin-bottom','0','','','.b-bottom'),(482271,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-bottom','0','','','.b-products-listing'),(482272,'furniture-mobile','.b-pagination .pagination','margin-bottom','20','','','.b-pagination'),(482273,'furniture-mobile','.b-pagination ul.pagination','margin-bottom','0','','','.b-pagination'),(482274,'furniture-mobile','.w-catalog-compare .list-compareproduct .stock','margin-bottom','0','','','.w-catalog-compare'),(482275,'furniture-mobile','.w-product-quantity-discounts .item','margin-bottom','0','2885','','.w-product-quantity-discounts'),(482276,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .item','margin-bottom','5','','','.w-product-properties-filters-widgets-chosen-filters'),(482277,'furniture-mobile','.w-product-multi-inventory .radio-attributes > span','margin-bottom','5','','','.w-product-multi-inventory'),(482278,'furniture-mobile','.w-product-multi-inventory .radio-attributes','margin-bottom','15','','','.w-product-multi-inventory'),(482279,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','margin-bottom','-1','','','.w-account-personal-catalog'),(482280,'furniture-mobile','.w-account-personal-catalog .list-row-action li','margin-bottom','0','','','.w-account-personal-catalog'),(482281,'furniture-mobile','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','margin-bottom','10','','','.w-account-personal-catalog'),(482282,'furniture-mobile','.b-products-listing .products-listing .radio-attributes','margin-bottom','15','','','.b-products-listing'),(482283,'furniture-mobile','.b-products-listing .products-listing .radio-attributes > span','margin-bottom','5','','','.b-products-listing'),(482284,'furniture-mobile','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(482285,'furniture-mobile','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(482286,'furniture-mobile','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(482287,'furniture-mobile','.w-account-customer-additional-field .field-type-text, .w-account-customer-additional-field .field-type-file','margin-bottom','10','','','.w-account-customer-additional-field'),(482288,'furniture-mobile','.w-product-attributes .radio-attributes','margin-bottom','15','','','.w-product-attributes'),(482289,'furniture-mobile','.w-product-attributes .radio-attributes > span','margin-bottom','5','','','.w-product-attributes'),(482290,'furniture-mobile','.w-product-properties .property-ul','margin-bottom','0','','','.w-product-properties'),(482291,'furniture-mobile','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(482292,'furniture-mobile','.w-questionnaire-widgets-questionnaire .question','margin-bottom','20','','','.w-questionnaire-widgets-questionnaire'),(482293,'furniture-mobile','.w-questionnaire-widgets-questionnaire .description','margin-bottom','10','','','.w-questionnaire-widgets-questionnaire'),(482294,'furniture-mobile','.w-product-groups .radioBox label','margin-bottom','15','','','.w-product-groups'),(482295,'furniture-mobile','.w-product-groups .radioBoxHead','margin-bottom','10','','','.w-product-groups'),(482296,'furniture-mobile','.w-delivery-day .title','margin-bottom','10','','','.w-delivery-day'),(482297,'furniture-mobile','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img','margin-bottom','10','','','.w-product-groups'),(482298,'furniture-mobile','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(482299,'furniture-mobile','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(482300,'furniture-mobile','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(482301,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .attribute-qty-block > span','margin-bottom','4','','','.b-products-listing'),(482302,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-bottom','0','','','.w-catalog-pages-category-pages-last-list'),(482303,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(482304,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-bottom','0','','','.w-catalog-pages-category-pages-last-list-block'),(482305,'furniture-mobile','.w-delivery-location-top-location-list .deliveryName','margin-bottom','10','','','.w-delivery-location-top-location-list'),(482306,'furniture-mobile','.w-delivery-location-location-list .deliveryName','margin-bottom','10','','','.w-delivery-location-location-list'),(482307,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(482308,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(482309,'furniture-mobile','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(482310,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','2876','','.w-delivery-location-top-location-list'),(482311,'furniture-mobile','.w-delivery-location-featured-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-featured-list'),(482312,'furniture-mobile','.w-blog-widget-recent-posts > div','margin-bottom','10','','','.w-blog-widget-recent-posts'),(482313,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent a','margin-bottom','5','','','.w-delivery-location-location-list'),(482314,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li','margin-bottom','20','','','.w-delivery-location-featured-list'),(482315,'furniture-mobile','.w-wedding-registry-widgets-search-form .closeable-heading','margin-bottom','20','','','.w-wedding-registry-widgets-search-form'),(482316,'furniture-mobile','.w-sale-category .ends','margin-bottom','20','','','.w-sale-category'),(482317,'furniture-mobile','.w-sale-category .left','margin-bottom','30','','','.w-sale-category'),(482318,'furniture-mobile','.w-sale-category .name','margin-bottom','20','','','.w-sale-category'),(482319,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-img','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(482320,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-name','margin-bottom','10','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(482321,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(482322,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(482323,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-img','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(482324,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-name','margin-bottom','10','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(482325,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(482326,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(482327,'furniture-mobile','.w-delivery-location-list-by-page .description ul','margin-bottom','5','','','.w-delivery-location-list-by-page'),(482328,'furniture-mobile','.w-delivery-location-list-by-page .item','margin-bottom','20','','','.w-delivery-location-list-by-page'),(482329,'furniture-mobile','.w-delivery-location-list-by-page .item','margin-bottom','10','2906','','.w-delivery-location-list-by-page'),(482330,'furniture-mobile','.w-delivery-location-cross-pages .description ul','margin-bottom','5','','','.w-delivery-location-cross-pages'),(482331,'furniture-mobile','.w-delivery-location-cross-pages .item','margin-bottom','20','','','.w-delivery-location-cross-pages'),(482332,'furniture-mobile','.w-delivery-location-cross-pages .item','margin-bottom','10','2906','','.w-delivery-location-cross-pages'),(482333,'furniture-mobile','.w-cart-credit-amount ','margin-bottom','10','','','.w-cart-credit-amount'),(482334,'furniture-mobile','.w-catalog-delivery-locations .item','margin-bottom','20','','','.w-catalog-delivery-locations'),(482335,'furniture-mobile','.w-catalog-delivery-locations .description ul','margin-bottom','5','','','.w-catalog-delivery-locations'),(482336,'furniture-mobile','.w-catalog-delivery-locations .name','margin-bottom','10','','','.w-catalog-delivery-locations'),(482337,'furniture-mobile','.w-catalog-delivery-locations .item','margin-bottom','20','2876','','.w-catalog-delivery-locations'),(482338,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination','margin-bottom','20','','','.w-wedding-registry-widgets-search-paging'),(482339,'furniture-mobile','.w-wedding-registry-widgets-search-paging ul.pagination','margin-bottom','0','','','.w-wedding-registry-widgets-search-paging'),(482340,'furniture-mobile','.w-product-designer-designer .grnamebox .title-sortable','margin-bottom','10','','','.w-product-designer-designer'),(482341,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','margin-bottom','10','','','.w-product-designer-designer'),(482342,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small ','margin-bottom','12','','','.w-press-reviews-widgets-press-reviews-small'),(482343,'furniture-mobile','.w-press-reviews-widgets-press-reviews ','margin-bottom','30','','','.w-press-reviews-widgets-press-reviews'),(482344,'furniture-mobile','.w-press-reviews-widgets-press-reviews .image','margin-bottom','15','','','.w-press-reviews-widgets-press-reviews'),(482345,'furniture-mobile','.w-press-reviews-widgets-press-reviews .reviews-list','margin-bottom','20','','','.w-press-reviews-widgets-press-reviews'),(482346,'furniture-mobile','.w-press-reviews-widgets-press-reviews .date','margin-bottom','10','2876','','.w-press-reviews-widgets-press-reviews'),(482347,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .image','margin-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(482348,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .item','margin-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(482349,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .product-name','margin-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(482350,'furniture-mobile','.b-products-listing .productGroup','margin-bottom','10','','','.b-products-listing'),(482351,'furniture-mobile','.w-gift-wrap-message-checkout .text','margin-bottom','20','','','.w-gift-wrap-message-checkout'),(482352,'furniture-mobile','.w-support-system-filter .filter_cats','margin-bottom','0','','','.w-support-system-filter'),(482353,'furniture-mobile','.w-support-system-listing .topic-products-listing .item','margin-bottom','30','','','.w-support-system-listing'),(482354,'furniture-mobile','.w-communication-post .buttons','margin-bottom','20','','','.w-communication-post'),(482355,'furniture-mobile','.w-rma-returns-history .content-messages .messages-table .top','margin-bottom','10','','','.w-rma-returns-history'),(482356,'furniture-mobile','.w-rma-returns-history .filterMessages','margin-bottom','0','','','.w-rma-returns-history'),(482357,'furniture-mobile','.w-rma-returns-history .column','margin-bottom','10','','screen and (max-width: 768px)','.w-rma-returns-history'),(482358,'furniture-mobile','.w-rma-returns-history .column .title','margin-bottom','5','','screen and (max-width: 768px)','.w-rma-returns-history'),(482359,'furniture-mobile','.w-rma-returns-history .column:last-child .title','margin-bottom','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(482360,'furniture-mobile','.w-product-designer-designer .productDesignerBox ul','margin-bottom','0','','','.w-product-designer-designer'),(482361,'furniture-mobile','.w-product-designer-designer .grnamebox','margin-bottom','10','','','.w-product-designer-designer'),(482362,'furniture-mobile','.w-product-configurator .pc-item','margin-bottom','0','','','.w-product-configurator'),(482363,'furniture-mobile','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(482364,'furniture-mobile','.w-product-configurator .pc_row','margin-bottom','10','','','.w-product-configurator'),(482365,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-bottom','0','','','.w-catalog-pages-category-pages-list'),(482366,'furniture-mobile','.w-predefined-promotion .heading-3','margin-bottom','20','','','.w-predefined-promotion'),(482367,'furniture-mobile','.w-predefined-promotion .nextdiscount .heading','margin-bottom','20','','','.w-predefined-promotion'),(482368,'furniture-mobile','.w-predefined-promotion .nextdiscount .promo-for-each','margin-bottom','10','','','.w-predefined-promotion'),(482369,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .heading','margin-bottom','10','','','.w-predefined-promotion'),(482370,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .heading','margin-bottom','10','','','.w-predefined-promotion'),(482371,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .item','margin-bottom','12','','','.w-predefined-promotion'),(482372,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .item','margin-bottom','2','','','.w-predefined-promotion'),(482373,'furniture-mobile','.w-predefined-promotion .promo-date','margin-bottom','10','','','.w-predefined-promotion'),(482374,'furniture-mobile','.w-predefined-promotion .promo-item','margin-bottom','30','','','.w-predefined-promotion'),(482375,'furniture-mobile','.w-predefined-promotion .promo-salemaker .item','margin-bottom','2','','','.w-predefined-promotion'),(482376,'furniture-mobile','.w-supplier-purchase-supplier-products .item','margin-bottom','10','','','.w-supplier-purchase-supplier-products'),(482377,'furniture-mobile','.w-filters .filter-box-content ul li','margin-bottom','10','','','.w-filters'),(482378,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-bottom','0','','','.w-filters'),(482379,'furniture-mobile','.mainBanner .title','margin-bottom','20','','','.mainBanner'),(482380,'furniture-mobile','.mainBanner .title','margin-bottom','15','2885','','.mainBanner'),(482381,'furniture-mobile','.mainBanner .topBox > .left','margin-bottom','5','2876','','.mainBanner'),(482382,'furniture-mobile','.lowestPricedBox .w-banner .banner','margin-bottom','0','','','.lowestPricedBox'),(482383,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner','margin-bottom','0','','','.lowestPricedBox'),(482384,'furniture-mobile','.lowestPricedBox .w-banner .ybg .descr','margin-bottom','15','','','.lowestPricedBox'),(482385,'furniture-mobile','.lowestPricedBox .w-banner .ybg .descr','margin-bottom','10','2890','','.lowestPricedBox'),(482386,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner:nth-child(1)','margin-bottom','20','2876','','.lowestPricedBox'),(482387,'furniture-mobile','.lowestPricedBox .w-banner .ybg .descr','margin-bottom','5','2906','','.lowestPricedBox'),(482388,'furniture-mobile','.shopByCollectionBox .w-banner .banner','margin-bottom','0','','','.shopByCollectionBox'),(482389,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','margin-bottom','0','','','.shopByCollectionBox'),(482390,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','margin-bottom','10','2885','','.shopByCollectionBox'),(482391,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','margin-bottom','10','2906','','.shopByCollectionBox'),(482392,'furniture-mobile','.account-address-book .address_book .row-buttons a','margin-bottom','0','','','.account-address-book'),(482393,'furniture-mobile','.account-address-book .address_book h1','margin-bottom','18','','','.account-address-book'),(482394,'furniture-mobile','.account-address-book .address_book h2','margin-bottom','15','','','.account-address-book'),(482395,'furniture-mobile','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-bottom','15','','','.account-address-book'),(482396,'furniture-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-bottom','10','','','.account-address-book'),(482397,'furniture-mobile','.account-address-book .address_book_row h2 a','margin-bottom','0','','','.account-address-book'),(482398,'furniture-mobile','.account-address-book .buttonBox .info','margin-bottom','0','','','.account-address-book'),(482399,'furniture-mobile','.account-address-book .address_book_row .column','margin-bottom','12','2876','','.account-address-book'),(482400,'furniture-mobile','.account-address-book .address_book_row .column + .column','margin-bottom','12','2876','','.account-address-book'),(482401,'furniture-mobile','.account-address-book .topInfo > div','margin-bottom','12','2876','','.account-address-book'),(482402,'furniture-mobile','.account-address-book .topInfo > div + div','margin-bottom','12','2876','','.account-address-book'),(482403,'furniture-mobile','.account-address-book-process .buttons','margin-bottom','20','','','.account-address-book-process'),(482404,'furniture-mobile','.account-edit-wrap .buttons','margin-bottom','20','','','.account-edit-wrap'),(482405,'furniture-mobile','.account-order-history .buttonBox','margin-bottom','15','','','.account-order-history'),(482406,'furniture-mobile','.account-order-history .order_history_table h2','margin-bottom','8','','','.account-order-history'),(482407,'furniture-mobile','.account-order-history .orders-table .item','margin-bottom','10','2885','','.account-order-history'),(482408,'furniture-mobile','.account-order-history-info .buttons','margin-bottom','20','','','.account-order-history-info'),(482409,'furniture-mobile','.account-order-history-info .history_info','margin-bottom','20','','','.account-order-history-info'),(482410,'furniture-mobile','.account-order-history-info .history_info > div','margin-bottom','12','2885','','.account-order-history-info'),(482411,'furniture-mobile','.account-index .account_info','margin-bottom','0','','','.account-index'),(482412,'furniture-mobile','.account-index .account_page','margin-bottom','20','','','.account-index'),(482413,'furniture-mobile','.account-index .account_page h1','margin-bottom','10','','','.account-index'),(482414,'furniture-mobile','.account-index .topAccount','margin-bottom','30','','','.account-index'),(482415,'furniture-mobile','.account-index .topInfo > div','margin-bottom','10','','','.account-index'),(482416,'furniture-mobile','.account-index .account_info','margin-bottom','20','2885','','.account-index'),(482417,'furniture-mobile','.account-index .orders-table .item','margin-bottom','10','2885','','.account-index'),(482418,'furniture-mobile','.account-order-pay .buttons','margin-bottom','20','','','.account-order-pay'),(482419,'furniture-mobile','.account-order-pay .history_info','margin-bottom','20','','','.account-order-pay'),(482420,'furniture-mobile','.account-order-pay .history_info > div','margin-bottom','12','2885','','.account-order-pay'),(482421,'furniture-mobile','.account-password-wrap .buttonedit','margin-bottom','0','','','.account-password-wrap'),(482422,'furniture-mobile','.account-password-wrap .buttons','margin-bottom','20','','','.account-password-wrap'),(482423,'furniture-mobile','.account-samples .buttonBox','margin-bottom','15','','','.account-samples'),(482424,'furniture-mobile','.account-samples .order_history_table h2','margin-bottom','8','','','.account-samples'),(482425,'furniture-mobile','.account-samples .orders-table .item','margin-bottom','10','2885','','.account-samples'),(482426,'furniture-mobile','.account-sample-info .buttons','margin-bottom','20','','','.account-sample-info'),(482427,'furniture-mobile','.account-sample-info .history_info','margin-bottom','20','','','.account-sample-info'),(482428,'furniture-mobile','.account-sample-info .history_info > div','margin-bottom','12','2885','','.account-sample-info'),(482429,'furniture-mobile','.catalog-product-wrap .pn-direction','margin-bottom','15','','','.catalog-product-wrap'),(482430,'furniture-mobile','.catalog-product-wrap .rating, .catalog-product-wrap .ratingCounts','margin-bottom','0','','','.catalog-product-wrap'),(482431,'furniture-mobile','.shopping-cart-index .closeable-heading .heading-2','margin-bottom','0','','','.shopping-cart-index'),(482432,'furniture-mobile','.checkout-index-wrap .dob-hide','margin-bottom','-10','','','.checkout-index-wrap'),(482433,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .address-item','margin-bottom','20','','','.checkout-index-wrap'),(482434,'furniture-mobile','.checkout-index-wrap .input-wrapper','margin-bottom','10','','','.checkout-index-wrap'),(482435,'furniture-mobile','.b-bottom .cart-options .buttons','margin-bottom_important','important','','','.b-bottom'),(482436,'furniture-mobile','.w-product-quantity-discounts .item','margin-bottom_important','important','2885','','.w-product-quantity-discounts'),(482437,'furniture-mobile','.heading-4 .edit, h4 .edit','margin-left','10','4','',''),(482438,'furniture-mobile','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(482439,'furniture-mobile','.message.success','margin-left','-40','3','',''),(482440,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-left','0','','','.p-account-subscription-historyinfo'),(482441,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(482442,'furniture-mobile','.p-blog-index .wp-widget li','margin-left','0','','','.p-blog-index'),(482443,'furniture-mobile','.w-cart .image','margin-left','-90','','','.w-cart'),(482444,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(482445,'furniture-mobile','.w-catalog-items-on-page select','margin-left','10','','','.w-catalog-items-on-page'),(482446,'furniture-mobile','.w-chat .w-chat-box','margin-left','5','','','.w-chat'),(482447,'furniture-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-left','0','','','.b-fancybox'),(482448,'furniture-mobile','.p-quick-order-index ul.token-input-list','margin-left','5','','','.p-quick-order-index'),(482449,'furniture-mobile','.p-quick-order-index .filters .clear','margin-left','15','','','.p-quick-order-index'),(482450,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','margin-left','5','','','.p-quick-order-index'),(482451,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.p-quick-order-index'),(482452,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-left','0','','','.p-blog-index'),(482453,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(482454,'furniture-mobile','.w-account .acc-returning','margin-left','0','','','.w-account'),(482455,'furniture-mobile','.w-account .account-dropdown','margin-left','0','','','.w-account'),(482456,'furniture-mobile','.w-account .account-top','margin-left','0','','','.w-account'),(482457,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-left','0','','','.p-reviews-info'),(482458,'furniture-mobile','.p-reviews-info .review-info-text','margin-left','0','','','.p-reviews-info'),(482459,'furniture-mobile','.p-reviews-info .review-info-content','margin-left','0','','','.p-reviews-info'),(482460,'furniture-mobile','.p-blog-index .wp-widget ul','margin-left','0','','','.p-blog-index'),(482461,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-left','0','','','.p-blog-index'),(482462,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(482463,'furniture-mobile','.w-catalog-paging .next','margin-left','2','','','.w-catalog-paging'),(482464,'furniture-mobile','.w-promotions .promo-salemaker .item','margin-left','2','','','.w-promotions'),(482465,'furniture-mobile','.w-promotions .promo-cart-discount .slave .item','margin-left','2','','','.w-promotions'),(482466,'furniture-mobile','.w-promotions .promo-cart-discount .master .item','margin-left','12','','','.w-promotions'),(482467,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','-17','3','','.b-warehouses-popup'),(482468,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','0','','','.b-warehouses-popup'),(482469,'furniture-mobile','.p-account-trade-form .trade-form-area .btn','margin-left','30','','','.p-account-trade-form'),(482470,'furniture-mobile','.w-account .acc-new','margin-left','0','','','.w-account'),(482471,'furniture-mobile','.w-sale .left-text-right','margin-left','2','','','.w-sale'),(482472,'furniture-mobile','.b-form .password-forgotten-link','margin-left','0','','','.b-form'),(482473,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(482474,'furniture-mobile','.b-messages .messages-menu ul','margin-left','0','','','.b-messages'),(482475,'furniture-mobile','.b-messages .msv_content','margin-left','0','','','.b-messages'),(482476,'furniture-mobile','.b-messages .msv_history','margin-left','0','','','.b-messages'),(482477,'furniture-mobile','.b-messages .messages-menu li','margin-left','0','','','.b-messages'),(482478,'furniture-mobile','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(482479,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-left','5','','','.b-messages'),(482480,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-left','0','','','.w-sitemap-delivery-location'),(482481,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-left','0','','','.p-reviews-info'),(482482,'furniture-mobile','.w-menu-style-1 ul','margin-left','0','','','.w-menu-style-1'),(482483,'furniture-mobile','.w-sitemap-delivery-location > ul','margin-left','0','','','.w-sitemap-delivery-location'),(482484,'furniture-mobile','.b-fancybox #fancybox-loading','margin-left','-22','','','.b-fancybox'),(482485,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(482486,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-left','0','','','.w-menu'),(482487,'furniture-mobile','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(482488,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(482489,'furniture-mobile','.p-account-trade-form .trade-form-area .btn','margin-left','30','','','.p-account-trade-form'),(482490,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-left','0','','','.p-account-subscription-historyinfo'),(482492,'furniture-mobile','.b-info .info','margin-left','-40','3','','.b-info'),(482493,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(482494,'furniture-mobile','.w-coupons-and-vauchers-checkout .btn-remove','margin-left','-30','','','.w-coupons-and-vauchers-checkout'),(482495,'furniture-mobile','.w-checkout-bonus-points .btn-remove','margin-left','-30','','','.w-checkout-bonus-points'),(482496,'furniture-mobile','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(482497,'furniture-mobile','.w-menu-horizontal li','margin-left','0','','','.w-menu-horizontal'),(482498,'furniture-mobile','.w-filters .input-checkbox','margin-left','0','','','.w-filters'),(482499,'furniture-mobile','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(482500,'furniture-mobile','.b-info .info ul','margin-left','0','','','.b-info'),(482501,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-left','0','','','.w-menu-slider'),(482502,'furniture-mobile','.w-menu-style-1 li','margin-left','0','','','.w-menu-style-1'),(482503,'furniture-mobile','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(482504,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(482505,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-left','0','','','.p-account-subscription-historyinfo'),(482506,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-left','0','','','.p-blog-index'),(482507,'furniture-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','margin-left','7','3','','.order-summary'),(482508,'furniture-mobile','.buttons .right-buttons .btn','margin-left','10','','',''),(482509,'furniture-mobile','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(482510,'furniture-mobile','.w-top-categories .categories','margin-left','0','2876','','.w-top-categories'),(482511,'furniture-mobile','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(482512,'furniture-mobile','.p-blog-index .nav-previous a','margin-left','-50','3','','.p-blog-index'),(482513,'furniture-mobile','.p-blog-index .wp-widget ul','margin-left','0','','','.p-blog-index'),(482514,'furniture-mobile','.p-blog-index .wp-widget li','margin-left','0','','','.p-blog-index'),(482515,'furniture-mobile','.p-reviews-info .review-info-image','margin-left','0','','','.p-reviews-info'),(482516,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','margin-left','0','','','.p-reviews-info'),(482517,'furniture-mobile','.p-reviews-info .review-info-content','margin-left','0','','','.p-reviews-info'),(482518,'furniture-mobile','.p-reviews-info .review-info-text','margin-left','0','','','.p-reviews-info'),(482519,'furniture-mobile','.p-blog-index .wp-widget li','margin-left','0','','','.p-blog-index'),(482520,'furniture-mobile','.w-cart-checkout-btn + .w-image','margin-left','0','','','.w-cart-checkout-btn'),(482521,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(482522,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(482523,'furniture-mobile','.b-form .col-3 + .col-3','margin-left','3','','','.b-form'),(482524,'furniture-mobile','.b-info .info','margin-left','-40','3','','.b-info'),(482525,'furniture-mobile','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(482526,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(482527,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-left','0','','','.b-select-suggest'),(482528,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(482529,'furniture-mobile','.w-socials > li','margin-left','10','','','.w-socials'),(482530,'furniture-mobile','.w-search .search-input','margin-left','0','','','.w-search'),(482531,'furniture-mobile','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(482532,'furniture-mobile','.b-delete-account .delete-box span','margin-left','10','','','.b-delete-account'),(482533,'furniture-mobile','.w-socials > li','margin-left','10','','','.w-socials'),(482534,'furniture-mobile','.p-blog-index .wp-widget ul','margin-left','0','','','.p-blog-index'),(482535,'furniture-mobile','.p-reviews-info .review-info-text','margin-left','0','','','.p-reviews-info'),(482536,'furniture-mobile','.p-reviews-info .review-info-content','margin-left','0','','','.p-reviews-info'),(482538,'furniture-mobile','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(482539,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(482540,'furniture-mobile','.w-catalog-listing-look .list','margin-left','5','','','.w-catalog-listing-look'),(482541,'furniture-mobile','.view-all .btn','margin-left','10','4','',''),(482542,'furniture-mobile','.w-socials > li','margin-left','10','','','.w-socials'),(482543,'furniture-mobile','.b-info .info li','margin-left','0','','','.b-info'),(482545,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-left','0','','','.w-menu-slider'),(482546,'furniture-mobile','.w-menu-style-1 li','margin-left','0','','','.w-menu-style-1'),(482547,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(482548,'furniture-mobile','.w-tabs .tab-navigation','margin-left','0','','','.w-tabs'),(482549,'furniture-mobile','.w-tabs .tab-li','margin-left','0','','','.w-tabs'),(482550,'furniture-mobile','.w-socials > li','margin-left','10','','','.w-socials'),(482551,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-left','0','','','.w-menu-slider'),(482552,'furniture-mobile','.b-info .info','margin-left','-40','3','','.b-info'),(482553,'furniture-mobile','.b-info .info li','margin-left','0','','','.b-info'),(482554,'furniture-mobile','.b-info .info ul','margin-left','0','','','.b-info'),(482555,'furniture-mobile','.w-menu-style-1 ul','margin-left','0','','','.w-menu-style-1'),(482556,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(482557,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(482558,'furniture-mobile','.w-cart-credit-amount .btn-remove','margin-left','-30','','','.w-cart-credit-amount'),(482559,'furniture-mobile','.p-blog-index .wp-widget li','margin-left','0','','','.p-blog-index'),(482560,'furniture-mobile','.heading-3 .right-text, h3 .right-text','margin-left','10','','',''),(482561,'furniture-mobile','.w-product-reviews .reviews-list','margin-left','0','','','.w-product-reviews'),(482562,'furniture-mobile','.b-products-listing .products-listing .bonus-points-price','margin-left','-20','3','','.b-products-listing'),(482563,'furniture-mobile','.w-menu .hided.menu ul li','margin-left','0','','','.w-menu'),(482565,'furniture-mobile','.w-filters .filter-ul-content','margin-left','0','','','.w-filters'),(482566,'furniture-mobile','.heading-3 .edit, h3 .edit','margin-left','10','4','',''),(482567,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-shipping-address'),(482568,'furniture-mobile','.b-info .info ul','margin-left','0','','','.b-info'),(482569,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(482570,'furniture-mobile','.w-cart-bonus-points .btn-remove','margin-left','-30','','','.w-cart-bonus-points'),(482571,'furniture-mobile','.w-menu-style-1 li','margin-left','0','','','.w-menu-style-1'),(482572,'furniture-mobile','.w-sale .left-count','margin-left','2','','','.w-sale'),(482573,'furniture-mobile','.b-select-suggest .select2-drop-mask','margin-left','0','','','.b-select-suggest'),(482574,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','margin-left','-5','','','.w-checkout-shipping-choice'),(482575,'furniture-mobile','.products-quick-index ul','margin-left','0','','',''),(482576,'furniture-mobile','.w-top-categories .categories h2','margin-left','0','','','.w-top-categories'),(482577,'furniture-mobile','.b-form .checkbox-style','margin-left','0','','','.b-form'),(482578,'furniture-mobile','.p-account-trade-form .trade-form-area .btn','margin-left','30','','','.p-account-trade-form'),(482579,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-left','0','','','.p-blog-index'),(482580,'furniture-mobile','.p-blog-index .wp-widget li','margin-left','-15','3','','.p-blog-index'),(482581,'furniture-mobile','.p-blog-index .post-thumbnail','margin-left','0','','','.p-blog-index'),(482582,'furniture-mobile','.p-blog-index .nav-next a','margin-left','0','3','','.p-blog-index'),(482583,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(482584,'furniture-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-left','0','','','.b-form'),(482585,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(482586,'furniture-mobile','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(482587,'furniture-mobile','.b-form .columns .col-2:nth-child(2n)','margin-left','0','2906','','.b-form'),(482588,'furniture-mobile','.w-product-quantity .qty_packs .price_1','margin-left','15','4','','.w-product-quantity'),(482589,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(482590,'furniture-mobile','.p-blog-index .wp-widget ul','margin-left','0','','','.p-blog-index'),(482591,'furniture-mobile','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(482592,'furniture-mobile','.b-select-suggest .select2-container','margin-left','0','','','.b-select-suggest'),(482593,'furniture-mobile','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(482594,'furniture-mobile','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(482595,'furniture-mobile','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(482596,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-left','0','','','.p-reviews-info'),(482597,'furniture-mobile','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(482598,'furniture-mobile','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(482599,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(482600,'furniture-mobile','.w-menu-style-1 ul','margin-left','0','','','.w-menu-style-1'),(482601,'furniture-mobile','.w-menu-style-1 li','margin-left','0','','','.w-menu-style-1'),(482602,'furniture-mobile','.w-sale .left-count','margin-left','2','','','.w-sale'),(482603,'furniture-mobile','.w-sale .left-text-right','margin-left','2','','','.w-sale'),(482604,'furniture-mobile','.b-info .info','margin-left','-40','3','','.b-info'),(482605,'furniture-mobile','.b-info .info ul','margin-left','0','','','.b-info'),(482606,'furniture-mobile','.b-info .info li','margin-left','0','','','.b-info'),(482607,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(482608,'furniture-mobile','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(482609,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-left','0','','','.w-menu'),(482610,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(482611,'furniture-mobile','.w-menu .hided.menu ul li','margin-left','0','','','.w-menu'),(482612,'furniture-mobile','.w-checkout-credit-amount .btn-remove','margin-left','-30','','','.w-checkout-credit-amount'),(482613,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(482614,'furniture-mobile','.p-account-trade-form .trade-form-area .btn','margin-left','30','','','.p-account-trade-form'),(482615,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-left','0','','','.p-account-subscription-historyinfo'),(482616,'furniture-mobile','.w-sale .left-text-right','margin-left','2','','','.w-sale'),(482617,'furniture-mobile','.w-sale .left-count','margin-left','2','','','.w-sale'),(482618,'furniture-mobile','.b-info .info','margin-left','-40','3','','.b-info'),(482619,'furniture-mobile','.b-autocomplete .ui-autocomplete','margin-left','0','','','.b-autocomplete'),(482620,'furniture-mobile','.w-top-categories .categories','margin-left','-10','2890','','.w-top-categories'),(482621,'furniture-mobile','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(482622,'furniture-mobile','.w-menu-style-1 ul','margin-left','0','','','.w-menu-style-1'),(482623,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(482624,'furniture-mobile','.w-menu .hided.menu ul li','margin-left','0','','','.w-menu'),(482625,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','margin-left','0','','','.b-select-suggest'),(482626,'furniture-mobile','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(482627,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(482628,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(482631,'furniture-mobile','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-billing-address'),(482632,'furniture-mobile','.b-bottom .pop-up-content .buttons','margin-left','0','','','.b-bottom'),(482633,'furniture-mobile','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(482634,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-left','0','','','.w-menu'),(482635,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(482636,'furniture-mobile','.b-fancybox .fancybox-error','margin-left','0','','','.b-fancybox'),(482637,'furniture-mobile','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(482638,'furniture-mobile','.w-cart-compare .product .image','margin-left','0','','','.w-cart-compare'),(482639,'furniture-mobile','.b-info .info li','margin-left','0','','','.b-info'),(482640,'furniture-mobile','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(482641,'furniture-mobile','.b-bottom .confirm-popup .buttons .btn','margin-left','20','','','.b-bottom'),(482642,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(482643,'furniture-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-left','0','','','.b-switch'),(482644,'furniture-mobile','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(482645,'furniture-mobile','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(482646,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-left','0','','','.p-reviews-info'),(482647,'furniture-mobile','.w-sale .left-text-right','margin-left','2','','','.w-sale'),(482648,'furniture-mobile','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(482650,'furniture-mobile','.w-cart-give-away .ga_attributes > div','margin-left','1','','','.w-cart-give-away'),(482651,'furniture-mobile','.w-cart-checkout-btn .or-text','margin-left','0','','','.w-cart-checkout-btn'),(482652,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(482653,'furniture-mobile','.w-cart-give-away .ga_column','margin-left','2','','','.w-cart-give-away'),(482654,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(482655,'furniture-mobile','.w-social-links a','margin-left','5','','','.w-social-links'),(482656,'furniture-mobile','.p-blog-index .wp-widget li','margin-left','0','','','.p-blog-index'),(482657,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(482658,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-left','0','','','.p-blog-index'),(482659,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-left','0','','','.b-select-suggest'),(482660,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-left','0','','','.b-select-suggest'),(482661,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-left','0','','','.b-select-suggest'),(482662,'furniture-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-left','0','','','.b-select-suggest'),(482663,'furniture-mobile','.b-select-suggest .select2-search input','margin-left','0','','','.b-select-suggest'),(482664,'furniture-mobile','.b-select-suggest .select2-search','margin-left','0','','','.b-select-suggest'),(482665,'furniture-mobile','.w-menu-style-1 li','margin-left','0','','','.w-menu-style-1'),(482666,'furniture-mobile','.w-socials > li','margin-left','10','','','.w-socials'),(482667,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-left','0','','','.w-menu'),(482668,'furniture-mobile','.w-menu .hided.menu ul li','margin-left','0','','','.w-menu'),(482669,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-left','0','','','.p-blog-index'),(482670,'furniture-mobile','.w-menu-style-1 ul','margin-left','0','','','.w-menu-style-1'),(482671,'furniture-mobile','.w-menu-horizontal ul','margin-left','0','','','.w-menu-horizontal'),(482672,'furniture-mobile','.w-menu .hided.menu ul li','margin-left','0','','','.w-menu'),(482673,'furniture-mobile','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(482674,'furniture-mobile','.p-reviews-info .review-info-content','margin-left','0','','','.p-reviews-info'),(482675,'furniture-mobile','.p-reviews-info .review-info-text','margin-left','0','','','.p-reviews-info'),(482676,'furniture-mobile','.p-blog-index .wp-widget li','margin-left','0','','','.p-blog-index'),(482677,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.b-data-table'),(482678,'furniture-mobile','.w-catalog-b2b-add-button .add-b2b-products','margin-left','50','','','.w-catalog-b2b-add-button'),(482679,'furniture-mobile','.b-products-listing .products-listing .description ul','margin-left','0','','','.b-products-listing'),(482680,'furniture-mobile','.w-blog-widget-related-posts-by-category .products','margin-left','-15','','','.w-blog-widget-related-posts-by-category'),(482681,'furniture-mobile','.w-blog-widget-related-posts .products','margin-left','-15','','','.w-blog-widget-related-posts'),(482682,'furniture-mobile','.w-blog-widget-post-title h1','margin-left','0','','','.w-blog-widget-post-title'),(482683,'furniture-mobile','.w-blog-widget-post-share a.mailto','margin-left','32','','','.w-blog-widget-post-share'),(482684,'furniture-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-left','8','','','.w-blog-widget-post-share'),(482685,'furniture-mobile','.w-blog-widget-post-listing ','margin-left','0','2885','','.w-blog-widget-post-listing'),(482686,'furniture-mobile','.w-blog-widget-post-listing .post_date span + span','margin-left','10','3','','.w-blog-widget-post-listing'),(482687,'furniture-mobile','.p-account-trade-form .trade-form-area .btn','margin-left','30','','','.p-account-trade-form'),(482688,'furniture-mobile','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(482689,'furniture-mobile','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(482690,'furniture-mobile','.w-sale .left-count','margin-left','2','','','.w-sale'),(482691,'furniture-mobile','.p-reviews-info .review-info-text','margin-left','0','','','.p-reviews-info'),(482693,'furniture-mobile','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(482694,'furniture-mobile','.w-checkout-gdpr .privacy-row','margin-left','0','','','.w-checkout-gdpr'),(482695,'furniture-mobile','.w-checkout-gdpr .bootstrap-switch','margin-left','25','','','.w-checkout-gdpr'),(482697,'furniture-mobile','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(482699,'furniture-mobile','.b-info .info','margin-left','-40','3','','.b-info'),(482700,'furniture-mobile','.b-info .info li','margin-left','0','','','.b-info'),(482701,'furniture-mobile','.w-socials > li','margin-left','10','','','.w-socials'),(482702,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(482703,'furniture-mobile','.w-menu-style-1 ul','margin-left','0','','','.w-menu-style-1'),(482704,'furniture-mobile','.p-blog-index .wp-widget ul','margin-left','0','','','.p-blog-index'),(482705,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(482706,'furniture-mobile','.w-taxable label','margin-left','5','','','.w-taxable'),(482707,'furniture-mobile','.w-taxable select','margin-left','5','','','.w-taxable'),(482708,'furniture-mobile','.heading-4 .right-text, h4 .right-text','margin-left','10','','',''),(482709,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-left','0','','',''),(482710,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-left','0','','','.b-h-inline'),(482711,'furniture-mobile','.b-info .info ul','margin-left','0','','','.b-info'),(482712,'furniture-mobile','.b-form .columns .col-2:nth-child(2n)','margin-left','4','','','.b-form'),(482713,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-left','0','','','.p-reviews-info'),(482714,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(482715,'furniture-mobile','.products-quick-index ul.token-input-list','margin-left','0','','',''),(482716,'furniture-mobile','.w-sale .left-count','margin-left','2','','','.w-sale'),(482717,'furniture-mobile','.w-sale .left-text-right','margin-left','2','','','.w-sale'),(482719,'furniture-mobile','.b-form .required-message','margin-left','0','','','.b-form'),(482720,'furniture-mobile','.b-info .info li','margin-left','0','','','.b-info'),(482721,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-left','0','','','.p-account-subscription-historyinfo'),(482722,'furniture-mobile','.w-catalog-listing-look .b2b','margin-left','5','','','.w-catalog-listing-look'),(482723,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(482724,'furniture-mobile','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(482725,'furniture-mobile','.w-cart-listing .points-redeem','margin-left','-25','3','','.w-cart-listing'),(482726,'furniture-mobile','.w-cart-listing .remove-btn','margin-left','0','2885','','.w-cart-listing'),(482727,'furniture-mobile','.w-cart-give-away .ga_column','margin-left','0','2876','','.w-cart-give-away'),(482728,'furniture-mobile','.w-cart-discount-coupon .btn-remove','margin-left','-30','','','.w-cart-discount-coupon'),(482729,'furniture-mobile','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(482730,'furniture-mobile','.w-cart .multicart .name','margin-left','-10','','','.w-cart'),(482731,'furniture-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-left','0','','','.b-fancybox'),(482732,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(482733,'furniture-mobile','.w-sale .left-text-right','margin-left','2','','','.w-sale'),(482734,'furniture-mobile','.w-sale .left-count','margin-left','2','','','.w-sale'),(482735,'furniture-mobile','.w-menu-style-1 li','margin-left','0','','','.w-menu-style-1'),(482736,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(482737,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-left','0','','','.p-reviews-info'),(482738,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-left','0','','','.p-account-subscription-historyinfo'),(482739,'furniture-mobile','.p-account-trade-form .trade-form-area .btn','margin-left','30','','','.p-account-trade-form'),(482740,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(482741,'furniture-mobile','.p-reviews-info .review-info-text','margin-left','0','','','.p-reviews-info'),(482742,'furniture-mobile','.w-socials .post_item_img','margin-left','0','','','.w-socials'),(482743,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(482744,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(482745,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-left','0','','','.w-menu-slider'),(482746,'furniture-mobile','.w-filters .view_more','margin-left','5','4','','.w-filters'),(482748,'furniture-mobile','.products-quick-index .token-input-list','margin-left','0','','',''),(482749,'furniture-mobile','.b-info .info ul','margin-left','0','','','.b-info'),(482750,'furniture-mobile','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(482751,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-left','0','','','.w-menu-slider'),(482752,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-left','0','','','.w-menu-slider'),(482753,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-left','0','','','.w-menu'),(482754,'furniture-mobile','.p-blog-index .wp-widget ul','margin-left','0','','','.p-blog-index'),(482755,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-left','0','','','.w-menu'),(482756,'furniture-mobile','.w-menu-big ul','margin-left','0','','','.w-menu-big'),(482757,'furniture-mobile','.w-menu-big li','margin-left','0','','','.w-menu-big'),(482758,'furniture-mobile','.w-menu .hided.menu ul li','margin-left','0','','','.w-menu'),(482759,'furniture-mobile','.p-reviews-info .review-info-content','margin-left','0','','','.p-reviews-info'),(482760,'furniture-mobile','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(482761,'furniture-mobile','.b-form .required-message-wrap','margin-left','0','','','.b-form'),(482762,'furniture-mobile','.p-reviews-info .review-info-content','margin-left','0','','','.p-reviews-info'),(482763,'furniture-mobile','.b-product-images .media-popup .slick-dots','margin-left','0','','','.b-product-images'),(482764,'furniture-mobile','.b-product-images .media-popup .slick-dots li','margin-left','5','','','.b-product-images'),(482765,'furniture-mobile','.b-product-images .media-popup button.slick-prev:active','margin-left','-3','','','.b-product-images'),(482766,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(482767,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(482768,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(482769,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(482770,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(482771,'furniture-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-left','0','','','.b-menu-style'),(482772,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','margin-left','5','4','','.b-menu-style-1'),(482773,'furniture-mobile','.b-trade-approval .steps-bar','margin-left','0','','','.b-trade-approval'),(482774,'furniture-mobile','.b-trade-approval .col-3 + .col-3','margin-left','3','','','.b-trade-approval'),(482775,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing','margin-left','0','','','.batchPr'),(482776,'furniture-mobile','.w-account-personal-catalog .list-switcher','margin-left','0','','','.w-account-personal-catalog'),(482777,'furniture-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-left','0','','','.w-catalog-additional-images'),(482778,'furniture-mobile','.w-delivery-day .left-count','margin-left','2','','','.w-delivery-day'),(482779,'furniture-mobile','.w-delivery-day .left-text-right','margin-left','2','','','.w-delivery-day'),(482780,'furniture-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-left','0','','','.b-cookie-notice'),(482781,'furniture-mobile','.tripleBanner ','margin-left','-15','','','.tripleBanner'),(482782,'furniture-mobile','.preFooter .w-banner .single_banner','margin-left','2','','','.preFooter'),(482783,'furniture-mobile','.b-slick .slick-list','margin-left','0','','','.b-slick'),(482784,'furniture-mobile','.b-slick .slick-track','margin-left','auto','','','.b-slick'),(482785,'furniture-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-left','-20','','','.b-slick'),(482786,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li','margin-left','-18','3','','.b-menu-style-3'),(482787,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li + li','margin-left','20','2945','','.b-menu-style-3'),(482788,'furniture-mobile','.LeftCategories .w-menu-simple ul','margin-left','0','','','.LeftCategories'),(482789,'furniture-mobile','.w-breadcrumb .breadcrumb-li','margin-left','0','','','.w-breadcrumb'),(482790,'furniture-mobile','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(482791,'furniture-mobile','.w-quote .image','margin-left','-90','','','.w-quote'),(482792,'furniture-mobile','.w-quote .multicart .name','margin-left','-10','','','.w-quote'),(482793,'furniture-mobile','.b-quantity .qty-box input','margin-left','3','','','.b-quantity'),(482794,'furniture-mobile','.w-product-sale-ends .left-count','margin-left','2','','','.w-product-sale-ends'),(482795,'furniture-mobile','.w-product-sale-ends .left-text-right','margin-left','2','','','.w-product-sale-ends'),(482796,'furniture-mobile','h1, .heading-1','margin-left','-100','3','',''),(482797,'furniture-mobile','.w-product-quantity .qty-input input[type=\'text\']','margin-left','5','','','.w-product-quantity'),(482798,'furniture-mobile','.w-compare .image','margin-left','-80','','','.w-compare'),(482799,'furniture-mobile','.w-files-catalog-widgets-files-list .file','margin-left','-20','3','','.w-files-catalog-widgets-files-list'),(482800,'furniture-mobile','.w-files-catalog-widgets-files-list .files','margin-left','10','','','.w-files-catalog-widgets-files-list'),(482801,'furniture-mobile','.w-sample .image','margin-left','-90','','','.w-sample'),(482802,'furniture-mobile','.w-sample .multicart .name','margin-left','-10','','','.w-sample'),(482803,'furniture-mobile','.w-cart-sub-total ','margin-left','0','','','.w-cart-sub-total'),(482804,'furniture-mobile','.shipping-ico .heading-3','margin-left','0','','','.shipping-ico'),(482805,'furniture-mobile','.order-summary .heading-2','margin-left','0','','','.order-summary'),(482806,'furniture-mobile','.w-cart-gift-certificate .heading-4','margin-left','0','','','.w-cart-gift-certificate'),(482807,'furniture-mobile','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(482808,'furniture-mobile','.w-cart-order-reference .input-apple button','margin-left','10','','','.w-cart-order-reference'),(482809,'furniture-mobile','.w-cart-gift-certificate .btn','margin-left','10','','','.w-cart-gift-certificate'),(482810,'furniture-mobile','.b-bottom .cart-options .buttons','margin-left','0','','','.b-bottom'),(482811,'furniture-mobile','.heading-2','margin-left','-100','3','',''),(482812,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-left','0','','','.b-products-listing'),(482813,'furniture-mobile','.b-pagination .pagination .next-pages','margin-left','5','','','.b-pagination'),(482814,'furniture-mobile','.b-pagination .pagination .page-number','margin-left','5','','','.b-pagination'),(482815,'furniture-mobile','.b-pagination .pagination .prev-pages','margin-left','5','','','.b-pagination'),(482816,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','margin-left','5','','','.b-pagination'),(482817,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','margin-left','5','','','.b-pagination'),(482818,'furniture-mobile','.b-pagination .pagination span','margin-left','5','2','','.b-pagination'),(482819,'furniture-mobile','.b-pagination ul.pagination','margin-left','0','','','.b-pagination'),(482820,'furniture-mobile','.w-product-quantity-discounts .item:nth-child(2n)','margin-left','2','','','.w-product-quantity-discounts'),(482821,'furniture-mobile','.w-product-quantity-discounts .item','margin-left','0','2885','','.w-product-quantity-discounts'),(482822,'furniture-mobile','.w-product-multi-inventory .select-box:nth-child(2n)','margin-left','4','','','.w-product-multi-inventory'),(482823,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .item','margin-left','0','','','.w-product-properties-filters-widgets-chosen-filters'),(482824,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .remove','margin-left','5','','','.w-product-properties-filters-widgets-chosen-filters'),(482825,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','margin-left','-100','3','','.p-quote-checkout-index'),(482826,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','margin-left','-100','3','','.p-sample-checkout-index'),(482827,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','margin-left','-1','','','.w-account-personal-catalog'),(482828,'furniture-mobile','.w-account-personal-catalog .list-row-action li','margin-left','0','','','.w-account-personal-catalog'),(482829,'furniture-mobile','.w-account-personal-catalog .buy-box a + a','margin-left','10','2876','','.w-account-personal-catalog'),(482830,'furniture-mobile','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(482831,'furniture-mobile','.w-product-properties .property-ul','margin-left','0','','','.w-product-properties'),(482832,'furniture-mobile','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(482833,'furniture-mobile','.b-products-listing .mix-attributes .mult-qty-input .qty-box > input','margin-left','3','','','.b-products-listing'),(482834,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list'),(482835,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list-block'),(482836,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(482837,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(482838,'furniture-mobile','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(482839,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-left','0','2876','','.w-delivery-location-top-location-list'),(482840,'furniture-mobile','.w-delivery-location-featured-list .deliveryList ul','margin-left','0','','','.w-delivery-location-featured-list'),(482841,'furniture-mobile','.w-wedding-registry-widgets-search-form .col-3:nth-child(3)','margin-left','0','2885','','.w-wedding-registry-widgets-search-form'),(482842,'furniture-mobile','.w-wedding-registry-widgets-search-form .col-3 + .col-3','margin-left','4','2885','','.w-wedding-registry-widgets-search-form'),(482843,'furniture-mobile','.w-wedding-registry-widgets-search-form .col-3 + .col-3','margin-left','0','2906','','.w-wedding-registry-widgets-search-form'),(482844,'furniture-mobile','.w-sale-category .left-count','margin-left','2','','','.w-sale-category'),(482845,'furniture-mobile','.w-sale-category .left-text-right','margin-left','2','','','.w-sale-category'),(482846,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(482847,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(482848,'furniture-mobile','.w-delivery-location-list-by-page .description ul','margin-left','0','','','.w-delivery-location-list-by-page'),(482849,'furniture-mobile','.w-delivery-location-list-by-page .item','margin-left','1','','','.w-delivery-location-list-by-page'),(482850,'furniture-mobile','.w-delivery-location-list-by-page .item','margin-left','0','2906','','.w-delivery-location-list-by-page'),(482851,'furniture-mobile','.w-delivery-location-cross-pages .description ul','margin-left','0','','','.w-delivery-location-cross-pages'),(482852,'furniture-mobile','.w-delivery-location-cross-pages .item','margin-left','1','','','.w-delivery-location-cross-pages'),(482853,'furniture-mobile','.w-delivery-location-cross-pages .item','margin-left','0','2906','','.w-delivery-location-cross-pages'),(482854,'furniture-mobile','.w-catalog-delivery-locations .item','margin-left','1','','','.w-catalog-delivery-locations'),(482855,'furniture-mobile','.w-catalog-delivery-locations .description ul','margin-left','0','','','.w-catalog-delivery-locations'),(482856,'furniture-mobile','.w-catalog-delivery-locations .item','margin-left','0','2876','','.w-catalog-delivery-locations'),(482857,'furniture-mobile','.w-wedding-registry-widgets-search-paging ul.pagination','margin-left','0','','','.w-wedding-registry-widgets-search-paging'),(482858,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','margin-left','5','','','.w-wedding-registry-widgets-search-paging'),(482859,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','margin-left','5','','','.w-wedding-registry-widgets-search-paging'),(482860,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','margin-left','5','','','.w-wedding-registry-widgets-search-paging'),(482861,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','margin-left','5','','','.w-wedding-registry-widgets-search-paging'),(482862,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','margin-left','10','','','.w-product-designer-designer'),(482863,'furniture-mobile','.w-press-reviews-widgets-press-reviews .date','margin-left','0','2876','','.w-press-reviews-widgets-press-reviews'),(482864,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .image','margin-left','0','','','.w-press-reviews-widgets-press-reviews-list'),(482865,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .item','margin-left','0','','','.w-press-reviews-widgets-press-reviews-list'),(482866,'furniture-mobile','.w-support-system-filter .filter_cats','margin-left','0','','','.w-support-system-filter'),(482867,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','margin-left','2','','','.w-rma-returns-history'),(482868,'furniture-mobile','.w-rma-returns-history .filterMessages','margin-left','-3','','','.w-rma-returns-history'),(482869,'furniture-mobile','.w-rma-returns-history .linkButton','margin-left','5','4','','.w-rma-returns-history'),(482870,'furniture-mobile','.w-rma-returns-history .column:last-child .title','margin-left','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(482871,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .goto-button a','margin-left','10','4','','.b-menu-style-1'),(482872,'furniture-mobile','.w-product-designer-designer .productDesignerBox ul','margin-left','0','','','.w-product-designer-designer'),(482873,'furniture-mobile','.w-product-configurator .pc-item','margin-left','0','','','.w-product-configurator'),(482874,'furniture-mobile','.b-products-listing .promos-info .promo-name','margin-left','-30','','','.b-products-listing'),(482875,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-list'),(482876,'furniture-mobile','.w-multi-cart-save-cart button','margin-left','20','','','.w-multi-cart-save-cart'),(482877,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .item','margin-left','12','','','.w-predefined-promotion'),(482878,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .item','margin-left','2','','','.w-predefined-promotion'),(482879,'furniture-mobile','.w-predefined-promotion .promo-salemaker .item','margin-left','2','','','.w-predefined-promotion'),(482880,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-left','0','','','.w-filters'),(482881,'furniture-mobile','.lowestPricedBox .w-banner .banner','margin-left','0','','','.lowestPricedBox'),(482882,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner','margin-left','15','','','.lowestPricedBox'),(482883,'furniture-mobile','.lowestPricedBox .w-banner .ybg .descr','margin-left','-5','','','.lowestPricedBox'),(482884,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner','margin-left','0','2876','','.lowestPricedBox'),(482885,'furniture-mobile','.shopByCollectionBox .w-banner .banner','margin-left','-15','','','.shopByCollectionBox'),(482886,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','margin-left','15','','','.shopByCollectionBox'),(482887,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','margin-left','10','2885','','.shopByCollectionBox'),(482888,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','margin-left','10','2906','','.shopByCollectionBox'),(482889,'furniture-mobile','.account-address-book .address_book .row-buttons a','margin-left','0','','','.account-address-book'),(482890,'furniture-mobile','.account-address-book .address_book h1','margin-left','0','','','.account-address-book'),(482891,'furniture-mobile','.account-address-book .address_book h2','margin-left','0','','','.account-address-book'),(482892,'furniture-mobile','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-left','2','','','.account-address-book'),(482893,'furniture-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-left','0','','','.account-address-book'),(482894,'furniture-mobile','.account-address-book .address_book_row h2 a','margin-left','15','','','.account-address-book'),(482895,'furniture-mobile','.account-address-book .buttonBox .info','margin-left','0','','','.account-address-book'),(482896,'furniture-mobile','.account-address-book .address_book_row .column','margin-left','0','2876','','.account-address-book'),(482897,'furniture-mobile','.account-address-book .address_book_row .column + .column','margin-left','0','2876','','.account-address-book'),(482898,'furniture-mobile','.account-address-book .topInfo > div','margin-left','0','2876','','.account-address-book'),(482899,'furniture-mobile','.account-address-book .topInfo > div + div','margin-left','0','2876','','.account-address-book'),(482900,'furniture-mobile','.account-order-history .buttonBox','margin-left','0','','','.account-order-history'),(482901,'furniture-mobile','.account-order-history .order_history_table h2','margin-left','0','','','.account-order-history'),(482902,'furniture-mobile','.account-order-history-info .buttons','margin-left','0','','','.account-order-history-info'),(482903,'furniture-mobile','.account-order-history-info .history_info','margin-left','0','','','.account-order-history-info'),(482904,'furniture-mobile','.account-order-history-info .history_info > div','margin-left','0','2885','','.account-order-history-info'),(482905,'furniture-mobile','.account-index .account_info','margin-left','0','','','.account-index'),(482906,'furniture-mobile','.account-index .account_info li:nth-child(3n+1)','margin-left','0','','','.account-index'),(482907,'furniture-mobile','.account-index .account_page h1','margin-left','0','','','.account-index'),(482908,'furniture-mobile','.account-index .topAccount','margin-left','0','','','.account-index'),(482909,'furniture-mobile','.account-index .topInfo > div','margin-left','0','','','.account-index'),(482910,'furniture-mobile','.account-index .account_info','margin-left','0','2885','','.account-index'),(482911,'furniture-mobile','.account-order-pay .buttons','margin-left','0','','','.account-order-pay'),(482912,'furniture-mobile','.account-order-pay .history_info','margin-left','0','','','.account-order-pay'),(482913,'furniture-mobile','.account-order-pay .history_info > div','margin-left','0','2885','','.account-order-pay'),(482914,'furniture-mobile','.account-password-wrap .buttonedit','margin-left','0','','','.account-password-wrap'),(482915,'furniture-mobile','.account-samples .buttonBox','margin-left','0','','','.account-samples'),(482916,'furniture-mobile','.account-samples .order_history_table h2','margin-left','0','','','.account-samples'),(482917,'furniture-mobile','.account-sample-info .buttons','margin-left','0','','','.account-sample-info'),(482918,'furniture-mobile','.account-sample-info .history_info','margin-left','0','','','.account-sample-info'),(482919,'furniture-mobile','.account-sample-info .history_info > div','margin-left','0','2885','','.account-sample-info'),(482920,'furniture-mobile','.shopping-cart-index .closeable-heading .heading-2','margin-left','0','','','.shopping-cart-index'),(482921,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','margin-left','-100','3','','.checkout-index-wrap'),(482922,'furniture-mobile','.b-bottom .cart-options .buttons','margin-left_important','important','','','.b-bottom'),(482923,'furniture-mobile','.w-product-quantity-discounts .item','margin-left_important','important','2885','','.w-product-quantity-discounts'),(482924,'furniture-mobile','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(482925,'furniture-mobile','.w-checkout-billing-address .btn-cancel','margin-right','20','','','.w-checkout-billing-address'),(482926,'furniture-mobile','.p-blog-index .author','margin-right','20','','','.p-blog-index'),(482927,'furniture-mobile','.p-reviews-info .review-info-text','margin-right','0','','','.p-reviews-info'),(482928,'furniture-mobile','.w-catalog-items-on-page select','margin-right','10','','','.w-catalog-items-on-page'),(482929,'furniture-mobile','.w-wedding-registry-widgets-photos .upload-file-template','margin-right','20','','','.w-wedding-registry-widgets-photos'),(482930,'furniture-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-right','0','','','.b-fancybox'),(482931,'furniture-mobile','.p-quick-order-index ul.token-input-list','margin-right','30','','','.p-quick-order-index'),(482932,'furniture-mobile','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(482933,'furniture-mobile','.p-blog-index .avatar','margin-right','10','','','.p-blog-index'),(482934,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(482935,'furniture-mobile','.w-account .acc-returning','margin-right','0','','','.w-account'),(482936,'furniture-mobile','.w-account .account-dropdown','margin-right','0','','','.w-account'),(482937,'furniture-mobile','.w-account .account-top','margin-right','0','','','.w-account'),(482938,'furniture-mobile','.w-wedding-registry-widgets-search-registry-button a','margin-right','10','3','','.w-wedding-registry-widgets-search-registry-button'),(482939,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-right','0','','','.p-reviews-info'),(482940,'furniture-mobile','.p-reviews-info .review-info-content','margin-right','0','','','.p-reviews-info'),(482941,'furniture-mobile','.p-reviews-info .review-info-text','margin-right','0','','','.p-reviews-info'),(482942,'furniture-mobile','.p-blog-index .wp-widget li','margin-right','0','','','.p-blog-index'),(482943,'furniture-mobile','.p-blog-index .wp-widget ul','margin-right','0','','','.p-blog-index'),(482944,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-right','0','','','.p-blog-index'),(482945,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(482946,'furniture-mobile','.w-promotions .prom-multi-discount > .heading','margin-right','5','3','','.w-promotions'),(482947,'furniture-mobile','.w-promotions .nextdiscount .heading','margin-right','10','3','','.w-promotions'),(482948,'furniture-mobile','.w-promotions .icon','margin-right','15','','','.w-promotions'),(482949,'furniture-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','margin-right','5','3','','.w-promotions'),(482950,'furniture-mobile','.w-promotions .promo-salemaker .item','margin-right','2','','','.w-promotions'),(482951,'furniture-mobile','.w-promotions .promo-cart-discount .slave .item','margin-right','2','','','.w-promotions'),(482952,'furniture-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','margin-right','5','3','','.w-promotions'),(482953,'furniture-mobile','.w-promotions .promo-cart-discount .master .item','margin-right','12','','','.w-promotions'),(482954,'furniture-mobile','.b-warehouses-popup .warehouses-popup-link','margin-right','5','3','','.b-warehouses-popup'),(482955,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-right','20','','','.b-warehouses-popup'),(482956,'furniture-mobile','.bell-ico .heading-2','margin-right','10','3','','.bell-ico'),(482957,'furniture-mobile','.w-checkout-create-account .account-benefits strong','margin-right','5','3','','.w-checkout-create-account'),(482958,'furniture-mobile','.w-account .acc-new','margin-right','0','','','.w-account'),(482959,'furniture-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-right','0','','','.b-fancybox'),(482960,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(482961,'furniture-mobile','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(482962,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-right','0','','','.p-blog-index'),(482963,'furniture-mobile','.p-blog-index .author','margin-right','20','','','.p-blog-index'),(482964,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(482965,'furniture-mobile','.b-messages .messages-menu ul','margin-right','0','','','.b-messages'),(482966,'furniture-mobile','.b-messages .messBtnMenuDelete','margin-right','8','3','','.b-messages'),(482967,'furniture-mobile','.b-messages .messBtnMenuUnread','margin-right','8','3','','.b-messages'),(482968,'furniture-mobile','.p-reviews-info .review-info-content','margin-right','0','','','.p-reviews-info'),(482969,'furniture-mobile','.b-messages .msv_content','margin-right','0','','','.b-messages'),(482970,'furniture-mobile','.b-messages .msv_history','margin-right','0','','','.b-messages'),(482971,'furniture-mobile','.b-messages .messBtnMenuStarred','margin-right','8','3','','.b-messages'),(482972,'furniture-mobile','.b-messages .messages-menu li','margin-right','0','','','.b-messages'),(482973,'furniture-mobile','.b-messages .content_management_attach span::before','margin-right','5','','','.b-messages'),(482974,'furniture-mobile','.b-messages .content_management_attach span','margin-right','10','','','.b-messages'),(482975,'furniture-mobile','.w-tabs .tab-navigation','margin-right','0','','','.w-tabs'),(482976,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-right','0','','','.w-sitemap-delivery-location'),(482977,'furniture-mobile','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(482978,'furniture-mobile','.p-blog-index .wp-widget ul','margin-right','0','','','.p-blog-index'),(482979,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-right','0','','','.p-account-subscription-historyinfo'),(482980,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(482981,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-right','0','','','.w-menu-slider'),(482982,'furniture-mobile','.w-sitemap-delivery-location > ul','margin-right','0','','','.w-sitemap-delivery-location'),(482983,'furniture-mobile','.p-payer-order-confirmation .order-ico','margin-right','10','3','','.p-payer-order-confirmation'),(482984,'furniture-mobile','.p-payer-order-confirmation .ship-ico','margin-right','10','3','','.p-payer-order-confirmation'),(482985,'furniture-mobile','.p-payer-order-confirmation .pay-ico','margin-right','10','3','','.p-payer-order-confirmation'),(482986,'furniture-mobile','.p-payer-order-confirmation .discount-ico','margin-right','10','3','','.p-payer-order-confirmation'),(482987,'furniture-mobile','.p-payer-order-confirmation .comment-ico','margin-right','10','3','','.p-payer-order-confirmation'),(482988,'furniture-mobile','.p-payer-order-pay .order-ico','margin-right','10','3','','.p-payer-order-pay'),(482989,'furniture-mobile','.p-payer-order-pay .ship-ico','margin-right','10','3','','.p-payer-order-pay'),(482990,'furniture-mobile','.p-payer-order-pay .pay-ico','margin-right','10','3','','.p-payer-order-pay'),(482991,'furniture-mobile','.p-payer-order-pay .discount-ico','margin-right','10','3','','.p-payer-order-pay'),(482992,'furniture-mobile','.p-payer-order-pay .comment-ico','margin-right','10','3','','.p-payer-order-pay'),(482993,'furniture-mobile','.p-blog-index .avatar','margin-right','10','','','.p-blog-index'),(482994,'furniture-mobile','.p-blog-index .author','margin-right','20','','','.p-blog-index'),(482995,'furniture-mobile','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(482996,'furniture-mobile','.b-delete-account .delete-box span','margin-right','10','','','.b-delete-account'),(482997,'furniture-mobile','.w-checkout-shipping-address .genders-title label','margin-right','20','','','.w-checkout-shipping-address'),(482998,'furniture-mobile','.w-checkout-shipping-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-shipping-address'),(482999,'furniture-mobile','.b-messages span.starred::before','margin-right','8','','','.b-messages'),(483000,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(483001,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(483002,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-right','0','','','.p-account-subscription-historyinfo'),(483003,'furniture-mobile','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(483004,'furniture-mobile','.w-menu-style-1 li','margin-right','0','','','.w-menu-style-1'),(483005,'furniture-mobile','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(483006,'furniture-mobile','.w-menu-horizontal li','margin-right','0','','','.w-menu-horizontal'),(483007,'furniture-mobile','.w-menu-horizontal ul','margin-right','0','','','.w-menu-horizontal'),(483008,'furniture-mobile','.b-info .info ul','margin-right','0','','','.b-info'),(483010,'furniture-mobile','.b-info .info li','margin-right','0','','','.b-info'),(483011,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-right','0','','','.p-account-subscription-historyinfo'),(483012,'furniture-mobile','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(483013,'furniture-mobile','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(483015,'furniture-mobile','.b-info .info li','margin-right','0','','','.b-info'),(483016,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(483017,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-right','0','','','.p-account-subscription-historyinfo'),(483018,'furniture-mobile','.p-blog-index .wp-widget ul','margin-right','0','','','.p-blog-index'),(483019,'furniture-mobile','.buttons .left-buttons .btn','margin-right','10','','',''),(483020,'furniture-mobile','.out-stock-icon','margin-right','3','3','',''),(483021,'furniture-mobile','.w-menu .hided.menu ul li','margin-right','0','','','.w-menu'),(483022,'furniture-mobile','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(483023,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(483024,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(483025,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-right','0','','','.w-menu-slider'),(483026,'furniture-mobile','.w-filters .input-checkbox:checked + .checkbox-span','margin-right','10','','','.w-filters'),(483027,'furniture-mobile','.p-reviews-info .review-info-image','margin-right','20','','','.p-reviews-info'),(483028,'furniture-mobile','.p-reviews-info .review-info-content','margin-right','0','','','.p-reviews-info'),(483029,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','margin-right','6','','','.p-reviews-info'),(483030,'furniture-mobile','.p-reviews-info .review-info-text','margin-right','0','','','.p-reviews-info'),(483031,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-right','0','','','.p-account-subscription-historyinfo'),(483032,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(483033,'furniture-mobile','.w-top-categories .categories','margin-right','-10','2890','','.w-top-categories'),(483034,'furniture-mobile','.b-info .info li','margin-right','0','','','.b-info'),(483035,'furniture-mobile','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(483036,'furniture-mobile','.b-info .info ul','margin-right','0','','','.b-info'),(483037,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-right','0','','','.b-select-suggest'),(483038,'furniture-mobile','.w-socials > li','margin-right','10','','','.w-socials'),(483039,'furniture-mobile','.w-search .search-input','margin-right','0','','','.w-search'),(483040,'furniture-mobile','.heading-settings .heading-4','margin-right','5','3','','.heading-settings'),(483041,'furniture-mobile','.p-blog-index .avatar','margin-right','10','','','.p-blog-index'),(483042,'furniture-mobile','.w-socials > li','margin-right','10','','','.w-socials'),(483043,'furniture-mobile','.p-blog-index .wp-widget li','margin-right','0','','','.p-blog-index'),(483044,'furniture-mobile','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(483045,'furniture-mobile','.b-info .info ul','margin-right','0','','','.b-info'),(483046,'furniture-mobile','.p-blog-index .author','margin-right','20','','','.p-blog-index'),(483047,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(483048,'furniture-mobile','.w-checkout-shipping-address .btn-cancel','margin-right','20','','','.w-checkout-shipping-address'),(483049,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-right','0','','','.w-menu-slider'),(483050,'furniture-mobile','.w-menu-style-1 ul','margin-right','0','','','.w-menu-style-1'),(483051,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(483052,'furniture-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','margin-right','10','3','','.w-multi-cart-actions'),(483053,'furniture-mobile','.w-tabs .tab-li','margin-right','0','','','.w-tabs'),(483054,'furniture-mobile','.w-socials > li','margin-right','10','','','.w-socials'),(483055,'furniture-mobile','.w-menu-style-1 li','margin-right','0','','','.w-menu-style-1'),(483056,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(483057,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(483058,'furniture-mobile','.w-cart-listing .actions > div','margin-right','20','','','.w-cart-listing'),(483059,'furniture-mobile','.b-form .required-message-wrap','margin-right','0','','','.b-form'),(483060,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-right','0','','','.p-blog-index'),(483061,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-right','0','','','.w-menu-slider'),(483062,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(483063,'furniture-mobile','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(483064,'furniture-mobile','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(483065,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-right','0','','','.w-menu'),(483066,'furniture-mobile','.heading-saved-lists .heading-4','margin-right','5','3','','.heading-saved-lists'),(483067,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(483068,'furniture-mobile','.b-info .info li','margin-right','0','','','.b-info'),(483069,'furniture-mobile','.b-info .info ul','margin-right','0','','','.b-info'),(483070,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-right','5','','','.b-messages'),(483071,'furniture-mobile','.w-filters .filter-ul-content','margin-right','0','','','.w-filters'),(483072,'furniture-mobile','.transit-icon','margin-right','3','3','',''),(483073,'furniture-mobile','.in-stock-icon','margin-right','3','3','',''),(483074,'furniture-mobile','.savings-ico .heading-2','margin-right','10','3','','.savings-ico'),(483075,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(483076,'furniture-mobile','.p-blog-index .author','margin-right','20','','','.p-blog-index'),(483077,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-right','0','','','.p-blog-index'),(483078,'furniture-mobile','.b-select-suggest .select2-drop-mask','margin-right','0','','','.b-select-suggest'),(483079,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-right','0','','','.p-blog-index'),(483080,'furniture-mobile','.js-stock-icon','margin-right','3','3','',''),(483081,'furniture-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-right','0','','','.b-form'),(483082,'furniture-mobile','.p-blog-index .avatar','margin-right','10','','','.p-blog-index'),(483083,'furniture-mobile','.products-quick-index ul','margin-right','0','','',''),(483084,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','margin-right','-100','','','.b-fancybox'),(483085,'furniture-mobile','.w-top-categories .categories h2','margin-right','0','','','.w-top-categories'),(483086,'furniture-mobile','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(483087,'furniture-mobile','.p-blog-index .nav-next a','margin-right','-50','3','','.p-blog-index'),(483088,'furniture-mobile','.p-blog-index .wp-widget ul','margin-right','0','','','.p-blog-index'),(483089,'furniture-mobile','.p-blog-index .wp-widget li','margin-right','0','3','','.p-blog-index'),(483090,'furniture-mobile','.p-blog-index .post-thumbnail','margin-right','40','','','.p-blog-index'),(483091,'furniture-mobile','.p-blog-index .nav-previous a','margin-right','0','3','','.p-blog-index'),(483092,'furniture-mobile','.p-blog-index .wp-widget li','margin-right','0','','','.p-blog-index'),(483093,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(483094,'furniture-mobile','.b-form .col-gender label','margin-right','20','','','.b-form'),(483095,'furniture-mobile','.w-socials .post_item_img','margin-right','10','','','.w-socials'),(483096,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(483097,'furniture-mobile','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(483098,'furniture-mobile','.w-product-quantity .qty_packs .price_1','margin-right','25','4','','.w-product-quantity'),(483099,'furniture-mobile','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(483100,'furniture-mobile','.b-select-suggest .select2-container.select2-allowclear .select2-choice .select2-chosen','margin-right','42','','','.b-select-suggest'),(483101,'furniture-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','margin-right','26','','','.b-select-suggest'),(483102,'furniture-mobile','.b-select-suggest .select2-container','margin-right','0','','','.b-select-suggest'),(483103,'furniture-mobile','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(483104,'furniture-mobile','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(483105,'furniture-mobile','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(483106,'furniture-mobile','.w-checkout-billing-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-billing-address'),(483107,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-right','0','','','.p-reviews-info'),(483108,'furniture-mobile','.b-info .info ul','margin-right','0','','','.b-info'),(483109,'furniture-mobile','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(483110,'furniture-mobile','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(483111,'furniture-mobile','.w-menu-style-1 ul','margin-right','0','','','.w-menu-style-1'),(483112,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(483113,'furniture-mobile','.w-menu-style-1 li','margin-right','0','','','.w-menu-style-1'),(483114,'furniture-mobile','.b-info .info li','margin-right','0','','','.b-info'),(483115,'furniture-mobile','.b-form .radio-buttons .radio-button','margin-right','30','','','.b-form'),(483116,'furniture-mobile','.b-form .checkbox-style:checked + .checkbox-span','margin-right','5','','','.b-form'),(483117,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(483118,'furniture-mobile','.w-menu-big ul','margin-right','0','','','.w-menu-big'),(483119,'furniture-mobile','.w-menu .hided.menu ul li','margin-right','0','','','.w-menu'),(483120,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(483121,'furniture-mobile','.p-blog-index .avatar','margin-right','10','','','.p-blog-index'),(483122,'furniture-mobile','.w-checkout-billing-address .genders-title label','margin-right','20','','','.w-checkout-billing-address'),(483123,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(483124,'furniture-mobile','.b-autocomplete .ui-autocomplete','margin-right','0','','','.b-autocomplete'),(483125,'furniture-mobile','.w-cart-checkout-btn + .w-image','margin-right','0','','','.w-cart-checkout-btn'),(483126,'furniture-mobile','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(483127,'furniture-mobile','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(483128,'furniture-mobile','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(483129,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(483130,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','margin-right','0','','','.b-select-suggest'),(483131,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-right','0','','','.p-reviews-info'),(483132,'furniture-mobile','.p-reviews-info .review-info-text','margin-right','0','','','.p-reviews-info'),(483133,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-right','0','','','.w-menu'),(483134,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-right','0','','','.w-menu-slider'),(483135,'furniture-mobile','.w-menu-style-1 ul','margin-right','0','','','.w-menu-style-1'),(483137,'furniture-mobile','.b-bottom .pop-up-content .buttons','margin-right','0','','','.b-bottom'),(483138,'furniture-mobile','.w-menu-big li','margin-right','0','','','.w-menu-big'),(483139,'furniture-mobile','.w-menu-style-1 li','margin-right','0','','','.w-menu-style-1'),(483140,'furniture-mobile','.w-socials > li','margin-right','10','','','.w-socials'),(483141,'furniture-mobile','.b-fancybox .fancybox-error','margin-right','0','','','.b-fancybox'),(483142,'furniture-mobile','.w-cart-compare .product .image','margin-right','10','','','.w-cart-compare'),(483143,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(483144,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','margin-right','5','3','','.b-form'),(483145,'furniture-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-right','0','','','.b-switch'),(483146,'furniture-mobile','.b-bottom .confirm-popup .buttons .btn','margin-right','20','','','.b-bottom'),(483147,'furniture-mobile','.b-info .info ul','margin-right','0','','','.b-info'),(483148,'furniture-mobile','.p-blog-index .avatar','margin-right','10','','','.p-blog-index'),(483149,'furniture-mobile','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(483150,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(483151,'furniture-mobile','.w-menu-style-1 ul','margin-right','0','','','.w-menu-style-1'),(483153,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(483154,'furniture-mobile','.w-cart-checkout-btn .or-text','margin-right','0','','','.w-cart-checkout-btn'),(483155,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-right','0','','','.p-account-subscription-historyinfo'),(483156,'furniture-mobile','.w-cart-give-away .ga_column','margin-right','2','','','.w-cart-give-away'),(483157,'furniture-mobile','.w-cart-compare .product-actions .dropdown-toggle','margin-right','8','3','','.w-cart-compare'),(483158,'furniture-mobile','.w-social-links a','margin-right','5','','','.w-social-links'),(483159,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-right','0','','','.p-reviews-info'),(483160,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-right','0','','','.p-blog-index'),(483161,'furniture-mobile','.p-blog-index .author','margin-right','20','','','.p-blog-index'),(483162,'furniture-mobile','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(483163,'furniture-mobile','.p-blog-index .wp-widget li','margin-right','0','','','.p-blog-index'),(483164,'furniture-mobile','.w-wedding-registry-widgets-share-link a','margin-right','5','3','','.w-wedding-registry-widgets-share-link'),(483165,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-right','0','','','.b-select-suggest'),(483166,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-right','0','','','.b-select-suggest'),(483167,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-right','0','','','.b-select-suggest'),(483168,'furniture-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-right','0','','','.b-select-suggest'),(483169,'furniture-mobile','.b-select-suggest .select2-search input','margin-right','0','','','.b-select-suggest'),(483170,'furniture-mobile','.b-select-suggest .select2-search','margin-right','0','','','.b-select-suggest'),(483171,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(483172,'furniture-mobile','.w-menu-style-1 li','margin-right','0','','','.w-menu-style-1'),(483173,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-right','0','','','.w-menu'),(483174,'furniture-mobile','.w-menu .hided.menu ul li','margin-right','0','','','.w-menu'),(483175,'furniture-mobile','.p-reviews-info .review-info-content','margin-right','0','','','.p-reviews-info'),(483176,'furniture-mobile','.p-reviews-info .review-info-text','margin-right','0','','','.p-reviews-info'),(483177,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(483178,'furniture-mobile','.w-menu-style-1 li','margin-right','0','','','.w-menu-style-1'),(483179,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','margin-right','12','','','.b-products-listing'),(483180,'furniture-mobile','.p-blog-index .wp-widget li','margin-right','0','','','.p-blog-index'),(483181,'furniture-mobile','.w-menu .hided.menu ul li','margin-right','0','','','.w-menu'),(483182,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-right','0','','','.w-menu-slider'),(483183,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-right','0','','','.w-menu'),(483184,'furniture-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','margin-right','10','','','.w-account-addresses-list'),(483185,'furniture-mobile','.b-products-listing .products-listing .btn-buy','margin-right','10','3','','.b-products-listing'),(483186,'furniture-mobile','.b-products-listing .products-listing .description ul','margin-right','0','','','.b-products-listing'),(483187,'furniture-mobile','.w-blog-widget-related-posts-by-category .products','margin-right','-15','','','.w-blog-widget-related-posts-by-category'),(483188,'furniture-mobile','.w-blog-widget-related-posts .products','margin-right','-15','','','.w-blog-widget-related-posts'),(483189,'furniture-mobile','.w-blog-widget-post-title h1','margin-right','0','','','.w-blog-widget-post-title'),(483190,'furniture-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-right','8','','','.w-blog-widget-post-share'),(483191,'furniture-mobile','.w-blog-widget-post-listing ','margin-right','0','2885','','.w-blog-widget-post-listing'),(483192,'furniture-mobile','.w-blog-widget-post-listing .post_view','margin-right','15','','','.w-blog-widget-post-listing'),(483193,'furniture-mobile','.w-blog-widget-post-listing .post_date span + span','margin-right','10','3','','.w-blog-widget-post-listing'),(483194,'furniture-mobile','.w-blog-widget-post-image ','margin-right','0','2876','','.w-blog-widget-post-image'),(483195,'furniture-mobile','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(483196,'furniture-mobile','.b-products-listing .products-listing .bonus-points-price','margin-right','10','','','.b-products-listing'),(483197,'furniture-mobile','.w-checkout-gdpr .privacy-row','margin-right','0','','','.w-checkout-gdpr'),(483198,'furniture-mobile','.b-compare .compare-box-btn','margin-right','20','','','.b-compare'),(483199,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(483200,'furniture-mobile','.w-socials > li','margin-right','10','','','.w-socials'),(483201,'furniture-mobile','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(483202,'furniture-mobile','.w-product-reviews .reviews-list','margin-right','0','','','.w-product-reviews'),(483203,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-right','0','','','.w-menu'),(483204,'furniture-mobile','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(483205,'furniture-mobile','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(483206,'furniture-mobile','.p-reviews-info .review-info-content','margin-right','0','','','.p-reviews-info'),(483207,'furniture-mobile','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(483208,'furniture-mobile','.w-taxable label','margin-right','5','','','.w-taxable'),(483209,'furniture-mobile','.w-taxable input[type=\"checkbox\"]','margin-right','5','','','.w-taxable'),(483210,'furniture-mobile','.w-taxable select','margin-right','0','','','.w-taxable'),(483211,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-right','0','','',''),(483212,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-right','0','','','.b-h-inline'),(483213,'furniture-mobile','.b-form .checkbox-style','margin-right','0','','','.b-form'),(483214,'furniture-mobile','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(483215,'furniture-mobile','.p-reviews-info .review-info-text','margin-right','0','','','.p-reviews-info'),(483216,'furniture-mobile','.w-menu-style-1 ul','margin-right','0','','','.w-menu-style-1'),(483217,'furniture-mobile','.w-filters .open','margin-right','10','3','','.w-filters'),(483218,'furniture-mobile','.w-catalog-paging .prev','margin-right','5','','','.w-catalog-paging'),(483219,'furniture-mobile','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(483220,'furniture-mobile','.b-info .info li','margin-right','0','','','.b-info'),(483221,'furniture-mobile','.products-quick-index .token-input-list','margin-right','0','','',''),(483222,'furniture-mobile','.w-cart-give-away .ga_attributes > div','margin-right','1','','','.w-cart-give-away'),(483223,'furniture-mobile','.w-product-cross-sell .buy-all-checker','margin-right','5','','','.w-product-cross-sell'),(483224,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(483225,'furniture-mobile','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','margin-right','10','3','','.w-cart-listing'),(483226,'furniture-mobile','.w-cart-give-away .ga_img','margin-right','2','','','.w-cart-give-away'),(483227,'furniture-mobile','.w-cart-give-away .ga_column','margin-right','0','2876','','.w-cart-give-away'),(483228,'furniture-mobile','.w-cart .multicart .name','margin-right','-10','','','.w-cart'),(483229,'furniture-mobile','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(483231,'furniture-mobile','.w-top-categories .categories','margin-right','0','2876','','.w-top-categories'),(483232,'furniture-mobile','.w-socials > li','margin-right','10','','','.w-socials'),(483233,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(483234,'furniture-mobile','.p-blog-index .wp-widget ul','margin-right','0','','','.p-blog-index'),(483235,'furniture-mobile','.p-blog-index .wp-widget li','margin-right','0','','','.p-blog-index'),(483236,'furniture-mobile','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(483237,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-right','0','','','.p-reviews-info'),(483238,'furniture-mobile','.b-form .password-forgotten-link','margin-right','0','','','.b-form'),(483239,'furniture-mobile','.w-menu .hided.menu ul li','margin-right','0','','','.w-menu'),(483240,'furniture-mobile','.w-menu-style-1 ul','margin-right','0','','','.w-menu-style-1'),(483241,'furniture-mobile','.w-catalog-listing-look .listing-look-title','margin-right','10','','','.w-catalog-listing-look'),(483242,'furniture-mobile','.w-filters .input-checkbox','margin-right','0','','','.w-filters'),(483243,'furniture-mobile','.products-quick-index ul.token-input-list','margin-right','0','','',''),(483244,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(483246,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','margin-right','5','','','.b-form'),(483247,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(483248,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-right','0','','','.w-menu'),(483249,'furniture-mobile','.w-menu .hided.menu ul li','margin-right','0','','','.w-menu'),(483250,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-right','0','','','.p-reviews-info'),(483251,'furniture-mobile','.p-blog-index .wp-widget ul','margin-right','0','','','.p-blog-index'),(483252,'furniture-mobile','.heading-ordered-items .heading-4','margin-right','5','3','','.heading-ordered-items'),(483253,'furniture-mobile','.b-form .required-message','margin-right','0','','','.b-form'),(483254,'furniture-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','margin-right','10','','','.w-filters'),(483255,'furniture-mobile','.p-reviews-info .review-info-content','margin-right','0','','','.p-reviews-info'),(483256,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(483257,'furniture-mobile','.b-product-images .media-popup .slick-dots','margin-right','0','','','.b-product-images'),(483258,'furniture-mobile','.b-product-images .media-popup .slick-dots li','margin-right','5','','','.b-product-images'),(483259,'furniture-mobile','.b-product-images .media-popup button.slick-next:active','margin-right','-3','','','.b-product-images'),(483260,'furniture-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-right','0','','','.b-menu-style'),(483261,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','margin-right','10','','','.b-menu-style-2'),(483262,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','margin-right','10','','','.b-menu-style-2'),(483263,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','margin-right','10','3','','.b-menu-style-2'),(483264,'furniture-mobile','.b-trade-approval .steps-bar','margin-right','0','','','.b-trade-approval'),(483265,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing','margin-right','0','','','.batchPr'),(483266,'furniture-mobile','.w-account-personal-catalog .list-switcher','margin-right','0','','','.w-account-personal-catalog'),(483267,'furniture-mobile','.w-account-subscription .info-popup','margin-right','20','','','.w-account-subscription'),(483268,'furniture-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-right','0','','','.w-catalog-additional-images'),(483269,'furniture-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-right','0','','','.b-cookie-notice'),(483270,'furniture-mobile','.tripleBanner ','margin-right','-15','','','.tripleBanner'),(483271,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .stock','margin-right','0','','','.b-products-listing'),(483272,'furniture-mobile','.preFooter .w-banner .single_banner','margin-right','2','','','.preFooter'),(483273,'furniture-mobile','.b-slick .slick-list','margin-right','0','','','.b-slick'),(483274,'furniture-mobile','.b-slick .slick-track','margin-right','auto','','','.b-slick'),(483275,'furniture-mobile','.b-products-listing .del-from-personal-catalog','margin-right','10','3','','.b-products-listing'),(483276,'furniture-mobile','.LeftCategories .w-menu-simple ul','margin-right','0','','','.LeftCategories'),(483277,'furniture-mobile','.w-breadcrumb .breadcrumb-li','margin-right','0','','','.w-breadcrumb'),(483278,'furniture-mobile','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(483279,'furniture-mobile','.w-quote .multicart .name','margin-right','-10','','','.w-quote'),(483280,'furniture-mobile','.b-quantity .qty-box input','margin-right','3','','','.b-quantity'),(483281,'furniture-mobile','h1, .heading-1','margin-right','-100','4','',''),(483282,'furniture-mobile','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','margin-right','10','3','','.w-product-buttons'),(483283,'furniture-mobile','.w-product-quantity .qty-input input[type=\'text\']','margin-right','5','','','.w-product-quantity'),(483284,'furniture-mobile','.w-compare .compare-list-buttons','margin-right','-250','','','.w-compare'),(483285,'furniture-mobile','.w-sample .multicart .name','margin-right','-10','','','.w-sample'),(483286,'furniture-mobile','.w-filters-simple .system-1','margin-right','20','','','.w-filters-simple'),(483287,'furniture-mobile','.w-cart-listing .points-earn','margin-right','12','','','.w-cart-listing'),(483288,'furniture-mobile','.w-cart-discount-coupon input[type=\"text\"]','margin-right','10','','','.w-cart-discount-coupon'),(483289,'furniture-mobile','.w-cart-sub-total ','margin-right','0','','','.w-cart-sub-total'),(483290,'furniture-mobile','.shipping-ico .heading-3','margin-right','0','','','.shipping-ico'),(483291,'furniture-mobile','.order-summary .heading-2','margin-right','0','','','.order-summary'),(483292,'furniture-mobile','.w-cart-gift-certificate .heading-4','margin-right','0','','','.w-cart-gift-certificate'),(483293,'furniture-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(483294,'furniture-mobile','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(483295,'furniture-mobile','.w-product-inventory input[type=\"radio\"]','margin-right','5','','','.w-product-inventory'),(483296,'furniture-mobile','.b-bottom .cart-options .buttons','margin-right','0','','','.b-bottom'),(483297,'furniture-mobile','.w-account-address-book .add_item a','margin-right','20','3','','.w-account-address-book'),(483298,'furniture-mobile','.heading-2','margin-right','-100','4','',''),(483299,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-right','0','','','.b-products-listing'),(483300,'furniture-mobile','.b-pagination ul.pagination','margin-right','0','','','.b-pagination'),(483301,'furniture-mobile','.w-product-quantity-discounts .item:nth-child(2n+1)','margin-right','2','','','.w-product-quantity-discounts'),(483302,'furniture-mobile','.w-product-quantity-discounts .item','margin-right','0','2885','','.w-product-quantity-discounts'),(483303,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .item','margin-right','5','','','.w-product-properties-filters-widgets-chosen-filters'),(483304,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','margin-right','0','3','','.p-quote-checkout-index'),(483305,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','margin-right','-100','4','','.p-quote-checkout-index'),(483306,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','margin-right','0','3','','.p-sample-checkout-index'),(483307,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','margin-right','-100','4','','.p-sample-checkout-index'),(483308,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','margin-right','-1','','','.w-account-personal-catalog'),(483309,'furniture-mobile','.w-account-personal-catalog .list-row-action li','margin-right','0','','','.w-account-personal-catalog'),(483310,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','margin-right','20','','','.w-account-personal-catalog'),(483311,'furniture-mobile','.w-product-collection .right-area .btn','margin-right','10','3','','.w-product-collection'),(483312,'furniture-mobile','.w-account-customer-additional-field .field-type-radio label','margin-right','20','','','.w-account-customer-additional-field'),(483313,'furniture-mobile','.w-product-collection .right-area .btn-2','margin-right','10','3','','.w-product-collection'),(483314,'furniture-mobile','.w-product-properties .property-ul','margin-right','0','','','.w-product-properties'),(483315,'furniture-mobile','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(483316,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','margin-right','30','','','.w-questionnaire-widgets-questionnaire'),(483317,'furniture-mobile','.b-products-listing .mix-attributes .mult-qty-input .qty-box > input','margin-right','3','','','.b-products-listing'),(483318,'furniture-mobile','.b-products-listing .products-listing .attribute-color','margin-right','4','','','.b-products-listing'),(483319,'furniture-mobile','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','margin-right','10','3','','.w-product-custom-bundle'),(483320,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list'),(483321,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list-block'),(483322,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(483323,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(483324,'furniture-mobile','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(483325,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-right','0','2876','','.w-delivery-location-top-location-list'),(483326,'furniture-mobile','.w-delivery-location-featured-list .deliveryList ul','margin-right','0','','','.w-delivery-location-featured-list'),(483327,'furniture-mobile','.w-wedding-registry-widgets-shipping-details .addresses .address-item label.radio-button > input','margin-right','4','','','.w-wedding-registry-widgets-shipping-details'),(483328,'furniture-mobile','.w-wedding-registry-widgets-delete-link .delete-registry','margin-right','5','3','','.w-wedding-registry-widgets-delete-link'),(483329,'furniture-mobile','.w-wedding-registry-widgets-edit-link .edit-registry','margin-right','5','3','','.w-wedding-registry-widgets-edit-link'),(483330,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(483331,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(483332,'furniture-mobile','.w-delivery-location-list-by-page .description ul','margin-right','0','','','.w-delivery-location-list-by-page'),(483333,'furniture-mobile','.w-delivery-location-list-by-page .item','margin-right','1','','','.w-delivery-location-list-by-page'),(483334,'furniture-mobile','.w-delivery-location-list-by-page .item','margin-right','0','2906','','.w-delivery-location-list-by-page'),(483335,'furniture-mobile','.w-delivery-location-cross-pages .description ul','margin-right','0','','','.w-delivery-location-cross-pages'),(483336,'furniture-mobile','.w-delivery-location-cross-pages .item','margin-right','1','','','.w-delivery-location-cross-pages'),(483337,'furniture-mobile','.w-delivery-location-cross-pages .item','margin-right','0','2906','','.w-delivery-location-cross-pages'),(483338,'furniture-mobile','.w-catalog-delivery-locations .item','margin-right','1','','','.w-catalog-delivery-locations'),(483339,'furniture-mobile','.w-catalog-delivery-locations .description ul','margin-right','0','','','.w-catalog-delivery-locations'),(483340,'furniture-mobile','.w-catalog-delivery-locations .item','margin-right','0','2876','','.w-catalog-delivery-locations'),(483341,'furniture-mobile','.w-wedding-registry-widgets-search-paging ul.pagination','margin-right','0','','','.w-wedding-registry-widgets-search-paging'),(483342,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','margin-right','12','','','.w-product-bonus-points'),(483343,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','margin-right','10','','','.w-product-designer-designer'),(483344,'furniture-mobile','.w-press-reviews-widgets-press-reviews .date','margin-right','0','2876','','.w-press-reviews-widgets-press-reviews'),(483345,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .image','margin-right','0','','','.w-press-reviews-widgets-press-reviews-list'),(483346,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .item','margin-right','0','','','.w-press-reviews-widgets-press-reviews-list'),(483347,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .review-box > *','margin-right','30','','','.w-press-reviews-widgets-press-reviews-list'),(483348,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .review-box > *','margin-right','0','2906','','.w-press-reviews-widgets-press-reviews-list'),(483349,'furniture-mobile','.w-gift-wrap-message-checkout .max-counter, .w-gift-wrap-message-checkout .max-words','margin-right','20','','','.w-gift-wrap-message-checkout'),(483350,'furniture-mobile','.w-gift-wrap-message-checkout .text','margin-right','20','','','.w-gift-wrap-message-checkout'),(483351,'furniture-mobile','.w-support-system-filter .filter_cats','margin-right','0','','','.w-support-system-filter'),(483352,'furniture-mobile','.w-support-system-listing .product_icon','margin-right','20','','','.w-support-system-listing'),(483353,'furniture-mobile','.w-rma-returns-history .filterMessages','margin-right','-3','','','.w-rma-returns-history'),(483354,'furniture-mobile','.w-rma-returns-history label[for=\'sCreateFrom\']','margin-right','5','','','.w-rma-returns-history'),(483355,'furniture-mobile','.w-rma-returns-history .column:last-child .title','margin-right','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(483356,'furniture-mobile','.w-show-inactive-show-inactive .out_stock_label','margin-right','10','','','.w-show-inactive-show-inactive'),(483357,'furniture-mobile','.w-product-designer-button label > input[type=\"checkbox\"]','margin-right','7','','','.w-product-designer-button'),(483358,'furniture-mobile','.w-product-designer-designer .productDesignerBox ul','margin-right','0','','','.w-product-designer-designer'),(483359,'furniture-mobile','.w-product-configurator .pc-item','margin-right','0','','','.w-product-configurator'),(483360,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-list'),(483361,'furniture-mobile','.w-predefined-promotion .icon','margin-right','15','','','.w-predefined-promotion'),(483362,'furniture-mobile','.w-predefined-promotion .nextdiscount .heading','margin-right','10','3','','.w-predefined-promotion'),(483363,'furniture-mobile','.w-predefined-promotion .prom-multi-discount > .heading','margin-right','5','3','','.w-predefined-promotion'),(483364,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','margin-right','5','3','','.w-predefined-promotion'),(483365,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .item','margin-right','12','','','.w-predefined-promotion'),(483366,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .item','margin-right','2','','','.w-predefined-promotion'),(483367,'furniture-mobile','.w-predefined-promotion .promo-salemaker .item','margin-right','2','','','.w-predefined-promotion'),(483368,'furniture-mobile','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','margin-right','5','3','','.w-predefined-promotion'),(483369,'furniture-mobile','.w-supplier-purchase-supplier-products .select_item','margin-right','20','','','.w-supplier-purchase-supplier-products'),(483370,'furniture-mobile','.w-supplier-purchase-supplier-products .name','margin-right','20','','','.w-supplier-purchase-supplier-products'),(483371,'furniture-mobile','.w-supplier-purchase-supplier-products .col-full','margin-right','20','','','.w-supplier-purchase-supplier-products'),(483372,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-right','0','','','.w-filters'),(483373,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','margin-right','10','','','.w-filters'),(483374,'furniture-mobile','.mainBanner .bottomBox .elf','margin-right','20','','','.mainBanner'),(483375,'furniture-mobile','.mainBanner .topBox > .left','margin-right','30','','','.mainBanner'),(483376,'furniture-mobile','.mainBanner .topBox > .right','margin-right','30','3','','.mainBanner'),(483377,'furniture-mobile','.mainBanner .topBox > .left','margin-right','15','2890','','.mainBanner'),(483378,'furniture-mobile','.mainBanner .topBox > .right','margin-right','10','2890,3','','.mainBanner'),(483379,'furniture-mobile','.mainBanner .topBox > .right','margin-right','5','2876,3','','.mainBanner'),(483380,'furniture-mobile','.lowestPricedBox .w-banner .banner','margin-right','0','','','.lowestPricedBox'),(483381,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner','margin-right','15','','','.lowestPricedBox'),(483382,'furniture-mobile','.lowestPricedBox .w-banner .ybg .descr','margin-right','-5','','','.lowestPricedBox'),(483383,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner','margin-right','0','2876','','.lowestPricedBox'),(483384,'furniture-mobile','.shopByCollectionBox .w-banner .banner','margin-right','-15','','','.shopByCollectionBox'),(483385,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','margin-right','15','','','.shopByCollectionBox'),(483386,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','margin-right','10','2885','','.shopByCollectionBox'),(483387,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','margin-right','10','2906','','.shopByCollectionBox'),(483388,'furniture-mobile','.w-search .extra','margin-right','10','3','','.w-search'),(483389,'furniture-mobile','.account-address-book .address_book .row-buttons a','margin-right','10','','','.account-address-book'),(483390,'furniture-mobile','.account-address-book .address_book h1','margin-right','0','','','.account-address-book'),(483391,'furniture-mobile','.account-address-book .address_book h2','margin-right','0','','','.account-address-book'),(483392,'furniture-mobile','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-right','0','','','.account-address-book'),(483393,'furniture-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-right','2','','','.account-address-book'),(483394,'furniture-mobile','.account-address-book .address_book_row h2 a','margin-right','0','','','.account-address-book'),(483395,'furniture-mobile','.account-address-book .buttonBox .info','margin-right','25','','','.account-address-book'),(483396,'furniture-mobile','.account-address-book .address_book_row .column','margin-right','0','2876','','.account-address-book'),(483397,'furniture-mobile','.account-address-book .address_book_row .column + .column','margin-right','0','2876','','.account-address-book'),(483398,'furniture-mobile','.account-address-book .topInfo > div','margin-right','0','2876','','.account-address-book'),(483399,'furniture-mobile','.account-address-book .topInfo > div + div','margin-right','0','2876','','.account-address-book'),(483400,'furniture-mobile','.account-order-history .buttonBox','margin-right','0','','','.account-order-history'),(483401,'furniture-mobile','.account-order-history .order_history_table h2','margin-right','0','','','.account-order-history'),(483402,'furniture-mobile','.account-order-history-info .buttons','margin-right','0','','','.account-order-history-info'),(483403,'furniture-mobile','.account-order-history-info .history_info','margin-right','0','','','.account-order-history-info'),(483404,'furniture-mobile','.account-order-history-info .history_info > div','margin-right','0','2885','','.account-order-history-info'),(483405,'furniture-mobile','.account-index .account_info','margin-right','0','','','.account-index'),(483406,'furniture-mobile','.account-index .account_page h1','margin-right','0','','','.account-index'),(483407,'furniture-mobile','.account-index .topAccount','margin-right','0','','','.account-index'),(483408,'furniture-mobile','.account-index .topInfo > div','margin-right','2','','','.account-index'),(483409,'furniture-mobile','.account-index .account_info','margin-right','0','2885','','.account-index'),(483410,'furniture-mobile','.account-order-pay .buttons','margin-right','0','','','.account-order-pay'),(483411,'furniture-mobile','.account-order-pay .history_info','margin-right','0','','','.account-order-pay'),(483412,'furniture-mobile','.account-order-pay .history_info > div','margin-right','0','2885','','.account-order-pay'),(483413,'furniture-mobile','.account-password-wrap .buttonedit','margin-right','0','','','.account-password-wrap'),(483414,'furniture-mobile','.account-samples .buttonBox','margin-right','0','','','.account-samples'),(483415,'furniture-mobile','.account-samples .order_history_table h2','margin-right','0','','','.account-samples'),(483416,'furniture-mobile','.account-sample-info .buttons','margin-right','0','','','.account-sample-info'),(483417,'furniture-mobile','.account-sample-info .history_info','margin-right','0','','','.account-sample-info'),(483418,'furniture-mobile','.account-sample-info .history_info > div','margin-right','0','2885','','.account-sample-info'),(483419,'furniture-mobile','.shopping-cart-index .closeable-heading .heading-2','margin-right','0','','','.shopping-cart-index'),(483420,'furniture-mobile','.checkout-index-wrap .order-ico','margin-right','10','3','','.checkout-index-wrap'),(483421,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','margin-right','0','3','','.checkout-index-wrap'),(483422,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','margin-right','-100','4','','.checkout-index-wrap'),(483423,'furniture-mobile','.checkout-index-wrap .pay-ico','margin-right','10','3','','.checkout-index-wrap'),(483424,'furniture-mobile','.checkout-index-wrap .ship-ico','margin-right','10','3','','.checkout-index-wrap'),(483425,'furniture-mobile','.checkout-order-confirmation .comment-ico','margin-right','10','3','','.checkout-order-confirmation'),(483426,'furniture-mobile','.checkout-order-confirmation .discount-ico','margin-right','10','3','','.checkout-order-confirmation'),(483427,'furniture-mobile','.checkout-order-confirmation .order-ico','margin-right','10','3','','.checkout-order-confirmation'),(483428,'furniture-mobile','.checkout-order-confirmation .ship-ico','margin-right','10','3','','.checkout-order-confirmation'),(483429,'furniture-mobile','.b-bottom .cart-options .buttons','margin-right_important','important','','','.b-bottom'),(483430,'furniture-mobile','.w-product-quantity-discounts .item','margin-right_important','important','2885','','.w-product-quantity-discounts'),(483431,'furniture-mobile','.b-info .info ul','margin-top','0','','','.b-info'),(483432,'furniture-mobile','.b-info .info li','margin-top','0','','','.b-info'),(483433,'furniture-mobile','.b-info .info ul','margin-top','0','','','.b-info'),(483434,'furniture-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-top','0','','','.b-switch'),(483435,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(483436,'furniture-mobile','.p-reviews-info .review-info-content','margin-top','0','','','.p-reviews-info'),(483437,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-top','0','','','.p-blog-index'),(483438,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-top','0','','','.p-reviews-info'),(483439,'furniture-mobile','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(483440,'furniture-mobile','.w-catalog-items-on-page select','margin-top','0','','','.w-catalog-items-on-page'),(483441,'furniture-mobile','.p-quick-order-index ul.token-input-list','margin-top','0','','','.p-quick-order-index'),(483442,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-top','0','','','.w-menu-slider'),(483443,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(483444,'furniture-mobile','.w-account .acc-returning','margin-top','0','','','.w-account'),(483445,'furniture-mobile','.w-account .account-dropdown','margin-top','-1','','','.w-account'),(483446,'furniture-mobile','.w-account .account-top','margin-top','0','','','.w-account'),(483447,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-top','0','','','.p-reviews-info'),(483448,'furniture-mobile','.p-reviews-info .review-info-text','margin-top','0','','','.p-reviews-info'),(483449,'furniture-mobile','.p-reviews-info .review-info-content','margin-top','0','','','.p-reviews-info'),(483450,'furniture-mobile','.p-blog-index .wp-widget ul','margin-top','0','','','.p-blog-index'),(483451,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-top','0','','','.p-blog-index'),(483452,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(483453,'furniture-mobile','.w-promotions .promo-salemaker .item','margin-top','2','','','.w-promotions'),(483454,'furniture-mobile','.w-promotions .promo-salemaker .content','margin-top','-18','','','.w-promotions'),(483455,'furniture-mobile','.w-promotions .promo-cart-discount .slave .item','margin-top','2','','','.w-promotions'),(483456,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-top','0','','','.b-warehouses-popup'),(483457,'furniture-mobile','.w-account .acc-new','margin-top','0','','','.w-account'),(483458,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(483459,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(483460,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-top','0','','','.p-account-subscription-historyinfo'),(483461,'furniture-mobile','.p-reviews-info .review-info-text','margin-top','0','','','.p-reviews-info'),(483462,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(483463,'furniture-mobile','.b-messages .messages-menu ul','margin-top','0','','','.b-messages'),(483464,'furniture-mobile','.b-messages .msv_content','margin-top','15','','','.b-messages'),(483465,'furniture-mobile','.b-messages .msv_btn','margin-top','10','','','.b-messages'),(483466,'furniture-mobile','.b-messages .msv_history','margin-top','15','','','.b-messages'),(483467,'furniture-mobile','.b-messages .messages-menu li','margin-top','0','','','.b-messages'),(483468,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul','margin-top','0','','','.w-sitemap-delivery-location'),(483469,'furniture-mobile','.w-tabs .tab-navigation','margin-top','0','','','.w-tabs'),(483470,'furniture-mobile','.w-socials > li','margin-top','10','','','.w-socials'),(483471,'furniture-mobile','.w-menu-style-1 li','margin-top','0','','','.w-menu-style-1'),(483472,'furniture-mobile','.b-form .g-recaptcha','margin-top','10','','','.b-form'),(483473,'furniture-mobile','.w-sitemap-delivery-location > ul','margin-top','0','','','.w-sitemap-delivery-location'),(483474,'furniture-mobile','.p-payer-order-confirmation .dob-hide','margin-top','20','','','.p-payer-order-confirmation'),(483475,'furniture-mobile','.p-payer-order-pay .dob-hide','margin-top','20','','','.p-payer-order-pay'),(483476,'furniture-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(483477,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(483478,'furniture-mobile','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(483479,'furniture-mobile','.b-info .info','margin-top','-8','3','','.b-info'),(483480,'furniture-mobile','.b-fancybox #fancybox-loading','margin-top','-22','','','.b-fancybox'),(483481,'furniture-mobile','.w-menu-style-1 ul','margin-top','0','','','.w-menu-style-1'),(483482,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(483483,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-top','0','','','.p-account-subscription-historyinfo'),(483485,'furniture-mobile','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(483486,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-template .btn','margin-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(483487,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(483488,'furniture-mobile','.b-info .info ul','margin-top','0','','','.b-info'),(483489,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(483490,'furniture-mobile','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(483491,'furniture-mobile','.w-menu-horizontal ul','margin-top','0','','','.w-menu-horizontal'),(483492,'furniture-mobile','.w-menu-horizontal li','margin-top','0','','','.w-menu-horizontal'),(483493,'furniture-mobile','.b-form .password-forgotten-link','margin-top','0','','','.b-form'),(483494,'furniture-mobile','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(483495,'furniture-mobile','.b-info .info li','margin-top','0','','','.b-info'),(483496,'furniture-mobile','.b-info .info li','margin-top','0','','','.b-info'),(483497,'furniture-mobile','.b-form .privacy-row','margin-top','10','','','.b-form'),(483498,'furniture-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(483499,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-top','0','','','.p-account-subscription-historyinfo'),(483500,'furniture-mobile','.b-fancybox .fancybox-title-outside-wrap','margin-top','10','','','.b-fancybox'),(483501,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(483502,'furniture-mobile','.b-info .info','margin-top','-8','3','','.b-info'),(483503,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(483504,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(483505,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-top','0','','','.p-account-subscription-historyinfo'),(483506,'furniture-mobile','.p-blog-index .wp-widget li','margin-top','0','','','.p-blog-index'),(483507,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(483508,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-top','0','','','.w-menu-slider'),(483509,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-top','0','','','.w-menu'),(483510,'furniture-mobile','.w-menu-style-1 ul','margin-top','0','','','.w-menu-style-1'),(483511,'furniture-mobile','.w-socials > li','margin-top','10','','','.w-socials'),(483512,'furniture-mobile','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(483513,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-top','0','','','.w-menu'),(483514,'furniture-mobile','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(483515,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(483516,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(483517,'furniture-mobile','.p-reviews-info .review-info-image','margin-top','0','','','.p-reviews-info'),(483518,'furniture-mobile','.p-blog-index .post-thumbnail','margin-top','0','','','.p-blog-index'),(483519,'furniture-mobile','.p-reviews-info .review-info-content','margin-top','0','','','.p-reviews-info'),(483520,'furniture-mobile','.p-blog-index .wp-widget ul','margin-top','0','','','.p-blog-index'),(483521,'furniture-mobile','.p-reviews-info .review-info-reviewed_by','margin-top','0','','','.p-reviews-info'),(483522,'furniture-mobile','.p-reviews-info .review-info-text','margin-top','0','','','.p-reviews-info'),(483523,'furniture-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(483524,'furniture-mobile','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(483525,'furniture-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-top','0','','','.b-fancybox'),(483526,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-top','0','','','.b-select-suggest'),(483527,'furniture-mobile','.w-socials > li','margin-top','10','','','.w-socials'),(483528,'furniture-mobile','.w-search .search-input','margin-top','0','','','.w-search'),(483529,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(483530,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-top','0','','','.p-blog-index'),(483531,'furniture-mobile','.p-blog-index .wp-widget li','margin-top','0','','','.p-blog-index'),(483532,'furniture-mobile','.p-reviews-info .review-info-text','margin-top','0','','','.p-reviews-info'),(483533,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(483534,'furniture-mobile','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(483535,'furniture-mobile','.w-cart-give-away .ga_attributes > div','margin-top','1','','','.w-cart-give-away'),(483536,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-top','0','','','.w-menu-slider'),(483537,'furniture-mobile','.w-menu-style-1 ul','margin-top','0','','','.w-menu-style-1'),(483538,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(483539,'furniture-mobile','.w-multi-cart-cart-switcher .cart-label','margin-top','-20','','','.w-multi-cart-cart-switcher'),(483540,'furniture-mobile','.w-tabs .tab-li','margin-top','0','','','.w-tabs'),(483541,'furniture-mobile','.w-socials > li','margin-top','10','','','.w-socials'),(483542,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(483543,'furniture-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(483544,'furniture-mobile','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(483545,'furniture-mobile','.b-form .required-message-wrap','margin-top','0','','','.b-form'),(483546,'furniture-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(483547,'furniture-mobile','.p-blog-index .wp-widget li','margin-top','0','','','.p-blog-index'),(483548,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-top','0','','','.w-menu-slider'),(483549,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(483550,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(483551,'furniture-mobile','.b-delete-account .delete-box span','margin-top','10','','','.b-delete-account'),(483552,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-top','0','','','.w-menu-slider'),(483553,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-top','0','','','.b-messages'),(483554,'furniture-mobile','.w-filters .filter-ul-content','margin-top','0','','','.w-filters'),(483555,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(483557,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(483558,'furniture-mobile','.p-quick-order-index .dataTables_info','margin-top','5','','','.p-quick-order-index'),(483559,'furniture-mobile','.b-select-suggest .select2-drop-mask','margin-top','0','','','.b-select-suggest'),(483560,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-top','0','','','.p-blog-index'),(483562,'furniture-mobile','.products-quick-index ul','margin-top','0','','',''),(483563,'furniture-mobile','.w-top-categories .categories h2','margin-top','0','','','.w-top-categories'),(483564,'furniture-mobile','.p-blog-index .nav-previous a','margin-top','0','3','','.p-blog-index'),(483565,'furniture-mobile','.p-blog-index .wp-widget li','margin-top','5','3','','.p-blog-index'),(483566,'furniture-mobile','.p-blog-index .wp-widget li','margin-top','0','','','.p-blog-index'),(483567,'furniture-mobile','.p-blog-index .nav-next a','margin-top','0','3','','.p-blog-index'),(483568,'furniture-mobile','.b-autocomplete .ui-autocomplete','margin-top','0','','','.b-autocomplete'),(483569,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(483570,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(483571,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(483572,'furniture-mobile','.w-wedding-registry-widgets-search-form .button','margin-top','-46','','','.w-wedding-registry-widgets-search-form'),(483573,'furniture-mobile','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(483574,'furniture-mobile','.w-product-quantity .qty_packs .price_1','margin-top','0','4','','.w-product-quantity'),(483575,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(483576,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-top','0','','','.p-account-subscription-historyinfo'),(483578,'furniture-mobile','.b-select-suggest .select2-container','margin-top','0','','','.b-select-suggest'),(483579,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(483580,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(483581,'furniture-mobile','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(483582,'furniture-mobile','.b-info .info','margin-top','-8','3','','.b-info'),(483583,'furniture-mobile','.b-info .info li','margin-top','0','','','.b-info'),(483584,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-top','0','','','.p-reviews-info'),(483585,'furniture-mobile','.b-info .info ul','margin-top','0','','','.b-info'),(483586,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(483587,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(483588,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(483589,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(483590,'furniture-mobile','.w-menu-style-1 ul','margin-top','0','','','.w-menu-style-1'),(483591,'furniture-mobile','.w-menu-style-1 li','margin-top','0','','','.w-menu-style-1'),(483592,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(483593,'furniture-mobile','.w-menu .hided.menu ul li','margin-top','0','','','.w-menu'),(483594,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(483595,'furniture-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-top','0','','','.b-fancybox'),(483596,'furniture-mobile','.w-menu-style-1 ul','margin-top','0','','','.w-menu-style-1'),(483597,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(483598,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(483599,'furniture-mobile','.b-info .info ul','margin-top','0','','','.b-info'),(483600,'furniture-mobile','.w-top-categories .categories','margin-top','0','2876','','.w-top-categories'),(483601,'furniture-mobile','.w-cart-checkout-btn .or-text','margin-top','-5','','','.w-cart-checkout-btn'),(483602,'furniture-mobile','.w-promotions .promo-cart-discount .master .item','margin-top','12','','','.w-promotions'),(483603,'furniture-mobile','.w-promotions .promo-cart-discount .master .image','margin-top','-16','','','.w-promotions'),(483604,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(483605,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','margin-top','0','','','.b-select-suggest'),(483606,'furniture-mobile','.p-blog-index .wp-widget li','margin-top','0','','','.p-blog-index'),(483607,'furniture-mobile','.p-reviews-info .review-info-content','margin-top','0','','','.p-reviews-info'),(483608,'furniture-mobile','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(483609,'furniture-mobile','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(483610,'furniture-mobile','.b-info .info','margin-top','-8','3','','.b-info'),(483611,'furniture-mobile','.b-form .required-message','margin-top','0','','','.b-form'),(483612,'furniture-mobile','.b-bottom .pop-up-content .buttons','margin-top','15','','','.b-bottom'),(483613,'furniture-mobile','.w-menu .hided.menu ul li','margin-top','0','','','.w-menu'),(483614,'furniture-mobile','.w-menu-big ul','margin-top','0','','','.w-menu-big'),(483615,'furniture-mobile','.w-menu-style-1 ul','margin-top','0','','','.w-menu-style-1'),(483616,'furniture-mobile','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(483617,'furniture-mobile','.b-fancybox .fancybox-error','margin-top','0','','','.b-fancybox'),(483618,'furniture-mobile','.b-info .info li','margin-top','0','','','.b-info'),(483619,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','margin-top','0','','','.b-switch'),(483620,'furniture-mobile','.w-cart-compare .product .image','margin-top','0','','','.w-cart-compare'),(483621,'furniture-mobile','.b-fancybox .fancybox-nav span','margin-top','-18','','','.b-fancybox'),(483622,'furniture-mobile','.b-info .info','margin-top','-8','3','','.b-info'),(483623,'furniture-mobile','.w-product-customers-activity .buttons','margin-top','10','','','.w-product-customers-activity'),(483624,'furniture-mobile','.b-bottom .confirm-popup .buttons .btn','margin-top','0','','','.b-bottom'),(483625,'furniture-mobile','.b-info .info li','margin-top','0','','','.b-info'),(483626,'furniture-mobile','.b-info .info ul','margin-top','0','','','.b-info'),(483627,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','margin-top','0','','','.p-account-subscription-historyinfo'),(483628,'furniture-mobile','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(483629,'furniture-mobile','.p-reviews-info .review-info-text','margin-top','0','','','.p-reviews-info'),(483630,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(483632,'furniture-mobile','.w-menu-style-1 li','margin-top','0','','','.w-menu-style-1'),(483633,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','margin-top','0','','','.w-menu-slider'),(483634,'furniture-mobile','.w-menu-big li','margin-top','0','','','.w-menu-big'),(483635,'furniture-mobile','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(483636,'furniture-mobile','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(483637,'furniture-mobile','.w-cart-checkout-btn + .w-image','margin-top','0','','','.w-cart-checkout-btn'),(483638,'furniture-mobile','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(483639,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(483640,'furniture-mobile','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(483641,'furniture-mobile','.w-social-links a','margin-top','0','','','.w-social-links'),(483642,'furniture-mobile','.p-reviews-info .review-info-content','margin-top','0','','','.p-reviews-info'),(483643,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(483644,'furniture-mobile','.p-blog-index .wp-widget ul','margin-top','0','','','.p-blog-index'),(483645,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-top','0','','','.p-blog-index'),(483646,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-top','1','','','.b-select-suggest'),(483647,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-top','0','','','.b-select-suggest'),(483648,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','margin-top','0','','','.b-select-suggest'),(483649,'furniture-mobile','.b-select-suggest .select2-results ul.select2-result-sub','margin-top','0','','','.b-select-suggest'),(483650,'furniture-mobile','.w-checkout-shipping-address .change-ab','margin-top','5','','','.w-checkout-shipping-address'),(483651,'furniture-mobile','.w-checkout-contact-information .contact-info-buttons','margin-top','5','','','.w-checkout-contact-information'),(483652,'furniture-mobile','.b-select-suggest .select2-drop.select2-drop-above .select2-search input','margin-top','4','','','.b-select-suggest'),(483653,'furniture-mobile','.b-select-suggest .select2-search input','margin-top','0','','','.b-select-suggest'),(483654,'furniture-mobile','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(483655,'furniture-mobile','.b-select-suggest .select2-search','margin-top','0','','','.b-select-suggest'),(483656,'furniture-mobile','.b-select-suggest .select2-drop.select2-drop-above','margin-top','1','','','.b-select-suggest'),(483657,'furniture-mobile','.b-select-suggest .select2-drop','margin-top','-1','','','.b-select-suggest'),(483658,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(483659,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-top','0','','','.w-menu'),(483660,'furniture-mobile','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(483661,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-top','0','','','.w-menu'),(483662,'furniture-mobile','.w-menu .hided.menu ul li','margin-top','0','','','.w-menu'),(483663,'furniture-mobile','.w-wedding-registry-widgets-products .rating','margin-top','15','','','.w-wedding-registry-widgets-products'),(483664,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(483665,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(483666,'furniture-mobile','.w-menu-style-1 li','margin-top','0','','','.w-menu-style-1'),(483667,'furniture-mobile','.p-blog-index .wp-widget ul','margin-top','0','','','.p-blog-index'),(483668,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(483669,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-top','0','','','.p-reviews-info'),(483670,'furniture-mobile','.p-reviews-info .review-info-text','margin-top','0','','','.p-reviews-info'),(483671,'furniture-mobile','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(483672,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-top','0','','','.w-menu'),(483673,'furniture-mobile','.w-menu .hided.menu ul li','margin-top','0','','','.w-menu'),(483674,'furniture-mobile','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(483675,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(483676,'furniture-mobile','.b-products-listing .products-listing .description ul','margin-top','0','','','.b-products-listing'),(483677,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','margin-top','-17','','','.w-blog-widget-related-posts'),(483678,'furniture-mobile','.w-blog-widget-post-title h1','margin-top','0','','','.w-blog-widget-post-title'),(483679,'furniture-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','margin-top','0','','','.w-blog-widget-post-share'),(483680,'furniture-mobile','.w-blog-widget-post-listing ','margin-top','0','2885','','.w-blog-widget-post-listing'),(483681,'furniture-mobile','.w-blog-widget-post-listing .post_date span + span','margin-top','0','3','','.w-blog-widget-post-listing'),(483682,'furniture-mobile','.w-blog-widget-categories-list div ~ div','margin-top','10','','','.w-blog-widget-categories-list'),(483683,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-top','0','','','.p-reviews-info'),(483684,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(483685,'furniture-mobile','.w-checkout-gdpr .privacy-row','margin-top','0','','','.w-checkout-gdpr'),(483686,'furniture-mobile','.w-checkout-gdpr .bootstrap-switch','margin-top','0','','','.w-checkout-gdpr'),(483687,'furniture-mobile','.b-form .checkbox-style','margin-top','0','','','.b-form'),(483688,'furniture-mobile','.b-form .wedding-form .heading-2','margin-top','10','','','.b-form'),(483689,'furniture-mobile','.w-product-reviews .reviews-list','margin-top','10','','','.w-product-reviews'),(483690,'furniture-mobile','.p-blog-index .wp-widget li','margin-top','0','','','.p-blog-index'),(483691,'furniture-mobile','.w-taxable label','margin-top','0','','','.w-taxable'),(483692,'furniture-mobile','.w-taxable select','margin-top','0','','','.w-taxable'),(483693,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-top','0','','',''),(483694,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-top','0','','','.b-h-inline'),(483695,'furniture-mobile','.w-communication-new-topic .files-box','margin-top','50','','','.w-communication-new-topic'),(483696,'furniture-mobile','.b-form .addresses .address-item input[type=\"radio\"]','margin-top','0','','','.b-form'),(483697,'furniture-mobile','.w-top-categories .categories','margin-top','0','2890','','.w-top-categories'),(483698,'furniture-mobile','.p-reviews-info .review-info-content','margin-top','0','','','.p-reviews-info'),(483699,'furniture-mobile','.w-menu-style-1 li','margin-top','0','','','.w-menu-style-1'),(483700,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(483701,'furniture-mobile','.products-quick-index .token-input-list','margin-top','0','','',''),(483702,'furniture-mobile','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(483704,'furniture-mobile','.b-info .info','margin-top','-8','3','','.b-info'),(483705,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(483706,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','margin-top','0','','','.p-blog-index'),(483707,'furniture-mobile','.w-menu-style-1 li','margin-top','0','','','.w-menu-style-1'),(483708,'furniture-mobile','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(483709,'furniture-mobile','.w-cart-listing .points-redeem','margin-top','-2','3','','.w-cart-listing'),(483710,'furniture-mobile','.w-cart .multicart .name','margin-top','0','','','.w-cart'),(483711,'furniture-mobile','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(483712,'furniture-mobile','.w-socials > li','margin-top','10','','','.w-socials'),(483713,'furniture-mobile','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(483714,'furniture-mobile','.w-menu .hided.menu ul li','margin-top','0','','','.w-menu'),(483715,'furniture-mobile','.w-filters .ui-slider','margin-top','5','','','.w-filters'),(483716,'furniture-mobile','.w-checkout-billing-address .bootstrap-switch','margin-top','-2','','','.w-checkout-billing-address'),(483717,'furniture-mobile','.p-reviews-info .reviews-info h1','margin-top','0','','','.p-reviews-info'),(483718,'furniture-mobile','.p-blog-index .wp-widget ul','margin-top','0','','','.p-blog-index'),(483719,'furniture-mobile','.w-socials .post_item_img','margin-top','0','','','.w-socials'),(483720,'furniture-mobile','.w-socials > li','margin-top','10','','','.w-socials'),(483721,'furniture-mobile','.p-account-update .privacy-row','margin-top','0','','','.p-account-update'),(483722,'furniture-mobile','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(483723,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top','0','','','.w-catalog-paging'),(483724,'furniture-mobile','.w-filters .input-checkbox','margin-top','0','','','.w-filters'),(483725,'furniture-mobile','.products-quick-index ul.token-input-list','margin-top','0','','',''),(483726,'furniture-mobile','.message.success','margin-top','-8','3','',''),(483727,'furniture-mobile','.p-blog-index .wp-widget ul','margin-top','0','','','.p-blog-index'),(483728,'furniture-mobile','.w-menu .hided.menu ul li','margin-top','0','','','.w-menu'),(483729,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','margin-top','0','','','.w-menu'),(483730,'furniture-mobile','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(483731,'furniture-mobile','.b-product-images .media-popup .slick-dots','margin-top','0','','','.b-product-images'),(483732,'furniture-mobile','.b-product-images .media-popup .slick-dots li','margin-top','0','','','.b-product-images'),(483733,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','margin-top','-50','','','.b-product-images'),(483734,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(483735,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-top','-44','','','.b-menu-lev_vis-click_icon'),(483736,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(483737,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(483738,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(483739,'furniture-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-top','0','','','.b-menu-style'),(483740,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','margin-top','-8','3','','.b-menu-style-2'),(483741,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','margin-top','-10','3','','.b-menu-style-2'),(483742,'furniture-mobile','.b-trade-approval .steps-bar','margin-top','0','','','.b-trade-approval'),(483743,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing','margin-top','0','','','.batchPr'),(483744,'furniture-mobile','.w-account-personal-catalog .list-switcher','margin-top','0','','','.w-account-personal-catalog'),(483745,'furniture-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-top','0','','','.w-catalog-additional-images'),(483746,'furniture-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-top','0','','','.b-cookie-notice'),(483747,'furniture-mobile','.w-cart .cart-box-link','margin-top','-5','4','','.w-cart'),(483748,'furniture-mobile','.w-account .my-acc-link','margin-top','-5','4','','.w-account'),(483749,'furniture-mobile','.tripleBanner ','margin-top','0','','','.tripleBanner'),(483750,'furniture-mobile','.preFooter .w-banner .single_banner','margin-top','0','','','.preFooter'),(483751,'furniture-mobile','.b-slick .slick-list','margin-top','0','','','.b-slick'),(483752,'furniture-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-top','0','','','.b-slick'),(483753,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','margin-top','-20','','','.b-slick'),(483754,'furniture-mobile','.tripleBanner > .block','margin-top','10','2885','','.tripleBanner'),(483755,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li.component-item','margin-top','20','','','.b-menu-style-3'),(483756,'furniture-mobile','.LeftCategories .w-menu-simple ul','margin-top','0','','','.LeftCategories'),(483757,'furniture-mobile','.w-breadcrumb .breadcrumb-li','margin-top','0','','','.w-breadcrumb'),(483758,'furniture-mobile','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(483759,'furniture-mobile','.w-quote .multicart .name','margin-top','0','','','.w-quote'),(483760,'furniture-mobile','.warrantyProduct .warranty','margin-top','-16','3','','.warrantyProduct'),(483761,'furniture-mobile','.warrantyProduct .delivery','margin-top','-15','3','','.warrantyProduct'),(483762,'furniture-mobile','.w-sample .cart-box-link','margin-top','-5','4','','.w-sample'),(483763,'furniture-mobile','.w-sample .multicart .name','margin-top','0','','','.w-sample'),(483764,'furniture-mobile','.w-cart-sub-total ','margin-top','0','','','.w-cart-sub-total'),(483765,'furniture-mobile','.shipping-ico .heading-3','margin-top','0','','','.shipping-ico'),(483766,'furniture-mobile','.order-summary .heading-2','margin-top','0','','','.order-summary'),(483767,'furniture-mobile','.w-cart-gift-certificate .heading-4','margin-top','0','','','.w-cart-gift-certificate'),(483768,'furniture-mobile','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(483769,'furniture-mobile','.w-product-bundle .bundle_price','margin-top','-5','','','.w-product-bundle'),(483770,'furniture-mobile','.b-bottom .cart-options .buttons','margin-top','10','','','.b-bottom'),(483771,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-top','0','','','.b-products-listing'),(483772,'furniture-mobile','.b-pagination ul.pagination','margin-top','0','','','.b-pagination'),(483773,'furniture-mobile','.w-product-quantity-discounts .item','margin-top','0','2885','','.w-product-quantity-discounts'),(483774,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .item','margin-top','0','','','.w-product-properties-filters-widgets-chosen-filters'),(483775,'furniture-mobile','.w-account-order-download .btn','margin-top','-70','2876','','.w-account-order-download'),(483776,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','margin-top','-1','','','.w-account-personal-catalog'),(483777,'furniture-mobile','.w-account-personal-catalog .list-row-action li','margin-top','0','','','.w-account-personal-catalog'),(483778,'furniture-mobile','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(483779,'furniture-mobile','.w-product-properties .property-ul','margin-top','0','','','.w-product-properties'),(483780,'furniture-mobile','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(483781,'furniture-mobile','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(483782,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list'),(483783,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list-block'),(483784,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(483785,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(483786,'furniture-mobile','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(483787,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','2876','','.w-delivery-location-top-location-list'),(483788,'furniture-mobile','.w-delivery-location-featured-list .deliveryList ul','margin-top','0','','','.w-delivery-location-featured-list'),(483789,'furniture-mobile','.w-product-wedding-registry-button .btn','margin-top','-10','3','','.w-product-wedding-registry-button'),(483790,'furniture-mobile','.w-product-wedding-registry-button .btn','margin-top','-10','4','','.w-product-wedding-registry-button'),(483791,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(483792,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(483793,'furniture-mobile','.w-delivery-location-list-by-page .description ul','margin-top','5','','','.w-delivery-location-list-by-page'),(483794,'furniture-mobile','.w-delivery-location-list-by-page .item','margin-top','0','','','.w-delivery-location-list-by-page'),(483795,'furniture-mobile','.w-delivery-location-list-by-page .item','margin-top','10','2906','','.w-delivery-location-list-by-page'),(483796,'furniture-mobile','.w-delivery-location-cross-pages .description ul','margin-top','5','','','.w-delivery-location-cross-pages'),(483797,'furniture-mobile','.w-delivery-location-cross-pages .item','margin-top','0','','','.w-delivery-location-cross-pages'),(483798,'furniture-mobile','.w-delivery-location-cross-pages .item','margin-top','10','2906','','.w-delivery-location-cross-pages'),(483799,'furniture-mobile','.w-catalog-delivery-locations .item','margin-top','0','','','.w-catalog-delivery-locations'),(483800,'furniture-mobile','.w-catalog-delivery-locations .description ul','margin-top','5','','','.w-catalog-delivery-locations'),(483801,'furniture-mobile','.w-catalog-delivery-locations .item','margin-top','0','2876','','.w-catalog-delivery-locations'),(483802,'furniture-mobile','.w-wedding-registry-widgets-search-paging ul.pagination','margin-top','0','','','.w-wedding-registry-widgets-search-paging'),(483803,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','margin-top','10','','','.w-product-designer-designer'),(483804,'furniture-mobile','.w-press-reviews-widgets-press-reviews .date','margin-top','10','2876','','.w-press-reviews-widgets-press-reviews'),(483805,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .image','margin-top','0','','','.w-press-reviews-widgets-press-reviews-list'),(483806,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .item','margin-top','10','','','.w-press-reviews-widgets-press-reviews-list'),(483807,'furniture-mobile','.w-support-system-filter .filter_cats','margin-top','0','','','.w-support-system-filter'),(483808,'furniture-mobile','.w-rma-returns-history .content-messages .messages-table .bottom','margin-top','10','','','.w-rma-returns-history'),(483809,'furniture-mobile','.w-rma-returns-history .content-messages .messages-table .top','margin-top','10','','','.w-rma-returns-history'),(483810,'furniture-mobile','.w-rma-returns-history .filterMessages','margin-top','0','','','.w-rma-returns-history'),(483811,'furniture-mobile','.w-rma-returns-history .column:last-child .title','margin-top','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(483812,'furniture-mobile','.w-product-designer-designer .productDesignerBox ul','margin-top','0','','','.w-product-designer-designer'),(483813,'furniture-mobile','.w-product-configurator .pc-item','margin-top','0','','','.w-product-configurator'),(483814,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-list'),(483815,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .image','margin-top','-16','','','.w-predefined-promotion'),(483816,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .item','margin-top','12','','','.w-predefined-promotion'),(483817,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .item','margin-top','2','','','.w-predefined-promotion'),(483818,'furniture-mobile','.w-predefined-promotion .promo-salemaker .content','margin-top','-18','','','.w-predefined-promotion'),(483819,'furniture-mobile','.w-predefined-promotion .promo-salemaker .item','margin-top','2','','','.w-predefined-promotion'),(483820,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-top','0','','','.w-filters'),(483821,'furniture-mobile','.mainBanner .topBox > .right','margin-top','-20','4','','.mainBanner'),(483822,'furniture-mobile','.mainBanner .topBox > .right','margin-top','-16','2876,4','','.mainBanner'),(483823,'furniture-mobile','.lowestPricedBox .w-banner .banner','margin-top','0','','','.lowestPricedBox'),(483824,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner','margin-top','0','','','.lowestPricedBox'),(483825,'furniture-mobile','.lowestPricedBox .w-banner .ybg .descr','margin-top','0','','','.lowestPricedBox'),(483826,'furniture-mobile','.shopByCollectionBox .w-banner .banner','margin-top','0','','','.shopByCollectionBox'),(483827,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','margin-top','0','','','.shopByCollectionBox'),(483828,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','margin-top','10','2885','','.shopByCollectionBox'),(483829,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','margin-top','10','2906','','.shopByCollectionBox'),(483830,'furniture-mobile','.account-address-book .address_book .row-buttons a','margin-top','0','','','.account-address-book'),(483831,'furniture-mobile','.account-address-book .address_book h1','margin-top','0','','','.account-address-book'),(483832,'furniture-mobile','.account-address-book .address_book h2','margin-top','0','','','.account-address-book'),(483833,'furniture-mobile','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-top','0','','','.account-address-book'),(483834,'furniture-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-top','0','','','.account-address-book'),(483835,'furniture-mobile','.account-address-book .address_book_row h2 a','margin-top','0','','','.account-address-book'),(483836,'furniture-mobile','.account-address-book .buttonBox .info','margin-top','0','','','.account-address-book'),(483837,'furniture-mobile','.account-address-book .address_book_row .column','margin-top','0','2876','','.account-address-book'),(483838,'furniture-mobile','.account-address-book .address_book_row .column + .column','margin-top','0','2876','','.account-address-book'),(483839,'furniture-mobile','.account-address-book .topInfo > div','margin-top','0','2876','','.account-address-book'),(483840,'furniture-mobile','.account-address-book .topInfo > div + div','margin-top','0','2876','','.account-address-book'),(483841,'furniture-mobile','.account-address-book-process .buttons','margin-top','-70','','','.account-address-book-process'),(483842,'furniture-mobile','.account-edit-wrap .buttons','margin-top','-70','','','.account-edit-wrap'),(483843,'furniture-mobile','.account-order-history .buttonBox','margin-top','15','','','.account-order-history'),(483844,'furniture-mobile','.account-order-history .order_history_table h2','margin-top','0','','','.account-order-history'),(483845,'furniture-mobile','.account-order-history-info .buttons','margin-top','20','','','.account-order-history-info'),(483846,'furniture-mobile','.account-order-history-info .history_info','margin-top','0','','','.account-order-history-info'),(483847,'furniture-mobile','.account-order-history-info .popup-tracking-number-link','margin-top','10','','','.account-order-history-info'),(483848,'furniture-mobile','.account-order-history-info .history_info > div','margin-top','0','2885','','.account-order-history-info'),(483849,'furniture-mobile','.account-index .account_info','margin-top','0','','','.account-index'),(483850,'furniture-mobile','.account-index .account_page h1','margin-top','0','','','.account-index'),(483851,'furniture-mobile','.account-index .remove-btn','margin-top','-15','','','.account-index'),(483852,'furniture-mobile','.account-index .topAccount','margin-top','0','','','.account-index'),(483853,'furniture-mobile','.account-index .topInfo > div','margin-top','0','','','.account-index'),(483854,'furniture-mobile','.account-index .account_info','margin-top','0','2885','','.account-index'),(483855,'furniture-mobile','.account-order-pay .buttons','margin-top','20','','','.account-order-pay'),(483856,'furniture-mobile','.account-order-pay .history_info','margin-top','0','','','.account-order-pay'),(483857,'furniture-mobile','.account-order-pay .history_info > div','margin-top','0','2885','','.account-order-pay'),(483858,'furniture-mobile','.account-password-wrap .buttonedit','margin-top','-40','','','.account-password-wrap'),(483859,'furniture-mobile','.account-password-wrap .buttons','margin-top','-70','','','.account-password-wrap'),(483860,'furniture-mobile','.account-samples .buttonBox','margin-top','15','','','.account-samples'),(483861,'furniture-mobile','.account-samples .order_history_table h2','margin-top','0','','','.account-samples'),(483862,'furniture-mobile','.account-sample-info .buttons','margin-top','20','','','.account-sample-info'),(483863,'furniture-mobile','.account-sample-info .history_info','margin-top','0','','','.account-sample-info'),(483864,'furniture-mobile','.account-sample-info .popup-tracking-number-link','margin-top','10','','','.account-sample-info'),(483865,'furniture-mobile','.account-sample-info .history_info > div','margin-top','0','2885','','.account-sample-info'),(483866,'furniture-mobile','.shopping-cart-index .closeable-heading .heading-2','margin-top','0','','','.shopping-cart-index'),(483867,'furniture-mobile','.checkout-index-wrap .dob-hide','margin-top','20','','','.checkout-index-wrap'),(483868,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top_important','important','','','.w-catalog-paging'),(483869,'furniture-mobile','.b-bottom .cart-options .buttons','margin-top_important','important','','','.b-bottom'),(483870,'furniture-mobile','.w-product-quantity-discounts .item','margin-top_important','important','2885','','.w-product-quantity-discounts'),(483871,'furniture-mobile','.p-quick-order-index ul.token-input-list','margin_bottom_measure','pt','','','.p-quick-order-index'),(483872,'furniture-mobile','.w-cart-give-away .ga_attributes > div','margin_bottom_measure','%','','','.w-cart-give-away'),(483873,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(483874,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(483875,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','2876','','.w-delivery-location-top-location-list'),(483876,'furniture-mobile','.p-quick-order-index ul.token-input-list','margin_left_measure','pt','','','.p-quick-order-index'),(483877,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_left_measure','pt','','','.b-warehouses-popup'),(483878,'furniture-mobile','.w-sale .left-text-right','margin_left_measure','%','','','.w-sale'),(483879,'furniture-mobile','.b-form .columns .col-2:nth-child(2n)','margin_left_measure','%','','','.b-form'),(483880,'furniture-mobile','.w-sale .left-count','margin_left_measure','%','','','.w-sale'),(483881,'furniture-mobile','.w-sale .left-count','margin_left_measure','%','','','.w-sale'),(483882,'furniture-mobile','.w-sale .left-text-right','margin_left_measure','%','','','.w-sale'),(483883,'furniture-mobile','.w-sale .left-count','margin_left_measure','%','','','.w-sale'),(483884,'furniture-mobile','.w-cart-give-away .ga_column','margin_left_measure','%','','','.w-cart-give-away'),(483885,'furniture-mobile','.w-sale .left-count','margin_left_measure','%','','','.w-sale'),(483886,'furniture-mobile','.w-sale .left-text-right','margin_left_measure','%','','','.w-sale'),(483887,'furniture-mobile','.w-sale .left-count','margin_left_measure','%','','','.w-sale'),(483888,'furniture-mobile','.w-sale .left-text-right','margin_left_measure','%','','','.w-sale'),(483889,'furniture-mobile','.w-sale .left-text-right','margin_left_measure','%','','','.w-sale'),(483890,'furniture-mobile','.w-taxable select','margin_left_measure','pt','','','.w-taxable'),(483891,'furniture-mobile','.b-form .col-3 + .col-3','margin_left_measure','%','','','.b-form'),(483892,'furniture-mobile','.w-sale .left-count','margin_left_measure','%','','','.w-sale'),(483893,'furniture-mobile','.w-sale .left-text-right','margin_left_measure','%','','','.w-sale'),(483894,'furniture-mobile','.w-cart-give-away .ga_attributes > div','margin_left_measure','%','','','.w-cart-give-away'),(483895,'furniture-mobile','.b-trade-approval .col-3 + .col-3','margin_left_measure','%','','','.b-trade-approval'),(483896,'furniture-mobile','.w-delivery-day .left-count','margin_left_measure','%','','','.w-delivery-day'),(483897,'furniture-mobile','.w-delivery-day .left-text-right','margin_left_measure','%','','','.w-delivery-day'),(483898,'furniture-mobile','.w-product-sale-ends .left-count','margin_left_measure','%','','','.w-product-sale-ends'),(483899,'furniture-mobile','.w-product-sale-ends .left-text-right','margin_left_measure','%','','','.w-product-sale-ends'),(483900,'furniture-mobile','h1, .heading-1','margin_left_measure','%','3','',''),(483901,'furniture-mobile','.heading-2','margin_left_measure','%','3','',''),(483902,'furniture-mobile','.w-product-quantity-discounts .item:nth-child(2n)','margin_left_measure','%','','','.w-product-quantity-discounts'),(483903,'furniture-mobile','.w-product-multi-inventory .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-multi-inventory'),(483904,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','margin_left_measure','%','3','','.p-quote-checkout-index'),(483905,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','margin_left_measure','%','3','','.p-sample-checkout-index'),(483906,'furniture-mobile','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(483907,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(483908,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(483909,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','2876','','.w-delivery-location-top-location-list'),(483910,'furniture-mobile','.w-wedding-registry-widgets-search-form .col-3 + .col-3','margin_left_measure','%','2885','','.w-wedding-registry-widgets-search-form'),(483911,'furniture-mobile','.w-wedding-registry-widgets-search-form .col-3 + .col-3','margin_left_measure','%','2906','','.w-wedding-registry-widgets-search-form'),(483912,'furniture-mobile','.w-sale-category .left-count','margin_left_measure','%','','','.w-sale-category'),(483913,'furniture-mobile','.w-sale-category .left-text-right','margin_left_measure','%','','','.w-sale-category'),(483914,'furniture-mobile','.w-delivery-location-list-by-page .item','margin_left_measure','%','','','.w-delivery-location-list-by-page'),(483915,'furniture-mobile','.w-delivery-location-cross-pages .item','margin_left_measure','%','','','.w-delivery-location-cross-pages'),(483916,'furniture-mobile','.w-catalog-delivery-locations .item','margin_left_measure','%','','','.w-catalog-delivery-locations'),(483917,'furniture-mobile','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin_left_measure','%','','','.account-address-book'),(483918,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','margin_left_measure','%','3','','.checkout-index-wrap'),(483919,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_right_measure','pt','','','.b-warehouses-popup'),(483920,'furniture-mobile','.p-quick-order-index ul.token-input-list','margin_right_measure','pt','','','.p-quick-order-index'),(483921,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','margin_right_measure','%','','','.b-fancybox'),(483922,'furniture-mobile','.w-cart-give-away .ga_column','margin_right_measure','%','','','.w-cart-give-away'),(483923,'furniture-mobile','.w-taxable select','margin_right_measure','pt','','','.w-taxable'),(483924,'furniture-mobile','.w-cart-give-away .ga_img','margin_right_measure','%','','','.w-cart-give-away'),(483925,'furniture-mobile','.w-cart-give-away .ga_attributes > div','margin_right_measure','%','','','.w-cart-give-away'),(483926,'furniture-mobile','h1, .heading-1','margin_right_measure','%','4','',''),(483927,'furniture-mobile','.heading-2','margin_right_measure','%','4','',''),(483928,'furniture-mobile','.w-product-quantity-discounts .item:nth-child(2n+1)','margin_right_measure','%','','','.w-product-quantity-discounts'),(483929,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','margin_right_measure','%','4','','.p-quote-checkout-index'),(483930,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','margin_right_measure','%','4','','.p-sample-checkout-index'),(483931,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(483932,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(483933,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','2876','','.w-delivery-location-top-location-list'),(483934,'furniture-mobile','.w-delivery-location-list-by-page .item','margin_right_measure','%','','','.w-delivery-location-list-by-page'),(483935,'furniture-mobile','.w-delivery-location-cross-pages .item','margin_right_measure','%','','','.w-delivery-location-cross-pages'),(483936,'furniture-mobile','.w-catalog-delivery-locations .item','margin_right_measure','%','','','.w-catalog-delivery-locations'),(483937,'furniture-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin_right_measure','%','','','.account-address-book'),(483938,'furniture-mobile','.account-index .topInfo > div','margin_right_measure','%','','','.account-index'),(483939,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','margin_right_measure','%','4','','.checkout-index-wrap'),(483940,'furniture-mobile','.p-quick-order-index ul.token-input-list','margin_top_measure','pt','','','.p-quick-order-index'),(483941,'furniture-mobile','.w-cart-give-away .ga_attributes > div','margin_top_measure','%','','','.w-cart-give-away'),(483942,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(483943,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(483944,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','2876','','.w-delivery-location-top-location-list'),(483945,'furniture-mobile','.w-sale .image img','max-height','300','','','.w-sale'),(483946,'furniture-mobile','.w-promotions .prom-multi-discount .image img','max-height','80','','','.w-promotions'),(483947,'furniture-mobile','.w-promotions .promo-salemaker .image img','max-height','80','','','.w-promotions'),(483948,'furniture-mobile','.w-promotions .promo-cart-discount .image img','max-height','80','','','.w-promotions'),(483949,'furniture-mobile','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(483950,'furniture-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(483951,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-height','100','','','.w-upload-customer-id-upload-customer-id-form'),(483952,'furniture-mobile','.w-product-images-additional .item-img','max-height','70','2906','','.w-product-images-additional'),(483953,'furniture-mobile','.w-product-images-additional .item-img','max-height','70','2906','','.w-product-images-additional'),(483954,'furniture-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(483955,'furniture-mobile','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(483956,'furniture-mobile','.b-fancybox .fancybox-tmp','max-height','99999','','','.b-fancybox'),(483957,'furniture-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(483958,'furniture-mobile','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(483959,'furniture-mobile','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(483960,'furniture-mobile','.w-sale .image img','max-height','300','','','.w-sale'),(483961,'furniture-mobile','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(483962,'furniture-mobile','.w-sale .image img','max-height','300','','','.w-sale'),(483963,'furniture-mobile','.b-fancybox .fancybox-image','max-height','100','','','.b-fancybox'),(483964,'furniture-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(483965,'furniture-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(483966,'furniture-mobile','.w-product-images-additional .item-img','max-height','70','2906','','.w-product-images-additional'),(483967,'furniture-mobile','.b-select-suggest .select2-results','max-height','200','','','.b-select-suggest'),(483968,'furniture-mobile','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(483969,'furniture-mobile','.w-sale .image img','max-height','300','','','.w-sale'),(483970,'furniture-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-height','100','','','.b-products-listing'),(483971,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_img img','max-height','167','','','.w-blog-widget-related-posts-by-category'),(483972,'furniture-mobile','.w-blog-widget-post-listing .post_image img','max-height','232','','','.w-blog-widget-post-listing'),(483973,'furniture-mobile','.w-sale .image img','max-height','300','','','.w-sale'),(483974,'furniture-mobile','.b-email-editor img','max-height','100','','','.b-email-editor'),(483975,'furniture-mobile','.w-product-images-additional .item-img','max-height','70','2906','','.w-product-images-additional'),(483976,'furniture-mobile','.w-sale .image img','max-height','300','','','.w-sale'),(483977,'furniture-mobile','.w-product-images-additional .item-img','max-height','70','2906','','.w-product-images-additional'),(483978,'furniture-mobile','.w-product-images-additional .item-img','max-height','70','2906','','.w-product-images-additional'),(483979,'furniture-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max-height','100','','','.b-product-images'),(483980,'furniture-mobile','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max-height','90','','','.b-product-images'),(483981,'furniture-mobile','.b-product-images .media-popup .mp-small-images img','max-height','90','','','.b-product-images'),(483982,'furniture-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','max-height','0','','','.b-menu-burger_icon'),(483983,'furniture-mobile','.b-menu-burger_icon .bi-opened .menu-style[data-open_from=\"top\"] .menu-content','max-height','2000','','','.b-menu-burger_icon'),(483984,'furniture-mobile','.batchPr .w-batch-products .products-listing .image img','max-height','80','','','.batchPr'),(483985,'furniture-mobile','.batchPr .w-batch-selected-products .image img','max-height','40','','','.batchPr'),(483986,'furniture-mobile','.batchPr .w-batch-products .image img','max-height','160','','','.batchPr'),(483987,'furniture-mobile','.w-product-images img','max-height','100','','','.w-product-images'),(483988,'furniture-mobile','.b-product-images .additional-horizontal .additional-images img','max-height','150','','','.b-product-images'),(483989,'furniture-mobile','.b-product-images .produst-image img','max-height','400','','','.b-product-images'),(483990,'furniture-mobile','.b-product-images .additional-horizontal .additional-images video','max-height','150','','','.b-product-images'),(483991,'furniture-mobile','.w-product-video .item img, .w-product-video .item video','max-height','150','','','.w-product-video'),(483992,'furniture-mobile','.w-catalog-additional-images img','max-height','150','','','.w-catalog-additional-images'),(483993,'furniture-mobile','.b-products-listing .products-listing .radio-attributes img','max-height','30','','','.b-products-listing'),(483994,'furniture-mobile','.b-product-images .additional-horizontal .additional-images img','max-height','100','2876','','.b-product-images'),(483995,'furniture-mobile','.b-product-images .additional-horizontal .additional-images video','max-height','100','2876','','.b-product-images'),(483996,'furniture-mobile','.w-sale-category .image img','max-height','300','','','.w-sale-category'),(483997,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .image img','max-height','80','','','.w-predefined-promotion'),(483998,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .image img','max-height','80','','','.w-predefined-promotion'),(483999,'furniture-mobile','.w-predefined-promotion .promo-salemaker .image img','max-height','80','','','.w-predefined-promotion'),(484000,'furniture-mobile','.w-search .image','max-height','80','','','.w-search'),(484001,'furniture-mobile','.w-search .suggest','max-height','500','','','.w-search'),(484002,'furniture-mobile','.b-product-images .additional-horizontal .additional-images img','max-height_important','important','','','.b-product-images'),(484003,'furniture-mobile','.b-product-images .additional-horizontal .additional-images video','max-height_important','important','','','.b-product-images'),(484004,'furniture-mobile','.b-product-images .additional-horizontal .additional-images img','max-height_important','important','2876','','.b-product-images'),(484005,'furniture-mobile','.b-product-images .additional-horizontal .additional-images video','max-height_important','important','2876','','.b-product-images'),(484006,'furniture-mobile','.w-checkout-guest-btn .btn-2','max-width','100','','','.w-checkout-guest-btn'),(484007,'furniture-mobile','.p-blog-index .post-thumbnail','max-width','40','','','.p-blog-index'),(484008,'furniture-mobile','.w-product-images-additional .item-img','max-width','70','2906','','.w-product-images-additional'),(484009,'furniture-mobile','.w-promotions .heading-3','max-width','calc(100% - 100px)','','','.w-promotions'),(484010,'furniture-mobile','.w-promotions .promo-salemaker .item','max-width','calc(50% - 4px)','','','.w-promotions'),(484011,'furniture-mobile','.w-promotions .promo-cart-discount .slave .item','max-width','calc(50% - 4px)','','','.w-promotions'),(484012,'furniture-mobile','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(484013,'furniture-mobile','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(484014,'furniture-mobile','.p-blog-index .avatar','max-width','28','','','.p-blog-index'),(484015,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-width','100','','','.w-upload-customer-id-upload-customer-id-form'),(484016,'furniture-mobile','.p-blog-index .avatar','max-width','28','','','.p-blog-index'),(484017,'furniture-mobile','.p-blog-index .avatar','max-width','28','','','.p-blog-index'),(484018,'furniture-mobile','.b-fancybox .fancybox-tmp','max-width','99999','','','.b-fancybox'),(484019,'furniture-mobile','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(484020,'furniture-mobile','.w-product-images-additional .item-img','max-width','70','2906','','.w-product-images-additional'),(484021,'furniture-mobile','.p-blog-index .post-thumbnail','max-width','40','','','.p-blog-index'),(484022,'furniture-mobile','.main-width, .type-1 > .block','max-width','1540','','',''),(484023,'furniture-mobile','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(484024,'furniture-mobile','textarea','max-width','100','','',''),(484025,'furniture-mobile','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(484026,'furniture-mobile','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(484027,'furniture-mobile','.w-product-images-additional .item-img','max-width','70','2906','','.w-product-images-additional'),(484028,'furniture-mobile','div.cart-popup','max-width','95','','',''),(484029,'furniture-mobile','.b-form .middle-form','max-width','560','','','.b-form'),(484030,'furniture-mobile','.p-blog-index .avatar','max-width','28','','','.p-blog-index'),(484031,'furniture-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(484032,'furniture-mobile','.w-product-images-additional .item-img','max-width','70','2906','','.w-product-images-additional'),(484033,'furniture-mobile','.w-promotions .promo-cart-discount .master .item','max-width','calc(50% - 24px)','','','.w-promotions'),(484034,'furniture-mobile','.w-menu .hided.menu ul ul','max-width','none','','','.w-menu'),(484035,'furniture-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(484036,'furniture-mobile','.w-menu .hided.menu ul ul','max-width','none','','','.w-menu'),(484037,'furniture-mobile','.w-menu .hided.menu ul ul','max-width','none','','','.w-menu'),(484038,'furniture-mobile','.w-product-images-additional .item-img','max-width','70','2906','','.w-product-images-additional'),(484039,'furniture-mobile','.w-menu .hided.menu ul ul','max-width','none','','','.w-menu'),(484040,'furniture-mobile','.p-blog-index .post-thumbnail','max-width','40','','','.p-blog-index'),(484041,'furniture-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','max-width','1250','','','.w-catalog-b2b-add-button'),(484042,'furniture-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-width','100','','','.b-products-listing'),(484043,'furniture-mobile','.b-products-listing .promo','max-width','30','','','.b-products-listing'),(484044,'furniture-mobile','.b-bottom .terms-info-popup','max-width','95','','','.b-bottom'),(484045,'furniture-mobile','.w-checkout-create-btn .btn-2','max-width','100','','','.w-checkout-create-btn'),(484046,'furniture-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(484047,'furniture-mobile','.b-fancybox .fancybox-image','max-width','100','','','.b-fancybox'),(484048,'furniture-mobile','.p-blog-index .post-thumbnail','max-width','40','','','.p-blog-index'),(484049,'furniture-mobile','.b-bottom .popup-credit-amount .popup-box','max-width','960','','','.b-bottom'),(484050,'furniture-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(484051,'furniture-mobile','.p-blog-index .avatar','max-width','28','','','.p-blog-index'),(484052,'furniture-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(484053,'furniture-mobile','.w-menu .hided.menu ul ul','max-width','none','','','.w-menu'),(484054,'furniture-mobile','.p-blog-index .avatar','max-width','28','','','.p-blog-index'),(484055,'furniture-mobile','.w-product-images-additional .item-img','max-width','70','2906','','.w-product-images-additional'),(484056,'furniture-mobile','.b-email-editor img','max-width','100','','','.b-email-editor'),(484057,'furniture-mobile','.p-blog-index .post-thumbnail','max-width','40','','','.p-blog-index'),(484058,'furniture-mobile','.b-upload-files .attached-block','max-width','300','','','.b-upload-files'),(484059,'furniture-mobile','.w-menu .hided.menu ul ul','max-width','none','','','.w-menu'),(484060,'furniture-mobile','.p-blog-index .post-thumbnail','max-width','40','','','.p-blog-index'),(484061,'furniture-mobile','.w-banner .na-banner','max-width','200','','','.w-banner'),(484062,'furniture-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max-width','100','','','.b-product-images'),(484063,'furniture-mobile','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max-width','100','','','.b-product-images'),(484064,'furniture-mobile','.b-product-images .media-popup .mp-small-images img','max-width','90','','','.b-product-images'),(484065,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max-width','100','','','.b-menu-lev_display-slide'),(484066,'furniture-mobile','.b-trade-approval .middle-form','max-width','560','','','.b-trade-approval'),(484067,'furniture-mobile','.batchPr .w-batch-products .products-listing .image','max-width','100','','','.batchPr'),(484068,'furniture-mobile','.w-login-register .middle-form','max-width','100','','','.w-login-register'),(484069,'furniture-mobile','.w-login-returning .middle-form','max-width','100','','','.w-login-returning'),(484070,'furniture-mobile','.w-catalog-additional-images img','max-width','150','','','.w-catalog-additional-images'),(484071,'furniture-mobile','.b-products-listing .products-listing .radio-attributes img','max-width','30','','','.b-products-listing'),(484072,'furniture-mobile','.w-product-multi-inventory .radio-attributes label img','max-width','23','','','.w-product-multi-inventory'),(484073,'furniture-mobile','.b-products-listing .products-listing .radio-attributes label img','max-width','23','','','.b-products-listing'),(484074,'furniture-mobile','.w-product-attributes .radio-attributes label img','max-width','23','','','.w-product-attributes'),(484075,'furniture-mobile','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img','max-width','100','','','.w-product-groups'),(484076,'furniture-mobile','.w-product-properties-icons .hover-box img','max-width','150','','','.w-product-properties-icons'),(484077,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small .item','max-width','100','','','.w-press-reviews-widgets-press-reviews-small'),(484078,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','max-width','150','','','.b-products-listing'),(484079,'furniture-mobile','.w-predefined-promotion .heading-3','max-width','calc(100% - 100px)','','','.w-predefined-promotion'),(484080,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .item','max-width','calc(50% - 24px)','','','.w-predefined-promotion'),(484081,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .item','max-width','calc(50% - 4px)','','','.w-predefined-promotion'),(484082,'furniture-mobile','.w-predefined-promotion .promo-salemaker .item','max-width','calc(50% - 4px)','','','.w-predefined-promotion'),(484083,'furniture-mobile','.mainBanner .bottomBox','max-width','690','','','.mainBanner'),(484084,'furniture-mobile','.mainBanner .bottomBox .elf','max-width','75','','','.mainBanner'),(484085,'furniture-mobile','.mainBanner > .block','max-width','100','','','.mainBanner'),(484086,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','max-width','220','','','.lowestPricedBox'),(484087,'furniture-mobile','.lowestPricedBox .w-banner .ybg .mark img','max-width','100','','','.lowestPricedBox'),(484088,'furniture-mobile','.lowestPricedBox .w-banner .ybg .mark img','max-width','60','2890','','.lowestPricedBox'),(484089,'furniture-mobile','.lowestPricedBox .w-banner .ybg .mark img','max-width','45','2876','','.lowestPricedBox'),(484090,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','max-width','185','2906','','.lowestPricedBox'),(484091,'furniture-mobile','.w-search .image','max-width','40','','','.w-search'),(484092,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','max-width','600','','','.checkout-index-wrap'),(484093,'furniture-mobile','.mainBanner > .block','max-width_important','important','','','.mainBanner'),(484094,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(484095,'furniture-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(484096,'furniture-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(484097,'furniture-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(484098,'furniture-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(484099,'furniture-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(484100,'furniture-mobile','.b-fancybox .fancybox-image','max_height_measure','%','','','.b-fancybox'),(484101,'furniture-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_height_measure','%','','','.b-products-listing'),(484102,'furniture-mobile','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(484103,'furniture-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max_height_measure','%','','','.b-product-images'),(484104,'furniture-mobile','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max_height_measure','%','','','.b-product-images'),(484105,'furniture-mobile','.b-product-images .media-popup .mp-small-images img','max_height_measure','%','','','.b-product-images'),(484106,'furniture-mobile','.w-product-images img','max_height_measure','%','','','.w-product-images'),(484107,'furniture-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(484108,'furniture-mobile','.p-blog-index .post-thumbnail','max_width_measure','%','','','.p-blog-index'),(484109,'furniture-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(484110,'furniture-mobile','.p-blog-index .post-thumbnail','max_width_measure','%','','','.p-blog-index'),(484111,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(484112,'furniture-mobile','.w-checkout-guest-btn .btn-2','max_width_measure','%','','','.w-checkout-guest-btn'),(484113,'furniture-mobile','.w-checkout-create-btn .btn-2','max_width_measure','%','','','.w-checkout-create-btn'),(484114,'furniture-mobile','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(484115,'furniture-mobile','.p-blog-index .post-thumbnail','max_width_measure','%','','','.p-blog-index'),(484116,'furniture-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(484117,'furniture-mobile','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(484118,'furniture-mobile','textarea','max_width_measure','%','','',''),(484119,'furniture-mobile','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(484120,'furniture-mobile','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(484121,'furniture-mobile','div.cart-popup','max_width_measure','%','','',''),(484122,'furniture-mobile','.p-blog-index .post-thumbnail','max_width_measure','%','','','.p-blog-index'),(484123,'furniture-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(484124,'furniture-mobile','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(484125,'furniture-mobile','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(484126,'furniture-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_width_measure','%','','','.b-products-listing'),(484127,'furniture-mobile','.b-products-listing .promo','max_width_measure','%','','','.b-products-listing'),(484128,'furniture-mobile','.b-bottom .terms-info-popup','max_width_measure','%','','','.b-bottom'),(484129,'furniture-mobile','.b-fancybox .fancybox-image','max_width_measure','%','','','.b-fancybox'),(484130,'furniture-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(484131,'furniture-mobile','.p-blog-index .post-thumbnail','max_width_measure','%','','','.p-blog-index'),(484132,'furniture-mobile','.p-blog-index .post-thumbnail','max_width_measure','%','','','.p-blog-index'),(484133,'furniture-mobile','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(484134,'furniture-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max_width_measure','%','','','.b-product-images'),(484135,'furniture-mobile','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max_width_measure','%','','','.b-product-images'),(484136,'furniture-mobile','.b-product-images .media-popup .mp-small-images img','max_width_measure','%','','','.b-product-images'),(484137,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max_width_measure','vw','','','.b-menu-lev_display-slide'),(484138,'furniture-mobile','.w-login-register .middle-form','max_width_measure','%','','','.w-login-register'),(484139,'furniture-mobile','.w-login-returning .middle-form','max_width_measure','%','','','.w-login-returning'),(484140,'furniture-mobile','.mainBanner > .block','max_width_measure','%','','','.mainBanner'),(484141,'furniture-mobile','.mainBanner > .block','max_width_measure_important','important','','','.mainBanner'),(484142,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','min-height','1','','','.b-select-suggest'),(484143,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','min-height','26','','','.b-select-suggest'),(484144,'furniture-mobile','.b-select-suggest .select2-search input','min-height','26','','','.b-select-suggest'),(484145,'furniture-mobile','.b-select-suggest .select2-search','min-height','26','','','.b-select-suggest'),(484146,'furniture-mobile','.b-select-suggest .select2-drop-mask','min-height','100','','','.b-select-suggest'),(484147,'furniture-mobile','.w-currencies .current','min-height','31','','','.w-currencies'),(484148,'furniture-mobile','.w-languages .current','min-height','31','','','.w-languages'),(484149,'furniture-mobile','.w-cart-listing .item > div','min-height','1','','','.w-cart-listing'),(484150,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1','min-height','35','','','.b-menu-style-1'),(484151,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','min-height','0','','','.batchPr'),(484152,'furniture-mobile','.batchPr .w-batch-selected-products','min-height','0','','','.batchPr'),(484153,'furniture-mobile','.b-slick .slick-slide','min-height','1','','','.b-slick'),(484154,'furniture-mobile','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(484155,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','min-height','40','','','.b-menu-style-1'),(484156,'furniture-mobile','.w-supplier-purchase-supplier-products .qty_col','min-height','40','','','.w-supplier-purchase-supplier-products'),(484157,'furniture-mobile','.mainBanner .bottomBox','min-height','345','','','.mainBanner'),(484158,'furniture-mobile','.mainBanner .bottomBox','min-height','230','2906','','.mainBanner'),(484159,'furniture-mobile','.batchPr .w-batch-products .products-listing .product-holder','min-height_important','important','','','.batchPr'),(484160,'furniture-mobile','.batchPr .w-batch-selected-products','min-height_important','important','','','.batchPr'),(484161,'furniture-mobile','.w-communication-new-topic #communication_group_holder table','min-width','800','','','.w-communication-new-topic'),(484162,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.p-quick-order-index'),(484163,'furniture-mobile','.p-quick-order-index .al_incart, .p-quick-order-index .al-incart','min-width','60','','','.p-quick-order-index'),(484164,'furniture-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(484165,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.p-quick-order-index'),(484166,'furniture-mobile','.w-catalog-paging .prev','min-width','35','','','.w-catalog-paging'),(484167,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','min-width','150','','','.w-menu-style-1'),(484168,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','min-width','150','','','.w-menu-horizontal'),(484169,'furniture-mobile','.w-communication-post .btn-submit','min-width','200','','','.w-communication-post'),(484170,'furniture-mobile','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','min-width','70','','','.b-form'),(484171,'furniture-mobile','.w-catalog-paging .prev-pages','min-width','35','','','.w-catalog-paging'),(484172,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','min-width','150','','','.w-menu-style-1'),(484173,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li ul','min-width','150','','','.w-menu-style-1'),(484174,'furniture-mobile','.b-bottom .popup-box.popupCompare','min-width','800','','','.b-bottom'),(484175,'furniture-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(484176,'furniture-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(484177,'furniture-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(484178,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li ul','min-width','150','','','.w-menu-style-1'),(484179,'furniture-mobile','.w-catalog-paging .next-pages','min-width','35','','','.w-catalog-paging'),(484180,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li ul','min-width','150','','','.w-menu-style-1'),(484181,'furniture-mobile','.b-bottom .confirm-popup .buttons .btn','min-width','120','','','.b-bottom'),(484182,'furniture-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(484183,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','min-width','150','','','.w-menu-style-1'),(484184,'furniture-mobile','.b-select-suggest .select2-drop-mask','min-width','100','','','.b-select-suggest'),(484185,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li','min-width','150','','','.w-menu-horizontal'),(484186,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','min-width','150','','','.w-menu-style-1'),(484187,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li ul','min-width','150','','','.w-menu-style-1'),(484188,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.b-data-table'),(484189,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.b-data-table'),(484190,'furniture-mobile','.w-catalog-paging .next','min-width','35','','','.w-catalog-paging'),(484191,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li ul','min-width','150','','','.w-menu-style-1'),(484192,'furniture-mobile','.w-communication-new-topic .quantity','min-width','70','','','.w-communication-new-topic'),(484193,'furniture-mobile','.w-communication-new-topic #communication_group_holder table table','min-width','0','','','.w-communication-new-topic'),(484194,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','min-width','150','','','.w-menu-style-1'),(484195,'furniture-mobile','.w-catalog-paging .page-number','min-width','35','','','.w-catalog-paging'),(484196,'furniture-mobile','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(484197,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li ul','min-width','150','','','.w-menu-style-1'),(484198,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','min-width','150','','','.w-menu-style-1'),(484199,'furniture-mobile','.w-catalog-paging ','min-width','35','2','','.w-catalog-paging'),(484200,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','min-width','200','','','.b-menu-lev_display-down'),(484201,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','min-width','200','','','.b-menu-lev_display-down'),(484202,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','min-width','200','','','.b-menu-lev_display-down'),(484203,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','min-width','200','','','.b-menu-lev_display-down'),(484204,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','min-width','200','','','.b-menu-lev_display-down'),(484205,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','min-width','200','','','.b-menu-lev_display-left'),(484206,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','min-width','200','','','.b-menu-lev_display-left'),(484207,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','min-width','200','','','.b-menu-lev_display-left'),(484208,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','min-width','200','','','.b-menu-lev_display-left'),(484209,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','min-width','200','','','.b-menu-lev_display-left'),(484210,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','min-width','200','','','.b-menu-lev_display-lra'),(484211,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','min-width','200','','','.b-menu-lev_display-lra'),(484212,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','min-width','200','','','.b-menu-lev_display-lra'),(484213,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','min-width','200','','','.b-menu-lev_display-lra'),(484214,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','min-width','200','','','.b-menu-lev_display-lra'),(484215,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','min-width','200','','','.b-menu-lev_display-right'),(484216,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','min-width','200','','','.b-menu-lev_display-right'),(484217,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','min-width','200','','','.b-menu-lev_display-right'),(484218,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','min-width','200','','','.b-menu-lev_display-right'),(484219,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','min-width','200','','','.b-menu-lev_display-right'),(484220,'furniture-mobile','.w-cart .no-text','min-width','120','','','.w-cart'),(484221,'furniture-mobile','.w-account .no-text','min-width','120','','','.w-account'),(484222,'furniture-mobile','.w-quote .no-text','min-width','120','','','.w-quote'),(484223,'furniture-mobile','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(484224,'furniture-mobile','.w-sample .no-text','min-width','120','','','.w-sample'),(484225,'furniture-mobile','.b-pagination .pagination .next-pages','min-width','30','','','.b-pagination'),(484226,'furniture-mobile','.b-pagination .pagination .page-number','min-width','30','','','.b-pagination'),(484227,'furniture-mobile','.b-pagination .pagination .prev-pages','min-width','30','','','.b-pagination'),(484228,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','min-width','30','','','.b-pagination'),(484229,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','min-width','30','','','.b-pagination'),(484230,'furniture-mobile','.b-pagination .pagination span','min-width','30','2','','.b-pagination'),(484231,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','min-width','30','','','.w-wedding-registry-widgets-search-paging'),(484232,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','min-width','30','','','.w-wedding-registry-widgets-search-paging'),(484233,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','min-width','30','','','.w-wedding-registry-widgets-search-paging'),(484234,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','min-width','30','','','.w-wedding-registry-widgets-search-paging'),(484235,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','min_height_measure','em','','','.b-select-suggest'),(484236,'furniture-mobile','.b-select-suggest .select2-drop-mask','min_height_measure','%','','','.b-select-suggest'),(484237,'furniture-mobile','.b-select-suggest .select2-drop-mask','min_width_measure','%','','','.b-select-suggest'),(484238,'furniture-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','opacity','0','','','.b-switch'),(484239,'furniture-mobile','.p-quick-order-index .paginate_button.next.disabled','opacity','0.3','3','','.p-quick-order-index'),(484240,'furniture-mobile','.p-quick-order-index .paginate_button.previous.disabled','opacity','0.3','3','','.p-quick-order-index'),(484241,'furniture-mobile','.b-fancybox #fancybox-loading','opacity','0.8','','','.b-fancybox'),(484242,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','opacity','0.5','','','.b-switch'),(484243,'furniture-mobile','.b-form .hide-billing-address','opacity','0.7','','','.b-form'),(484244,'furniture-mobile','.disabled-area','opacity','0.5','','',''),(484245,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled.readonly','opacity','0.7','','','.b-switch'),(484246,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled','opacity','0.4','','','.b-switch'),(484247,'furniture-mobile','.b-form .checkbox-style','opacity','0','','','.b-form'),(484248,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','opacity','0.5','','','.b-switch'),(484249,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','opacity','0.5','','','.b-switch'),(484250,'furniture-mobile','.b-select-suggest .select2-drop-mask','opacity','0','','','.b-select-suggest'),(484251,'furniture-mobile','.b-products-listing .products-listing .qty-input.hidden','opacity','0.7','3','','.b-products-listing'),(484252,'furniture-mobile','.b-form .required-message','opacity','0.5','1','','.b-form'),(484253,'furniture-mobile','.w-catalog-paging .paging span.prev, .w-catalog-paging .paging span.next','opacity','0.3','','','.w-catalog-paging'),(484254,'furniture-mobile','.w-filters .input-checkbox','opacity','0','','','.w-filters'),(484255,'furniture-mobile','.b-slick button.slick-disabled','opacity','0.3','','','.b-slick'),(484256,'furniture-mobile','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(484257,'furniture-mobile','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(484258,'furniture-mobile','.b-pagination .pagination .paging span.prev, .b-pagination .pagination .paging span.next','opacity','0.3','','','.b-pagination'),(484259,'furniture-mobile','.w-product-groups .radioBox label input','opacity','0','','','.w-product-groups'),(484260,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li.disabled','opacity','0.3','','','.w-wedding-registry-widgets-search-paging'),(484261,'furniture-mobile','.w-product-designer-designer .productDesignerBox input','opacity','0','','','.w-product-designer-designer'),(484262,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','opacity','0','','','.w-filters'),(484263,'furniture-mobile','.account-order-history-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-order-history-info'),(484264,'furniture-mobile','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-order-pay'),(484265,'furniture-mobile','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-sample-info'),(484266,'furniture-mobile','.w-promotions .promo-cart-discount .slave .heading','order','1','','','.w-promotions'),(484267,'furniture-mobile','.w-promotions .promo-cart-discount .slave .content','order','3','','','.w-promotions'),(484268,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition','order','2','','','.w-promotions'),(484269,'furniture-mobile','.w-cart-gift-certificate .input-apple .btn','order','2','','','.w-cart-gift-certificate'),(484270,'furniture-mobile','.w-cart-gift-certificate .input-apple div','order','1','','','.w-cart-gift-certificate'),(484271,'furniture-mobile','.w-cart-order-reference .input-apple div','order','1','','','.w-cart-order-reference'),(484272,'furniture-mobile','.w-cart-order-reference .input-apple button','order','2','','','.w-cart-order-reference'),(484273,'furniture-mobile','.w-account-address-book .add_item','order','100','','','.w-account-address-book'),(484274,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .date-added','order','4','','','.w-press-reviews-widgets-press-reviews-list'),(484275,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .description','order','5','','','.w-press-reviews-widgets-press-reviews-list'),(484276,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .image','order','1','','','.w-press-reviews-widgets-press-reviews-list'),(484277,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .out-link','order','6','','','.w-press-reviews-widgets-press-reviews-list'),(484278,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .rating','order','2','','','.w-press-reviews-widgets-press-reviews-list'),(484279,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .short-description','order','3','','','.w-press-reviews-widgets-press-reviews-list'),(484280,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition','order','2','','','.w-predefined-promotion'),(484281,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .content','order','3','','','.w-predefined-promotion'),(484282,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .heading','order','1','','','.w-predefined-promotion'),(484283,'furniture-mobile','.w-search .products','order','2','','','.w-search'),(484284,'furniture-mobile','.w-search .wrap','order','3','','','.w-search'),(484285,'furniture-mobile','.w-search .history','order','1','','','.w-search'),(484286,'furniture-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','outline','none','','','.b-fancybox'),(484287,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','outline','0','','','.b-select-suggest'),(484288,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-focused','outline','0','','','.b-switch'),(484289,'furniture-mobile','.b-select-suggest .select2-search-choice-close','outline','none','','','.b-select-suggest'),(484290,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','outline','0','','','.b-select-suggest'),(484291,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(484292,'furniture-mobile','.b-select-suggest .select2-container-active .select2-choice, .b-select-suggest .select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(484293,'furniture-mobile','.b-select-suggest .select2-search input','outline','0','','','.b-select-suggest'),(484294,'furniture-mobile','input:focus','outline','none','','',''),(484295,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline','0','','','.b-select-suggest'),(484296,'furniture-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','outline','none','','','.b-fancybox'),(484297,'furniture-mobile','.b-product-images .media-popup .mp-big-images .item','outline','none','','','.b-product-images'),(484298,'furniture-mobile','.b-product-images .media-popup .mp-small-images .item','outline','none','','','.b-product-images'),(484299,'furniture-mobile','.batchPr .products-listing .item','outline','none','','','.batchPr'),(484300,'furniture-mobile','.b-slick .slick-list:focus','outline','none','','','.b-slick'),(484301,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline_important','important','','','.b-select-suggest'),(484302,'furniture-mobile','.w-communication-new-topic #communication_group_holder','overflow','auto','','','.w-communication-new-topic'),(484303,'furniture-mobile','.b-form .shipping-method .sub-title','overflow','hidden','','','.b-form'),(484304,'furniture-mobile','.p-reviews-info .review-info-head','overflow','hidden','','','.p-reviews-info'),(484305,'furniture-mobile','.p-blog-index .nav-links','overflow','hidden','','','.p-blog-index'),(484306,'furniture-mobile','.p-quick-order-index .top','overflow','hidden','','','.p-quick-order-index'),(484307,'furniture-mobile','.p-reviews-info .review-info-head','overflow','hidden','','','.p-reviews-info'),(484308,'furniture-mobile','.p-blog-index .nav-links','overflow','hidden','','','.p-blog-index'),(484309,'furniture-mobile','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','overflow','hidden','','','.w-promotions'),(484310,'furniture-mobile','.w-cart-compare .product .name','overflow','hidden','','','.w-cart-compare'),(484311,'furniture-mobile','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(484312,'furniture-mobile','.p-reviews-info .review-info-head','overflow','hidden','','','.p-reviews-info'),(484313,'furniture-mobile','.p-account-trade-form .widget','overflow','hidden','','','.p-account-trade-form'),(484314,'furniture-mobile','.p-account-trade-form .widget','overflow','hidden','','','.p-account-trade-form'),(484315,'furniture-mobile','.b-switch .bootstrap-switch','overflow','hidden','','','.b-switch'),(484316,'furniture-mobile','.b-fancybox .fancybox-lock .fancybox-overlay','overflow','auto','','','.b-fancybox'),(484317,'furniture-mobile','.p-account-trade-form .widget','overflow','hidden','','','.p-account-trade-form'),(484318,'furniture-mobile','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(484319,'furniture-mobile','.w-sale .left','overflow','hidden','','','.w-sale'),(484320,'furniture-mobile','.b-select-suggest .select2-measure-scrollbar','overflow','scroll','','','.b-select-suggest'),(484321,'furniture-mobile','.b-fancybox .fancybox-tmp','overflow','visible','','','.b-fancybox'),(484322,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow','hidden','','','.b-select-suggest'),(484323,'furniture-mobile','.p-quick-order-index .bottom','overflow','hidden','','','.p-quick-order-index'),(484324,'furniture-mobile','.w-cart-listing .right-area','overflow','hidden','2885','','.w-cart-listing'),(484325,'furniture-mobile','.p-blog-index .nav-links','overflow','hidden','','','.p-blog-index'),(484326,'furniture-mobile','.w-search .suggest','overflow','auto','','','.w-search'),(484327,'furniture-mobile','.w-sale .sale-holder','overflow','hidden','','','.w-sale'),(484328,'furniture-mobile','.w-sale .left','overflow','hidden','','','.w-sale'),(484329,'furniture-mobile','.b-fancybox .fancybox-inner','overflow','hidden','','','.b-fancybox'),(484330,'furniture-mobile','.b-fancybox .fancybox-lock','overflow','hidden','','','.b-fancybox'),(484331,'furniture-mobile','.b-fancybox .fancybox-overlay','overflow','hidden','','','.b-fancybox'),(484332,'furniture-mobile','.w-sale .sale-holder','overflow','hidden','','','.w-sale'),(484333,'furniture-mobile','.p-account-trade-form .widget','overflow','hidden','','','.p-account-trade-form'),(484334,'furniture-mobile','.p-reviews-info .review-info-head','overflow','hidden','','','.p-reviews-info'),(484335,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','overflow','hidden','','','.b-select-suggest'),(484336,'furniture-mobile','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(484337,'furniture-mobile','.p-blog-index .nav-links','overflow','hidden','','','.p-blog-index'),(484338,'furniture-mobile','.b-bottom .cart-options .options','overflow','hidden','','','.b-bottom'),(484339,'furniture-mobile','.w-sale .left','overflow','hidden','','','.w-sale'),(484340,'furniture-mobile','.b-autocomplete .ui-autocomplete','overflow','auto','','','.b-autocomplete'),(484341,'furniture-mobile','.b-upload-files .attach-active-holder','overflow','hidden','','','.b-upload-files'),(484342,'furniture-mobile','.b-upload-files .added-file','overflow','hidden','','','.b-upload-files'),(484343,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','overflow','hidden','','','.w-wedding-registry-widgets-photos'),(484344,'furniture-mobile','.b-fancybox .fancybox-lock body','overflow','hidden','','','.b-fancybox'),(484345,'furniture-mobile','.w-checkout-shipping-choice input','overflow','hidden','','','.w-checkout-shipping-choice'),(484346,'furniture-mobile','.w-checkout-shipping-choice #shippingchoice-choice','overflow','hidden','','','.w-checkout-shipping-choice'),(484347,'furniture-mobile','.w-sale .sale-holder','overflow','hidden','','','.w-sale'),(484348,'furniture-mobile','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(484349,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','overflow','hidden','','','.b-select-suggest'),(484350,'furniture-mobile','.b-preloader .preloader','overflow','hidden','3','','.b-preloader'),(484351,'furniture-mobile','.p-reviews-info .review-info-head','overflow','hidden','','','.p-reviews-info'),(484352,'furniture-mobile','.p-reviews-info .review-info-head','overflow','hidden','','','.p-reviews-info'),(484353,'furniture-mobile','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(484354,'furniture-mobile','.w-sale .sale-holder','overflow','hidden','','','.w-sale'),(484355,'furniture-mobile','.w-sale .left','overflow','hidden','','','.w-sale'),(484356,'furniture-mobile','.w-account-addresses-list ','overflow','hidden','','','.w-account-addresses-list'),(484357,'furniture-mobile','.b-products-listing .btn-preloader','overflow','hidden','3','','.b-products-listing'),(484358,'furniture-mobile','.b-products-listing .loader','overflow','hidden','4','','.b-products-listing'),(484359,'furniture-mobile','.w-blog-widget-related-posts-by-category ','overflow','hidden','','','.w-blog-widget-related-posts-by-category'),(484360,'furniture-mobile','.w-blog-widget-related-posts ','overflow','hidden','','','.w-blog-widget-related-posts'),(484361,'furniture-mobile','.w-blog-widget-post-linked-products .heading-2','overflow','hidden','','','.w-blog-widget-post-linked-products'),(484362,'furniture-mobile','.w-sale .left','overflow','hidden','','','.w-sale'),(484363,'furniture-mobile','.b-compare .compare-box-item','overflow','hidden','','','.b-compare'),(484364,'furniture-mobile','.w-search .item','overflow','hidden','','','.w-search'),(484365,'furniture-mobile','.p-account-trade-form .widget','overflow','hidden','','','.p-account-trade-form'),(484366,'furniture-mobile','.b-form .payment-method .item-radio label span','overflow','hidden','','','.b-form'),(484367,'furniture-mobile','.w-quote .no-text','overflow','hidden','','','.w-quote'),(484368,'furniture-mobile','.w-sale .left','overflow','hidden','','','.w-sale'),(484369,'furniture-mobile','.w-sale .sale-holder','overflow','hidden','','','.w-sale'),(484370,'furniture-mobile','.b-compare .col-two','overflow','hidden','','','.b-compare'),(484371,'furniture-mobile','.w-cart-give-away .ga_ovr','overflow','hidden','','','.w-cart-give-away'),(484372,'furniture-mobile','.w-cart-give-away .ga_wrapper','overflow','hidden','','','.w-cart-give-away'),(484373,'furniture-mobile','.w-cart .sub-total-row','overflow','hidden','','','.w-cart'),(484374,'furniture-mobile','.w-cart .no-text','overflow','hidden','','','.w-cart'),(484375,'furniture-mobile','.w-cart .multicart .sub-total-row','overflow','hidden','','','.w-cart'),(484376,'furniture-mobile','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(484377,'furniture-mobile','.w-sale .sale-holder','overflow','hidden','','','.w-sale'),(484378,'furniture-mobile','.w-cart-shipping-estimator .item .row','overflow','hidden','','','.w-cart-shipping-estimator'),(484379,'furniture-mobile','.w-catalog-paging .paging-holder.slick-slider','overflow','visible','','','.w-catalog-paging'),(484380,'furniture-mobile','.w-catalog-paging .paging-holder','overflow','hidden','','','.w-catalog-paging'),(484381,'furniture-mobile','.p-blog-index .nav-links','overflow','hidden','','','.p-blog-index'),(484382,'furniture-mobile','.p-account-trade-form .widget','overflow','hidden','','','.p-account-trade-form'),(484383,'furniture-mobile','.b-upload-files .attached-block','overflow','hidden','','','.b-upload-files'),(484384,'furniture-mobile','.b-upload-files .attach-block','overflow','hidden','','','.b-upload-files'),(484385,'furniture-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','overflow','hidden','','','.b-select-suggest'),(484386,'furniture-mobile','.p-blog-index .nav-links','overflow','hidden','','','.p-blog-index'),(484387,'furniture-mobile','.w-banner .banner .image-box','overflow','hidden','','','.w-banner'),(484388,'furniture-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','overflow','hidden','','','.b-menu-burger_icon'),(484389,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','overflow','auto','','','.b-menu-lev_display-width'),(484390,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','overflow','auto','','','.b-menu-lev_display-width'),(484391,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','overflow','auto','','','.b-menu-lev_display-width'),(484392,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','overflow','auto','','','.b-menu-lev_display-width'),(484393,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','overflow','auto','','','.b-menu-lev_display-width'),(484394,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','overflow','auto','','','.b-menu-lev_display-width_cont'),(484395,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','overflow','auto','','','.b-menu-lev_display-width_cont'),(484396,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','overflow','auto','','','.b-menu-lev_display-width_cont'),(484397,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','overflow','auto','','','.b-menu-lev_display-width_cont'),(484398,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','overflow','auto','','','.b-menu-lev_display-width_cont'),(484399,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','overflow','auto','','','.b-menu-open_from-left'),(484400,'furniture-mobile','.b-trade-approval .steps-bar','overflow','hidden','','','.b-trade-approval'),(484401,'furniture-mobile','.batchPr .w-batch-products .products-listing .image + .type-1','overflow','hidden','','','.batchPr'),(484402,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','overflow','hidden','','','.batchPr'),(484403,'furniture-mobile','.batchPr .batch-selected-products-list','overflow','auto','','','.batchPr'),(484404,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(2)','overflow','hidden','','','.batchPr'),(484405,'furniture-mobile','.w-catalog-compare .compare','overflow','hidden','','','.w-catalog-compare'),(484406,'furniture-mobile','.w-delivery-day .time-left','overflow','hidden','','','.w-delivery-day'),(484407,'furniture-mobile','.w-product-images .slick-vertical + .produst-image','overflow','hidden','','','.w-product-images'),(484408,'furniture-mobile','.b-slick .slick-list','overflow','hidden','','','.b-slick'),(484409,'furniture-mobile','.w-quote .multicart .sub-total-row','overflow','hidden','','','.w-quote'),(484410,'furniture-mobile','.w-quote .sub-total-row','overflow','hidden','','','.w-quote'),(484411,'furniture-mobile','h1, .heading-1','overflow','hidden','','',''),(484412,'furniture-mobile','.w-product-sale-ends .left','overflow','hidden','','','.w-product-sale-ends'),(484413,'furniture-mobile','.heading-2, h2, .h-block h2','overflow','hidden','','',''),(484414,'furniture-mobile','.w-compare .compare-list-holder','overflow','hidden','','','.w-compare'),(484415,'furniture-mobile','.w-compare .item-holder','overflow','hidden','','','.w-compare'),(484416,'furniture-mobile','.w-sample .multicart .sub-total-row','overflow','hidden','','','.w-sample'),(484417,'furniture-mobile','.w-sample .no-text','overflow','hidden','','','.w-sample'),(484418,'furniture-mobile','.w-sample .sub-total-row','overflow','hidden','','','.w-sample'),(484419,'furniture-mobile','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(484420,'furniture-mobile','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(484421,'furniture-mobile','.w-product-bundle .bundle_item','overflow','hidden','','','.w-product-bundle'),(484422,'furniture-mobile','.w-product-in-bundles .bundle_item','overflow','hidden','','','.w-product-in-bundles'),(484423,'furniture-mobile','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(484424,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','overflow','hidden','','','.w-account-personal-catalog'),(484425,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','overflow','visible','1','','.w-account-personal-catalog'),(484426,'furniture-mobile','.w-product-groups .radioBox','overflow','hidden','','','.w-product-groups'),(484427,'furniture-mobile','.w-sale-category .left','overflow','hidden','','','.w-sale-category'),(484428,'furniture-mobile','.w-sale-category .sale-holder','overflow','hidden','','','.w-sale-category'),(484429,'furniture-mobile','.w-gift-wrap-message-checkout ','overflow','hidden','','','.w-gift-wrap-message-checkout'),(484430,'furniture-mobile','.w-support-system-listing .support-head','overflow','hidden','','','.w-support-system-listing'),(484431,'furniture-mobile','.w-rma-returns-history .content-messages .messages-table .top','overflow','hidden','','','.w-rma-returns-history'),(484432,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','overflow','hidden','','','.w-predefined-promotion'),(484433,'furniture-mobile','.account-address-book .buttonBox','overflow','hidden','','','.account-address-book'),(484434,'furniture-mobile','.account-order-history-info .history_info','overflow','hidden','','','.account-order-history-info'),(484435,'furniture-mobile','.account-index .account_page','overflow','hidden','','','.account-index'),(484436,'furniture-mobile','.account-index .acount_row','overflow','hidden','','','.account-index'),(484437,'furniture-mobile','.account-index .topAccount','overflow','hidden','','','.account-index'),(484438,'furniture-mobile','.account-order-pay .history_info','overflow','hidden','','','.account-order-pay'),(484439,'furniture-mobile','.account-sample-info .history_info','overflow','hidden','','','.account-sample-info'),(484440,'furniture-mobile','.b-compare .compare_list','overflow-x','hidden','','','.b-compare'),(484441,'furniture-mobile','.b-select-suggest .select2-results','overflow-x','hidden','','','.b-select-suggest'),(484442,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-x','hidden','','','.b-menu-lev_display-slide'),(484443,'furniture-mobile','.b-compare .compare_list','overflow-y','auto','','','.b-compare'),(484444,'furniture-mobile','.b-fancybox .fancybox-lock .fancybox-overlay','overflow-y','scroll','','','.b-fancybox'),(484445,'furniture-mobile','.b-fancybox .fancybox-lock-test','overflow-y','hidden','','','.b-fancybox'),(484446,'furniture-mobile','.b-select-suggest .select2-results','overflow-y','auto','','','.b-select-suggest'),(484447,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-y','auto','','','.b-menu-lev_display-slide'),(484448,'furniture-mobile','.b-fancybox .fancybox-lock-test','overflow-y_important','important','','','.b-fancybox'),(484449,'furniture-mobile','.b-fancybox .fancybox-lock','overflow_important','important','','','.b-fancybox'),(484450,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow_important','important','','','.b-select-suggest'),(484451,'furniture-mobile','.b-fancybox .fancybox-tmp','overflow_important','important','','','.b-fancybox'),(484452,'furniture-mobile','.b-fancybox .fancybox-lock body','overflow_important','important','','','.b-fancybox'),(484453,'furniture-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-bottom','10','','','.w-communication-new-topic'),(484454,'furniture-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(484455,'furniture-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(484456,'furniture-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(484457,'furniture-mobile','.b-table .table td','padding-bottom','15','','','.b-table'),(484458,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-bottom','10','','','.p-account-subscription-historyinfo'),(484459,'furniture-mobile','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(484460,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(484461,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(484462,'furniture-mobile','.p-blog-index .comment-list','padding-bottom','30','','','.p-blog-index'),(484463,'furniture-mobile','.w-product-images-additional .images','padding-bottom','20','2906','','.w-product-images-additional'),(484464,'furniture-mobile','.w-cart .multicart .cart-content','padding-bottom','0','','','.w-cart'),(484465,'furniture-mobile','.w-cart a.item','padding-bottom','5','','','.w-cart'),(484466,'furniture-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(484467,'furniture-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(484468,'furniture-mobile','.p-quick-order-index ul.token-input-list','padding-bottom','0','','','.p-quick-order-index'),(484469,'furniture-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-bottom','7','','','.p-quick-order-index'),(484470,'furniture-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-bottom','8','','','.p-quick-order-index'),(484471,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.p-quick-order-index'),(484472,'furniture-mobile','.w-promotions .promo-item','padding-bottom','20','','','.w-promotions'),(484473,'furniture-mobile','.w-top-categories h2.name','padding-bottom','3','','','.w-top-categories'),(484474,'furniture-mobile','.w-sale .left-text-left','padding-bottom','24','','','.w-sale'),(484475,'furniture-mobile','.p-blog-index .nav-links','padding-bottom','20','','','.p-blog-index'),(484476,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-bottom','0','','','.p-blog-index'),(484477,'furniture-mobile','.w-cart-compare .attributes-label','padding-bottom','10','','','.w-cart-compare'),(484478,'furniture-mobile','.w-account .acc-returning','padding-bottom','0','','','.w-account'),(484479,'furniture-mobile','.w-account .acc-top','padding-bottom','10','','','.w-account'),(484480,'furniture-mobile','.w-account .account-top','padding-bottom','0','','','.w-account'),(484481,'furniture-mobile','.w-account .account-dropdown','padding-bottom','15','','','.w-account'),(484482,'furniture-mobile','.w-account .f-pass','padding-bottom','6','','','.w-account'),(484483,'furniture-mobile','.w-account .my-acc-link','padding-bottom','0','','','.w-account'),(484484,'furniture-mobile','.w-personal-gift-status-bar .start-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(484485,'furniture-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(484486,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-bottom','20','','','.p-reviews-info'),(484487,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(484488,'furniture-mobile','.p-reviews-info .review-info-text','padding-bottom','10','','','.p-reviews-info'),(484489,'furniture-mobile','.p-reviews-info .review-info-image','padding-bottom','20','','','.p-reviews-info'),(484490,'furniture-mobile','.p-reviews-info .review-info-content','padding-bottom','20','','','.p-reviews-info'),(484491,'furniture-mobile','.p-blog-index .wp-widget ul','padding-bottom','0','','','.p-blog-index'),(484492,'furniture-mobile','.p-blog-index .nav-links','padding-bottom','20','','','.p-blog-index'),(484493,'furniture-mobile','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(484494,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(484495,'furniture-mobile','.testimonials .review','padding-bottom','10','','',''),(484496,'furniture-mobile','.testimonials .heading-3','padding-bottom','10','','',''),(484497,'furniture-mobile','.testimonials .reviews-list .name','padding-bottom','5','','',''),(484498,'furniture-mobile','.testimonials .name','padding-bottom','5','','',''),(484499,'furniture-mobile','.w-categories .image','padding-bottom','75','','','.w-categories'),(484500,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','padding-bottom','0','','','.w-promotions'),(484501,'furniture-mobile','.w-promotions .prom-multi-discount .promo-product','padding-bottom','20','','','.w-promotions'),(484502,'furniture-mobile','.w-promotions .nextdiscount .promo-for-each','padding-bottom','2','','','.w-promotions'),(484503,'furniture-mobile','.w-promotions .nextdiscount .content > div','padding-bottom','10','','','.w-promotions'),(484504,'furniture-mobile','.w-catalog-paging .paging-item','padding-bottom','0','','','.w-catalog-paging'),(484505,'furniture-mobile','.w-promotions .promo-salemaker .item','padding-bottom','20','','','.w-promotions'),(484506,'furniture-mobile','.w-promotions .promo-salemaker .discount','padding-bottom','0','','','.w-promotions'),(484507,'furniture-mobile','.w-promotions .promo-cart-discount .slave .item','padding-bottom','20','','','.w-promotions'),(484508,'furniture-mobile','.w-promotions .promo-cart-discount .slave .heading','padding-bottom','1','','','.w-promotions'),(484509,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-bottom','0','','','.w-promotions'),(484510,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-bottom','0','','','.w-promotions'),(484511,'furniture-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-bottom','20','','','.b-warehouses-popup'),(484512,'furniture-mobile','.w-product-available-in-warehouses .warehouse-item','padding-bottom','20','','','.w-product-available-in-warehouses'),(484513,'furniture-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-bottom','6','','','.b-products-listing'),(484514,'furniture-mobile','.w-account .acc-new','padding-bottom','0','','','.w-account'),(484515,'furniture-mobile','.w-menu-slider > ul > li > a','padding-bottom','5','','','.w-menu-slider'),(484516,'furniture-mobile','.w-cart-compare .attributes-cell','padding-bottom','8','','','.w-cart-compare'),(484517,'furniture-mobile','.p-reviews-info .review-info-image','padding-bottom','20','','','.p-reviews-info'),(484518,'furniture-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(484519,'furniture-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(484520,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-bottom','20','','','.p-reviews-info'),(484521,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-bottom','0','','','.p-blog-index'),(484522,'furniture-mobile','.p-blog-index .wp-widget li','padding-bottom','10','','','.p-blog-index'),(484523,'furniture-mobile','.b-bottom .confirm-popup .confirm-text','padding-bottom','30','','','.b-bottom'),(484524,'furniture-mobile','.b-messages .msv_btn','padding-bottom','12','','','.b-messages'),(484525,'furniture-mobile','.b-messages .msv_content','padding-bottom','10','','','.b-messages'),(484526,'furniture-mobile','.b-messages .msv_history','padding-bottom','10','','','.b-messages'),(484527,'furniture-mobile','.b-messages .messMenuButton span','padding-bottom','10','','','.b-messages'),(484528,'furniture-mobile','.b-messages .messages-menu li a','padding-bottom','8','','','.b-messages'),(484529,'furniture-mobile','.b-messages .messages-menu li','padding-bottom','0','','','.b-messages'),(484530,'furniture-mobile','.b-messages .messages-menu ul','padding-bottom','0','','','.b-messages'),(484531,'furniture-mobile','.b-messages .content_management_attach button','padding-bottom','1','','','.b-messages'),(484532,'furniture-mobile','.b-messages .email-heading','padding-bottom','15','','','.b-messages'),(484533,'furniture-mobile','.b-messages .content_management_attach','padding-bottom','8','','','.b-messages'),(484534,'furniture-mobile','.b-messages .emailLineTextArea textarea','padding-bottom','30','','','.b-messages'),(484535,'furniture-mobile','.b-messages .msv_to_cc','padding-bottom','10','','','.b-messages'),(484536,'furniture-mobile','.b-messages .emailBtn','padding-bottom','10','','','.b-messages'),(484537,'furniture-mobile','.b-messages .dataTables_wrapper > .bottom','padding-bottom','4','','','.b-messages'),(484538,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-bottom','5','','','.b-messages'),(484539,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-bottom','6','','',''),(484540,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(484541,'furniture-mobile','.w-search .items-title','padding-bottom','5','','','.w-search'),(484542,'furniture-mobile','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(484543,'furniture-mobile','.w-reviews-content .item','padding-bottom','25','','','.w-reviews-content'),(484544,'furniture-mobile','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(484545,'furniture-mobile','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(484546,'furniture-mobile','.w-sitemap-delivery-location > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(484547,'furniture-mobile','.w-checkout-terms .required-message','padding-bottom','5','','','.w-checkout-terms'),(484548,'furniture-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(484549,'furniture-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(484550,'furniture-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(484551,'furniture-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(484552,'furniture-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(484553,'furniture-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(484554,'furniture-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(484555,'furniture-mobile','.w-checkout-shipping-address .edit-ab','padding-bottom','0','','','.w-checkout-shipping-address'),(484556,'furniture-mobile','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(484557,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','5','','','.w-menu-style-1'),(484558,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-bottom','10','','','.w-menu-slider'),(484559,'furniture-mobile','.w-reviews-content .author','padding-bottom','20','','','.w-reviews-content'),(484560,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-bottom','20','','','.p-account-trade-form'),(484561,'furniture-mobile','.p-account-trade-form .widget','padding-bottom','20','','','.p-account-trade-form'),(484562,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-bottom','10','','','.p-account-subscription-historyinfo'),(484563,'furniture-mobile','.w-promo-code .holder','padding-bottom','20','2906','','.w-promo-code'),(484565,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-bottom','5','','','.p-blog-index'),(484566,'furniture-mobile','.p-blog-index .comment-list','padding-bottom','30','','','.p-blog-index'),(484567,'furniture-mobile','.w-cart-listing .item .remove','padding-bottom','5','2885','','.w-cart-listing'),(484568,'furniture-mobile','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(484570,'furniture-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(484571,'furniture-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(484572,'furniture-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(484573,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(484574,'furniture-mobile','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(484575,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(484576,'furniture-mobile','.w-filters .filter-ul-content','padding-bottom','0','','','.w-filters'),(484577,'furniture-mobile','.w-filters .filter-box-head','padding-bottom','5','','','.w-filters'),(484578,'furniture-mobile','.w-filters .filter-li-content','padding-bottom','15','','','.w-filters'),(484579,'furniture-mobile','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(484580,'furniture-mobile','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(484581,'furniture-mobile','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(484582,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li','padding-bottom','2','','','.w-menu-horizontal'),(484583,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-bottom','2','','','.w-menu-horizontal'),(484584,'furniture-mobile','.w-menu-horizontal ul','padding-bottom','0','','','.w-menu-horizontal'),(484585,'furniture-mobile','.w-menu-slider > ul > li > a','padding-bottom','5','','','.w-menu-slider'),(484586,'furniture-mobile','.w-tabs .tab-navigation','padding-bottom','0','','','.w-tabs'),(484587,'furniture-mobile','.w-sale .holder-2','padding-bottom','20','','','.w-sale'),(484588,'furniture-mobile','.w-sale .left-count','padding-bottom','0','','','.w-sale'),(484589,'furniture-mobile','.b-table .table td','padding-bottom','15','','','.b-table'),(484590,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-bottom','10','','','.p-account-subscription-historyinfo'),(484591,'furniture-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(484592,'furniture-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(484593,'furniture-mobile','.w-sale .holder-1','padding-bottom','20','','','.w-sale'),(484594,'furniture-mobile','.w-sale .left-text-left','padding-bottom','24','','','.w-sale'),(484595,'furniture-mobile','.w-languages .lang-link','padding-bottom','5','','','.w-languages'),(484596,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-bottom','5','','','.p-blog-index'),(484597,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-bottom','10','','','.p-account-subscription-historyinfo'),(484598,'furniture-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(484599,'furniture-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(484600,'furniture-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(484601,'furniture-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(484602,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-bottom','0','','','.w-menu-slider'),(484603,'furniture-mobile','.p-account-trade-form .widget','padding-bottom','20','','','.p-account-trade-form'),(484604,'furniture-mobile','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(484605,'furniture-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(484606,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-bottom','20','','','.p-account-trade-form'),(484607,'furniture-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(484608,'furniture-mobile','.p-blog-index .wp-widget ul','padding-bottom','0','','','.p-blog-index'),(484609,'furniture-mobile','.p-reviews-info .review-info-text','padding-bottom','10','','','.p-reviews-info'),(484610,'furniture-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(484611,'furniture-mobile','.b-bottom .terms-info-popup .pop-up-content','padding-bottom','20','','','.b-bottom'),(484612,'furniture-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-bottom','5','','','.w-cart-compare'),(484613,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-bottom','20','','','.p-reviews-info'),(484614,'furniture-mobile','.no-found','padding-bottom','20','','',''),(484615,'furniture-mobile','textarea','padding-bottom','5','','',''),(484616,'furniture-mobile','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(484617,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(484618,'furniture-mobile','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(484619,'furniture-mobile','.p-quick-order-index .bottom','padding-bottom','10','','','.p-quick-order-index'),(484620,'furniture-mobile','.w-chat .w-chat-box','padding-bottom','2','','','.w-chat'),(484621,'furniture-mobile','.w-languages .current','padding-bottom','13','2885','','.w-languages'),(484622,'furniture-mobile','.w-sale .holder-1','padding-bottom','20','','','.w-sale'),(484623,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-bottom','20','','','.p-account-trade-form'),(484624,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-bottom','10','','','.w-image-maps'),(484625,'furniture-mobile','.b-table .table td','padding-bottom','15','','','.b-table'),(484626,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(484627,'furniture-mobile','.p-blog-index .wp-widget ul','padding-bottom','0','','','.p-blog-index'),(484628,'furniture-mobile','.message.success','padding-bottom','15','','',''),(484629,'furniture-mobile','.p-reviews-info .review-info-content','padding-bottom','20','','','.p-reviews-info'),(484630,'furniture-mobile','.p-reviews-info .review-info-image','padding-bottom','20','','','.p-reviews-info'),(484631,'furniture-mobile','.p-reviews-info .review-info-text','padding-bottom','10','','','.p-reviews-info'),(484632,'furniture-mobile','.w-personal-gift-status-bar .inform','padding-bottom','0','4','','.w-personal-gift-status-bar'),(484633,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-bottom','20','','','.p-account-trade-form'),(484634,'furniture-mobile','.p-blog-index .wp-widget ul','padding-bottom','0','','','.p-blog-index'),(484635,'furniture-mobile','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(484636,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(484637,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(484638,'furniture-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(484639,'furniture-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(484640,'furniture-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-bottom','0','','','.b-fancybox'),(484641,'furniture-mobile','.w-checkout-shipping-choice span','padding-bottom','4','','','.w-checkout-shipping-choice'),(484644,'furniture-mobile','.b-info .info','padding-bottom','15','','','.b-info'),(484645,'furniture-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(484646,'furniture-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(484647,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-bottom','0','','','.b-select-suggest'),(484648,'furniture-mobile','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(484649,'furniture-mobile','.w-reviews .review','padding-bottom','5','','','.w-reviews'),(484650,'furniture-mobile','.w-socials > li','padding-bottom','15','','','.w-socials'),(484651,'furniture-mobile','.w-search .search-input','padding-bottom','5','','','.w-search'),(484652,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-style-1'),(484653,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-style-1'),(484654,'furniture-mobile','.b-info-popup .info-popup div','padding-bottom','10','','','.b-info-popup'),(484655,'furniture-mobile','.b-form .payment-method .item','padding-bottom','7','','','.b-form'),(484656,'furniture-mobile','.w-checkout-create-account .create-account','padding-bottom','10','','','.w-checkout-create-account'),(484657,'furniture-mobile','.b-form .password-forgotten-link','padding-bottom','0','','','.b-form'),(484658,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-bottom','20','','','.p-reviews-info'),(484659,'furniture-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(484660,'furniture-mobile','.w-catalog-sorting .before','padding-bottom','0','','','.w-catalog-sorting'),(484661,'furniture-mobile','.w-languages .lang-link','padding-bottom','13','2885','','.w-languages'),(484662,'furniture-mobile','.w-sale .holder-2','padding-bottom','20','','','.w-sale'),(484663,'furniture-mobile','.w-sale .left-text-left','padding-bottom','24','','','.w-sale'),(484664,'furniture-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(484665,'furniture-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(484666,'furniture-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(484667,'furniture-mobile','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(484668,'furniture-mobile','.w-sale .holder-1','padding-bottom','20','','','.w-sale'),(484669,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-bottom','10','','','.w-menu-slider'),(484670,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-bottom','0','','','.w-menu-slider'),(484671,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','5','','','.w-menu-style-1'),(484672,'furniture-mobile','.w-menu-style-1 ul','padding-bottom','0','','','.w-menu-style-1'),(484673,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(484674,'furniture-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-bottom','3','','','.w-multi-cart-actions'),(484675,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-style-1'),(484676,'furniture-mobile','.w-top-categories .item','padding-bottom','30','','','.w-top-categories'),(484677,'furniture-mobile','.w-tabs > .block','padding-bottom','20','','','.w-tabs'),(484678,'furniture-mobile','.w-tabs .accordion-heading','padding-bottom','6','2','','.w-tabs'),(484679,'furniture-mobile','.w-tabs .accordion-heading','padding-bottom','9','2876','','.w-tabs'),(484680,'furniture-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-bottom','0','','','.w-cart-cart-tabs'),(484681,'furniture-mobile','.w-tabs .tab-a','padding-bottom','12','','','.w-tabs'),(484682,'furniture-mobile','.w-tabs .tab-li','padding-bottom','0','','','.w-tabs'),(484683,'furniture-mobile','.w-socials > li','padding-bottom','15','','','.w-socials'),(484684,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-style-1'),(484685,'furniture-mobile','.b-info .info li','padding-bottom','0','','','.b-info'),(484686,'furniture-mobile','.w-promo-code .holder','padding-bottom','20','2906','','.w-promo-code'),(484687,'furniture-mobile','.b-bottom .popup-buttons','padding-bottom','15','','','.b-bottom'),(484688,'furniture-mobile','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-bottom','7','','','.order-summary'),(484689,'furniture-mobile','.p-account-trade-form .widget','padding-bottom','20','','','.p-account-trade-form'),(484690,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(484691,'furniture-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(484692,'furniture-mobile','.b-sub-totals .historyTotal td','padding-bottom','2','','','.b-sub-totals'),(484693,'furniture-mobile','.w-sale .holder-1','padding-bottom','20','','','.w-sale'),(484694,'furniture-mobile','.p-reviews-info .review-info-content','padding-bottom','20','','','.p-reviews-info'),(484695,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(484696,'furniture-mobile','.b-form .required-message','padding-bottom','0','','','.b-form'),(484697,'furniture-mobile','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(484698,'furniture-mobile','.w-sale .left-count','padding-bottom','0','','','.w-sale'),(484699,'furniture-mobile','.w-sale .holder-2','padding-bottom','20','','','.w-sale'),(484700,'furniture-mobile','.p-reviews-info .review-info-content','padding-bottom','20','','','.p-reviews-info'),(484701,'furniture-mobile','.p-blog-index .wp-widget li','padding-bottom','10','','','.p-blog-index'),(484702,'furniture-mobile','.p-blog-index .wp-widget ul','padding-bottom','0','','','.p-blog-index'),(484703,'furniture-mobile','.btn-1','padding-bottom','4','','',''),(484704,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-bottom','10','','','.w-menu-slider'),(484705,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-bottom','0','','','.w-menu-slider'),(484706,'furniture-mobile','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(484707,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(484708,'furniture-mobile','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(484709,'furniture-mobile','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(484710,'furniture-mobile','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(484711,'furniture-mobile','.w-menu .hided.menu ul li','padding-bottom','0','','','.w-menu'),(484712,'furniture-mobile','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(484713,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(484714,'furniture-mobile','.b-info .info','padding-bottom','15','','','.b-info'),(484715,'furniture-mobile','.btn-3','padding-bottom','13','','',''),(484716,'furniture-mobile','.b-products-listing .products-listing .buyButton .btn','padding-bottom','4','','','.b-products-listing'),(484717,'furniture-mobile','.w-product-images-additional .images','padding-bottom','20','2906','','.w-product-images-additional'),(484718,'furniture-mobile','.b-form .required-message-wrap','padding-bottom','0','','','.b-form'),(484719,'furniture-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(484721,'furniture-mobile','.b-info .info li','padding-bottom','0','','','.b-info'),(484722,'furniture-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(484723,'furniture-mobile','.w-cart-discount-coupon .btn','padding-bottom','4','','','.w-cart-discount-coupon'),(484724,'furniture-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(484725,'furniture-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(484726,'furniture-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(484727,'furniture-mobile','.order-summary .price-row','padding-bottom','7','','','.order-summary'),(484728,'furniture-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(484729,'furniture-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(484730,'furniture-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(484731,'furniture-mobile','.w-socials > li','padding-bottom','15','','','.w-socials'),(484732,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(484733,'furniture-mobile','.b-upload-file .upload-file-template','padding-bottom','25','','','.b-upload-file'),(484734,'furniture-mobile','.w-search .name','padding-bottom','5','','','.w-search'),(484735,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-bottom','0','','','.p-blog-index'),(484736,'furniture-mobile','.p-blog-index .comment-list','padding-bottom','30','','','.p-blog-index'),(484737,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-bottom','0','','','.w-menu-slider'),(484738,'furniture-mobile','.w-sale .left-text-right','padding-bottom','24','','','.w-sale'),(484739,'furniture-mobile','.b-select-suggest .select2-drop-mask','padding-bottom','0','','','.b-select-suggest'),(484740,'furniture-mobile','.w-sale .left-text-left','padding-bottom','24','','','.w-sale'),(484741,'furniture-mobile','.w-sale .left-count','padding-bottom','0','','','.w-sale'),(484742,'furniture-mobile','.w-sale .holder-2','padding-bottom','20','','','.w-sale'),(484743,'furniture-mobile','.w-quote .cart-box-link','padding-bottom','0','','','.w-quote'),(484744,'furniture-mobile','.w-reviews .author','padding-bottom','10','','','.w-reviews'),(484745,'furniture-mobile','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(484746,'furniture-mobile','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(484747,'furniture-mobile','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(484748,'furniture-mobile','.w-search .suggest','padding-bottom','0','','','.w-search'),(484749,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-style-1'),(484750,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-bottom','0','','','.p-blog-index'),(484751,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-bottom','5','','','.p-blog-index'),(484752,'furniture-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(484753,'furniture-mobile','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(484754,'furniture-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(484756,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-bottom','2','','','.b-fancybox'),(484757,'furniture-mobile','.w-checkout-shipping-choice span','padding-bottom','4','2906','','.w-checkout-shipping-choice'),(484758,'furniture-mobile','.w-top-categories .categories h2','padding-bottom','0','','','.w-top-categories'),(484759,'furniture-mobile','.w-top-categories .image','padding-bottom','75','','','.w-top-categories'),(484760,'furniture-mobile','.w-product-reviews .reviews-list .review','padding-bottom','10','','','.w-product-reviews'),(484761,'furniture-mobile','.w-product-reviews .reviews-list .name','padding-bottom','5','','','.w-product-reviews'),(484762,'furniture-mobile','.w-reviews-content .rating','padding-bottom','10','','','.w-reviews-content'),(484763,'furniture-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(484764,'furniture-mobile','.b-info .info ul','padding-bottom','0','','','.b-info'),(484765,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(484766,'furniture-mobile','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(484767,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-bottom','20','','','.p-account-trade-form'),(484768,'furniture-mobile','.p-blog-index .wp-widget li','padding-bottom','10','','','.p-blog-index'),(484769,'furniture-mobile','.p-blog-index .nav-links','padding-bottom','20','','','.p-blog-index'),(484770,'furniture-mobile','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(484771,'furniture-mobile','.b-table .table td','padding-bottom','15','','','.b-table'),(484772,'furniture-mobile','.b-bottom .rfq-form','padding-bottom','0','','','.b-bottom'),(484773,'furniture-mobile','.b-bottom .popup-simple','padding-bottom','20','','','.b-bottom'),(484774,'furniture-mobile','.b-bottom .popup-heading','padding-bottom','12','','','.b-bottom'),(484775,'furniture-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(484776,'furniture-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(484777,'furniture-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(484778,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(484779,'furniture-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(484780,'furniture-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(484781,'furniture-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(484782,'furniture-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(484783,'furniture-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(484784,'furniture-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(484785,'furniture-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(484786,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(484787,'furniture-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(484788,'furniture-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(484789,'furniture-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(484790,'furniture-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(484791,'furniture-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(484792,'furniture-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(484794,'furniture-mobile','.w-checkout-shipping .sub-item','padding-bottom','5','','','.w-checkout-shipping'),(484795,'furniture-mobile','.b-info .info','padding-bottom','15','','','.b-info'),(484796,'furniture-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(484797,'furniture-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(484798,'furniture-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(484799,'furniture-mobile','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(484800,'furniture-mobile','.b-table .table td','padding-bottom','15','','','.b-table'),(484801,'furniture-mobile','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(484802,'furniture-mobile','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(484803,'furniture-mobile','.w-promo-code .holder','padding-bottom','20','2906','','.w-promo-code'),(484804,'furniture-mobile','.w-sale .holder-1','padding-bottom','20','','','.w-sale'),(484805,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(484806,'furniture-mobile','.b-form .center-buttons','padding-bottom','20','','','.b-form'),(484807,'furniture-mobile','.b-form .shipping-method .input','padding-bottom','0','','','.b-form'),(484808,'furniture-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(484809,'furniture-mobile','.w-reviews .item','padding-bottom','15','','','.w-reviews'),(484810,'furniture-mobile','.w-reviews .product-name','padding-bottom','12','','','.w-reviews'),(484811,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(484812,'furniture-mobile','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(484813,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','padding-bottom','0','','','.b-select-suggest'),(484814,'furniture-mobile','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(484815,'furniture-mobile','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(484816,'furniture-mobile','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(484817,'furniture-mobile','.w-banner .carousel-text > span','padding-bottom','20','','','.w-banner'),(484818,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-bottom','20','','','.p-reviews-info'),(484819,'furniture-mobile','.w-cart-compare .price-label','padding-bottom','10','','','.w-cart-compare'),(484820,'furniture-mobile','.b-info .info','padding-bottom','15','','','.b-info'),(484821,'furniture-mobile','.b-info .info li','padding-bottom','0','','','.b-info'),(484822,'furniture-mobile','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(484823,'furniture-mobile','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(484824,'furniture-mobile','.w-languages .current','padding-bottom','3','','','.w-languages'),(484825,'furniture-mobile','.b-upload-files .upload-files','padding-bottom','10','','','.b-upload-files'),(484826,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-style-1'),(484827,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(484828,'furniture-mobile','.w-menu-style-1 ul','padding-bottom','0','','','.w-menu-style-1'),(484829,'furniture-mobile','.w-sale .left-text-left','padding-bottom','24','','','.w-sale'),(484830,'furniture-mobile','.w-sale .left-text-right','padding-bottom','24','','','.w-sale'),(484831,'furniture-mobile','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(484832,'furniture-mobile','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(484833,'furniture-mobile','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(484834,'furniture-mobile','.b-form .col-full-padding','padding-bottom','30','','','.b-form'),(484835,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-style-1'),(484836,'furniture-mobile','.b-info .info ul','padding-bottom','0','','','.b-info'),(484837,'furniture-mobile','.w-categories .item','padding-bottom','30','','','.w-categories'),(484838,'furniture-mobile','.b-form .form-buttons','padding-bottom','50','','','.b-form'),(484839,'furniture-mobile','.b-fancybox .fancybox-title-over-wrap','padding-bottom','10','','','.b-fancybox'),(484840,'furniture-mobile','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(484841,'furniture-mobile','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(484842,'furniture-mobile','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(484843,'furniture-mobile','.w-menu-slider > ul > li > a','padding-bottom','5','','','.w-menu-slider'),(484844,'furniture-mobile','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(484845,'furniture-mobile','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(484846,'furniture-mobile','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(484847,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(484848,'furniture-mobile','.w-cart-compare .delete-cart','padding-bottom','10','','','.w-cart-compare'),(484849,'furniture-mobile','.w-personal-gift-status-bar .end-date','padding-bottom','0','3','','.w-personal-gift-status-bar'),(484850,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-bottom','5','','','.p-blog-index'),(484851,'furniture-mobile','.p-quick-order-index .all-scroll-div','padding-bottom','10','','','.p-quick-order-index'),(484852,'furniture-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(484853,'furniture-mobile','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(484855,'furniture-mobile','.w-checkout-billing-address .same-address','padding-bottom','10','','','.w-checkout-billing-address'),(484856,'furniture-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(484857,'furniture-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(484858,'furniture-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(484859,'furniture-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(484860,'furniture-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(484861,'furniture-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-bottom','10','','','.b-bottom'),(484862,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-style-1'),(484863,'furniture-mobile','.w-cart-compare .cart-cell','padding-bottom','20','','','.w-cart-compare'),(484864,'furniture-mobile','.w-promotions .promo-cart-discount .master .item','padding-bottom','20','','','.w-promotions'),(484865,'furniture-mobile','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(484866,'furniture-mobile','.w-sale .left-text-right','padding-bottom','24','','','.w-sale'),(484867,'furniture-mobile','.w-sale .left-count','padding-bottom','0','','','.w-sale'),(484868,'furniture-mobile','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(484869,'furniture-mobile','.w-menu-style-1 ul','padding-bottom','0','','','.w-menu-style-1'),(484870,'furniture-mobile','.b-bottom .cart-options','padding-bottom','20','','','.b-bottom'),(484871,'furniture-mobile','.b-bottom .alert-message','padding-bottom','20','','','.b-bottom'),(484872,'furniture-mobile','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(484873,'furniture-mobile','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(484874,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','padding-bottom','4','','','.b-select-suggest'),(484875,'furniture-mobile','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(484876,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(484877,'furniture-mobile','.p-reviews-info .review-info-image','padding-bottom','20','','','.p-reviews-info'),(484878,'furniture-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(484879,'furniture-mobile','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(484880,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-bottom','10','','','.w-menu-slider'),(484881,'furniture-mobile','.w-reviews-content .product-name','padding-bottom','20','','','.w-reviews-content'),(484885,'furniture-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(484886,'furniture-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(484887,'furniture-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(484888,'furniture-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(484889,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(484890,'furniture-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(484891,'furniture-mobile','.b-info .info ul','padding-bottom','0','','','.b-info'),(484892,'furniture-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-bottom','4','','','.b-compare'),(484893,'furniture-mobile','.b-bottom .pop-up-close','padding-bottom','1','','','.b-bottom'),(484894,'furniture-mobile','.b-bottom .footerTitle','padding-bottom','9','2876','','.b-bottom'),(484895,'furniture-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(484896,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(484897,'furniture-mobile','.w-cart-up-sell .w-list-type-1','padding-bottom','0','','','.w-cart-up-sell'),(484898,'furniture-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','0','1','','.w-cart-up-sell'),(484899,'furniture-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','1','','','.w-cart-up-sell'),(484900,'furniture-mobile','.b-products-listing .products-listing .btn-buy','padding-bottom','4','','','.b-products-listing'),(484901,'furniture-mobile','.b-upload-files .added-file','padding-bottom','5','','','.b-upload-files'),(484902,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-bottom','0','','','.w-menu'),(484903,'furniture-mobile','.w-menu-big ul','padding-bottom','0','','','.w-menu-big'),(484904,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','5','','','.w-menu-style-1'),(484905,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(484906,'furniture-mobile','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(484907,'furniture-mobile','.w-sale .holder-2','padding-bottom','20','','','.w-sale'),(484908,'furniture-mobile','.w-sale .left-count','padding-bottom','0','','','.w-sale'),(484909,'furniture-mobile','.w-categories h2.name','padding-bottom','3','','','.w-categories'),(484910,'furniture-mobile','.b-bottom .header-info','padding-bottom','20','','','.b-bottom'),(484911,'furniture-mobile','.b-bottom .popup-box-wrap','padding-bottom','10','','','.b-bottom'),(484912,'furniture-mobile','.w-product-images-additional .images','padding-bottom','20','2906','','.w-product-images-additional'),(484913,'furniture-mobile','.b-bottom .pop-up-info','padding-bottom','20','','','.b-bottom'),(484914,'furniture-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(484915,'furniture-mobile','.b-fancybox .fancybox-error','padding-bottom','15','','','.b-fancybox'),(484916,'furniture-mobile','.b-info .info li','padding-bottom','0','','','.b-info'),(484917,'furniture-mobile','.w-product-customers-activity .customers-activity','padding-bottom','20','','','.w-product-customers-activity'),(484918,'furniture-mobile','.b-compare .compare-box-item','padding-bottom','10','','','.b-compare'),(484919,'furniture-mobile','.b-bottom .confirm-popup .buttons','padding-bottom','30','','','.b-bottom'),(484920,'furniture-mobile','.b-compare .compare-head','padding-bottom','0','','','.b-compare'),(484921,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(484922,'furniture-mobile','.b-email .heading-image','padding-bottom','5','','','.b-email'),(484923,'furniture-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(484924,'furniture-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(484925,'furniture-mobile','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(484926,'furniture-mobile','.b-info .info li','padding-bottom','0','','','.b-info'),(484927,'furniture-mobile','.b-form .login-col-1','padding-bottom','0','','','.b-form'),(484928,'furniture-mobile','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(484929,'furniture-mobile','.p-blog-index .comments-area article','padding-bottom','10','','','.p-blog-index'),(484930,'furniture-mobile','.p-blog-index .nav-links','padding-bottom','20','','','.p-blog-index'),(484931,'furniture-mobile','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(484935,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-bottom','10','','','.w-menu-slider'),(484936,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-bottom','0','','','.w-menu'),(484937,'furniture-mobile','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(484938,'furniture-mobile','.w-checkout-billing-address .edit-ab','padding-bottom','0','','','.w-checkout-billing-address'),(484939,'furniture-mobile','.w-checkout-shipping-choice #shippingchoice-choice','padding-bottom','7','','','.w-checkout-shipping-choice'),(484940,'furniture-mobile','.w-promo-code .holder','padding-bottom','20','2906','','.w-promo-code'),(484941,'furniture-mobile','.w-product-images-additional .images','padding-bottom','20','2906','','.w-product-images-additional'),(484942,'furniture-mobile','.b-bottom .header-error','padding-bottom','20','','','.b-bottom'),(484943,'furniture-mobile','.w-sale .left-text-right','padding-bottom','24','','','.w-sale'),(484944,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-style-1'),(484945,'furniture-mobile','.w-tabs .accordion-heading','padding-bottom','8','','','.w-tabs'),(484946,'furniture-mobile','.w-socials > li','padding-bottom','15','','','.w-socials'),(484947,'furniture-mobile','.b-autocomplete .ui-autocomplete li','padding-bottom','3','','','.b-autocomplete'),(484949,'furniture-mobile','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(484950,'furniture-mobile','.w-cart-give-away .ga_column','padding-bottom','15','','','.w-cart-give-away'),(484951,'furniture-mobile','.w-cart-compare .price-cell','padding-bottom','8','','','.w-cart-compare'),(484952,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(484953,'furniture-mobile','.p-blog-index .nav-links','padding-bottom','20','','','.p-blog-index'),(484954,'furniture-mobile','.p-blog-index .comment-list','padding-bottom','30','','','.p-blog-index'),(484955,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-bottom','20','','','.p-account-trade-form'),(484956,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(484957,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(484958,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-bottom','5','','','.b-select-suggest'),(484959,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-bottom','0','','','.b-select-suggest'),(484960,'furniture-mobile','.b-select-suggest .select2-locked','padding-bottom','3','','','.b-select-suggest'),(484961,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-bottom','0','','','.b-select-suggest'),(484962,'furniture-mobile','.b-select-suggest .select2-results','padding-bottom','0','','','.b-select-suggest'),(484963,'furniture-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','5','','','.w-menu-horizontal'),(484964,'furniture-mobile','.w-menu-slider > ul > li > a','padding-bottom','5','','','.w-menu-slider'),(484965,'furniture-mobile','.b-form .shipping-method .item + .item','padding-bottom','5','','','.b-form'),(484966,'furniture-mobile','.b-select-suggest .select2-search input','padding-bottom','4','','','.b-select-suggest'),(484967,'furniture-mobile','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(484968,'furniture-mobile','.w-menu-style-1 ul','padding-bottom','0','','','.w-menu-style-1'),(484969,'furniture-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-horizontal'),(484970,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-bottom','10','','','.w-menu-slider'),(484971,'furniture-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(484972,'furniture-mobile','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(484973,'furniture-mobile','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(484974,'furniture-mobile','.w-socials > li','padding-bottom','15','','','.w-socials'),(484975,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-style-1'),(484976,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-bottom','0','','','.w-menu'),(484977,'furniture-mobile','.w-menu .hided.menu ul li','padding-bottom','0','','','.w-menu'),(484978,'furniture-mobile','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(484979,'furniture-mobile','.w-cart-compare .dropdown li','padding-bottom','5','','','.w-cart-compare'),(484980,'furniture-mobile','.w-cart-compare .product-label','padding-bottom','15','','','.w-cart-compare'),(484981,'furniture-mobile','.p-account-trade-form .widget','padding-bottom','20','','','.p-account-trade-form'),(484982,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-bottom','0','','','.p-blog-index'),(484983,'furniture-mobile','.p-reviews-info .review-info-text','padding-bottom','10','','','.p-reviews-info'),(484984,'furniture-mobile','.p-reviews-info .review-info-image','padding-bottom','20','','','.p-reviews-info'),(484985,'furniture-mobile','.w-menu-slider > ul > li > a','padding-bottom','5','','','.w-menu-slider'),(484986,'furniture-mobile','.w-menu .hided.menu ul li','padding-bottom','0','','','.w-menu'),(484987,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-bottom','0','','','.w-menu'),(484988,'furniture-mobile','.p-account-trade-form .widget','padding-bottom','20','','','.p-account-trade-form'),(484989,'furniture-mobile','.p-account-update .privacy-row','padding-bottom','10','','','.p-account-update'),(484990,'furniture-mobile','.p-reviews-info .review-info-content','padding-bottom','20','','','.p-reviews-info'),(484991,'furniture-mobile','.p-reviews-info .review-info-text','padding-bottom','10','','','.p-reviews-info'),(484992,'furniture-mobile','.b-compare .col-two label','padding-bottom','5','','','.b-compare'),(484993,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(484994,'furniture-mobile','.w-account .acc-buttons','padding-bottom','10','','','.w-account'),(484995,'furniture-mobile','.w-account .acc-form-item','padding-bottom','10','','','.w-account'),(484996,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-bottom','20','','','.p-reviews-info'),(484997,'furniture-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(484998,'furniture-mobile','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(484999,'furniture-mobile','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(485000,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(485001,'furniture-mobile','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(485002,'furniture-mobile','.p-blog-index .wp-widget ul','padding-bottom','0','','','.p-blog-index'),(485003,'furniture-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-bottom','20','','','.w-account-addresses-list'),(485004,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.b-data-table'),(485005,'furniture-mobile','.w-communication-post .communication-post','padding-bottom','5','','','.w-communication-post'),(485006,'furniture-mobile','.w-communication-post .communication-post-author','padding-bottom','10','','','.w-communication-post'),(485007,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','padding-bottom','0','','','.b-products-listing'),(485008,'furniture-mobile','.b-products-listing .in-cart','padding-bottom','4','','','.b-products-listing'),(485009,'furniture-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-bottom','5','','','.w-catalog-b2b-add-button'),(485010,'furniture-mobile','.b-products-listing .promos-info .promo-item','padding-bottom','3','','','.b-products-listing'),(485011,'furniture-mobile','.b-products-listing .promos-info .promo-name','padding-bottom','3','','','.b-products-listing'),(485012,'furniture-mobile','.w-blog-widget-tag-cloud a','padding-bottom','10','','','.w-blog-widget-tag-cloud'),(485013,'furniture-mobile','.w-blog-widget-tag-cloud ','padding-bottom','25','','','.w-blog-widget-tag-cloud'),(485014,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-bottom','20','','','.w-blog-widget-related-posts-by-category'),(485015,'furniture-mobile','.w-blog-widget-related-posts-by-category .post','padding-bottom','0','','','.w-blog-widget-related-posts-by-category'),(485016,'furniture-mobile','.w-blog-widget-related-posts ','padding-bottom','20','2906','','.w-blog-widget-related-posts'),(485017,'furniture-mobile','.w-blog-widget-related-posts .post_content a','padding-bottom','20','','','.w-blog-widget-related-posts'),(485018,'furniture-mobile','.w-blog-widget-related-posts .post','padding-bottom','0','','','.w-blog-widget-related-posts'),(485019,'furniture-mobile','.w-blog-widget-post-title h1','padding-bottom','0','','','.w-blog-widget-post-title'),(485020,'furniture-mobile','.w-blog-widget-post-title ','padding-bottom','20','','','.w-blog-widget-post-title'),(485021,'furniture-mobile','.w-blog-widget-post-listing .post','padding-bottom','0','2890','','.w-blog-widget-post-listing'),(485022,'furniture-mobile','.w-blog-widget-post-listing .post_name','padding-bottom','10','','','.w-blog-widget-post-listing'),(485023,'furniture-mobile','.w-blog-widget-post-listing .post_date','padding-bottom','10','','','.w-blog-widget-post-listing'),(485024,'furniture-mobile','.w-blog-widget-post-listing .post_content','padding-bottom','20','','','.w-blog-widget-post-listing'),(485025,'furniture-mobile','.w-blog-widget-post-listing .post','padding-bottom','0','','','.w-blog-widget-post-listing'),(485026,'furniture-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-bottom','10','','','.w-blog-widget-most-popular-posts'),(485027,'furniture-mobile','.w-blog-widget-most-popular-posts ','padding-bottom','20','','','.w-blog-widget-most-popular-posts'),(485028,'furniture-mobile','.w-blog-widget-categories-list ','padding-bottom','25','','','.w-blog-widget-categories-list'),(485029,'furniture-mobile','.w-currencies .select-link','padding-bottom','12','2885','','.w-currencies'),(485030,'furniture-mobile','.w-currencies .current','padding-bottom','14','2885','','.w-currencies'),(485031,'furniture-mobile','.w-currencies .select-link','padding-bottom','5','','','.w-currencies'),(485032,'furniture-mobile','.w-currencies .current','padding-bottom','3','','','.w-currencies'),(485033,'furniture-mobile','.w-currencies .currencies-title','padding-bottom','1','','','.w-currencies'),(485034,'furniture-mobile','.p-reviews-info .review-info-content','padding-bottom','20','','','.p-reviews-info'),(485035,'furniture-mobile','.p-reviews-info .review-info-text','padding-bottom','10','','','.p-reviews-info'),(485036,'furniture-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(485037,'furniture-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(485038,'furniture-mobile','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(485039,'furniture-mobile','.w-checkout-gdpr .privacy-row','padding-bottom','0','','','.w-checkout-gdpr'),(485040,'furniture-mobile','.w-checkout-gdpr .terms-login','padding-bottom','0','','','.w-checkout-gdpr'),(485041,'furniture-mobile','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(485042,'furniture-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(485043,'furniture-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(485044,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(485045,'furniture-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(485046,'furniture-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(485047,'furniture-mobile','.b-email .heading-price','padding-bottom','5','','','.b-email'),(485048,'furniture-mobile','.w-reviews .heading-3','padding-bottom','15','','','.w-reviews'),(485049,'furniture-mobile','.w-menu-style-1 ul','padding-bottom','0','','','.w-menu-style-1'),(485050,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','5','','','.w-menu-style-1'),(485051,'furniture-mobile','.w-menu .hided.menu ul li','padding-bottom','0','','','.w-menu'),(485052,'furniture-mobile','.w-personal-gift-status-bar .timeline','padding-bottom','16','','','.w-personal-gift-status-bar'),(485053,'furniture-mobile','.p-blog-index .nav-links','padding-bottom','20','','','.p-blog-index'),(485054,'furniture-mobile','.p-blog-index .comment-list','padding-bottom','30','','','.p-blog-index'),(485055,'furniture-mobile','.p-blog-index .comments-area article','padding-bottom','10','','','.p-blog-index'),(485056,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-bottom','10','','','.p-account-subscription-historyinfo'),(485057,'furniture-mobile','.p-account-trade-form .widget','padding-bottom','20','','','.p-account-trade-form'),(485058,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(485059,'furniture-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(485060,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(485061,'furniture-mobile','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(485062,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-bottom','0','','',''),(485063,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-bottom','0','','','.b-h-inline'),(485064,'furniture-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(485065,'furniture-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(485066,'furniture-mobile','.blogsidebar .heading-title','padding-bottom','12','','','.blogsidebar'),(485067,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-bottom','0','','','.w-communication-new-topic'),(485068,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-bottom','5','','','.w-communication-new-topic'),(485069,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-bottom','5','','','.w-communication-new-topic'),(485070,'furniture-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-bottom','0','','','.w-communication-new-topic'),(485072,'furniture-mobile','.b-info .info ul','padding-bottom','0','','','.b-info'),(485073,'furniture-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(485074,'furniture-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(485075,'furniture-mobile','.b-bottom .popup-content','padding-bottom','15','','','.b-bottom'),(485076,'furniture-mobile','.b-compare .compare_pagination','padding-bottom','10','','','.b-compare'),(485077,'furniture-mobile','.w-promo-code .holder','padding-bottom','20','2906','','.w-promo-code'),(485078,'furniture-mobile','.w-top-categories .item','padding-bottom','30','2876','','.w-top-categories'),(485079,'furniture-mobile','.w-sale .left-text-right','padding-bottom','24','','','.w-sale'),(485080,'furniture-mobile','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(485081,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(485082,'furniture-mobile','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(485083,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-bottom','0','','','.w-menu'),(485084,'furniture-mobile','.w-menu .hided.menu ul li','padding-bottom','0','','','.w-menu'),(485085,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(485086,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(485087,'furniture-mobile','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(485088,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(485089,'furniture-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(485091,'furniture-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-bottom','0','','','.b-fancybox'),(485092,'furniture-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(485093,'furniture-mobile','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(485094,'furniture-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(485095,'furniture-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(485096,'furniture-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(485097,'furniture-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(485098,'furniture-mobile','.products-quick-index .token-input-list','padding-bottom','0','','',''),(485099,'furniture-mobile','.w-cart-compare .product','padding-bottom','10','','','.w-cart-compare'),(485100,'furniture-mobile','.w-cart-compare .product-actions','padding-bottom','0','','','.w-cart-compare'),(485101,'furniture-mobile','.w-cart-shipping-estimator .address-item','padding-bottom','20','','','.w-cart-shipping-estimator'),(485102,'furniture-mobile','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(485103,'furniture-mobile','.w-sale .left-text-left','padding-bottom','24','','','.w-sale'),(485104,'furniture-mobile','.w-sale .holder-2','padding-bottom','20','','','.w-sale'),(485105,'furniture-mobile','.w-sale .holder-1','padding-bottom','20','','','.w-sale'),(485106,'furniture-mobile','.w-sale .left-count','padding-bottom','0','','','.w-sale'),(485107,'furniture-mobile','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(485108,'furniture-mobile','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(485109,'furniture-mobile','.w-sale .left-text-right','padding-bottom','24','','','.w-sale'),(485110,'furniture-mobile','.b-info .info li','padding-bottom','0','','','.b-info'),(485111,'furniture-mobile','.b-form .shipping-method .item','padding-bottom','5','','','.b-form'),(485112,'furniture-mobile','.b-info .info','padding-bottom','15','','','.b-info'),(485113,'furniture-mobile','.b-email .model','padding-bottom','5','','','.b-email'),(485114,'furniture-mobile','.b-form .middle-form','padding-bottom','0','','','.b-form'),(485115,'furniture-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(485116,'furniture-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(485117,'furniture-mobile','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(485118,'furniture-mobile','.w-product-images-additional .images','padding-bottom','20','2906','','.w-product-images-additional'),(485119,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-bottom','5','','','.p-blog-index'),(485120,'furniture-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(485121,'furniture-mobile','.w-cart-listing .item .gift-wrap label','padding-bottom','10','','','.w-cart-listing'),(485122,'furniture-mobile','.w-cart-listing .item > div','padding-bottom','10','','','.w-cart-listing'),(485123,'furniture-mobile','.w-cart-listing .points-earn','padding-bottom','5','','','.w-cart-listing'),(485124,'furniture-mobile','.w-cart-listing .points-redeem','padding-bottom','10','','','.w-cart-listing'),(485125,'furniture-mobile','.w-cart .cart-box-link','padding-bottom','0','','','.w-cart'),(485126,'furniture-mobile','.w-cart .buttons .btn','padding-bottom','4','','','.w-cart'),(485127,'furniture-mobile','.w-cart .buttons','padding-bottom','15','','','.w-cart'),(485128,'furniture-mobile','.w-cart .multicart .name','padding-bottom','0','','','.w-cart'),(485129,'furniture-mobile','.w-cart .multicart .item','padding-bottom','15','','','.w-cart'),(485130,'furniture-mobile','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(485131,'furniture-mobile','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(485132,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-bottom','17','','','.w-wedding-registry-widgets-photos'),(485133,'furniture-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(485134,'furniture-mobile','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(485136,'furniture-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(485137,'furniture-mobile','.b-email .totals-value','padding-bottom','5','','','.b-email'),(485138,'furniture-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(485139,'furniture-mobile','.b-email .price','padding-bottom','5','','','.b-email'),(485140,'furniture-mobile','.b-email .name','padding-bottom','5','','','.b-email'),(485141,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(485142,'furniture-mobile','.b-email .heading-name','padding-bottom','5','','','.b-email'),(485143,'furniture-mobile','.b-email .image','padding-bottom','5','','','.b-email'),(485144,'furniture-mobile','.w-product-images-additional .images','padding-bottom','20','2906','','.w-product-images-additional'),(485145,'furniture-mobile','.w-promo-code .holder','padding-bottom','20','2906','','.w-promo-code'),(485146,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-style-1'),(485147,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(485148,'furniture-mobile','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(485149,'furniture-mobile','.w-menu-style-1 ul','padding-bottom','0','','','.w-menu-style-1'),(485150,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','5','','','.w-menu-style-1'),(485151,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-bottom','0','','','.w-menu-slider'),(485152,'furniture-mobile','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(485153,'furniture-mobile','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(485154,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(485155,'furniture-mobile','.w-cart .cart-content','padding-bottom','5','','','.w-cart'),(485156,'furniture-mobile','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(485157,'furniture-mobile','.p-blog-index .wp-widget li','padding-bottom','10','','','.p-blog-index'),(485158,'furniture-mobile','.p-blog-index .comments-area article','padding-bottom','10','','','.p-blog-index'),(485159,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(485160,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-bottom','10','','','.p-account-subscription-historyinfo'),(485161,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-bottom','5','','','.p-blog-index'),(485162,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-bottom','0','','','.p-blog-index'),(485163,'furniture-mobile','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(485164,'furniture-mobile','.p-blog-index .comments-area article','padding-bottom','10','','','.p-blog-index'),(485165,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-bottom','0','','','.w-menu-slider'),(485166,'furniture-mobile','.w-filters .fsl_handle','padding-bottom','15','','','.w-filters'),(485167,'furniture-mobile','.w-filters .head-filter-widget','padding-bottom','0','2885','','.w-filters'),(485168,'furniture-mobile','.w-filters .filter-box-content','padding-bottom','20','','','.w-filters'),(485169,'furniture-mobile','.w-filters .ui-slider-range','padding-bottom','0','','','.w-filters'),(485170,'furniture-mobile','.p-blog-index .comments-area article','padding-bottom','10','','','.p-blog-index'),(485171,'furniture-mobile','.p-blog-index .wp-widget li','padding-bottom','10','','','.p-blog-index'),(485172,'furniture-mobile','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(485173,'furniture-mobile','.w-cart .cart-total','padding-bottom','10','','','.w-cart'),(485174,'furniture-mobile','.w-filters .head-filter-widget','padding-bottom','10','','','.w-filters'),(485175,'furniture-mobile','.b-autocomplete .ui-autocomplete','padding-bottom','2','','','.b-autocomplete'),(485176,'furniture-mobile','.b-bottom .notify-form','padding-bottom','0','','','.b-bottom'),(485177,'furniture-mobile','.order-summary .heading-2','padding-bottom','0','','','.order-summary'),(485178,'furniture-mobile','.w-personal-gift-status-bar .end-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(485179,'furniture-mobile','.b-compare .column_wrapper','padding-bottom','10','','','.b-compare'),(485180,'furniture-mobile','.b-info .info','padding-bottom','15','','','.b-info'),(485181,'furniture-mobile','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(485182,'furniture-mobile','.b-email .heading-model','padding-bottom','5','','','.b-email'),(485183,'furniture-mobile','.b-info .info ul','padding-bottom','0','','','.b-info'),(485184,'furniture-mobile','.w-socials > li','padding-bottom','15','','','.w-socials'),(485185,'furniture-mobile','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(485186,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-bottom','12','2885','','.w-menu-style-1'),(485187,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','5','','','.w-menu-style-1'),(485188,'furniture-mobile','.w-reviews-content .review','padding-bottom','10','','','.w-reviews-content'),(485189,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom','0','','','.b-data-table'),(485190,'furniture-mobile','.b-data-table table.dataTable tbody td','padding-bottom','10','','','.b-data-table'),(485191,'furniture-mobile','.b-data-table table.dataTable thead td','padding-bottom','10','','','.b-data-table'),(485192,'furniture-mobile','.p-reviews-info .review-info-image','padding-bottom','20','','','.p-reviews-info'),(485193,'furniture-mobile','.b-compare .popupCompare .pop-up-content','padding-bottom','10','','','.b-compare'),(485194,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-bottom','0','','','.w-menu'),(485195,'furniture-mobile','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(485196,'furniture-mobile','.w-menu-slider > ul > li > a','padding-bottom','5','','','.w-menu-slider'),(485197,'furniture-mobile','.btn-2','padding-bottom','12','','',''),(485198,'furniture-mobile','.w-menu .hided.menu ul li','padding-bottom','0','','','.w-menu'),(485199,'furniture-mobile','.w-quote-products .empty','padding-bottom','100','','','.w-quote-products'),(485200,'furniture-mobile','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(485201,'furniture-mobile','.b-table .table td','padding-bottom','15','','','.b-table'),(485202,'furniture-mobile','.b-info .info ul','padding-bottom','0','','','.b-info'),(485203,'furniture-mobile','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(485204,'furniture-mobile','.b-compare .col-gender','padding-bottom','10','','','.b-compare'),(485205,'furniture-mobile','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(485206,'furniture-mobile','.b-email .totals-title','padding-bottom','5','','','.b-email'),(485207,'furniture-mobile','.b-email .qty','padding-bottom','5','','','.b-email'),(485208,'furniture-mobile','.btn','padding-bottom','6','','',''),(485209,'furniture-mobile','.p-blog-index .comments-area article','padding-bottom','10','','','.p-blog-index'),(485210,'furniture-mobile','.p-blog-index .comment-list','padding-bottom','30','','','.p-blog-index'),(485211,'furniture-mobile','.p-blog-index .wp-widget li','padding-bottom','10','','','.p-blog-index'),(485212,'furniture-mobile','.b-product-images .media-popup .mp-content','padding-bottom','0','','','.b-product-images'),(485213,'furniture-mobile','.b-product-images .media-popup .mp-small-images .item','padding-bottom','10','','','.b-product-images'),(485214,'furniture-mobile','.b-product-images .media-popup .slick-dots','padding-bottom','0','','','.b-product-images'),(485215,'furniture-mobile','.b-product-images .media-popup .slick-dots li','padding-bottom','0','','','.b-product-images'),(485216,'furniture-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-bottom','0','','','.b-menu-style'),(485217,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-bottom','12','','','.b-menu-style-1'),(485218,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-bottom','5','','','.b-menu-style-2'),(485219,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-bottom','5','','','.b-menu-style-2'),(485220,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-bottom','0','','','.b-menu-style-2'),(485221,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-bottom','0','','','.b-menu-style-2'),(485222,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-bottom','10','','','.b-menu-style-2'),(485223,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-bottom','0','','','.b-menu-style-2'),(485224,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-bottom','5','','','.b-menu-style-2'),(485225,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-bottom','10','','','.b-menu-style-2'),(485226,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-bottom','5','','','.b-menu-style-2'),(485227,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-bottom','10','','','.b-menu-style-2'),(485228,'furniture-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-bottom','20','','','.b-personal-catalog-popup'),(485229,'furniture-mobile','.b-trade-approval .steps-bar li a','padding-bottom','7','','','.b-trade-approval'),(485230,'furniture-mobile','.b-trade-approval .middle-form','padding-bottom','20','','','.b-trade-approval'),(485231,'furniture-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-bottom','5','','','.b-trade-approval'),(485232,'furniture-mobile','.b-trade-approval .steps-bar','padding-bottom','0','','','.b-trade-approval'),(485233,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-bottom','6','','','.b-trade-approval'),(485234,'furniture-mobile','.b-trade-approval .center-buttons','padding-bottom','20','','','.b-trade-approval'),(485235,'furniture-mobile','.batchPr .w-batch-products .products-listing .image','padding-bottom','0','','','.batchPr'),(485236,'furniture-mobile','.batchPr .w-batch-products','padding-bottom','0','','','.batchPr'),(485237,'furniture-mobile','.batchPr > .block:nth-child(2)','padding-bottom','12','','','.batchPr'),(485238,'furniture-mobile','.batchPr .w-batch-selected-products','padding-bottom','15','','','.batchPr'),(485239,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-bottom','0','','','.batchPr'),(485240,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-bottom','10','','','.batchPr'),(485241,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-bottom','0','','','.batchPr'),(485242,'furniture-mobile','.batchPr ','padding-bottom','0','','','.batchPr'),(485243,'furniture-mobile','.batchPr .batch-selected-products-empty','padding-bottom','10','','','.batchPr'),(485244,'furniture-mobile','.batchPr .batch-selected-products-total','padding-bottom','10','','','.batchPr'),(485245,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-bottom','0','','','.batchPr'),(485246,'furniture-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-bottom','15','','','.batchPr'),(485247,'furniture-mobile','.batchPr .w-batch-products .products-listing .image','padding-bottom','10','','','.batchPr'),(485248,'furniture-mobile','.w-account-personal-catalog .list-switcher','padding-bottom','0','','','.w-account-personal-catalog'),(485249,'furniture-mobile','.w-account-personal-catalog .list-switcher a','padding-bottom','12','','','.w-account-personal-catalog'),(485250,'furniture-mobile','.w-account-subscription .subscription-variant','padding-bottom','10','','','.w-account-subscription'),(485251,'furniture-mobile','.w-catalog-additional-images li','padding-bottom','10','','','.w-catalog-additional-images'),(485252,'furniture-mobile','.w-catalog-additional-images ul','padding-bottom','0','','','.w-catalog-additional-images'),(485253,'furniture-mobile','.w-catalog-compare td','padding-bottom','10','','','.w-catalog-compare'),(485254,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-bottom','0','','','.w-catalog-compare'),(485255,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','padding-bottom','11','2','','.w-catalog-compare'),(485256,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','padding-bottom','10','','','.w-catalog-compare'),(485257,'furniture-mobile','.w-delivery-day .left-count','padding-bottom','0','','','.w-delivery-day'),(485258,'furniture-mobile','.w-delivery-day .left-text-left','padding-bottom','24','','','.w-delivery-day'),(485259,'furniture-mobile','.w-delivery-day .left-text-right','padding-bottom','24','','','.w-delivery-day'),(485260,'furniture-mobile','.w-top-text .top-text','padding-bottom','5','','','.w-top-text'),(485261,'furniture-mobile','.w-cart-listing .points','padding-bottom','0','2876','','.w-cart-listing'),(485262,'furniture-mobile','.w-product-images .additional-horizontal .item','padding-bottom','10','','','.w-product-images'),(485263,'furniture-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-bottom','10','','','.b-cookie-notice'),(485264,'furniture-mobile','.w-cart .no-text','padding-bottom','0','','','.w-cart'),(485265,'furniture-mobile','.lowestPricedBox .w-banner .banner','padding-bottom','30','','','.lowestPricedBox'),(485266,'furniture-mobile','.tripleBanner ','padding-bottom','30','','','.tripleBanner'),(485267,'furniture-mobile','.tripleBanner > .block','padding-bottom','0','','','.tripleBanner'),(485268,'furniture-mobile','.tripleBanner .w-html_box','padding-bottom','16','','','.tripleBanner'),(485269,'furniture-mobile','.w-languages .current','padding-bottom','7','2906','','.w-languages'),(485270,'furniture-mobile','.w-currencies .current','padding-bottom','7','2906','','.w-currencies'),(485271,'furniture-mobile','.b-slick .slick-list','padding-bottom','0','','','.b-slick'),(485272,'furniture-mobile','.b-slick .slick-vertical button.slick-next','padding-bottom','0','3','','.b-slick'),(485273,'furniture-mobile','.b-slick .slick-vertical button.slick-prev','padding-bottom','0','3','','.b-slick'),(485274,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-bottom','0','','','.b-slick'),(485275,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-bottom','5','2885','','.b-menu-style-3'),(485276,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2','padding-bottom','20','2885','','.b-menu-style-3'),(485277,'furniture-mobile','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','padding-bottom','0','','','.b-products-listing'),(485278,'furniture-mobile','.w-cart-listing .headings .head','padding-bottom','10','','','.w-cart-listing'),(485279,'furniture-mobile','.b-products-listing .item-nav > div','padding-bottom','10','','','.b-products-listing'),(485280,'furniture-mobile','.LeftCategories .w-menu-simple ul','padding-bottom','0','','','.LeftCategories'),(485281,'furniture-mobile','.LeftCategories .w-menu-simple ul li a','padding-bottom','4','','','.LeftCategories'),(485282,'furniture-mobile','.w-filters .filter-widget','padding-bottom','20','','','.w-filters'),(485283,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item','padding-bottom','20','','','.b-products-listing'),(485284,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-bottom','0','','','.b-products-listing'),(485285,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-content','padding-bottom','0','','','.b-products-listing'),(485286,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','padding-bottom','10','','','.b-products-listing'),(485287,'furniture-mobile','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-bottom','15','','','.b-products-listing'),(485288,'furniture-mobile','.b-products-listing .products-listing.list-rows .item-nav > div','padding-bottom','0','','','.b-products-listing'),(485289,'furniture-mobile','.w-breadcrumb .breadcrumb-li','padding-bottom','0','','','.w-breadcrumb'),(485290,'furniture-mobile','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(485291,'furniture-mobile','.w-subscribers .btn-submit','padding-bottom','6','','','.w-subscribers'),(485292,'furniture-mobile','.w-quote .buttons','padding-bottom','15','','','.w-quote'),(485293,'furniture-mobile','.w-quote .buttons .btn','padding-bottom','4','','','.w-quote'),(485294,'furniture-mobile','.w-quote .cart-content','padding-bottom','5','','','.w-quote'),(485295,'furniture-mobile','.w-quote .cart-total','padding-bottom','10','','','.w-quote'),(485296,'furniture-mobile','.w-quote .multicart .cart-content','padding-bottom','0','','','.w-quote'),(485297,'furniture-mobile','.w-quote .multicart .item','padding-bottom','15','','','.w-quote'),(485298,'furniture-mobile','.w-quote .multicart .name','padding-bottom','0','','','.w-quote'),(485299,'furniture-mobile','.w-quote .no-text','padding-bottom','0','','','.w-quote'),(485300,'furniture-mobile','.w-quote a.item','padding-bottom','5','','','.w-quote'),(485301,'furniture-mobile','.w-social-links a','padding-bottom','4','','','.w-social-links'),(485302,'furniture-mobile','.w-product-images .additional-vertical .additional-images','padding-bottom','30','','','.w-product-images'),(485303,'furniture-mobile','.w-product-personal-catalog-button .btn','padding-bottom','0','','','.w-product-personal-catalog-button'),(485304,'furniture-mobile','.b-quantity .qty-box input','padding-bottom','5','','','.b-quantity'),(485305,'furniture-mobile','.w-product-model > div','padding-bottom','7','','','.w-product-model'),(485306,'furniture-mobile','.w-product-sale-ends .left-count','padding-bottom','0','','','.w-product-sale-ends'),(485307,'furniture-mobile','.w-product-sale-ends .left-text-left','padding-bottom','24','','','.w-product-sale-ends'),(485308,'furniture-mobile','.w-product-sale-ends .left-text-right','padding-bottom','24','','','.w-product-sale-ends'),(485309,'furniture-mobile','.w-product-sale-ends .left-count-days','padding-bottom','7','','','.w-product-sale-ends'),(485310,'furniture-mobile','.w-product-sale-ends .left-count-hours','padding-bottom','7','','','.w-product-sale-ends'),(485311,'furniture-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(485312,'furniture-mobile','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(485313,'furniture-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(485314,'furniture-mobile','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(485315,'furniture-mobile','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(485316,'furniture-mobile','.warrantyProduct .warranty, .warrantyProduct .delivery','padding-bottom','10','','','.warrantyProduct'),(485317,'furniture-mobile','.w-compare .compare-list-buttons','padding-bottom','10','','','.w-compare'),(485318,'furniture-mobile','.w-compare .item-holder','padding-bottom','10','','','.w-compare'),(485319,'furniture-mobile','.w-compare .compare-list-products','padding-bottom','0','','','.w-compare'),(485320,'furniture-mobile','.w-files-catalog-widgets-files-catalog .name','padding-bottom','10','','','.w-files-catalog-widgets-files-catalog'),(485321,'furniture-mobile','.w-sample .buttons','padding-bottom','15','','','.w-sample'),(485322,'furniture-mobile','.w-sample .buttons .btn','padding-bottom','4','','','.w-sample'),(485323,'furniture-mobile','.w-sample .cart-box-link','padding-bottom','0','','','.w-sample'),(485324,'furniture-mobile','.w-sample .cart-content','padding-bottom','5','','','.w-sample'),(485325,'furniture-mobile','.w-sample .cart-total','padding-bottom','10','','','.w-sample'),(485326,'furniture-mobile','.w-sample .multicart .cart-content','padding-bottom','0','','','.w-sample'),(485327,'furniture-mobile','.w-sample .multicart .item','padding-bottom','15','','','.w-sample'),(485328,'furniture-mobile','.w-sample .multicart .name','padding-bottom','0','','','.w-sample'),(485329,'furniture-mobile','.w-sample .no-text','padding-bottom','0','','','.w-sample'),(485330,'furniture-mobile','.w-sample a.item','padding-bottom','5','','','.w-sample'),(485331,'furniture-mobile','.w-cart-listing .item > div.points','padding-bottom','0','','','.w-cart-listing'),(485332,'furniture-mobile','.w-filters-simple .integrate-price-holder','padding-bottom','10','','','.w-filters-simple'),(485333,'furniture-mobile','.w-cart-discount-coupon .title','padding-bottom','7','','','.w-cart-discount-coupon'),(485334,'furniture-mobile','.w-product-video .item','padding-bottom','10','','','.w-product-video'),(485335,'furniture-mobile','.w-cart-bonus-points .title','padding-bottom','5','','','.w-cart-bonus-points'),(485336,'furniture-mobile','.shipping-ico .heading-3','padding-bottom','10','','','.shipping-ico'),(485337,'furniture-mobile','.w-cart-order-reference .btn','padding-bottom','4','','','.w-cart-order-reference'),(485338,'furniture-mobile','.w-cart-gift-certificate .btn','padding-bottom','4','','','.w-cart-gift-certificate'),(485339,'furniture-mobile','.w-cart-shipping-estimator .btn','padding-bottom','4','','','.w-cart-shipping-estimator'),(485340,'furniture-mobile','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(485341,'furniture-mobile','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(485342,'furniture-mobile','.w-product-in-bundles .attributes-item','padding-bottom','10','','','.w-product-in-bundles'),(485343,'furniture-mobile','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(485344,'furniture-mobile','.w-cart-listing .item > div.actions','padding-bottom','10','2876','','.w-cart-listing'),(485345,'furniture-mobile','.w-account-address-book .item','padding-bottom','10','','','.w-account-address-book'),(485346,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-bottom','0','','','.b-products-listing'),(485347,'furniture-mobile','.b-pagination ul.pagination','padding-bottom','0','','','.b-pagination'),(485348,'furniture-mobile','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','padding-bottom','10','','','.w-catalog-compare'),(485349,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .item','padding-bottom','3','','','.w-product-properties-filters-widgets-chosen-filters'),(485350,'furniture-mobile','.p-quote-checkout-index .datepicker-inline','padding-bottom','10','','','.p-quote-checkout-index'),(485351,'furniture-mobile','.p-sample-checkout-index .datepicker-inline','padding-bottom','10','','','.p-sample-checkout-index'),(485352,'furniture-mobile','.w-account-order-download td','padding-bottom','5','','','.w-account-order-download'),(485353,'furniture-mobile','.w-account-order-download td','padding-bottom','0','2876','','.w-account-order-download'),(485354,'furniture-mobile','.w-account-order-download tr','padding-bottom','10','2876','','.w-account-order-download'),(485355,'furniture-mobile','.w-product-multi-inventory .radio-attributes','padding-bottom','5','','','.w-product-multi-inventory'),(485356,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','padding-bottom','10','','','.w-product-multi-inventory'),(485357,'furniture-mobile','.w-product-multi-inventory .radio-attributes > label','padding-bottom','10','','','.w-product-multi-inventory'),(485358,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','padding-bottom','0','','','.w-account-personal-catalog'),(485359,'furniture-mobile','.w-account-personal-catalog .list-row-action li','padding-bottom','5','','','.w-account-personal-catalog'),(485360,'furniture-mobile','.w-account-personal-catalog .buy-box','padding-bottom','0','2876','','.w-account-personal-catalog'),(485361,'furniture-mobile','.b-products-listing .products-listing .radio-attributes','padding-bottom','5','','','.b-products-listing'),(485362,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','padding-bottom','10','','','.b-products-listing'),(485363,'furniture-mobile','.b-products-listing .products-listing .radio-attributes > label','padding-bottom','10','','','.b-products-listing'),(485364,'furniture-mobile','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(485365,'furniture-mobile','.w-product-collection .right-area .btn','padding-bottom','14','','','.w-product-collection'),(485366,'furniture-mobile','.w-account-customer-additional-field .tf-file','padding-bottom','5','','','.w-account-customer-additional-field'),(485367,'furniture-mobile','.w-product-collection .right-area','padding-bottom','20','2885','','.w-product-collection'),(485368,'furniture-mobile','.w-product-attributes .radio-attributes','padding-bottom','5','','','.w-product-attributes'),(485369,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','padding-bottom','10','','','.w-product-attributes'),(485370,'furniture-mobile','.w-product-attributes .radio-attributes > label','padding-bottom','10','','','.w-product-attributes'),(485371,'furniture-mobile','.w-product-properties .property-ul','padding-bottom','0','','','.w-product-properties'),(485372,'furniture-mobile','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(485373,'furniture-mobile','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(485374,'furniture-mobile','.w-product-groups ','padding-bottom','30','','','.w-product-groups'),(485375,'furniture-mobile','.w-product-groups .radioBox','padding-bottom','20','','','.w-product-groups'),(485376,'furniture-mobile','.w-product-groups .radioBox label','padding-bottom','0','','','.w-product-groups'),(485377,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','padding-bottom','20','','','.w-product-groups'),(485378,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','padding-bottom','5','2906','','.w-product-groups'),(485379,'furniture-mobile','.b-products-listing .mix-attributes .attribute-qty-block','padding-bottom','5','','','.b-products-listing'),(485380,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block','padding-bottom','5','','','.b-products-listing'),(485381,'furniture-mobile','.blogsidebar','padding-bottom','0','2885','',''),(485382,'furniture-mobile','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(485383,'furniture-mobile','.w-product-custom-bundle .chosen-products','padding-bottom','10','','','.w-product-custom-bundle'),(485384,'furniture-mobile','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-bottom','12','','','.w-product-custom-bundle'),(485385,'furniture-mobile','.w-product-custom-bundle .right-area .main-button','padding-bottom','20','2885','','.w-product-custom-bundle'),(485386,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list'),(485387,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list'),(485388,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list-block'),(485389,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list-block'),(485390,'furniture-mobile','.w-delivery-location-top-location-list .deliveryName','padding-bottom','10','','','.w-delivery-location-top-location-list'),(485391,'furniture-mobile','.w-delivery-location-location-list .deliveryName','padding-bottom','10','','','.w-delivery-location-location-list'),(485392,'furniture-mobile','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(485393,'furniture-mobile','.w-delivery-location-location-description .deliveryDesc','padding-bottom','10','','','.w-delivery-location-location-description'),(485394,'furniture-mobile','.w-delivery-location-location-long-description ','padding-bottom','20','','','.w-delivery-location-location-long-description'),(485395,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent a','padding-bottom','6','','','.w-delivery-location-location-list'),(485396,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','padding-bottom','10','','','.w-delivery-location-location-list'),(485397,'furniture-mobile','.w-delivery-location-featured-list .deliveryName','padding-bottom','10','','','.w-delivery-location-featured-list'),(485398,'furniture-mobile','.w-wedding-registry-widgets-search-form .closeable-heading','padding-bottom','10','','','.w-wedding-registry-widgets-search-form'),(485399,'furniture-mobile','.btn-2','padding-bottom','6','2876','',''),(485400,'furniture-mobile','.w-sale-category .holder-1','padding-bottom','20','','','.w-sale-category'),(485401,'furniture-mobile','.w-sale-category .holder-2','padding-bottom','20','','','.w-sale-category'),(485402,'furniture-mobile','.w-sale-category .left-count','padding-bottom','0','','','.w-sale-category'),(485403,'furniture-mobile','.w-sale-category .left-text-left','padding-bottom','24','','','.w-sale-category'),(485404,'furniture-mobile','.w-sale-category .left-text-right','padding-bottom','24','','','.w-sale-category'),(485405,'furniture-mobile','.w-product-wedding-registry-button .btn','padding-bottom','6','','','.w-product-wedding-registry-button'),(485406,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(485407,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(485408,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(485409,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(485410,'furniture-mobile','.w-product-properties-icons .property-image','padding-bottom','10','','','.w-product-properties-icons'),(485411,'furniture-mobile','.w-product-properties-icons .hover-box-content','padding-bottom','10','','','.w-product-properties-icons'),(485412,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','padding-bottom','15','','','.w-delivery-location-product-categories'),(485413,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','padding-bottom','10','2885','','.w-delivery-location-product-categories'),(485414,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','padding-bottom','10','2906','','.w-delivery-location-product-categories'),(485415,'furniture-mobile','.w-delivery-location-product-categories .name','padding-bottom','10','','','.w-delivery-location-product-categories'),(485416,'furniture-mobile','.w-catalog-delivery-locations .name','padding-bottom','10','','','.w-catalog-delivery-locations'),(485417,'furniture-mobile','.w-wedding-registry-widgets-search-paging ul.pagination','padding-bottom','0','','','.w-wedding-registry-widgets-search-paging'),(485418,'furniture-mobile','.w-wedding-registry-widgets-search-list .table td, .w-wedding-registry-widgets-search-list .table .headings td','padding-bottom','5','2885','','.w-wedding-registry-widgets-search-list'),(485419,'furniture-mobile','.w-wedding-registry-widgets-search-list .table .headings td','padding-bottom','5','','','.w-wedding-registry-widgets-search-list'),(485420,'furniture-mobile','.delivery-options-popup','padding-bottom','20','','',''),(485421,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','padding-bottom','7','','','.w-product-bonus-points'),(485422,'furniture-mobile','.w-product-designer-designer .grnamebox .title-sortable','padding-bottom','8','','','.w-product-designer-designer'),(485423,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','padding-bottom','10','','','.w-product-designer-designer'),(485424,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small ','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews-small'),(485425,'furniture-mobile','.w-press-reviews-widgets-press-reviews ','padding-bottom','30','','','.w-press-reviews-widgets-press-reviews'),(485426,'furniture-mobile','.w-press-reviews-widgets-press-reviews .author','padding-bottom','20','','','.w-press-reviews-widgets-press-reviews'),(485427,'furniture-mobile','.w-press-reviews-widgets-press-reviews .item','padding-bottom','20','','','.w-press-reviews-widgets-press-reviews'),(485428,'furniture-mobile','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-bottom','30','','','.w-press-reviews-widgets-press-reviews'),(485429,'furniture-mobile','.w-press-reviews-widgets-press-reviews .rating','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews'),(485430,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews'),(485431,'furniture-mobile','.w-press-reviews-widgets-press-reviews ','padding-bottom','20','2876','','.w-press-reviews-widgets-press-reviews'),(485432,'furniture-mobile','.w-press-reviews-widgets-press-reviews .author','padding-bottom','0','2876','','.w-press-reviews-widgets-press-reviews'),(485433,'furniture-mobile','.w-press-reviews-widgets-press-reviews .item','padding-bottom','15','2876','','.w-press-reviews-widgets-press-reviews'),(485434,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','padding-bottom','10','2876','','.w-press-reviews-widgets-press-reviews'),(485435,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .date-added','padding-bottom','20','','','.w-press-reviews-widgets-press-reviews-list'),(485436,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .item','padding-bottom','0','','','.w-press-reviews-widgets-press-reviews-list'),(485437,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .rating','padding-bottom','5','','','.w-press-reviews-widgets-press-reviews-list'),(485438,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .short-description','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(485439,'furniture-mobile','.b-products-listing .productGroup label a','padding-bottom','5','','','.b-products-listing'),(485440,'furniture-mobile','.w-support-system-filter ','padding-bottom','25','','','.w-support-system-filter'),(485441,'furniture-mobile','.w-support-system-filter .filter_cats','padding-bottom','0','','','.w-support-system-filter'),(485442,'furniture-mobile','.w-support-system-listing .support-head','padding-bottom','13','','','.w-support-system-listing'),(485443,'furniture-mobile','.w-communication-post .btn.refresh','padding-bottom','0','','','.w-communication-post'),(485444,'furniture-mobile','.w-rma-returns-history .btn','padding-bottom','7','','','.w-rma-returns-history'),(485445,'furniture-mobile','.w-rma-returns-history .column','padding-bottom','0','','','.w-rma-returns-history'),(485446,'furniture-mobile','.w-rma-returns-history .column .title','padding-bottom','5','','','.w-rma-returns-history'),(485447,'furniture-mobile','.w-rma-returns-history .topRow','padding-bottom','10','','','.w-rma-returns-history'),(485448,'furniture-mobile','.w-rma-returns-history .column:last-child .title','padding-bottom','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(485449,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','padding-bottom','5','','','.b-menu-style-1'),(485450,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .goto-button','padding-bottom','0','','','.b-menu-style-1'),(485451,'furniture-mobile','.w-product-designer-designer .productDesignerBox ul','padding-bottom','0','','','.w-product-designer-designer'),(485452,'furniture-mobile','.w-product-configurator .pc-item','padding-bottom','0','','','.w-product-configurator'),(485453,'furniture-mobile','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(485454,'furniture-mobile','.w-product-configurator .pc_item','padding-bottom','10','2885','','.w-product-configurator'),(485455,'furniture-mobile','.w-product-configurator .pc_attr','padding-bottom','5','2876','','.w-product-configurator'),(485456,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','padding-bottom','7','','','.b-products-listing'),(485457,'furniture-mobile','.b-products-listing .promos-info .promo-name-span','padding-bottom','3','','','.b-products-listing'),(485458,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-list'),(485459,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-bottom','20','','','.w-catalog-pages-category-pages-list'),(485460,'furniture-mobile','.w-predefined-promotion .nextdiscount .content > div','padding-bottom','10','','','.w-predefined-promotion'),(485461,'furniture-mobile','.w-predefined-promotion .nextdiscount .promo-for-each','padding-bottom','2','','','.w-predefined-promotion'),(485462,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-product','padding-bottom','20','','','.w-predefined-promotion'),(485463,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','padding-bottom','0','','','.w-predefined-promotion'),(485464,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .item','padding-bottom','20','','','.w-predefined-promotion'),(485465,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-bottom','0','','','.w-predefined-promotion'),(485466,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-bottom','0','','','.w-predefined-promotion'),(485467,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .heading','padding-bottom','1','','','.w-predefined-promotion'),(485468,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .item','padding-bottom','20','','','.w-predefined-promotion'),(485469,'furniture-mobile','.w-predefined-promotion .promo-item','padding-bottom','20','','','.w-predefined-promotion'),(485470,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','padding-bottom','0','','','.w-predefined-promotion'),(485471,'furniture-mobile','.w-predefined-promotion .promo-salemaker .item','padding-bottom','20','','','.w-predefined-promotion'),(485472,'furniture-mobile','.w-supplier-purchase-supplier-products .item','padding-bottom','10','','','.w-supplier-purchase-supplier-products'),(485473,'furniture-mobile','.w-filters .filter-box-content ul','padding-bottom','20','','','.w-filters'),(485474,'furniture-mobile','.mainBanner .bottomBox','padding-bottom','55','','','.mainBanner'),(485475,'furniture-mobile','.mainBanner .bottomBox .btn','padding-bottom','1.09','','','.mainBanner'),(485476,'furniture-mobile','.mainBanner .title','padding-bottom','30','','','.mainBanner'),(485477,'furniture-mobile','.mainBanner .topBox > .right','padding-bottom','5','','','.mainBanner'),(485478,'furniture-mobile','.mainBanner .wrapper','padding-bottom','0','','','.mainBanner'),(485479,'furniture-mobile','.mainBanner .bottomBox','padding-bottom','33','2890','','.mainBanner'),(485480,'furniture-mobile','.mainBanner .bottomBox .btn','padding-bottom','8','2890','','.mainBanner'),(485481,'furniture-mobile','.mainBanner .topBox > .right','padding-bottom','5','2890','','.mainBanner'),(485482,'furniture-mobile','.mainBanner .wrapper','padding-bottom','0','2890','','.mainBanner'),(485483,'furniture-mobile','.mainBanner .bottomBox .btn','padding-bottom','6','2885','','.mainBanner'),(485484,'furniture-mobile','.mainBanner .title','padding-bottom','15','2885','','.mainBanner'),(485485,'furniture-mobile','.mainBanner .topBox > .right','padding-bottom','5','2876','','.mainBanner'),(485486,'furniture-mobile','.mainBanner .wrapper','padding-bottom','3','2876','','.mainBanner'),(485487,'furniture-mobile','.mainBanner .bottomBox','padding-bottom','25','2906','','.mainBanner'),(485488,'furniture-mobile','.mainBanner .bottomBox .btn','padding-bottom','4','2906','','.mainBanner'),(485489,'furniture-mobile','.mainBanner .wrapper','padding-bottom','8','2906','','.mainBanner'),(485490,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','padding-bottom','15','','','.lowestPricedBox'),(485491,'furniture-mobile','.lowestPricedBox .w-banner .ybg .mark','padding-bottom','10','','','.lowestPricedBox'),(485492,'furniture-mobile','.lowestPricedBox .w-banner .banner','padding-bottom','0','2876','','.lowestPricedBox'),(485493,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','padding-bottom','10','2906','','.lowestPricedBox'),(485494,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','padding-bottom','4','2906','','.lowestPricedBox'),(485495,'furniture-mobile','.lowestPricedBox .w-banner .ybg .mark','padding-bottom','5','2906','','.lowestPricedBox'),(485496,'furniture-mobile','.shopByCollectionBox .bannerButton a','padding-bottom','6','','','.shopByCollectionBox'),(485497,'furniture-mobile','.shopByCollectionBox .content','padding-bottom','10','','','.shopByCollectionBox'),(485498,'furniture-mobile','.shopByCollectionBox .bannerButton a','padding-bottom','6','2890','','.shopByCollectionBox'),(485499,'furniture-mobile','.w-cart-shipping-estimator .estimate-shipping','padding-bottom','20','2876','','.w-cart-shipping-estimator'),(485500,'furniture-mobile','.w-quote-products .no-price','padding-bottom','15','','','.w-quote-products'),(485501,'furniture-mobile','.w-search .products','padding-bottom','15','','','.w-search'),(485502,'furniture-mobile','.w-search .products .item a','padding-bottom','10','','','.w-search'),(485503,'furniture-mobile','.w-search .wrap','padding-bottom','25','','','.w-search'),(485504,'furniture-mobile','.account-address-book .address_book','padding-bottom','30','','','.account-address-book'),(485505,'furniture-mobile','.account-address-book .address_book h1','padding-bottom','5','','','.account-address-book'),(485506,'furniture-mobile','.account-address-book .address_book h2','padding-bottom','10','','','.account-address-book'),(485507,'furniture-mobile','.account-address-book .address_book, .account-address-book .account_history_info','padding-bottom','10','','','.account-address-book'),(485508,'furniture-mobile','.account-address-book .btn-edit','padding-bottom','0','4','','.account-address-book'),(485509,'furniture-mobile','.account-address-book .buttonBox','padding-bottom','15','','','.account-address-book'),(485510,'furniture-mobile','.account-address-book .rightMes ul','padding-bottom','0','','','.account-address-book'),(485511,'furniture-mobile','.account-address-book .topButtons','padding-bottom','15','','','.account-address-book'),(485512,'furniture-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','padding-bottom','10','','','.account-order-history'),(485513,'furniture-mobile','.account-order-history .orders-table th','padding-bottom','2','','','.account-order-history'),(485514,'furniture-mobile','.account-order-history .order_history_table th','padding-bottom','10','','','.account-order-history'),(485515,'furniture-mobile','.account-order-history .view_link','padding-bottom','0','','','.account-order-history'),(485516,'furniture-mobile','.account-order-history .orders-table .item','padding-bottom','60','2885','','.account-order-history'),(485517,'furniture-mobile','.account-order-history .orders-table .td-alignright','padding-bottom','5','2885','','.account-order-history'),(485518,'furniture-mobile','.account-order-history .orders-table td','padding-bottom','5','2885','','.account-order-history'),(485519,'furniture-mobile','.account-order-history-info .contentColumn','padding-bottom','10','','','.account-order-history-info'),(485520,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','padding-bottom','5','','','.account-order-history-info'),(485521,'furniture-mobile','.account-order-history-info .history_info > div + div','padding-bottom','0','','','.account-order-history-info'),(485522,'furniture-mobile','.account-order-history-info .popup-tracking-number','padding-bottom','10','','','.account-order-history-info'),(485523,'furniture-mobile','.account-order-history-info .history_info > div','padding-bottom','0','2885','','.account-order-history-info'),(485524,'furniture-mobile','.account-order-history-info .history_info > div + div','padding-bottom','0','2885','','.account-order-history-info'),(485525,'furniture-mobile','.account-index .account_block','padding-bottom','20','','','.account-index'),(485526,'furniture-mobile','.account-index .account_info','padding-bottom','0','','','.account-index'),(485527,'furniture-mobile','.account-index .account_info .info','padding-bottom','25','','','.account-index'),(485528,'furniture-mobile','.account-index .account_info li','padding-bottom','0','','','.account-index'),(485529,'furniture-mobile','.account-index .account_page','padding-bottom','0','','','.account-index'),(485530,'furniture-mobile','.account-index .badc_bottom','padding-bottom','58','','','.account-index'),(485531,'furniture-mobile','.account-index .date_title','padding-bottom','0','','','.account-index'),(485532,'furniture-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','padding-bottom','10','','','.account-index'),(485533,'furniture-mobile','.account-index .rightMes ul','padding-bottom','0','','','.account-index'),(485534,'furniture-mobile','.account-index .topAccount','padding-bottom','17','','','.account-index'),(485535,'furniture-mobile','.account-index .topAccount > li','padding-bottom','0','','','.account-index'),(485536,'furniture-mobile','.account-index .view_link','padding-bottom','0','','','.account-index'),(485537,'furniture-mobile','.account-index .account_info','padding-bottom','0','2885','','.account-index'),(485538,'furniture-mobile','.account-index .orders-table .item','padding-bottom','45','2885','','.account-index'),(485539,'furniture-mobile','.account-index .orders-table .links','padding-bottom','5','2885','','.account-index'),(485540,'furniture-mobile','.account-index .orders-table td','padding-bottom','5','2885','','.account-index'),(485541,'furniture-mobile','.account-index .account_info li','padding-bottom','10','2876','','.account-index'),(485542,'furniture-mobile','.account-index .topAccount > li','padding-bottom','10','2876','','.account-index'),(485543,'furniture-mobile','.account-index .topAccount > li > div','padding-bottom','0','2876','','.account-index'),(485544,'furniture-mobile','.account-order-pay .contentColumn','padding-bottom','10','','','.account-order-pay'),(485545,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-bottom','5','','','.account-order-pay'),(485546,'furniture-mobile','.account-order-pay .history_info > div + div','padding-bottom','0','','','.account-order-pay'),(485547,'furniture-mobile','.account-order-pay .history_info > div','padding-bottom','0','2885','','.account-order-pay'),(485548,'furniture-mobile','.account-order-pay .history_info > div + div','padding-bottom','0','2885','','.account-order-pay'),(485549,'furniture-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-bottom','10','','','.account-samples'),(485550,'furniture-mobile','.account-samples .orders-table th','padding-bottom','2','','','.account-samples'),(485551,'furniture-mobile','.account-samples .order_history_table th','padding-bottom','10','','','.account-samples'),(485552,'furniture-mobile','.account-samples .view_link','padding-bottom','0','','','.account-samples'),(485553,'furniture-mobile','.account-samples .orders-table .item','padding-bottom','60','2885','','.account-samples'),(485554,'furniture-mobile','.account-samples .orders-table .td-alignright','padding-bottom','5','2885','','.account-samples'),(485555,'furniture-mobile','.account-samples .orders-table td','padding-bottom','5','2885','','.account-samples'),(485556,'furniture-mobile','.account-sample-info .contentColumn','padding-bottom','10','','','.account-sample-info'),(485557,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-bottom','5','','','.account-sample-info'),(485558,'furniture-mobile','.account-sample-info .history_info > div + div','padding-bottom','0','','','.account-sample-info'),(485559,'furniture-mobile','.account-sample-info .popup-tracking-number','padding-bottom','10','','','.account-sample-info'),(485560,'furniture-mobile','.account-sample-info .history_info > div','padding-bottom','0','2885','','.account-sample-info'),(485561,'furniture-mobile','.account-sample-info .history_info > div + div','padding-bottom','0','2885','','.account-sample-info'),(485562,'furniture-mobile','.catalog-product-wrap .next-product','padding-bottom','20','','','.catalog-product-wrap'),(485563,'furniture-mobile','.catalog-product-wrap .pn-direction','padding-bottom','0','','','.catalog-product-wrap'),(485564,'furniture-mobile','.catalog-product-wrap .pn-image','padding-bottom','20','','','.catalog-product-wrap'),(485565,'furniture-mobile','.catalog-product-wrap .prev-product','padding-bottom','20','','','.catalog-product-wrap'),(485566,'furniture-mobile','.catalog-product-wrap .next-product','padding-bottom','20','2885','','.catalog-product-wrap'),(485567,'furniture-mobile','.catalog-product-wrap .pn-direction','padding-bottom','0','2885','','.catalog-product-wrap'),(485568,'furniture-mobile','.catalog-product-wrap .prev-product','padding-bottom','20','2885','','.catalog-product-wrap'),(485569,'furniture-mobile','.shopping-cart-index .btn-3','padding-bottom','11','','','.shopping-cart-index'),(485570,'furniture-mobile','.shopping-cart-index .cart-page .empty','padding-bottom','100','','','.shopping-cart-index'),(485571,'furniture-mobile','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-bottom','10','','','.shopping-cart-index'),(485572,'furniture-mobile','.checkout-index-wrap .datepicker-inline','padding-bottom','10','','','.checkout-index-wrap'),(485573,'furniture-mobile','.checkout-index-wrap .edit-address-popup','padding-bottom','20','','','.checkout-index-wrap'),(485574,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-bottom','6','','','.checkout-index-wrap'),(485575,'furniture-mobile','.checkout-order-confirmation .price-row','padding-bottom','5','','','.checkout-order-confirmation'),(485576,'furniture-mobile','.p-blog-index .comment-list','padding-bottom_important','important','','','.p-blog-index'),(485577,'furniture-mobile','.p-blog-index .comment-list','padding-bottom_important','important','','','.p-blog-index'),(485578,'furniture-mobile','.p-blog-index .comment-list','padding-bottom_important','important','','','.p-blog-index'),(485579,'furniture-mobile','.p-blog-index .comment-list','padding-bottom_important','important','','','.p-blog-index'),(485580,'furniture-mobile','.p-blog-index .comment-list','padding-bottom_important','important','','','.p-blog-index'),(485581,'furniture-mobile','.b-data-table table.dataTable tbody td','padding-bottom_important','important','','','.b-data-table'),(485582,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom_important','important','','','.b-data-table'),(485583,'furniture-mobile','.b-data-table table.dataTable thead td','padding-bottom_important','important','','','.b-data-table'),(485584,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom_important','important','','','.b-data-table'),(485585,'furniture-mobile','.p-blog-index .comment-list','padding-bottom_important','important','','','.p-blog-index'),(485586,'furniture-mobile','.batchPr .w-batch-products','padding-bottom_important','important','','','.batchPr'),(485587,'furniture-mobile','.w-cart-listing .points','padding-bottom_important','important','2876','','.w-cart-listing'),(485588,'furniture-mobile','.w-account-personal-catalog .buy-box','padding-bottom_important','important','2876','','.w-account-personal-catalog'),(485589,'furniture-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-left','10','','','.w-communication-new-topic'),(485591,'furniture-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(485592,'furniture-mobile','.b-email .name','padding-left','10','','','.b-email'),(485593,'furniture-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(485594,'furniture-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(485595,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(485596,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-left','10','','','.p-account-subscription-historyinfo'),(485597,'furniture-mobile','.order-summary .btn-2, .order-summary .btn-3','padding-left','5','','','.order-summary'),(485598,'furniture-mobile','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(485599,'furniture-mobile','.w-promo-code .holder','padding-left','20','2906','','.w-promo-code'),(485600,'furniture-mobile','.w-cart .multicart .cart-content','padding-left','0','','','.w-cart'),(485601,'furniture-mobile','.w-cart .cart-total','padding-left','0','','','.w-cart'),(485602,'furniture-mobile','.w-catalog-paging .next','padding-left','5','','','.w-catalog-paging'),(485603,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(485604,'furniture-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(485605,'furniture-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(485606,'furniture-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-left','10','','','.p-quick-order-index'),(485607,'furniture-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-left','10','','','.p-quick-order-index'),(485608,'furniture-mobile','.p-quick-order-index ul.token-input-list','padding-left','0','','','.p-quick-order-index'),(485609,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.p-quick-order-index'),(485610,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.p-quick-order-index'),(485611,'furniture-mobile','.w-promotions .promo-item','padding-left','40','','','.w-promotions'),(485612,'furniture-mobile','.w-top-categories h2.name','padding-left','3','','','.w-top-categories'),(485613,'furniture-mobile','.w-sale .holder-2','padding-left','20','','','.w-sale'),(485614,'furniture-mobile','.w-sale .left-count','padding-left','5','','','.w-sale'),(485615,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-left','0','','','.p-blog-index'),(485616,'furniture-mobile','.p-blog-index .comments-area ol ol','padding-left','50','','','.p-blog-index'),(485617,'furniture-mobile','.w-cart-compare .attributes-label','padding-left','10','','','.w-cart-compare'),(485618,'furniture-mobile','.w-account .acc-returning','padding-left','0','','','.w-account'),(485619,'furniture-mobile','.w-account .account-dropdown','padding-left','25','','','.w-account'),(485620,'furniture-mobile','.w-account .account-top','padding-left','0','','','.w-account'),(485621,'furniture-mobile','.w-account .my-acc-link','padding-left','10','','','.w-account'),(485622,'furniture-mobile','.w-account .no-text','padding-left','10','','','.w-account'),(485623,'furniture-mobile','.w-wedding-registry-widgets-delete-link a','padding-left','12','','','.w-wedding-registry-widgets-delete-link'),(485624,'furniture-mobile','.w-wedding-registry-widgets-share-link a','padding-left','12','','','.w-wedding-registry-widgets-share-link'),(485625,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(485626,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-left','0','','','.p-reviews-info'),(485627,'furniture-mobile','.p-reviews-info .review-info-image','padding-left','20','','','.p-reviews-info'),(485628,'furniture-mobile','.p-reviews-info .review-info-text','padding-left','10','','','.p-reviews-info'),(485629,'furniture-mobile','.p-reviews-info .review-info-content','padding-left','20','','','.p-reviews-info'),(485630,'furniture-mobile','.p-blog-index .wp-widget ul','padding-left','0','','','.p-blog-index'),(485631,'furniture-mobile','.p-blog-index .nav-previous','padding-left','50','','','.p-blog-index'),(485632,'furniture-mobile','.p-blog-index .nav-links','padding-left','0','','','.p-blog-index'),(485633,'furniture-mobile','.p-account-trade-form .widget','padding-left','0','','','.p-account-trade-form'),(485634,'furniture-mobile','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(485635,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(485636,'furniture-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(485637,'furniture-mobile','.b-email .name','padding-left','10','','','.b-email'),(485638,'furniture-mobile','.testimonials .review','padding-left','10','','',''),(485639,'furniture-mobile','.testimonials .heading-3','padding-left','55','','',''),(485640,'furniture-mobile','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(485641,'furniture-mobile','.w-categories .image','padding-left','0','','','.w-categories'),(485642,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','padding-left','20','','','.w-promotions'),(485643,'furniture-mobile','.w-promotions .prom-multi-discount .promo-product','padding-left','20','','','.w-promotions'),(485644,'furniture-mobile','.w-promotions .nextdiscount .promo-for-each','padding-left','10','','','.w-promotions'),(485645,'furniture-mobile','.w-promotions .nextdiscount .content > div','padding-left','10','','','.w-promotions'),(485646,'furniture-mobile','.w-promotions .promo-salemaker .item','padding-left','20','','','.w-promotions'),(485647,'furniture-mobile','.w-promotions .promo-salemaker .promo-manufacturers','padding-left','12','','','.w-promotions'),(485648,'furniture-mobile','.w-promotions .promo-salemaker .discount','padding-left','20','','','.w-promotions'),(485649,'furniture-mobile','.w-promotions .promo-cart-discount .slave .item','padding-left','20','','','.w-promotions'),(485650,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-left','20','','','.w-promotions'),(485651,'furniture-mobile','.w-promotions .promo-cart-discount .slave','padding-left','15','','','.w-promotions'),(485652,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-left','20','','','.w-promotions'),(485653,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','padding-left','17','','','.b-warehouses-popup'),(485654,'furniture-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-left','20','','','.b-warehouses-popup'),(485655,'furniture-mobile','.w-product-available-in-warehouses .warehouse-item','padding-left','0','','','.w-product-available-in-warehouses'),(485656,'furniture-mobile','.w-checkout-create-account .account-benefits ul','padding-left','20','','','.w-checkout-create-account'),(485657,'furniture-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-left','2','','','.b-products-listing'),(485658,'furniture-mobile','.w-account .acc-new','padding-left','10','','','.w-account'),(485659,'furniture-mobile','.w-cart-compare .dropdown li','padding-left','10','','','.w-cart-compare'),(485660,'furniture-mobile','.w-cart-compare .attributes-cell','padding-left','20','','','.w-cart-compare'),(485661,'furniture-mobile','.w-cart a.item','padding-left','90','','','.w-cart'),(485662,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(485663,'furniture-mobile','.w-menu .hided.menu ul li','padding-left','0','','','.w-menu'),(485664,'furniture-mobile','.w-login-block .new','padding-left','40','','','.w-login-block'),(485665,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-left','10','','','.p-blog-index'),(485666,'furniture-mobile','.p-blog-index .comments-area ol ol','padding-left','50','','','.p-blog-index'),(485667,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','','','.w-menu-style-1'),(485668,'furniture-mobile','.b-bottom .confirm-popup .confirm-text','padding-left','0','','','.b-bottom'),(485669,'furniture-mobile','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(485670,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(485671,'furniture-mobile','.b-messages .messages-menu ul','padding-left','0','','','.b-messages'),(485672,'furniture-mobile','.b-messages .development-content .type-6 .content','padding-left','0','','','.b-messages'),(485673,'furniture-mobile','.b-messages .msv_btn','padding-left','0','','','.b-messages'),(485674,'furniture-mobile','.b-messages .msv_content','padding-left','20','','','.b-messages'),(485675,'furniture-mobile','.b-messages .msv_history','padding-left','20','','','.b-messages'),(485676,'furniture-mobile','.b-messages .messMenuButton span','padding-left','15','','','.b-messages'),(485677,'furniture-mobile','.b-messages .messages-menu li a','padding-left','0','','','.b-messages'),(485678,'furniture-mobile','.b-messages .messages-menu li','padding-left','0','','','.b-messages'),(485679,'furniture-mobile','.b-messages .content_management_attach button','padding-left','27','','','.b-messages'),(485680,'furniture-mobile','.b-messages .email-heading','padding-left','15','','','.b-messages'),(485681,'furniture-mobile','.b-messages .content_management_attach','padding-left','8','','','.b-messages'),(485682,'furniture-mobile','.b-messages .emailLineTextArea textarea','padding-left','10','','','.b-messages'),(485683,'furniture-mobile','.b-messages .msv_to_cc','padding-left','15','','','.b-messages'),(485684,'furniture-mobile','.b-messages .emailBtn','padding-left','10','','','.b-messages'),(485685,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-left','10','','','.b-messages'),(485686,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-left','0','','','.w-sitemap-delivery-location'),(485687,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-left','10','','',''),(485688,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul ul','padding-left','20','','','.w-sitemap-delivery-location'),(485689,'furniture-mobile','.w-tabs .tab-navigation','padding-left','0','','','.w-tabs'),(485690,'furniture-mobile','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(485691,'furniture-mobile','.w-reviews-content .item','padding-left','0','','','.w-reviews-content'),(485692,'furniture-mobile','.p-quick-order-index .bottom','padding-left','0','','','.p-quick-order-index'),(485693,'furniture-mobile','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(485694,'furniture-mobile','.p-reviews-info .review-info-content','padding-left','20','','','.p-reviews-info'),(485695,'furniture-mobile','.p-blog-index .wp-widget li','padding-left','15','','','.p-blog-index'),(485696,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-left','0','','','.p-blog-index'),(485697,'furniture-mobile','.w-menu-style-1 ul','padding-left','0','','','.w-menu-style-1'),(485698,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','','','.w-menu-style-1'),(485699,'furniture-mobile','.w-sitemap-delivery-location > ul','padding-left','0','','','.w-sitemap-delivery-location'),(485700,'furniture-mobile','.w-checkout-terms .required-message','padding-left','10','','','.w-checkout-terms'),(485701,'furniture-mobile','.w-cart-listing .item .remove','padding-left','10','2885','','.w-cart-listing'),(485702,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(485703,'furniture-mobile','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(485704,'furniture-mobile','.w-socials > li','padding-left','15','','','.w-socials'),(485705,'furniture-mobile','.b-info .info','padding-left','40','','','.b-info'),(485706,'furniture-mobile','.b-form .required-message-wrap','padding-left','0','','','.b-form'),(485707,'furniture-mobile','.b-email .image','padding-left','10','','','.b-email'),(485708,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-left','0','','','.w-menu-slider'),(485709,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','','','.w-menu-style-1'),(485710,'furniture-mobile','.w-catalog-paging .paging-item','padding-left','2','','','.w-catalog-paging'),(485711,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-left','10','','','.p-account-subscription-historyinfo'),(485712,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-left','20','','','.p-account-trade-form'),(485713,'furniture-mobile','.p-account-trade-form .widget','padding-left','0','','','.p-account-trade-form'),(485714,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-left','10','','','.p-blog-index'),(485715,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-preview','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(485716,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(485717,'furniture-mobile','.b-table .table .headings td','padding-left','10','','','.b-table'),(485718,'furniture-mobile','.b-info .info li','padding-left','0','','','.b-info'),(485719,'furniture-mobile','.b-email .model','padding-left','10','','','.b-email'),(485720,'furniture-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(485721,'furniture-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(485722,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','padding-left','30','','','.b-products-listing'),(485723,'furniture-mobile','.w-login-block .guest','padding-left','40','','','.w-login-block'),(485724,'furniture-mobile','.w-login-block .new','padding-left','40','','','.w-login-block'),(485725,'furniture-mobile','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(485726,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-left','10','','','.w-menu-horizontal'),(485727,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li','padding-left','10','','','.w-menu-horizontal'),(485728,'furniture-mobile','.w-menu-horizontal ul','padding-left','0','','','.w-menu-horizontal'),(485729,'furniture-mobile','.w-menu-slider > ul > li > a','padding-left','10','','','.w-menu-slider'),(485730,'furniture-mobile','.w-sale .holder-1','padding-left','20','','','.w-sale'),(485731,'furniture-mobile','.b-table .table td','padding-left','15','','','.b-table'),(485732,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(485733,'furniture-mobile','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(485734,'furniture-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(485735,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(485736,'furniture-mobile','.w-product-images-additional .images','padding-left','0','2906','','.w-product-images-additional'),(485737,'furniture-mobile','.b-form .login-col-1','padding-left','0','','','.b-form'),(485738,'furniture-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(485739,'furniture-mobile','.w-menu .hided.menu li li a','padding-left','40','2885','','.w-menu'),(485740,'furniture-mobile','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(485741,'furniture-mobile','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-left','0','','','.order-summary'),(485742,'furniture-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(485743,'furniture-mobile','.b-email .price','padding-left','10','','','.b-email'),(485744,'furniture-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(485746,'furniture-mobile','.w-menu-style-1 ul','padding-left','0','','','.w-menu-style-1'),(485747,'furniture-mobile','.w-menu .hided.menu li li li a','padding-left','60','2885','','.w-menu'),(485748,'furniture-mobile','.p-account-trade-form .widget','padding-left','0','','','.p-account-trade-form'),(485749,'furniture-mobile','.w-categories .item','padding-left','20','','','.w-categories'),(485750,'furniture-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(485751,'furniture-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(485752,'furniture-mobile','.p-blog-index .nav-links','padding-left','0','','','.p-blog-index'),(485753,'furniture-mobile','.p-reviews-info .review-info-image','padding-left','20','','','.p-reviews-info'),(485754,'furniture-mobile','.b-bottom .terms-info-popup .pop-up-content','padding-left','20','','','.b-bottom'),(485755,'furniture-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-left','0','','','.w-cart-compare'),(485756,'furniture-mobile','textarea','padding-left','10','','',''),(485757,'furniture-mobile','.w-menu-style-1 ul','padding-left','0','','','.w-menu-style-1'),(485758,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-left','0','','','.w-menu-slider'),(485759,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','','','.w-menu-style-1'),(485760,'furniture-mobile','.w-catalog-paging .prev','padding-left','5','','','.w-catalog-paging'),(485761,'furniture-mobile','.w-menu .hided.menu ul li','padding-left','0','','','.w-menu'),(485762,'furniture-mobile','.w-languages .current','padding-left','10','2885','','.w-languages'),(485763,'furniture-mobile','.w-languages .lang-link','padding-left','10','','','.w-languages'),(485764,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','2885','','.w-menu-style-1'),(485765,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','2885','','.w-menu-style-1'),(485766,'furniture-mobile','.w-socials > li','padding-left','15','','','.w-socials'),(485767,'furniture-mobile','.w-reviews-content .review','padding-left','20','','','.w-reviews-content'),(485768,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-left','0','','','.w-menu'),(485769,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-left','10','','','.w-menu-slider'),(485770,'furniture-mobile','.w-filters .filter-ul-content','padding-left','0','','','.w-filters'),(485771,'furniture-mobile','.message.success','padding-left','40','','',''),(485772,'furniture-mobile','.p-blog-index .wp-widget ul','padding-left','0','','','.p-blog-index'),(485773,'furniture-mobile','.p-reviews-info .review-info-content','padding-left','20','','','.p-reviews-info'),(485774,'furniture-mobile','.p-reviews-info .review-info-image','padding-left','20','','','.p-reviews-info'),(485775,'furniture-mobile','.p-reviews-info .review-info-text','padding-left','10','','','.p-reviews-info'),(485776,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-left','0','','','.p-reviews-info'),(485777,'furniture-mobile','.p-blog-index .wp-widget li','padding-left','15','','','.p-blog-index'),(485778,'furniture-mobile','.p-quick-order-index .all-scroll-div','padding-left','0','','','.p-quick-order-index'),(485779,'furniture-mobile','.w-personal-gift-status-bar .end-label','padding-left','5','','','.w-personal-gift-status-bar'),(485780,'furniture-mobile','.p-blog-index .comments-area ol ol','padding-left','20','2906','','.p-blog-index'),(485781,'furniture-mobile','.w-promo-code .heading-4','padding-left','30','2906','','.w-promo-code'),(485782,'furniture-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(485783,'furniture-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(485784,'furniture-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(485785,'furniture-mobile','.b-email .name','padding-left','10','','','.b-email'),(485786,'furniture-mobile','.b-email .qty','padding-left','10','','','.b-email'),(485787,'furniture-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(485788,'furniture-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-left','0','','','.b-fancybox'),(485789,'furniture-mobile','.w-checkout-shipping-choice span','padding-left','0','','','.w-checkout-shipping-choice'),(485791,'furniture-mobile','.w-menu .hided.menu li li li a','padding-left','60','2885','','.w-menu'),(485792,'furniture-mobile','.b-info .info','padding-left','40','','','.b-info'),(485793,'furniture-mobile','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(485794,'furniture-mobile','.b-fancybox .fancybox-title-over-wrap','padding-left','10','','','.b-fancybox'),(485795,'furniture-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(485796,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-left','0','','','.b-select-suggest'),(485797,'furniture-mobile','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(485798,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-left','20','','','.w-menu-style-1'),(485799,'furniture-mobile','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(485800,'furniture-mobile','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(485801,'furniture-mobile','.w-reviews .review','padding-left','0','','','.w-reviews'),(485802,'furniture-mobile','.w-socials > li','padding-left','15','','','.w-socials'),(485803,'furniture-mobile','.w-search .items-title','padding-left','0','','','.w-search'),(485804,'furniture-mobile','.w-search .search-input','padding-left','10','','','.w-search'),(485805,'furniture-mobile','.b-compare .popupCompare td.level-2:first-child','padding-left','12','','','.b-compare'),(485806,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','2885','','.w-menu-style-1'),(485807,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','2885','','.w-menu-style-1'),(485808,'furniture-mobile','.b-info-popup .info-popup div','padding-left','15','','','.b-info-popup'),(485809,'furniture-mobile','.b-form .payment-method .item','padding-left','0','','','.b-form'),(485810,'furniture-mobile','.b-form .password-forgotten-link','padding-left','0','','','.b-form'),(485811,'furniture-mobile','.p-blog-index .wp-widget li','padding-left','15','','','.p-blog-index'),(485812,'furniture-mobile','.p-reviews-info .review-info-content','padding-left','20','','','.p-reviews-info'),(485813,'furniture-mobile','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(485814,'furniture-mobile','.w-cart-compare .price-label','padding-left','10','','','.w-cart-compare'),(485815,'furniture-mobile','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(485816,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-left','10','','','.w-image-maps'),(485817,'furniture-mobile','.w-promo-code .holder','padding-left','20','2906','','.w-promo-code'),(485818,'furniture-mobile','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(485819,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','2885','','.w-menu-style-1'),(485820,'furniture-mobile','.w-menu .hided.menu li li li a','padding-left','60','2885','','.w-menu'),(485821,'furniture-mobile','.p-blog-index .comments-area ol ol','padding-left','20','2906','','.p-blog-index'),(485822,'furniture-mobile','.w-reviews .heading-3','padding-left','55','','','.w-reviews'),(485823,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(485824,'furniture-mobile','.w-text .customer-service','padding-left','30','','','.w-text'),(485825,'furniture-mobile','.b-email .name','padding-left','10','','','.b-email'),(485827,'furniture-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(485828,'furniture-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(485829,'furniture-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(485830,'furniture-mobile','.b-email .image','padding-left','10','','','.b-email'),(485831,'furniture-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(485832,'furniture-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(485833,'furniture-mobile','.b-email .price','padding-left','10','','','.b-email'),(485834,'furniture-mobile','.w-sale .left-count','padding-left','5','','','.w-sale'),(485835,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-left','10','','','.w-menu-slider'),(485836,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-left','0','','','.w-menu-slider'),(485837,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','','','.w-menu-style-1'),(485838,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','','','.w-menu-style-1'),(485839,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-left','20','','','.w-menu-style-1'),(485840,'furniture-mobile','.w-menu-style-1 ul','padding-left','0','','','.w-menu-style-1'),(485841,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(485842,'furniture-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-left','0','','','.w-multi-cart-actions'),(485843,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','2885','','.w-menu-style-1'),(485844,'furniture-mobile','.w-text .customer-service','padding-left','30','','','.w-text'),(485845,'furniture-mobile','.w-top-categories .item','padding-left','20','','','.w-top-categories'),(485846,'furniture-mobile','.w-tabs > .block','padding-left','20','','','.w-tabs'),(485847,'furniture-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-left','0','','','.w-cart-cart-tabs'),(485848,'furniture-mobile','.w-tabs .accordion-heading','padding-left','8','2876','','.w-tabs'),(485849,'furniture-mobile','.w-tabs .tab-a','padding-left','6','','','.w-tabs'),(485850,'furniture-mobile','.w-tabs .tab-li','padding-left','0','','','.w-tabs'),(485851,'furniture-mobile','.w-socials > li','padding-left','15','','','.w-socials'),(485852,'furniture-mobile','.w-search .suggest','padding-left','0','','','.w-search'),(485853,'furniture-mobile','.w-search .name','padding-left','10','','','.w-search'),(485854,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(485855,'furniture-mobile','.b-bottom .popup-box-wrap','padding-left','10','','','.b-bottom'),(485856,'furniture-mobile','.b-bottom .popup-buttons','padding-left','15','','','.b-bottom'),(485857,'furniture-mobile','.w-menu .hided.menu li a','padding-left','20','2885','','.w-menu'),(485858,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','2885','','.w-menu-style-1'),(485859,'furniture-mobile','.p-account-trade-form .widget','padding-left','0','','','.p-account-trade-form'),(485860,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(485861,'furniture-mobile','.w-chat .w-chat-box','padding-left','12','','','.w-chat'),(485862,'furniture-mobile','.w-sale .holder-1','padding-left','20','','','.w-sale'),(485863,'furniture-mobile','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(485864,'furniture-mobile','.b-form .required-message','padding-left','3','','','.b-form'),(485865,'furniture-mobile','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(485866,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(485867,'furniture-mobile','.w-sale .left-count','padding-left','5','','','.w-sale'),(485868,'furniture-mobile','.w-sale .holder-2','padding-left','20','','','.w-sale'),(485869,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-left','0','','','.p-blog-index'),(485870,'furniture-mobile','.p-blog-index .comments-area ol ol','padding-left','50','','','.p-blog-index'),(485871,'furniture-mobile','.p-blog-index .wp-widget li','padding-left','15','','','.p-blog-index'),(485872,'furniture-mobile','.p-blog-index .wp-widget ul','padding-left','0','','','.p-blog-index'),(485873,'furniture-mobile','.btn-1','padding-left','25','','',''),(485874,'furniture-mobile','.b-autocomplete .ui-autocomplete li','padding-left','10','','','.b-autocomplete'),(485875,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','','','.w-menu-style-1'),(485876,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-left','10','','','.w-menu-slider'),(485877,'furniture-mobile','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(485878,'furniture-mobile','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(485879,'furniture-mobile','.b-table .table td','padding-left','15','','','.b-table'),(485880,'furniture-mobile','.b-table .table .headings td','padding-left','10','','','.b-table'),(485881,'furniture-mobile','.w-socials > li','padding-left','15','','','.w-socials'),(485882,'furniture-mobile','.w-login-block .guest','padding-left','40','','','.w-login-block'),(485883,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-left','10','','','.w-menu-slider'),(485884,'furniture-mobile','.b-products-listing .products-listing .buyButton .btn','padding-left','10','','','.b-products-listing'),(485885,'furniture-mobile','.w-product-images-additional .images','padding-left','0','2906','','.w-product-images-additional'),(485886,'furniture-mobile','.b-products-listing .products-listing .bonus-points-price','padding-left','20','','','.b-products-listing'),(485887,'furniture-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(485888,'furniture-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(485890,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','2885','','.w-menu-style-1'),(485891,'furniture-mobile','.order-summary .price-row','padding-left','0','','','.order-summary'),(485892,'furniture-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(485893,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-left','17','','','.w-wedding-registry-widgets-photos'),(485894,'furniture-mobile','.w-quote .no-text','padding-left','20','','','.w-quote'),(485895,'furniture-mobile','.p-blog-index .nav-previous','padding-left','50','','','.p-blog-index'),(485896,'furniture-mobile','.w-menu-style-1 ul','padding-left','0','','','.w-menu-style-1'),(485897,'furniture-mobile','.b-select-suggest .select2-drop-mask','padding-left','0','','','.b-select-suggest'),(485898,'furniture-mobile','.p-reviews-info .review-info-content','padding-left','20','','','.p-reviews-info'),(485899,'furniture-mobile','.w-reviews .author','padding-left','0','','','.w-reviews'),(485900,'furniture-mobile','.w-languages .lang-link','padding-left','10','2885','','.w-languages'),(485901,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','2885','','.w-menu-style-1'),(485902,'furniture-mobile','.testimonials .answer','padding-left','30','','',''),(485903,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-left','10','','','.p-blog-index'),(485904,'furniture-mobile','.p-blog-index .comments-area ol ol','padding-left','50','','','.p-blog-index'),(485905,'furniture-mobile','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(485906,'furniture-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(485907,'furniture-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(485909,'furniture-mobile','.w-menu .hided.menu li a','padding-left','20','2885','','.w-menu'),(485910,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-left','20','','','.b-fancybox'),(485911,'furniture-mobile','.w-checkout-shipping-choice span','padding-left','10','2906','','.w-checkout-shipping-choice'),(485912,'furniture-mobile','.w-top-categories .categories h2','padding-left','0','','','.w-top-categories'),(485913,'furniture-mobile','.w-top-categories .image','padding-left','0','','','.w-top-categories'),(485914,'furniture-mobile','.w-product-reviews .reviews-list .review','padding-left','10','','','.w-product-reviews'),(485915,'furniture-mobile','.b-email .model','padding-left','10','','','.b-email'),(485916,'furniture-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(485917,'furniture-mobile','.b-email .price','padding-left','10','','','.b-email'),(485918,'furniture-mobile','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(485919,'furniture-mobile','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(485920,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-left','10','','','.p-account-subscription-historyinfo'),(485921,'furniture-mobile','.p-blog-index .wp-widget li','padding-left','15','','','.p-blog-index'),(485922,'furniture-mobile','.p-blog-index .nav-links','padding-left','0','','','.p-blog-index'),(485923,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-left','0','','','.p-blog-index'),(485924,'furniture-mobile','.w-promo-code .heading-4','padding-left','30','2906','','.w-promo-code'),(485925,'furniture-mobile','.w-product-images-additional .images','padding-left','0','2906','','.w-product-images-additional'),(485926,'furniture-mobile','.b-bottom .popup-heading','padding-left','15','','','.b-bottom'),(485927,'furniture-mobile','.b-bottom .popup-simple','padding-left','20','','','.b-bottom'),(485928,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(485929,'furniture-mobile','.p-blog-index .wp-widget ul','padding-left','0','','','.p-blog-index'),(485930,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(485931,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(485932,'furniture-mobile','.b-email .image','padding-left','10','','','.b-email'),(485933,'furniture-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(485934,'furniture-mobile','.b-email .name','padding-left','10','','','.b-email'),(485935,'furniture-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(485936,'furniture-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(485937,'furniture-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(485938,'furniture-mobile','.b-email .qty','padding-left','10','','','.b-email'),(485939,'furniture-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(485940,'furniture-mobile','.b-email .model','padding-left','10','','','.b-email'),(485941,'furniture-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(485942,'furniture-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(485943,'furniture-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(485944,'furniture-mobile','.w-checkout-create-account .create-account','padding-left','0','','','.w-checkout-create-account'),(485945,'furniture-mobile','.w-checkout-shipping .sub-item','padding-left','0','','','.w-checkout-shipping'),(485946,'furniture-mobile','.b-info .info','padding-left','40','','','.b-info'),(485947,'furniture-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(485948,'furniture-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(485949,'furniture-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(485950,'furniture-mobile','.b-table .table td','padding-left','15','','','.b-table'),(485951,'furniture-mobile','.b-table .table .headings td','padding-left','10','','','.b-table'),(485952,'furniture-mobile','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(485953,'furniture-mobile','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(485954,'furniture-mobile','.w-promo-code .holder','padding-left','20','2906','','.w-promo-code'),(485955,'furniture-mobile','.w-promo-code .heading-4','padding-left','30','2906','','.w-promo-code'),(485956,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(485957,'furniture-mobile','.b-form .shipping-method .input','padding-left','0','','','.b-form'),(485958,'furniture-mobile','.b-form .center-buttons','padding-left','0','','','.b-form'),(485959,'furniture-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(485960,'furniture-mobile','.b-info .info li','padding-left','0','','','.b-info'),(485961,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-left','10','','','.p-account-subscription-historyinfo'),(485962,'furniture-mobile','.w-reviews .item','padding-left','0','','','.w-reviews'),(485963,'furniture-mobile','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(485964,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(485965,'furniture-mobile','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(485966,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','padding-left','8','','','.b-select-suggest'),(485967,'furniture-mobile','.w-menu .hided.menu li li li a','padding-left','60','2885','','.w-menu'),(485968,'furniture-mobile','.w-menu .hided.menu li li a','padding-left','40','2885','','.w-menu'),(485969,'furniture-mobile','.w-menu .hided.menu li a','padding-left','20','2885','','.w-menu'),(485970,'furniture-mobile','.b-sub-totals .historyTotal td','padding-left','5','','','.b-sub-totals'),(485971,'furniture-mobile','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(485972,'furniture-mobile','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(485973,'furniture-mobile','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(485974,'furniture-mobile','.w-banner .carousel-text > span','padding-left','20','','','.w-banner'),(485975,'furniture-mobile','.w-personal-gift-status-bar .end-date','padding-left','5','3','','.w-personal-gift-status-bar'),(485976,'furniture-mobile','.b-info .info','padding-left','40','','','.b-info'),(485977,'furniture-mobile','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(485978,'furniture-mobile','.w-languages .current','padding-left','10','','','.w-languages'),(485979,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','2885','','.w-menu-style-1'),(485980,'furniture-mobile','.b-upload-files .upload-files','padding-left','10','','','.b-upload-files'),(485981,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(485982,'furniture-mobile','.w-menu-style-1 ul','padding-left','0','','','.w-menu-style-1'),(485983,'furniture-mobile','.w-login-block .guest','padding-left','40','','','.w-login-block'),(485984,'furniture-mobile','.w-login-block .new','padding-left','40','','','.w-login-block'),(485985,'furniture-mobile','.w-product-images-additional .images','padding-left','0','2906','','.w-product-images-additional'),(485986,'furniture-mobile','.w-checkout-shipping-address .edit-ab','padding-left','15','','','.w-checkout-shipping-address'),(485987,'furniture-mobile','.b-info .info ul','padding-left','0','','','.b-info'),(485988,'furniture-mobile','.b-info .info li','padding-left','0','','','.b-info'),(485989,'furniture-mobile','.b-bottom .header-error','padding-left','20','','','.b-bottom'),(485990,'furniture-mobile','.w-categories h2.name','padding-left','3','','','.w-categories'),(485991,'furniture-mobile','.w-cart-discount-coupon .btn','padding-left','25','','','.w-cart-discount-coupon'),(485992,'furniture-mobile','.b-form .form-buttons','padding-left','0','','','.b-form'),(485993,'furniture-mobile','.b-form .payment-method .item-radio label span','padding-left','5','','','.b-form'),(485994,'furniture-mobile','.w-checkout-billing-address .same-address','padding-left','10','','','.w-checkout-billing-address'),(485995,'furniture-mobile','.btn-3','padding-left','25','','',''),(485996,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','','','.w-menu-style-1'),(485997,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-left','20','','','.w-menu-style-1'),(485998,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','','','.w-menu-style-1'),(485999,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-left','0','','','.w-menu-slider'),(486000,'furniture-mobile','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(486001,'furniture-mobile','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(486002,'furniture-mobile','.w-cart-compare .delete-cart','padding-left','10','','','.w-cart-compare'),(486003,'furniture-mobile','.w-cart-compare .price-cell','padding-left','20','','','.w-cart-compare'),(486004,'furniture-mobile','.p-blog-index .nav-previous','padding-left','50','','','.p-blog-index'),(486005,'furniture-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','60','','','.b-select-suggest'),(486006,'furniture-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(486007,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(486008,'furniture-mobile','.b-info .info','padding-left','40','','','.b-info'),(486009,'furniture-mobile','.b-info .info li','padding-left','0','','','.b-info'),(486010,'furniture-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(486011,'furniture-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(486012,'furniture-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(486013,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','padding-left','10','','','.b-bottom'),(486014,'furniture-mobile','.w-product-images-additional .images','padding-left','0','2906','','.w-product-images-additional'),(486015,'furniture-mobile','.w-promo-code .heading-4','padding-left','30','2906','','.w-promo-code'),(486016,'furniture-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-left','20','','','.b-bottom'),(486017,'furniture-mobile','.b-bottom .cart-options .cart-item input[type=\"text\"]','padding-left','0','','','.b-bottom'),(486018,'furniture-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-left','6','','','.b-compare'),(486019,'furniture-mobile','.w-cart-compare .cart-cell','padding-left','7','','','.w-cart-compare'),(486020,'furniture-mobile','.w-cart-compare .product','padding-left','15','','','.w-cart-compare'),(486021,'furniture-mobile','.w-promotions .promo-cart-discount .master .item','padding-left','20','','','.w-promotions'),(486022,'furniture-mobile','.w-menu .hided.menu li a','padding-left','20','2885','','.w-menu'),(486023,'furniture-mobile','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(486025,'furniture-mobile','.b-bottom .alert-message','padding-left','20','','','.b-bottom'),(486026,'furniture-mobile','.b-bottom .cart-options','padding-left','20','','','.b-bottom'),(486027,'furniture-mobile','.w-menu-slider > ul > li > a','padding-left','10','','','.w-menu-slider'),(486028,'furniture-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','2885','','.w-menu-horizontal'),(486029,'furniture-mobile','.w-login-block .guest','padding-left','40','','','.w-login-block'),(486030,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','padding-left','7','','','.b-select-suggest'),(486031,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(486032,'furniture-mobile','.w-login-block .new','padding-left','40','','','.w-login-block'),(486033,'furniture-mobile','.w-login-block .guest','padding-left','40','','','.w-login-block'),(486034,'furniture-mobile','.w-sale .holder-2','padding-left','20','','','.w-sale'),(486035,'furniture-mobile','.w-quote .cart-box-link','padding-left','10','','','.w-quote'),(486036,'furniture-mobile','.b-info .info ul','padding-left','0','','','.b-info'),(486037,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(486038,'furniture-mobile','.w-catalog-paging .prev-pages','padding-left','5','','','.w-catalog-paging'),(486039,'furniture-mobile','.p-blog-index .comments-area ol ol','padding-left','20','2906','','.p-blog-index'),(486041,'furniture-mobile','.b-email .totals-value','padding-left','10','','','.b-email'),(486044,'furniture-mobile','.b-info .info ul','padding-left','0','','','.b-info'),(486045,'furniture-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(486046,'furniture-mobile','.b-email .qty','padding-left','10','','','.b-email'),(486047,'furniture-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(486048,'furniture-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(486049,'furniture-mobile','.b-bottom .rfq-form','padding-left','20','','','.b-bottom'),(486050,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(486051,'furniture-mobile','.b-bottom .footerTitle','padding-left','0','2876','','.b-bottom'),(486052,'furniture-mobile','.b-bottom .pop-up-close','padding-left','1','','','.b-bottom'),(486053,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(486054,'furniture-mobile','.b-info .info li','padding-left','0','','','.b-info'),(486055,'furniture-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(486056,'furniture-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(486057,'furniture-mobile','.w-cart-up-sell .w-list-type-1','padding-left','0','','','.w-cart-up-sell'),(486058,'furniture-mobile','.w-cart-shipping-estimator .address-item','padding-left','0','','','.w-cart-shipping-estimator'),(486059,'furniture-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-left','20','1','','.w-cart-up-sell'),(486060,'furniture-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-left','21','','','.w-cart-up-sell'),(486061,'furniture-mobile','.b-products-listing .products-listing .btn-buy','padding-left','10','','','.b-products-listing'),(486062,'furniture-mobile','.b-upload-files .added-file','padding-left','0','','','.b-upload-files'),(486063,'furniture-mobile','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(486064,'furniture-mobile','.w-menu-big ul','padding-left','0','','','.w-menu-big'),(486065,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-left','20','','','.w-menu-style-1'),(486066,'furniture-mobile','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(486067,'furniture-mobile','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(486068,'furniture-mobile','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(486069,'furniture-mobile','.w-menu .hided.menu li li a','padding-left','40','2885','','.w-menu'),(486070,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','2885','','.w-menu-style-1'),(486071,'furniture-mobile','.p-blog-index .comments-area ol ol','padding-left','20','2906','','.p-blog-index'),(486072,'furniture-mobile','.w-promo-code .holder','padding-left','20','2906','','.w-promo-code'),(486073,'furniture-mobile','.b-bottom .pop-up-info','padding-left','20','','','.b-bottom'),(486074,'furniture-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(486075,'furniture-mobile','.b-email .image','padding-left','10','','','.b-email'),(486076,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(486077,'furniture-mobile','.b-fancybox .fancybox-error','padding-left','15','','','.b-fancybox'),(486078,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-left','20','','','.w-menu-style-1'),(486079,'furniture-mobile','.w-cart-compare .product .stock','padding-left','3','','','.w-cart-compare'),(486081,'furniture-mobile','.b-fancybox .fancybox-next span','padding-left','4','3','','.b-fancybox'),(486083,'furniture-mobile','.b-info .info','padding-left','40','','','.b-info'),(486084,'furniture-mobile','.b-form .middle-form','padding-left','0','','','.b-form'),(486085,'furniture-mobile','.b-info .info ul','padding-left','0','','','.b-info'),(486086,'furniture-mobile','.w-product-customers-activity .customers-activity','padding-left','20','','','.w-product-customers-activity'),(486087,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-left','20','','','.w-blog-widget-related-posts-by-category'),(486088,'furniture-mobile','.b-table .table td','padding-left','15','','','.b-table'),(486089,'furniture-mobile','.b-compare .compare-box-item','padding-left','10','','','.b-compare'),(486090,'furniture-mobile','.b-compare .compare-head','padding-left','10','','','.b-compare'),(486091,'furniture-mobile','.b-email .model','padding-left','10','','','.b-email'),(486092,'furniture-mobile','.b-email .image','padding-left','10','','','.b-email'),(486093,'furniture-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(486094,'furniture-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(486095,'furniture-mobile','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(486096,'furniture-mobile','.b-table .table .headings td','padding-left','10','','','.b-table'),(486097,'furniture-mobile','.w-menu .hided.menu li li a','padding-left','40','2885','','.w-menu'),(486098,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-left','10','','','.p-blog-index'),(486099,'furniture-mobile','.w-text .customer-service','padding-left','30','','','.w-text'),(486100,'furniture-mobile','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(486101,'furniture-mobile','.w-text .customer-service','padding-left','30','','','.w-text'),(486102,'furniture-mobile','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(486103,'furniture-mobile','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(486107,'furniture-mobile','.w-menu-slider > ul > li > a','padding-left','10','','','.w-menu-slider'),(486108,'furniture-mobile','.w-login-block .new','padding-left','40','','','.w-login-block'),(486109,'furniture-mobile','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(486110,'furniture-mobile','.w-login-block .guest','padding-left','40','','','.w-login-block'),(486111,'furniture-mobile','.w-menu .hided.menu li li a','padding-left','40','2885','','.w-menu'),(486112,'furniture-mobile','.w-checkout-billing-address .edit-ab','padding-left','15','','','.w-checkout-billing-address'),(486113,'furniture-mobile','.w-checkout-billing-address .addresses.address-main label','padding-left','0','','','.w-checkout-billing-address'),(486114,'furniture-mobile','.w-checkout-billing-address .addresses .address-item label','padding-left','15','','','.w-checkout-billing-address'),(486115,'furniture-mobile','.w-promo-code .holder','padding-left','20','2906','','.w-promo-code'),(486116,'furniture-mobile','.w-promo-code .heading-4','padding-left','30','2906','','.w-promo-code'),(486117,'furniture-mobile','.w-product-images-additional .images','padding-left','0','2906','','.w-product-images-additional'),(486118,'furniture-mobile','.p-blog-index .comments-area ol ol','padding-left','20','2906','','.p-blog-index'),(486119,'furniture-mobile','.w-cart-checkout-btn a','padding-left','12','2876','','.w-cart-checkout-btn'),(486120,'furniture-mobile','.w-tabs .accordion-heading','padding-left','6','','','.w-tabs'),(486121,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-left','20','','','.p-account-trade-form'),(486123,'furniture-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(486124,'furniture-mobile','.b-bottom .header-info','padding-left','20','','','.b-bottom'),(486125,'furniture-mobile','.w-personal-gift-status-bar .start-label','padding-left','30','','','.w-personal-gift-status-bar'),(486126,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-left','0','','','.p-reviews-info'),(486127,'furniture-mobile','.p-blog-index .nav-links','padding-left','0','','','.p-blog-index'),(486128,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-left','20','','','.p-account-trade-form'),(486129,'furniture-mobile','.b-upload-file .upload-file-template','padding-left','1','','','.b-upload-file'),(486130,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(486131,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','padding-left','5','','','.b-switch'),(486132,'furniture-mobile','.p-blog-index .nav-links','padding-left','0','','','.p-blog-index'),(486133,'furniture-mobile','.p-account-trade-form .widget','padding-left','0','','','.p-account-trade-form'),(486134,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-left','5','','','.b-select-suggest'),(486135,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-left','18','','','.b-select-suggest'),(486136,'furniture-mobile','.w-menu .hided.menu li a','padding-left','20','2885','','.w-menu'),(486137,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-left','5','','','.b-select-suggest'),(486138,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-left','0','','','.b-select-suggest'),(486139,'furniture-mobile','.b-select-suggest .select2-locked','padding-left','5','','','.b-select-suggest'),(486140,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-left','0','','','.b-select-suggest'),(486141,'furniture-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','100','','','.b-select-suggest'),(486142,'furniture-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','120','','','.b-select-suggest'),(486143,'furniture-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','110','','','.b-select-suggest'),(486144,'furniture-mobile','.b-select-suggest .select2-results ul.select2-result-sub','padding-left','0','','','.b-select-suggest'),(486145,'furniture-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','80','','','.b-select-suggest'),(486146,'furniture-mobile','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','40','','','.b-select-suggest'),(486147,'furniture-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','','','.w-menu-horizontal'),(486148,'furniture-mobile','.w-menu-slider > ul > li > a','padding-left','10','','','.w-menu-slider'),(486149,'furniture-mobile','.b-select-suggest .select2-results','padding-left','4','','','.b-select-suggest'),(486150,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item label','padding-left','15','','','.w-checkout-shipping-address'),(486151,'furniture-mobile','.b-select-suggest .select2-results ul.select2-result-sub > li .select2-result-label','padding-left','20','','','.b-select-suggest'),(486152,'furniture-mobile','.b-form .shipping-method .item + .item','padding-left','0','','','.b-form'),(486153,'furniture-mobile','.w-checkout-shipping-address .addresses.address-main label','padding-left','0','','','.w-checkout-shipping-address'),(486154,'furniture-mobile','.b-select-suggest .select2-search input','padding-left','5','','','.b-select-suggest'),(486155,'furniture-mobile','.b-select-suggest .select2-search','padding-left','4','','','.b-select-suggest'),(486156,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(486157,'furniture-mobile','.w-text .customer-service','padding-left','30','','','.w-text'),(486158,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-left','0','','','.w-menu-slider'),(486159,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-left','0','','','.w-menu'),(486160,'furniture-mobile','.w-menu .hided.menu ul li','padding-left','0','','','.w-menu'),(486161,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-left','10','','','.p-account-subscription-historyinfo'),(486162,'furniture-mobile','.w-cart-compare .product-label','padding-left','10','','','.w-cart-compare'),(486163,'furniture-mobile','.p-blog-index .comments-area ol ol','padding-left','50','','','.p-blog-index'),(486164,'furniture-mobile','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(486165,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-left','20','','','.w-menu-style-1'),(486166,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-left','10','','','.w-menu-slider'),(486167,'furniture-mobile','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(486168,'furniture-mobile','.p-reviews-info .review-info-image','padding-left','20','','','.p-reviews-info'),(486169,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-left','0','','','.p-reviews-info'),(486170,'furniture-mobile','.b-table .table .headings td','padding-left','10','','','.b-table'),(486171,'furniture-mobile','.b-compare .col-two label','padding-left','0','','','.b-compare'),(486172,'furniture-mobile','.w-account .acc-link','padding-left','15','','','.w-account'),(486173,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-left','0','','','.w-menu'),(486174,'furniture-mobile','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(486175,'furniture-mobile','.b-bottom .notify-form','padding-left','20','','','.b-bottom'),(486176,'furniture-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-left','0','','','.w-account-addresses-list'),(486177,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.b-data-table'),(486178,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.b-data-table'),(486179,'furniture-mobile','.w-communication-post .communication-post-author','padding-left','0','','','.w-communication-post'),(486180,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','padding-left','0','','','.b-products-listing'),(486181,'furniture-mobile','.b-products-listing .in-cart','padding-left','10','','','.b-products-listing'),(486182,'furniture-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-left','5','','','.w-catalog-b2b-add-button'),(486183,'furniture-mobile','.b-products-listing .promos-info .promo-item','padding-left','0','','','.b-products-listing'),(486184,'furniture-mobile','.b-products-listing .promos-info .promo-name','padding-left','15','','','.b-products-listing'),(486185,'furniture-mobile','.w-blog-widget-tag-cloud a','padding-left','13','','','.w-blog-widget-tag-cloud'),(486186,'furniture-mobile','.w-blog-widget-related-posts-by-category ','padding-left','0','2906','','.w-blog-widget-related-posts-by-category'),(486187,'furniture-mobile','.w-blog-widget-related-posts-by-category .post','padding-left','15','','','.w-blog-widget-related-posts-by-category'),(486188,'furniture-mobile','.w-blog-widget-related-posts-by-category ','padding-left','15','','','.w-blog-widget-related-posts-by-category'),(486189,'furniture-mobile','.w-blog-widget-related-posts .post_content a','padding-left','20','','','.w-blog-widget-related-posts'),(486190,'furniture-mobile','.w-blog-widget-related-posts .post','padding-left','15','','','.w-blog-widget-related-posts'),(486191,'furniture-mobile','.w-blog-widget-post-title h1','padding-left','0','','','.w-blog-widget-post-title'),(486192,'furniture-mobile','.w-blog-widget-post-title ','padding-left','0','','','.w-blog-widget-post-title'),(486193,'furniture-mobile','.w-blog-widget-post-listing .post','padding-left','15','2890','','.w-blog-widget-post-listing'),(486194,'furniture-mobile','.w-blog-widget-post-listing .post_name','padding-left','0','','','.w-blog-widget-post-listing'),(486195,'furniture-mobile','.w-blog-widget-post-listing .post_comment','padding-left','22','','','.w-blog-widget-post-listing'),(486196,'furniture-mobile','.w-blog-widget-post-listing .post','padding-left','33','','','.w-blog-widget-post-listing'),(486197,'furniture-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-left','0','','','.w-blog-widget-most-popular-posts'),(486198,'furniture-mobile','.w-blog-widget-post-comments-count span','padding-left','22','','','.w-blog-widget-post-comments-count'),(486199,'furniture-mobile','.w-blog-widget-most-popular-posts a','padding-left','15','','','.w-blog-widget-most-popular-posts'),(486200,'furniture-mobile','.w-blog-widget-categories-list a','padding-left','15','','','.w-blog-widget-categories-list'),(486201,'furniture-mobile','.blogsidebar','padding-left','35','','',''),(486202,'furniture-mobile','.w-currencies .select-link','padding-left','10','2885','','.w-currencies'),(486203,'furniture-mobile','.w-currencies .current','padding-left','10','2885','','.w-currencies'),(486204,'furniture-mobile','.w-currencies .select-link','padding-left','10','','','.w-currencies'),(486205,'furniture-mobile','.w-currencies .current','padding-left','10','','','.w-currencies'),(486206,'furniture-mobile','.w-currencies .currencies-title','padding-left','4','','','.w-currencies'),(486207,'furniture-mobile','.w-sale .holder-2','padding-left','20','','','.w-sale'),(486208,'furniture-mobile','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(486209,'furniture-mobile','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(486210,'furniture-mobile','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(486211,'furniture-mobile','.w-sale .left-count','padding-left','5','','','.w-sale'),(486212,'furniture-mobile','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(486213,'furniture-mobile','.w-checkout-gdpr .terms-login','padding-left','0','','','.w-checkout-gdpr'),(486214,'furniture-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(486215,'furniture-mobile','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(486216,'furniture-mobile','.w-checkout-gdpr .privacy-row','padding-left','0','','','.w-checkout-gdpr'),(486217,'furniture-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(486218,'furniture-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(486219,'furniture-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(486220,'furniture-mobile','.b-compare .column_wrapper','padding-left','10','','','.b-compare'),(486221,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(486222,'furniture-mobile','.b-email .price','padding-left','10','','','.b-email'),(486223,'furniture-mobile','.b-email .heading-name','padding-left','10','','','.b-email'),(486224,'furniture-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(486225,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(486226,'furniture-mobile','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(486227,'furniture-mobile','.p-blog-index .comments-area ol ol','padding-left','20','2906','','.p-blog-index'),(486228,'furniture-mobile','.w-text .customer-service','padding-left','30','','','.w-text'),(486229,'furniture-mobile','.w-top-categories .item','padding-left','10','2876','','.w-top-categories'),(486230,'furniture-mobile','.w-sale .holder-1','padding-left','20','','','.w-sale'),(486231,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(486232,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(486233,'furniture-mobile','.w-catalog-paging ','padding-left','5','2','','.w-catalog-paging'),(486234,'furniture-mobile','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(486235,'furniture-mobile','.w-personal-gift-status-bar .timeline','padding-left','10','','','.w-personal-gift-status-bar'),(486236,'furniture-mobile','.w-personal-gift-status-bar .inform','padding-left','5','4','','.w-personal-gift-status-bar'),(486237,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-left','0','','','.p-blog-index'),(486238,'furniture-mobile','.p-blog-index .wp-widget ul','padding-left','0','','','.p-blog-index'),(486239,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-left','20','','','.p-account-trade-form'),(486240,'furniture-mobile','.b-table .table td','padding-left','15','','','.b-table'),(486241,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(486242,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-left','0','','',''),(486243,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-left','0','','','.b-h-inline'),(486244,'furniture-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(486245,'furniture-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(486246,'furniture-mobile','.blogsidebar .heading-title','padding-left','0','','','.blogsidebar'),(486247,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-left','5','','','.w-communication-new-topic'),(486248,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-left','10','','','.w-communication-new-topic'),(486249,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-left','5','','','.w-communication-new-topic'),(486250,'furniture-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-left','0','','','.w-communication-new-topic'),(486252,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(486253,'furniture-mobile','.b-email .heading-price','padding-left','10','','','.b-email'),(486254,'furniture-mobile','.b-email .image','padding-left','10','','','.b-email'),(486255,'furniture-mobile','.btn-2','padding-left','25','','',''),(486256,'furniture-mobile','.b-compare .compare_pagination','padding-left','0','','','.b-compare'),(486257,'furniture-mobile','.b-bottom .popup-content','padding-left','15','','','.b-bottom'),(486258,'furniture-mobile','.w-sale .holder-2','padding-left','20','','','.w-sale'),(486259,'furniture-mobile','.w-sale .left-count','padding-left','5','','','.w-sale'),(486260,'furniture-mobile','.w-reviews-content .author','padding-left','20','','','.w-reviews-content'),(486261,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-left','0','','','.p-reviews-info'),(486262,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','','','.w-menu-style-1'),(486263,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-left','10','','','.w-menu-slider'),(486264,'furniture-mobile','.b-email .qty','padding-left','10','','','.b-email'),(486265,'furniture-mobile','.w-login-block .new','padding-left','40','','','.w-login-block'),(486266,'furniture-mobile','.w-menu .hided.menu ul li','padding-left','0','','','.w-menu'),(486267,'furniture-mobile','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(486268,'furniture-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(486269,'furniture-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-left','0','','','.b-fancybox'),(486270,'furniture-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(486271,'furniture-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(486272,'furniture-mobile','.b-email .heading-image','padding-left','10','','','.b-email'),(486273,'furniture-mobile','.b-email .price','padding-left','10','','','.b-email'),(486274,'furniture-mobile','.products-quick-index .token-input-list','padding-left','0','','',''),(486275,'furniture-mobile','.w-menu .hided.menu li a','padding-left','20','2885','','.w-menu'),(486276,'furniture-mobile','.w-menu .hided.menu li li li a','padding-left','60','2885','','.w-menu'),(486277,'furniture-mobile','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(486278,'furniture-mobile','.w-sale .holder-2','padding-left','20','','','.w-sale'),(486279,'furniture-mobile','.w-sale .holder-1','padding-left','20','','','.w-sale'),(486280,'furniture-mobile','.w-sale .left-count','padding-left','5','','','.w-sale'),(486281,'furniture-mobile','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(486282,'furniture-mobile','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(486283,'furniture-mobile','.b-info .info ul','padding-left','0','','','.b-info'),(486284,'furniture-mobile','.b-form .shipping-method .item','padding-left','0','','','.b-form'),(486285,'furniture-mobile','.b-email .model','padding-left','10','','','.b-email'),(486286,'furniture-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(486287,'furniture-mobile','.w-promo-code .holder','padding-left','20','2906','','.w-promo-code'),(486288,'furniture-mobile','.p-blog-index .comments-area ol ol','padding-left','50','','','.p-blog-index'),(486289,'furniture-mobile','.p-blog-index .nav-links','padding-left','0','','','.p-blog-index'),(486290,'furniture-mobile','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(486291,'furniture-mobile','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(486292,'furniture-mobile','.w-catalog-paging .next-pages','padding-left','5','','','.w-catalog-paging'),(486293,'furniture-mobile','.w-cart-listing .item .gift-wrap label','padding-left','10','','','.w-cart-listing'),(486294,'furniture-mobile','.w-cart-listing .item > div','padding-left','0','','','.w-cart-listing'),(486295,'furniture-mobile','.w-cart-listing .points-earn','padding-left','10','','','.w-cart-listing'),(486296,'furniture-mobile','.w-cart-listing .points-redeem','padding-left','25','','','.w-cart-listing'),(486297,'furniture-mobile','.w-cart-listing .item .gift-wrap .value','padding-left','5','','','.w-cart-listing'),(486298,'furniture-mobile','.w-cart-listing .item .gift-wrap','padding-left','0','2885','','.w-cart-listing'),(486299,'furniture-mobile','.w-cart-give-away .ga_img','padding-left','1','','','.w-cart-give-away'),(486300,'furniture-mobile','.w-cart .cart-box-link','padding-left','10','','','.w-cart'),(486301,'furniture-mobile','.w-cart .buttons','padding-left','15','','','.w-cart'),(486302,'furniture-mobile','.w-cart .buttons .btn','padding-left','15','','','.w-cart'),(486303,'furniture-mobile','.w-cart .qty','padding-left','5','4','','.w-cart'),(486304,'furniture-mobile','.w-cart .no-text','padding-left','20','','','.w-cart'),(486305,'furniture-mobile','.w-cart .multicart .name','padding-left','10','','','.w-cart'),(486306,'furniture-mobile','.w-cart .multicart .item','padding-left','45','','','.w-cart'),(486307,'furniture-mobile','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(486308,'furniture-mobile','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(486309,'furniture-mobile','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(486310,'furniture-mobile','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(486311,'furniture-mobile','.b-info .info li','padding-left','0','','','.b-info'),(486312,'furniture-mobile','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(486313,'furniture-mobile','.b-email .heading-model','padding-left','10','','','.b-email'),(486314,'furniture-mobile','.b-email .model','padding-left','10','','','.b-email'),(486315,'furniture-mobile','.b-compare .col-gender','padding-left','0','','','.b-compare'),(486316,'furniture-mobile','.w-menu .hided.menu li li a','padding-left','40','2885','','.w-menu'),(486317,'furniture-mobile','.w-socials > li','padding-left','15','','','.w-socials'),(486318,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(486319,'furniture-mobile','.w-sale .holder-1','padding-left','20','','','.w-sale'),(486320,'furniture-mobile','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(486321,'furniture-mobile','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(486322,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','','','.w-menu-style-1'),(486323,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-left','0','','','.w-menu'),(486324,'furniture-mobile','.b-compare .popupCompare td.level-3:first-child','padding-left','18','','','.b-compare'),(486325,'furniture-mobile','.w-cart .cart-content','padding-left','15','','','.w-cart'),(486326,'furniture-mobile','.p-reviews-info .review-info-image','padding-left','20','','','.p-reviews-info'),(486327,'furniture-mobile','.p-reviews-info .review-info-text','padding-left','10','','','.p-reviews-info'),(486328,'furniture-mobile','.p-blog-index .nav-previous','padding-left','50','','','.p-blog-index'),(486329,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-left','0','','','.p-blog-index'),(486330,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-left','10','','','.p-blog-index'),(486331,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-left','10','','','.p-account-subscription-historyinfo'),(486332,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(486333,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(486334,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(486335,'furniture-mobile','.b-table .table .headings td','padding-left','10','','','.b-table'),(486336,'furniture-mobile','.p-blog-index .nav-previous','padding-left','50','','','.p-blog-index'),(486337,'furniture-mobile','.w-sale .holder-1','padding-left','20','','','.w-sale'),(486338,'furniture-mobile','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(486339,'furniture-mobile','.w-catalog-paging .page-number','padding-left','5','','','.w-catalog-paging'),(486340,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-left','0','','','.w-menu'),(486341,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(486342,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','','','.w-menu-style-1'),(486343,'furniture-mobile','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(486344,'furniture-mobile','.w-filters .fsl_handle','padding-left','0','','','.w-filters'),(486345,'furniture-mobile','.w-filters .head-filter-widget','padding-left','10','2885','','.w-filters'),(486346,'furniture-mobile','.w-catalog-sorting .before','padding-left','0','','','.w-catalog-sorting'),(486347,'furniture-mobile','.w-filters .ui-slider-range','padding-left','0','','','.w-filters'),(486348,'furniture-mobile','.w-menu .hided.menu li li li a','padding-left','60','2885','','.w-menu'),(486350,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(486351,'furniture-mobile','.p-reviews-info .review-info-text','padding-left','10','','','.p-reviews-info'),(486352,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(486353,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-left','20','','','.p-account-trade-form'),(486354,'furniture-mobile','.p-account-trade-form .widget','padding-left','0','','','.p-account-trade-form'),(486355,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-left','10','','','.p-blog-index'),(486356,'furniture-mobile','.w-filters .head-filter-widget','padding-left','0','','','.w-filters'),(486357,'furniture-mobile','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(486358,'furniture-mobile','.b-autocomplete .ui-autocomplete','padding-left','2','','','.b-autocomplete'),(486359,'furniture-mobile','.w-promo-code .heading-4','padding-left','30','2906','','.w-promo-code'),(486360,'furniture-mobile','.order-summary .heading-2','padding-left','25','','','.order-summary'),(486361,'furniture-mobile','.b-email .name','padding-left','10','','','.b-email'),(486362,'furniture-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(486363,'furniture-mobile','.b-email .heading-qty','padding-left','10','','','.b-email'),(486364,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','2885','','.w-menu-style-1'),(486365,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-left','0','','','.w-menu-slider'),(486366,'furniture-mobile','.w-menu-slider > ul > li > a','padding-left','10','','','.w-menu-slider'),(486367,'furniture-mobile','.w-menu .hided.menu ul li','padding-left','0','','','.w-menu'),(486368,'furniture-mobile','.b-data-table table.dataTable tbody td','padding-left','20','','','.b-data-table'),(486369,'furniture-mobile','.b-data-table table.dataTable thead td','padding-left','20','','','.b-data-table'),(486370,'furniture-mobile','.p-blog-index .wp-widget li','padding-left','15','','','.p-blog-index'),(486371,'furniture-mobile','.b-compare .popupCompare .pop-up-content','padding-left','10','','','.b-compare'),(486372,'furniture-mobile','.w-menu .hided.menu ul li','padding-left','0','','','.w-menu'),(486373,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-left','0','','','.w-menu'),(486374,'furniture-mobile','.w-menu-slider > ul > li > a','padding-left','10','','','.w-menu-slider'),(486375,'furniture-mobile','.p-reviews-info .review-info-text','padding-left','10','','','.p-reviews-info'),(486376,'furniture-mobile','.p-reviews-info .review-info-content','padding-left','20','','','.p-reviews-info'),(486377,'furniture-mobile','.p-reviews-info .review-info-image','padding-left','20','','','.p-reviews-info'),(486378,'furniture-mobile','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(486379,'furniture-mobile','.b-table .table td','padding-left','15','','','.b-table'),(486380,'furniture-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(486381,'furniture-mobile','.b-info .info ul','padding-left','0','','','.b-info'),(486382,'furniture-mobile','.b-email .qty','padding-left','10','','','.b-email'),(486383,'furniture-mobile','.b-email .totals-title','padding-left','10','','','.b-email'),(486384,'furniture-mobile','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(486385,'furniture-mobile','.b-email .qty','padding-left','10','','','.b-email'),(486386,'furniture-mobile','.b-email .price','padding-left','10','','','.b-email'),(486387,'furniture-mobile','.btn','padding-left','25','','',''),(486388,'furniture-mobile','.p-blog-index .nav-previous','padding-left','50','','','.p-blog-index'),(486389,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-left','20','','','.p-account-trade-form'),(486390,'furniture-mobile','.p-reviews-info .review-info-text','padding-left','10','','','.p-reviews-info'),(486391,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(486392,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-left','0','','','.p-reviews-info'),(486393,'furniture-mobile','.p-blog-index .wp-widget ul','padding-left','0','','','.p-blog-index'),(486394,'furniture-mobile','.b-product-images .media-popup .mp-content','padding-left','5','','','.b-product-images'),(486395,'furniture-mobile','.b-product-images .media-popup .mp-small-images .item','padding-left','10','','','.b-product-images'),(486396,'furniture-mobile','.b-product-images .media-popup .slick-dots','padding-left','0','','','.b-product-images'),(486397,'furniture-mobile','.b-product-images .media-popup .slick-dots li','padding-left','0','','','.b-product-images'),(486398,'furniture-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-left','0','','','.b-menu-style'),(486399,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-left','5','','','.b-menu-style-1'),(486400,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-left','0','','','.b-menu-style-2'),(486401,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-left','0','','','.b-menu-style-2'),(486402,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-left','0','','','.b-menu-style-2'),(486403,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-left','0','','','.b-menu-style-2'),(486404,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-left','20','','','.b-menu-style-2'),(486405,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-left','0','','','.b-menu-style-2'),(486406,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-left','20','','','.b-menu-style-2'),(486407,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-left','20','','','.b-menu-style-2'),(486408,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-left','20','','','.b-menu-style-2'),(486409,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-left','50','','','.b-menu-style-2'),(486410,'furniture-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-left','0','','','.b-personal-catalog-popup'),(486411,'furniture-mobile','.b-trade-approval .steps-bar li a','padding-left','0','','','.b-trade-approval'),(486412,'furniture-mobile','.b-trade-approval .middle-form','padding-left','0','','','.b-trade-approval'),(486413,'furniture-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-left','5','','','.b-trade-approval'),(486414,'furniture-mobile','.b-trade-approval .steps-bar','padding-left','12','','','.b-trade-approval'),(486415,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-left','10','','','.b-trade-approval'),(486416,'furniture-mobile','.b-trade-approval .center-buttons','padding-left','0','','','.b-trade-approval'),(486417,'furniture-mobile','.batchPr .w-batch-products .products-listing .image','padding-left','0','','','.batchPr'),(486418,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-left','0','','','.batchPr'),(486419,'furniture-mobile','.batchPr .w-batch-products','padding-left','0','','','.batchPr'),(486420,'furniture-mobile','.batchPr > .block:nth-child(2)','padding-left','20','','','.batchPr'),(486421,'furniture-mobile','.batchPr .w-batch-selected-products','padding-left','15','','','.batchPr'),(486422,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-left','0','','','.batchPr'),(486423,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-left','0','','','.batchPr'),(486424,'furniture-mobile','.batchPr ','padding-left','0','','','.batchPr'),(486425,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-left','0','','','.batchPr'),(486426,'furniture-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-left','0','','','.batchPr'),(486427,'furniture-mobile','.batchPr .w-batch-products .products-listing .image','padding-left','0','','','.batchPr'),(486428,'furniture-mobile','.w-account-personal-catalog .list-switcher','padding-left','0','','','.w-account-personal-catalog'),(486429,'furniture-mobile','.w-account-personal-catalog .list-switcher a','padding-left','6','','','.w-account-personal-catalog'),(486430,'furniture-mobile','.w-account-subscription .subscription-variant','padding-left','10','','','.w-account-subscription'),(486431,'furniture-mobile','.w-catalog-additional-images li','padding-left','10','','','.w-catalog-additional-images'),(486432,'furniture-mobile','.w-catalog-additional-images ul','padding-left','0','','','.w-catalog-additional-images'),(486433,'furniture-mobile','.w-catalog-compare td','padding-left','20','','','.w-catalog-compare'),(486434,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-left','0','','','.w-catalog-compare'),(486435,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','padding-left','5','2','','.w-catalog-compare'),(486436,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','padding-left','5','','','.w-catalog-compare'),(486437,'furniture-mobile','.w-catalog-compare .cross-box .return','padding-left','20','','','.w-catalog-compare'),(486438,'furniture-mobile','.w-delivery-day .left-count','padding-left','5','','','.w-delivery-day'),(486439,'furniture-mobile','.w-top-text .top-text','padding-left','10','','','.w-top-text'),(486440,'furniture-mobile','.w-cart-listing .points','padding-left','0','2876','','.w-cart-listing'),(486441,'furniture-mobile','.w-product-images .additional-horizontal .item','padding-left','10','','','.w-product-images'),(486442,'furniture-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-left','10','','','.b-cookie-notice'),(486443,'furniture-mobile','.w-account .account-dropdown ul','padding-left','20','','','.w-account'),(486444,'furniture-mobile','.lowestPricedBox .w-banner .banner','padding-left','0','','','.lowestPricedBox'),(486445,'furniture-mobile','.tripleBanner > .block','padding-left','15','','','.tripleBanner'),(486446,'furniture-mobile','.tripleBanner .w-html_box','padding-left','90','','','.tripleBanner'),(486447,'furniture-mobile','.w-languages .current','padding-left','10','2906','','.w-languages'),(486448,'furniture-mobile','.w-currencies .current','padding-left','10','2906','','.w-currencies'),(486449,'furniture-mobile','.b-slick .slick-list','padding-left','0','','','.b-slick'),(486450,'furniture-mobile','.b-slick .slick-vertical button.slick-next','padding-left','0','3','','.b-slick'),(486451,'furniture-mobile','.b-slick .slick-vertical button.slick-prev','padding-left','0','3','','.b-slick'),(486452,'furniture-mobile','.b-slick button.slick-next','padding-left','4','3','','.b-slick'),(486453,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-left','0','','','.b-slick'),(486454,'furniture-mobile','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-left','15','','',''),(486455,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li','padding-left','18','','','.b-menu-style-3'),(486456,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li.component-item','padding-left','0','','','.b-menu-style-3'),(486457,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li + li','padding-left','20','2945','','.b-menu-style-3'),(486458,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-left','0','2885','','.b-menu-style-3'),(486459,'furniture-mobile','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','padding-left','0','','','.b-products-listing'),(486460,'furniture-mobile','.w-cart-listing .headings .head','padding-left','0','','','.w-cart-listing'),(486461,'furniture-mobile','.b-products-listing .item-nav > div','padding-left','15','','','.b-products-listing'),(486462,'furniture-mobile','.LeftCategories .w-menu-simple ul','padding-left','0','','','.LeftCategories'),(486463,'furniture-mobile','.LeftCategories .w-menu-simple ul li a','padding-left','25','','','.LeftCategories'),(486464,'furniture-mobile','.w-filters .filter-widget','padding-left','25','','','.w-filters'),(486465,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item','padding-left','15','','','.b-products-listing'),(486466,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-left','0','','','.b-products-listing'),(486467,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-content','padding-left','25','','','.b-products-listing'),(486468,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','padding-left','30','','','.b-products-listing'),(486469,'furniture-mobile','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-left','25','','','.b-products-listing'),(486470,'furniture-mobile','.b-products-listing .products-listing.list-rows .item-nav > div','padding-left','5','','','.b-products-listing'),(486471,'furniture-mobile','.w-breadcrumb .breadcrumb-li','padding-left','0','','','.w-breadcrumb'),(486472,'furniture-mobile','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(486473,'furniture-mobile','.w-subscribers .btn-submit','padding-left','25','','','.w-subscribers'),(486474,'furniture-mobile','.w-quote .buttons','padding-left','15','','','.w-quote'),(486475,'furniture-mobile','.w-quote .buttons .btn','padding-left','15','','','.w-quote'),(486476,'furniture-mobile','.w-quote .cart-content','padding-left','15','','','.w-quote'),(486477,'furniture-mobile','.w-quote .cart-total','padding-left','0','','','.w-quote'),(486478,'furniture-mobile','.w-quote .multicart .cart-content','padding-left','0','','','.w-quote'),(486479,'furniture-mobile','.w-quote .multicart .item','padding-left','45','','','.w-quote'),(486480,'furniture-mobile','.w-quote .multicart .name','padding-left','10','','','.w-quote'),(486481,'furniture-mobile','.w-quote .qty','padding-left','5','4','','.w-quote'),(486482,'furniture-mobile','.w-quote a.item','padding-left','90','','','.w-quote'),(486483,'furniture-mobile','.w-social-links a','padding-left','8','','','.w-social-links'),(486484,'furniture-mobile','.w-product-images .additional-vertical .additional-images','padding-left','0','','','.w-product-images'),(486485,'furniture-mobile','.w-product-personal-catalog-button .btn','padding-left','0','','','.w-product-personal-catalog-button'),(486486,'furniture-mobile','.b-quantity .qty-box input','padding-left','3','','','.b-quantity'),(486487,'furniture-mobile','.w-product-sale-ends .left-count','padding-left','5','','','.w-product-sale-ends'),(486488,'furniture-mobile','.w-product-sale-ends .left-count-days','padding-left','0','','','.w-product-sale-ends'),(486489,'furniture-mobile','.w-product-sale-ends .left-count-hours','padding-left','0','','','.w-product-sale-ends'),(486490,'furniture-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(486491,'furniture-mobile','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(486492,'furniture-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(486493,'furniture-mobile','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(486494,'furniture-mobile','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(486495,'furniture-mobile','.w-product-bonus-points > div > div','padding-left','25','','','.w-product-bonus-points'),(486496,'furniture-mobile','.warrantyProduct .warranty, .warrantyProduct .delivery','padding-left','50','','','.warrantyProduct'),(486497,'furniture-mobile','.w-compare .compare-list-buttons','padding-left','10','','','.w-compare'),(486498,'furniture-mobile','.w-compare .item-holder','padding-left','90','','','.w-compare'),(486499,'furniture-mobile','.w-compare .compare-list-products','padding-left','30','','','.w-compare'),(486500,'furniture-mobile','.w-files-catalog-widgets-files-catalog .name','padding-left','10','','','.w-files-catalog-widgets-files-catalog'),(486501,'furniture-mobile','.w-files-catalog-widgets-files-list .file','padding-left','20','','','.w-files-catalog-widgets-files-list'),(486502,'furniture-mobile','.w-sample .buttons','padding-left','15','','','.w-sample'),(486503,'furniture-mobile','.w-sample .buttons .btn','padding-left','15','','','.w-sample'),(486504,'furniture-mobile','.w-sample .cart-box-link','padding-left','10','','','.w-sample'),(486505,'furniture-mobile','.w-sample .cart-content','padding-left','15','','','.w-sample'),(486506,'furniture-mobile','.w-sample .cart-total','padding-left','0','','','.w-sample'),(486507,'furniture-mobile','.w-sample .multicart .cart-content','padding-left','0','','','.w-sample'),(486508,'furniture-mobile','.w-sample .multicart .item','padding-left','45','','','.w-sample'),(486509,'furniture-mobile','.w-sample .multicart .name','padding-left','10','','','.w-sample'),(486510,'furniture-mobile','.w-sample .no-text','padding-left','20','','','.w-sample'),(486511,'furniture-mobile','.w-sample .qty','padding-left','5','4','','.w-sample'),(486512,'furniture-mobile','.w-sample a.item','padding-left','90','','','.w-sample'),(486513,'furniture-mobile','.w-cart-listing .item > div.points','padding-left','0','','','.w-cart-listing'),(486514,'furniture-mobile','.w-filters-simple .integrate-price-holder','padding-left','0','','','.w-filters-simple'),(486515,'furniture-mobile','.w-cart-discount-coupon .title','padding-left','0','','','.w-cart-discount-coupon'),(486516,'furniture-mobile','.w-product-video .item','padding-left','10','','','.w-product-video'),(486517,'furniture-mobile','.shipping-ico .heading-3','padding-left','0','','','.shipping-ico'),(486518,'furniture-mobile','.w-cart-order-reference .btn','padding-left','25','','','.w-cart-order-reference'),(486519,'furniture-mobile','.w-cart-gift-certificate .btn','padding-left','25','','','.w-cart-gift-certificate'),(486520,'furniture-mobile','.w-cart-shipping-estimator .btn','padding-left','25','','','.w-cart-shipping-estimator'),(486521,'furniture-mobile','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(486522,'furniture-mobile','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(486523,'furniture-mobile','.w-product-in-bundles .attributes-item','padding-left','0','','','.w-product-in-bundles'),(486524,'furniture-mobile','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(486525,'furniture-mobile','.w-cart-listing .item > div.actions','padding-left','10','2876','','.w-cart-listing'),(486526,'furniture-mobile','.w-account-address-book .item','padding-left','10','','','.w-account-address-book'),(486527,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-left','0','','','.b-products-listing'),(486528,'furniture-mobile','.b-pagination .pagination .next-pages','padding-left','5','','','.b-pagination'),(486529,'furniture-mobile','.b-pagination .pagination .page-number','padding-left','5','','','.b-pagination'),(486530,'furniture-mobile','.b-pagination .pagination .prev-pages','padding-left','5','','','.b-pagination'),(486531,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','padding-left','5','','','.b-pagination'),(486532,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','padding-left','5','','','.b-pagination'),(486533,'furniture-mobile','.b-pagination .pagination span','padding-left','5','2','','.b-pagination'),(486534,'furniture-mobile','.b-pagination ul.pagination','padding-left','0','','','.b-pagination'),(486535,'furniture-mobile','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','padding-left','10','','','.w-catalog-compare'),(486536,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .item','padding-left','10','','','.w-product-properties-filters-widgets-chosen-filters'),(486537,'furniture-mobile','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block, .checkout > .type-1 > .block','padding-left','15','','',''),(486538,'furniture-mobile','.w-tabs .tab-li.active + .tab-li','padding-left','15','','','.w-tabs'),(486539,'furniture-mobile','.p-quote-checkout-index .datepicker-inline','padding-left','0','','','.p-quote-checkout-index'),(486540,'furniture-mobile','.p-sample-checkout-index .datepicker-inline','padding-left','0','','','.p-sample-checkout-index'),(486541,'furniture-mobile','.w-account-order-download td + tl','padding-left','20','','','.w-account-order-download'),(486542,'furniture-mobile','.w-account-order-download td','padding-left','0','2876','','.w-account-order-download'),(486543,'furniture-mobile','.w-account-order-download tr','padding-left','0','2876','','.w-account-order-download'),(486544,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','padding-left','15','','','.w-product-multi-inventory'),(486545,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','padding-left','0','','','.w-account-personal-catalog'),(486546,'furniture-mobile','.w-account-personal-catalog .list-row-action li','padding-left','10','','','.w-account-personal-catalog'),(486547,'furniture-mobile','.w-account-personal-catalog .buy-box','padding-left','0','2876','','.w-account-personal-catalog'),(486548,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','padding-left','15','','','.b-products-listing'),(486549,'furniture-mobile','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(486550,'furniture-mobile','.w-product-collection .right-area .btn','padding-left','25','','','.w-product-collection'),(486551,'furniture-mobile','.w-account-customer-additional-field .tf-file','padding-left','0','','','.w-account-customer-additional-field'),(486552,'furniture-mobile','.w-product-collection .right-area','padding-left','2','','','.w-product-collection'),(486553,'furniture-mobile','.w-product-collection .right-area','padding-left','0','2885','','.w-product-collection'),(486554,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','padding-left','15','','','.w-product-attributes'),(486555,'furniture-mobile','.w-product-properties .property-ul','padding-left','0','','','.w-product-properties'),(486556,'furniture-mobile','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(486557,'furniture-mobile','.w-product-properties li','padding-left','0','','','.w-product-properties'),(486558,'furniture-mobile','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(486559,'furniture-mobile','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(486560,'furniture-mobile','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(486561,'furniture-mobile','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(486562,'furniture-mobile','.w-product-groups .radioBox','padding-left','0','','','.w-product-groups'),(486563,'furniture-mobile','.w-product-groups .radioBox label','padding-left','0','','','.w-product-groups'),(486564,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','padding-left','10','','','.w-product-groups'),(486565,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','padding-left','10','2906','','.w-product-groups'),(486566,'furniture-mobile','.w-product-groups .radioBox label .containerBlock img + .name','padding-left','60','','','.w-product-groups'),(486567,'furniture-mobile','.w-product-groups .radioBox label .containerBlock img + .name + .val2','padding-left','60','','','.w-product-groups'),(486568,'furniture-mobile','.b-products-listing .mix-attributes .attribute-qty-block','padding-left','10','','','.b-products-listing'),(486569,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block','padding-left','5','','','.b-products-listing'),(486570,'furniture-mobile','.blogsidebar','padding-left','0','2885','',''),(486571,'furniture-mobile','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(486572,'furniture-mobile','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-left','25','','','.w-product-custom-bundle'),(486573,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list'),(486574,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(486575,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-left','10','','','.w-catalog-pages-category-pages-last-list'),(486576,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list-block'),(486577,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-left','10','','','.w-catalog-pages-category-pages-last-list-block'),(486578,'furniture-mobile','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(486579,'furniture-mobile','.w-delivery-location-location-description .deliveryDesc','padding-left','0','','','.w-delivery-location-location-description'),(486580,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent a','padding-left','25','','','.w-delivery-location-location-list'),(486581,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','padding-left','15','','','.w-delivery-location-location-list'),(486582,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding-left','2','','','.w-delivery-location-featured-list'),(486583,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul','padding-left','0','','','.w-delivery-location-featured-list'),(486584,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding-left','0','2906','','.w-delivery-location-featured-list'),(486585,'furniture-mobile','.btn-2','padding-left','25','2876','',''),(486586,'furniture-mobile','.w-sale-category .holder-1','padding-left','20','','','.w-sale-category'),(486587,'furniture-mobile','.w-sale-category .holder-2','padding-left','20','','','.w-sale-category'),(486588,'furniture-mobile','.w-sale-category .left-count','padding-left','5','','','.w-sale-category'),(486589,'furniture-mobile','.w-product-wedding-registry-button .btn','padding-left','70','','','.w-product-wedding-registry-button'),(486590,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(486591,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-left','10','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(486592,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(486593,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-left','10','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(486594,'furniture-mobile','.w-delivery-location-list-by-page .description ul','padding-left','30','','','.w-delivery-location-list-by-page'),(486595,'furniture-mobile','.w-product-properties-icons .property-image','padding-left','10','','','.w-product-properties-icons'),(486596,'furniture-mobile','.w-product-properties-icons .hover-box-content','padding-left','10','','','.w-product-properties-icons'),(486597,'furniture-mobile','.w-delivery-location-cross-pages .description ul','padding-left','30','','','.w-delivery-location-cross-pages'),(486598,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','padding-left','15','','','.w-delivery-location-product-categories'),(486599,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','padding-left','10','2885','','.w-delivery-location-product-categories'),(486600,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','padding-left','0','2906','','.w-delivery-location-product-categories'),(486601,'furniture-mobile','.w-delivery-location-product-categories .name','padding-left','15','','','.w-delivery-location-product-categories'),(486602,'furniture-mobile','.w-catalog-delivery-locations .description ul','padding-left','30','','','.w-catalog-delivery-locations'),(486603,'furniture-mobile','.w-wedding-registry-widgets-search-paging ul.pagination','padding-left','0','','','.w-wedding-registry-widgets-search-paging'),(486604,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','padding-left','5','','','.w-wedding-registry-widgets-search-paging'),(486605,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','padding-left','5','','','.w-wedding-registry-widgets-search-paging'),(486606,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','padding-left','5','','','.w-wedding-registry-widgets-search-paging'),(486607,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','padding-left','5','','','.w-wedding-registry-widgets-search-paging'),(486608,'furniture-mobile','.w-wedding-registry-widgets-search-list .table td, .w-wedding-registry-widgets-search-list .table .headings td','padding-left','10','2885','','.w-wedding-registry-widgets-search-list'),(486609,'furniture-mobile','.w-wedding-registry-widgets-search-list .table .headings td','padding-left','15','','','.w-wedding-registry-widgets-search-list'),(486610,'furniture-mobile','.delivery-options-popup','padding-left','20','','',''),(486611,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','padding-left','45','','','.w-product-bonus-points'),(486612,'furniture-mobile','.w-product-designer-designer .grnamebox .title-sortable','padding-left','15','','','.w-product-designer-designer'),(486613,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','padding-left','10','','','.w-product-designer-designer'),(486614,'furniture-mobile','.w-press-reviews-widgets-press-reviews ','padding-left','30','','','.w-press-reviews-widgets-press-reviews'),(486615,'furniture-mobile','.w-press-reviews-widgets-press-reviews .author','padding-left','25','','','.w-press-reviews-widgets-press-reviews'),(486616,'furniture-mobile','.w-press-reviews-widgets-press-reviews .item','padding-left','20','','','.w-press-reviews-widgets-press-reviews'),(486617,'furniture-mobile','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-left','30','','','.w-press-reviews-widgets-press-reviews'),(486618,'furniture-mobile','.w-press-reviews-widgets-press-reviews .rating','padding-left','15','','','.w-press-reviews-widgets-press-reviews'),(486619,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','padding-left','25','','','.w-press-reviews-widgets-press-reviews'),(486620,'furniture-mobile','.w-press-reviews-widgets-press-reviews .sub-box','padding-left','20','','','.w-press-reviews-widgets-press-reviews'),(486621,'furniture-mobile','.w-press-reviews-widgets-press-reviews .sub-box ul','padding-left','20','','','.w-press-reviews-widgets-press-reviews'),(486622,'furniture-mobile','.w-press-reviews-widgets-press-reviews .title','padding-left','15','','','.w-press-reviews-widgets-press-reviews'),(486623,'furniture-mobile','.w-press-reviews-widgets-press-reviews ','padding-left','15','2876','','.w-press-reviews-widgets-press-reviews'),(486624,'furniture-mobile','.w-press-reviews-widgets-press-reviews .author','padding-left','0','2876','','.w-press-reviews-widgets-press-reviews'),(486625,'furniture-mobile','.w-press-reviews-widgets-press-reviews .item','padding-left','0','2876','','.w-press-reviews-widgets-press-reviews'),(486626,'furniture-mobile','.w-press-reviews-widgets-press-reviews .rating','padding-left','0','2876','','.w-press-reviews-widgets-press-reviews'),(486627,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','padding-left','0','2876','','.w-press-reviews-widgets-press-reviews'),(486628,'furniture-mobile','.w-press-reviews-widgets-press-reviews .title','padding-left','0','2876','','.w-press-reviews-widgets-press-reviews'),(486629,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .item','padding-left','25','','','.w-press-reviews-widgets-press-reviews-list'),(486630,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .short-description','padding-left','0','','','.w-press-reviews-widgets-press-reviews-list'),(486631,'furniture-mobile','.b-products-listing .productGroup label a','padding-left','16','','','.b-products-listing'),(486632,'furniture-mobile','.w-support-system-filter ','padding-left','0','','','.w-support-system-filter'),(486633,'furniture-mobile','.w-support-system-filter .filter_cats','padding-left','0','','','.w-support-system-filter'),(486634,'furniture-mobile','.w-support-system-listing .support-head','padding-left','13','','','.w-support-system-listing'),(486635,'furniture-mobile','.w-communication-post .btn.refresh','padding-left','0','','','.w-communication-post'),(486636,'furniture-mobile','.w-rma-returns-history .btn','padding-left','10','','','.w-rma-returns-history'),(486637,'furniture-mobile','.w-rma-returns-history .column','padding-left','3','','','.w-rma-returns-history'),(486638,'furniture-mobile','.w-rma-returns-history .column .title','padding-left','10','','','.w-rma-returns-history'),(486639,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','padding-left','5','','','.w-rma-returns-history'),(486640,'furniture-mobile','.w-rma-returns-history .icons .print','padding-left','15','','','.w-rma-returns-history'),(486641,'furniture-mobile','.w-rma-returns-history .topRow','padding-left','0','','','.w-rma-returns-history'),(486642,'furniture-mobile','.w-rma-returns-history .column:last-child .title','padding-left','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(486643,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','padding-left','20','','','.b-menu-style-1'),(486644,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .goto-button','padding-left','20','','','.b-menu-style-1'),(486645,'furniture-mobile','.w-product-designer-designer .productDesignerBox ul','padding-left','0','','','.w-product-designer-designer'),(486646,'furniture-mobile','.w-product-configurator .pc-item','padding-left','0','','','.w-product-configurator'),(486647,'furniture-mobile','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(486648,'furniture-mobile','.w-product-configurator .pc_item','padding-left','0','2885','','.w-product-configurator'),(486649,'furniture-mobile','.w-product-configurator .pc_attr','padding-left','0','2876','','.w-product-configurator'),(486650,'furniture-mobile','.w-product-configurator .pc-item label','padding-left','20','','','.w-product-configurator'),(486651,'furniture-mobile','.b-products-listing .promos-info .promo-name-span','padding-left','40','','','.b-products-listing'),(486652,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-list'),(486653,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-left','10','','','.w-catalog-pages-category-pages-list'),(486654,'furniture-mobile','.w-predefined-promotion .nextdiscount .content > div','padding-left','10','','','.w-predefined-promotion'),(486655,'furniture-mobile','.w-predefined-promotion .nextdiscount .promo-for-each','padding-left','10','','','.w-predefined-promotion'),(486656,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-product','padding-left','20','','','.w-predefined-promotion'),(486657,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','padding-left','20','','','.w-predefined-promotion'),(486658,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .item','padding-left','20','','','.w-predefined-promotion'),(486659,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-left','20','','','.w-predefined-promotion'),(486660,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave','padding-left','15','','','.w-predefined-promotion'),(486661,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-left','20','','','.w-predefined-promotion'),(486662,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .item','padding-left','20','','','.w-predefined-promotion'),(486663,'furniture-mobile','.w-predefined-promotion .promo-item','padding-left','40','','','.w-predefined-promotion'),(486664,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','padding-left','20','','','.w-predefined-promotion'),(486665,'furniture-mobile','.w-predefined-promotion .promo-salemaker .item','padding-left','20','','','.w-predefined-promotion'),(486666,'furniture-mobile','.w-predefined-promotion .promo-salemaker .promo-manufacturers','padding-left','12','','','.w-predefined-promotion'),(486667,'furniture-mobile','.w-supplier-purchase-supplier-products .item','padding-left','20','','','.w-supplier-purchase-supplier-products'),(486668,'furniture-mobile','.w-filters .filter-box-content ul','padding-left','0','','','.w-filters'),(486669,'furniture-mobile','.mainBanner .bottomBox','padding-left','20','','','.mainBanner'),(486670,'furniture-mobile','.mainBanner .bottomBox .btn','padding-left','1.30','','','.mainBanner'),(486671,'furniture-mobile','.mainBanner .title','padding-left','130','','','.mainBanner'),(486672,'furniture-mobile','.mainBanner .topBox','padding-left','10','','','.mainBanner'),(486673,'furniture-mobile','.mainBanner .topBox > .right','padding-left','15','','','.mainBanner'),(486674,'furniture-mobile','.mainBanner .wrapper','padding-left','6','','','.mainBanner'),(486675,'furniture-mobile','.mainBanner > .block','padding-left','0','','','.mainBanner'),(486676,'furniture-mobile','.mainBanner .bottomBox','padding-left','20','2890','','.mainBanner'),(486677,'furniture-mobile','.mainBanner .bottomBox .btn','padding-left','20','2890','','.mainBanner'),(486678,'furniture-mobile','.mainBanner .topBox','padding-left','10','2890','','.mainBanner'),(486679,'furniture-mobile','.mainBanner .topBox > .right','padding-left','15','2890','','.mainBanner'),(486680,'furniture-mobile','.mainBanner .wrapper','padding-left','2','2890','','.mainBanner'),(486681,'furniture-mobile','.mainBanner .bottomBox .btn','padding-left','20','2885','','.mainBanner'),(486682,'furniture-mobile','.mainBanner .title','padding-left','90','2885','','.mainBanner'),(486683,'furniture-mobile','.mainBanner .topBox','padding-left','40','2876','','.mainBanner'),(486684,'furniture-mobile','.mainBanner .topBox > .right','padding-left','15','2876','','.mainBanner'),(486685,'furniture-mobile','.mainBanner .wrapper','padding-left','2','2876','','.mainBanner'),(486686,'furniture-mobile','.mainBanner .bottomBox','padding-left','20','2906','','.mainBanner'),(486687,'furniture-mobile','.mainBanner .bottomBox .btn','padding-left','15','2906','','.mainBanner'),(486688,'furniture-mobile','.mainBanner .wrapper','padding-left','2','2906','','.mainBanner'),(486689,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','padding-left','24','','','.lowestPricedBox'),(486690,'furniture-mobile','.lowestPricedBox .w-banner .ybg .mark','padding-left','0','','','.lowestPricedBox'),(486691,'furniture-mobile','.lowestPricedBox .w-banner .banner','padding-left','0','2876','','.lowestPricedBox'),(486692,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','padding-left','10','2906','','.lowestPricedBox'),(486693,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','padding-left','20','2906','','.lowestPricedBox'),(486694,'furniture-mobile','.shopByCollectionBox .bannerButton a','padding-left','25','','','.shopByCollectionBox'),(486695,'furniture-mobile','.shopByCollectionBox .content','padding-left','20','','','.shopByCollectionBox'),(486696,'furniture-mobile','.shopByCollectionBox .bannerButton a','padding-left','25','2890','','.shopByCollectionBox'),(486697,'furniture-mobile','.w-quote-products .no-price','padding-left','15','','','.w-quote-products'),(486698,'furniture-mobile','.w-search .products .item a','padding-left','0','','','.w-search'),(486699,'furniture-mobile','.w-search .wrap','padding-left','15','','','.w-search'),(486700,'furniture-mobile','.w-search .products .item','padding-left','20','','','.w-search'),(486701,'furniture-mobile','.w-search .products .items-title','padding-left','20','','','.w-search'),(486702,'furniture-mobile','.account-address-book .address_book','padding-left','0','','','.account-address-book'),(486703,'furniture-mobile','.account-address-book .address_book h1','padding-left','0','','','.account-address-book'),(486704,'furniture-mobile','.account-address-book .address_book h2','padding-left','10','','','.account-address-book'),(486705,'furniture-mobile','.account-address-book .address_book, .account-address-book .account_history_info','padding-left','0','','','.account-address-book'),(486706,'furniture-mobile','.account-address-book .btn-edit','padding-left','10','4','','.account-address-book'),(486707,'furniture-mobile','.account-address-book .buttonBox','padding-left','0','','','.account-address-book'),(486708,'furniture-mobile','.account-address-book .leftMes ul','padding-left','0','','','.account-address-book'),(486709,'furniture-mobile','.account-address-book .rightMes ul','padding-left','19','','','.account-address-book'),(486710,'furniture-mobile','.account-address-book .topButtons','padding-left','0','','','.account-address-book'),(486711,'furniture-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','padding-left','10','','','.account-order-history'),(486712,'furniture-mobile','.account-order-history .orders-table th','padding-left','10','','','.account-order-history'),(486713,'furniture-mobile','.account-order-history .order_history_table th','padding-left','10','','','.account-order-history'),(486714,'furniture-mobile','.account-order-history .view_link','padding-left','0','','','.account-order-history'),(486715,'furniture-mobile','.account-order-history .orders-table .td-alignright','padding-left','10','2885','','.account-order-history'),(486716,'furniture-mobile','.account-order-history .orders-table td','padding-left','10','2885','','.account-order-history'),(486717,'furniture-mobile','.account-order-history-info .contentColumn','padding-left','40','','','.account-order-history-info'),(486718,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','padding-left','40','','','.account-order-history-info'),(486719,'furniture-mobile','.account-order-history-info .history_info > div + div','padding-left','2','','','.account-order-history-info'),(486720,'furniture-mobile','.account-order-history-info .popup-tracking-number','padding-left','10','','','.account-order-history-info'),(486721,'furniture-mobile','.account-order-history-info .history_info > div','padding-left','0','2885','','.account-order-history-info'),(486722,'furniture-mobile','.account-order-history-info .history_info > div + div','padding-left','0','2885','','.account-order-history-info'),(486723,'furniture-mobile','.account-index .account_block','padding-left','40','','','.account-index'),(486724,'furniture-mobile','.account-index .account_info','padding-left','0','','','.account-index'),(486725,'furniture-mobile','.account-index .account_info li','padding-left','0','','','.account-index'),(486726,'furniture-mobile','.account-index .account_page','padding-left','0','','','.account-index'),(486727,'furniture-mobile','.account-index .account_page h2.order-table-title','padding-left','30','','','.account-index'),(486728,'furniture-mobile','.account-index .account_page h4','padding-left','40','','','.account-index'),(486729,'furniture-mobile','.account-index .badc_bottom','padding-left','0','','','.account-index'),(486730,'furniture-mobile','.account-index .date_title','padding-left','0','','','.account-index'),(486731,'furniture-mobile','.account-index .leftMes ul','padding-left','0','','','.account-index'),(486732,'furniture-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','padding-left','10','','','.account-index'),(486733,'furniture-mobile','.account-index .rightMes ul','padding-left','19','','','.account-index'),(486734,'furniture-mobile','.account-index .topAccount','padding-left','19','','','.account-index'),(486735,'furniture-mobile','.account-index .topAccount > li','padding-left','2','','','.account-index'),(486736,'furniture-mobile','.account-index .view_link','padding-left','0','','','.account-index'),(486737,'furniture-mobile','.account-index .account_info','padding-left','0','2885','','.account-index'),(486738,'furniture-mobile','.account-index .orders-table .links','padding-left','10','2885','','.account-index'),(486739,'furniture-mobile','.account-index .orders-table td','padding-left','10','2885','','.account-index'),(486740,'furniture-mobile','.account-index .account_info li','padding-left','0','2876','','.account-index'),(486741,'furniture-mobile','.account-index .topAccount > li','padding-left','0','2876','','.account-index'),(486742,'furniture-mobile','.account-index .topAccount > li > div','padding-left','55','2876','','.account-index'),(486743,'furniture-mobile','.account-order-pay .contentColumn','padding-left','40','','','.account-order-pay'),(486744,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-left','40','','','.account-order-pay'),(486745,'furniture-mobile','.account-order-pay .history_info > div + div','padding-left','2','','','.account-order-pay'),(486746,'furniture-mobile','.account-order-pay .history_info > div','padding-left','0','2885','','.account-order-pay'),(486747,'furniture-mobile','.account-order-pay .history_info > div + div','padding-left','0','2885','','.account-order-pay'),(486748,'furniture-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-left','10','','','.account-samples'),(486749,'furniture-mobile','.account-samples .orders-table th','padding-left','10','','','.account-samples'),(486750,'furniture-mobile','.account-samples .order_history_table th','padding-left','10','','','.account-samples'),(486751,'furniture-mobile','.account-samples .view_link','padding-left','0','','','.account-samples'),(486752,'furniture-mobile','.account-samples .orders-table .td-alignright','padding-left','10','2885','','.account-samples'),(486753,'furniture-mobile','.account-samples .orders-table td','padding-left','10','2885','','.account-samples'),(486754,'furniture-mobile','.account-sample-info .contentColumn','padding-left','40','','','.account-sample-info'),(486755,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-left','40','','','.account-sample-info'),(486756,'furniture-mobile','.account-sample-info .history_info > div + div','padding-left','2','','','.account-sample-info'),(486757,'furniture-mobile','.account-sample-info .popup-tracking-number','padding-left','10','','','.account-sample-info'),(486758,'furniture-mobile','.account-sample-info .history_info > div','padding-left','0','2885','','.account-sample-info'),(486759,'furniture-mobile','.account-sample-info .history_info > div + div','padding-left','0','2885','','.account-sample-info'),(486760,'furniture-mobile','.catalog-product-wrap .next-product','padding-left','20','','','.catalog-product-wrap'),(486761,'furniture-mobile','.catalog-product-wrap .next-product .pn-image','padding-left','2','3','','.catalog-product-wrap'),(486762,'furniture-mobile','.catalog-product-wrap .pn-direction','padding-left','4','','','.catalog-product-wrap'),(486763,'furniture-mobile','.catalog-product-wrap .pn-image','padding-left','5','','','.catalog-product-wrap'),(486764,'furniture-mobile','.catalog-product-wrap .prev-product','padding-left','50','','','.catalog-product-wrap'),(486765,'furniture-mobile','.catalog-product-wrap .next-product','padding-left','0','2885','','.catalog-product-wrap'),(486766,'furniture-mobile','.catalog-product-wrap .pn-direction','padding-left','0','2885','','.catalog-product-wrap'),(486767,'furniture-mobile','.catalog-product-wrap .prev-product','padding-left','0','2885','','.catalog-product-wrap'),(486768,'furniture-mobile','.shopping-cart-index .btn-3','padding-left','25','','','.shopping-cart-index'),(486769,'furniture-mobile','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-left','20','','','.shopping-cart-index'),(486770,'furniture-mobile','.checkout-index-wrap .datepicker-inline','padding-left','0','','','.checkout-index-wrap'),(486771,'furniture-mobile','.checkout-index-wrap .edit-address-popup','padding-left','20','','','.checkout-index-wrap'),(486772,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-left','25','','','.checkout-index-wrap'),(486773,'furniture-mobile','.checkout-order-confirmation .price-row','padding-left','0','','','.checkout-order-confirmation'),(486774,'furniture-mobile','.b-data-table table.dataTable tbody td','padding-left_important','important','','','.b-data-table'),(486775,'furniture-mobile','.b-data-table table.dataTable thead td','padding-left_important','important','','','.b-data-table'),(486776,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left_important','important','','','.b-data-table'),(486777,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left_important','important','','','.b-data-table'),(486778,'furniture-mobile','.batchPr .w-batch-products','padding-left_important','important','','','.batchPr'),(486779,'furniture-mobile','.w-cart-listing .points','padding-left_important','important','2876','','.w-cart-listing'),(486780,'furniture-mobile','.w-account-personal-catalog .buy-box','padding-left_important','important','2876','','.w-account-personal-catalog'),(486781,'furniture-mobile','.mainBanner > .block','padding-left_important','important','','','.mainBanner'),(486782,'furniture-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-right','10','','','.w-communication-new-topic'),(486784,'furniture-mobile','.b-email .image','padding-right','10','','','.b-email'),(486785,'furniture-mobile','.p-blog-index .wp-widget ul','padding-right','0','','','.p-blog-index'),(486786,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-right','10','','','.p-blog-index'),(486787,'furniture-mobile','.p-reviews-info .review-info-content','padding-right','20','','','.p-reviews-info'),(486788,'furniture-mobile','.order-summary .btn-2, .order-summary .btn-3','padding-right','5','','','.order-summary'),(486789,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-right','0','','','.p-reviews-info'),(486790,'furniture-mobile','.b-table .table td','padding-right','15','','','.b-table'),(486791,'furniture-mobile','.w-cart .multicart .cart-content','padding-right','0','','','.w-cart'),(486792,'furniture-mobile','.w-catalog-paging .next','padding-right','5','','','.w-catalog-paging'),(486793,'furniture-mobile','.w-cart a.item','padding-right','0','','','.w-cart'),(486794,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(486795,'furniture-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(486796,'furniture-mobile','.b-form .required-message-wrap','padding-right','0','','','.b-form'),(486797,'furniture-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-right','10','','','.p-quick-order-index'),(486798,'furniture-mobile','.p-quick-order-index ul.token-input-list','padding-right','0','','','.p-quick-order-index'),(486799,'furniture-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-right','10','','','.p-quick-order-index'),(486800,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.p-quick-order-index'),(486801,'furniture-mobile','.w-promotions .promo-date > div','padding-right','50','','','.w-promotions'),(486802,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.p-quick-order-index'),(486803,'furniture-mobile','.w-promotions .promo-item','padding-right','40','','','.w-promotions'),(486804,'furniture-mobile','.w-socials > li','padding-right','15','','','.w-socials'),(486805,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-right','0','','','.p-blog-index'),(486806,'furniture-mobile','.w-cart-compare .attributes-label','padding-right','10','','','.w-cart-compare'),(486807,'furniture-mobile','.w-account .acc-returning','padding-right','0','','','.w-account'),(486808,'furniture-mobile','.w-account .account-dropdown','padding-right','25','','','.w-account'),(486809,'furniture-mobile','.w-account .account-top','padding-right','0','','','.w-account'),(486810,'furniture-mobile','.w-account .my-acc-link','padding-right','10','','','.w-account'),(486811,'furniture-mobile','.w-personal-gift-status-bar .start-label','padding-right','5','','','.w-personal-gift-status-bar'),(486812,'furniture-mobile','.w-personal-gift-status-bar .end-label','padding-right','30','','','.w-personal-gift-status-bar'),(486813,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(486814,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-right','0','','','.p-reviews-info'),(486815,'furniture-mobile','.p-reviews-info .review-info-image','padding-right','20','','','.p-reviews-info'),(486816,'furniture-mobile','.p-reviews-info .review-info-text','padding-right','10','','','.p-reviews-info'),(486817,'furniture-mobile','.p-reviews-info .review-info-content','padding-right','20','','','.p-reviews-info'),(486818,'furniture-mobile','.p-blog-index .wp-widget ul','padding-right','0','','','.p-blog-index'),(486819,'furniture-mobile','.p-blog-index .nav-next','padding-right','50','','','.p-blog-index'),(486820,'furniture-mobile','.p-blog-index .nav-links','padding-right','0','','','.p-blog-index'),(486821,'furniture-mobile','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(486822,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(486823,'furniture-mobile','.b-email .image','padding-right','10','','','.b-email'),(486824,'furniture-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(486825,'furniture-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(486826,'furniture-mobile','.b-email .model','padding-right','10','','','.b-email'),(486827,'furniture-mobile','.testimonials .heading-3','padding-right','0','','',''),(486828,'furniture-mobile','.testimonials .review','padding-right','10','','',''),(486829,'furniture-mobile','.testimonials .reviews-list .name','padding-right','10','','',''),(486830,'furniture-mobile','.testimonials .name','padding-right','10','','',''),(486831,'furniture-mobile','.w-categories .image','padding-right','0','','','.w-categories'),(486832,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','padding-right','20','','','.w-promotions'),(486833,'furniture-mobile','.w-promotions .prom-multi-discount .promo-product','padding-right','20','','','.w-promotions'),(486834,'furniture-mobile','.w-catalog-paging .paging-item','padding-right','2','','','.w-catalog-paging'),(486835,'furniture-mobile','.w-promotions .nextdiscount .item-holder .image','padding-right','10','','','.w-promotions'),(486836,'furniture-mobile','.w-promotions .nextdiscount .content > div','padding-right','10','','','.w-promotions'),(486837,'furniture-mobile','.w-promotions .master','padding-right','15','','','.w-promotions'),(486838,'furniture-mobile','.w-promotions .nextdiscount .promo-for-each','padding-right','20','','','.w-promotions'),(486839,'furniture-mobile','.w-promotions .heading','padding-right','10','','','.w-promotions'),(486840,'furniture-mobile','.w-promotions .promo-salemaker .promo-categories','padding-right','12','','','.w-promotions'),(486841,'furniture-mobile','.w-promotions .promo-salemaker .item','padding-right','20','','','.w-promotions'),(486842,'furniture-mobile','.w-promotions .promo-salemaker .discount','padding-right','20','','','.w-promotions'),(486843,'furniture-mobile','.w-promotions .promo-cart-discount .slave .item','padding-right','20','','','.w-promotions'),(486844,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-right','20','','','.w-promotions'),(486845,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-right','20','','','.w-promotions'),(486846,'furniture-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-right','20','','','.b-warehouses-popup'),(486847,'furniture-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-right','2','','','.b-products-listing'),(486848,'furniture-mobile','.w-account .acc-new','padding-right','10','','','.w-account'),(486849,'furniture-mobile','.w-cart-compare .attributes-cell','padding-right','20','','','.w-cart-compare'),(486850,'furniture-mobile','.b-table .table td','padding-right','15','','','.b-table'),(486851,'furniture-mobile','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(486852,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(486853,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-right','20','','','.p-account-trade-form'),(486854,'furniture-mobile','.p-account-trade-form .widget','padding-right','0','','','.p-account-trade-form'),(486855,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-right','10','','','.p-account-subscription-historyinfo'),(486856,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-right','0','','','.w-menu'),(486857,'furniture-mobile','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(486858,'furniture-mobile','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(486859,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(486860,'furniture-mobile','.b-bottom .confirm-popup .confirm-text','padding-right','0','','','.b-bottom'),(486861,'furniture-mobile','.w-top-categories h2.name','padding-right','3','','','.w-top-categories'),(486862,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','2885','','.w-menu-style-1'),(486863,'furniture-mobile','.b-messages .messages-menu ul','padding-right','0','','','.b-messages'),(486864,'furniture-mobile','.b-messages .development-content .type-6 .content','padding-right','40','','','.b-messages'),(486865,'furniture-mobile','.b-messages .msv_btn','padding-right','0','','','.b-messages'),(486866,'furniture-mobile','.b-messages .msv_content','padding-right','20','','','.b-messages'),(486867,'furniture-mobile','.b-messages .msv_history','padding-right','20','','','.b-messages'),(486868,'furniture-mobile','.b-messages .messMenuButton span','padding-right','15','','','.b-messages'),(486869,'furniture-mobile','.b-messages .messages-menu li a','padding-right','0','','','.b-messages'),(486870,'furniture-mobile','.b-messages .messages-menu li','padding-right','0','','','.b-messages'),(486871,'furniture-mobile','.b-messages .content_management_attach button','padding-right','27','','','.b-messages'),(486872,'furniture-mobile','.b-messages .email-heading','padding-right','15','','','.b-messages'),(486873,'furniture-mobile','.b-messages .content_management_attach','padding-right','8','','','.b-messages'),(486874,'furniture-mobile','.b-messages .emailLineTextArea textarea','padding-right','10','','','.b-messages'),(486875,'furniture-mobile','.b-messages .msv_to_cc','padding-right','15','','','.b-messages'),(486876,'furniture-mobile','.b-messages .emailBtn','padding-right','10','','','.b-messages'),(486877,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-right','10','','','.b-messages'),(486878,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-right','10','','',''),(486879,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul > li','padding-right','20','','','.w-sitemap-delivery-location'),(486880,'furniture-mobile','.w-sale .holder-2','padding-right','20','','','.w-sale'),(486881,'furniture-mobile','.w-sale .left-count','padding-right','5','','','.w-sale'),(486882,'furniture-mobile','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(486883,'furniture-mobile','.w-reviews-content .item','padding-right','0','','','.w-reviews-content'),(486884,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(486885,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-right','0','','','.p-reviews-info'),(486886,'furniture-mobile','.p-reviews-info .review-info-image','padding-right','20','','','.p-reviews-info'),(486887,'furniture-mobile','.p-blog-index .nav-next','padding-right','50','','','.p-blog-index'),(486888,'furniture-mobile','.p-blog-index .wp-widget ul','padding-right','0','','','.p-blog-index'),(486889,'furniture-mobile','.p-blog-index .nav-links','padding-right','0','','','.p-blog-index'),(486890,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-right','0','','','.w-sitemap-delivery-location'),(486891,'furniture-mobile','.w-sitemap-delivery-location > ul','padding-right','0','','','.w-sitemap-delivery-location'),(486892,'furniture-mobile','.w-checkout-terms .required-message','padding-right','10','','','.w-checkout-terms'),(486893,'furniture-mobile','.w-cart-listing .item .remove','padding-right','10','2885','','.w-cart-listing'),(486894,'furniture-mobile','.b-table .table td','padding-right','15','','','.b-table'),(486895,'furniture-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(486896,'furniture-mobile','.b-info .info li','padding-right','0','','','.b-info'),(486897,'furniture-mobile','.b-info .info ul','padding-right','0','','','.b-info'),(486898,'furniture-mobile','.b-email .model','padding-right','10','','','.b-email'),(486899,'furniture-mobile','.b-upload-file .upload-file-template','padding-right','1','','','.b-upload-file'),(486900,'furniture-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(486901,'furniture-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(486902,'furniture-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(486903,'furniture-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(486904,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-right','20','','','.p-account-trade-form'),(486905,'furniture-mobile','.p-account-trade-form .widget','padding-right','0','','','.p-account-trade-form'),(486906,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-right','10','','','.p-account-subscription-historyinfo'),(486907,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-right','10','','','.p-blog-index'),(486908,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(486909,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(486910,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(486911,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(486912,'furniture-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(486913,'furniture-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(486915,'furniture-mobile','.b-email .price','padding-right','10','','','.b-email'),(486916,'furniture-mobile','.w-filters .filter-ul-content','padding-right','0','','','.w-filters'),(486917,'furniture-mobile','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(486918,'furniture-mobile','.w-login-block .returning','padding-right','40','','','.w-login-block'),(486919,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li','padding-right','10','','','.w-menu-horizontal'),(486920,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-right','10','','','.w-menu-horizontal'),(486921,'furniture-mobile','.w-menu-horizontal ul','padding-right','0','','','.w-menu-horizontal'),(486922,'furniture-mobile','.w-menu-slider > ul > li > a','padding-right','10','','','.w-menu-slider'),(486923,'furniture-mobile','.w-tabs .tab-navigation','padding-right','0','','','.w-tabs'),(486924,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-right','0','','','.p-blog-index'),(486925,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-right','10','','','.p-blog-index'),(486926,'furniture-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(486927,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(486928,'furniture-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(486929,'furniture-mobile','.w-sale .holder-2','padding-right','20','','','.w-sale'),(486930,'furniture-mobile','.w-sale .left-count','padding-right','5','','','.w-sale'),(486931,'furniture-mobile','.w-languages .lang-link','padding-right','10','','','.w-languages'),(486932,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-right','10','','','.p-account-subscription-historyinfo'),(486933,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(486934,'furniture-mobile','.b-fancybox .fancybox-title-over-wrap','padding-right','10','','','.b-fancybox'),(486935,'furniture-mobile','.b-email .image','padding-right','10','','','.b-email'),(486936,'furniture-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(486937,'furniture-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(486938,'furniture-mobile','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(486939,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-right','50','','','.w-menu-slider'),(486940,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(486941,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-right','10','','','.p-blog-index'),(486942,'furniture-mobile','.p-account-trade-form .widget','padding-right','0','','','.p-account-trade-form'),(486943,'furniture-mobile','.b-table .table .headings td','padding-right','10','','','.b-table'),(486944,'furniture-mobile','.b-sub-totals .historyTotal td','padding-right','5','','','.b-sub-totals'),(486945,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(486946,'furniture-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(486947,'furniture-mobile','.b-email .qty','padding-right','10','','','.b-email'),(486948,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-right','0','','','.p-blog-index'),(486949,'furniture-mobile','.p-blog-index .wp-widget li','padding-right','0','','','.p-blog-index'),(486950,'furniture-mobile','.p-reviews-info .review-info-image','padding-right','20','','','.p-reviews-info'),(486951,'furniture-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-right','0','','','.w-cart-compare'),(486952,'furniture-mobile','textarea','padding-right','10','','',''),(486953,'furniture-mobile','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(486954,'furniture-mobile','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(486955,'furniture-mobile','.w-catalog-paging .prev','padding-right','5','','','.w-catalog-paging'),(486956,'furniture-mobile','.w-cart-compare .product','padding-right','15','','','.w-cart-compare'),(486957,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','2885','','.w-menu-style-1'),(486958,'furniture-mobile','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(486959,'furniture-mobile','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(486960,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','','','.w-menu-style-1'),(486961,'furniture-mobile','.w-menu .hided.menu ul li','padding-right','0','','','.w-menu'),(486962,'furniture-mobile','.w-menu-style-1 ul','padding-right','0','','','.w-menu-style-1'),(486963,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-right','10','','','.w-image-maps'),(486964,'furniture-mobile','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(486965,'furniture-mobile','.b-table .table .headings td','padding-right','10','','','.b-table'),(486966,'furniture-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(486967,'furniture-mobile','.b-form .payment-method .item','padding-right','0','','','.b-form'),(486968,'furniture-mobile','.message.success','padding-right','0','','',''),(486969,'furniture-mobile','.p-reviews-info .review-info-image','padding-right','20','','','.p-reviews-info'),(486970,'furniture-mobile','.p-reviews-info .review-info-content','padding-right','20','','','.p-reviews-info'),(486971,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-right','0','','','.p-reviews-info'),(486972,'furniture-mobile','.p-reviews-info .review-info-text','padding-right','10','','','.p-reviews-info'),(486973,'furniture-mobile','.p-blog-index .nav-next','padding-right','50','','','.p-blog-index'),(486974,'furniture-mobile','.p-blog-index .nav-links','padding-right','0','','','.p-blog-index'),(486975,'furniture-mobile','.w-promo-code .holder','padding-right','20','2906','','.w-promo-code'),(486976,'furniture-mobile','.w-cart-discount-coupon .btn','padding-right','25','','','.w-cart-discount-coupon'),(486977,'furniture-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(486978,'furniture-mobile','.w-checkout-shipping-choice span','padding-right','0','','','.w-checkout-shipping-choice'),(486980,'furniture-mobile','.b-info .info ul','padding-right','0','','','.b-info'),(486981,'furniture-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(486982,'furniture-mobile','.p-quick-order-index .bottom','padding-right','0','','','.p-quick-order-index'),(486983,'furniture-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(486984,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-right','0','','','.b-select-suggest'),(486985,'furniture-mobile','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(486986,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(486987,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-right','20','','','.w-menu-style-1'),(486988,'furniture-mobile','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(486989,'furniture-mobile','.w-reviews .review','padding-right','10','','','.w-reviews'),(486990,'furniture-mobile','.w-socials > li','padding-right','15','','','.w-socials'),(486991,'furniture-mobile','.w-search .suggest','padding-right','0','','','.w-search'),(486992,'furniture-mobile','.w-search .search-input','padding-right','40','','','.w-search'),(486993,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','2885','','.w-menu-style-1'),(486994,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','2885','','.w-menu-style-1'),(486995,'furniture-mobile','.b-info-popup .info-popup div','padding-right','15','','','.b-info-popup'),(486996,'furniture-mobile','.b-form .password-forgotten-link','padding-right','0','','','.b-form'),(486997,'furniture-mobile','.p-blog-index .nav-links','padding-right','0','','','.p-blog-index'),(486998,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-right','20','','','.p-account-trade-form'),(486999,'furniture-mobile','.w-languages .lang-link','padding-right','10','2885','','.w-languages'),(487000,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','2885','','.w-menu-style-1'),(487001,'furniture-mobile','.w-cart-compare .atr-col','padding-right','30','','','.w-cart-compare'),(487002,'furniture-mobile','.w-reviews .author','padding-right','10','','','.w-reviews'),(487003,'furniture-mobile','.b-info .info ul','padding-right','0','','','.b-info'),(487004,'furniture-mobile','.b-form .login-col-1','padding-right','20','','','.b-form'),(487005,'furniture-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(487006,'furniture-mobile','.w-promo-code .holder','padding-right','20','2906','','.w-promo-code'),(487007,'furniture-mobile','.w-product-images-additional .images','padding-right','0','2906','','.w-product-images-additional'),(487008,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-right','50','','','.w-menu-slider'),(487009,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-right','0','','','.w-menu-slider'),(487010,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','','','.w-menu-style-1'),(487011,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','','','.w-menu-style-1'),(487012,'furniture-mobile','.w-menu-style-1 ul','padding-right','0','','','.w-menu-style-1'),(487013,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(487014,'furniture-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-right','0','','','.w-multi-cart-actions'),(487015,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','2885','','.w-menu-style-1'),(487016,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','2885','','.w-menu-style-1'),(487017,'furniture-mobile','.w-top-categories .item','padding-right','20','','','.w-top-categories'),(487018,'furniture-mobile','.w-tabs > .block','padding-right','20','','','.w-tabs'),(487019,'furniture-mobile','.w-tabs .accordion-heading','padding-right','8','2876','','.w-tabs'),(487020,'furniture-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-right','0','','','.w-cart-cart-tabs'),(487021,'furniture-mobile','.w-tabs .tab-a','padding-right','6','','','.w-tabs'),(487022,'furniture-mobile','.w-tabs .tab-li','padding-right','15','','','.w-tabs'),(487023,'furniture-mobile','.w-socials > li','padding-right','15','','','.w-socials'),(487024,'furniture-mobile','.b-autocomplete .ui-autocomplete li','padding-right','10','','','.b-autocomplete'),(487025,'furniture-mobile','.b-bottom .popup-buttons','padding-right','15','','','.b-bottom'),(487026,'furniture-mobile','.b-bottom .popup-content','padding-right','15','','','.b-bottom'),(487027,'furniture-mobile','.w-product-images-additional .images','padding-right','0','2906','','.w-product-images-additional'),(487028,'furniture-mobile','.p-account-trade-form .widget','padding-right','0','','','.p-account-trade-form'),(487029,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(487030,'furniture-mobile','.w-sale .holder-1','padding-right','20','','','.w-sale'),(487031,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-right','0','','','.p-reviews-info'),(487032,'furniture-mobile','.b-form .required-message','padding-right','3','','','.b-form'),(487033,'furniture-mobile','.w-sale .holder-2','padding-right','20','','','.w-sale'),(487034,'furniture-mobile','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(487035,'furniture-mobile','.w-sale .left-count','padding-right','5','','','.w-sale'),(487036,'furniture-mobile','.p-blog-index .nav-links','padding-right','0','','','.p-blog-index'),(487037,'furniture-mobile','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(487038,'furniture-mobile','.p-blog-index .wp-widget li','padding-right','0','','','.p-blog-index'),(487039,'furniture-mobile','.p-blog-index .wp-widget ul','padding-right','0','','','.p-blog-index'),(487040,'furniture-mobile','.w-menu-slider > ul > li > a','padding-right','10','','','.w-menu-slider'),(487041,'furniture-mobile','.btn-1','padding-right','25','','',''),(487042,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-right','50','','','.w-menu-slider'),(487043,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-right','0','','','.w-menu-slider'),(487044,'furniture-mobile','.w-reviews-content .review','padding-right','20','','','.w-reviews-content'),(487045,'furniture-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(487046,'furniture-mobile','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(487047,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-right','20','','','.w-menu-style-1'),(487048,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','','','.w-menu-style-1'),(487049,'furniture-mobile','.b-table .table .headings td','padding-right','10','','','.b-table'),(487050,'furniture-mobile','.b-info .info','padding-right','0','','','.b-info'),(487051,'furniture-mobile','.btn-3','padding-right','25','','',''),(487052,'furniture-mobile','.w-filters .filter-widget-horizontal .filter-box','padding-right','20','','','.w-filters'),(487053,'furniture-mobile','.w-product-images-additional .images','padding-right','0','2906','','.w-product-images-additional'),(487054,'furniture-mobile','.b-products-listing .products-listing .buyButton .btn','padding-right','10','','','.b-products-listing'),(487055,'furniture-mobile','.b-bottom .popup-heading','padding-right','15','','','.b-bottom'),(487056,'furniture-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(487057,'furniture-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(487058,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(487059,'furniture-mobile','.b-info .info li','padding-right','0','','','.b-info'),(487060,'furniture-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(487061,'furniture-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(487062,'furniture-mobile','.b-email .price','padding-right','10','','','.b-email'),(487063,'furniture-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(487064,'furniture-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(487065,'furniture-mobile','.b-email .image','padding-right','10','','','.b-email'),(487066,'furniture-mobile','.b-email .name','padding-right','10','','','.b-email'),(487067,'furniture-mobile','.order-summary .price-row','padding-right','0','','','.order-summary'),(487068,'furniture-mobile','.b-email .name','padding-right','10','','','.b-email'),(487069,'furniture-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-right','0','','','.b-fancybox'),(487070,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','2885','','.w-menu-style-1'),(487071,'furniture-mobile','.w-socials > li','padding-right','15','','','.w-socials'),(487072,'furniture-mobile','.w-search .items-title','padding-right','0','','','.w-search'),(487073,'furniture-mobile','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(487074,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-right','50','','','.w-menu-slider'),(487075,'furniture-mobile','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(487076,'furniture-mobile','.b-select-suggest .select2-drop-mask','padding-right','0','','','.b-select-suggest'),(487077,'furniture-mobile','.w-search .name','padding-right','0','','','.w-search'),(487078,'furniture-mobile','.w-quote .cart-box-link','padding-right','10','','','.w-quote'),(487079,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-right','10','','','.p-account-subscription-historyinfo'),(487080,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-right','0','','','.p-blog-index'),(487081,'furniture-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(487082,'furniture-mobile','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(487083,'furniture-mobile','.b-email .price','padding-right','10','','','.b-email'),(487084,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-right','20','','','.b-fancybox'),(487085,'furniture-mobile','.w-checkout-shipping-choice span','padding-right','10','2906','','.w-checkout-shipping-choice'),(487086,'furniture-mobile','.w-top-categories .categories h2','padding-right','0','','','.w-top-categories'),(487087,'furniture-mobile','.w-top-categories .image','padding-right','0','','','.w-top-categories'),(487088,'furniture-mobile','.w-product-reviews .reviews-list .review','padding-right','10','','','.w-product-reviews'),(487089,'furniture-mobile','.w-reviews-content .product-image','padding-right','10','','','.w-reviews-content'),(487090,'furniture-mobile','.w-product-reviews .reviews-list .name','padding-right','10','','','.w-product-reviews'),(487091,'furniture-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(487092,'furniture-mobile','.b-email .name','padding-right','10','','','.b-email'),(487093,'furniture-mobile','.b-fancybox .fancybox-prev span','padding-right','4','3','','.b-fancybox'),(487094,'furniture-mobile','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(487095,'furniture-mobile','.p-blog-index .wp-widget ul','padding-right','0','','','.p-blog-index'),(487096,'furniture-mobile','.p-blog-index .wp-widget li','padding-right','0','','','.p-blog-index'),(487097,'furniture-mobile','.p-blog-index .nav-links','padding-right','0','','','.p-blog-index'),(487098,'furniture-mobile','.b-bottom .popup-simple','padding-right','20','','','.b-bottom'),(487099,'furniture-mobile','.b-bottom .rfq-form','padding-right','20','','','.b-bottom'),(487100,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(487101,'furniture-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(487102,'furniture-mobile','.p-blog-index .wp-widget li','padding-right','0','','','.p-blog-index'),(487103,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-right','17','','','.w-wedding-registry-widgets-photos'),(487104,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(487105,'furniture-mobile','.b-email .model','padding-right','10','','','.b-email'),(487106,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(487107,'furniture-mobile','.b-email .name','padding-right','10','','','.b-email'),(487108,'furniture-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(487109,'furniture-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(487110,'furniture-mobile','.b-email .image','padding-right','10','','','.b-email'),(487111,'furniture-mobile','.b-email .price','padding-right','10','','','.b-email'),(487112,'furniture-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(487113,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-right','0','','','.p-blog-index'),(487114,'furniture-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(487115,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(487116,'furniture-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(487117,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(487118,'furniture-mobile','.b-email .price','padding-right','10','','','.b-email'),(487119,'furniture-mobile','.b-email .qty','padding-right','10','','','.b-email'),(487120,'furniture-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(487121,'furniture-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(487122,'furniture-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(487125,'furniture-mobile','.b-info .info li','padding-right','0','','','.b-info'),(487126,'furniture-mobile','.w-checkout-shipping .sub-item','padding-right','0','','','.w-checkout-shipping'),(487127,'furniture-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(487128,'furniture-mobile','.b-table .table .headings td','padding-right','10','','','.b-table'),(487129,'furniture-mobile','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(487130,'furniture-mobile','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(487131,'furniture-mobile','.w-sale .holder-1','padding-right','20','','','.w-sale'),(487132,'furniture-mobile','.w-promo-code .holder','padding-right','20','2906','','.w-promo-code'),(487133,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(487134,'furniture-mobile','.b-form .center-buttons','padding-right','0','','','.b-form'),(487135,'furniture-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(487136,'furniture-mobile','.b-form .shipping-method .input','padding-right','10','','','.b-form'),(487137,'furniture-mobile','.w-menu-slider > ul > li > a','padding-right','10','','','.w-menu-slider'),(487138,'furniture-mobile','.w-reviews .item','padding-right','0','','','.w-reviews'),(487139,'furniture-mobile','.w-reviews .product-image','padding-right','20','','','.w-reviews'),(487140,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(487141,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(487142,'furniture-mobile','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(487143,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','padding-right','0','','','.b-select-suggest'),(487145,'furniture-mobile','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(487146,'furniture-mobile','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(487147,'furniture-mobile','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(487148,'furniture-mobile','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(487149,'furniture-mobile','.w-banner .carousel-text > span','padding-right','20','','','.w-banner'),(487150,'furniture-mobile','.b-info .info','padding-right','0','','','.b-info'),(487151,'furniture-mobile','.b-info .info li','padding-right','0','','','.b-info'),(487152,'furniture-mobile','.b-info .info ul','padding-right','0','','','.b-info'),(487153,'furniture-mobile','.b-bottom .terms-info-popup .pop-up-content','padding-right','20','','','.b-bottom'),(487154,'furniture-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','2885','','.w-menu-horizontal'),(487155,'furniture-mobile','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(487156,'furniture-mobile','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(487157,'furniture-mobile','.b-upload-files .upload-files','padding-right','10','','','.b-upload-files'),(487158,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','2885','','.w-menu-style-1'),(487159,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','2885','','.w-menu-style-1'),(487160,'furniture-mobile','.w-menu-style-1 ul','padding-right','0','','','.w-menu-style-1'),(487161,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(487162,'furniture-mobile','.w-login-block .returning','padding-right','40','','','.w-login-block'),(487163,'furniture-mobile','.b-form .form-buttons','padding-right','0','','','.b-form'),(487164,'furniture-mobile','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(487165,'furniture-mobile','.w-login-block .returning','padding-right','40','','','.w-login-block'),(487166,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(487167,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-right','0','','','.w-menu'),(487168,'furniture-mobile','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(487169,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(487170,'furniture-mobile','.w-cart-compare .delete-cart','padding-right','10','','','.w-cart-compare'),(487171,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-right','0','','','.p-reviews-info'),(487172,'furniture-mobile','.p-blog-index .wp-widget li','padding-right','0','','','.p-blog-index'),(487173,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-right','10','','','.p-blog-index'),(487174,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-right','20','','','.p-account-trade-form'),(487175,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(487177,'furniture-mobile','.b-email .name','padding-right','10','','','.b-email'),(487178,'furniture-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(487179,'furniture-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(487180,'furniture-mobile','.b-email .qty','padding-right','10','','','.b-email'),(487181,'furniture-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(487182,'furniture-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(487183,'furniture-mobile','.w-categories .item','padding-right','20','','','.w-categories'),(487184,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(487185,'furniture-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(487186,'furniture-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(487187,'furniture-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(487188,'furniture-mobile','.b-email .image','padding-right','10','','','.b-email'),(487189,'furniture-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-right','20','','','.b-bottom'),(487190,'furniture-mobile','.w-promo-code .holder','padding-right','20','2906','','.w-promo-code'),(487191,'furniture-mobile','.b-compare .popupCompare .pop-up-content','padding-right','10','','','.b-compare'),(487192,'furniture-mobile','.w-promotions .promo-cart-discount .master .item','padding-right','20','','','.w-promotions'),(487193,'furniture-mobile','.w-sale .holder-1','padding-right','20','','','.w-sale'),(487194,'furniture-mobile','.w-sale .holder-1','padding-right','20','','','.w-sale'),(487195,'furniture-mobile','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(487196,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','','','.w-menu-style-1'),(487197,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','','','.w-menu-style-1'),(487198,'furniture-mobile','.b-bottom .cart-options','padding-right','20','','','.b-bottom'),(487199,'furniture-mobile','.b-bottom .alert-message','padding-right','20','','','.b-bottom'),(487200,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-right','0','','','.w-menu-slider'),(487201,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','padding-right','7','','','.b-select-suggest'),(487202,'furniture-mobile','.w-personal-gift-status-bar .inform','padding-right','5','4','','.w-personal-gift-status-bar'),(487203,'furniture-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(487204,'furniture-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(487205,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-right','0','','','.w-menu'),(487206,'furniture-mobile','.w-menu .hided.menu ul li','padding-right','0','','','.w-menu'),(487207,'furniture-mobile','.w-menu-slider > ul > li > a','padding-right','10','','','.w-menu-slider'),(487208,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-right','50','','','.w-menu-slider'),(487209,'furniture-mobile','.w-sale .left-count','padding-right','5','','','.w-sale'),(487210,'furniture-mobile','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(487211,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-right','20','','','.w-menu-style-1'),(487212,'furniture-mobile','.w-catalog-paging .prev-pages','padding-right','5','','','.w-catalog-paging'),(487215,'furniture-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(487216,'furniture-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(487218,'furniture-mobile','.b-info .info','padding-right','0','','','.b-info'),(487219,'furniture-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(487220,'furniture-mobile','.b-email .model','padding-right','10','','','.b-email'),(487221,'furniture-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(487222,'furniture-mobile','.b-bottom .footerTitle','padding-right','0','2876','','.b-bottom'),(487223,'furniture-mobile','.b-bottom .pop-up-close','padding-right','1','','','.b-bottom'),(487224,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(487225,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(487226,'furniture-mobile','.w-cart-shipping-estimator .address-item','padding-right','10','','','.w-cart-shipping-estimator'),(487227,'furniture-mobile','.w-cart-up-sell .w-list-type-1','padding-right','0','','','.w-cart-up-sell'),(487228,'furniture-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-right','21','','','.w-cart-up-sell'),(487229,'furniture-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-right','20','1','','.w-cart-up-sell'),(487230,'furniture-mobile','.b-products-listing .products-listing .btn-buy','padding-right','10','','','.b-products-listing'),(487231,'furniture-mobile','.b-upload-files .added-file','padding-right','0','','','.b-upload-files'),(487232,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-right','0','','','.w-menu-slider'),(487233,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(487234,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','2885','','.w-menu-style-1'),(487235,'furniture-mobile','.b-bottom .popup-box-wrap','padding-right','10','','','.b-bottom'),(487236,'furniture-mobile','.b-bottom .pop-up-info','padding-right','20','','','.b-bottom'),(487237,'furniture-mobile','.b-email .qty','padding-right','10','','','.b-email'),(487238,'furniture-mobile','.b-email .name','padding-right','10','','','.b-email'),(487239,'furniture-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(487240,'furniture-mobile','.b-fancybox .fancybox-error','padding-right','15','','','.b-fancybox'),(487241,'furniture-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(487242,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-right','20','','','.w-menu-style-1'),(487243,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','','','.w-menu-style-1'),(487244,'furniture-mobile','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(487246,'furniture-mobile','.w-product-customers-activity .customers-activity','padding-right','20','','','.w-product-customers-activity'),(487247,'furniture-mobile','.w-product-available-in-warehouses .warehouse-item','padding-right','20','','','.w-product-available-in-warehouses'),(487248,'furniture-mobile','.b-table .table td','padding-right','15','','','.b-table'),(487249,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(487250,'furniture-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(487251,'furniture-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(487252,'furniture-mobile','.b-email .heading-model','padding-right','10','','','.b-email'),(487253,'furniture-mobile','.b-table .table .headings td','padding-right','10','','','.b-table'),(487254,'furniture-mobile','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(487255,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-right','10','','','.p-account-subscription-historyinfo'),(487256,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-right','20','','','.p-account-trade-form'),(487257,'furniture-mobile','.p-reviews-info .review-info-text','padding-right','10','','','.p-reviews-info'),(487258,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(487259,'furniture-mobile','.w-cart-compare .price-label','padding-right','10','','','.w-cart-compare'),(487260,'furniture-mobile','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(487261,'furniture-mobile','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(487265,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-right','20','','','.w-menu-style-1'),(487266,'furniture-mobile','.w-checkout-billing-address .edit-ab','padding-right','0','','','.w-checkout-billing-address'),(487267,'furniture-mobile','.w-checkout-billing-address .addresses .address-item label','padding-right','10','','','.w-checkout-billing-address'),(487268,'furniture-mobile','.w-promo-code .holder','padding-right','20','2906','','.w-promo-code'),(487269,'furniture-mobile','.w-product-images-additional .images','padding-right','0','2906','','.w-product-images-additional'),(487270,'furniture-mobile','.w-categories h2.name','padding-right','3','','','.w-categories'),(487271,'furniture-mobile','.w-tabs .accordion-heading','padding-right','6','','','.w-tabs'),(487272,'furniture-mobile','.w-socials > li','padding-right','15','','','.w-socials'),(487273,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-right','20','','','.p-account-trade-form'),(487274,'furniture-mobile','.w-product-images-additional .images','padding-right','0','2906','','.w-product-images-additional'),(487275,'furniture-mobile','.w-promo-code .holder','padding-right','20','2906','','.w-promo-code'),(487276,'furniture-mobile','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(487277,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','padding-right','5','','','.b-switch'),(487278,'furniture-mobile','.p-quick-order-index .all-scroll-div','padding-right','0','','','.p-quick-order-index'),(487279,'furniture-mobile','.w-cart-compare .price-cell','padding-right','20','','','.w-cart-compare'),(487280,'furniture-mobile','.p-reviews-info .review-info-text','padding-right','10','','','.p-reviews-info'),(487281,'furniture-mobile','.p-reviews-info .review-info-image','padding-right','20','','','.p-reviews-info'),(487282,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-right','0','','','.p-blog-index'),(487283,'furniture-mobile','.p-account-trade-form .widget','padding-right','0','','','.p-account-trade-form'),(487284,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(487285,'furniture-mobile','.w-checkout-shipping-address .edit-ab','padding-right','0','','','.w-checkout-shipping-address'),(487286,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(487287,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-right','5','','','.b-select-suggest'),(487288,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-right','0','','','.b-select-suggest'),(487289,'furniture-mobile','.b-select-suggest .select2-locked','padding-right','5','','','.b-select-suggest'),(487290,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-right','0','','','.b-select-suggest'),(487291,'furniture-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','','','.w-menu-horizontal'),(487292,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-right','50','','','.w-menu-slider'),(487293,'furniture-mobile','.w-menu-slider > ul > li > a','padding-right','10','','','.w-menu-slider'),(487294,'furniture-mobile','.b-form .shipping-method .item + .item','padding-right','0','','','.b-form'),(487295,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item label','padding-right','10','','','.w-checkout-shipping-address'),(487296,'furniture-mobile','.b-select-suggest .select2-search','padding-right','4','','','.b-select-suggest'),(487297,'furniture-mobile','.b-select-suggest .select2-search input','padding-right','20','','','.b-select-suggest'),(487298,'furniture-mobile','.b-select-suggest .select2-results','padding-right','4','','','.b-select-suggest'),(487299,'furniture-mobile','.p-wedding-registry-search .search-list','padding-right','20','','','.p-wedding-registry-search'),(487300,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','','','.w-menu-style-1'),(487301,'furniture-mobile','.w-menu .hided.menu ul li','padding-right','0','','','.w-menu'),(487302,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-right','0','','','.w-menu'),(487303,'furniture-mobile','.w-menu .hided.menu ul li','padding-right','0','','','.w-menu'),(487304,'furniture-mobile','.b-compare .compare-box-item','padding-right','10','','','.b-compare'),(487305,'furniture-mobile','.w-cart-compare .product-label','padding-right','10','','','.w-cart-compare'),(487306,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-right','10','','','.p-blog-index'),(487307,'furniture-mobile','.p-reviews-info .review-info-content','padding-right','20','','','.p-reviews-info'),(487308,'furniture-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(487310,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(487311,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(487312,'furniture-mobile','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(487313,'furniture-mobile','.w-cart-compare .dropdown li','padding-right','10','','','.w-cart-compare'),(487314,'furniture-mobile','.p-reviews-info .review-info-text','padding-right','10','','','.p-reviews-info'),(487315,'furniture-mobile','.w-personal-gift-status-bar .end-date','padding-right','5','3','','.w-personal-gift-status-bar'),(487316,'furniture-mobile','.w-account .acc-link','padding-right','15','','','.w-account'),(487317,'furniture-mobile','.w-login-block .returning','padding-right','40','','','.w-login-block'),(487318,'furniture-mobile','.w-menu-big ul','padding-right','0','','','.w-menu-big'),(487319,'furniture-mobile','.w-menu-style-1 ul','padding-right','0','','','.w-menu-style-1'),(487320,'furniture-mobile','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(487321,'furniture-mobile','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(487322,'furniture-mobile','.p-reviews-info .review-info-content','padding-right','20','','','.p-reviews-info'),(487323,'furniture-mobile','.b-bottom .notify-form','padding-right','20','','','.b-bottom'),(487324,'furniture-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-right','20','','','.w-account-addresses-list'),(487325,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.b-data-table'),(487326,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.b-data-table'),(487327,'furniture-mobile','.w-communication-post .communication-post-author','padding-right','0','','','.w-communication-post'),(487328,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','padding-right','0','','','.b-products-listing'),(487329,'furniture-mobile','.b-products-listing .in-cart','padding-right','10','','','.b-products-listing'),(487330,'furniture-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-right','5','','','.w-catalog-b2b-add-button'),(487331,'furniture-mobile','.b-products-listing .promos-info .promo-name','padding-right','15','','','.b-products-listing'),(487332,'furniture-mobile','.b-products-listing .promos-info .promo-item','padding-right','10','','','.b-products-listing'),(487333,'furniture-mobile','.w-blog-widget-tag-cloud a','padding-right','13','','','.w-blog-widget-tag-cloud'),(487334,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-right','20','','','.w-blog-widget-related-posts-by-category'),(487335,'furniture-mobile','.w-blog-widget-related-posts-by-category .post','padding-right','15','','','.w-blog-widget-related-posts-by-category'),(487336,'furniture-mobile','.w-blog-widget-related-posts ','padding-right','0','2906','','.w-blog-widget-related-posts'),(487337,'furniture-mobile','.w-blog-widget-related-posts .post_content a','padding-right','20','','','.w-blog-widget-related-posts'),(487338,'furniture-mobile','.w-blog-widget-related-posts ','padding-right','15','','','.w-blog-widget-related-posts'),(487339,'furniture-mobile','.w-blog-widget-related-posts .post','padding-right','15','','','.w-blog-widget-related-posts'),(487340,'furniture-mobile','.w-blog-widget-post-title h1','padding-right','0','','','.w-blog-widget-post-title'),(487341,'furniture-mobile','.w-blog-widget-post-title ','padding-right','0','','','.w-blog-widget-post-title'),(487342,'furniture-mobile','.w-blog-widget-post-listing .post','padding-right','15','2890','','.w-blog-widget-post-listing'),(487343,'furniture-mobile','.w-blog-widget-post-listing .post_view','padding-right','15','','','.w-blog-widget-post-listing'),(487344,'furniture-mobile','.w-blog-widget-post-listing .post_name','padding-right','0','','','.w-blog-widget-post-listing'),(487345,'furniture-mobile','.w-blog-widget-post-listing .post','padding-right','33','','','.w-blog-widget-post-listing'),(487346,'furniture-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-right','0','','','.w-blog-widget-most-popular-posts'),(487347,'furniture-mobile','.p-account-trade-form .widget','padding-right','0','','','.p-account-trade-form'),(487348,'furniture-mobile','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(487349,'furniture-mobile','.w-currencies .current','padding-right','27','2885','','.w-currencies'),(487350,'furniture-mobile','.w-currencies .select-link','padding-right','10','2885','','.w-currencies'),(487351,'furniture-mobile','.w-currencies .select-link','padding-right','10','','','.w-currencies'),(487352,'furniture-mobile','.w-currencies .current','padding-right','27','','','.w-currencies'),(487353,'furniture-mobile','.w-currencies .currencies-title','padding-right','4','','','.w-currencies'),(487354,'furniture-mobile','.w-sale .holder-1','padding-right','20','','','.w-sale'),(487355,'furniture-mobile','.b-compare .col-two label','padding-right','0','','','.b-compare'),(487356,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(487357,'furniture-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(487358,'furniture-mobile','.w-checkout-gdpr .privacy-row','padding-right','0','','','.w-checkout-gdpr'),(487359,'furniture-mobile','.w-checkout-gdpr .terms-login','padding-right','0','','','.w-checkout-gdpr'),(487360,'furniture-mobile','.b-table .table td','padding-right','15','','','.b-table'),(487361,'furniture-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(487362,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(487363,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(487364,'furniture-mobile','.b-info .info ul','padding-right','0','','','.b-info'),(487365,'furniture-mobile','.b-form .middle-form','padding-right','0','','','.b-form'),(487366,'furniture-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(487367,'furniture-mobile','.w-languages .current','padding-right','27','','','.w-languages'),(487368,'furniture-mobile','.w-checkout-billing-address .same-address','padding-right','10','','','.w-checkout-billing-address'),(487369,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','2885','','.w-menu-style-1'),(487370,'furniture-mobile','.w-sale .left-count','padding-right','5','','','.w-sale'),(487371,'furniture-mobile','.w-sale .holder-2','padding-right','20','','','.w-sale'),(487372,'furniture-mobile','.w-reviews .heading-3','padding-right','0','','','.w-reviews'),(487373,'furniture-mobile','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(487374,'furniture-mobile','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(487375,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','','','.w-menu-style-1'),(487376,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-right','0','','','.w-menu-slider'),(487377,'furniture-mobile','.w-personal-gift-status-bar .timeline','padding-right','10','','','.w-personal-gift-status-bar'),(487378,'furniture-mobile','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(487379,'furniture-mobile','.w-catalog-sorting .before','padding-right','5','','','.w-catalog-sorting'),(487380,'furniture-mobile','.w-chat .w-chat-box','padding-right','12','','','.w-chat'),(487381,'furniture-mobile','.w-catalog-paging ','padding-right','5','2','','.w-catalog-paging'),(487382,'furniture-mobile','.p-reviews-info .review-info-text','padding-right','10','','','.p-reviews-info'),(487383,'furniture-mobile','.p-reviews-info .review-info-content','padding-right','20','','','.p-reviews-info'),(487384,'furniture-mobile','.p-reviews-info .review-info-image','padding-right','20','','','.p-reviews-info'),(487385,'furniture-mobile','.b-compare .compare-head','padding-right','10','','','.b-compare'),(487386,'furniture-mobile','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(487387,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(487388,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-right','0','','',''),(487389,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-right','0','','','.b-h-inline'),(487390,'furniture-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(487391,'furniture-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(487392,'furniture-mobile','.blogsidebar .heading-title','padding-right','0','','','.blogsidebar'),(487393,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-right','0','','','.w-communication-new-topic'),(487394,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-right','10','','','.w-communication-new-topic'),(487395,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-right','5','','','.w-communication-new-topic'),(487396,'furniture-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-right','0','','','.w-communication-new-topic'),(487397,'furniture-mobile','.b-info .info','padding-right','0','','','.b-info'),(487398,'furniture-mobile','.b-info .info li','padding-right','0','','','.b-info'),(487399,'furniture-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(487400,'furniture-mobile','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(487401,'furniture-mobile','.b-email .heading-qty','padding-right','10','','','.b-email'),(487402,'furniture-mobile','.b-email .model','padding-right','10','','','.b-email'),(487403,'furniture-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-right','6','','','.b-compare'),(487404,'furniture-mobile','.btn-2','padding-right','25','','',''),(487405,'furniture-mobile','.b-compare .compare_pagination','padding-right','0','','','.b-compare'),(487406,'furniture-mobile','.w-product-images-additional .images','padding-right','0','2906','','.w-product-images-additional'),(487407,'furniture-mobile','.b-bottom .header-info','padding-right','20','','','.b-bottom'),(487408,'furniture-mobile','.w-cart-checkout-btn a','padding-right','12','2876','','.w-cart-checkout-btn'),(487409,'furniture-mobile','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(487410,'furniture-mobile','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-right','10','','','.order-summary'),(487411,'furniture-mobile','.w-menu-slider > ul > li > a','padding-right','10','','','.w-menu-slider'),(487412,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-right','0','','','.w-menu'),(487413,'furniture-mobile','.w-menu .hided.menu ul li','padding-right','0','','','.w-menu'),(487414,'furniture-mobile','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(487415,'furniture-mobile','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(487416,'furniture-mobile','.b-table .table td','padding-right','15','','','.b-table'),(487417,'furniture-mobile','.b-info .info','padding-right','0','','','.b-info'),(487418,'furniture-mobile','.b-info .info ul','padding-right','0','','','.b-info'),(487419,'furniture-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-right','0','','','.b-fancybox'),(487420,'furniture-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(487421,'furniture-mobile','.products-quick-index .token-input-list','padding-right','0','','',''),(487422,'furniture-mobile','.w-cart-compare .cart-cell','padding-right','7','','','.w-cart-compare'),(487423,'furniture-mobile','.w-sale .holder-1','padding-right','20','','','.w-sale'),(487424,'furniture-mobile','.w-sale .holder-2','padding-right','20','','','.w-sale'),(487425,'furniture-mobile','.w-sale .left-count','padding-right','5','','','.w-sale'),(487426,'furniture-mobile','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(487427,'furniture-mobile','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(487428,'furniture-mobile','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(487430,'furniture-mobile','.b-form .shipping-method .item','padding-right','0','','','.b-form'),(487431,'furniture-mobile','.b-email .price','padding-right','10','','','.b-email'),(487432,'furniture-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(487433,'furniture-mobile','.b-email .heading-image','padding-right','10','','','.b-email'),(487434,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-right','20','','','.w-menu-style-1'),(487435,'furniture-mobile','.w-catalog-paging .next-pages','padding-right','5','','','.w-catalog-paging'),(487437,'furniture-mobile','.w-cart-listing .item .attributes strong','padding-right','10','','','.w-cart-listing'),(487438,'furniture-mobile','.w-cart-listing .item .gift-wrap label','padding-right','10','','','.w-cart-listing'),(487439,'furniture-mobile','.w-cart-listing .item > div','padding-right','10','','','.w-cart-listing'),(487440,'furniture-mobile','.w-cart-listing .points-earn','padding-right','0','','','.w-cart-listing'),(487441,'furniture-mobile','.w-cart-listing .points-redeem','padding-right','0','','','.w-cart-listing'),(487442,'furniture-mobile','.w-cart-give-away .ga_img','padding-right','1','','','.w-cart-give-away'),(487443,'furniture-mobile','.b-bottom .header-error','padding-right','20','','','.b-bottom'),(487444,'furniture-mobile','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(487445,'furniture-mobile','.w-cart .cart-box-link','padding-right','10','','','.w-cart'),(487446,'furniture-mobile','.w-cart .buttons','padding-right','15','','','.w-cart'),(487447,'furniture-mobile','.w-cart .buttons .btn','padding-right','15','','','.w-cart'),(487448,'furniture-mobile','.w-cart .qty','padding-right','5','4','','.w-cart'),(487449,'furniture-mobile','.w-cart .multicart .name','padding-right','10','','','.w-cart'),(487450,'furniture-mobile','.w-cart .multicart .item','padding-right','15','','','.w-cart'),(487451,'furniture-mobile','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(487452,'furniture-mobile','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(487453,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(487454,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(487455,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(487456,'furniture-mobile','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(487457,'furniture-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(487458,'furniture-mobile','.b-compare .col-gender','padding-right','0','','','.b-compare'),(487459,'furniture-mobile','.b-email .qty','padding-right','10','','','.b-email'),(487460,'furniture-mobile','.b-email .heading-price','padding-right','10','','','.b-email'),(487461,'furniture-mobile','.w-top-categories .item','padding-right','10','2876','','.w-top-categories'),(487462,'furniture-mobile','.w-sale .holder-2','padding-right','20','','','.w-sale'),(487463,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(487464,'furniture-mobile','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(487465,'furniture-mobile','.w-cart .cart-total','padding-right','0','','','.w-cart'),(487466,'furniture-mobile','.w-cart .cart-content','padding-right','15','','','.w-cart'),(487467,'furniture-mobile','.p-blog-index .wp-widget li','padding-right','0','','','.p-blog-index'),(487468,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(487469,'furniture-mobile','.p-blog-index .nav-next','padding-right','50','','','.p-blog-index'),(487470,'furniture-mobile','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(487471,'furniture-mobile','.w-socials > li','padding-right','15','','','.w-socials'),(487472,'furniture-mobile','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(487473,'furniture-mobile','.w-catalog-paging .page-number','padding-right','5','','','.w-catalog-paging'),(487474,'furniture-mobile','.w-login-block .returning','padding-right','40','','','.w-login-block'),(487475,'furniture-mobile','.w-menu-style-1 ul','padding-right','0','','','.w-menu-style-1'),(487476,'furniture-mobile','.w-languages .current','padding-right','27','2885','','.w-languages'),(487477,'furniture-mobile','.w-filters .fsl_handle','padding-right','0','','','.w-filters'),(487478,'furniture-mobile','.w-filters .head-filter-widget','padding-right','10','2885','','.w-filters'),(487479,'furniture-mobile','.w-filters .ui-slider-range','padding-right','0','','','.w-filters'),(487480,'furniture-mobile','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(487481,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-right','10','','','.p-account-subscription-historyinfo'),(487482,'furniture-mobile','.w-filters .head-filter-widget','padding-right','0','','','.w-filters'),(487483,'furniture-mobile','.w-filters .handle_tit','padding-right','5','','','.w-filters'),(487484,'furniture-mobile','.b-autocomplete .ui-autocomplete','padding-right','2','','','.b-autocomplete'),(487485,'furniture-mobile','.order-summary .heading-2','padding-right','25','','','.order-summary'),(487486,'furniture-mobile','.b-compare .column_wrapper','padding-right','10','','','.b-compare'),(487487,'furniture-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(487488,'furniture-mobile','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(487489,'furniture-mobile','.b-email .model','padding-right','10','','','.b-email'),(487490,'furniture-mobile','.b-email .heading-name','padding-right','10','','','.b-email'),(487491,'furniture-mobile','.b-info .info li','padding-right','0','','','.b-info'),(487492,'furniture-mobile','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(487493,'furniture-mobile','.w-reviews-content .author','padding-right','20','','','.w-reviews-content'),(487494,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','','','.w-menu-style-1'),(487495,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-right','0','','','.w-menu-slider'),(487496,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','','','.w-menu-style-1'),(487497,'furniture-mobile','.w-menu-style-1 ul','padding-right','0','','','.w-menu-style-1'),(487498,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','','','.w-menu-style-1'),(487499,'furniture-mobile','.w-login-block .returning','padding-right','40','','','.w-login-block'),(487500,'furniture-mobile','.b-data-table table.dataTable tbody td','padding-right','20','','','.b-data-table'),(487501,'furniture-mobile','.b-data-table table.dataTable thead td','padding-right','20','','','.b-data-table'),(487502,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(487503,'furniture-mobile','.b-table .table .headings td','padding-right','10','','','.b-table'),(487504,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-right','0','','','.w-menu'),(487505,'furniture-mobile','.w-menu .hided.menu ul li','padding-right','0','','','.w-menu'),(487506,'furniture-mobile','.p-blog-index .wp-widget ul','padding-right','0','','','.p-blog-index'),(487507,'furniture-mobile','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(487509,'furniture-mobile','.w-checkout-create-account .create-account','padding-right','0','','','.w-checkout-create-account'),(487510,'furniture-mobile','.b-info .info','padding-right','0','','','.b-info'),(487511,'furniture-mobile','.b-email .totals-title','padding-right','10','','','.b-email'),(487512,'furniture-mobile','.b-email .totals-value','padding-right','10','','','.b-email'),(487513,'furniture-mobile','.b-email .qty','padding-right','10','','','.b-email'),(487514,'furniture-mobile','.p-blog-index .nav-next','padding-right','50','','','.p-blog-index'),(487515,'furniture-mobile','.btn','padding-right','25','','',''),(487516,'furniture-mobile','.p-blog-index .nav-next','padding-right','50','','','.p-blog-index'),(487517,'furniture-mobile','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(487518,'furniture-mobile','.b-product-images .media-popup .mp-content','padding-right','5','','','.b-product-images'),(487519,'furniture-mobile','.b-product-images .media-popup .mp-small-images .item','padding-right','10','','','.b-product-images'),(487520,'furniture-mobile','.b-product-images .media-popup .slick-dots','padding-right','0','','','.b-product-images'),(487521,'furniture-mobile','.b-product-images .media-popup .slick-dots li','padding-right','0','','','.b-product-images'),(487522,'furniture-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-right','0','','','.b-menu-style'),(487523,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-right','5','','','.b-menu-style-1'),(487524,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-right','20','','','.b-menu-style-2'),(487525,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-right','20','','','.b-menu-style-2'),(487526,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-right','0','','','.b-menu-style-2'),(487527,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-right','0','','','.b-menu-style-2'),(487528,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-right','20','','','.b-menu-style-2'),(487529,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-right','0','','','.b-menu-style-2'),(487530,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-right','20','','','.b-menu-style-2'),(487531,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-right','20','','','.b-menu-style-2'),(487532,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-right','50','','','.b-menu-style-2'),(487533,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-right','30','','','.b-menu-style-2'),(487534,'furniture-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-right','0','','','.b-personal-catalog-popup'),(487535,'furniture-mobile','.b-trade-approval .steps-bar li a','padding-right','0','','','.b-trade-approval'),(487536,'furniture-mobile','.b-trade-approval .middle-form','padding-right','0','','','.b-trade-approval'),(487537,'furniture-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-right','5','','','.b-trade-approval'),(487538,'furniture-mobile','.b-trade-approval .steps-bar','padding-right','0','','','.b-trade-approval'),(487539,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-right','10','','','.b-trade-approval'),(487540,'furniture-mobile','.b-trade-approval .center-buttons','padding-right','0','','','.b-trade-approval'),(487541,'furniture-mobile','.batchPr .w-batch-products .products-listing .image','padding-right','15','','','.batchPr'),(487542,'furniture-mobile','.batchPr .w-batch-products','padding-right','0','','','.batchPr'),(487543,'furniture-mobile','.batchPr > .block:nth-child(2)','padding-right','0','','','.batchPr'),(487544,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-right','0','','','.batchPr'),(487545,'furniture-mobile','.batchPr .w-batch-selected-products','padding-right','15','','','.batchPr'),(487546,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-right','0','','','.batchPr'),(487547,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-right','15','','','.batchPr'),(487548,'furniture-mobile','.batchPr .w-batch-selected-products .item','padding-right','40','','','.batchPr'),(487549,'furniture-mobile','.batchPr ','padding-right','0','','','.batchPr'),(487550,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-right','0','','','.batchPr'),(487551,'furniture-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-right','0','','','.batchPr'),(487552,'furniture-mobile','.batchPr .w-batch-products .products-listing .image','padding-right','0','','','.batchPr'),(487553,'furniture-mobile','.w-account-personal-catalog .list-switcher','padding-right','0','','','.w-account-personal-catalog'),(487554,'furniture-mobile','.w-account-personal-catalog .list-switcher a','padding-right','6','','','.w-account-personal-catalog'),(487555,'furniture-mobile','.w-account-subscription .subscription-variant','padding-right','10','','','.w-account-subscription'),(487556,'furniture-mobile','.w-catalog-additional-images li','padding-right','10','','','.w-catalog-additional-images'),(487557,'furniture-mobile','.w-catalog-additional-images ul','padding-right','0','','','.w-catalog-additional-images'),(487558,'furniture-mobile','.w-catalog-compare td','padding-right','20','','','.w-catalog-compare'),(487559,'furniture-mobile','.w-catalog-compare .image','padding-right','10','','','.w-catalog-compare'),(487560,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','padding-right','5','2','','.w-catalog-compare'),(487561,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','padding-right','5','','','.w-catalog-compare'),(487562,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-right','0','','','.w-catalog-compare'),(487563,'furniture-mobile','.w-delivery-day .left-count','padding-right','5','','','.w-delivery-day'),(487564,'furniture-mobile','.w-top-text .top-text','padding-right','10','','','.w-top-text'),(487565,'furniture-mobile','.w-cart-listing .points','padding-right','0','2876','','.w-cart-listing'),(487566,'furniture-mobile','.w-product-images .additional-horizontal .item','padding-right','10','','','.w-product-images'),(487567,'furniture-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-right','10','','','.b-cookie-notice'),(487568,'furniture-mobile','.w-cart .no-text','padding-right','20','','','.w-cart'),(487569,'furniture-mobile','.lowestPricedBox .w-banner .banner','padding-right','0','','','.lowestPricedBox'),(487570,'furniture-mobile','.tripleBanner > .block','padding-right','15','','','.tripleBanner'),(487571,'furniture-mobile','.w-languages .current','padding-right','20','2906','','.w-languages'),(487572,'furniture-mobile','.w-currencies .current','padding-right','20','2906','','.w-currencies'),(487573,'furniture-mobile','.b-slick .slick-list','padding-right','0','','','.b-slick'),(487574,'furniture-mobile','.b-slick .slick-vertical button.slick-next','padding-right','0','3','','.b-slick'),(487575,'furniture-mobile','.b-slick .slick-vertical button.slick-prev','padding-right','0','3','','.b-slick'),(487576,'furniture-mobile','.b-slick button.slick-prev','padding-right','4','3','','.b-slick'),(487577,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-right','0','','','.b-slick'),(487578,'furniture-mobile','.header-middle ','padding-right','50','2885','','.header-middle'),(487579,'furniture-mobile','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-right','15','','',''),(487580,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-right','0','2885','','.b-menu-style-3'),(487581,'furniture-mobile','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','padding-right','0','','','.b-products-listing'),(487582,'furniture-mobile','.w-cart-listing .headings .head','padding-right','0','','','.w-cart-listing'),(487583,'furniture-mobile','.w-cart-listing .item div.price','padding-right','0','','','.w-cart-listing'),(487584,'furniture-mobile','.b-products-listing .item-nav > div','padding-right','15','','','.b-products-listing'),(487585,'furniture-mobile','.LeftCategories .w-menu-simple ul','padding-right','0','','','.LeftCategories'),(487586,'furniture-mobile','.LeftCategories .w-menu-simple ul li a','padding-right','25','','','.LeftCategories'),(487587,'furniture-mobile','.w-filters .filter-widget','padding-right','25','','','.w-filters'),(487588,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item','padding-right','15','','','.b-products-listing'),(487589,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-right','0','','','.b-products-listing'),(487590,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-content','padding-right','25','','','.b-products-listing'),(487591,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','padding-right','30','','','.b-products-listing'),(487592,'furniture-mobile','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-right','25','','','.b-products-listing'),(487593,'furniture-mobile','.b-products-listing .products-listing.list-rows .item-nav > div','padding-right','5','','','.b-products-listing'),(487594,'furniture-mobile','.w-breadcrumb .breadcrumb-li','padding-right','0','','','.w-breadcrumb'),(487595,'furniture-mobile','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(487596,'furniture-mobile','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(487597,'furniture-mobile','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(487598,'furniture-mobile','.w-subscribers .btn-submit','padding-right','25','','','.w-subscribers'),(487599,'furniture-mobile','.w-quote .buttons','padding-right','15','','','.w-quote'),(487600,'furniture-mobile','.w-quote .buttons .btn','padding-right','15','','','.w-quote'),(487601,'furniture-mobile','.w-quote .cart-content','padding-right','15','','','.w-quote'),(487602,'furniture-mobile','.w-quote .cart-total','padding-right','0','','','.w-quote'),(487603,'furniture-mobile','.w-quote .multicart .cart-content','padding-right','0','','','.w-quote'),(487604,'furniture-mobile','.w-quote .multicart .item','padding-right','15','','','.w-quote'),(487605,'furniture-mobile','.w-quote .multicart .name','padding-right','10','','','.w-quote'),(487606,'furniture-mobile','.w-quote .no-text','padding-right','20','','','.w-quote'),(487607,'furniture-mobile','.w-quote .qty','padding-right','5','4','','.w-quote'),(487608,'furniture-mobile','.w-quote a.item','padding-right','0','','','.w-quote'),(487609,'furniture-mobile','.w-social-links a','padding-right','8','','','.w-social-links'),(487610,'furniture-mobile','.w-product-images .additional-vertical .additional-images','padding-right','0','','','.w-product-images'),(487611,'furniture-mobile','.w-product-personal-catalog-button .btn','padding-right','0','','','.w-product-personal-catalog-button'),(487612,'furniture-mobile','.b-quantity .qty-box input','padding-right','3','','','.b-quantity'),(487613,'furniture-mobile','.w-product-sale-ends .left-count','padding-right','5','','','.w-product-sale-ends'),(487614,'furniture-mobile','.w-product-sale-ends .left-count-days','padding-right','0','','','.w-product-sale-ends'),(487615,'furniture-mobile','.w-product-sale-ends .left-count-hours','padding-right','0','','','.w-product-sale-ends'),(487616,'furniture-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(487617,'furniture-mobile','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(487618,'furniture-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(487619,'furniture-mobile','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(487620,'furniture-mobile','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(487621,'furniture-mobile','.w-compare .compare-list-holder','padding-right','250','','','.w-compare'),(487622,'furniture-mobile','.w-compare .compare-list-buttons','padding-right','10','','','.w-compare'),(487623,'furniture-mobile','.w-compare .item-holder','padding-right','10','','','.w-compare'),(487624,'furniture-mobile','.w-compare .compare-list-products','padding-right','30','','','.w-compare'),(487625,'furniture-mobile','.w-files-catalog-widgets-files-catalog .name','padding-right','10','','','.w-files-catalog-widgets-files-catalog'),(487626,'furniture-mobile','.w-sample .buttons','padding-right','15','','','.w-sample'),(487627,'furniture-mobile','.w-sample .buttons .btn','padding-right','15','','','.w-sample'),(487628,'furniture-mobile','.w-sample .cart-box-link','padding-right','10','','','.w-sample'),(487629,'furniture-mobile','.w-sample .cart-content','padding-right','15','','','.w-sample'),(487630,'furniture-mobile','.w-sample .cart-total','padding-right','0','','','.w-sample'),(487631,'furniture-mobile','.w-sample .multicart .cart-content','padding-right','0','','','.w-sample'),(487632,'furniture-mobile','.w-sample .multicart .item','padding-right','15','','','.w-sample'),(487633,'furniture-mobile','.w-sample .multicart .name','padding-right','10','','','.w-sample'),(487634,'furniture-mobile','.w-sample .no-text','padding-right','20','','','.w-sample'),(487635,'furniture-mobile','.w-sample .qty','padding-right','5','4','','.w-sample'),(487636,'furniture-mobile','.w-sample a.item','padding-right','0','','','.w-sample'),(487637,'furniture-mobile','.w-cart-listing .item > div.points','padding-right','0','','','.w-cart-listing'),(487638,'furniture-mobile','.w-filters-simple .integrate-price-holder','padding-right','0','','','.w-filters-simple'),(487639,'furniture-mobile','.w-cart-discount-coupon .title','padding-right','0','','','.w-cart-discount-coupon'),(487640,'furniture-mobile','.w-product-video .item','padding-right','10','','','.w-product-video'),(487641,'furniture-mobile','.shipping-ico .heading-3','padding-right','0','','','.shipping-ico'),(487642,'furniture-mobile','.w-cart-order-reference .btn','padding-right','25','','','.w-cart-order-reference'),(487643,'furniture-mobile','.w-cart-gift-certificate .btn','padding-right','25','','','.w-cart-gift-certificate'),(487644,'furniture-mobile','.w-cart-shipping-estimator .btn','padding-right','25','','','.w-cart-shipping-estimator'),(487645,'furniture-mobile','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(487646,'furniture-mobile','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(487647,'furniture-mobile','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(487648,'furniture-mobile','.w-product-in-bundles .attributes-item','padding-right','2','','','.w-product-in-bundles'),(487649,'furniture-mobile','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(487650,'furniture-mobile','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(487651,'furniture-mobile','.w-cart-listing .item > div.actions','padding-right','0','2876','','.w-cart-listing'),(487652,'furniture-mobile','.w-cart-listing .item div.price','padding-right','10','2885','','.w-cart-listing'),(487653,'furniture-mobile','.w-account-address-book .item','padding-right','10','','','.w-account-address-book'),(487654,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-right','0','','','.b-products-listing'),(487655,'furniture-mobile','.b-pagination .pagination .next-pages','padding-right','5','','','.b-pagination'),(487656,'furniture-mobile','.b-pagination .pagination .page-number','padding-right','5','','','.b-pagination'),(487657,'furniture-mobile','.b-pagination .pagination .prev-pages','padding-right','5','','','.b-pagination'),(487658,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','padding-right','5','','','.b-pagination'),(487659,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','padding-right','5','','','.b-pagination'),(487660,'furniture-mobile','.b-pagination .pagination span','padding-right','5','2','','.b-pagination'),(487661,'furniture-mobile','.b-pagination ul.pagination','padding-right','0','','','.b-pagination'),(487662,'furniture-mobile','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','padding-right','10','','','.w-catalog-compare'),(487663,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .item','padding-right','6','','','.w-product-properties-filters-widgets-chosen-filters'),(487664,'furniture-mobile','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block, .checkout > .type-1 > .block','padding-right','15','','',''),(487665,'furniture-mobile','.w-tabs .tab-li','padding-right','0','2','','.w-tabs'),(487666,'furniture-mobile','.w-tabs .tab-li:last-of-type','padding-right','0','','','.w-tabs'),(487667,'furniture-mobile','.w-cart-listing .no-price .headings .qty','padding-right','10','','','.w-cart-listing'),(487668,'furniture-mobile','.p-quote-checkout-index .datepicker-inline','padding-right','0','','','.p-quote-checkout-index'),(487669,'furniture-mobile','.p-sample-checkout-index .datepicker-inline','padding-right','0','','','.p-sample-checkout-index'),(487670,'furniture-mobile','.w-account-order-download td','padding-right','0','2876','','.w-account-order-download'),(487671,'furniture-mobile','.w-account-order-download tr','padding-right','0','2876','','.w-account-order-download'),(487672,'furniture-mobile','.w-quote-products .cart-listing .qty','padding-right','10','','','.w-quote-products'),(487673,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','padding-right','15','','','.w-product-multi-inventory'),(487674,'furniture-mobile','.w-product-multi-inventory .radio-attributes > label','padding-right','10','','','.w-product-multi-inventory'),(487675,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','padding-right','20','','','.w-account-personal-catalog'),(487676,'furniture-mobile','.w-account-personal-catalog .list-row-action li','padding-right','10','','','.w-account-personal-catalog'),(487677,'furniture-mobile','.w-account-personal-catalog .price','padding-right','10','','','.w-account-personal-catalog'),(487678,'furniture-mobile','.tripleBanner .w-html_box','padding-right','10','','','.tripleBanner'),(487679,'furniture-mobile','.w-account-personal-catalog .buy-box','padding-right','0','2876','','.w-account-personal-catalog'),(487680,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','padding-right','15','','','.b-products-listing'),(487681,'furniture-mobile','.b-products-listing .products-listing .radio-attributes > label','padding-right','10','','','.b-products-listing'),(487682,'furniture-mobile','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(487683,'furniture-mobile','.w-product-collection .right-area .btn','padding-right','25','','','.w-product-collection'),(487684,'furniture-mobile','.w-account-customer-additional-field .tf-file','padding-right','0','','','.w-account-customer-additional-field'),(487685,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','padding-right','15','','','.w-product-attributes'),(487686,'furniture-mobile','.w-product-attributes .radio-attributes > label','padding-right','10','','','.w-product-attributes'),(487687,'furniture-mobile','.w-product-properties .property-ul','padding-right','0','','','.w-product-properties'),(487688,'furniture-mobile','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(487689,'furniture-mobile','.w-product-properties li','padding-right','5','','','.w-product-properties'),(487690,'furniture-mobile','.w-product-groups .radioBox','padding-right','0','','','.w-product-groups'),(487691,'furniture-mobile','.w-product-groups .radioBox label','padding-right','15','','','.w-product-groups'),(487692,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','padding-right','10','','','.w-product-groups'),(487693,'furniture-mobile','.w-product-groups .radioBox label','padding-right','0','2906','','.w-product-groups'),(487694,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','padding-right','10','2906','','.w-product-groups'),(487695,'furniture-mobile','.b-products-listing .mix-attributes .attribute-qty-block','padding-right','10','','','.b-products-listing'),(487696,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block','padding-right','5','','','.b-products-listing'),(487697,'furniture-mobile','.blogsidebar','padding-right','0','2885','',''),(487698,'furniture-mobile','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(487699,'furniture-mobile','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-right','25','','','.w-product-custom-bundle'),(487700,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list'),(487701,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-right','10','','','.w-catalog-pages-category-pages-last-list'),(487702,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list-block'),(487703,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-right','10','','','.w-catalog-pages-category-pages-last-list-block'),(487704,'furniture-mobile','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(487705,'furniture-mobile','.w-delivery-location-location-description .deliveryDesc','padding-right','0','','','.w-delivery-location-location-description'),(487706,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent a','padding-right','25','','','.w-delivery-location-location-list'),(487707,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','padding-right','15','','','.w-delivery-location-location-list'),(487708,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding-right','2','','','.w-delivery-location-featured-list'),(487709,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding-right','0','2906','','.w-delivery-location-featured-list'),(487710,'furniture-mobile','.btn-2','padding-right','25','2876','',''),(487711,'furniture-mobile','.w-sale-category .holder-1','padding-right','20','','','.w-sale-category'),(487712,'furniture-mobile','.w-sale-category .holder-2','padding-right','20','','','.w-sale-category'),(487713,'furniture-mobile','.w-sale-category .left-count','padding-right','5','','','.w-sale-category'),(487714,'furniture-mobile','.w-product-wedding-registry-button .btn','padding-right','25','','','.w-product-wedding-registry-button'),(487715,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(487716,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-right','10','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(487717,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(487718,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-right','10','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(487719,'furniture-mobile','.w-product-properties-icons .property-image','padding-right','10','','','.w-product-properties-icons'),(487720,'furniture-mobile','.w-product-properties-icons .hover-box-content','padding-right','10','','','.w-product-properties-icons'),(487721,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','padding-right','15','','','.w-delivery-location-product-categories'),(487722,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','padding-right','10','2885','','.w-delivery-location-product-categories'),(487723,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','padding-right','0','2906','','.w-delivery-location-product-categories'),(487724,'furniture-mobile','.w-delivery-location-product-categories .name','padding-right','15','','','.w-delivery-location-product-categories'),(487725,'furniture-mobile','.w-wedding-registry-widgets-search-paging ul.pagination','padding-right','0','','','.w-wedding-registry-widgets-search-paging'),(487726,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','padding-right','5','','','.w-wedding-registry-widgets-search-paging'),(487727,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','padding-right','5','','','.w-wedding-registry-widgets-search-paging'),(487728,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','padding-right','5','','','.w-wedding-registry-widgets-search-paging'),(487729,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','padding-right','5','','','.w-wedding-registry-widgets-search-paging'),(487730,'furniture-mobile','.w-wedding-registry-widgets-search-list .table td, .w-wedding-registry-widgets-search-list .table .headings td','padding-right','10','2885','','.w-wedding-registry-widgets-search-list'),(487731,'furniture-mobile','.w-wedding-registry-widgets-search-list .table .headings td','padding-right','15','','','.w-wedding-registry-widgets-search-list'),(487732,'furniture-mobile','.delivery-options-popup','padding-right','20','','',''),(487733,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','padding-right','15','','','.w-product-bonus-points'),(487734,'furniture-mobile','.w-product-designer-designer .grnamebox .title-sortable','padding-right','15','','','.w-product-designer-designer'),(487735,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','padding-right','10','','','.w-product-designer-designer'),(487736,'furniture-mobile','.w-press-reviews-widgets-press-reviews ','padding-right','30','','','.w-press-reviews-widgets-press-reviews'),(487737,'furniture-mobile','.w-press-reviews-widgets-press-reviews .author','padding-right','25','','','.w-press-reviews-widgets-press-reviews'),(487738,'furniture-mobile','.w-press-reviews-widgets-press-reviews .image','padding-right','10','','','.w-press-reviews-widgets-press-reviews'),(487739,'furniture-mobile','.w-press-reviews-widgets-press-reviews .item','padding-right','20','','','.w-press-reviews-widgets-press-reviews'),(487740,'furniture-mobile','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-right','30','','','.w-press-reviews-widgets-press-reviews'),(487741,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','padding-right','25','','','.w-press-reviews-widgets-press-reviews'),(487742,'furniture-mobile','.w-press-reviews-widgets-press-reviews ','padding-right','15','2876','','.w-press-reviews-widgets-press-reviews'),(487743,'furniture-mobile','.w-press-reviews-widgets-press-reviews .item','padding-right','0','2876','','.w-press-reviews-widgets-press-reviews'),(487744,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','padding-right','0','2876','','.w-press-reviews-widgets-press-reviews'),(487745,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .item','padding-right','25','','','.w-press-reviews-widgets-press-reviews-list'),(487746,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .short-description','padding-right','0','','','.w-press-reviews-widgets-press-reviews-list'),(487747,'furniture-mobile','.b-products-listing .productGroup label a','padding-right','16','','','.b-products-listing'),(487748,'furniture-mobile','.w-support-system-filter ','padding-right','40','','','.w-support-system-filter'),(487749,'furniture-mobile','.w-support-system-filter .filter_cats','padding-right','0','','','.w-support-system-filter'),(487750,'furniture-mobile','.w-support-system-listing .support-head','padding-right','13','','','.w-support-system-listing'),(487751,'furniture-mobile','.w-communication-post .btn.refresh','padding-right','0','','','.w-communication-post'),(487752,'furniture-mobile','.w-rma-returns-history .btn','padding-right','10','','','.w-rma-returns-history'),(487753,'furniture-mobile','.w-rma-returns-history .column','padding-right','3','','','.w-rma-returns-history'),(487754,'furniture-mobile','.w-rma-returns-history .column .title','padding-right','10','','','.w-rma-returns-history'),(487755,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','padding-right','5','','','.w-rma-returns-history'),(487756,'furniture-mobile','.w-rma-returns-history .topRow','padding-right','0','','','.w-rma-returns-history'),(487757,'furniture-mobile','.w-rma-returns-history .column:last-child .title','padding-right','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(487758,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','padding-right','20','','','.b-menu-style-1'),(487759,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .goto-button','padding-right','20','','','.b-menu-style-1'),(487760,'furniture-mobile','.w-product-designer-designer .productDesignerBox ul','padding-right','0','','','.w-product-designer-designer'),(487761,'furniture-mobile','.w-product-configurator .pc-item','padding-right','0','','','.w-product-configurator'),(487762,'furniture-mobile','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(487763,'furniture-mobile','.w-product-configurator .pc_item','padding-right','0','2885','','.w-product-configurator'),(487764,'furniture-mobile','.w-product-configurator .pc_attr','padding-right','0','2876','','.w-product-configurator'),(487765,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','padding-right','15','','','.b-products-listing'),(487766,'furniture-mobile','.b-products-listing .promos-info .promo-name-span','padding-right','40','','','.b-products-listing'),(487767,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-list'),(487768,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-right','10','','','.w-catalog-pages-category-pages-list'),(487769,'furniture-mobile','.w-predefined-promotion .heading','padding-right','10','','','.w-predefined-promotion'),(487770,'furniture-mobile','.w-predefined-promotion .master','padding-right','15','','','.w-predefined-promotion'),(487771,'furniture-mobile','.w-predefined-promotion .nextdiscount .content > div','padding-right','10','','','.w-predefined-promotion'),(487772,'furniture-mobile','.w-predefined-promotion .nextdiscount .item-holder .image','padding-right','10','','','.w-predefined-promotion'),(487773,'furniture-mobile','.w-predefined-promotion .nextdiscount .promo-for-each','padding-right','20','','','.w-predefined-promotion'),(487774,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-product','padding-right','20','','','.w-predefined-promotion'),(487775,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','padding-right','20','','','.w-predefined-promotion'),(487776,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .item','padding-right','20','','','.w-predefined-promotion'),(487777,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-right','20','','','.w-predefined-promotion'),(487778,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-right','20','','','.w-predefined-promotion'),(487779,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .item','padding-right','20','','','.w-predefined-promotion'),(487780,'furniture-mobile','.w-predefined-promotion .promo-date > div','padding-right','50','','','.w-predefined-promotion'),(487781,'furniture-mobile','.w-predefined-promotion .promo-item','padding-right','40','','','.w-predefined-promotion'),(487782,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','padding-right','20','','','.w-predefined-promotion'),(487783,'furniture-mobile','.w-predefined-promotion .promo-salemaker .item','padding-right','20','','','.w-predefined-promotion'),(487784,'furniture-mobile','.w-predefined-promotion .promo-salemaker .promo-categories','padding-right','12','','','.w-predefined-promotion'),(487785,'furniture-mobile','.w-supplier-purchase-supplier-products .item','padding-right','20','','','.w-supplier-purchase-supplier-products'),(487786,'furniture-mobile','.w-filters .filter-box-content ul','padding-right','0','','','.w-filters'),(487787,'furniture-mobile','.mainBanner .bottomBox','padding-right','20','','','.mainBanner'),(487788,'furniture-mobile','.mainBanner .bottomBox .btn','padding-right','1.30','','','.mainBanner'),(487789,'furniture-mobile','.mainBanner .buttonBox','padding-right','10','','','.mainBanner'),(487790,'furniture-mobile','.mainBanner .topBox > .right','padding-right','47','','','.mainBanner'),(487791,'furniture-mobile','.mainBanner .wrapper','padding-right','6','','','.mainBanner'),(487792,'furniture-mobile','.mainBanner > .block','padding-right','0','','','.mainBanner'),(487793,'furniture-mobile','.mainBanner .bottomBox','padding-right','20','2890','','.mainBanner'),(487794,'furniture-mobile','.mainBanner .bottomBox .btn','padding-right','20','2890','','.mainBanner'),(487795,'furniture-mobile','.mainBanner .topBox','padding-right','15','2890','','.mainBanner'),(487796,'furniture-mobile','.mainBanner .topBox > .right','padding-right','20','2890','','.mainBanner'),(487797,'furniture-mobile','.mainBanner .wrapper','padding-right','2','2890','','.mainBanner'),(487798,'furniture-mobile','.mainBanner .bottomBox .btn','padding-right','20','2885','','.mainBanner'),(487799,'furniture-mobile','.mainBanner .topBox','padding-right','10','2876','','.mainBanner'),(487800,'furniture-mobile','.mainBanner .topBox > .right','padding-right','15','2876','','.mainBanner'),(487801,'furniture-mobile','.mainBanner .wrapper','padding-right','2','2876','','.mainBanner'),(487802,'furniture-mobile','.mainBanner .bottomBox','padding-right','20','2906','','.mainBanner'),(487803,'furniture-mobile','.mainBanner .bottomBox .btn','padding-right','15','2906','','.mainBanner'),(487804,'furniture-mobile','.mainBanner .wrapper','padding-right','2','2906','','.mainBanner'),(487805,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','padding-right','24','','','.lowestPricedBox'),(487806,'furniture-mobile','.lowestPricedBox .w-banner .ybg .mark','padding-right','0','','','.lowestPricedBox'),(487807,'furniture-mobile','.lowestPricedBox .w-banner .banner','padding-right','0','2876','','.lowestPricedBox'),(487808,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','padding-right','10','2906','','.lowestPricedBox'),(487809,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','padding-right','20','2906','','.lowestPricedBox'),(487810,'furniture-mobile','.shopByCollectionBox .bannerButton a','padding-right','25','','','.shopByCollectionBox'),(487811,'furniture-mobile','.shopByCollectionBox .content','padding-right','20','','','.shopByCollectionBox'),(487812,'furniture-mobile','.shopByCollectionBox .bannerButton a','padding-right','25','2890','','.shopByCollectionBox'),(487813,'furniture-mobile','.w-quote-products .no-price','padding-right','15','','','.w-quote-products'),(487814,'furniture-mobile','.w-search .wrap','padding-right','10','','','.w-search'),(487815,'furniture-mobile','.w-search .products .item a','padding-right','0','','','.w-search'),(487816,'furniture-mobile','.w-search .products .item','padding-right','20','','','.w-search'),(487817,'furniture-mobile','.account-address-book .address_book','padding-right','0','','','.account-address-book'),(487818,'furniture-mobile','.account-address-book .address_book h1','padding-right','0','','','.account-address-book'),(487819,'furniture-mobile','.account-address-book .address_book h2','padding-right','10','','','.account-address-book'),(487820,'furniture-mobile','.account-address-book .address_book, .account-address-book .account_history_info','padding-right','0','','','.account-address-book'),(487821,'furniture-mobile','.account-address-book .btn-edit','padding-right','0','4','','.account-address-book'),(487822,'furniture-mobile','.account-address-book .buttonBox','padding-right','0','','','.account-address-book'),(487823,'furniture-mobile','.account-address-book .rightMes ul','padding-right','0','','','.account-address-book'),(487824,'furniture-mobile','.account-address-book .topButtons','padding-right','0','','','.account-address-book'),(487825,'furniture-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','padding-right','10','','','.account-order-history'),(487826,'furniture-mobile','.account-order-history .orders-table th','padding-right','10','','','.account-order-history'),(487827,'furniture-mobile','.account-order-history .order_history_table th','padding-right','10','','','.account-order-history'),(487828,'furniture-mobile','.account-order-history .view_link','padding-right','20','','','.account-order-history'),(487829,'furniture-mobile','.account-order-history .orders-table .td-alignright','padding-right','10','2885','','.account-order-history'),(487830,'furniture-mobile','.account-order-history .orders-table td','padding-right','10','2885','','.account-order-history'),(487831,'furniture-mobile','.account-order-history-info .contentColumn','padding-right','10','','','.account-order-history-info'),(487832,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','padding-right','0','','','.account-order-history-info'),(487833,'furniture-mobile','.account-order-history-info .history_attr div strong, .account-order-history-info .history_attr div span','padding-right','10','','','.account-order-history-info'),(487834,'furniture-mobile','.account-order-history-info .history_info > div + div','padding-right','0','','','.account-order-history-info'),(487835,'furniture-mobile','.account-order-history-info .popup-tracking-number','padding-right','10','','','.account-order-history-info'),(487836,'furniture-mobile','.account-order-history-info .history_info > div','padding-right','0','2885','','.account-order-history-info'),(487837,'furniture-mobile','.account-order-history-info .history_info > div + div','padding-right','0','2885','','.account-order-history-info'),(487838,'furniture-mobile','.account-index .account_block','padding-right','0','','','.account-index'),(487839,'furniture-mobile','.account-index .account_info','padding-right','0','','','.account-index'),(487840,'furniture-mobile','.account-index .account_info .info .info_span','padding-right','5','','','.account-index'),(487841,'furniture-mobile','.account-index .account_info li','padding-right','0','','','.account-index'),(487842,'furniture-mobile','.account-index .account_page','padding-right','0','','','.account-index'),(487843,'furniture-mobile','.account-index .badc_bottom','padding-right','0','','','.account-index'),(487844,'furniture-mobile','.account-index .date_title','padding-right','0','','','.account-index'),(487845,'furniture-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','padding-right','10','','','.account-index'),(487846,'furniture-mobile','.account-index .rightMes ul','padding-right','0','','','.account-index'),(487847,'furniture-mobile','.account-index .topAccount','padding-right','19','','','.account-index'),(487848,'furniture-mobile','.account-index .topAccount > li','padding-right','2','','','.account-index'),(487849,'furniture-mobile','.account-index .view_link','padding-right','20','','','.account-index'),(487850,'furniture-mobile','.account-index .account_info','padding-right','0','2885','','.account-index'),(487851,'furniture-mobile','.account-index .orders-table .links','padding-right','10','2885','','.account-index'),(487852,'furniture-mobile','.account-index .orders-table td','padding-right','10','2885','','.account-index'),(487853,'furniture-mobile','.account-index .account_info li','padding-right','0','2876','','.account-index'),(487854,'furniture-mobile','.account-index .topAccount > li','padding-right','0','2876','','.account-index'),(487855,'furniture-mobile','.account-index .topAccount > li > div','padding-right','0','2876','','.account-index'),(487856,'furniture-mobile','.account-order-pay .contentColumn','padding-right','10','','','.account-order-pay'),(487857,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-right','0','','','.account-order-pay'),(487858,'furniture-mobile','.account-order-pay .history_attr div strong, .account-order-pay .history_attr div span','padding-right','10','','','.account-order-pay'),(487859,'furniture-mobile','.account-order-pay .history_info > div + div','padding-right','0','','','.account-order-pay'),(487860,'furniture-mobile','.account-order-pay .history_info > div','padding-right','0','2885','','.account-order-pay'),(487861,'furniture-mobile','.account-order-pay .history_info > div + div','padding-right','0','2885','','.account-order-pay'),(487862,'furniture-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-right','10','','','.account-samples'),(487863,'furniture-mobile','.account-samples .orders-table th','padding-right','10','','','.account-samples'),(487864,'furniture-mobile','.account-samples .order_history_table th','padding-right','10','','','.account-samples'),(487865,'furniture-mobile','.account-samples .view_link','padding-right','20','','','.account-samples'),(487866,'furniture-mobile','.account-samples .orders-table .td-alignright','padding-right','10','2885','','.account-samples'),(487867,'furniture-mobile','.account-samples .orders-table td','padding-right','10','2885','','.account-samples'),(487868,'furniture-mobile','.account-sample-info .contentColumn','padding-right','10','','','.account-sample-info'),(487869,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-right','0','','','.account-sample-info'),(487870,'furniture-mobile','.account-sample-info .history_attr div strong, .account-sample-info .history_attr div span','padding-right','10','','','.account-sample-info'),(487871,'furniture-mobile','.account-sample-info .history_info > div + div','padding-right','0','','','.account-sample-info'),(487872,'furniture-mobile','.account-sample-info .popup-tracking-number','padding-right','10','','','.account-sample-info'),(487873,'furniture-mobile','.account-sample-info .history_info > div','padding-right','0','2885','','.account-sample-info'),(487874,'furniture-mobile','.account-sample-info .history_info > div + div','padding-right','0','2885','','.account-sample-info'),(487875,'furniture-mobile','.catalog-product-wrap .next-product','padding-right','50','','','.catalog-product-wrap'),(487876,'furniture-mobile','.catalog-product-wrap .pn-direction','padding-right','4','','','.catalog-product-wrap'),(487877,'furniture-mobile','.catalog-product-wrap .pn-image','padding-right','5','','','.catalog-product-wrap'),(487878,'furniture-mobile','.catalog-product-wrap .prev-product','padding-right','20','','','.catalog-product-wrap'),(487879,'furniture-mobile','.catalog-product-wrap .prev-product .pn-image','padding-right','2','3','','.catalog-product-wrap'),(487880,'furniture-mobile','.catalog-product-wrap .next-product','padding-right','0','2885','','.catalog-product-wrap'),(487881,'furniture-mobile','.catalog-product-wrap .pn-direction','padding-right','0','2885','','.catalog-product-wrap'),(487882,'furniture-mobile','.catalog-product-wrap .prev-product','padding-right','0','2885','','.catalog-product-wrap'),(487883,'furniture-mobile','.shopping-cart-index .btn-3','padding-right','25','','','.shopping-cart-index'),(487884,'furniture-mobile','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-right','20','','','.shopping-cart-index'),(487885,'furniture-mobile','.checkout-index-wrap .datepicker-inline','padding-right','0','','','.checkout-index-wrap'),(487886,'furniture-mobile','.checkout-index-wrap .edit-address-popup','padding-right','20','','','.checkout-index-wrap'),(487887,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-right','25','','','.checkout-index-wrap'),(487888,'furniture-mobile','.checkout-order-confirmation .price-row','padding-right','0','','','.checkout-order-confirmation'),(487889,'furniture-mobile','.b-data-table table.dataTable tbody td','padding-right_important','important','','','.b-data-table'),(487890,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right_important','important','','','.b-data-table'),(487891,'furniture-mobile','.b-data-table table.dataTable thead td','padding-right_important','important','','','.b-data-table'),(487892,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right_important','important','','','.b-data-table'),(487893,'furniture-mobile','.batchPr .w-batch-products','padding-right_important','important','','','.batchPr'),(487894,'furniture-mobile','.w-cart-listing .points','padding-right_important','important','2876','','.w-cart-listing'),(487895,'furniture-mobile','.w-account-personal-catalog .price','padding-right_important','important','','','.w-account-personal-catalog'),(487896,'furniture-mobile','.w-account-personal-catalog .buy-box','padding-right_important','important','2876','','.w-account-personal-catalog'),(487897,'furniture-mobile','.mainBanner > .block','padding-right_important','important','','','.mainBanner'),(487898,'furniture-mobile','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-top','10','','','.w-communication-new-topic'),(487899,'furniture-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(487900,'furniture-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(487901,'furniture-mobile','.heading-4 .edit, h4 .edit','padding-top','2','','',''),(487902,'furniture-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(487903,'furniture-mobile','.b-info .info','padding-top','20','','','.b-info'),(487904,'furniture-mobile','.b-form .password-forgotten-link','padding-top','15','','','.b-form'),(487905,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-top','10','','','.p-account-subscription-historyinfo'),(487906,'furniture-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(487907,'furniture-mobile','.p-blog-index .wp-widget li','padding-top','0','','','.p-blog-index'),(487908,'furniture-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(487909,'furniture-mobile','.w-cart .multicart .cart-content','padding-top','0','','','.w-cart'),(487910,'furniture-mobile','.w-cart a.item','padding-top','5','','','.w-cart'),(487911,'furniture-mobile','.w-cart-discount-coupon .btn','padding-top','6','','','.w-cart-discount-coupon'),(487912,'furniture-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(487913,'furniture-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(487914,'furniture-mobile','.p-quick-order-index ul.token-input-list','padding-top','0','','','.p-quick-order-index'),(487915,'furniture-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-top','7','','','.p-quick-order-index'),(487916,'furniture-mobile','.p-account-trade-form .widget','padding-top','10','','','.p-account-trade-form'),(487917,'furniture-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-top','8','','','.p-quick-order-index'),(487918,'furniture-mobile','.w-promotions .promo-item','padding-top','30','','','.w-promotions'),(487919,'furniture-mobile','.w-sale .left-text-right','padding-top','24','','','.w-sale'),(487920,'furniture-mobile','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(487921,'furniture-mobile','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(487922,'furniture-mobile','.p-blog-index .wp-widget li','padding-top','0','','','.p-blog-index'),(487923,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-top','0','','','.p-blog-index'),(487924,'furniture-mobile','.w-cart-compare .attributes-label','padding-top','10','','','.w-cart-compare'),(487925,'furniture-mobile','.w-account .acc-returning','padding-top','0','','','.w-account'),(487926,'furniture-mobile','.w-account .acc-top','padding-top','5','','','.w-account'),(487927,'furniture-mobile','.w-account .account-dropdown','padding-top','15','','','.w-account'),(487928,'furniture-mobile','.w-account .account-top','padding-top','0','','','.w-account'),(487929,'furniture-mobile','.w-account .f-pass','padding-top','5','','','.w-account'),(487930,'furniture-mobile','.w-account .my-acc-link','padding-top','0','','','.w-account'),(487931,'furniture-mobile','.w-wedding-registry-widgets-search-registry-button ','padding-top','5','','','.w-wedding-registry-widgets-search-registry-button'),(487932,'furniture-mobile','.w-personal-gift-status-bar .end-label','padding-top','0','','','.w-personal-gift-status-bar'),(487933,'furniture-mobile','.p-sample-checkout-success .page-success .text-1','padding-top','120','','','.p-sample-checkout-success'),(487934,'furniture-mobile','.w-personal-gift-status-bar .start-label','padding-top','0','','','.w-personal-gift-status-bar'),(487935,'furniture-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(487936,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(487937,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-top','0','','','.p-reviews-info'),(487938,'furniture-mobile','.p-reviews-info .review-info-image','padding-top','20','','','.p-reviews-info'),(487939,'furniture-mobile','.p-reviews-info .review-info-content','padding-top','20','','','.p-reviews-info'),(487940,'furniture-mobile','.p-reviews-info .review-info-text','padding-top','10','','','.p-reviews-info'),(487941,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(487942,'furniture-mobile','.p-blog-index .wp-widget ul','padding-top','0','','','.p-blog-index'),(487943,'furniture-mobile','.p-blog-index .nav-links','padding-top','20','','','.p-blog-index'),(487944,'furniture-mobile','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(487945,'furniture-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(487946,'furniture-mobile','.w-product-images-additional .images','padding-top','10','2906','','.w-product-images-additional'),(487947,'furniture-mobile','.testimonials .reviews-list .name','padding-top','5','','',''),(487948,'furniture-mobile','.testimonials .heading-3','padding-top','7','','',''),(487949,'furniture-mobile','.testimonials .review','padding-top','10','','',''),(487950,'furniture-mobile','.testimonials .name','padding-top','5','','',''),(487951,'furniture-mobile','.testimonials .reviews-list .answer .name','padding-top','10','','',''),(487952,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(487953,'furniture-mobile','.w-categories .image','padding-top','0','','','.w-categories'),(487954,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','padding-top','0','','','.w-promotions'),(487955,'furniture-mobile','.w-promotions .prom-multi-discount .promo-product','padding-top','20','','','.w-promotions'),(487956,'furniture-mobile','.w-catalog-items-on-page .before, .w-catalog-items-on-page .after','padding-top','5','','','.w-catalog-items-on-page'),(487957,'furniture-mobile','.w-promotions .nextdiscount .content > div','padding-top','10','','','.w-promotions'),(487958,'furniture-mobile','.w-promotions .nextdiscount .promo-for-each','padding-top','3','','','.w-promotions'),(487959,'furniture-mobile','.w-promotions .promo-salemaker .item','padding-top','20','','','.w-promotions'),(487960,'furniture-mobile','.w-promotions .promo-salemaker .discount','padding-top','0','','','.w-promotions'),(487961,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.p-quick-order-index'),(487962,'furniture-mobile','.w-promotions .promo-cart-discount .slave .item','padding-top','20','','','.w-promotions'),(487963,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition-holder','padding-top','0','','','.w-promotions'),(487964,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','padding-top','0','','','.w-promotions'),(487965,'furniture-mobile','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-top','20','','','.b-warehouses-popup'),(487966,'furniture-mobile','.w-product-available-in-warehouses .warehouse-item','padding-top','0','','','.w-product-available-in-warehouses'),(487967,'furniture-mobile','.w-chat .w-chat-box','padding-top','2','','','.w-chat'),(487968,'furniture-mobile','.w-cart-give-away .ga_column','padding-top','15','','','.w-cart-give-away'),(487969,'furniture-mobile','.w-cart-compare .attributes-cell','padding-top','8','','','.w-cart-compare'),(487970,'furniture-mobile','.p-quick-order-index .bottom','padding-top','10','','','.p-quick-order-index'),(487971,'furniture-mobile','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(487972,'furniture-mobile','.p-blog-index .wp-widget li','padding-top','0','','','.p-blog-index'),(487973,'furniture-mobile','.p-reviews-info .review-info-content','padding-top','20','','','.p-reviews-info'),(487974,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(487975,'furniture-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(487976,'furniture-mobile','.p-blog-index .nav-links','padding-top','20','','','.p-blog-index'),(487977,'furniture-mobile','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(487978,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','12','2885','','.w-menu-style-1'),(487979,'furniture-mobile','.b-messages .messages-menu ul','padding-top','0','','','.b-messages'),(487980,'furniture-mobile','.b-messages .messages-menu li','padding-top','0','','','.b-messages'),(487981,'furniture-mobile','.b-messages .messMenuButton span','padding-top','10','','','.b-messages'),(487982,'furniture-mobile','.b-messages .msv_btn','padding-top','12','','','.b-messages'),(487983,'furniture-mobile','.b-messages .msv_content','padding-top','10','','','.b-messages'),(487984,'furniture-mobile','.b-messages .msv_history','padding-top','10','','','.b-messages'),(487985,'furniture-mobile','.b-messages .messages-menu li a','padding-top','10','','','.b-messages'),(487986,'furniture-mobile','.b-messages .email-heading','padding-top','15','','','.b-messages'),(487987,'furniture-mobile','.b-messages .content_management_attach button','padding-top','1','','','.b-messages'),(487988,'furniture-mobile','.b-messages .content_management_attach','padding-top','8','','','.b-messages'),(487989,'furniture-mobile','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(487990,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','padding-top','4','','','.b-messages'),(487991,'furniture-mobile','.b-messages .emailBtn','padding-top','10','','','.b-messages'),(487992,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-top','5','','','.b-messages'),(487993,'furniture-mobile','.b-messages .msv_to_cc','padding-top','10','','','.b-messages'),(487994,'furniture-mobile','.b-messages .messMenuButtonTop','padding-top','5','','','.b-messages'),(487995,'furniture-mobile','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-top','4','','',''),(487996,'furniture-mobile','.w-sale .text','padding-top','10','','','.w-sale'),(487997,'furniture-mobile','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(487998,'furniture-mobile','.p-reviews-info .review-info-text','padding-top','10','','','.p-reviews-info'),(487999,'furniture-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(488000,'furniture-mobile','.p-blog-index .comment-metadata','padding-top','4','','','.p-blog-index'),(488001,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-top','20','','','.p-account-trade-form'),(488002,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(488003,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-top','0','','','.w-menu-slider'),(488004,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul','padding-top','0','','','.w-sitemap-delivery-location'),(488005,'furniture-mobile','.w-sitemap-delivery-location > ul','padding-top','0','','','.w-sitemap-delivery-location'),(488006,'furniture-mobile','.p-payer-order-confirmation .dob-hide label','padding-top','5','','','.p-payer-order-confirmation'),(488007,'furniture-mobile','.p-payer-order-pay .dob-hide label','padding-top','5','','','.p-payer-order-pay'),(488008,'furniture-mobile','.w-checkout-terms .required-message','padding-top','5','','','.w-checkout-terms'),(488009,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','padding-top','17','','','.w-wedding-registry-widgets-photos'),(488010,'furniture-mobile','.w-cart-listing .item .remove','padding-top','5','2885','','.w-cart-listing'),(488011,'furniture-mobile','.b-table .table td','padding-top','15','','','.b-table'),(488012,'furniture-mobile','.b-table .table .headings td','padding-top','5','','','.b-table'),(488013,'furniture-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(488014,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(488015,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(488016,'furniture-mobile','.w-reviews-content .item','padding-top','20','','','.w-reviews-content'),(488017,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-top','0','','','.w-menu'),(488018,'furniture-mobile','.w-menu-slider > ul > li > a','padding-top','5','','','.w-menu-slider'),(488019,'furniture-mobile','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(488020,'furniture-mobile','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(488021,'furniture-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(488022,'furniture-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(488023,'furniture-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(488024,'furniture-mobile','.p-quick-order-index .all-scroll-div','padding-top','10','','','.p-quick-order-index'),(488025,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-top','20','','','.p-account-trade-form'),(488026,'furniture-mobile','.p-account-trade-form .widget','padding-top','10','','','.p-account-trade-form'),(488027,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-top','10','','','.p-account-subscription-historyinfo'),(488029,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-top','5','','','.p-blog-index'),(488030,'furniture-mobile','.p-blog-index .comment-metadata','padding-top','4','','','.p-blog-index'),(488031,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-template','padding-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(488032,'furniture-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(488033,'furniture-mobile','.b-email .name','padding-top','5','','','.b-email'),(488034,'furniture-mobile','.b-email .qty','padding-top','5','','','.b-email'),(488035,'furniture-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(488036,'furniture-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(488037,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(488038,'furniture-mobile','.w-filters .filter-ul-content','padding-top','0','','','.w-filters'),(488039,'furniture-mobile','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(488040,'furniture-mobile','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(488041,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-top','2','','','.w-menu-horizontal'),(488042,'furniture-mobile','.w-menu-horizontal ul','padding-top','0','','','.w-menu-horizontal'),(488043,'furniture-mobile','.w-menu-slider > ul > li > a','padding-top','5','','','.w-menu-slider'),(488044,'furniture-mobile','.w-sale .left-text-right','padding-top','24','','','.w-sale'),(488045,'furniture-mobile','.w-tabs .tab-navigation','padding-top','0','','','.w-tabs'),(488046,'furniture-mobile','.w-promo-code .holder','padding-top','20','2906','','.w-promo-code'),(488047,'furniture-mobile','.b-info .info ul','padding-top','0','','','.b-info'),(488048,'furniture-mobile','.w-promo-code .holder','padding-top','20','2906','','.w-promo-code'),(488049,'furniture-mobile','.w-product-images-additional .images','padding-top','10','2906','','.w-product-images-additional'),(488050,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','2876','','.p-quote-checkout-success'),(488051,'furniture-mobile','.b-fancybox .fancybox-title-over-wrap','padding-top','10','','','.b-fancybox'),(488052,'furniture-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(488053,'furniture-mobile','.b-fancybox .fancybox-title-inside-wrap','padding-top','10','','','.b-fancybox'),(488054,'furniture-mobile','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(488055,'furniture-mobile','.b-info .info ul','padding-top','0','','','.b-info'),(488056,'furniture-mobile','.w-multi-cart-cart-switcher .carts-switcher','padding-top','20','','','.w-multi-cart-cart-switcher'),(488057,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(488058,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(488059,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(488060,'furniture-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(488061,'furniture-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(488062,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-top','10','','','.p-account-subscription-historyinfo'),(488063,'furniture-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-top','0','','','.b-fancybox'),(488064,'furniture-mobile','.w-cart-compare .dropdown li','padding-top','5','','','.w-cart-compare'),(488065,'furniture-mobile','.no-found','padding-top','20','','',''),(488066,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-top','5','','','.w-menu-slider'),(488067,'furniture-mobile','.w-menu .hided.menu ul li','padding-top','0','','','.w-menu'),(488068,'furniture-mobile','.b-upload-files .attached-block','padding-top','10','','','.b-upload-files'),(488069,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-top','0','','','.w-menu'),(488070,'furniture-mobile','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(488071,'furniture-mobile','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(488072,'furniture-mobile','.w-sale .left-count','padding-top','5','','','.w-sale'),(488073,'furniture-mobile','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(488074,'furniture-mobile','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(488075,'furniture-mobile','.w-sale .holder-2','padding-top','20','','','.w-sale'),(488076,'furniture-mobile','.w-menu .hided.menu ul li','padding-top','0','','','.w-menu'),(488077,'furniture-mobile','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(488078,'furniture-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(488079,'furniture-mobile','.message.success','padding-top','20','','',''),(488080,'furniture-mobile','.p-reviews-info .review-info-content','padding-top','20','','','.p-reviews-info'),(488081,'furniture-mobile','.p-reviews-info .review-info-image','padding-top','20','','','.p-reviews-info'),(488082,'furniture-mobile','.p-blog-index .wp-widget ul','padding-top','0','','','.p-blog-index'),(488083,'furniture-mobile','.p-reviews-info .review-info-text','padding-top','10','','','.p-reviews-info'),(488084,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-top','0','','','.p-reviews-info'),(488085,'furniture-mobile','.w-cart-compare .dropdown .dropdown-menu','padding-top','5','','','.w-cart-compare'),(488086,'furniture-mobile','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(488087,'furniture-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(488088,'furniture-mobile','.b-email .model','padding-top','5','','','.b-email'),(488089,'furniture-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(488090,'furniture-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(488091,'furniture-mobile','.b-info .info','padding-top','20','','','.b-info'),(488092,'furniture-mobile','.b-info .info li','padding-top','0','','','.b-info'),(488094,'furniture-mobile','.b-info .info li','padding-top','0','','','.b-info'),(488095,'furniture-mobile','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(488096,'furniture-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(488097,'furniture-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(488098,'furniture-mobile','.b-email .name','padding-top','5','','','.b-email'),(488099,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-top','0','','','.b-select-suggest'),(488100,'furniture-mobile','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(488101,'furniture-mobile','.w-reviews .review','padding-top','10','','','.w-reviews'),(488102,'furniture-mobile','.w-socials > li','padding-top','15','','','.w-socials'),(488103,'furniture-mobile','.w-search .suggest','padding-top','0','','','.w-search'),(488104,'furniture-mobile','.w-search .search-input','padding-top','5','','','.w-search'),(488105,'furniture-mobile','.w-sale .text','padding-top','10','','','.w-sale'),(488106,'furniture-mobile','.w-cart-compare .product','padding-top','10','','','.w-cart-compare'),(488107,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','12','2885','','.w-menu-style-1'),(488108,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-top','12','2885','','.w-menu-style-1'),(488109,'furniture-mobile','.b-info-popup .info-popup div','padding-top','10','','','.b-info-popup'),(488110,'furniture-mobile','.w-search .name','padding-top','5','','','.w-search'),(488111,'furniture-mobile','.p-account-trade-form .widget','padding-top','10','','','.p-account-trade-form'),(488112,'furniture-mobile','.w-quote .cart-box-link','padding-top','0','','','.w-quote'),(488113,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-top','20','','','.p-account-trade-form'),(488114,'furniture-mobile','.p-blog-index .nav-links','padding-top','20','','','.p-blog-index'),(488115,'furniture-mobile','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-top','7','','','.order-summary'),(488116,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','12','2885','','.w-menu-style-1'),(488117,'furniture-mobile','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(488118,'furniture-mobile','.w-reviews .author','padding-top','0','','','.w-reviews'),(488119,'furniture-mobile','.w-sale .left-count','padding-top','5','','','.w-sale'),(488120,'furniture-mobile','.w-sale .text','padding-top','10','','','.w-sale'),(488121,'furniture-mobile','.w-sale .left-text-right','padding-top','24','','','.w-sale'),(488123,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(488124,'furniture-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(488125,'furniture-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(488126,'furniture-mobile','.b-email .model','padding-top','5','','','.b-email'),(488127,'furniture-mobile','textarea','padding-top','5','','',''),(488128,'furniture-mobile','.w-sale .left-text-left','padding-top','24','','','.w-sale'),(488129,'furniture-mobile','.w-sale .holder-2','padding-top','20','','','.w-sale'),(488130,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','2876','','.p-quote-checkout-success'),(488131,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-top','5','','','.w-menu-slider'),(488132,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-top','0','','','.w-menu-slider'),(488133,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','6','','','.w-menu-style-1'),(488134,'furniture-mobile','.w-menu-style-1 ul','padding-top','0','','','.w-menu-style-1'),(488135,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(488136,'furniture-mobile','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-top','3','','','.w-multi-cart-actions'),(488137,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-top','12','2885','','.w-menu-style-1'),(488138,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','12','2885','','.w-menu-style-1'),(488139,'furniture-mobile','.w-top-categories h2.name','padding-top','3','','','.w-top-categories'),(488140,'furniture-mobile','.w-top-categories .item','padding-top','5','','','.w-top-categories'),(488141,'furniture-mobile','.w-tabs .accordion-heading','padding-top','9','2876','','.w-tabs'),(488142,'furniture-mobile','.w-tabs > .block','padding-top','20','','','.w-tabs'),(488143,'furniture-mobile','.w-cart-cart-tabs .w-tabs > .block','padding-top','0','','','.w-cart-cart-tabs'),(488144,'furniture-mobile','.w-tabs .tab-a','padding-top','14','','','.w-tabs'),(488145,'furniture-mobile','.w-tabs .tab-a','padding-top','12','2','','.w-tabs'),(488146,'furniture-mobile','.w-tabs .tab-li','padding-top','0','','','.w-tabs'),(488147,'furniture-mobile','.w-socials > li','padding-top','15','','','.w-socials'),(488148,'furniture-mobile','.w-sale .text','padding-top','10','','','.w-sale'),(488149,'furniture-mobile','.order-summary > div','padding-top','10','','','.order-summary'),(488150,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(488151,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(488152,'furniture-mobile','.b-bottom .popup-buttons','padding-top','15','','','.b-bottom'),(488153,'furniture-mobile','.b-autocomplete .ui-autocomplete li','padding-top','3','','','.b-autocomplete'),(488154,'furniture-mobile','.b-bottom .popup-content','padding-top','15','','','.b-bottom'),(488155,'furniture-mobile','.p-account-trade-form .widget','padding-top','10','','','.p-account-trade-form'),(488156,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(488157,'furniture-mobile','.w-sale .holder-1','padding-top','20','','','.w-sale'),(488158,'furniture-mobile','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(488159,'furniture-mobile','.w-wedding-registry-widgets-products .rating','padding-top','10','','','.w-wedding-registry-widgets-products'),(488160,'furniture-mobile','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(488161,'furniture-mobile','.w-sale .left-count','padding-top','5','','','.w-sale'),(488162,'furniture-mobile','.w-sale .holder-1','padding-top','20','','','.w-sale'),(488163,'furniture-mobile','.p-blog-index .wp-widget li','padding-top','0','','','.p-blog-index'),(488164,'furniture-mobile','.p-blog-index .wp-widget li','padding-top','0','','','.p-blog-index'),(488165,'furniture-mobile','.btn-1','padding-top','5','','',''),(488166,'furniture-mobile','.w-menu-slider > ul > li > a','padding-top','5','','','.w-menu-slider'),(488167,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-top','5','','','.w-menu-slider'),(488168,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(488169,'furniture-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(488170,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(488171,'furniture-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(488172,'furniture-mobile','.p-sample-checkout-success .page-success .text-1','padding-top','5','2876','','.p-sample-checkout-success'),(488173,'furniture-mobile','.b-info .info ul','padding-top','0','','','.b-info'),(488174,'furniture-mobile','.b-messages .emailLineTextArea textarea','padding-top','30','','','.b-messages'),(488175,'furniture-mobile','.btn-3','padding-top','13','','',''),(488176,'furniture-mobile','.b-bottom .confirm-popup .confirm-text','padding-top','40','','','.b-bottom'),(488177,'furniture-mobile','.w-product-images-additional .images','padding-top','10','2906','','.w-product-images-additional'),(488178,'furniture-mobile','.b-products-listing .products-listing .buyButton .btn','padding-top','5','','','.b-products-listing'),(488179,'furniture-mobile','.heading-3 .right-text, h3 .right-text','padding-top','3','','',''),(488180,'furniture-mobile','.b-bottom .popup-heading','padding-top','10','','','.b-bottom'),(488181,'furniture-mobile','.b-form .shipping-method .item + .item','padding-top','5','','','.b-form'),(488182,'furniture-mobile','.heading-3 .edit, h3 .edit','padding-top','2','','',''),(488183,'furniture-mobile','.b-info .info li','padding-top','0','','','.b-info'),(488184,'furniture-mobile','.b-email .model','padding-top','5','','','.b-email'),(488185,'furniture-mobile','.b-upload-file .upload-file-template','padding-top','25','','','.b-upload-file'),(488186,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','2876','','.p-quote-checkout-success'),(488189,'furniture-mobile','.b-form .middle-form','padding-top','20','','','.b-form'),(488190,'furniture-mobile','.b-email .qty','padding-top','5','','','.b-email'),(488191,'furniture-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(488192,'furniture-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(488193,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-top','12','2885','','.w-menu-style-1'),(488194,'furniture-mobile','.w-socials > li','padding-top','15','','','.w-socials'),(488195,'furniture-mobile','.order-summary .price-row','padding-top','7','','','.order-summary'),(488196,'furniture-mobile','.b-email .model','padding-top','5','','','.b-email'),(488197,'furniture-mobile','.b-email .image','padding-top','5','','','.b-email'),(488198,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(488199,'furniture-mobile','.b-select-suggest .select2-drop-mask','padding-top','0','','','.b-select-suggest'),(488200,'furniture-mobile','.p-reviews-info .review-info-content','padding-top','20','','','.p-reviews-info'),(488201,'furniture-mobile','.w-search .items-title','padding-top','10','','','.w-search'),(488202,'furniture-mobile','.w-sale .left-text-right','padding-top','24','','','.w-sale'),(488203,'furniture-mobile','.w-sale .holder-1','padding-top','20','','','.w-sale'),(488204,'furniture-mobile','.w-reviews-content .review','padding-top','20','','','.w-reviews-content'),(488205,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-top','12','2885','','.w-menu-style-1'),(488206,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-top','5','','','.p-blog-index'),(488207,'furniture-mobile','.p-blog-index .comment-metadata','padding-top','4','','','.p-blog-index'),(488208,'furniture-mobile','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(488209,'furniture-mobile','.b-email .price','padding-top','5','','','.b-email'),(488210,'furniture-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(488211,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','padding-top','2','','','.b-fancybox'),(488212,'furniture-mobile','.w-checkout-shipping-choice span','padding-top','7','2906','','.w-checkout-shipping-choice'),(488213,'furniture-mobile','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(488214,'furniture-mobile','.w-top-categories .categories h2','padding-top','0','','','.w-top-categories'),(488215,'furniture-mobile','.w-top-categories .image','padding-top','0','','','.w-top-categories'),(488216,'furniture-mobile','.w-product-reviews .reviews-list .review','padding-top','10','','','.w-product-reviews'),(488217,'furniture-mobile','.w-product-reviews .reviews-list .name','padding-top','5','','','.w-product-reviews'),(488218,'furniture-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(488219,'furniture-mobile','.b-email .name','padding-top','5','','','.b-email'),(488220,'furniture-mobile','.b-form .required-message','padding-top','0','','','.b-form'),(488221,'furniture-mobile','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(488222,'furniture-mobile','.p-blog-index .nav-links','padding-top','20','','','.p-blog-index'),(488223,'furniture-mobile','.p-blog-index .wp-widget li','padding-top','0','','','.p-blog-index'),(488224,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-top','0','','','.p-blog-index'),(488225,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','2876','','.p-quote-checkout-success'),(488226,'furniture-mobile','.w-promo-code .holder','padding-top','20','2906','','.w-promo-code'),(488227,'furniture-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(488228,'furniture-mobile','.b-bottom .popup-simple','padding-top','20','','','.b-bottom'),(488229,'furniture-mobile','.b-bottom .rfq-form','padding-top','0','','','.b-bottom'),(488230,'furniture-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(488231,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(488232,'furniture-mobile','.b-email .price','padding-top','5','','','.b-email'),(488233,'furniture-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(488234,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(488235,'furniture-mobile','.b-email .model','padding-top','5','','','.b-email'),(488236,'furniture-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(488237,'furniture-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(488238,'furniture-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(488239,'furniture-mobile','.b-email .qty','padding-top','5','','','.b-email'),(488240,'furniture-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(488241,'furniture-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(488242,'furniture-mobile','.b-email .image','padding-top','5','','','.b-email'),(488243,'furniture-mobile','.b-email .price','padding-top','5','','','.b-email'),(488244,'furniture-mobile','.b-email .qty','padding-top','5','','','.b-email'),(488245,'furniture-mobile','.b-email .name','padding-top','5','','','.b-email'),(488246,'furniture-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(488247,'furniture-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(488248,'furniture-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(488252,'furniture-mobile','.w-checkout-shipping .sub-item','padding-top','5','','','.w-checkout-shipping'),(488253,'furniture-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(488254,'furniture-mobile','.b-table .table .headings td','padding-top','5','','','.b-table'),(488255,'furniture-mobile','.b-table .table td','padding-top','15','','','.b-table'),(488256,'furniture-mobile','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(488257,'furniture-mobile','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(488258,'furniture-mobile','.w-promo-code .holder','padding-top','20','2906','','.w-promo-code'),(488259,'furniture-mobile','.w-socials > li','padding-top','15','','','.w-socials'),(488260,'furniture-mobile','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(488261,'furniture-mobile','.w-sale .holder-2','padding-top','20','','','.w-sale'),(488262,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(488263,'furniture-mobile','.b-form .center-buttons','padding-top','20','','','.b-form'),(488264,'furniture-mobile','.b-form .shipping-method .input','padding-top','0','','','.b-form'),(488265,'furniture-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(488266,'furniture-mobile','.w-reviews .heading-3','padding-top','7','','','.w-reviews'),(488267,'furniture-mobile','.w-checkout-shipping-address .edit-ab','padding-top','5','','','.w-checkout-shipping-address'),(488268,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(488269,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','padding-top','0','','','.b-select-suggest'),(488273,'furniture-mobile','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(488274,'furniture-mobile','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(488275,'furniture-mobile','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(488276,'furniture-mobile','.w-banner .carousel-text > span','padding-top','20','','','.w-banner'),(488277,'furniture-mobile','.b-info .info','padding-top','20','','','.b-info'),(488278,'furniture-mobile','.b-info .info li','padding-top','0','','','.b-info'),(488279,'furniture-mobile','.b-bottom .terms-info-popup .pop-up-content','padding-top','20','','','.b-bottom'),(488280,'furniture-mobile','.w-checkout-create-account .create-account-switcher','padding-top','8','','','.w-checkout-create-account'),(488281,'furniture-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','12','2885','','.w-menu-horizontal'),(488282,'furniture-mobile','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(488283,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','12','2885','','.w-menu-style-1'),(488284,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-top','12','2885','','.w-menu-style-1'),(488285,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(488286,'furniture-mobile','.w-menu-style-1 ul','padding-top','0','','','.w-menu-style-1'),(488287,'furniture-mobile','.w-sale .left-text-left','padding-top','24','','','.w-sale'),(488288,'furniture-mobile','.w-sale .left-text-right','padding-top','24','','','.w-sale'),(488289,'furniture-mobile','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(488290,'furniture-mobile','.w-product-images-additional .images','padding-top','10','2906','','.w-product-images-additional'),(488291,'furniture-mobile','.b-info .info ul','padding-top','0','','','.b-info'),(488292,'furniture-mobile','.b-form .login-col-1','padding-top','40','','','.b-form'),(488293,'furniture-mobile','.b-form .form-buttons','padding-top','17','','','.b-form'),(488294,'furniture-mobile','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(488295,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(488296,'furniture-mobile','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(488297,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','6','','','.w-menu-style-1'),(488298,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-top','0','','','.w-menu'),(488299,'furniture-mobile','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(488300,'furniture-mobile','.w-cart-compare .delete-cart','padding-top','10','','','.w-cart-compare'),(488301,'furniture-mobile','.p-account-trade-form .widget','padding-top','10','','','.p-account-trade-form'),(488302,'furniture-mobile','.p-blog-index .comment-metadata','padding-top','4','','','.p-blog-index'),(488303,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-top','10','','','.p-account-subscription-historyinfo'),(488304,'furniture-mobile','.w-catalog-listing-look .listing-look-title','padding-top','4','','','.w-catalog-listing-look'),(488305,'furniture-mobile','.b-table .table td','padding-top','15','','','.b-table'),(488307,'furniture-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(488308,'furniture-mobile','.b-email .image','padding-top','5','','','.b-email'),(488309,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(488310,'furniture-mobile','.b-email .price','padding-top','5','','','.b-email'),(488311,'furniture-mobile','.w-product-images-additional .images','padding-top','10','2906','','.w-product-images-additional'),(488312,'furniture-mobile','.b-bottom .cart-options .heading-4','padding-top','10','','','.b-bottom'),(488313,'furniture-mobile','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-top','0','','','.b-bottom'),(488314,'furniture-mobile','.b-compare .popupCompare .pop-up-content','padding-top','0','','','.b-compare'),(488315,'furniture-mobile','.w-promotions .promo-cart-discount .master .item','padding-top','0','','','.w-promotions'),(488316,'furniture-mobile','.w-sale .left-count','padding-top','5','','','.w-sale'),(488317,'furniture-mobile','.w-sale .left-text-left','padding-top','24','','','.w-sale'),(488318,'furniture-mobile','.w-sale .holder-1','padding-top','20','','','.w-sale'),(488319,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(488320,'furniture-mobile','.b-bottom .alert-message','padding-top','20','','','.b-bottom'),(488321,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-top','5','','','.w-menu-slider'),(488322,'furniture-mobile','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(488323,'furniture-mobile','.w-menu-slider > ul > li > a','padding-top','5','','','.w-menu-slider'),(488324,'furniture-mobile','.w-sale .holder-1','padding-top','20','','','.w-sale'),(488325,'furniture-mobile','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(488326,'furniture-mobile','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(488327,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(488328,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(488330,'furniture-mobile','.b-email .image','padding-top','5','','','.b-email'),(488331,'furniture-mobile','.b-bottom .cart-options','padding-top','20','','','.b-bottom'),(488333,'furniture-mobile','.b-info .info','padding-top','20','','','.b-info'),(488334,'furniture-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(488336,'furniture-mobile','.b-email .price','padding-top','5','','','.b-email'),(488337,'furniture-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding-top','15','','','.w-wedding-registry-widgets-manage-banner'),(488338,'furniture-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(488339,'furniture-mobile','.b-email .image','padding-top','5','','','.b-email'),(488340,'furniture-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(488341,'furniture-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(488342,'furniture-mobile','.b-bottom .footerTitle','padding-top','9','2876','','.b-bottom');
INSERT INTO `themes_styles` VALUES (488343,'furniture-mobile','.b-bottom .pop-up-info','padding-top','20','','','.b-bottom'),(488344,'furniture-mobile','.b-bottom .pop-up-close','padding-top','1','','','.b-bottom'),(488345,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(488346,'furniture-mobile','.w-cart-up-sell .w-list-type-1','padding-top','0','','','.w-cart-up-sell'),(488347,'furniture-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-top','1','','','.w-cart-up-sell'),(488348,'furniture-mobile','.w-cart-shipping-estimator .address-item','padding-top','0','','','.w-cart-shipping-estimator'),(488349,'furniture-mobile','.w-cart-up-sell .w-list-type-1 .item','padding-top','0','1','','.w-cart-up-sell'),(488350,'furniture-mobile','.b-products-listing .products-listing .btn-buy','padding-top','5','','','.b-products-listing'),(488351,'furniture-mobile','.b-upload-files .added-file','padding-top','5','','','.b-upload-files'),(488352,'furniture-mobile','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(488353,'furniture-mobile','.w-menu-style-1 ul','padding-top','0','','','.w-menu-style-1'),(488354,'furniture-mobile','.w-sale .left-text-left','padding-top','24','','','.w-sale'),(488355,'furniture-mobile','.w-socials > li','padding-top','15','','','.w-socials'),(488356,'furniture-mobile','.w-personal-gift-status-bar .end-date','padding-top','0','3','','.w-personal-gift-status-bar'),(488357,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','2876','','.p-quote-checkout-success'),(488358,'furniture-mobile','.b-bottom .popup-box-wrap','padding-top','10','','','.b-bottom'),(488359,'furniture-mobile','.b-fancybox .fancybox-error','padding-top','15','','','.b-fancybox'),(488360,'furniture-mobile','.b-info .info','padding-top','20','','','.b-info'),(488361,'furniture-mobile','.b-info .info ul','padding-top','0','','','.b-info'),(488362,'furniture-mobile','.b-form .privacy-row','padding-top','10','','','.b-form'),(488363,'furniture-mobile','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(488364,'furniture-mobile','.b-form .payment-method .item','padding-top','7','','','.b-form'),(488365,'furniture-mobile','.b-form .required-message-wrap','padding-top','0','','','.b-form'),(488366,'furniture-mobile','.w-product-customers-activity .customers-activity','padding-top','35','','','.w-product-customers-activity'),(488367,'furniture-mobile','.b-table .table .headings td','padding-top','5','','','.b-table'),(488368,'furniture-mobile','.b-email .name','padding-top','5','','','.b-email'),(488369,'furniture-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(488370,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-top','0','','','.p-blog-index'),(488371,'furniture-mobile','.p-blog-index .comment-metadata','padding-top','4','','','.p-blog-index'),(488372,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(488373,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-top','0','','','.p-reviews-info'),(488374,'furniture-mobile','.w-sale .left-count','padding-top','5','','','.w-sale'),(488375,'furniture-mobile','.w-sale .holder-2','padding-top','20','','','.w-sale'),(488380,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-top','0','','','.w-menu-slider'),(488381,'furniture-mobile','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(488382,'furniture-mobile','.w-checkout-billing-address .edit-ab','padding-top','5','','','.w-checkout-billing-address'),(488383,'furniture-mobile','.w-checkout-shipping-choice span','padding-top','7','','','.w-checkout-shipping-choice'),(488384,'furniture-mobile','.w-promo-code .holder','padding-top','20','2906','','.w-promo-code'),(488385,'furniture-mobile','.w-product-images-additional .images','padding-top','10','2906','','.w-product-images-additional'),(488386,'furniture-mobile','.w-categories .item','padding-top','5','','','.w-categories'),(488387,'furniture-mobile','.w-menu-style-1 ul','padding-top','0','','','.w-menu-style-1'),(488388,'furniture-mobile','.w-sale .text','padding-top','10','','','.w-sale'),(488389,'furniture-mobile','.w-tabs .accordion-heading','padding-top','6','','','.w-tabs'),(488390,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','12','2885','','.w-menu-style-1'),(488391,'furniture-mobile','.w-socials > li','padding-top','15','','','.w-socials'),(488392,'furniture-mobile','.p-account-trade-form .widget','padding-top','10','','','.p-account-trade-form'),(488393,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-top','20','','','.p-account-trade-form'),(488394,'furniture-mobile','.b-form .shipping-method .sub-title','padding-top','2','','','.b-form'),(488395,'furniture-mobile','.w-categories h2.name','padding-top','3','','','.w-categories'),(488396,'furniture-mobile','.b-table .table .headings td','padding-top','5','','','.b-table'),(488397,'furniture-mobile','.w-catalog-sorting .before','padding-top','5','','','.w-catalog-sorting'),(488398,'furniture-mobile','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(488399,'furniture-mobile','.w-account .acc-new','padding-top','0','','','.w-account'),(488400,'furniture-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding-top','25','2890','','.w-wedding-registry-widgets-manage-banner'),(488401,'furniture-mobile','.p-reviews-info .review-info-content','padding-top','20','','','.p-reviews-info'),(488402,'furniture-mobile','.p-blog-index .comment-metadata','padding-top','4','','','.p-blog-index'),(488403,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-top','5','','','.p-blog-index'),(488404,'furniture-mobile','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(488405,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(488406,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(488407,'furniture-mobile','.p-blog-index .wp-widget ul','padding-top','0','','','.p-blog-index'),(488408,'furniture-mobile','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(488409,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(488410,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-top','0','','','.b-select-suggest'),(488411,'furniture-mobile','.b-select-suggest .select2-locked','padding-top','3','','','.b-select-suggest'),(488412,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-top','5','','','.b-select-suggest'),(488413,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','padding-top','0','','','.b-select-suggest'),(488414,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','padding-top','3','','','.b-select-suggest'),(488415,'furniture-mobile','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','5','','','.w-menu-horizontal'),(488416,'furniture-mobile','.w-menu-slider > ul > li > a','padding-top','5','','','.w-menu-slider'),(488417,'furniture-mobile','.b-select-suggest .select2-results','padding-top','0','','','.b-select-suggest'),(488418,'furniture-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','padding-top','4','','','.b-select-suggest'),(488419,'furniture-mobile','.b-select-suggest .select2-search input','padding-top','4','','','.b-select-suggest'),(488420,'furniture-mobile','.b-bottom .notify-form','padding-top','0','','','.b-bottom'),(488421,'furniture-mobile','.b-select-suggest .select2-drop-auto-width .select2-search','padding-top','4','','','.b-select-suggest'),(488422,'furniture-mobile','.w-neighbour-checkout .neighbour-comment-box','padding-top','10','','','.w-neighbour-checkout'),(488423,'furniture-mobile','.w-sale .holder-2','padding-top','20','','','.w-sale'),(488424,'furniture-mobile','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(488425,'furniture-mobile','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(488426,'furniture-mobile','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(488427,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','6','','','.w-menu-style-1'),(488428,'furniture-mobile','.w-personal-gift-status-bar .inform','padding-top','0','4','','.w-personal-gift-status-bar'),(488429,'furniture-mobile','.w-languages .lang-link','padding-top','5','','','.w-languages'),(488430,'furniture-mobile','.w-checkout-billing-address .same-address','padding-top','10','','','.w-checkout-billing-address'),(488431,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-top','12','2885','','.w-menu-style-1'),(488432,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li','padding-top','2','','','.w-menu-horizontal'),(488433,'furniture-mobile','.w-menu-big ul','padding-top','0','','','.w-menu-big'),(488434,'furniture-mobile','.w-menu .hided.menu ul li','padding-top','0','','','.w-menu'),(488435,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-top','0','','','.w-menu'),(488436,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-top','0','','','.w-menu'),(488437,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-top','20','','','.p-account-trade-form'),(488438,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(488439,'furniture-mobile','.w-cart-compare .product-label','padding-top','15','','','.w-cart-compare'),(488440,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-top','10','','','.p-account-subscription-historyinfo'),(488441,'furniture-mobile','.p-blog-index .wp-widget ul','padding-top','0','','','.p-blog-index'),(488442,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(488443,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-top','0','','','.p-reviews-info'),(488444,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(488445,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-top','0','','','.w-menu-slider'),(488446,'furniture-mobile','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(488447,'furniture-mobile','.b-sub-totals .historyTotal td','padding-top','2','','','.b-sub-totals'),(488448,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-top','0','','','.p-reviews-info'),(488449,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(488450,'furniture-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(488451,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','6','','','.w-menu-style-1'),(488452,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(488453,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(488454,'furniture-mobile','.w-cart-compare .price-cell','padding-top','8','','','.w-cart-compare'),(488455,'furniture-mobile','.w-account-address-book .name','padding-top','4','','','.w-account-address-book'),(488456,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','padding-top','0','','','.w-menu'),(488457,'furniture-mobile','.w-account .acc-bottom','padding-top','10','','','.w-account'),(488458,'furniture-mobile','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(488459,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-top','0','','','.w-menu-slider'),(488460,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','6','','','.w-menu-style-1'),(488461,'furniture-mobile','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(488462,'furniture-mobile','.w-account-addresses-list .addsess-suggestion-item','padding-top','0','','','.w-account-addresses-list'),(488463,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top','0','','','.b-data-table'),(488464,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.b-data-table'),(488465,'furniture-mobile','.w-communication-post .communication-post-author','padding-top','10','','','.w-communication-post'),(488466,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','padding-top','0','','','.b-products-listing'),(488467,'furniture-mobile','.b-products-listing .in-cart','padding-top','5','','','.b-products-listing'),(488468,'furniture-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-top','4','','','.b-products-listing'),(488469,'furniture-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-top','5','','','.w-catalog-b2b-add-button'),(488470,'furniture-mobile','.b-products-listing .promos-info .promo-name','padding-top','3','','','.b-products-listing'),(488471,'furniture-mobile','.b-products-listing .promos-info .promo-item','padding-top','3','','','.b-products-listing'),(488472,'furniture-mobile','.w-blog-widget-tag-cloud a','padding-top','10','','','.w-blog-widget-tag-cloud'),(488473,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_content','padding-top','20','','','.w-blog-widget-related-posts-by-category'),(488474,'furniture-mobile','.w-blog-widget-related-posts-by-category .post','padding-top','0','','','.w-blog-widget-related-posts-by-category'),(488475,'furniture-mobile','.w-blog-widget-related-posts .post_content a','padding-top','20','','','.w-blog-widget-related-posts'),(488476,'furniture-mobile','.w-blog-widget-related-posts .post','padding-top','0','','','.w-blog-widget-related-posts'),(488477,'furniture-mobile','.w-blog-widget-post-title h1','padding-top','0','','','.w-blog-widget-post-title'),(488478,'furniture-mobile','.w-blog-widget-post-title ','padding-top','0','','','.w-blog-widget-post-title'),(488479,'furniture-mobile','.w-blog-widget-post-share ','padding-top','15','2906','','.w-blog-widget-post-share'),(488480,'furniture-mobile','.w-blog-widget-post-listing .post','padding-top','0','2890','','.w-blog-widget-post-listing'),(488481,'furniture-mobile','.w-blog-widget-post-listing .post_name','padding-top','10','','','.w-blog-widget-post-listing'),(488482,'furniture-mobile','.w-blog-widget-post-listing .post','padding-top','0','','','.w-blog-widget-post-listing'),(488483,'furniture-mobile','.w-blog-widget-most-popular-posts .heading-title ~ div','padding-top','0','','','.w-blog-widget-most-popular-posts'),(488484,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','padding-top','10','','','.p-account-subscription-historyinfo'),(488485,'furniture-mobile','.w-currencies .select-link','padding-top','12','2885','','.w-currencies'),(488486,'furniture-mobile','.w-currencies .select-link','padding-top','5','','','.w-currencies'),(488487,'furniture-mobile','.w-currencies .current','padding-top','13','2885','','.w-currencies'),(488488,'furniture-mobile','.w-currencies .current','padding-top','4','','','.w-currencies'),(488489,'furniture-mobile','.w-currencies .currencies-title','padding-top','2','','','.w-currencies'),(488490,'furniture-mobile','.w-sale .text','padding-top','10','','','.w-sale'),(488491,'furniture-mobile','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(488492,'furniture-mobile','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(488493,'furniture-mobile','.p-reviews-info .reviews-info .buttons','padding-top','0','','','.p-reviews-info'),(488494,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','5','2876','','.p-quote-checkout-success'),(488495,'furniture-mobile','.w-checkout-gdpr .privacy-row','padding-top','0','','','.w-checkout-gdpr'),(488496,'furniture-mobile','.w-checkout-gdpr .terms-login','padding-top','0','','','.w-checkout-gdpr'),(488497,'furniture-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(488498,'furniture-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(488499,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','padding-top','3','3','','.b-select-suggest'),(488500,'furniture-mobile','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(488501,'furniture-mobile','.b-table .table .headings td','padding-top','5','','','.b-table'),(488502,'furniture-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(488503,'furniture-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(488504,'furniture-mobile','.b-compare .compare-box-item','padding-top','10','','','.b-compare'),(488505,'furniture-mobile','.b-email .heading-qty','padding-top','5','','','.b-email'),(488506,'furniture-mobile','.b-bottom .header-info','padding-top','20','','','.b-bottom'),(488507,'furniture-mobile','.w-sale .left-text-left','padding-top','24','','','.w-sale'),(488508,'furniture-mobile','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(488509,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-top','5','','','.w-menu-slider'),(488510,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(488511,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-top','5','','','.p-blog-index'),(488512,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-top','0','','','.p-blog-index'),(488513,'furniture-mobile','.b-compare .compare-head','padding-top','10','','','.b-compare'),(488514,'furniture-mobile','.heading-4 .right-text, h4 .right-text','padding-top','4','','',''),(488515,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-top','0','','',''),(488516,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-top','0','','','.b-h-inline'),(488517,'furniture-mobile','h1, .heading-1','padding-top','20','','',''),(488518,'furniture-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(488519,'furniture-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(488520,'furniture-mobile','.blogsidebar .heading-title','padding-top','0','','','.blogsidebar'),(488521,'furniture-mobile','.w-communication-new-topic .topick-left-col','padding-top','24','','','.w-communication-new-topic'),(488522,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-top','0','','','.w-communication-new-topic'),(488523,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-top','5','','','.w-communication-new-topic'),(488524,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-top','5','','','.w-communication-new-topic'),(488525,'furniture-mobile','.w-communication-new-topic #communication_topic_form .middle-form','padding-top','20','','','.w-communication-new-topic'),(488527,'furniture-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(488528,'furniture-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(488529,'furniture-mobile','.b-email .price','padding-top','5','','','.b-email'),(488530,'furniture-mobile','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-top','4','','','.b-compare'),(488531,'furniture-mobile','.w-languages .current','padding-top','3','','','.w-languages'),(488532,'furniture-mobile','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(488533,'furniture-mobile','.p-reviews-info .review-info-text','padding-top','10','','','.p-reviews-info'),(488534,'furniture-mobile','.p-reviews-info .review-info-image','padding-top','20','','','.p-reviews-info'),(488535,'furniture-mobile','.w-cart-compare .price-label','padding-top','10','','','.w-cart-compare'),(488536,'furniture-mobile','.w-menu-style-1 ul','padding-top','0','','','.w-menu-style-1'),(488537,'furniture-mobile','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(488538,'furniture-mobile','.w-menu .hided.menu ul li','padding-top','0','','','.w-menu'),(488539,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(488540,'furniture-mobile','.b-table .table td','padding-top','15','','','.b-table'),(488541,'furniture-mobile','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(488542,'furniture-mobile','.b-info .info li','padding-top','0','','','.b-info'),(488544,'furniture-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(488545,'furniture-mobile','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(488546,'furniture-mobile','.b-email .model','padding-top','5','','','.b-email'),(488547,'furniture-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(488548,'furniture-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(488549,'furniture-mobile','.products-quick-index .token-input-list','padding-top','0','','',''),(488550,'furniture-mobile','.w-cart-compare .cart-cell','padding-top','0','','','.w-cart-compare'),(488551,'furniture-mobile','.w-languages .current','padding-top','12','2885','','.w-languages'),(488552,'furniture-mobile','.w-reviews .item','padding-top','15','','','.w-reviews'),(488553,'furniture-mobile','.w-sale .left-text-left','padding-top','24','','','.w-sale'),(488554,'furniture-mobile','.w-sale .holder-1','padding-top','20','','','.w-sale'),(488555,'furniture-mobile','.w-sale .holder-2','padding-top','20','','','.w-sale'),(488556,'furniture-mobile','.w-sale .left-count','padding-top','5','','','.w-sale'),(488557,'furniture-mobile','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(488558,'furniture-mobile','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(488559,'furniture-mobile','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(488560,'furniture-mobile','.w-sale .left-text-right','padding-top','24','','','.w-sale'),(488562,'furniture-mobile','.b-email .name','padding-top','5','','','.b-email'),(488563,'furniture-mobile','.b-form .shipping-method .item','padding-top','0','','','.b-form'),(488564,'furniture-mobile','.b-email .heading-name','padding-top','5','','','.b-email'),(488565,'furniture-mobile','.b-email .qty','padding-top','5','','','.b-email'),(488566,'furniture-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(488567,'furniture-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(488568,'furniture-mobile','.b-email .heading-model','padding-top','5','','','.b-email'),(488569,'furniture-mobile','.b-compare .col-two label','padding-top','5','','','.b-compare'),(488570,'furniture-mobile','.w-cart-listing .item .attributes','padding-top','5','','','.w-cart-listing'),(488571,'furniture-mobile','.w-cart-listing .item .gift-wrap label','padding-top','10','','','.w-cart-listing'),(488572,'furniture-mobile','.w-cart-listing .item > div','padding-top','10','','','.w-cart-listing'),(488573,'furniture-mobile','.w-cart-listing .points-earn','padding-top','5','','','.w-cart-listing'),(488574,'furniture-mobile','.w-cart-listing .points-redeem','padding-top','0','','','.w-cart-listing'),(488575,'furniture-mobile','.b-bottom .header-error','padding-top','20','','','.b-bottom'),(488576,'furniture-mobile','.w-cart .cart-box-link','padding-top','0','','','.w-cart'),(488577,'furniture-mobile','.w-cart .buttons','padding-top','15','','','.w-cart'),(488578,'furniture-mobile','.w-cart .buttons .btn','padding-top','5','','','.w-cart'),(488579,'furniture-mobile','.w-cart .multicart .name','padding-top','0','','','.w-cart'),(488580,'furniture-mobile','.w-cart .multicart .item','padding-top','15','','','.w-cart'),(488581,'furniture-mobile','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(488582,'furniture-mobile','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(488583,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(488584,'furniture-mobile','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(488585,'furniture-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(488586,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-top','10','','','.w-image-maps'),(488587,'furniture-mobile','.b-info .info ul','padding-top','0','','','.b-info'),(488588,'furniture-mobile','.b-compare .col-gender','padding-top','0','','','.b-compare'),(488589,'furniture-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(488590,'furniture-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-top','0','','','.b-fancybox'),(488591,'furniture-mobile','.b-compare .compare_pagination','padding-top','10','','','.b-compare'),(488592,'furniture-mobile','.w-top-categories .item','padding-top','5','2876','','.w-top-categories'),(488593,'furniture-mobile','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(488594,'furniture-mobile','.w-catalog-paging .paging-item','padding-top','0','','','.w-catalog-paging'),(488595,'furniture-mobile','.w-cart .cart-total','padding-top','10','','','.w-cart'),(488596,'furniture-mobile','.w-cart .cart-content','padding-top','15','','','.w-cart'),(488597,'furniture-mobile','.p-reviews-info .review-info-image','padding-top','20','','','.p-reviews-info'),(488598,'furniture-mobile','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(488599,'furniture-mobile','.p-reviews-info .review-info-text','padding-top','10','','','.p-reviews-info'),(488600,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-top','0','','','.p-blog-index'),(488601,'furniture-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(488602,'furniture-mobile','.b-table .table td','padding-top','15','','','.b-table'),(488603,'furniture-mobile','.p-account-trade-form .trade-form-area','padding-top','20','','','.p-account-trade-form'),(488604,'furniture-mobile','.p-blog-index .nav-links','padding-top','20','','','.p-blog-index'),(488605,'furniture-mobile','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(488606,'furniture-mobile','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(488607,'furniture-mobile','.p-reviews-info .review-info-text','padding-top','10','','','.p-reviews-info'),(488608,'furniture-mobile','.w-menu .hided.menu ul li','padding-top','0','','','.w-menu'),(488609,'furniture-mobile','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(488610,'furniture-mobile','.w-menu-slider > ul > li > ul > li','padding-top','5','','','.w-menu-slider'),(488611,'furniture-mobile','.w-filters .fsl_handle','padding-top','20','','','.w-filters'),(488612,'furniture-mobile','.w-filters .head-filter-widget','padding-top','0','2885','','.w-filters'),(488613,'furniture-mobile','.w-filters .ui-slider-range','padding-top','0','','','.w-filters'),(488614,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-top','5','','','.p-blog-index'),(488615,'furniture-mobile','.p-reviews-info .review-info-image','padding-top','20','','','.p-reviews-info'),(488616,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(488617,'furniture-mobile','.p-reviews-info .review-info-content','padding-top','20','','','.p-reviews-info'),(488618,'furniture-mobile','.p-blog-index .wp-widget ul','padding-top','0','','','.p-blog-index'),(488619,'furniture-mobile','.p-blog-index .comments-area ol, .p-blog-index .comments-area li','padding-top','0','','','.p-blog-index'),(488620,'furniture-mobile','.p-blog-index .nav-links','padding-top','20','','','.p-blog-index'),(488621,'furniture-mobile','.w-filters .head-filter-widget','padding-top','0','','','.w-filters'),(488622,'furniture-mobile','.b-autocomplete .ui-autocomplete','padding-top','2','','','.b-autocomplete'),(488623,'furniture-mobile','.w-promo-code .holder','padding-top','20','2906','','.w-promo-code'),(488624,'furniture-mobile','.w-languages .lang-link','padding-top','13','2885','','.w-languages'),(488625,'furniture-mobile','.order-summary .heading-2','padding-top','10','','','.order-summary'),(488626,'furniture-mobile','.b-compare .column_wrapper','padding-top','0','','','.b-compare'),(488627,'furniture-mobile','.b-email .image','padding-top','5','','','.b-email'),(488628,'furniture-mobile','.b-email .heading-price','padding-top','5','','','.b-email'),(488629,'furniture-mobile','.b-email .heading-image','padding-top','5','','','.b-email'),(488630,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(488632,'furniture-mobile','.b-table .table .headings td','padding-top','5','','','.b-table'),(488633,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','6','','','.w-menu-style-1'),(488634,'furniture-mobile','.w-menu-slider ul, .w-menu-slider li','padding-top','0','','','.w-menu-slider'),(488635,'furniture-mobile','.w-reviews-content .author','padding-top','0','','','.w-reviews-content'),(488636,'furniture-mobile','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(488637,'furniture-mobile','.w-menu-style-1 ul','padding-top','0','','','.w-menu-style-1'),(488638,'furniture-mobile','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(488639,'furniture-mobile','.price .old','padding-top','0.3','','',''),(488640,'furniture-mobile','.b-data-table table.dataTable tbody td','padding-top','10','','','.b-data-table'),(488641,'furniture-mobile','.b-data-table table.dataTable thead td','padding-top','10','','','.b-data-table'),(488642,'furniture-mobile','.p-reviews-info .review-info-image','padding-top','20','','','.p-reviews-info'),(488643,'furniture-mobile','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(488644,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(488645,'furniture-mobile','.b-table .table td','padding-top','15','','','.b-table'),(488646,'furniture-mobile','.w-menu .hided.menu ul li','padding-top','0','','','.w-menu'),(488647,'furniture-mobile','.btn-2','padding-top','12','','',''),(488648,'furniture-mobile','.w-quote-products .empty','padding-top','100','','','.w-quote-products'),(488649,'furniture-mobile','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(488651,'furniture-mobile','.b-info .info li','padding-top','0','','','.b-info'),(488652,'furniture-mobile','.b-info .info','padding-top','20','','','.b-info'),(488653,'furniture-mobile','.w-checkout-create-account .create-account','padding-top','10','','','.w-checkout-create-account'),(488654,'furniture-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(488655,'furniture-mobile','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(488656,'furniture-mobile','.b-upload-files .upload-files','padding-top','0','','','.b-upload-files'),(488657,'furniture-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(488658,'furniture-mobile','.w-menu-slider > ul > li > a','padding-top','5','','','.w-menu-slider'),(488659,'furniture-mobile','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(488660,'furniture-mobile','.b-email .totals-value','padding-top','5','','','.b-email'),(488661,'furniture-mobile','.b-email .totals-title','padding-top','5','','','.b-email'),(488662,'furniture-mobile','.b-email .qty','padding-top','5','','','.b-email'),(488663,'furniture-mobile','.btn','padding-top','7','','',''),(488664,'furniture-mobile','.p-blog-index .comment-form p input[name=\"url\"]','padding-top','5','','','.p-blog-index'),(488665,'furniture-mobile','.p-blog-index .wp-widget ul','padding-top','0','','','.p-blog-index'),(488666,'furniture-mobile','.w-personal-gift-status-bar .timeline','padding-top','16','','','.w-personal-gift-status-bar'),(488667,'furniture-mobile','.b-product-images .media-popup .mp-content','padding-top','0','','','.b-product-images'),(488668,'furniture-mobile','.b-product-images .media-popup .mp-small-images .item','padding-top','10','','','.b-product-images'),(488669,'furniture-mobile','.b-product-images .media-popup .slick-dots','padding-top','0','','','.b-product-images'),(488670,'furniture-mobile','.b-product-images .media-popup .slick-dots li','padding-top','0','','','.b-product-images'),(488671,'furniture-mobile','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-top','0','','','.b-menu-style'),(488672,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-top','12','','','.b-menu-style-1'),(488673,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-top','5','','','.b-menu-style-2'),(488674,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-top','5','','','.b-menu-style-2'),(488675,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-top','0','','','.b-menu-style-2'),(488676,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-top','0','','','.b-menu-style-2'),(488677,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-top','10','','','.b-menu-style-2'),(488678,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-top','0','','','.b-menu-style-2'),(488679,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-top','5','','','.b-menu-style-2'),(488680,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-top','10','','','.b-menu-style-2'),(488681,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-top','5','','','.b-menu-style-2'),(488682,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-html_box','padding-top','7','','','.b-menu-style-2'),(488683,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-top','10','','','.b-menu-style-2'),(488684,'furniture-mobile','.b-personal-catalog-popup #personal_catalog_popup','padding-top','20','','','.b-personal-catalog-popup'),(488685,'furniture-mobile','.b-trade-approval .steps-bar li a','padding-top','7','','','.b-trade-approval'),(488686,'furniture-mobile','.b-trade-approval .middle-form','padding-top','20','','','.b-trade-approval'),(488687,'furniture-mobile','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-top','5','','','.b-trade-approval'),(488688,'furniture-mobile','.b-trade-approval .steps-bar','padding-top','0','','','.b-trade-approval'),(488689,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-top','4','','','.b-trade-approval'),(488690,'furniture-mobile','.b-trade-approval .center-buttons','padding-top','20','','','.b-trade-approval'),(488691,'furniture-mobile','.batchPr .w-batch-products .products-listing .image','padding-top','0','','','.batchPr'),(488692,'furniture-mobile','.batchPr .w-batch-products .products-listing .image + .type-1','padding-top','5','','','.batchPr'),(488693,'furniture-mobile','.batchPr .w-batch-products','padding-top','0','','','.batchPr'),(488694,'furniture-mobile','.batchPr > .block:nth-child(2)','padding-top','12','','','.batchPr'),(488695,'furniture-mobile','.batchPr .w-batch-selected-products','padding-top','15','','','.batchPr'),(488696,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .product-holder','padding-top','0','','','.batchPr'),(488697,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .item + .item','padding-top','10','','','.batchPr'),(488698,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .item','padding-top','0','','','.batchPr'),(488699,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','padding-top','0','','','.batchPr'),(488700,'furniture-mobile','.batchPr ','padding-top','20','','','.batchPr'),(488701,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','padding-top','0','','','.batchPr'),(488702,'furniture-mobile','.batchPr .w-batch-products .products-listing .image','padding-top','0','','','.batchPr'),(488703,'furniture-mobile','.batchPr .w-batch-products .productGroup .radioBox','padding-top','0','','','.batchPr'),(488704,'furniture-mobile','.w-account-personal-catalog .list-switcher','padding-top','0','','','.w-account-personal-catalog'),(488705,'furniture-mobile','.w-account-personal-catalog .list-switcher a','padding-top','14','','','.w-account-personal-catalog'),(488706,'furniture-mobile','.w-account-personal-catalog .list-switcher a','padding-top','12','2','','.w-account-personal-catalog'),(488707,'furniture-mobile','.w-account-subscription .subscription-variant','padding-top','10','','','.w-account-subscription'),(488708,'furniture-mobile','.w-catalog-additional-images li','padding-top','10','','','.w-catalog-additional-images'),(488709,'furniture-mobile','.w-catalog-additional-images ul','padding-top','0','','','.w-catalog-additional-images'),(488710,'furniture-mobile','.w-catalog-compare td','padding-top','10','','','.w-catalog-compare'),(488711,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','padding-top','12','','','.w-catalog-compare'),(488712,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','padding-top','10','2','','.w-catalog-compare'),(488713,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-top','0','','','.w-catalog-compare'),(488714,'furniture-mobile','.w-delivery-day .left-count','padding-top','5','','','.w-delivery-day'),(488715,'furniture-mobile','.w-delivery-day .left-text-left','padding-top','24','','','.w-delivery-day'),(488716,'furniture-mobile','.w-delivery-day .left-text-right','padding-top','24','','','.w-delivery-day'),(488717,'furniture-mobile','.w-top-text .top-text','padding-top','5','','','.w-top-text'),(488718,'furniture-mobile','.w-product-images .slick-vertical + .produst-image','padding-top','400','','','.w-product-images'),(488719,'furniture-mobile','.w-cart-listing .points','padding-top','0','2876','','.w-cart-listing'),(488720,'furniture-mobile','.w-product-images .additional-horizontal .item','padding-top','10','','','.w-product-images'),(488721,'furniture-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-top','10','','','.b-cookie-notice'),(488722,'furniture-mobile','.w-cart .no-text','padding-top','0','','','.w-cart'),(488723,'furniture-mobile','.lowestPricedBox .w-banner .banner','padding-top','30','','','.lowestPricedBox'),(488724,'furniture-mobile','.tripleBanner ','padding-top','15','','','.tripleBanner'),(488725,'furniture-mobile','.tripleBanner > .block','padding-top','0','','','.tripleBanner'),(488726,'furniture-mobile','.tripleBanner .w-html_box','padding-top','17','','','.tripleBanner'),(488727,'furniture-mobile','.preFooter .w-banner .single_banner picture','padding-top','0','','','.preFooter'),(488728,'furniture-mobile','.w-languages .current','padding-top','7','2906','','.w-languages'),(488729,'furniture-mobile','.w-currencies .current','padding-top','7','2906','','.w-currencies'),(488730,'furniture-mobile','.b-slick .slick-list','padding-top','0','','','.b-slick'),(488731,'furniture-mobile','.b-slick .slick-vertical button.slick-next','padding-top','0','3','','.b-slick'),(488732,'furniture-mobile','.b-slick .slick-vertical button.slick-prev','padding-top','0','3','','.b-slick'),(488733,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','padding-top','0','','','.b-slick'),(488734,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-top','5','2885','','.b-menu-style-3'),(488735,'furniture-mobile','body','padding-top','75','2885','',''),(488736,'furniture-mobile','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','padding-top','0','','','.b-products-listing'),(488737,'furniture-mobile','.w-cart-listing .headings .head','padding-top','10','','','.w-cart-listing'),(488738,'furniture-mobile','.b-products-listing .item-nav > div','padding-top','10','','','.b-products-listing'),(488739,'furniture-mobile','.LeftCategories .w-menu-simple ul','padding-top','0','','','.LeftCategories'),(488740,'furniture-mobile','.LeftCategories .w-menu-simple ul li a','padding-top','4','','','.LeftCategories'),(488741,'furniture-mobile','.w-filters .filter-widget','padding-top','20','','','.w-filters'),(488742,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item','padding-top','0','','','.b-products-listing'),(488743,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-top','0','','','.b-products-listing'),(488744,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-content','padding-top','15','','','.b-products-listing'),(488745,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','padding-top','0','','','.b-products-listing'),(488746,'furniture-mobile','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-top','15','','','.b-products-listing'),(488747,'furniture-mobile','.b-products-listing .products-listing.list-rows .item-nav > div','padding-top','0','','','.b-products-listing'),(488748,'furniture-mobile','.b-products-listing .products-listing.list-rows .item:first-of-type .BlockBox.item-holder','padding-top','10','','','.b-products-listing'),(488749,'furniture-mobile','.w-breadcrumb .breadcrumb-li','padding-top','0','','','.w-breadcrumb'),(488750,'furniture-mobile','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(488751,'furniture-mobile','.w-subscribers .btn-submit','padding-top','5','','','.w-subscribers'),(488752,'furniture-mobile','.w-quote .buttons','padding-top','15','','','.w-quote'),(488753,'furniture-mobile','.w-quote .buttons .btn','padding-top','5','','','.w-quote'),(488754,'furniture-mobile','.w-quote .cart-content','padding-top','15','','','.w-quote'),(488755,'furniture-mobile','.w-quote .cart-total','padding-top','10','','','.w-quote'),(488756,'furniture-mobile','.w-quote .multicart .cart-content','padding-top','0','','','.w-quote'),(488757,'furniture-mobile','.w-quote .multicart .item','padding-top','15','','','.w-quote'),(488758,'furniture-mobile','.w-quote .multicart .name','padding-top','0','','','.w-quote'),(488759,'furniture-mobile','.w-quote .no-text','padding-top','0','','','.w-quote'),(488760,'furniture-mobile','.w-quote a.item','padding-top','5','','','.w-quote'),(488761,'furniture-mobile','.w-social-links a','padding-top','4','','','.w-social-links'),(488762,'furniture-mobile','.w-product-images .additional-vertical .additional-images','padding-top','30','','','.w-product-images'),(488763,'furniture-mobile','.w-product-personal-catalog-button .btn','padding-top','0','','','.w-product-personal-catalog-button'),(488764,'furniture-mobile','.b-quantity .qty-box input','padding-top','5','','','.b-quantity'),(488765,'furniture-mobile','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(488766,'furniture-mobile','.w-product-sale-ends .left-count','padding-top','5','','','.w-product-sale-ends'),(488767,'furniture-mobile','.w-product-sale-ends .left-text-left','padding-top','24','','','.w-product-sale-ends'),(488768,'furniture-mobile','.w-product-sale-ends .left-text-right','padding-top','24','','','.w-product-sale-ends'),(488769,'furniture-mobile','.w-product-sale-ends .left-count-days','padding-top','7','','','.w-product-sale-ends'),(488770,'furniture-mobile','.w-product-sale-ends .left-count-hours','padding-top','7','','','.w-product-sale-ends'),(488771,'furniture-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(488772,'furniture-mobile','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(488773,'furniture-mobile','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(488774,'furniture-mobile','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(488775,'furniture-mobile','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(488776,'furniture-mobile','.warrantyProduct .warranty, .warrantyProduct .delivery','padding-top','10','','','.warrantyProduct'),(488777,'furniture-mobile','.w-compare .compare-list-buttons','padding-top','10','','','.w-compare'),(488778,'furniture-mobile','.w-compare .item-holder','padding-top','10','','','.w-compare'),(488779,'furniture-mobile','.w-compare .compare-list-products','padding-top','0','','','.w-compare'),(488780,'furniture-mobile','.w-files-catalog-widgets-files-catalog .name','padding-top','10','','','.w-files-catalog-widgets-files-catalog'),(488781,'furniture-mobile','.w-files-catalog-widgets-files-list .item + .item','padding-top','30','','','.w-files-catalog-widgets-files-list'),(488782,'furniture-mobile','.w-sample .buttons','padding-top','15','','','.w-sample'),(488783,'furniture-mobile','.w-sample .buttons .btn','padding-top','5','','','.w-sample'),(488784,'furniture-mobile','.w-sample .cart-box-link','padding-top','0','','','.w-sample'),(488785,'furniture-mobile','.w-sample .cart-content','padding-top','15','','','.w-sample'),(488786,'furniture-mobile','.w-sample .cart-total','padding-top','10','','','.w-sample'),(488787,'furniture-mobile','.w-sample .multicart .cart-content','padding-top','0','','','.w-sample'),(488788,'furniture-mobile','.w-sample .multicart .item','padding-top','15','','','.w-sample'),(488789,'furniture-mobile','.w-sample .multicart .name','padding-top','0','','','.w-sample'),(488790,'furniture-mobile','.w-sample .no-text','padding-top','0','','','.w-sample'),(488791,'furniture-mobile','.w-sample a.item','padding-top','5','','','.w-sample'),(488792,'furniture-mobile','.w-cart-listing .item > div.points','padding-top','0','','','.w-cart-listing'),(488793,'furniture-mobile','.w-filters-simple .integrate-price-holder','padding-top','10','','','.w-filters-simple'),(488794,'furniture-mobile','.w-cart-discount-coupon .title','padding-top','0','','','.w-cart-discount-coupon'),(488795,'furniture-mobile','.w-product-video .item','padding-top','10','','','.w-product-video'),(488796,'furniture-mobile','.shipping-ico .heading-3','padding-top','0','','','.shipping-ico'),(488797,'furniture-mobile','.w-cart-order-reference .btn','padding-top','6','','','.w-cart-order-reference'),(488798,'furniture-mobile','.w-cart-gift-certificate .btn','padding-top','6','','','.w-cart-gift-certificate'),(488799,'furniture-mobile','.w-cart-shipping-estimator .btn','padding-top','6','','','.w-cart-shipping-estimator'),(488800,'furniture-mobile','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(488801,'furniture-mobile','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(488802,'furniture-mobile','.w-product-in-bundles .attributes-item','padding-top','0','','','.w-product-in-bundles'),(488803,'furniture-mobile','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(488804,'furniture-mobile','.w-cart-listing .item > div.actions','padding-top','10','2876','','.w-cart-listing'),(488805,'furniture-mobile','.w-account-address-book .item','padding-top','10','','','.w-account-address-book'),(488806,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-top','0','','','.b-products-listing'),(488807,'furniture-mobile','.b-pagination ul.pagination','padding-top','0','','','.b-pagination'),(488808,'furniture-mobile','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','padding-top','10','','','.w-catalog-compare'),(488809,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .item','padding-top','3','','','.w-product-properties-filters-widgets-chosen-filters'),(488810,'furniture-mobile','.p-quote-checkout-index .datepicker-inline','padding-top','10','','','.p-quote-checkout-index'),(488811,'furniture-mobile','.p-sample-checkout-index .datepicker-inline','padding-top','10','','','.p-sample-checkout-index'),(488812,'furniture-mobile','.w-account-order-download td','padding-top','5','','','.w-account-order-download'),(488813,'furniture-mobile','.w-account-order-download td','padding-top','0','2876','','.w-account-order-download'),(488814,'furniture-mobile','.w-account-order-download tr','padding-top','10','2876','','.w-account-order-download'),(488815,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','padding-top','10','','','.w-product-multi-inventory'),(488816,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','padding-top','0','','','.w-account-personal-catalog'),(488817,'furniture-mobile','.w-account-personal-catalog .list-row-action li','padding-top','5','','','.w-account-personal-catalog'),(488818,'furniture-mobile','.w-account-personal-catalog .buy-box','padding-top','0','2876','','.w-account-personal-catalog'),(488819,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','padding-top','10','','','.b-products-listing'),(488820,'furniture-mobile','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(488821,'furniture-mobile','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(488822,'furniture-mobile','.w-product-collection .choose-products','padding-top','20','','','.w-product-collection'),(488823,'furniture-mobile','.w-product-collection .right-area .btn','padding-top','12','','','.w-product-collection'),(488824,'furniture-mobile','.w-account-customer-additional-field .tf-file','padding-top','5','','','.w-account-customer-additional-field'),(488825,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','padding-top','10','','','.w-product-attributes'),(488826,'furniture-mobile','.w-product-properties .property-ul','padding-top','0','','','.w-product-properties'),(488827,'furniture-mobile','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(488828,'furniture-mobile','.w-product-properties li','padding-top','5','','','.w-product-properties'),(488829,'furniture-mobile','.w-questionnaire-widgets-questionnaire .question + .question','padding-top','20','','','.w-questionnaire-widgets-questionnaire'),(488830,'furniture-mobile','.w-product-groups .radioBox','padding-top','0','','','.w-product-groups'),(488831,'furniture-mobile','.w-product-groups .radioBox label','padding-top','0','','','.w-product-groups'),(488832,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','padding-top','20','','','.w-product-groups'),(488833,'furniture-mobile','.w-product-groups .radioBox label .containerBlock','padding-top','5','2906','','.w-product-groups'),(488834,'furniture-mobile','.b-products-listing .mix-attributes .attribute-qty-block','padding-top','5','','','.b-products-listing'),(488835,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block','padding-top','5','','','.b-products-listing'),(488836,'furniture-mobile','.blogsidebar','padding-top','0','2885','',''),(488837,'furniture-mobile','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(488838,'furniture-mobile','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(488839,'furniture-mobile','.w-product-custom-bundle .choose-products','padding-top','10','','','.w-product-custom-bundle'),(488840,'furniture-mobile','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-top','14','','','.w-product-custom-bundle'),(488841,'furniture-mobile','.w-product-custom-bundle .right-area','padding-top','0','2885','','.w-product-custom-bundle'),(488842,'furniture-mobile','.w-product-custom-bundle .right-area .price','padding-top','20','2885','','.w-product-custom-bundle'),(488843,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list'),(488844,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-top','0','','','.w-catalog-pages-category-pages-last-list'),(488845,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list-block'),(488846,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-top','0','','','.w-catalog-pages-category-pages-last-list-block'),(488847,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(488848,'furniture-mobile','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(488849,'furniture-mobile','.w-delivery-location-location-description .deliveryDesc','padding-top','10','','','.w-delivery-location-location-description'),(488850,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent a','padding-top','6','','','.w-delivery-location-location-list'),(488851,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','padding-top','10','','','.w-delivery-location-location-list'),(488852,'furniture-mobile','.btn-2','padding-top','7','2876','',''),(488853,'furniture-mobile','.w-sale-category .holder-1','padding-top','20','','','.w-sale-category'),(488854,'furniture-mobile','.w-sale-category .holder-2','padding-top','20','','','.w-sale-category'),(488855,'furniture-mobile','.w-sale-category .left-count','padding-top','5','','','.w-sale-category'),(488856,'furniture-mobile','.w-sale-category .left-text-left','padding-top','24','','','.w-sale-category'),(488857,'furniture-mobile','.w-sale-category .left-text-right','padding-top','24','','','.w-sale-category'),(488858,'furniture-mobile','.w-sale-category .text','padding-top','10','','','.w-sale-category'),(488859,'furniture-mobile','.w-product-wedding-registry-button .btn','padding-top','7','','','.w-product-wedding-registry-button'),(488860,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(488861,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(488862,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(488863,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(488864,'furniture-mobile','.w-delivery-location-list-by-page .item','padding-top','20','','','.w-delivery-location-list-by-page'),(488865,'furniture-mobile','.w-product-properties-icons .property-image','padding-top','10','','','.w-product-properties-icons'),(488866,'furniture-mobile','.w-product-properties-icons .hover-box-content','padding-top','10','','','.w-product-properties-icons'),(488867,'furniture-mobile','.w-delivery-location-cross-pages .item','padding-top','20','','','.w-delivery-location-cross-pages'),(488868,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','padding-top','15','','','.w-delivery-location-product-categories'),(488869,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','padding-top','10','2885','','.w-delivery-location-product-categories'),(488870,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','padding-top','10','2906','','.w-delivery-location-product-categories'),(488871,'furniture-mobile','.w-delivery-location-product-categories .name','padding-top','10','','','.w-delivery-location-product-categories'),(488872,'furniture-mobile','.w-wedding-registry-widgets-search-paging ul.pagination','padding-top','0','','','.w-wedding-registry-widgets-search-paging'),(488873,'furniture-mobile','.w-wedding-registry-widgets-search-list .table td, .w-wedding-registry-widgets-search-list .table .headings td','padding-top','5','2885','','.w-wedding-registry-widgets-search-list'),(488874,'furniture-mobile','.w-wedding-registry-widgets-search-list .table .headings td','padding-top','5','','','.w-wedding-registry-widgets-search-list'),(488875,'furniture-mobile','.delivery-options-popup','padding-top','20','','',''),(488876,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','padding-top','8','','','.w-product-bonus-points'),(488877,'furniture-mobile','.w-product-designer-designer .grnamebox .title-sortable','padding-top','7','','','.w-product-designer-designer'),(488878,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','padding-top','10','','','.w-product-designer-designer'),(488879,'furniture-mobile','.w-press-reviews-widgets-press-reviews ','padding-top','30','','','.w-press-reviews-widgets-press-reviews'),(488880,'furniture-mobile','.w-press-reviews-widgets-press-reviews .author','padding-top','0','','','.w-press-reviews-widgets-press-reviews'),(488881,'furniture-mobile','.w-press-reviews-widgets-press-reviews .item','padding-top','20','','','.w-press-reviews-widgets-press-reviews'),(488882,'furniture-mobile','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-top','30','','','.w-press-reviews-widgets-press-reviews'),(488883,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','padding-top','10','','','.w-press-reviews-widgets-press-reviews'),(488884,'furniture-mobile','.w-press-reviews-widgets-press-reviews ','padding-top','20','2876','','.w-press-reviews-widgets-press-reviews'),(488885,'furniture-mobile','.w-press-reviews-widgets-press-reviews .item','padding-top','15','2876','','.w-press-reviews-widgets-press-reviews'),(488886,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','padding-top','10','2876','','.w-press-reviews-widgets-press-reviews'),(488887,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .item','padding-top','0','','','.w-press-reviews-widgets-press-reviews-list'),(488888,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .short-description','padding-top','0','','','.w-press-reviews-widgets-press-reviews-list'),(488889,'furniture-mobile','.b-products-listing .productGroup label a','padding-top','5','','','.b-products-listing'),(488890,'furniture-mobile','.w-gift-wrap-message-checkout .text','padding-top','2','','','.w-gift-wrap-message-checkout'),(488891,'furniture-mobile','.w-support-system-filter ','padding-top','0','','','.w-support-system-filter'),(488892,'furniture-mobile','.w-support-system-filter .filter_cats','padding-top','0','','','.w-support-system-filter'),(488893,'furniture-mobile','.w-support-system-listing .support-head','padding-top','13','','','.w-support-system-listing'),(488894,'furniture-mobile','.w-communication-post .btn.refresh','padding-top','0','','','.w-communication-post'),(488895,'furniture-mobile','.w-rma-returns-history .btn','padding-top','7','','','.w-rma-returns-history'),(488896,'furniture-mobile','.w-rma-returns-history .column','padding-top','0','','','.w-rma-returns-history'),(488897,'furniture-mobile','.w-rma-returns-history .column .title','padding-top','5','','','.w-rma-returns-history'),(488898,'furniture-mobile','.w-rma-returns-history .topRow','padding-top','10','','','.w-rma-returns-history'),(488899,'furniture-mobile','.w-rma-returns-history .column:last-child .title','padding-top','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(488900,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','padding-top','5','','','.b-menu-style-1'),(488901,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .goto-button','padding-top','0','','','.b-menu-style-1'),(488902,'furniture-mobile','.w-show-inactive-show-inactive .out_stock_label','padding-top','2','','','.w-show-inactive-show-inactive'),(488903,'furniture-mobile','.w-product-designer-designer .productDesignerBox ul','padding-top','0','','','.w-product-designer-designer'),(488904,'furniture-mobile','.w-product-configurator .pc-item','padding-top','0','','','.w-product-configurator'),(488905,'furniture-mobile','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(488906,'furniture-mobile','.w-product-configurator .pc_item','padding-top','10','2885','','.w-product-configurator'),(488907,'furniture-mobile','.w-product-configurator .pc_attr','padding-top','5','2876','','.w-product-configurator'),(488908,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','padding-top','8','','','.b-products-listing'),(488909,'furniture-mobile','.b-products-listing .promos-info .promo-name-span','padding-top','3','','','.b-products-listing'),(488910,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-list'),(488911,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-top','0','','','.w-catalog-pages-category-pages-list'),(488912,'furniture-mobile','.w-predefined-promotion .nextdiscount .content > div','padding-top','10','','','.w-predefined-promotion'),(488913,'furniture-mobile','.w-predefined-promotion .nextdiscount .promo-for-each','padding-top','3','','','.w-predefined-promotion'),(488914,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-product','padding-top','20','','','.w-predefined-promotion'),(488915,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','padding-top','0','','','.w-predefined-promotion'),(488916,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .item','padding-top','0','','','.w-predefined-promotion'),(488917,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-top','0','','','.w-predefined-promotion'),(488918,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-top','0','','','.w-predefined-promotion'),(488919,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .item','padding-top','20','','','.w-predefined-promotion'),(488920,'furniture-mobile','.w-predefined-promotion .promo-item','padding-top','30','','','.w-predefined-promotion'),(488921,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','padding-top','0','','','.w-predefined-promotion'),(488922,'furniture-mobile','.w-predefined-promotion .promo-salemaker .item','padding-top','20','','','.w-predefined-promotion'),(488923,'furniture-mobile','.w-supplier-purchase-supplier-products .item','padding-top','10','','','.w-supplier-purchase-supplier-products'),(488924,'furniture-mobile','.w-filters .filter-box-content ul','padding-top','0','','','.w-filters'),(488925,'furniture-mobile','.mainBanner .bottomBox','padding-top','55','','','.mainBanner'),(488926,'furniture-mobile','.mainBanner .bottomBox .btn','padding-top','1.09','','','.mainBanner'),(488927,'furniture-mobile','.mainBanner .topBox','padding-top','3','','','.mainBanner'),(488928,'furniture-mobile','.mainBanner .topBox > .right','padding-top','5','','','.mainBanner'),(488929,'furniture-mobile','.mainBanner .wrapper','padding-top','0','','','.mainBanner'),(488930,'furniture-mobile','.mainBanner .bottomBox','padding-top','33','2890','','.mainBanner'),(488931,'furniture-mobile','.mainBanner .bottomBox .btn','padding-top','8','2890','','.mainBanner'),(488932,'furniture-mobile','.mainBanner .topBox > .right','padding-top','5','2890','','.mainBanner'),(488933,'furniture-mobile','.mainBanner .wrapper','padding-top','0','2890','','.mainBanner'),(488934,'furniture-mobile','.mainBanner .bottomBox .btn','padding-top','6','2885','','.mainBanner'),(488935,'furniture-mobile','.mainBanner .content','padding-top','15','2876','','.mainBanner'),(488936,'furniture-mobile','.mainBanner .topBox > .right','padding-top','5','2876','','.mainBanner'),(488937,'furniture-mobile','.mainBanner .wrapper','padding-top','3','2876','','.mainBanner'),(488938,'furniture-mobile','.mainBanner .bottomBox','padding-top','25','2906','','.mainBanner'),(488939,'furniture-mobile','.mainBanner .bottomBox .btn','padding-top','4','2906','','.mainBanner'),(488940,'furniture-mobile','.mainBanner .content','padding-top','5','2906','','.mainBanner'),(488941,'furniture-mobile','.mainBanner .wrapper','padding-top','3','2906','','.mainBanner'),(488942,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','padding-top','15','','','.lowestPricedBox'),(488943,'furniture-mobile','.lowestPricedBox .w-banner .ybg .mark','padding-top','15','','','.lowestPricedBox'),(488944,'furniture-mobile','.lowestPricedBox .w-banner .ybg .mark','padding-top','10','2890','','.lowestPricedBox'),(488945,'furniture-mobile','.lowestPricedBox .w-banner .banner','padding-top','15','2876','','.lowestPricedBox'),(488946,'furniture-mobile','.lowestPricedBox .w-banner .ybg .mark','padding-top','0','2876','','.lowestPricedBox'),(488947,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','padding-top','10','2906','','.lowestPricedBox'),(488948,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','padding-top','4','2906','','.lowestPricedBox'),(488949,'furniture-mobile','.shopByCollectionBox .bannerButton','padding-top','10','','','.shopByCollectionBox'),(488950,'furniture-mobile','.shopByCollectionBox .bannerButton a','padding-top','7','','','.shopByCollectionBox'),(488951,'furniture-mobile','.shopByCollectionBox .content','padding-top','10','','','.shopByCollectionBox'),(488952,'furniture-mobile','.shopByCollectionBox .bannerButton','padding-top','5','2890','','.shopByCollectionBox'),(488953,'furniture-mobile','.shopByCollectionBox .bannerButton a','padding-top','7','2890','','.shopByCollectionBox'),(488954,'furniture-mobile','.w-quote-products .no-price','padding-top','15','','','.w-quote-products'),(488955,'furniture-mobile','.w-search .products .item a','padding-top','10','','','.w-search'),(488956,'furniture-mobile','.account-address-book .address_book','padding-top','0','','','.account-address-book'),(488957,'furniture-mobile','.account-address-book .address_book h1','padding-top','0','','','.account-address-book'),(488958,'furniture-mobile','.account-address-book .address_book h2','padding-top','15','','','.account-address-book'),(488959,'furniture-mobile','.account-address-book .address_book, .account-address-book .account_history_info','padding-top','10','','','.account-address-book'),(488960,'furniture-mobile','.account-address-book .btn-edit','padding-top','0','4','','.account-address-book'),(488961,'furniture-mobile','.account-address-book .buttonBox','padding-top','15','','','.account-address-book'),(488962,'furniture-mobile','.account-address-book .rightMes ul','padding-top','22','','','.account-address-book'),(488963,'furniture-mobile','.account-address-book .topButtons','padding-top','0','','','.account-address-book'),(488964,'furniture-mobile','.account-order-history .orders-table td, .account-order-history .order-info td, .account-order-history .order_history_table td','padding-top','10','','','.account-order-history'),(488965,'furniture-mobile','.account-order-history .orders-table th','padding-top','2','','','.account-order-history'),(488966,'furniture-mobile','.account-order-history .order_history_table th','padding-top','10','','','.account-order-history'),(488967,'furniture-mobile','.account-order-history .view_link','padding-top','0','','','.account-order-history'),(488968,'furniture-mobile','.account-order-history .orders-table .td-alignright','padding-top','5','2885','','.account-order-history'),(488969,'furniture-mobile','.account-order-history .orders-table td','padding-top','5','2885','','.account-order-history'),(488970,'furniture-mobile','.account-order-history-info .contentColumn','padding-top','10','','','.account-order-history-info'),(488971,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','padding-top','5','','','.account-order-history-info'),(488972,'furniture-mobile','.account-order-history-info .history_attr','padding-top','5','','','.account-order-history-info'),(488973,'furniture-mobile','.account-order-history-info .history_info > div + div','padding-top','0','','','.account-order-history-info'),(488974,'furniture-mobile','.account-order-history-info .popup-tracking-number','padding-top','10','','','.account-order-history-info'),(488975,'furniture-mobile','.account-order-history-info .history_info > div','padding-top','0','2885','','.account-order-history-info'),(488976,'furniture-mobile','.account-order-history-info .history_info > div + div','padding-top','0','2885','','.account-order-history-info'),(488977,'furniture-mobile','.account-index .account_block','padding-top','10','','','.account-index'),(488978,'furniture-mobile','.account-index .account_info','padding-top','0','','','.account-index'),(488979,'furniture-mobile','.account-index .account_info li','padding-top','0','','','.account-index'),(488980,'furniture-mobile','.account-index .account_page','padding-top','10','','','.account-index'),(488981,'furniture-mobile','.account-index .badc_bottom','padding-top','0','','','.account-index'),(488982,'furniture-mobile','.account-index .date_title','padding-top','5','','','.account-index'),(488983,'furniture-mobile','.account-index .orders-table td, .account-index .order-info td, .account-index .order_history_table td','padding-top','10','','','.account-index'),(488984,'furniture-mobile','.account-index .rightMes ul','padding-top','22','','','.account-index'),(488985,'furniture-mobile','.account-index .topAccount','padding-top','24','','','.account-index'),(488986,'furniture-mobile','.account-index .topAccount > li','padding-top','0','','','.account-index'),(488987,'furniture-mobile','.account-index .view_link','padding-top','0','','','.account-index'),(488988,'furniture-mobile','.account-index .account_info','padding-top','0','2885','','.account-index'),(488989,'furniture-mobile','.account-index .orders-table .links','padding-top','5','2885','','.account-index'),(488990,'furniture-mobile','.account-index .orders-table td','padding-top','5','2885','','.account-index'),(488991,'furniture-mobile','.account-index .account_info li','padding-top','0','2876','','.account-index'),(488992,'furniture-mobile','.account-index .topAccount > li','padding-top','0','2876','','.account-index'),(488993,'furniture-mobile','.account-index .topAccount > li > div','padding-top','0','2876','','.account-index'),(488994,'furniture-mobile','.account-order-pay .contentColumn','padding-top','10','','','.account-order-pay'),(488995,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-top','5','','','.account-order-pay'),(488996,'furniture-mobile','.account-order-pay .history_attr','padding-top','5','','','.account-order-pay'),(488997,'furniture-mobile','.account-order-pay .history_info > div + div','padding-top','0','','','.account-order-pay'),(488998,'furniture-mobile','.account-order-pay .history_info > div','padding-top','0','2885','','.account-order-pay'),(488999,'furniture-mobile','.account-order-pay .history_info > div + div','padding-top','0','2885','','.account-order-pay'),(489000,'furniture-mobile','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-top','10','','','.account-samples'),(489001,'furniture-mobile','.account-samples .orders-table th','padding-top','2','','','.account-samples'),(489002,'furniture-mobile','.account-samples .order_history_table th','padding-top','10','','','.account-samples'),(489003,'furniture-mobile','.account-samples .view_link','padding-top','0','','','.account-samples'),(489004,'furniture-mobile','.account-samples .orders-table .td-alignright','padding-top','5','2885','','.account-samples'),(489005,'furniture-mobile','.account-samples .orders-table td','padding-top','5','2885','','.account-samples'),(489006,'furniture-mobile','.account-sample-info .contentColumn','padding-top','10','','','.account-sample-info'),(489007,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-top','5','','','.account-sample-info'),(489008,'furniture-mobile','.account-sample-info .history_attr','padding-top','5','','','.account-sample-info'),(489009,'furniture-mobile','.account-sample-info .history_info > div + div','padding-top','0','','','.account-sample-info'),(489010,'furniture-mobile','.account-sample-info .popup-tracking-number','padding-top','10','','','.account-sample-info'),(489011,'furniture-mobile','.account-sample-info .history_info > div','padding-top','0','2885','','.account-sample-info'),(489012,'furniture-mobile','.account-sample-info .history_info > div + div','padding-top','0','2885','','.account-sample-info'),(489013,'furniture-mobile','.catalog-product-wrap .next-product','padding-top','20','','','.catalog-product-wrap'),(489014,'furniture-mobile','.catalog-product-wrap .pn-direction','padding-top','0','','','.catalog-product-wrap'),(489015,'furniture-mobile','.catalog-product-wrap .pn-image','padding-top','20','','','.catalog-product-wrap'),(489016,'furniture-mobile','.catalog-product-wrap .pn-name','padding-top','15','','','.catalog-product-wrap'),(489017,'furniture-mobile','.catalog-product-wrap .prev-product','padding-top','20','','','.catalog-product-wrap'),(489018,'furniture-mobile','.catalog-product-wrap .next-product','padding-top','20','2885','','.catalog-product-wrap'),(489019,'furniture-mobile','.catalog-product-wrap .pn-direction','padding-top','0','2885','','.catalog-product-wrap'),(489020,'furniture-mobile','.catalog-product-wrap .prev-product','padding-top','20','2885','','.catalog-product-wrap'),(489021,'furniture-mobile','.shopping-cart-index .btn-3','padding-top','11','','','.shopping-cart-index'),(489022,'furniture-mobile','.shopping-cart-index .cart-page .empty','padding-top','100','','','.shopping-cart-index'),(489023,'furniture-mobile','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-top','0','','','.shopping-cart-index'),(489024,'furniture-mobile','.checkout-index-wrap .datepicker-inline','padding-top','10','','','.checkout-index-wrap'),(489025,'furniture-mobile','.checkout-index-wrap .dob-hide label','padding-top','5','','','.checkout-index-wrap'),(489026,'furniture-mobile','.checkout-index-wrap .edit-address-popup','padding-top','20','','','.checkout-index-wrap'),(489027,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-top','7','','','.checkout-index-wrap'),(489028,'furniture-mobile','.checkout-order-confirmation .price-row','padding-top','5','','','.checkout-order-confirmation'),(489029,'furniture-mobile','.checkout-login-wrap .password-forgotten-link','padding-top','0','','','.checkout-login-wrap'),(489030,'furniture-mobile','.checkout-success-wrap .page-success .text-1','padding-top','120','','','.checkout-success-wrap'),(489031,'furniture-mobile','.checkout-success-wrap .page-success .text-1','padding-top','5','2876','','.checkout-success-wrap'),(489032,'furniture-mobile','.b-data-table table.dataTable tbody td','padding-top_important','important','','','.b-data-table'),(489033,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top_important','important','','','.b-data-table'),(489034,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top_important','important','','','.b-data-table'),(489035,'furniture-mobile','.b-data-table table.dataTable thead td','padding-top_important','important','','','.b-data-table'),(489036,'furniture-mobile','.batchPr .w-batch-products','padding-top_important','important','','','.batchPr'),(489037,'furniture-mobile','.w-cart-listing .points','padding-top_important','important','2876','','.w-cart-listing'),(489038,'furniture-mobile','.preFooter .w-banner .single_banner picture','padding-top_important','important','','','.preFooter'),(489039,'furniture-mobile','.w-account-personal-catalog .buy-box','padding-top_important','important','2876','','.w-account-personal-catalog'),(489040,'furniture-mobile','.w-categories .image','padding_bottom_measure','%','','','.w-categories'),(489041,'furniture-mobile','.w-top-categories .image','padding_bottom_measure','%','','','.w-top-categories'),(489042,'furniture-mobile','.mainBanner .bottomBox .btn','padding_bottom_measure','vw','','','.mainBanner'),(489043,'furniture-mobile','.mainBanner .wrapper','padding_bottom_measure','%','2876','','.mainBanner'),(489044,'furniture-mobile','.mainBanner .wrapper','padding_bottom_measure','%','2906','','.mainBanner'),(489045,'furniture-mobile','.b-upload-file .upload-file-template','padding_left_measure','%','','','.b-upload-file'),(489046,'furniture-mobile','.w-cart-give-away .ga_img','padding_left_measure','%','','','.w-cart-give-away'),(489047,'furniture-mobile','.b-product-images .media-popup .mp-content','padding_left_measure','%','','','.b-product-images'),(489048,'furniture-mobile','.w-product-collection .right-area','padding_left_measure','%','','','.w-product-collection'),(489049,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding_left_measure','%','','','.w-delivery-location-featured-list'),(489050,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding_left_measure','%','2906','','.w-delivery-location-featured-list'),(489051,'furniture-mobile','.mainBanner .bottomBox .btn','padding_left_measure','vw','','','.mainBanner'),(489052,'furniture-mobile','.mainBanner .topBox','padding_left_measure','%','','','.mainBanner'),(489053,'furniture-mobile','.mainBanner .wrapper','padding_left_measure','%','','','.mainBanner'),(489054,'furniture-mobile','.mainBanner .topBox','padding_left_measure','%','2890','','.mainBanner'),(489055,'furniture-mobile','.mainBanner .wrapper','padding_left_measure','%','2890','','.mainBanner'),(489056,'furniture-mobile','.mainBanner .topBox','padding_left_measure','%','2876','','.mainBanner'),(489057,'furniture-mobile','.mainBanner .wrapper','padding_left_measure','%','2876','','.mainBanner'),(489058,'furniture-mobile','.mainBanner .wrapper','padding_left_measure','%','2906','','.mainBanner'),(489059,'furniture-mobile','.account-order-history-info .history_info > div + div','padding_left_measure','%','','','.account-order-history-info'),(489060,'furniture-mobile','.account-index .topAccount > li','padding_left_measure','%','','','.account-index'),(489061,'furniture-mobile','.account-order-pay .history_info > div + div','padding_left_measure','%','','','.account-order-pay'),(489062,'furniture-mobile','.account-sample-info .history_info > div + div','padding_left_measure','%','','','.account-sample-info'),(489063,'furniture-mobile','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(489064,'furniture-mobile','.b-upload-file .upload-file-template','padding_right_measure','%','','','.b-upload-file'),(489065,'furniture-mobile','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(489066,'furniture-mobile','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(489067,'furniture-mobile','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(489068,'furniture-mobile','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(489069,'furniture-mobile','.w-cart-give-away .ga_img','padding_right_measure','%','','','.w-cart-give-away'),(489070,'furniture-mobile','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(489071,'furniture-mobile','.b-product-images .media-popup .mp-content','padding_right_measure','%','','','.b-product-images'),(489072,'furniture-mobile','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(489073,'furniture-mobile','.w-product-in-bundles .attributes-item','padding_right_measure','%','','','.w-product-in-bundles'),(489074,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding_right_measure','%','','','.w-delivery-location-featured-list'),(489075,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding_right_measure','%','2906','','.w-delivery-location-featured-list'),(489076,'furniture-mobile','.mainBanner .bottomBox .btn','padding_right_measure','vw','','','.mainBanner'),(489077,'furniture-mobile','.mainBanner .wrapper','padding_right_measure','%','','','.mainBanner'),(489078,'furniture-mobile','.mainBanner .wrapper','padding_right_measure','%','2890','','.mainBanner'),(489079,'furniture-mobile','.mainBanner .topBox','padding_right_measure','%','2876','','.mainBanner'),(489080,'furniture-mobile','.mainBanner .wrapper','padding_right_measure','%','2876','','.mainBanner'),(489081,'furniture-mobile','.mainBanner .wrapper','padding_right_measure','%','2906','','.mainBanner'),(489082,'furniture-mobile','.account-index .topAccount > li','padding_right_measure','%','','','.account-index'),(489083,'furniture-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding_top_measure','%','2890','','.w-wedding-registry-widgets-manage-banner'),(489084,'furniture-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','padding_top_measure','%','','','.w-wedding-registry-widgets-manage-banner'),(489085,'furniture-mobile','.price .old','padding_top_measure','em','','',''),(489086,'furniture-mobile','.mainBanner .bottomBox .btn','padding_top_measure','vw','','','.mainBanner'),(489087,'furniture-mobile','.mainBanner .topBox','padding_top_measure','%','','','.mainBanner'),(489088,'furniture-mobile','.mainBanner .content','padding_top_measure','%','2876','','.mainBanner'),(489089,'furniture-mobile','.mainBanner .wrapper','padding_top_measure','%','2876','','.mainBanner'),(489090,'furniture-mobile','.mainBanner .content','padding_top_measure','%','2906','','.mainBanner'),(489091,'furniture-mobile','.mainBanner .wrapper','padding_top_measure','%','2906','','.mainBanner'),(489092,'furniture-mobile','.b-slick .slick-slide.dragging img','pointer-events','none','','','.b-slick'),(489093,'furniture-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(489094,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item label','position','relative','','','.w-checkout-shipping-address'),(489095,'furniture-mobile','.b-form .radio-buttons .radio-button','position','relative','','','.b-form'),(489096,'furniture-mobile','.w-checkout-billing-address .addresses .address-item label','position','relative','','','.w-checkout-billing-address'),(489097,'furniture-mobile','.b-info .info','position','relative','3','','.b-info'),(489098,'furniture-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position','absolute','','','.b-switch'),(489099,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','position','relative','3','','.b-switch'),(489100,'furniture-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(489101,'furniture-mobile','.p-reviews-info .review-info-text','position','relative','','','.p-reviews-info'),(489102,'furniture-mobile','.p-reviews-info .review-info-text','position','absolute','4','','.p-reviews-info'),(489103,'furniture-mobile','.b-fancybox .filter-listing-preloader','position','absolute','','','.b-fancybox'),(489104,'furniture-mobile','.b-fancybox .filter-listing-loader','position','absolute','','','.b-fancybox'),(489105,'furniture-mobile','.w-promotions .prom-multi-discount > .heading','position','relative','3','','.w-promotions'),(489106,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','position','relative','','','.w-promotions'),(489107,'furniture-mobile','.w-promotions .promo-date','position','relative','','','.w-promotions'),(489108,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','position','static','','','.w-menu'),(489109,'furniture-mobile','.w-account .account-dropdown','position','absolute','','','.w-account'),(489110,'furniture-mobile','.w-account .account-top','position','relative','','','.w-account'),(489111,'furniture-mobile','.w-account .my-acc-link','position','relative','','','.w-account'),(489112,'furniture-mobile','.p-wedding-registry-view h1','position','relative','4','','.p-wedding-registry-view'),(489113,'furniture-mobile','.p-wedding-registry-view h1','position','relative','3','','.p-wedding-registry-view'),(489114,'furniture-mobile','.w-wedding-registry-widgets-delete-link a','position','relative','','','.w-wedding-registry-widgets-delete-link'),(489115,'furniture-mobile','.w-wedding-registry-widgets-share-link a','position','absolute','4','','.w-wedding-registry-widgets-share-link'),(489116,'furniture-mobile','.w-wedding-registry-widgets-share-link a','position','relative','','','.w-wedding-registry-widgets-share-link'),(489117,'furniture-mobile','.w-wedding-registry-widgets-products .remove','position','absolute','','','.w-wedding-registry-widgets-products'),(489118,'furniture-mobile','.p-sample-checkout-success .page-success > div','position','relative','','','.p-sample-checkout-success'),(489119,'furniture-mobile','.p-reviews-info .review-info-text','position','absolute','4','','.p-reviews-info'),(489120,'furniture-mobile','.p-reviews-info .review-info-text','position','relative','','','.p-reviews-info'),(489121,'furniture-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(489122,'furniture-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(489123,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(489124,'furniture-mobile','.testimonials .reviews-list span','position','relative','','',''),(489125,'furniture-mobile','.testimonials .heading-3','position','relative','','',''),(489126,'furniture-mobile','.testimonials .review','position','absolute','3','',''),(489127,'furniture-mobile','.testimonials .review','position','relative','','',''),(489128,'furniture-mobile','.testimonials .rating','position','relative','','',''),(489129,'furniture-mobile','.testimonials .heading-3','position','absolute','3','',''),(489130,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(489131,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','position','absolute','','','.w-compare-box-item'),(489132,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span','position','relative','','','.w-compare-box-item'),(489133,'furniture-mobile','.w-compare-box-item .checkbox:not(checked)','position','absolute','','','.w-compare-box-item'),(489134,'furniture-mobile','.w-promotions .prom-multi-discount .products','position','relative','','','.w-promotions'),(489135,'furniture-mobile','.w-promotions .icon','position','relative','','','.w-promotions'),(489136,'furniture-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','position','relative','3','','.w-promotions'),(489137,'furniture-mobile','.w-promotions .promo-salemaker .discount','position','relative','','','.w-promotions'),(489138,'furniture-mobile','.w-promotions .promo-cart-discount .slave .content','position','relative','','','.w-promotions'),(489139,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','position','relative','','','.w-promotions'),(489140,'furniture-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','position','relative','3','','.w-promotions'),(489141,'furniture-mobile','.b-preloader .preloader','position','absolute','3','','.b-preloader'),(489142,'furniture-mobile','.b-preloader .preloader','position','absolute','','','.b-preloader'),(489143,'furniture-mobile','.w-compare-box-item .checkbox:not(checked)','position','absolute','','','.w-compare-box-item'),(489144,'furniture-mobile','.w-checkout-create-account .account-benefits strong','position','relative','3','','.w-checkout-create-account'),(489145,'furniture-mobile','.w-cart-compare .cart-cell > div','position','relative','','','.w-cart-compare'),(489146,'furniture-mobile','.p-wedding-registry-view h1','position','relative','3','','.p-wedding-registry-view'),(489147,'furniture-mobile','.p-reviews-info .review-info-text','position','relative','','','.p-reviews-info'),(489148,'furniture-mobile','.w-menu .menu .menu-ico','position','relative','','','.w-menu'),(489149,'furniture-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(489150,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(489151,'furniture-mobile','.closeable-heading','position','absolute','3','',''),(489152,'furniture-mobile','.closeable-heading','position','relative','','',''),(489153,'furniture-mobile','.b-messages .messBtnMenuDelete','position','relative','3','','.b-messages'),(489154,'furniture-mobile','.b-messages .messMenuButton span','position','relative','','','.b-messages'),(489155,'furniture-mobile','.b-messages .messBtnMenuStarred','position','relative','3','','.b-messages'),(489156,'furniture-mobile','.b-messages span.starred::before','position','relative','','','.b-messages'),(489157,'furniture-mobile','.b-messages .messBtnMenuUnread','position','relative','3','','.b-messages'),(489158,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-messages'),(489159,'furniture-mobile','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(489160,'furniture-mobile','.b-info-popup .info-popup div','position','absolute','3','','.b-info-popup'),(489161,'furniture-mobile','.p-reviews-info .review-info-text','position','absolute','4','','.p-reviews-info'),(489162,'furniture-mobile','.b-info .info','position','relative','','','.b-info'),(489163,'furniture-mobile','.p-payer-order-confirmation .order-ico','position','relative','3','','.p-payer-order-confirmation'),(489164,'furniture-mobile','.p-payer-order-confirmation .comment-ico','position','relative','3','','.p-payer-order-confirmation'),(489165,'furniture-mobile','.p-payer-order-confirmation .discount-ico','position','relative','3','','.p-payer-order-confirmation'),(489166,'furniture-mobile','.p-payer-order-pay .order-ico','position','relative','3','','.p-payer-order-pay'),(489167,'furniture-mobile','.w-checkout-terms .terms-box','position','relative','','','.w-checkout-terms'),(489168,'furniture-mobile','.p-payer-order-pay .discount-ico','position','relative','3','','.p-payer-order-pay'),(489169,'furniture-mobile','.p-payer-order-pay .comment-ico','position','relative','3','','.p-payer-order-pay'),(489170,'furniture-mobile','.w-checkout-terms .required-message-wrap','position','static','','','.w-checkout-terms'),(489171,'furniture-mobile','.w-checkout-terms input[type=\"checkbox\"]','position','relative','','','.w-checkout-terms'),(489172,'furniture-mobile','.p-blog-index .author .avatar','position','relative','','','.p-blog-index'),(489173,'furniture-mobile','.w-checkout-shipping-address .genders-title input','position','relative','','','.w-checkout-shipping-address'),(489174,'furniture-mobile','.b-fancybox #fancybox-loading','position','fixed','','','.b-fancybox'),(489175,'furniture-mobile','.b-form .radio-button input[type=\"radio\"]','position','relative','','','.b-form'),(489176,'furniture-mobile','.b-fancybox .fancybox-wrap','position','absolute','','','.b-fancybox'),(489177,'furniture-mobile','.b-upload-file .snapshot','position','absolute','','','.b-upload-file'),(489178,'furniture-mobile','.w-menu-style-1 ul ul','position','absolute','','','.w-menu-style-1'),(489179,'furniture-mobile','.w-menu-slider .close','position','absolute','','','.w-menu-slider'),(489180,'furniture-mobile','.w-cart .cart-box.hover-box .cart-content','position','absolute','','','.w-cart'),(489181,'furniture-mobile','.b-rating .glyphicon','position','relative','','','.b-rating'),(489182,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','position','absolute','','','.w-checkout-shipping-choice'),(489183,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(489184,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(489185,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(489186,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(489187,'furniture-mobile','.b-switch .bootstrap-switch','position','relative','','','.b-switch'),(489189,'furniture-mobile','.b-info .info','position','relative','','','.b-info'),(489190,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span','position','relative','','','.w-compare-box-item'),(489191,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(489192,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(489193,'furniture-mobile','.w-coupons-and-vauchers-checkout .btn-remove','position','relative','','','.w-coupons-and-vauchers-checkout'),(489194,'furniture-mobile','.b-products-listing .products-listing .radio-attributes input','position','relative','','','.b-products-listing'),(489195,'furniture-mobile','.w-checkout-bonus-points .btn-remove','position','relative','','','.w-checkout-bonus-points'),(489196,'furniture-mobile','.b-products-listing .products-listing .btn-buy','position','relative','3','','.b-products-listing'),(489197,'furniture-mobile','.b-form .col-3','position','relative','','','.b-form'),(489198,'furniture-mobile','.w-menu .hided.menu','position','relative','','','.w-menu'),(489199,'furniture-mobile','.w-menu .hided.menu > ul','position','absolute','','','.w-menu'),(489200,'furniture-mobile','.w-menu-horizontal li','position','relative','','','.w-menu-horizontal'),(489201,'furniture-mobile','.w-menu-slider > ul','position','relative','','','.w-menu-slider'),(489202,'furniture-mobile','.w-menu-slider > ul > li > ul','position','absolute','','','.w-menu-slider'),(489203,'furniture-mobile','.w-menu-slider .close','position','absolute','','','.w-menu-slider'),(489205,'furniture-mobile','.b-info .info','position','relative','','','.b-info'),(489206,'furniture-mobile','.b-form .billing-address','position','relative','','','.b-form'),(489207,'furniture-mobile','.w-quote .cart-box-link','position','relative','','','.w-quote'),(489208,'furniture-mobile','.b-form .form-buttons','position','relative','','','.b-form'),(489209,'furniture-mobile','.w-sale .badge','position','absolute','','','.w-sale'),(489210,'furniture-mobile','.b-fancybox .fancybox-title-over-wrap','position','absolute','','','.b-fancybox'),(489211,'furniture-mobile','.b-fancybox .fancybox-title-outside-wrap','position','relative','','','.b-fancybox'),(489212,'furniture-mobile','.w-menu .hided.menu','position','relative','','','.w-menu'),(489213,'furniture-mobile','.w-wedding-registry-widgets-manage-banner .wedding-image','position','relative','','','.w-wedding-registry-widgets-manage-banner'),(489214,'furniture-mobile','.w-menu .hided.menu ul li','position','static','','','.w-menu'),(489215,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','position','absolute','','','.b-switch'),(489216,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(489217,'furniture-mobile','.w-menu-slider > ul > li > ul','position','absolute','','','.w-menu-slider'),(489218,'furniture-mobile','.w-menu .hided.menu > ul','position','absolute','','','.w-menu'),(489219,'furniture-mobile','.w-menu-style-1 li','position','relative','','','.w-menu-style-1'),(489220,'furniture-mobile','.w-menu .hided.menu ul li','position','static','','','.w-menu'),(489221,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','position','static','','','.w-menu'),(489222,'furniture-mobile','.w-menu .hided.menu > ul','position','absolute','','','.w-menu'),(489223,'furniture-mobile','.w-languages .languages','position','relative','','','.w-languages'),(489224,'furniture-mobile','.w-cart-compare .atr-col','position','relative','','','.w-cart-compare'),(489225,'furniture-mobile','.w-sale .badge','position','absolute','','','.w-sale'),(489226,'furniture-mobile','.w-sale .sale-holder','position','relative','','','.w-sale'),(489227,'furniture-mobile','.w-menu .hided.menu','position','relative','','','.w-menu'),(489228,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','position','relative','','','.b-switch'),(489229,'furniture-mobile','.b-switch .candlestick-wrapper','position','relative','','','.b-switch'),(489230,'furniture-mobile','.p-blog-index .author .avatar','position','relative','','','.p-blog-index'),(489231,'furniture-mobile','.b-bottom .footerTitle','position','absolute','2876,4','','.b-bottom'),(489232,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(489233,'furniture-mobile','.b-select-suggest .select2-measure-scrollbar','position','absolute','','','.b-select-suggest'),(489234,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position','absolute','','','.b-select-suggest'),(489235,'furniture-mobile','.w-menu .menu .menu-ico','position','relative','','','.w-menu'),(489236,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(489237,'furniture-mobile','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(489238,'furniture-mobile','.w-reviews .review','position','relative','','','.w-reviews'),(489239,'furniture-mobile','.w-reviews .heading-3','position','relative','','','.w-reviews'),(489240,'furniture-mobile','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(489241,'furniture-mobile','.w-search .button-search','position','absolute','','','.w-search'),(489242,'furniture-mobile','.b-info-popup .info-popup div','position','absolute','','','.b-info-popup'),(489243,'furniture-mobile','.bell-ico .heading-2','position','relative','3','','.bell-ico'),(489244,'furniture-mobile','.w-menu .hided.menu > ul','position','absolute','','','.w-menu'),(489245,'furniture-mobile','.w-sale .sale-holder','position','relative','','','.w-sale'),(489246,'furniture-mobile','.w-menu .hided.menu','position','relative','','','.w-menu'),(489247,'furniture-mobile','.b-select-suggest .select2-search-choice-close','position','absolute','','','.b-select-suggest'),(489248,'furniture-mobile','.view-all','position','absolute','3','',''),(489249,'furniture-mobile','.view-all','position','relative','','',''),(489250,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(489251,'furniture-mobile','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(489252,'furniture-mobile','.view-all .btn','position','relative','','',''),(489253,'furniture-mobile','.w-sale .badge','position','absolute','','','.w-sale'),(489254,'furniture-mobile','.w-menu-style-1 li','position','relative','','','.w-menu-style-1'),(489255,'furniture-mobile','.w-menu-style-1 ul ul','position','absolute','','','.w-menu-style-1'),(489256,'furniture-mobile','.w-text .customer-service','position','relative','','','.w-text'),(489257,'furniture-mobile','.w-text .customer-service','position','absolute','3','','.w-text'),(489258,'furniture-mobile','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(489259,'furniture-mobile','.w-search .search','position','relative','','','.w-search'),(489260,'furniture-mobile','.b-form .checkbox-style','position','absolute','','','.b-form'),(489261,'furniture-mobile','.heading-saved-lists .heading-4','position','relative','3','','.heading-saved-lists'),(489262,'furniture-mobile','.edit-link','position','relative','','',''),(489263,'furniture-mobile','.message.success','position','relative','3','',''),(489264,'furniture-mobile','.w-text .customer-service','position','relative','','','.w-text'),(489265,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(489266,'furniture-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(489267,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(489268,'furniture-mobile','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(489269,'furniture-mobile','.w-wedding-registry-widgets-delete-link a','position','absolute','4','','.w-wedding-registry-widgets-delete-link'),(489270,'furniture-mobile','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(489271,'furniture-mobile','.p-reviews-info .review-info-text','position','relative','','','.p-reviews-info'),(489272,'furniture-mobile','.w-menu-slider > ul','position','relative','','','.w-menu-slider'),(489273,'furniture-mobile','.w-menu-slider .close','position','absolute','','','.w-menu-slider'),(489274,'furniture-mobile','.b-upload-file .upload-remove','position','absolute','','','.b-upload-file'),(489275,'furniture-mobile','.w-menu .hided.menu > ul','position','absolute','','','.w-menu'),(489277,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','position','absolute','','','.b-switch'),(489278,'furniture-mobile','.b-info .info','position','relative','3','','.b-info'),(489279,'furniture-mobile','.w-text .customer-service','position','absolute','3','','.w-text'),(489280,'furniture-mobile','.w-cart-bonus-points .btn-remove','position','relative','','','.w-cart-bonus-points'),(489281,'furniture-mobile','.savings-ico .heading-2','position','relative','3','','.savings-ico'),(489282,'furniture-mobile','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(489283,'furniture-mobile','.w-multi-cart-actions .cart-actions','position','relative','','','.w-multi-cart-actions'),(489284,'furniture-mobile','.w-reviews .review','position','absolute','3','','.w-reviews'),(489285,'furniture-mobile','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(489286,'furniture-mobile','.w-text .customer-service','position','absolute','3','','.w-text'),(489287,'furniture-mobile','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(489288,'furniture-mobile','.b-form .addresses .address-item input[type=\"radio\"]','position','relative','','','.b-form'),(489289,'furniture-mobile','.w-sale .sale-holder','position','relative','','','.w-sale'),(489290,'furniture-mobile','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(489291,'furniture-mobile','.w-product-reviews .reviews-list .review','position','relative','','','.w-product-reviews'),(489292,'furniture-mobile','.b-fancybox .fancybox-skin','position','relative','','','.b-fancybox'),(489293,'furniture-mobile','.b-fancybox .fancybox-overlay-fixed','position','fixed','','','.b-fancybox'),(489294,'furniture-mobile','.b-fancybox .fancybox-overlay','position','absolute','','','.b-fancybox'),(489295,'furniture-mobile','.w-sale .sale-holder','position','relative','','','.w-sale'),(489296,'furniture-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(489297,'furniture-mobile','.w-account-address-book .heading-4','position','relative','','','.w-account-address-book'),(489298,'furniture-mobile','.heading-ordered-items .heading-4','position','relative','3','','.heading-ordered-items'),(489299,'furniture-mobile','.b-pass-strength .pass-strength span','position','absolute','','','.b-pass-strength'),(489300,'furniture-mobile','.w-text .customer-service','position','relative','','','.w-text'),(489301,'furniture-mobile','.b-fancybox .fancybox-nav','position','absolute','','','.b-fancybox'),(489302,'furniture-mobile','.b-info .info','position','relative','3','','.b-info'),(489303,'furniture-mobile','.p-wedding-registry-view h1','position','relative','3','','.p-wedding-registry-view'),(489304,'furniture-mobile','.p-wedding-registry-view h1','position','relative','4','','.p-wedding-registry-view'),(489305,'furniture-mobile','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(489306,'furniture-mobile','.w-promo-code .holder','position','relative','','','.w-promo-code'),(489307,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(489308,'furniture-mobile','.b-form .shipping-method .input input','position','relative','','','.b-form'),(489309,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','position','relative','','','.w-wedding-registry-widgets-photos'),(489310,'furniture-mobile','.w-reviews .heading-3','position','absolute','3','','.w-reviews'),(489311,'furniture-mobile','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(489312,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','position','relative','','','.b-select-suggest'),(489313,'furniture-mobile','.b-select-suggest .select2-container','position','relative','','','.b-select-suggest'),(489314,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span','position','relative','','','.w-compare-box-item'),(489317,'furniture-mobile','.w-banner .carousel-text','position','absolute','','','.w-banner'),(489318,'furniture-mobile','.w-banner .image-text-banner','position','relative','','','.w-banner'),(489319,'furniture-mobile','.w-banner .image-text-banner .text-banner','position','absolute','','','.w-banner'),(489320,'furniture-mobile','.b-info .info','position','relative','3','','.b-info'),(489321,'furniture-mobile','.b-info .info','position','relative','','','.b-info'),(489322,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','position','relative','3','','.b-switch'),(489323,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','position','relative','3','','.b-switch'),(489324,'furniture-mobile','.w-languages .select','position','absolute','','','.w-languages'),(489325,'furniture-mobile','.w-menu-style-1 ul ul','position','absolute','','','.w-menu-style-1'),(489326,'furniture-mobile','.w-menu-style-1 li','position','relative','','','.w-menu-style-1'),(489327,'furniture-mobile','.p-reviews-info .review-info-text','position','relative','','','.p-reviews-info'),(489328,'furniture-mobile','.b-form .hide-billing-address','position','absolute','','','.b-form'),(489329,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no','position','absolute','','','.b-form'),(489330,'furniture-mobile','.b-form .payment-method .item-radio input','position','relative','','','.b-form'),(489331,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span','position','relative','','','.w-compare-box-item'),(489332,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(489333,'furniture-mobile','.w-compare-box-item .checkbox:not(checked)','position','absolute','','','.w-compare-box-item'),(489334,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','position','absolute','','','.w-compare-box-item'),(489335,'furniture-mobile','.w-compare-box-item .checkbox:not(checked)','position','absolute','','','.w-compare-box-item'),(489336,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(489337,'furniture-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(489338,'furniture-mobile','.p-reviews-info .review-info-text','position','relative','','','.p-reviews-info'),(489339,'furniture-mobile','.w-reviews-content .review','position','absolute','3','','.w-reviews-content'),(489340,'furniture-mobile','.w-menu-style-1 ul ul','position','absolute','','','.w-menu-style-1'),(489341,'furniture-mobile','.w-menu .hided.menu ul li','position','static','','','.w-menu'),(489342,'furniture-mobile','.w-menu-slider .close','position','absolute','','','.w-menu-slider'),(489343,'furniture-mobile','.w-menu-slider > ul > li > ul','position','absolute','','','.w-menu-slider'),(489344,'furniture-mobile','.p-quick-order-index .all-scroll-div','position','fixed','','','.p-quick-order-index'),(489345,'furniture-mobile','.p-reviews-info .review-info-text','position','absolute','4','','.p-reviews-info'),(489346,'furniture-mobile','.w-checkout-billing-address .genders-title input','position','relative','','','.w-checkout-billing-address'),(489347,'furniture-mobile','.b-form .required-message-wrap','position','relative','','','.b-form'),(489348,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','position','relative','3','','.b-form'),(489349,'furniture-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(489350,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(489351,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition','position','relative','','','.w-promotions'),(489352,'furniture-mobile','.w-sale .sale-holder','position','relative','','','.w-sale'),(489353,'furniture-mobile','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(489354,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(489355,'furniture-mobile','.w-menu .menu .menu-ico','position','relative','','','.w-menu'),(489356,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(489357,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','position','absolute','','','.w-compare-box-item'),(489358,'furniture-mobile','.w-account-address-book .btn-del','position','absolute','','','.w-account-address-book'),(489359,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(489360,'furniture-mobile','.w-checkout-credit-amount .btn-remove','position','relative','','','.w-checkout-credit-amount'),(489361,'furniture-mobile','.w-menu-slider .close','position','absolute','','','.w-menu-slider'),(489362,'furniture-mobile','.w-languages .current','position','absolute','3','','.w-languages'),(489363,'furniture-mobile','.w-promo-code .holder','position','relative','','','.w-promo-code'),(489364,'furniture-mobile','.b-info-popup .info-popup','position','relative','3','','.b-info-popup'),(489365,'furniture-mobile','.b-autocomplete .ui-autocomplete','position','absolute','','','.b-autocomplete'),(489366,'furniture-mobile','.p-blog-index .author .avatar','position','relative','','','.p-blog-index'),(489368,'furniture-mobile','.b-info .info','position','relative','','','.b-info'),(489369,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(489370,'furniture-mobile','.b-bottom .footerTitle','position','relative','2876','','.b-bottom'),(489371,'furniture-mobile','.b-info-popup .info-popup','position','relative','','','.b-info-popup'),(489372,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','position','relative','','','.w-wedding-registry-widgets-photos'),(489373,'furniture-mobile','.b-upload-files .attach-active-holder .attach-file','position','absolute','','','.b-upload-files'),(489374,'furniture-mobile','.w-menu-slider > ul','position','relative','','','.w-menu-slider'),(489375,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','position','static','','','.w-menu'),(489376,'furniture-mobile','.w-cart-credit-amount .btn-remove','position','relative','','','.w-cart-credit-amount'),(489377,'furniture-mobile','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(489378,'furniture-mobile','.w-sale .badge','position','absolute','','','.w-sale'),(489379,'furniture-mobile','.b-fancybox .fancybox-close','position','absolute','','','.b-fancybox'),(489380,'furniture-mobile','.b-form .required-message','position','absolute','','','.b-form'),(489381,'furniture-mobile','.b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner','position','relative','','','.b-fancybox'),(489382,'furniture-mobile','.w-product-customers-activity .customers-activity','position','fixed','','','.w-product-customers-activity'),(489383,'furniture-mobile','.w-product-customers-activity .close','position','absolute','','','.w-product-customers-activity'),(489384,'furniture-mobile','.w-menu .hided.menu > ul','position','absolute','','','.w-menu'),(489385,'furniture-mobile','.w-text .customer-service','position','absolute','3','','.w-text'),(489386,'furniture-mobile','.p-wedding-registry-view h1','position','relative','4','','.p-wedding-registry-view'),(489387,'furniture-mobile','.w-cart-compare .remove-cart','position','absolute','','','.w-cart-compare'),(489388,'furniture-mobile','.w-compare-box-item .checkbox:not(checked)','position','absolute','','','.w-compare-box-item'),(489389,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','position','absolute','','','.w-compare-box-item'),(489390,'furniture-mobile','.w-promo-code .holder','position','relative','','','.w-promo-code'),(489391,'furniture-mobile','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(489392,'furniture-mobile','.w-menu .menu .menu-ico','position','relative','','','.w-menu'),(489393,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(489394,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span','position','relative','','','.w-compare-box-item'),(489395,'furniture-mobile','.w-checkout-billing-address .addresses .address-item label input','position','absolute','','','.w-checkout-billing-address'),(489396,'furniture-mobile','.w-checkout-shipping-choice input:checked + span','position','relative','','','.w-checkout-shipping-choice'),(489397,'furniture-mobile','.w-checkout-shipping-choice input','position','absolute','','','.w-checkout-shipping-choice'),(489398,'furniture-mobile','.w-text .customer-service','position','absolute','3','','.w-text'),(489399,'furniture-mobile','.w-quote .cart-box','position','relative','','','.w-quote'),(489400,'furniture-mobile','.w-product-reviews .reviews-list span','position','relative','','','.w-product-reviews'),(489401,'furniture-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(489402,'furniture-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(489403,'furniture-mobile','.p-blog-index .author .avatar','position','relative','','','.p-blog-index'),(489404,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-select-suggest'),(489405,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices','position','relative','','','.b-select-suggest'),(489406,'furniture-mobile','.b-select-suggest .select2-results','position','relative','','','.b-select-suggest'),(489407,'furniture-mobile','.w-image-maps .svg-wrap svg','position','absolute','','','.w-image-maps'),(489408,'furniture-mobile','.w-menu-slider .close','position','absolute','','','.w-menu-slider'),(489409,'furniture-mobile','.w-menu-slider > ul > li > ul','position','absolute','','','.w-menu-slider'),(489410,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item label input','position','absolute','','','.w-checkout-shipping-address'),(489411,'furniture-mobile','.w-neighbour-checkout .bootstrap-switch','position','relative','','','.w-neighbour-checkout'),(489412,'furniture-mobile','.b-select-suggest .select2-search','position','relative','','','.b-select-suggest'),(489413,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','position','absolute','','','.b-select-suggest'),(489414,'furniture-mobile','.b-select-suggest .select2-drop','position','absolute','','','.b-select-suggest'),(489415,'furniture-mobile','.b-select-suggest .select2-drop-mask','position','fixed','','','.b-select-suggest'),(489416,'furniture-mobile','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(489417,'furniture-mobile','.w-menu .hided.menu ul li','position','static','','','.w-menu'),(489418,'furniture-mobile','.w-text .customer-service','position','relative','','','.w-text'),(489419,'furniture-mobile','.w-menu .menu .menu-ico','position','relative','','','.w-menu'),(489420,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','position','static','','','.w-menu'),(489421,'furniture-mobile','.w-menu .hided.menu ul li','position','static','','','.w-menu'),(489422,'furniture-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(489423,'furniture-mobile','.heading-settings .heading-4','position','relative','3','','.heading-settings'),(489424,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','position','absolute','','','.b-switch'),(489425,'furniture-mobile','.b-pass-strength .pass-strength','position','relative','','','.b-pass-strength'),(489426,'furniture-mobile','.p-wedding-registry-view h1','position','relative','3','','.p-wedding-registry-view'),(489427,'furniture-mobile','.p-sample-checkout-success .page-success','position','relative','','','.p-sample-checkout-success'),(489428,'furniture-mobile','.w-menu-big li','position','static','','','.w-menu-big'),(489429,'furniture-mobile','.w-menu-style-1 li','position','relative','','','.w-menu-style-1'),(489430,'furniture-mobile','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(489431,'furniture-mobile','.w-promo-code .holder','position','relative','','','.w-promo-code'),(489432,'furniture-mobile','.w-compare-box-item .checkbox:not(checked)','position','absolute','','','.w-compare-box-item'),(489433,'furniture-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','position','relative','','','.w-account-addresses-list'),(489434,'furniture-mobile','.b-products-listing .products-listing .promos-info','position','absolute','','','.b-products-listing'),(489435,'furniture-mobile','.b-products-listing .products-listing .image','position','relative','','','.b-products-listing'),(489436,'furniture-mobile','.b-products-listing .hover-box-content','position','absolute','3','','.b-products-listing'),(489437,'furniture-mobile','.b-products-listing .hover-box','position','relative','','','.b-products-listing'),(489438,'furniture-mobile','.b-products-listing .hover-box-content','position','absolute','','','.b-products-listing'),(489439,'furniture-mobile','.b-products-listing .loader','position','absolute','4','','.b-products-listing'),(489440,'furniture-mobile','.b-products-listing .loader','position','absolute','3','','.b-products-listing'),(489441,'furniture-mobile','.b-products-listing .loader','position','relative','','','.b-products-listing'),(489442,'furniture-mobile','.w-catalog-b2b-add-button ','position','fixed','','','.w-catalog-b2b-add-button'),(489443,'furniture-mobile','.b-products-listing .products-listing .qty-input.hidden','position','absolute','3','','.b-products-listing'),(489444,'furniture-mobile','.b-products-listing .promo','position','absolute','','','.b-products-listing'),(489445,'furniture-mobile','.b-products-listing .promo-icon','position','relative','','','.b-products-listing'),(489446,'furniture-mobile','.b-products-listing .promos-info','position','relative','','','.b-products-listing'),(489447,'furniture-mobile','.checkbox input:not(checked) + span:before','position','absolute','','',''),(489448,'furniture-mobile','.w-blog-widget-post-share ','position','absolute','4','','.w-blog-widget-post-share'),(489449,'furniture-mobile','.w-blog-widget-post-share ','position','relative','','','.w-blog-widget-post-share'),(489450,'furniture-mobile','.w-blog-widget-post-listing .post_comment','position','relative','','','.w-blog-widget-post-listing'),(489451,'furniture-mobile','.w-blog-widget-post-listing .post_comment','position','absolute','3','','.w-blog-widget-post-listing'),(489452,'furniture-mobile','.w-blog-widget-post-linked-products .heading-2','position','relative','','','.w-blog-widget-post-linked-products'),(489453,'furniture-mobile','.w-blog-widget-most-popular-posts a','position','relative','','','.w-blog-widget-most-popular-posts'),(489454,'furniture-mobile','.w-blog-widget-post-comments-count span','position','absolute','3','','.w-blog-widget-post-comments-count'),(489455,'furniture-mobile','.w-blog-widget-post-comments-count span','position','relative','','','.w-blog-widget-post-comments-count'),(489456,'furniture-mobile','.w-blog-widget-most-popular-posts a','position','absolute','3','','.w-blog-widget-most-popular-posts'),(489457,'furniture-mobile','.w-blog-widget-categories-list a','position','absolute','3','','.w-blog-widget-categories-list'),(489458,'furniture-mobile','.w-blog-widget-categories-list a','position','relative','','','.w-blog-widget-categories-list'),(489459,'furniture-mobile','.checkbox input','position','ablolute','','',''),(489460,'furniture-mobile','.w-currencies .select','position','absolute','','','.w-currencies'),(489461,'furniture-mobile','.w-currencies .current','position','relative','','','.w-currencies'),(489462,'furniture-mobile','.w-currencies .current','position','absolute','3','','.w-currencies'),(489463,'furniture-mobile','.w-currencies .currencies','position','relative','','','.w-currencies'),(489464,'furniture-mobile','.w-promo-code .holder','position','relative','','','.w-promo-code'),(489465,'furniture-mobile','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(489466,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','position','absolute','','','.w-compare-box-item'),(489467,'furniture-mobile','.b-form .hide-box','position','relative','','','.b-form'),(489468,'furniture-mobile','.b-info .info','position','relative','','','.b-info'),(489469,'furniture-mobile','.b-fancybox .fancybox-title','position','relative','','','.b-fancybox'),(489470,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap','position','absolute','','','.b-fancybox'),(489471,'furniture-mobile','.w-personal-gift-status-bar .end-date','position','relative','3','','.w-personal-gift-status-bar'),(489472,'furniture-mobile','.w-text .customer-service','position','relative','','','.w-text'),(489473,'furniture-mobile','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(489474,'furniture-mobile','.w-menu-style-1 li','position','relative','','','.w-menu-style-1'),(489475,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','position','static','','','.w-catalog-paging'),(489476,'furniture-mobile','.p-wedding-registry-view h1','position','relative','4','','.p-wedding-registry-view'),(489477,'furniture-mobile','.w-taxable input[type=\"radio\"]','position','relative','','','.w-taxable'),(489478,'furniture-mobile','.b-form .eye-password-wrap','position','relative','','','.b-form'),(489479,'furniture-mobile','.b-form .eye-password','position','absolute','','','.b-form'),(489480,'furniture-mobile','.w-taxable input[type=\"checkbox\"]','position','relative','','','.w-taxable'),(489481,'furniture-mobile','.b-info .info','position','relative','3','','.b-info'),(489482,'furniture-mobile','.b-fancybox .fancybox-tmp','position','absolute','','','.b-fancybox'),(489483,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(489484,'furniture-mobile','.b-datepicker .datepicker-dropdown','position','absolute','','','.b-datepicker'),(489485,'furniture-mobile','.w-text .customer-service','position','absolute','3','','.w-text'),(489486,'furniture-mobile','.w-text .customer-service','position','relative','','','.w-text'),(489487,'furniture-mobile','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(489488,'furniture-mobile','.p-reviews-info .review-info-text','position','absolute','4','','.p-reviews-info'),(489489,'furniture-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(489490,'furniture-mobile','.w-menu-slider > ul > li > ul','position','absolute','','','.w-menu-slider'),(489491,'furniture-mobile','.w-menu-slider > ul','position','relative','','','.w-menu-slider'),(489492,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span','position','relative','','','.w-compare-box-item'),(489493,'furniture-mobile','.b-info .info','position','relative','3','','.b-info'),(489494,'furniture-mobile','.b-form .columns .col-2','position','relative','','','.b-form'),(489495,'furniture-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','position','relative','3','','.order-summary'),(489496,'furniture-mobile','.w-cart-compare .atr-col','position','absolute','3','','.w-cart-compare'),(489497,'furniture-mobile','.w-sale .badge','position','absolute','','','.w-sale'),(489498,'furniture-mobile','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(489499,'furniture-mobile','.w-promo-code .holder','position','relative','','','.w-promo-code'),(489500,'furniture-mobile','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(489501,'furniture-mobile','.w-sale .sale-holder','position','relative','','','.w-sale'),(489502,'furniture-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(489503,'furniture-mobile','.w-menu-horizontal ul ul','position','absolute','','','.w-menu-horizontal'),(489504,'furniture-mobile','.w-cart-listing .item .gift-wrap label','position','relative','','','.w-cart-listing'),(489505,'furniture-mobile','.w-cart-listing .remove-btn span','position','relative','2885','','.w-cart-listing'),(489506,'furniture-mobile','.w-cart-discount-coupon .btn-remove','position','relative','','','.w-cart-discount-coupon'),(489507,'furniture-mobile','.w-cart .cart-box-link','position','relative','','','.w-cart'),(489508,'furniture-mobile','.w-cart .cart-box','position','relative','','','.w-cart'),(489509,'furniture-mobile','.w-cart .multicart .switch-cart','position','absolute','','','.w-cart'),(489510,'furniture-mobile','.w-cart .multicart .item','position','relative','','','.w-cart'),(489511,'furniture-mobile','.w-sale .badge','position','absolute','','','.w-sale'),(489512,'furniture-mobile','.w-image-maps .svg-wrap','position','relative','','','.w-image-maps'),(489513,'furniture-mobile','.b-fancybox .fancybox-nav span','position','absolute','','','.b-fancybox'),(489514,'furniture-mobile','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(489515,'furniture-mobile','.w-personal-gift-status-bar .inform','position','relative','4','','.w-personal-gift-status-bar'),(489516,'furniture-mobile','.w-languages .current','position','relative','','','.w-languages'),(489517,'furniture-mobile','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(489518,'furniture-mobile','.w-menu-style-1 ul ul','position','absolute','','','.w-menu-style-1'),(489519,'furniture-mobile','.w-catalog-paging .paging-holder','position','relative','','','.w-catalog-paging'),(489520,'furniture-mobile','.p-wedding-registry-view h1','position','relative','3','','.p-wedding-registry-view'),(489521,'furniture-mobile','.p-reviews-info .review-info-text','position','absolute','4','','.p-reviews-info'),(489522,'furniture-mobile','.p-blog-index .author .avatar','position','relative','','','.p-blog-index'),(489523,'furniture-mobile','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(489524,'furniture-mobile','.w-menu .hided.menu','position','relative','','','.w-menu'),(489525,'furniture-mobile','.w-menu-style-1 ul ul','position','absolute','','','.w-menu-style-1'),(489526,'furniture-mobile','.w-menu-style-1 li','position','relative','','','.w-menu-style-1'),(489527,'furniture-mobile','.w-product-reviews .reviews-list .review','position','absolute','3','','.w-product-reviews'),(489528,'furniture-mobile','.p-blog-index .author .avatar','position','relative','','','.p-blog-index'),(489529,'furniture-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(489530,'furniture-mobile','.w-banner .carousel .item','position','relative','','','.w-banner'),(489531,'furniture-mobile','.p-wedding-registry-view h1','position','relative','4','','.p-wedding-registry-view'),(489532,'furniture-mobile','.w-filters .input-checkbox','position','absolute','','','.w-filters'),(489533,'furniture-mobile','.w-filters .head-filter-widget','position','relative','','','.w-filters'),(489534,'furniture-mobile','.b-bottom .pop-up-close','position','absolute','','','.b-bottom'),(489535,'furniture-mobile','.w-reviews-content .review','position','relative','','','.w-reviews-content'),(489536,'furniture-mobile','.w-search .suggest','position','absolute','','','.w-search'),(489537,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(489538,'furniture-mobile','.b-form .same-address','position','relative','','','.b-form'),(489539,'furniture-mobile','.p-wedding-registry-view h1','position','relative','4','','.p-wedding-registry-view'),(489540,'furniture-mobile','.w-menu-slider > ul','position','relative','','','.w-menu-slider'),(489541,'furniture-mobile','.w-menu .hided.menu','position','relative','','','.w-menu'),(489542,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','position','static','','','.w-menu'),(489543,'furniture-mobile','.w-menu-big ','position','relative','','','.w-menu-big'),(489544,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','position','absolute','','','.w-compare-box-item'),(489545,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(489546,'furniture-mobile','.w-menu .hided.menu ul li','position','static','','','.w-menu'),(489547,'furniture-mobile','.w-menu .hided.menu ul, .w-menu .hided.menu li:hover ul','position','static','','','.w-menu'),(489548,'furniture-mobile','.w-menu .menu .menu-ico','position','relative','','','.w-menu'),(489549,'furniture-mobile','.w-menu-big > ul > li > ul','position','absolute','','','.w-menu-big'),(489550,'furniture-mobile','.w-menu-slider > ul > li > ul','position','absolute','','','.w-menu-slider'),(489551,'furniture-mobile','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(489552,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(489553,'furniture-mobile','.w-menu-slider > ul','position','relative','','','.w-menu-slider'),(489554,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','position','absolute','','','.b-select-suggest'),(489555,'furniture-mobile','.w-filters .mobileCollapse','position','absolute','','','.w-filters'),(489556,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','position','fixed','','','.w-image-maps'),(489557,'furniture-mobile','.p-wedding-registry-view h1','position','relative','3','','.p-wedding-registry-view'),(489558,'furniture-mobile','.w-banner .banner','position','relative','','','.w-banner'),(489559,'furniture-mobile','.w-banner .banner img + img','position','absolute','','','.w-banner'),(489560,'furniture-mobile','.b-product-images .media-popup .mp-close','position','absolute','','','.b-product-images'),(489561,'furniture-mobile','.b-product-images .mp-shadow, .b-product-images .media-popup','position','fixed','','','.b-product-images'),(489562,'furniture-mobile','.b-menu-burger_icon .menu-style[data-burger_icon]','position','relative','','','.b-menu-burger_icon'),(489563,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-1 > li','position','relative','','','.b-menu-lev_display-down'),(489564,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','position','absolute','','','.b-menu-lev_display-down'),(489565,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-2 > li','position','relative','','','.b-menu-lev_display-down'),(489566,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','position','absolute','','','.b-menu-lev_display-down'),(489567,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-3 > li','position','relative','','','.b-menu-lev_display-down'),(489568,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','position','absolute','','','.b-menu-lev_display-down'),(489569,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-4 > li','position','relative','','','.b-menu-lev_display-down'),(489570,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','position','absolute','','','.b-menu-lev_display-down'),(489571,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-5 > li','position','relative','','','.b-menu-lev_display-down'),(489572,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','position','absolute','','','.b-menu-lev_display-down'),(489573,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-1 > li','position','relative','','','.b-menu-lev_display-left'),(489574,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','position','absolute','','','.b-menu-lev_display-left'),(489575,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-2 > li','position','relative','','','.b-menu-lev_display-left'),(489576,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','position','absolute','','','.b-menu-lev_display-left'),(489577,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-3 > li','position','relative','','','.b-menu-lev_display-left'),(489578,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','position','absolute','','','.b-menu-lev_display-left'),(489579,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-4 > li','position','relative','','','.b-menu-lev_display-left'),(489580,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','position','absolute','','','.b-menu-lev_display-left'),(489581,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-5 > li','position','relative','','','.b-menu-lev_display-left'),(489582,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','position','absolute','','','.b-menu-lev_display-left'),(489583,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-1 > li','position','relative','','','.b-menu-lev_display-lra'),(489584,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','position','absolute','','','.b-menu-lev_display-lra'),(489585,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-2 > li','position','relative','','','.b-menu-lev_display-lra'),(489586,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','position','absolute','','','.b-menu-lev_display-lra'),(489587,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-3 > li','position','relative','','','.b-menu-lev_display-lra'),(489588,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','position','absolute','','','.b-menu-lev_display-lra'),(489589,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-4 > li','position','relative','','','.b-menu-lev_display-lra'),(489590,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','position','absolute','','','.b-menu-lev_display-lra'),(489591,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-5 > li','position','relative','','','.b-menu-lev_display-lra'),(489592,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','position','absolute','','','.b-menu-lev_display-lra'),(489593,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right'),(489594,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','position','absolute','','','.b-menu-lev_display-right'),(489595,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right'),(489596,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','position','absolute','','','.b-menu-lev_display-right'),(489597,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right'),(489598,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','position','absolute','','','.b-menu-lev_display-right'),(489599,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right'),(489600,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','position','absolute','','','.b-menu-lev_display-right'),(489601,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right'),(489602,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','position','absolute','','','.b-menu-lev_display-right'),(489603,'furniture-mobile','.b-menu-lev_display-right_top .menu-style[data-lev2_display=\"right_top\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right_top'),(489604,'furniture-mobile','.b-menu-lev_display-right_top .menu-style[data-lev3_display=\"right_top\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right_top'),(489605,'furniture-mobile','.b-menu-lev_display-right_top .menu-style[data-lev4_display=\"right_top\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right_top'),(489606,'furniture-mobile','.b-menu-lev_display-right_top .menu-style[data-lev5_display=\"right_top\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right_top'),(489607,'furniture-mobile','.b-menu-lev_display-right_top .menu-style[data-lev6_display=\"right_top\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right_top'),(489608,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .level-1','position','relative','','','.b-menu-lev_display-slide'),(489609,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] .level-2','position','relative','','','.b-menu-lev_display-slide'),(489610,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','position','absolute','','','.b-menu-lev_display-slide'),(489611,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] .level-3','position','relative','','','.b-menu-lev_display-slide'),(489612,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','position','absolute','','','.b-menu-lev_display-slide'),(489613,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] .level-4','position','relative','','','.b-menu-lev_display-slide'),(489614,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','position','absolute','','','.b-menu-lev_display-slide'),(489615,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] .level-5','position','relative','','','.b-menu-lev_display-slide'),(489616,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','position','absolute','','','.b-menu-lev_display-slide'),(489617,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','position','absolute','','','.b-menu-lev_display-slide'),(489618,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width'),(489619,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','position','absolute','','','.b-menu-lev_display-width'),(489620,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width'),(489621,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','position','absolute','','','.b-menu-lev_display-width'),(489622,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width'),(489623,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','position','absolute','','','.b-menu-lev_display-width'),(489624,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width'),(489625,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','position','absolute','','','.b-menu-lev_display-width'),(489626,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width'),(489627,'furniture-mobile','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','position','absolute','','','.b-menu-lev_display-width'),(489628,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width_cont'),(489629,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','position','absolute','','','.b-menu-lev_display-width_cont'),(489630,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width_cont'),(489631,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','position','absolute','','','.b-menu-lev_display-width_cont'),(489632,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width_cont'),(489633,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','position','absolute','','','.b-menu-lev_display-width_cont'),(489634,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width_cont'),(489635,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','position','absolute','','','.b-menu-lev_display-width_cont'),(489636,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width_cont'),(489637,'furniture-mobile','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','position','absolute','','','.b-menu-lev_display-width_cont'),(489638,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(489639,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(489640,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(489641,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(489642,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(489643,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','position','fixed','','','.b-menu-open_from-left'),(489644,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','position','static','','','.b-menu-style-2'),(489645,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','position','relative','','','.b-menu-style-2'),(489646,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','position','absolute','3','','.b-menu-style-2'),(489647,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','position','static','','','.b-menu-style-2'),(489648,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','position','relative','','','.b-menu-style-2'),(489649,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','position','absolute','3','','.b-menu-style-2'),(489650,'furniture-mobile','.batchPr .w-batch-products .item-holder','position','relative','','','.batchPr'),(489651,'furniture-mobile','.batchPr .checkbox input:checked + span:before','position','static','','','.batchPr'),(489652,'furniture-mobile','.batchPr .checkbox input + span','position','absolute','','','.batchPr'),(489653,'furniture-mobile','.batchPr .batchSelect .checkbox','position','relative','','','.batchPr'),(489654,'furniture-mobile','.batchPr .batchSelect','position','static','','','.batchPr'),(489655,'furniture-mobile','.batchPr .w-batch-selected-products .item','position','relative','','','.batchPr'),(489656,'furniture-mobile','.batchPr .checkbox input:not(checked) + span:before','position','absolute','','','.batchPr'),(489657,'furniture-mobile','.batchPr .batchSelect','position','absolute','','','.batchPr'),(489658,'furniture-mobile','.batchPr .btn-batch-remove','position','absolute','','','.batchPr'),(489659,'furniture-mobile','.w-catalog-compare .compare .checkbox span','position','relative','','','.w-catalog-compare'),(489660,'furniture-mobile','.w-currencies ','position','relative','','','.w-currencies'),(489661,'furniture-mobile','.tripleBanner .w-html_box','position','relative','','','.tripleBanner'),(489662,'furniture-mobile','.tripleBanner .w-html_box','position','absolute','3','','.tripleBanner'),(489663,'furniture-mobile','.preFooter .w-banner .single_banner picture img','position','static','','','.preFooter'),(489664,'furniture-mobile','.b-slick .slick-list','position','relative','','','.b-slick'),(489665,'furniture-mobile','.b-slick .slick-slider','position','relative','','','.b-slick'),(489666,'furniture-mobile','.b-slick .slick-track','position','relative','','','.b-slick'),(489667,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','position','absolute','','','.b-slick'),(489668,'furniture-mobile','.menu-header ','position','relative','2885','','.menu-header'),(489669,'furniture-mobile','.menu-header .w-menu','position','absolute','2885','','.menu-header'),(489670,'furniture-mobile','.w-search .suggest-js','position','absolute','2885','','.w-search'),(489671,'furniture-mobile','.header-middle ','position','relative','2885','','.header-middle'),(489672,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','position','relative','2885','','.b-menu-style-3'),(489673,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','position','absolute','2885,3','','.b-menu-style-3'),(489674,'furniture-mobile','.header','position','fixed','2885','',''),(489675,'furniture-mobile','.b-products-listing .del-from-personal-catalog','position','relative','3','','.b-products-listing'),(489676,'furniture-mobile','.w-cart-listing .item, .w-cart-listing .headings','position','relative','','','.w-cart-listing'),(489677,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item:hover .item-wrapper','position','relative','','','.b-products-listing'),(489678,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','position','absolute','','','.b-products-listing'),(489679,'furniture-mobile','.b-products-listing .products-listing .compare .checkbox input:not(checked) + span:before','position','static','','','.b-products-listing'),(489680,'furniture-mobile','.w-quote .multicart .item','position','relative','','','.w-quote'),(489681,'furniture-mobile','.w-quote .multicart .switch-cart','position','absolute','','','.w-quote'),(489682,'furniture-mobile','.w-cart .qty','position','relative','4','','.w-cart'),(489683,'furniture-mobile','.w-product-personal-catalog-button .btn','position','relative','3','','.w-product-personal-catalog-button'),(489684,'furniture-mobile','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(489685,'furniture-mobile','h1, .heading-1','position','relative','3','',''),(489686,'furniture-mobile','h1, .heading-1','position','relative','4','',''),(489687,'furniture-mobile','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(489688,'furniture-mobile','.warrantyProduct .warranty, .warrantyProduct .delivery','position','relative','','','.warrantyProduct'),(489689,'furniture-mobile','.warrantyProduct .warranty','position','absolute','3','','.warrantyProduct'),(489690,'furniture-mobile','.warrantyProduct .delivery','position','absolute','3','','.warrantyProduct'),(489691,'furniture-mobile','.w-compare ','position','fixed','','','.w-compare'),(489692,'furniture-mobile','.w-compare .item-holder','position','relative','','','.w-compare'),(489693,'furniture-mobile','.w-compare .remove','position','absolute','','','.w-compare'),(489694,'furniture-mobile','.w-files-catalog-widgets-files-list .file','position','relative','3','','.w-files-catalog-widgets-files-list'),(489695,'furniture-mobile','.w-sample .cart-box','position','relative','','','.w-sample'),(489696,'furniture-mobile','.w-sample .cart-box-link','position','relative','','','.w-sample'),(489697,'furniture-mobile','.w-sample .multicart .item','position','relative','','','.w-sample'),(489698,'furniture-mobile','.w-sample .multicart .switch-cart','position','absolute','','','.w-sample'),(489699,'furniture-mobile','.w-sample .qty','position','relative','4','','.w-sample'),(489700,'furniture-mobile','.w-quote .cart-box.hover-box .cart-content','position','absolute','','','.w-quote'),(489701,'furniture-mobile','.w-sample .cart-box .cart-content','position','absolute','','','.w-sample'),(489702,'furniture-mobile','.w-cart-listing .points-earn','position','relative','','','.w-cart-listing'),(489703,'furniture-mobile','.w-cart-listing .points-earn','position','absolute','4','','.w-cart-listing'),(489704,'furniture-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(489705,'furniture-mobile','.w-product-inventory input[type=\"radio\"]','position','relative','','','.w-product-inventory'),(489706,'furniture-mobile','.w-account-address-book .add_item a','position','relative','3','','.w-account-address-book'),(489707,'furniture-mobile','.heading-2','position','relative','3','',''),(489708,'furniture-mobile','.heading-2','position','relative','4','',''),(489709,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .remove','position','relative','3','','.w-product-properties-filters-widgets-chosen-filters'),(489710,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','position','relative','3','','.p-quote-checkout-index'),(489711,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','position','relative','4','','.p-quote-checkout-index'),(489712,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','position','relative','3','','.p-sample-checkout-index'),(489713,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','position','relative','4','','.p-sample-checkout-index'),(489714,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','position','relative','','','.w-account-personal-catalog'),(489715,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','position','relative','','','.w-account-personal-catalog'),(489716,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','position','absolute','4','','.w-account-personal-catalog'),(489717,'furniture-mobile','.w-account-personal-catalog .checkbox input:not(checked) + span:before','position','static','','','.w-account-personal-catalog'),(489718,'furniture-mobile','.w-account-customer-additional-field .field-type-radio input','position','relative','','','.w-account-customer-additional-field'),(489719,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input','position','absolute','','','.w-questionnaire-widgets-questionnaire'),(489720,'furniture-mobile','.w-product-groups .radioBox label','position','relative','','','.w-product-groups'),(489721,'furniture-mobile','.w-product-groups .radioBox label input','position','absolute','','','.w-product-groups'),(489722,'furniture-mobile','.w-sale-category .badge','position','absolute','','','.w-sale-category'),(489723,'furniture-mobile','.w-sale-category .sale-holder','position','relative','','','.w-sale-category'),(489724,'furniture-mobile','.w-product-wedding-registry-button .btn','position','relative','','','.w-product-wedding-registry-button'),(489725,'furniture-mobile','.w-product-wedding-registry-button .btn','position','absolute','3','','.w-product-wedding-registry-button'),(489726,'furniture-mobile','.w-product-wedding-registry-button .btn','position','absolute','4','','.w-product-wedding-registry-button'),(489727,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','position','relative','','','.w-product-bonus-points'),(489728,'furniture-mobile','.w-product-bonus-points > div > div','position','absolute','3','','.w-product-bonus-points'),(489729,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','position','relative','','','.w-product-designer-designer'),(489730,'furniture-mobile','.w-product-designer-designer .productDesignerBox input','position','absolute','','','.w-product-designer-designer'),(489731,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','position','relative','','','.w-press-reviews-widgets-press-reviews'),(489732,'furniture-mobile','.w-support-system-listing .support-head','position','relative','','','.w-support-system-listing'),(489733,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .goto-button','position','absolute','','','.b-menu-style-1'),(489734,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','position','relative','','','.b-menu-style-1'),(489735,'furniture-mobile','.w-product-configurator .pc-item label','position','relative','','','.w-product-configurator'),(489736,'furniture-mobile','.w-product-configurator .pc-item label input','position','absolute','','','.w-product-configurator'),(489737,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','position','absolute','3','','.b-products-listing'),(489738,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','position','relative','','','.b-products-listing'),(489739,'furniture-mobile','.w-predefined-promotion .icon','position','relative','','','.w-predefined-promotion'),(489740,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .products','position','relative','','','.w-predefined-promotion'),(489741,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','position','relative','','','.w-predefined-promotion'),(489742,'furniture-mobile','.w-predefined-promotion .prom-multi-discount > .heading','position','relative','3','','.w-predefined-promotion'),(489743,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','position','relative','3','','.w-predefined-promotion'),(489744,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','position','relative','','','.w-predefined-promotion'),(489745,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition','position','relative','','','.w-predefined-promotion'),(489746,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .content','position','relative','','','.w-predefined-promotion'),(489747,'furniture-mobile','.w-predefined-promotion .promo-date','position','relative','','','.w-predefined-promotion'),(489748,'furniture-mobile','.w-predefined-promotion .promo-salemaker .discount','position','relative','','','.w-predefined-promotion'),(489749,'furniture-mobile','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','position','relative','3','','.w-predefined-promotion'),(489750,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','position','absolute','','','.w-filters'),(489751,'furniture-mobile','.mainBanner .title','position','absolute','3','','.mainBanner'),(489752,'furniture-mobile','.mainBanner .title','position','relative','','','.mainBanner'),(489753,'furniture-mobile','.mainBanner .topBox > .right','position','relative','','','.mainBanner'),(489754,'furniture-mobile','.mainBanner .topBox > .right','position','absolute','4','','.mainBanner'),(489755,'furniture-mobile','.mainBanner .w-banner .banner-item','position','relative','','','.mainBanner'),(489756,'furniture-mobile','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','position','absolute','','','.mainBanner'),(489757,'furniture-mobile','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','position','absolute','','','.mainBanner'),(489758,'furniture-mobile','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','position','absolute','','','.mainBanner'),(489759,'furniture-mobile','.order-summary .icon','position','relative','','','.order-summary'),(489760,'furniture-mobile','.order-summary .icon','position','absolute','3','','.order-summary'),(489761,'furniture-mobile','.w-search .background','position','fixed','','','.w-search'),(489762,'furniture-mobile','.w-search .opened','position','fixed','3','','.w-search'),(489763,'furniture-mobile','.w-search form','position','relative','','','.w-search'),(489764,'furniture-mobile','.w-search .products','position','relative','','','.w-search'),(489765,'furniture-mobile','.w-search .suggest','position','absolute','4','','.w-search'),(489766,'furniture-mobile','.account-order-history .moduleRowDue td','position','relative','','','.account-order-history'),(489767,'furniture-mobile','.account-order-history .not_fully_paid_td','position','absolute','','','.account-order-history'),(489768,'furniture-mobile','.account-order-history .view_link','position','relative','','','.account-order-history'),(489769,'furniture-mobile','.account-order-history .view_link','position','absolute','4','','.account-order-history'),(489770,'furniture-mobile','.account-order-history .orders-table .item','position','relative','2885','','.account-order-history'),(489771,'furniture-mobile','.account-order-history .orders-table .order-total','position','absolute','2885','','.account-order-history'),(489772,'furniture-mobile','.account-order-history .orders-table .status-name','position','absolute','2885','','.account-order-history'),(489773,'furniture-mobile','.account-order-history .orders-table .td-alignright','position','absolute','2885','','.account-order-history'),(489774,'furniture-mobile','.account-order-history-info .account_history_info.account_history_info_due','position','relative','','','.account-order-history-info'),(489775,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','position','relative','','','.account-order-history-info'),(489776,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','position','absolute','3','','.account-order-history-info'),(489777,'furniture-mobile','.account-order-history-info .not_fully_paid_td','position','absolute','','','.account-order-history-info'),(489778,'furniture-mobile','.account-index .account_page h4','position','absolute','3','','.account-index'),(489779,'furniture-mobile','.account-index .account_page h4','position','relative','','','.account-index'),(489780,'furniture-mobile','.account-index .moduleRowDue td','position','relative','','','.account-index'),(489781,'furniture-mobile','.account-index .not_fully_paid_td','position','absolute','','','.account-index'),(489782,'furniture-mobile','.account-index .remove-btn','position','relative','','','.account-index'),(489783,'furniture-mobile','.account-index .topAccount > li > div','position','absolute','3','','.account-index'),(489784,'furniture-mobile','.account-index .view_link','position','absolute','4','','.account-index'),(489785,'furniture-mobile','.account-index .view_link','position','relative','','','.account-index'),(489786,'furniture-mobile','.account-index .orders-table .item','position','relative','2885','','.account-index'),(489787,'furniture-mobile','.account-index .orders-table .links','position','absolute','2885','','.account-index'),(489788,'furniture-mobile','.account-index .orders-table .price','position','absolute','2885','','.account-index'),(489789,'furniture-mobile','.account-index .topAccount > li > div','position','relative','2876','','.account-index'),(489790,'furniture-mobile','.account-order-pay .account_history_info.account_history_info_due','position','relative','','','.account-order-pay'),(489791,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','position','relative','','','.account-order-pay'),(489792,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','position','absolute','3','','.account-order-pay'),(489793,'furniture-mobile','.account-order-pay .not_fully_paid_td','position','absolute','','','.account-order-pay'),(489794,'furniture-mobile','.account-samples .moduleRowDue td','position','relative','','','.account-samples'),(489795,'furniture-mobile','.account-samples .not_fully_paid_td','position','absolute','','','.account-samples'),(489796,'furniture-mobile','.account-samples .view_link','position','relative','','','.account-samples'),(489797,'furniture-mobile','.account-samples .view_link','position','absolute','4','','.account-samples'),(489798,'furniture-mobile','.account-samples .orders-table .item','position','relative','2885','','.account-samples'),(489799,'furniture-mobile','.account-samples .orders-table .order-total','position','absolute','2885','','.account-samples'),(489800,'furniture-mobile','.account-samples .orders-table .status-name','position','absolute','2885','','.account-samples'),(489801,'furniture-mobile','.account-samples .orders-table .td-alignright','position','absolute','2885','','.account-samples'),(489802,'furniture-mobile','.account-sample-info .account_history_info.account_history_info_due','position','relative','','','.account-sample-info'),(489803,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','position','relative','','','.account-sample-info'),(489804,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','position','absolute','3','','.account-sample-info'),(489805,'furniture-mobile','.account-sample-info .not_fully_paid_td','position','absolute','','','.account-sample-info'),(489806,'furniture-mobile','.catalog-product-wrap .pn-image','position','absolute','3','','.catalog-product-wrap'),(489807,'furniture-mobile','.catalog-product-wrap .prev-next-product','position','fixed','','','.catalog-product-wrap'),(489808,'furniture-mobile','.shopping-cart-index .gift-code .heading-4','position','absolute','4','','.shopping-cart-index'),(489809,'furniture-mobile','.shopping-cart-index .gift-code .heading-4','position','relative','2876','','.shopping-cart-index'),(489810,'furniture-mobile','.checkout-index-wrap .order-ico','position','relative','3','','.checkout-index-wrap'),(489811,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','position','relative','3','','.checkout-index-wrap'),(489812,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','position','relative','4','','.checkout-index-wrap'),(489813,'furniture-mobile','.checkout-order-confirmation .comment-ico','position','relative','3','','.checkout-order-confirmation'),(489814,'furniture-mobile','.checkout-order-confirmation .discount-ico','position','relative','3','','.checkout-order-confirmation'),(489815,'furniture-mobile','.checkout-order-confirmation .order-ico','position','relative','3','','.checkout-order-confirmation'),(489816,'furniture-mobile','.checkout-success-wrap .page-success','position','relative','','','.checkout-success-wrap'),(489817,'furniture-mobile','.checkout-success-wrap .page-success > div','position','relative','','','.checkout-success-wrap'),(489818,'furniture-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position_important','important','','','.b-switch'),(489819,'furniture-mobile','.w-menu .hided.menu > ul','position_important','important','','','.w-menu'),(489820,'furniture-mobile','.b-autocomplete .ui-autocomplete','position_important','important','','','.b-autocomplete'),(489821,'furniture-mobile','.w-menu .hided.menu > ul','position_important','important','','','.w-menu'),(489822,'furniture-mobile','.w-menu .hided.menu > ul','position_important','important','','','.w-menu'),(489823,'furniture-mobile','.w-checkout-billing-address .addresses .address-item label input','position_important','important','','','.w-checkout-billing-address'),(489824,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item label input','position_important','important','','','.w-checkout-shipping-address'),(489825,'furniture-mobile','.w-menu .hided.menu > ul','position_important','important','','','.w-menu'),(489826,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position_important','important','','','.b-select-suggest'),(489827,'furniture-mobile','.w-menu .hided.menu > ul','position_important','important','','','.w-menu'),(489828,'furniture-mobile','.w-menu .hided.menu > ul','position_important','important','','','.w-menu'),(489829,'furniture-mobile','.w-socials .post_item > div','right','10','3','','.w-socials'),(489830,'furniture-mobile','.w-banner .image-text-banner.middle-right .text-banner','right','0','','','.w-banner'),(489831,'furniture-mobile','.w-account .account-dropdown','right','0','','','.w-account'),(489832,'furniture-mobile','.p-wedding-registry-view h1','right','-10','4','','.p-wedding-registry-view'),(489833,'furniture-mobile','.w-wedding-registry-widgets-products .remove','right','0','','','.w-wedding-registry-widgets-products'),(489834,'furniture-mobile','.w-banner .image-text-banner.top-right .text-banner','right','0','','','.w-banner'),(489835,'furniture-mobile','.b-upload-file .snapshot','right','5','','','.b-upload-file'),(489836,'furniture-mobile','.p-wedding-registry-view h1','right','-10','4','','.p-wedding-registry-view'),(489837,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','right','5','','','.w-upload-customer-id-upload-customer-id-form'),(489838,'furniture-mobile','.w-menu-slider .close','right','10','','','.w-menu-slider'),(489839,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','right','0','','','.b-switch'),(489840,'furniture-mobile','.p-wedding-registry-view h1','right','-10','4','','.p-wedding-registry-view'),(489841,'furniture-mobile','.w-cart-compare .dropdown .dropdown-menu','right','0','','','.w-cart-compare'),(489842,'furniture-mobile','.closeable-heading','right','0','3','',''),(489843,'furniture-mobile','.b-bottom .footerTitle','right','0','2876,4','','.b-bottom'),(489844,'furniture-mobile','.w-socials .post_item > div','right','10','3','','.w-socials'),(489845,'furniture-mobile','.b-info-popup .info-popup.top-left div','right','13','3','','.b-info-popup'),(489846,'furniture-mobile','.w-search .button-search','right','15','','','.w-search'),(489847,'furniture-mobile','.w-socials .post_item > div','right','10','3','','.w-socials'),(489848,'furniture-mobile','.w-socials .post_item > div','right','10','3','','.w-socials'),(489849,'furniture-mobile','.w-cart-compare .atr-col','right','0','3','','.w-cart-compare'),(489850,'furniture-mobile','.w-multi-cart-actions .dropdown .dropdown-menu','right','auto','','','.w-multi-cart-actions'),(489851,'furniture-mobile','.w-socials .post_item > div','right','10','3','','.w-socials'),(489852,'furniture-mobile','.w-menu-slider .close','right','10','','','.w-menu-slider'),(489853,'furniture-mobile','.b-pass-strength .pass-strength span','right','25','','','.b-pass-strength'),(489854,'furniture-mobile','.b-info-popup .info-popup.top-left div','right','-10','','','.b-info-popup'),(489855,'furniture-mobile','.b-fancybox .fancybox-overlay-fixed','right','0','','','.b-fancybox'),(489856,'furniture-mobile','.p-wedding-registry-view h1','right','-10','4','','.p-wedding-registry-view'),(489857,'furniture-mobile','.w-banner .image-text-banner.bottom-right .text-banner','right','0','','','.w-banner'),(489858,'furniture-mobile','.w-cart-compare .remove-cart','right','0','','','.w-cart-compare'),(489859,'furniture-mobile','.b-fancybox .fancybox-close','right','10','','','.b-fancybox'),(489860,'furniture-mobile','.b-fancybox .fancybox-next','right','0','','','.b-fancybox'),(489861,'furniture-mobile','.b-fancybox .fancybox-next span','right','10','','','.b-fancybox'),(489862,'furniture-mobile','.w-product-customers-activity .customers-activity','right','20','','','.w-product-customers-activity'),(489863,'furniture-mobile','.w-product-customers-activity .close','right','5','','','.w-product-customers-activity'),(489864,'furniture-mobile','.w-menu-slider .close','right','10','','','.w-menu-slider'),(489865,'furniture-mobile','.b-select-suggest .select2-search-choice-close','right','3','','','.b-select-suggest'),(489866,'furniture-mobile','.w-menu-slider .close','right','10','','','.w-menu-slider'),(489867,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','right','0','','','.b-select-suggest'),(489868,'furniture-mobile','.w-menu-slider .close','right','10','','','.w-menu-slider'),(489869,'furniture-mobile','.w-blog-widget-related-posts-by-category button.slick-next','right','10','','','.w-blog-widget-related-posts-by-category'),(489870,'furniture-mobile','.w-blog-widget-related-posts button.slick-next','right','10','','','.w-blog-widget-related-posts'),(489871,'furniture-mobile','.w-blog-widget-post-share','right','auto','2906,4','','.w-blog-widget-post-share'),(489872,'furniture-mobile','.w-blog-widget-post-share ','right','100','4','','.w-blog-widget-post-share'),(489873,'furniture-mobile','.w-blog-widget-post-linked-products button.slick-next','right','10','','','.w-blog-widget-post-linked-products'),(489874,'furniture-mobile','.w-currencies .current','right','0','3','','.w-currencies'),(489875,'furniture-mobile','.p-wedding-registry-view h1','right','-10','4','','.p-wedding-registry-view'),(489876,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap','right','50','','','.b-fancybox'),(489877,'furniture-mobile','.b-form .eye-password','right','5','','','.b-form'),(489878,'furniture-mobile','.w-menu-slider .close','right','10','','','.w-menu-slider'),(489879,'furniture-mobile','.w-languages .current','right','0','3','','.w-languages'),(489880,'furniture-mobile','.b-upload-file .upload-remove','right','10','','','.b-upload-file'),(489881,'furniture-mobile','.w-socials .post_item > div','right','10','3','','.w-socials'),(489882,'furniture-mobile','.p-wedding-registry-view h1','right','-10','4','','.p-wedding-registry-view'),(489883,'furniture-mobile','.w-account-address-book .btn-del','right','0','','','.w-account-address-book'),(489884,'furniture-mobile','.b-bottom .pop-up-close','right','6','','','.b-bottom'),(489885,'furniture-mobile','.w-menu-big > ul > li > ul','right','0','','','.w-menu-big'),(489886,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','right','24','','','.b-select-suggest'),(489887,'furniture-mobile','.w-filters .mobileCollapse','right','12','','','.w-filters'),(489888,'furniture-mobile','.b-product-images .media-popup .mp-close','right','20','','','.b-product-images'),(489889,'furniture-mobile','.b-product-images .mp-shadow, .b-product-images .media-popup','right','0','','','.b-product-images'),(489890,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right','100','','','.b-menu-lev_display-left'),(489891,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right','100','','','.b-menu-lev_display-left'),(489892,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right','100','','','.b-menu-lev_display-left'),(489893,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right','100','','','.b-menu-lev_display-left'),(489894,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right','100','','','.b-menu-lev_display-left'),(489895,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right','100','','','.b-menu-lev_display-lra'),(489896,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right','100','','','.b-menu-lev_display-lra'),(489897,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right','100','','','.b-menu-lev_display-lra'),(489898,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right','100','','','.b-menu-lev_display-lra'),(489899,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right','100','','','.b-menu-lev_display-lra'),(489900,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','right','10','3','','.b-menu-style-2'),(489901,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .parent > .no-link','right','40','3','','.b-menu-style-2'),(489902,'furniture-mobile','.batchPr .w-batch-products .products-listing .slick-next','right','-10','','','.batchPr'),(489903,'furniture-mobile','.batchPr .batchSelect','right','20','','','.batchPr'),(489904,'furniture-mobile','.batchPr .btn-batch-remove','right','0','','','.batchPr'),(489905,'furniture-mobile','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','right','auto','','','.b-slick'),(489906,'furniture-mobile','.b-slick button.slick-next','right','0','','','.b-slick'),(489907,'furniture-mobile','.b-slick button.slick-prev','right','auto','','','.b-slick'),(489908,'furniture-mobile','.menu-header .w-menu','right','10','2885','','.menu-header'),(489909,'furniture-mobile','.w-search .suggest-js','right','0','2885','','.w-search'),(489910,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','right','10','2885,3','','.b-menu-style-3'),(489911,'furniture-mobile','.header','right','0','2885','',''),(489912,'furniture-mobile','h1, .heading-1','right','-14','4','',''),(489913,'furniture-mobile','.w-compare ','right','0','','','.w-compare'),(489914,'furniture-mobile','.w-compare .remove','right','20','','','.w-compare'),(489915,'furniture-mobile','.w-cart-listing .points-earn','right','-12','4','','.w-cart-listing'),(489916,'furniture-mobile','.heading-2','right','-14','4','',''),(489917,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','right','-14','4','','.p-quote-checkout-index'),(489918,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','right','-14','4','','.p-sample-checkout-index'),(489919,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','right','7','4','','.w-account-personal-catalog'),(489920,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','right','-100','','','.w-product-properties-icons'),(489921,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','right','-14','2906,4','','.w-product-bonus-points'),(489922,'furniture-mobile','.mainBanner .topBox > .right','right','-18','4','','.mainBanner'),(489923,'furniture-mobile','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','right','0','','','.mainBanner'),(489924,'furniture-mobile','.order-summary .icon','right','0','3','','.order-summary'),(489925,'furniture-mobile','.w-search .background','right','0','','','.w-search'),(489926,'furniture-mobile','.w-search .opened','right','0','3','','.w-search'),(489927,'furniture-mobile','.w-search .suggest','right','0','4','','.w-search'),(489928,'furniture-mobile','.account-order-history .orders-table .order-total','right','0','2885','','.account-order-history'),(489929,'furniture-mobile','.account-samples .orders-table .order-total','right','0','2885','','.account-samples'),(489930,'furniture-mobile','.catalog-product-wrap .next-product','right','0','','','.catalog-product-wrap'),(489931,'furniture-mobile','.catalog-product-wrap .next-product .pn-image','right','20','3','','.catalog-product-wrap'),(489932,'furniture-mobile','.shopping-cart-index .gift-code .heading-4','right','0','4','','.shopping-cart-index'),(489933,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','right','-14','4','','.checkout-index-wrap'),(489934,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap','right_measure','%','','','.b-fancybox'),(489935,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right_measure','%','','','.b-menu-lev_display-left'),(489936,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right_measure','%','','','.b-menu-lev_display-left'),(489937,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right_measure','%','','','.b-menu-lev_display-left'),(489938,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right_measure','%','','','.b-menu-lev_display-left'),(489939,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right_measure','%','','','.b-menu-lev_display-left'),(489940,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right_measure','%','','','.b-menu-lev_display-lra'),(489941,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right_measure','%','','','.b-menu-lev_display-lra'),(489942,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right_measure','%','','','.b-menu-lev_display-lra'),(489943,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right_measure','%','','','.b-menu-lev_display-lra'),(489944,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right_measure','%','','','.b-menu-lev_display-lra'),(489945,'furniture-mobile','.b-info-popup .info-popup.top-left div','rotate','-135','3','','.b-info-popup'),(489946,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','rotate','45','','','.w-checkout-shipping-choice'),(489947,'furniture-mobile','.b-info-popup .info-popup div','rotate','-45','3','','.b-info-popup'),(489948,'furniture-mobile','.w-cart .cart-box-link','rotate','45','4','','.w-cart'),(489949,'furniture-mobile','.w-account .my-acc-link','rotate','45','4','','.w-account'),(489950,'furniture-mobile','.w-sample .cart-box-link','rotate','45','4','','.w-sample'),(489951,'furniture-mobile','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','stroke-width','0','','','.w-image-maps'),(489952,'furniture-mobile','.w-image-maps rect:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(489953,'furniture-mobile','.w-image-maps circle:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(489954,'furniture-mobile','.w-image-maps polygon:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(489955,'furniture-mobile','.w-tabs .tab-navigation','table-layout','fixed','','','.w-tabs'),(489956,'furniture-mobile','.w-communication-new-topic .orders-id','text-align','center','','','.w-communication-new-topic'),(489957,'furniture-mobile','.w-communication-new-topic .model','text-align','center','','','.w-communication-new-topic'),(489958,'furniture-mobile','.w-communication-new-topic .date-purchased','text-align','right','','','.w-communication-new-topic'),(489959,'furniture-mobile','.w-communication-new-topic .quantity','text-align','center','','','.w-communication-new-topic'),(489961,'furniture-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(489962,'furniture-mobile','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(489963,'furniture-mobile','.p-account-trade-form .trade-form-area','text-align','center','','','.p-account-trade-form'),(489964,'furniture-mobile','.w-product-wishlist-button .btn','text-align','center','2876','','.w-product-wishlist-button'),(489965,'furniture-mobile','.b-email .price','text-align','right','','','.b-email'),(489966,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.p-quick-order-index'),(489967,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.p-quick-order-index'),(489968,'furniture-mobile','.w-promotions .promo-date','text-align','center','','','.w-promotions'),(489969,'furniture-mobile','.w-promotions .promo-item','text-align','center','','','.w-promotions'),(489970,'furniture-mobile','.w-sale .badge','text-align','center','','','.w-sale'),(489971,'furniture-mobile','.w-account-address-book .button-add','text-align','right','','','.w-account-address-book'),(489972,'furniture-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(489973,'furniture-mobile','.w-account .acc-top','text-align','center','','','.w-account'),(489974,'furniture-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(489975,'furniture-mobile','.p-reviews-info .review-info-image','text-align','center','','','.p-reviews-info'),(489976,'furniture-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(489977,'furniture-mobile','.p-blog-index .nav-next','text-align','right','','','.p-blog-index'),(489978,'furniture-mobile','.p-blog-index .form-submit','text-align','right','','','.p-blog-index'),(489979,'furniture-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(489980,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','text-align','center','','','.w-compare-box-item'),(489981,'furniture-mobile','.w-categories .item','text-align','center','','','.w-categories'),(489982,'furniture-mobile','.w-promotions .prom-multi-discount .heading','text-align','center','','','.w-promotions'),(489983,'furniture-mobile','.b-products-listing .products-listing .btn-preloader','text-align','center','','','.b-products-listing'),(489984,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','text-align','center','','','.w-compare-box-item'),(489985,'furniture-mobile','.p-account-trade-form .widget h3','text-align','center','','','.p-account-trade-form'),(489986,'furniture-mobile','.w-menu-slider .close','text-align','center','','','.w-menu-slider'),(489987,'furniture-mobile','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(489988,'furniture-mobile','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(489989,'furniture-mobile','.p-reviews-info .review-info-image','text-align','center','','','.p-reviews-info'),(489990,'furniture-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(489991,'furniture-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(489992,'furniture-mobile','.b-messages .development-content','text-align','left','','','.b-messages'),(489993,'furniture-mobile','.b-messages .msv_to_cc, .b-messages .msv_btn','text-align','left','','','.b-messages'),(489994,'furniture-mobile','.b-messages .msv_content','text-align','left','','','.b-messages'),(489995,'furniture-mobile','.b-messages .msv_history','text-align','left','','','.b-messages'),(489996,'furniture-mobile','.b-messages .attach-view','text-align','left','','','.b-messages'),(489997,'furniture-mobile','.b-messages .messages-sidebar .heading-2','text-align','center','','','.b-messages'),(489998,'furniture-mobile','.b-messages .messages-sidebar .btn-2','text-align','center','','','.b-messages'),(489999,'furniture-mobile','.b-messages .emailBtn','text-align','right','','','.b-messages'),(490000,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','text-align','left','','','.b-messages'),(490001,'furniture-mobile','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(490002,'furniture-mobile','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align','left','','','.p-quick-order-index'),(490003,'furniture-mobile','.p-account-trade-form .widget h3','text-align','center','','','.p-account-trade-form'),(490004,'furniture-mobile','.w-menu-style-1 ul ul li','text-align','left','','','.w-menu-style-1'),(490005,'furniture-mobile','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(490006,'furniture-mobile','.w-checkout-terms .terms-box','text-align','left','','','.w-checkout-terms'),(490007,'furniture-mobile','.w-checkout-terms .required-message','text-align','left','','','.w-checkout-terms'),(490008,'furniture-mobile','.w-cart-listing .price','text-align','right','2876','','.w-cart-listing'),(490009,'furniture-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(490010,'furniture-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(490011,'furniture-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(490012,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','text-align','center','','','.b-switch'),(490013,'furniture-mobile','.w-menu-slider .menu-ico','text-align','center','','','.w-menu-slider'),(490014,'furniture-mobile','.w-sale .badge','text-align','center','','','.w-sale'),(490015,'furniture-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(490016,'furniture-mobile','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(490017,'furniture-mobile','.p-account-trade-form .trade-form-area','text-align','center','','','.p-account-trade-form'),(490018,'furniture-mobile','.p-account-trade-form .widget h3','text-align','center','','','.p-account-trade-form'),(490021,'furniture-mobile','.order-summary .price-box .title','text-align','left','','','.order-summary'),(490022,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','text-align','center','','','.w-upload-customer-id-upload-customer-id-form'),(490023,'furniture-mobile','.b-switch .bootstrap-switch','text-align','left','','','.b-switch'),(490024,'furniture-mobile','.b-page-name .page-name','text-align','center','','','.b-page-name'),(490025,'furniture-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(490026,'furniture-mobile','.w-coupons-and-vauchers-checkout .btn-remove','text-align','center','','','.w-coupons-and-vauchers-checkout'),(490027,'furniture-mobile','.w-checkout-bonus-points .btn-remove','text-align','center','','','.w-checkout-bonus-points'),(490028,'furniture-mobile','.w-login-block .buttons','text-align','right','','','.w-login-block'),(490029,'furniture-mobile','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(490030,'furniture-mobile','.w-menu-slider > ul','text-align','center','','','.w-menu-slider'),(490031,'furniture-mobile','.w-menu-slider > ul > li > ul','text-align','center','','','.w-menu-slider'),(490032,'furniture-mobile','.w-menu-slider .menu-ico','text-align','center','','','.w-menu-slider'),(490033,'furniture-mobile','.w-menu-slider .close','text-align','center','','','.w-menu-slider'),(490035,'furniture-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(490036,'furniture-mobile','.p-blog-index .nav-next','text-align','right','','','.p-blog-index'),(490037,'furniture-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(490038,'furniture-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(490039,'furniture-mobile','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(490040,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','text-align','center','','','.b-switch'),(490041,'furniture-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(490042,'furniture-mobile','.b-email .qty','text-align','center','','','.b-email'),(490043,'furniture-mobile','.w-menu-slider > ul','text-align','center','','','.w-menu-slider'),(490044,'furniture-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(490045,'furniture-mobile','.p-account-trade-form .widget h3','text-align','center','','','.p-account-trade-form'),(490046,'furniture-mobile','.p-reviews-info .review-info-image','text-align','center','','','.p-reviews-info'),(490047,'furniture-mobile','.pop-up-content .buttons .btn-2','text-align','center','2885','',''),(490048,'furniture-mobile','.pop-up-content .buttons .btn','text-align','center','2885','',''),(490049,'furniture-mobile','.no-found','text-align','center','','',''),(490050,'furniture-mobile','.w-menu-style-1 .box','text-align','center','','','.w-menu-style-1'),(490051,'furniture-mobile','.w-menu-style-1 ul ul li','text-align','left','','','.w-menu-style-1'),(490052,'furniture-mobile','.w-login-block .buttons','text-align','right','','','.w-login-block'),(490053,'furniture-mobile','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(490054,'furniture-mobile','.p-quick-order-index .all-scroll-div td + td','text-align','right','','','.p-quick-order-index'),(490055,'furniture-mobile','.w-sale .badge','text-align','center','','','.w-sale'),(490056,'furniture-mobile','.w-sale .btn','text-align','center','','','.w-sale'),(490057,'furniture-mobile','.w-menu-style-1 .box','text-align','center','','','.w-menu-style-1'),(490058,'furniture-mobile','.w-menu-slider .close','text-align','center','','','.w-menu-slider'),(490059,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(490060,'furniture-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(490063,'furniture-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(490064,'furniture-mobile','.b-email .model','text-align','center','','','.b-email'),(490065,'furniture-mobile','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(490066,'furniture-mobile','.b-form .wedding-form .heading-2','text-align','left','','','.b-form'),(490067,'furniture-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(490068,'furniture-mobile','.b-email .price','text-align','right','','','.b-email'),(490069,'furniture-mobile','.w-catalog-paging .prev-pages','text-align','center','','','.w-catalog-paging'),(490070,'furniture-mobile','.w-sale .left','text-align','center','','','.w-sale'),(490071,'furniture-mobile','.w-top-categories .categories','text-align','center','','','.w-top-categories'),(490072,'furniture-mobile','.w-success-continue-btn','text-align','center','2885','','.w-success-continue-btn'),(490073,'furniture-mobile','.p-account-trade-form .trade-form-area','text-align','center','','','.p-account-trade-form'),(490074,'furniture-mobile','.b-page-name .page-name','text-align','center','','','.b-page-name'),(490075,'furniture-mobile','.p-reviews-info .review-info-image','text-align','center','','','.p-reviews-info'),(490076,'furniture-mobile','.w-wedding-registry-widgets-products .rating','text-align','center','','','.w-wedding-registry-widgets-products'),(490077,'furniture-mobile','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(490078,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(490080,'furniture-mobile','.b-page-name .page-name','text-align','center','','','.b-page-name'),(490081,'furniture-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(490082,'furniture-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(490083,'furniture-mobile','.w-sale .left','text-align','center','','','.w-sale'),(490084,'furniture-mobile','.w-sale .image','text-align','center','','','.w-sale'),(490085,'furniture-mobile','.w-menu-style-1 .box','text-align','center','','','.w-menu-style-1'),(490086,'furniture-mobile','.w-menu-slider > ul > li > ul li','text-align','left','','','.w-menu-slider'),(490087,'furniture-mobile','.w-menu-style-1 .menu-ico','text-align','center','','','.w-menu-style-1'),(490088,'furniture-mobile','.w-menu-style-1 > ul','text-align','center','','','.w-menu-style-1'),(490089,'furniture-mobile','.w-menu-style-1 ul ul li','text-align','left','','','.w-menu-style-1'),(490090,'furniture-mobile','.w-tabs .tab-a','text-align','center','','','.w-tabs'),(490091,'furniture-mobile','.w-sale .btn','text-align','center','','','.w-sale'),(490092,'furniture-mobile','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(490093,'furniture-mobile','.w-menu-slider > ul > li > ul li','text-align','left','','','.w-menu-slider'),(490094,'furniture-mobile','.w-menu-style-1 .box','text-align','center','','','.w-menu-style-1'),(490095,'furniture-mobile','.w-menu-slider .close','text-align','center','','','.w-menu-slider'),(490096,'furniture-mobile','.w-menu-slider > ul','text-align','center','','','.w-menu-slider'),(490097,'furniture-mobile','.w-menu-style-1 .menu-ico','text-align','center','','','.w-menu-style-1'),(490098,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','text-align','center','','','.b-switch'),(490099,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-label','text-align','center','','','.b-switch'),(490100,'furniture-mobile','.b-social-login .social-login','text-align','center','','','.b-social-login'),(490101,'furniture-mobile','.w-menu-style-1 > ul','text-align','center','','','.w-menu-style-1'),(490102,'furniture-mobile','.w-menu-style-1 .box','text-align','center','','','.w-menu-style-1'),(490103,'furniture-mobile','.b-page-name .page-name','text-align','center','','','.b-page-name'),(490105,'furniture-mobile','.b-email .price','text-align','right','','','.b-email'),(490106,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','text-align','center','','','.b-switch'),(490107,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','text-align','center','','','.b-switch'),(490108,'furniture-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(490109,'furniture-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(490110,'furniture-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(490111,'furniture-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(490112,'furniture-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(490113,'furniture-mobile','.w-cart-bonus-points .bonus_points_amount','text-align','center','','','.w-cart-bonus-points'),(490114,'furniture-mobile','.w-cart-bonus-points .btn-remove','text-align','center','','','.w-cart-bonus-points'),(490115,'furniture-mobile','.w-cart-credit-amount input','text-align','center','','','.w-cart-credit-amount'),(490116,'furniture-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(490117,'furniture-mobile','.w-reviews .date','text-align','right','','','.w-reviews'),(490118,'furniture-mobile','.w-success-continue-btn','text-align','center','2885','','.w-success-continue-btn'),(490119,'furniture-mobile','.w-top-categories .item','text-align','center','','','.w-top-categories'),(490120,'furniture-mobile','.w-reviews-content .product-image','text-align','center','','','.w-reviews-content'),(490121,'furniture-mobile','.b-email .model','text-align','center','','','.b-email'),(490122,'furniture-mobile','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(490123,'furniture-mobile','.w-sale .image','text-align','center','','','.w-sale'),(490124,'furniture-mobile','.p-account-trade-form .trade-form-area','text-align','center','','','.p-account-trade-form'),(490125,'furniture-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(490126,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(490127,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(490128,'furniture-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(490129,'furniture-mobile','.b-email .price','text-align','right','','','.b-email'),(490130,'furniture-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(490131,'furniture-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(490132,'furniture-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(490133,'furniture-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(490134,'furniture-mobile','.b-email .qty','text-align','center','','','.b-email'),(490135,'furniture-mobile','.b-email .model','text-align','center','','','.b-email'),(490136,'furniture-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(490137,'furniture-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(490138,'furniture-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(490139,'furniture-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(490140,'furniture-mobile','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(490141,'furniture-mobile','.b-form .center-buttons','text-align','center','','','.b-form'),(490142,'furniture-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(490143,'furniture-mobile','.p-account-trade-form .trade-form-area','text-align','center','','','.p-account-trade-form'),(490144,'furniture-mobile','.w-reviews .product-image','text-align','center','','','.w-reviews'),(490145,'furniture-mobile','.b-sub-totals .historyTotal table td','text-align','right','','','.b-sub-totals'),(490147,'furniture-mobile','.b-social-login .social-login','text-align','center','','','.b-social-login'),(490148,'furniture-mobile','.w-success-continue-btn','text-align','center','2885','','.w-success-continue-btn'),(490149,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','text-align','center','3','','.b-switch'),(490150,'furniture-mobile','.w-menu .hided.menu ul li','text-align','left','2885','','.w-menu'),(490151,'furniture-mobile','.b-social-login .social-login','text-align','center','','','.b-social-login'),(490152,'furniture-mobile','.w-sale .left','text-align','center','','','.w-sale'),(490153,'furniture-mobile','.w-menu-style-1 ul ul li','text-align','left','','','.w-menu-style-1'),(490154,'furniture-mobile','.w-login-block .buttons','text-align','right','','','.w-login-block'),(490155,'furniture-mobile','.w-sale .btn','text-align','center','','','.w-sale'),(490156,'furniture-mobile','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(490157,'furniture-mobile','.w-menu-slider .menu-ico','text-align','center','','','.w-menu-slider'),(490158,'furniture-mobile','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','text-align','center','','','.p-quick-order-index'),(490159,'furniture-mobile','.w-cart-checkout-btn a','text-align','center','2876','','.w-cart-checkout-btn'),(490160,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','text-align','center','','','.w-compare-box-item'),(490161,'furniture-mobile','.w-categories .categories','text-align','center','','','.w-categories'),(490162,'furniture-mobile','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(490163,'furniture-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(490164,'furniture-mobile','.w-menu-slider > ul > li > ul li','text-align','left','','','.w-menu-slider'),(490165,'furniture-mobile','.w-login-block .buttons','text-align','right','','','.w-login-block'),(490166,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','text-align','center','','','.w-compare-box-item'),(490167,'furniture-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(490168,'furniture-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(490169,'furniture-mobile','.view-all','text-align','center','','',''),(490170,'furniture-mobile','.b-page-name .page-name','text-align','center','','','.b-page-name'),(490171,'furniture-mobile','.b-form .message.error','text-align','center','','','.b-form'),(490172,'furniture-mobile','.b-email .qty','text-align','center','','','.b-email'),(490173,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','text-align','center','3','','.w-checkout-contact-information'),(490174,'furniture-mobile','.b-email .model','text-align','center','','','.b-email'),(490175,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','text-align','center','3','','.w-checkout-contact-information'),(490176,'furniture-mobile','.p-wedding-registry-search .result-table td:nth-child(4)','text-align','right','','','.p-wedding-registry-search'),(490177,'furniture-mobile','.w-product-wishlist-button .btn','text-align','center','2876','','.w-product-wishlist-button'),(490178,'furniture-mobile','.b-email .heading-qty','text-align','center','','','.b-email'),(490179,'furniture-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(490180,'furniture-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(490181,'furniture-mobile','.w-product-wishlist-button .btn','text-align','center','2876','','.w-product-wishlist-button'),(490182,'furniture-mobile','.b-bottom .cart-options .js-carts','text-align','center','','','.b-bottom'),(490183,'furniture-mobile','.b-bottom .cart-options .heading-4','text-align','center','','','.b-bottom'),(490184,'furniture-mobile','.b-bottom .cart-options .heading-3','text-align','center','','','.b-bottom'),(490185,'furniture-mobile','.w-sale .btn','text-align','center','','','.w-sale'),(490186,'furniture-mobile','.w-sale .btn','text-align','center','','','.w-sale'),(490187,'furniture-mobile','.w-menu-style-1 > ul','text-align','center','','','.w-menu-style-1'),(490188,'furniture-mobile','.b-bottom .cart-options .buttons','text-align','center','','','.b-bottom'),(490189,'furniture-mobile','.b-bottom .alert-message','text-align','center','','','.b-bottom'),(490190,'furniture-mobile','.w-menu-slider > ul > li > ul li','text-align','left','','','.w-menu-slider'),(490191,'furniture-mobile','.w-checkout-credit-amount .btn-remove','text-align','center','','','.w-checkout-credit-amount'),(490192,'furniture-mobile','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(490193,'furniture-mobile','.b-products-listing .btn-choose-options','text-align','center','','','.b-products-listing'),(490194,'furniture-mobile','.w-menu-slider > ul > li > ul','text-align','center','','','.w-menu-slider'),(490195,'furniture-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(490196,'furniture-mobile','.w-catalog-paging .next-pages','text-align','center','','','.w-catalog-paging'),(490198,'furniture-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(490199,'furniture-mobile','.w-product-wishlist-button .btn','text-align','center','2876','','.w-product-wishlist-button'),(490200,'furniture-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(490202,'furniture-mobile','.b-email .qty','text-align','center','','','.b-email'),(490203,'furniture-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(490204,'furniture-mobile','.w-menu .hided.menu ul li','text-align','left','2885','','.w-menu'),(490205,'furniture-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(490206,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(490207,'furniture-mobile','.order-summary .price-row.ot_gv .title','text-align','center','3','','.order-summary'),(490208,'furniture-mobile','.w-menu-slider > ul > li > ul li','text-align','left','','','.w-menu-slider'),(490209,'furniture-mobile','.w-cart-credit-amount .btn-remove','text-align','center','','','.w-cart-credit-amount'),(490210,'furniture-mobile','.b-email .qty','text-align','center','','','.b-email'),(490211,'furniture-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(490212,'furniture-mobile','.b-fancybox .fancybox-close','text-align','center','','','.b-fancybox'),(490214,'furniture-mobile','.w-menu-style-1 > ul','text-align','center','','','.w-menu-style-1'),(490215,'furniture-mobile','.w-product-customers-activity .customers-activity','text-align','center','','','.w-product-customers-activity'),(490216,'furniture-mobile','.w-product-customers-activity .close','text-align','center','','','.w-product-customers-activity'),(490217,'furniture-mobile','.b-bottom .confirm-popup .buttons','text-align','center','','','.b-bottom'),(490218,'furniture-mobile','.b-bottom .confirm-popup .confirm-text','text-align','center','','','.b-bottom'),(490219,'furniture-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(490220,'furniture-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(490221,'furniture-mobile','.b-email .price','text-align','right','','','.b-email'),(490222,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','text-align','center','3','','.b-switch'),(490223,'furniture-mobile','.w-quote-products .empty','text-align','center','','','.w-quote-products'),(490224,'furniture-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(490225,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','text-align','center','','','.w-compare-box-item'),(490226,'furniture-mobile','.w-sale .left','text-align','center','','','.w-sale'),(490227,'furniture-mobile','.w-sale .image','text-align','center','','','.w-sale'),(490229,'furniture-mobile','.w-menu-slider > ul > li > ul','text-align','center','','','.w-menu-slider'),(490230,'furniture-mobile','.w-menu-style-1 > ul','text-align','center','','','.w-menu-style-1'),(490231,'furniture-mobile','.w-menu-horizontal .menu-ico','text-align','center','','','.w-menu-horizontal'),(490232,'furniture-mobile','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(490233,'furniture-mobile','.w-checkout-credit-amount .cot_gv_amount','text-align','center','','','.w-checkout-credit-amount'),(490234,'furniture-mobile','.w-checkout-bonus-points .bonus_points_amount','text-align','center','','','.w-checkout-bonus-points'),(490235,'furniture-mobile','.w-product-wishlist-button .btn','text-align','center','2876','','.w-product-wishlist-button'),(490236,'furniture-mobile','.w-success-continue-btn','text-align','center','2885','','.w-success-continue-btn'),(490237,'furniture-mobile','.p-wedding-registry-search #searchform-status label','text-align','right','','','.p-wedding-registry-search'),(490238,'furniture-mobile','.b-page-name .page-name','text-align','center','','','.b-page-name'),(490239,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-align','left','','','.b-switch'),(490240,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-align','right','','','.b-switch'),(490241,'furniture-mobile','.p-reviews-info .review-info-image','text-align','center','','','.p-reviews-info'),(490242,'furniture-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(490243,'furniture-mobile','.p-blog-index .nav-next','text-align','right','','','.p-blog-index'),(490244,'furniture-mobile','.p-blog-index .form-submit','text-align','right','','','.p-blog-index'),(490245,'furniture-mobile','.b-social-login .social-login','text-align','center','','','.b-social-login'),(490247,'furniture-mobile','.b-products-listing .products-listing .buyButton .btn','text-align','center','','','.b-products-listing'),(490248,'furniture-mobile','.w-menu-style-1 .menu-ico','text-align','center','','','.w-menu-style-1'),(490249,'furniture-mobile','.w-menu-slider > ul > li > ul','text-align','center','','','.w-menu-slider'),(490250,'furniture-mobile','.w-menu-slider .close','text-align','center','','','.w-menu-slider'),(490251,'furniture-mobile','.w-menu .hided.menu ul li','text-align','left','2885','','.w-menu'),(490252,'furniture-mobile','.w-menu-big li li li','text-align','left','','','.w-menu-big'),(490253,'furniture-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(490254,'furniture-mobile','.w-menu-horizontal .box','text-align','center','','','.w-menu-horizontal'),(490255,'furniture-mobile','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(490256,'furniture-mobile','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(490257,'furniture-mobile','.b-social-login .social-login','text-align','center','','','.b-social-login'),(490258,'furniture-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(490259,'furniture-mobile','.w-sale .image','text-align','center','','','.w-sale'),(490260,'furniture-mobile','.w-login-block .buttons','text-align','right','','','.w-login-block'),(490261,'furniture-mobile','.w-menu-slider > ul > li > ul','text-align','center','','','.w-menu-slider'),(490262,'furniture-mobile','.w-menu-slider > ul','text-align','center','','','.w-menu-slider'),(490263,'furniture-mobile','.w-menu-style-1 ul ul li','text-align','left','','','.w-menu-style-1'),(490264,'furniture-mobile','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(490265,'furniture-mobile','.w-cart-listing .links','text-align','center','','','.w-cart-listing'),(490266,'furniture-mobile','.w-sale .image','text-align','center','','','.w-sale'),(490267,'furniture-mobile','.w-product-wishlist-button .btn','text-align','center','2876','','.w-product-wishlist-button'),(490268,'furniture-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(490269,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.b-data-table'),(490270,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.b-data-table'),(490271,'furniture-mobile','.w-communication-post .communication-post-attach','text-align','right','','','.w-communication-post'),(490272,'furniture-mobile','.b-products-listing .products-listing .image','text-align','center','','','.b-products-listing'),(490273,'furniture-mobile','.b-products-listing .products-listing','text-align','center','','','.b-products-listing'),(490274,'furniture-mobile','.b-products-listing .products-listing .btn-buy','text-align','center','','','.b-products-listing'),(490275,'furniture-mobile','.w-catalog-b2b-add-button .b2b-add-box-wrap','text-align','right','','','.w-catalog-b2b-add-button'),(490276,'furniture-mobile','.b-products-listing .products-listing .properties','text-align','left','','','.b-products-listing'),(490277,'furniture-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','text-align','left','','','.b-products-listing'),(490278,'furniture-mobile','.b-products-listing .show-ofstock-products','text-align','center','','','.b-products-listing'),(490279,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_img','text-align','center','','','.w-blog-widget-related-posts-by-category'),(490280,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_content a','text-align','center','','','.w-blog-widget-related-posts-by-category'),(490281,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','text-align','center','','','.w-blog-widget-related-posts'),(490282,'furniture-mobile','.w-blog-widget-post-title h1','text-align','center','','','.w-blog-widget-post-title'),(490283,'furniture-mobile','.w-blog-widget-post-listing .post_image','text-align','center','','','.w-blog-widget-post-listing'),(490284,'furniture-mobile','.w-blog-widget-post-listing .post_name','text-align','center','','','.w-blog-widget-post-listing'),(490285,'furniture-mobile','.w-blog-widget-post-listing .post_date','text-align','center','','','.w-blog-widget-post-listing'),(490286,'furniture-mobile','.w-blog-widget-post-linked-products .heading-2','text-align','center','','','.w-blog-widget-post-linked-products'),(490287,'furniture-mobile','.w-blog-widget-post-date ','text-align','center','','','.w-blog-widget-post-date'),(490288,'furniture-mobile','.checkbox input:checked + span:before','text-align','center','','',''),(490289,'furniture-mobile','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(490290,'furniture-mobile','.p-sample-checkout-success .page-success','text-align','center','','','.p-sample-checkout-success'),(490291,'furniture-mobile','.b-products-listing .products-listing .in-cart','text-align','center','','','.b-products-listing'),(490292,'furniture-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(490293,'furniture-mobile','.w-catalog-paging .prev','text-align','center','','','.w-catalog-paging'),(490294,'furniture-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(490295,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','text-align','center','3','','.w-checkout-contact-information'),(490298,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap','text-align','center','','','.b-fancybox'),(490299,'furniture-mobile','.b-email .model','text-align','center','','','.b-email'),(490300,'furniture-mobile','.p-account-trade-form .widget h3','text-align','center','','','.p-account-trade-form'),(490301,'furniture-mobile','.w-menu .hided.menu ul li','text-align','left','2885','','.w-menu'),(490302,'furniture-mobile','.w-sale .left','text-align','center','','','.w-sale'),(490303,'furniture-mobile','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(490304,'furniture-mobile','.w-menu-style-1 ul ul li','text-align','left','','','.w-menu-style-1'),(490305,'furniture-mobile','.w-menu-slider .menu-ico','text-align','center','','','.w-menu-slider'),(490306,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align','center','','','.w-catalog-paging'),(490307,'furniture-mobile','.w-catalog-paging .next','text-align','center','','','.w-catalog-paging'),(490308,'furniture-mobile','.w-banner .single_banner','text-align','center','','','.w-banner'),(490309,'furniture-mobile','.order-summary .price-row.ot_coupon .title','text-align','center','3','','.order-summary'),(490310,'furniture-mobile','.p-account-trade-form .widget h3','text-align','center','','','.p-account-trade-form'),(490311,'furniture-mobile','.p-account-trade-form .trade-form-area','text-align','center','','','.p-account-trade-form'),(490312,'furniture-mobile','h1, .heading-1','text-align','center','','',''),(490313,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','text-align','center','','','.w-communication-new-topic'),(490314,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','text-align','center','','','.w-communication-new-topic'),(490315,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(5), .w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(7)','text-align','center','','','.w-communication-new-topic'),(490317,'furniture-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(490318,'furniture-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(490319,'furniture-mobile','.w-menu .hided.menu ul li','text-align','left','2885','','.w-menu'),(490320,'furniture-mobile','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(490321,'furniture-mobile','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(490322,'furniture-mobile','.w-menu-style-1 .box','text-align','center','','','.w-menu-style-1'),(490323,'furniture-mobile','.b-email .model','text-align','center','','','.b-email'),(490324,'furniture-mobile','.w-menu-style-1 .menu-ico','text-align','center','','','.w-menu-style-1'),(490325,'furniture-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(490326,'furniture-mobile','.w-compare-box-item .checkbox:checked + span:before','text-align','center','','','.w-compare-box-item'),(490327,'furniture-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(490328,'furniture-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(490329,'furniture-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(490330,'furniture-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(490331,'furniture-mobile','.w-menu .hided.menu ul li','text-align','left','2885','','.w-menu'),(490332,'furniture-mobile','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(490333,'furniture-mobile','.w-sale .badge','text-align','center','','','.w-sale'),(490334,'furniture-mobile','.w-sale .btn','text-align','center','','','.w-sale'),(490335,'furniture-mobile','.w-sale .image','text-align','center','','','.w-sale'),(490336,'furniture-mobile','.w-sale .left','text-align','center','','','.w-sale'),(490337,'furniture-mobile','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(490338,'furniture-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(490339,'furniture-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(490340,'furniture-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(490341,'furniture-mobile','.b-email .price','text-align','right','','','.b-email'),(490342,'furniture-mobile','.b-email .heading-price','text-align','right','','','.b-email'),(490343,'furniture-mobile','.b-compare .compare-head','text-align','left','','','.b-compare'),(490344,'furniture-mobile','.w-menu-horizontal ul ul li','text-align','left','','','.w-menu-horizontal'),(490345,'furniture-mobile','.p-blog-index .form-submit','text-align','right','','','.p-blog-index'),(490346,'furniture-mobile','.w-search .suggest','text-align','left','','','.w-search'),(490347,'furniture-mobile','.b-email .heading-model','text-align','center','','','.b-email'),(490348,'furniture-mobile','.w-catalog-paging .page-number','text-align','center','','','.w-catalog-paging'),(490349,'furniture-mobile','.w-catalog-paging .p-blog-index','text-align','right','','','.w-catalog-paging'),(490350,'furniture-mobile','.w-catalog-listing-look .grid','text-align','center','','','.w-catalog-listing-look'),(490351,'furniture-mobile','.w-catalog-listing-look .b2b','text-align','center','','','.w-catalog-listing-look'),(490352,'furniture-mobile','.w-catalog-listing-look .list','text-align','center','','','.w-catalog-listing-look'),(490353,'furniture-mobile','.w-cart-listing .image','text-align','center','','','.w-cart-listing'),(490354,'furniture-mobile','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(490355,'furniture-mobile','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','text-align','left','','','.w-cart-listing'),(490356,'furniture-mobile','.w-cart-listing .points-earn','text-align','left','','','.w-cart-listing'),(490357,'furniture-mobile','.w-cart-listing .points-redeem','text-align','left','','','.w-cart-listing'),(490358,'furniture-mobile','.w-cart-listing .no-price .qty','text-align','right','','','.w-cart-listing'),(490359,'furniture-mobile','.w-cart-listing .remove-btn','text-align','center','','','.w-cart-listing'),(490360,'furniture-mobile','.w-cart-listing .price','text-align','right','','','.w-cart-listing'),(490361,'furniture-mobile','.w-cart-listing .remove','text-align','center','','','.w-cart-listing'),(490362,'furniture-mobile','.w-cart-listing .item .qty','text-align','right','2885','','.w-cart-listing'),(490363,'furniture-mobile','.w-cart-give-away .ga_img','text-align','center','','','.w-cart-give-away'),(490364,'furniture-mobile','.w-cart-discount-coupon .btn-remove','text-align','center','','','.w-cart-discount-coupon'),(490365,'furniture-mobile','.w-cart .price','text-align','right','','','.w-cart'),(490366,'furniture-mobile','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(490367,'furniture-mobile','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(490368,'furniture-mobile','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(490369,'furniture-mobile','.w-sale .badge','text-align','center','','','.w-sale'),(490370,'furniture-mobile','.w-menu-style-1 .menu-ico','text-align','center','','','.w-menu-style-1'),(490371,'furniture-mobile','.b-fancybox .fancybox-nav span','text-align','center','','','.b-fancybox'),(490372,'furniture-mobile','.w-success-continue-btn','text-align','center','2885','','.w-success-continue-btn'),(490373,'furniture-mobile','.w-tabs .accordion-heading','text-align','center','','','.w-tabs'),(490375,'furniture-mobile','.w-sale .badge','text-align','center','','','.w-sale'),(490376,'furniture-mobile','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(490377,'furniture-mobile','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(490378,'furniture-mobile','.w-menu-slider > ul > li > ul li','text-align','left','','','.w-menu-slider'),(490379,'furniture-mobile','.w-menu-style-1 > ul','text-align','center','','','.w-menu-style-1'),(490380,'furniture-mobile','.w-menu-slider .menu-ico','text-align','center','','','.w-menu-slider'),(490381,'furniture-mobile','.w-menu-slider > ul','text-align','center','','','.w-menu-slider'),(490382,'furniture-mobile','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','text-align','center','','','.p-quick-order-index'),(490383,'furniture-mobile','.p-blog-index .form-submit','text-align','right','','','.p-blog-index'),(490384,'furniture-mobile','.p-blog-index .nav-next','text-align','right','','','.p-blog-index'),(490385,'furniture-mobile','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(490386,'furniture-mobile','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(490387,'furniture-mobile','.w-login-block .buttons','text-align','right','','','.w-login-block'),(490388,'furniture-mobile','.w-menu-slider > ul','text-align','center','','','.w-menu-slider'),(490389,'furniture-mobile','.w-menu-slider .menu-ico','text-align','center','','','.w-menu-slider'),(490390,'furniture-mobile','.w-filters .handle-to','text-align','right','','','.w-filters'),(490391,'furniture-mobile','.order-summary .box','text-align','center','','','.order-summary'),(490392,'furniture-mobile','.p-reviews-info .review-info-image','text-align','center','','','.p-reviews-info'),(490393,'furniture-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(490394,'furniture-mobile','.w-catalog-paging ','text-align','center','2','','.w-catalog-paging'),(490395,'furniture-mobile','.b-bottom .pop-up-close','text-align','center','','','.b-bottom'),(490396,'furniture-mobile','.order-summary .price-row.ot_bonus_points .title','text-align','center','3','','.order-summary'),(490397,'furniture-mobile','.w-success-continue-btn','text-align','center','2885','','.w-success-continue-btn'),(490398,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','text-align','center','3','','.b-form'),(490399,'furniture-mobile','.b-social-login .social-login','text-align','center','','','.b-social-login'),(490400,'furniture-mobile','.p-blog-index .nav-next','text-align','right','','','.p-blog-index'),(490401,'furniture-mobile','.w-reviews-content .date','text-align','right','','','.w-reviews-content'),(490402,'furniture-mobile','.w-menu-style-1 .menu-ico','text-align','center','','','.w-menu-style-1'),(490403,'furniture-mobile','.w-menu-slider .close','text-align','center','','','.w-menu-slider'),(490404,'furniture-mobile','.b-data-table table.dataTable tbody td:last-child','text-align','right','','','.b-data-table'),(490405,'furniture-mobile','.b-data-table .dt-body-center','text-align','center','','','.b-data-table'),(490406,'furniture-mobile','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(490407,'furniture-mobile','.w-menu-big li a, .w-menu-big li .no-link','text-align','left','','','.w-menu-big'),(490408,'furniture-mobile','.w-menu-slider > ul > li > ul','text-align','center','','','.w-menu-slider'),(490409,'furniture-mobile','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(490410,'furniture-mobile','.b-upload-file .upload-file-template','text-align','center','','','.b-upload-file'),(490411,'furniture-mobile','.b-email-editor .price','text-align','center','','','.b-email-editor'),(490412,'furniture-mobile','.b-email .totals-value','text-align','right','','','.b-email'),(490413,'furniture-mobile','.b-email .totals-label','text-align','right','','','.b-email'),(490414,'furniture-mobile','.b-email .totals-title','text-align','right','','','.b-email'),(490415,'furniture-mobile','.b-email .qty','text-align','center','','','.b-email'),(490416,'furniture-mobile','.p-blog-index .nav-next','text-align','right','','','.p-blog-index'),(490417,'furniture-mobile','.p-blog-index .form-submit','text-align','right','','','.p-blog-index'),(490418,'furniture-mobile','.p-blog-index .form-submit','text-align','right','','','.p-blog-index'),(490419,'furniture-mobile','.b-upload-file .snapshot','text-align','center','','','.b-upload-file'),(490420,'furniture-mobile','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(490421,'furniture-mobile','.b-product-images .media-popup .mp-close','text-align','center','','','.b-product-images'),(490422,'furniture-mobile','.b-product-images .media-popup .mp-small-images','text-align','center','','','.b-product-images'),(490423,'furniture-mobile','.b-product-images .media-popup .mp-small-images .item','text-align','center','','','.b-product-images'),(490424,'furniture-mobile','.b-product-images .media-popup .slick-dots','text-align','center','','','.b-product-images'),(490425,'furniture-mobile','.b-product-images .media-popup .slick-dots li','text-align','center','','','.b-product-images'),(490426,'furniture-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','text-align','center','','','.b-menu-burger_icon'),(490427,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(490428,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(490429,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(490430,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(490431,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(490432,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(490433,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','text-align','center','','','.b-menu-style-2'),(490434,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','text-align','center','','','.b-menu-style-2'),(490435,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','text-align','right','','','.b-menu-style-2'),(490436,'furniture-mobile','.b-personal-catalog-popup #personal_catalog_popup','text-align','left','','','.b-personal-catalog-popup'),(490437,'furniture-mobile','.b-trade-approval .steps-bar li','text-align','center','','','.b-trade-approval'),(490438,'furniture-mobile','.b-trade-approval .steps-bar li a','text-align','center','','','.b-trade-approval'),(490439,'furniture-mobile','.b-trade-approval .orders-table td:nth-child(1), .b-trade-approval .orders-table th:nth-child(1)','text-align','left','','','.b-trade-approval'),(490440,'furniture-mobile','.b-trade-approval .orders-table td:nth-child(2)','text-align','right','','','.b-trade-approval'),(490441,'furniture-mobile','.b-trade-approval .w-login-block label','text-align','left','','','.b-trade-approval'),(490442,'furniture-mobile','.b-trade-approval .steps-bar','text-align','left','','','.b-trade-approval'),(490443,'furniture-mobile','.b-trade-approval .center-buttons','text-align','center','','','.b-trade-approval'),(490444,'furniture-mobile','.b-trade-approval .comments','text-align','left','','','.b-trade-approval'),(490445,'furniture-mobile','.batchPr .w-batch-products .products-listing .image + .type-1','text-align','left','','','.batchPr'),(490446,'furniture-mobile','.batchPr .checkbox input:not(checked) + span:before','text-align','center','','','.batchPr'),(490447,'furniture-mobile','.batchPr .checkbox input + span','text-align','center','','','.batchPr'),(490448,'furniture-mobile','.batchPr .btn-batch-remove','text-align','center','3','','.batchPr'),(490449,'furniture-mobile','.batchPr .buttons','text-align','center','','','.batchPr'),(490450,'furniture-mobile','.batchPr .batchSelect .checkbox','text-align','center','','','.batchPr'),(490451,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .type-1','text-align','left','','','.batchPr'),(490452,'furniture-mobile','.batchPr .checkbox input:checked + span:before','text-align','center','','','.batchPr'),(490453,'furniture-mobile','.batchPr .batch-selected-products-empty','text-align','center','','','.batchPr'),(490454,'furniture-mobile','.batchPr .batch-selected-products-total','text-align','center','','','.batchPr'),(490455,'furniture-mobile','.w-account-personal-catalog .list-switcher a','text-align','center','','','.w-account-personal-catalog'),(490456,'furniture-mobile','.w-catalog-additional-images ul, .w-catalog-additional-images li','text-align','center','','','.w-catalog-additional-images'),(490457,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','text-align','center','','','.w-catalog-compare'),(490458,'furniture-mobile','.w-delivery-day .time-left','text-align','center','','','.w-delivery-day'),(490459,'furniture-mobile','.w-top-text .top-text','text-align','center','','','.w-top-text'),(490460,'furniture-mobile','.b-cookie-notice .cookie-notice','text-align','center','','','.b-cookie-notice'),(490461,'furniture-mobile','.w-cart .cart-box-link','text-align','center','3','','.w-cart'),(490462,'furniture-mobile','.w-account .my-acc-link','text-align','center','3','','.w-account'),(490463,'furniture-mobile','.w-account .account-dropdown','text-align','center','3','','.w-account'),(490464,'furniture-mobile','.preFooter .test','text-align','center','','','.preFooter'),(490465,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','text-align','center','','','.b-slick'),(490466,'furniture-mobile','.w-search .search-ico','text-align','center','2885,3','','.w-search'),(490467,'furniture-mobile','.menu-header .burger-icon','text-align','center','2885','','.menu-header'),(490468,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','text-align','center','','','.b-products-listing'),(490469,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item:hover .item-wrapper','text-align','center','','','.b-products-listing'),(490470,'furniture-mobile','.b-products-listing .item-nav > div','text-align','center','','','.b-products-listing'),(490471,'furniture-mobile','.w-quote .cart-box-link','text-align','center','3','','.w-quote'),(490472,'furniture-mobile','.w-quote .price','text-align','right','','','.w-quote'),(490473,'furniture-mobile','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(490474,'furniture-mobile','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(490475,'furniture-mobile','.b-quantity .qty-box input','text-align','center','','','.b-quantity'),(490476,'furniture-mobile','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(490477,'furniture-mobile','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(490478,'furniture-mobile','.productNavigation .test','text-align','center','','','.productNavigation'),(490479,'furniture-mobile','.w-product-sale-ends .ends','text-align','center','','','.w-product-sale-ends'),(490480,'furniture-mobile','.w-product-sale-ends .left','text-align','center','','','.w-product-sale-ends'),(490481,'furniture-mobile','.heading-2, h2, .h-block h2','text-align','center','','',''),(490482,'furniture-mobile','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','text-align','center','','','.w-product-buttons'),(490483,'furniture-mobile','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(490484,'furniture-mobile','.w-product-quantity .qty-input','text-align','left','','','.w-product-quantity'),(490485,'furniture-mobile','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(490486,'furniture-mobile','.w-files-catalog-widgets-files-catalog .item','text-align','center','','','.w-files-catalog-widgets-files-catalog'),(490487,'furniture-mobile','.w-sample .cart-box-link','text-align','center','3','','.w-sample'),(490488,'furniture-mobile','.w-sample .price','text-align','right','','','.w-sample'),(490489,'furniture-mobile','.w-cart-listing .item > div.points','text-align','right','','','.w-cart-listing'),(490490,'furniture-mobile','.w-filters-simple .integrate-price-holder','text-align','right','','','.w-filters-simple'),(490491,'furniture-mobile','.w-cart-sub-total .price','text-align','right','','','.w-cart-sub-total'),(490492,'furniture-mobile','.w-product-images .additional-horizontal .item','text-align','center','','','.w-product-images'),(490493,'furniture-mobile','.w-product-video .frame-video','text-align','center','','','.w-product-video'),(490494,'furniture-mobile','.w-product-video .item','text-align','center','','','.w-product-video'),(490495,'furniture-mobile','.w-product-bundle .bundle-total-price','text-align','right','','','.w-product-bundle'),(490496,'furniture-mobile','.w-product-in-bundles .bundle-total-price','text-align','right','','','.w-product-in-bundles'),(490497,'furniture-mobile','.b-bottom .cart-options .cart-item','text-align','center','','','.b-bottom'),(490498,'furniture-mobile','.w-cart-listing .item div.price','text-align','right','2885','','.w-cart-listing'),(490499,'furniture-mobile','.w-sample-products .w-cart-listing .item .qty','text-align','right','2876','','.w-sample-products'),(490500,'furniture-mobile','.w-account-address-book .add_item','text-align','center','','','.w-account-address-book'),(490501,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','text-align','inherit','','','.b-products-listing'),(490502,'furniture-mobile','.b-pagination .pagination .next-pages','text-align','center','','','.b-pagination'),(490503,'furniture-mobile','.b-pagination .pagination .p-blog-index','text-align','right','','','.b-pagination'),(490504,'furniture-mobile','.b-pagination .pagination .page-number','text-align','center','','','.b-pagination'),(490505,'furniture-mobile','.b-pagination .pagination .prev-pages','text-align','center','','','.b-pagination'),(490506,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','text-align','center','','','.b-pagination'),(490507,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','text-align','center','','','.b-pagination'),(490508,'furniture-mobile','.b-pagination .pagination span','text-align','center','2','','.b-pagination'),(490509,'furniture-mobile','.p-quote-checkout-index .heading-2','text-align','left','','','.p-quote-checkout-index'),(490510,'furniture-mobile','.p-sample-checkout-index .heading-2','text-align','left','','','.p-sample-checkout-index'),(490511,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','text-align','center','','','.p-quote-checkout-index'),(490512,'furniture-mobile','.w-sample-products .w-cart-listing .qty','text-align','center','','','.w-sample-products'),(490513,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','text-align','center','','','.p-sample-checkout-index'),(490514,'furniture-mobile','.w-account-order-download td:nth-child(4)','text-align','right','','','.w-account-order-download'),(490515,'furniture-mobile','.w-quote-products .cart-listing .qty','text-align','right','','','.w-quote-products'),(490516,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','text-align','center','','','.w-product-multi-inventory'),(490517,'furniture-mobile','.w-account-personal-catalog .check-box','text-align','center','','','.w-account-personal-catalog'),(490518,'furniture-mobile','.w-account-personal-catalog .remove','text-align','center','','','.w-account-personal-catalog'),(490519,'furniture-mobile','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','text-align','center','','','.w-account-personal-catalog'),(490520,'furniture-mobile','.w-account-personal-catalog .w-cart-listing .item .remove','text-align','center','2885','','.w-account-personal-catalog'),(490521,'furniture-mobile','.b-products-listing .products-listing.list-rows .qtyInput','text-align','center','','','.b-products-listing'),(490522,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','text-align','center','','','.b-products-listing'),(490523,'furniture-mobile','.b-products-listing .products-listing.list-b2b .qtyInput','text-align','center','','','.b-products-listing'),(490524,'furniture-mobile','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(490525,'furniture-mobile','.w-product-collection .item','text-align','center','','','.w-product-collection'),(490526,'furniture-mobile','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(490527,'furniture-mobile','.w-product-collection .choose-products .heading-3','text-align','center','','','.w-product-collection'),(490528,'furniture-mobile','.w-account-customer-additional-field .add-buttons','text-align','right','','','.w-account-customer-additional-field'),(490529,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','text-align','center','','','.w-product-attributes'),(490530,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','text-align','center','','','.w-questionnaire-widgets-questionnaire'),(490531,'furniture-mobile','.w-product-groups .val1','text-align','center','','','.w-product-groups'),(490532,'furniture-mobile','.w-product-groups .prop-group-swatch','text-align','center','','','.w-product-groups'),(490533,'furniture-mobile','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img + .val2','text-align','center','','','.w-product-groups'),(490534,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block > span','text-align','center','','','.b-products-listing'),(490535,'furniture-mobile','.w-product-custom-bundle .heading-3','text-align','center','','','.w-product-custom-bundle'),(490536,'furniture-mobile','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(490537,'furniture-mobile','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(490538,'furniture-mobile','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(490539,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','text-align','center','','','.w-catalog-pages-category-pages-last-list'),(490540,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','text-align','center','','','.w-catalog-pages-category-pages-last-list-block'),(490541,'furniture-mobile','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(490542,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','text-align','center','','','.w-delivery-location-location-list'),(490543,'furniture-mobile','.w-sale-category .badge','text-align','center','','','.w-sale-category'),(490544,'furniture-mobile','.w-sale-category .btn','text-align','center','','','.w-sale-category'),(490545,'furniture-mobile','.w-sale-category .image','text-align','center','','','.w-sale-category'),(490546,'furniture-mobile','.w-sale-category .left','text-align','center','','','.w-sale-category'),(490547,'furniture-mobile','.w-wedding-registry-widgets-products .price','text-align','center','','','.w-wedding-registry-widgets-products'),(490548,'furniture-mobile','.w-wedding-registry-widgets-products .qty-input','text-align','center','','','.w-wedding-registry-widgets-products'),(490549,'furniture-mobile','.w-success-download table','text-align','center','','','.w-success-download'),(490550,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-img','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(490551,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-name','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(490552,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(490553,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-img','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(490554,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-name','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(490555,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(490556,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description + div','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(490557,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(490558,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(490559,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description + div','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(490560,'furniture-mobile','.w-product-properties-icons .hover-box-content','text-align','center','','','.w-product-properties-icons'),(490561,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','text-align','center','','','.w-delivery-location-product-categories'),(490562,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','text-align','center','','','.w-wedding-registry-widgets-search-paging'),(490563,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','text-align','center','','','.w-wedding-registry-widgets-search-paging'),(490564,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','text-align','center','','','.w-wedding-registry-widgets-search-paging'),(490565,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','text-align','center','','','.w-wedding-registry-widgets-search-paging'),(490566,'furniture-mobile','.w-wedding-registry-widgets-search-list .test','text-align','center','','','.w-wedding-registry-widgets-search-list'),(490567,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','text-align','left','','','.w-product-bonus-points'),(490568,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','text-align','right','','','.w-press-reviews-widgets-press-reviews-small'),(490569,'furniture-mobile','.w-press-reviews-widgets-press-reviews .date','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(490570,'furniture-mobile','.w-press-reviews-widgets-press-reviews .heading-3','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(490571,'furniture-mobile','.w-press-reviews-widgets-press-reviews .image','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(490572,'furniture-mobile','.w-press-reviews-widgets-press-reviews .item','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(490573,'furniture-mobile','.w-press-reviews-widgets-press-reviews .press-reviews-button','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(490574,'furniture-mobile','.w-press-reviews-widgets-press-reviews .sub-box','text-align','left','','','.w-press-reviews-widgets-press-reviews'),(490575,'furniture-mobile','.w-press-reviews-widgets-press-reviews .author','text-align','center','2876','','.w-press-reviews-widgets-press-reviews'),(490576,'furniture-mobile','.w-press-reviews-widgets-press-reviews .date','text-align','center','2876','','.w-press-reviews-widgets-press-reviews'),(490577,'furniture-mobile','.w-press-reviews-widgets-press-reviews .image','text-align','center','2876','','.w-press-reviews-widgets-press-reviews'),(490578,'furniture-mobile','.w-press-reviews-widgets-press-reviews .rating','text-align','center','2876','','.w-press-reviews-widgets-press-reviews'),(490579,'furniture-mobile','.w-press-reviews-widgets-press-reviews .review','text-align','center','2876','','.w-press-reviews-widgets-press-reviews'),(490580,'furniture-mobile','.w-press-reviews-widgets-press-reviews .title','text-align','center','2876','','.w-press-reviews-widgets-press-reviews'),(490581,'furniture-mobile','.w-press-reviews-widgets-press-reviews-list .review-box ul li','text-align','left','','','.w-press-reviews-widgets-press-reviews-list'),(490582,'furniture-mobile','.w-support-system-listing .product_icon','text-align','center','','','.w-support-system-listing'),(490583,'furniture-mobile','.w-rma-returns-history .btn','text-align','center','','','.w-rma-returns-history'),(490584,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','text-align','center','','','.w-rma-returns-history'),(490585,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(490586,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(490587,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(490588,'furniture-mobile','.w-banner .image-text-banner.bottom-center .text-banner','text-align','center','','','.w-banner'),(490589,'furniture-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner','text-align','center','','','.w-banner'),(490590,'furniture-mobile','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(490591,'furniture-mobile','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(490592,'furniture-mobile','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(490593,'furniture-mobile','.w-product-configurator .pc_qty','text-align','left','2876','','.w-product-configurator'),(490594,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','text-align','left','','','.b-products-listing'),(490595,'furniture-mobile','.b-products-listing .promo-icon','text-align','center','','','.b-products-listing'),(490596,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','text-align','center','','','.w-catalog-pages-category-pages-list'),(490597,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .heading','text-align','center','','','.w-predefined-promotion'),(490598,'furniture-mobile','.w-predefined-promotion .promo-date','text-align','center','','','.w-predefined-promotion'),(490599,'furniture-mobile','.w-predefined-promotion .promo-item','text-align','center','','','.w-predefined-promotion'),(490600,'furniture-mobile','.w-supplier-purchase-supplier-products .active .select_item > div','text-align','center','','','.w-supplier-purchase-supplier-products'),(490601,'furniture-mobile','.mainBanner .bottomBox','text-align','center','','','.mainBanner'),(490602,'furniture-mobile','.mainBanner .buttonBox','text-align','right','','','.mainBanner'),(490603,'furniture-mobile','.mainBanner .content','text-align','center','','','.mainBanner'),(490604,'furniture-mobile','.mainBanner .topBox','text-align','center','','','.mainBanner'),(490605,'furniture-mobile','.mainBanner .topBox','text-align','left','2876','','.mainBanner'),(490606,'furniture-mobile','.lowestPricedBox .w-banner .ybg','text-align','center','','','.lowestPricedBox'),(490607,'furniture-mobile','.shopByCollectionBox .content .title','text-align','left','','','.shopByCollectionBox'),(490608,'furniture-mobile','.account-address-book .address_book h2','text-align','right','','','.account-address-book'),(490609,'furniture-mobile','.account-order-history .orders-table td.td-alignright','text-align','right','','','.account-order-history'),(490610,'furniture-mobile','.account-order-history .orders-table th','text-align','left','','','.account-order-history'),(490611,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','text-align','left','','','.account-order-history-info'),(490612,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','text-align','left','3','','.account-order-history-info'),(490613,'furniture-mobile','.account-order-history-info .popup-tracking-number','text-align','center','','','.account-order-history-info'),(490614,'furniture-mobile','.account-order-history-info .tableForm th','text-align','left','','','.account-order-history-info'),(490615,'furniture-mobile','.account-order-history-info .trackings-nambers','text-align','center','','','.account-order-history-info'),(490616,'furniture-mobile','.account-index .badc_bottom','text-align','center','','','.account-index'),(490617,'furniture-mobile','.account-index .remove-btn','text-align','center','','','.account-index'),(490618,'furniture-mobile','.account-index .topAccount > li > div','text-align','center','3','','.account-index'),(490619,'furniture-mobile','.account-index .topAccount > li > div','text-align','center','','','.account-index'),(490620,'furniture-mobile','.account-index td.td-alignright','text-align','right','','','.account-index'),(490621,'furniture-mobile','.account-index th, .account-index td','text-align','left','','','.account-index'),(490622,'furniture-mobile','.account-index th.wish_remove_title, .account-index td.acc_wish_remove','text-align','center','','','.account-index'),(490623,'furniture-mobile','.account-index .topAccount > li > div','text-align','left','2876','','.account-index'),(490624,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-align','left','','','.account-order-pay'),(490625,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-align','left','3','','.account-order-pay'),(490626,'furniture-mobile','.account-order-pay .tableForm th','text-align','left','','','.account-order-pay'),(490627,'furniture-mobile','.account-samples .orders-table td.td-alignright','text-align','right','','','.account-samples'),(490628,'furniture-mobile','.account-samples .orders-table th','text-align','left','','','.account-samples'),(490629,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-align','left','','','.account-sample-info'),(490630,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-align','left','3','','.account-sample-info'),(490631,'furniture-mobile','.account-sample-info .popup-tracking-number','text-align','center','','','.account-sample-info'),(490632,'furniture-mobile','.account-sample-info .tableForm th','text-align','left','','','.account-sample-info'),(490633,'furniture-mobile','.account-sample-info .trackings-nambers','text-align','center','','','.account-sample-info'),(490634,'furniture-mobile','.catalog-product-wrap .prev-next-product','text-align','center','','','.catalog-product-wrap'),(490635,'furniture-mobile','.shopping-cart-index .cart-page .empty','text-align','center','','','.shopping-cart-index'),(490636,'furniture-mobile','.checkout-index-wrap .heading-2','text-align','left','','','.checkout-index-wrap'),(490637,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','text-align','center','','','.checkout-index-wrap'),(490638,'furniture-mobile','.checkout-order-confirmation .heading-2.prod-ico','text-align','left','','','.checkout-order-confirmation'),(490639,'furniture-mobile','.checkout-order-confirmation .price-box .title','text-align','left','','','.checkout-order-confirmation'),(490640,'furniture-mobile','.checkout-success-wrap .page-success','text-align','center','','','.checkout-success-wrap'),(490641,'furniture-mobile','.w-success-continue-btn','text-align_important','important','2885','','.w-success-continue-btn'),(490642,'furniture-mobile','.w-success-continue-btn','text-align_important','important','2885','','.w-success-continue-btn'),(490643,'furniture-mobile','.w-success-continue-btn','text-align_important','important','2885','','.w-success-continue-btn'),(490644,'furniture-mobile','.w-success-continue-btn','text-align_important','important','2885','','.w-success-continue-btn'),(490645,'furniture-mobile','.w-success-continue-btn','text-align_important','important','2885','','.w-success-continue-btn'),(490646,'furniture-mobile','.w-success-continue-btn','text-align_important','important','2885','','.w-success-continue-btn'),(490647,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align_important','important','','','.w-catalog-paging'),(490648,'furniture-mobile','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align_important','important','','','.p-quick-order-index'),(490649,'furniture-mobile','.p-blog-index a','text-decoration','none','1','','.p-blog-index'),(490650,'furniture-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(490651,'furniture-mobile','.b-fancybox a.fancybox-close','text-decoration','none','1','','.b-fancybox'),(490652,'furniture-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(490653,'furniture-mobile','.p-blog-index a','text-decoration','none','1','','.p-blog-index'),(490654,'furniture-mobile','.w-chat .w-chat-box a','text-decoration','none','1','','.w-chat'),(490655,'furniture-mobile','.w-cart a.item','text-decoration','none','1','','.w-cart'),(490656,'furniture-mobile','.p-blog-index a','text-decoration','none','1','','.p-blog-index'),(490657,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(490658,'furniture-mobile','.w-sale .old','text-decoration','line-through','','','.w-sale'),(490659,'furniture-mobile','.w-socials > li a','text-decoration','none','','','.w-socials'),(490660,'furniture-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(490661,'furniture-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(490662,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','text-decoration','none','1','','.w-menu-style-1'),(490663,'furniture-mobile','.price .old','text-decoration','line-through','','',''),(490664,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(490665,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','text-decoration','none','1','','.w-menu-style-1'),(490666,'furniture-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(490667,'furniture-mobile','.b-select-suggest .select2-result-selectable .select2-match, .b-select-suggest .select2-result-unselectable .select2-match','text-decoration','underline','','','.b-select-suggest'),(490668,'furniture-mobile','.w-socials > li a','text-decoration','none','','','.w-socials'),(490669,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(490670,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','text-decoration','none','1','','.w-menu-style-1'),(490671,'furniture-mobile','.w-tabs .tab-a','text-decoration','none','','','.w-tabs'),(490672,'furniture-mobile','.w-socials > li a','text-decoration','none','','','.w-socials'),(490673,'furniture-mobile','.btn-edit','text-decoration','none','1','',''),(490674,'furniture-mobile','.w-socials > li a','text-decoration','none','','','.w-socials'),(490675,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(490676,'furniture-mobile','.heading-3 .right-text, h3 .right-text','text-decoration','none','','',''),(490677,'furniture-mobile','.w-sale .old','text-decoration','line-through','','','.w-sale'),(490678,'furniture-mobile','.w-socials > li a','text-decoration','none','','','.w-socials'),(490679,'furniture-mobile','.w-image-maps .categories-items .item a','text-decoration','none','1','','.w-image-maps'),(490680,'furniture-mobile','.w-sale .old','text-decoration','line-through','','','.w-sale'),(490681,'furniture-mobile','.w-social-links a','text-decoration','none','1','','.w-social-links'),(490682,'furniture-mobile','.w-chat .w-chat-box a','text-decoration','none','','','.w-chat'),(490683,'furniture-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(490684,'furniture-mobile','.w-socials > li a','text-decoration','none','','','.w-socials'),(490685,'furniture-mobile','.w-sale .old','text-decoration','line-through','','','.w-sale'),(490686,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(490687,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(490688,'furniture-mobile','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(490689,'furniture-mobile','.w-catalog-paging a','text-decoration','none','1','','.w-catalog-paging'),(490690,'furniture-mobile','.w-catalog-paging span','text-decoration','none','1','','.w-catalog-paging'),(490691,'furniture-mobile','.p-blog-index a','text-decoration','none','1','','.p-blog-index'),(490692,'furniture-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(490693,'furniture-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(490694,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(490695,'furniture-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(490696,'furniture-mobile','.p-blog-index a','text-decoration','none','1','','.p-blog-index'),(490697,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','text-decoration','none','1','','.w-menu-style-1'),(490698,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(490699,'furniture-mobile','.w-blog-widget-post-share a','text-decoration','none','1','','.w-blog-widget-post-share'),(490700,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','text-decoration','none','','','.b-select-suggest'),(490701,'furniture-mobile','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(490702,'furniture-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(490703,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(490704,'furniture-mobile','.w-sale .old','text-decoration','line-through','','','.w-sale'),(490705,'furniture-mobile','.w-sale .old','text-decoration','line-through','','','.w-sale'),(490706,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(490707,'furniture-mobile','.w-cart-listing .remove-btn','text-decoration','none','','','.w-cart-listing'),(490708,'furniture-mobile','.w-cart .multicart a.name','text-decoration','none','1','','.w-cart'),(490709,'furniture-mobile','.w-cart .multicart a.switch-cart','text-decoration','none','1','','.w-cart'),(490710,'furniture-mobile','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(490711,'furniture-mobile','.w-image-maps .float-items .item a','text-decoration','none','1','','.w-image-maps'),(490712,'furniture-mobile','.b-fancybox .fancybox-nav','text-decoration','none','','','.b-fancybox'),(490713,'furniture-mobile','.w-tabs .accordion-heading','text-decoration','none','','','.w-tabs'),(490714,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','text-decoration','none','1','','.w-menu-style-1'),(490715,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(490716,'furniture-mobile','.p-blog-index a','text-decoration','none','1','','.p-blog-index'),(490717,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','text-decoration','none','1','','.w-menu-style-1'),(490718,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','text-decoration','none','','','.b-select-suggest'),(490719,'furniture-mobile','.w-filters .mobileCollapse','text-decoration','none','1','','.w-filters'),(490720,'furniture-mobile','.w-account-personal-catalog .list-switcher a','text-decoration','none','','','.w-account-personal-catalog'),(490721,'furniture-mobile','.w-cart a.cart-box-link','text-decoration','none','1','','.w-cart'),(490722,'furniture-mobile','.w-account a.my-acc-link','text-decoration','none','1','','.w-account'),(490723,'furniture-mobile','.LeftCategories ul li a','text-decoration','none','1','','.LeftCategories'),(490724,'furniture-mobile','.w-quote .multicart a.name','text-decoration','none','1','','.w-quote'),(490725,'furniture-mobile','.w-quote .multicart a.switch-cart','text-decoration','none','1','','.w-quote'),(490726,'furniture-mobile','.w-quote a.cart-box-link','text-decoration','none','1','','.w-quote'),(490727,'furniture-mobile','.w-quote a.item','text-decoration','none','1','','.w-quote'),(490728,'furniture-mobile','.w-sample .multicart a.name','text-decoration','none','1','','.w-sample'),(490729,'furniture-mobile','.w-sample .multicart a.switch-cart','text-decoration','none','1','','.w-sample'),(490730,'furniture-mobile','.w-sample a.cart-box-link','text-decoration','none','1','','.w-sample'),(490731,'furniture-mobile','.w-sample a.item','text-decoration','none','1','','.w-sample'),(490732,'furniture-mobile','.w-product-bundle .bundle_price .old','text-decoration','line-through','','','.w-product-bundle'),(490733,'furniture-mobile','.w-product-in-bundles .bundle_price .old','text-decoration','line-through','','','.w-product-in-bundles'),(490734,'furniture-mobile','.b-pagination .pagination a','text-decoration','none','1','','.b-pagination'),(490735,'furniture-mobile','.b-pagination .pagination span','text-decoration','none','1','','.b-pagination'),(490736,'furniture-mobile','.w-delivery-location-location-list .deliveryList li a','text-decoration','none','1','','.w-delivery-location-location-list'),(490737,'furniture-mobile','.w-sale-category .old','text-decoration','line-through','','','.w-sale-category'),(490738,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination a','text-decoration','none','1','','.w-wedding-registry-widgets-search-paging'),(490739,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination span','text-decoration','none','1','','.w-wedding-registry-widgets-search-paging'),(490740,'furniture-mobile','.w-wedding-registry-widgets-products .remove a','text-decoration','none','1','','.w-wedding-registry-widgets-products'),(490741,'furniture-mobile','.w-checkout-shipping-address .change-ab','text-decoration','underline','','','.w-checkout-shipping-address'),(490742,'furniture-mobile','.w-checkout-shipping-address .change-ab','text-decoration','none','1','','.w-checkout-shipping-address'),(490743,'furniture-mobile','.w-checkout-shipping-address .edit-ab','text-decoration','underline','','','.w-checkout-shipping-address'),(490744,'furniture-mobile','.w-checkout-shipping-address .edit-ab','text-decoration','none','1','','.w-checkout-shipping-address'),(490745,'furniture-mobile','.w-checkout-contact-information .btn-edit1','text-decoration','underline','','','.w-checkout-contact-information'),(490746,'furniture-mobile','.w-checkout-contact-information .btn-edit1','text-decoration','none','1','','.w-checkout-contact-information'),(490747,'furniture-mobile','.w-search .item a','text-decoration','none','1','','.w-search'),(490748,'furniture-mobile','.account-order-history .orders-table a, .account-order-history .order-info a','text-decoration','none','1','','.account-order-history'),(490749,'furniture-mobile','.account-order-history .view_link','text-decoration','underline','','','.account-order-history'),(490750,'furniture-mobile','.account-index .orders-table a, .account-index .order-info a','text-decoration','none','1','','.account-index'),(490751,'furniture-mobile','.account-index .remove-btn','text-decoration','none','','','.account-index'),(490752,'furniture-mobile','.account-index .view_history','text-decoration','underline','','','.account-index'),(490753,'furniture-mobile','.account-samples .orders-table a, .account-samples .order-info a','text-decoration','none','1','','.account-samples'),(490754,'furniture-mobile','.account-samples .view_link','text-decoration','underline','','','.account-samples'),(490755,'furniture-mobile','.catalog-product-wrap a.prev-next-product','text-decoration','none','1','','.catalog-product-wrap'),(490756,'furniture-mobile','.checkout-index-wrap .edit-address-popup .edit-ab','text-decoration','underline','','','.checkout-index-wrap'),(490757,'furniture-mobile','.checkout-index-wrap .edit-address-popup .edit-ab','text-decoration','none','1','','.checkout-index-wrap'),(490758,'furniture-mobile','.batchPr .btn-batch-remove','text-indent','-33333em','','','.batchPr'),(490759,'furniture-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','text-overflow','ellipsis','','','.b-select-suggest'),(490760,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(490761,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(490762,'furniture-mobile','.b-fancybox .fancybox-skin','text-shadow','none','','','.b-fancybox'),(490763,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(490764,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(490765,'furniture-mobile','.b-fancybox .fancybox-title','text-shadow','none','','','.b-fancybox'),(490766,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(490767,'furniture-mobile','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(490769,'furniture-mobile','.heading-4 .right-text, h4 .right-text','text-transform','none','','',''),(490770,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(490771,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-transform','uppercase','','','.b-switch'),(490772,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','text-transform','none','','','.p-account-subscription-historyinfo'),(490773,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(490774,'furniture-mobile','.p-sample-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-sample-checkout-success'),(490775,'furniture-mobile','.p-sample-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-sample-checkout-success'),(490776,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(490777,'furniture-mobile','.w-promotions .heading-3','text-transform','uppercase','','','.w-promotions'),(490778,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(490779,'furniture-mobile','.b-messages .content-messages .heading-2','text-transform','none','','','.b-messages'),(490780,'furniture-mobile','.heading-4 .edit, h4 .edit','text-transform','none','','',''),(490781,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','text-transform','uppercase','4','','.b-switch'),(490782,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','text-transform','uppercase','','','.p-account-trade-form'),(490783,'furniture-mobile','.p-account-trade-form .widget h3','text-transform','uppercase','','','.p-account-trade-form'),(490784,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','text-transform','none','','','.p-account-subscription-historyinfo'),(490785,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','text-transform','uppercase','','','.p-account-subscription-historyinfo'),(490787,'furniture-mobile','.p-account-trade-form .widget h3','text-transform','uppercase','','','.p-account-trade-form'),(490788,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','text-transform','none','','','.p-account-subscription-historyinfo'),(490789,'furniture-mobile','.p-account-trade-form .widget h3','text-transform','uppercase','','','.p-account-trade-form'),(490790,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','text-transform','none','','','.p-account-subscription-historyinfo'),(490791,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','text-transform','uppercase','','','.p-account-subscription-historyinfo'),(490792,'furniture-mobile','.w-personal-gift-status-bar .end-date','text-transform','uppercase','','','.w-personal-gift-status-bar'),(490793,'furniture-mobile','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(490794,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','text-transform','none','','','.p-account-subscription-historyinfo'),(490795,'furniture-mobile','.b-info .info strong','text-transform','uppercase','','','.b-info'),(490796,'furniture-mobile','.b-info .info strong','text-transform','uppercase','','','.b-info'),(490797,'furniture-mobile','.w-checkout-shipping-choice span','text-transform','uppercase','','','.w-checkout-shipping-choice'),(490798,'furniture-mobile','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(490799,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(490801,'furniture-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(490802,'furniture-mobile','.w-account-address-book .btn-edit','text-transform','none','','','.w-account-address-book'),(490803,'furniture-mobile','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(490804,'furniture-mobile','.w-cart-compare .cart-name a','text-transform','uppercase','','','.w-cart-compare'),(490806,'furniture-mobile','.heading-3 .edit, h3 .edit','text-transform','none','','',''),(490807,'furniture-mobile','.b-info .info strong','text-transform','uppercase','','','.b-info'),(490808,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(490809,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','text-transform','uppercase','4','','.b-switch'),(490810,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','text-transform','uppercase','4','','.b-switch'),(490811,'furniture-mobile','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','text-transform','uppercase','','','.w-multi-cart-cart-switcher'),(490812,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','text-transform','uppercase','','','.p-account-subscription-historyinfo'),(490813,'furniture-mobile','.p-account-trade-form .widget h3','text-transform','uppercase','','','.p-account-trade-form'),(490814,'furniture-mobile','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(490815,'furniture-mobile','.w-top-categories .categories h2','text-transform','inherit','','','.w-top-categories'),(490817,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-transform','uppercase','','','.b-switch'),(490818,'furniture-mobile','.b-info .info strong','text-transform','uppercase','','','.b-info'),(490819,'furniture-mobile','.w-categories h2.name','text-transform','uppercase','','','.w-categories'),(490820,'furniture-mobile','.p-account-trade-form .widget h3','text-transform','uppercase','','','.p-account-trade-form'),(490821,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','text-transform','uppercase','','','.p-account-trade-form'),(490822,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table th','text-transform','none','','','.p-account-subscription-historyinfo'),(490823,'furniture-mobile','.b-bottom .cart-options .heading-4','text-transform','none','','','.b-bottom'),(490824,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(490825,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(490829,'furniture-mobile','.b-info .info strong','text-transform','uppercase','','','.b-info'),(490830,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','text-transform','uppercase','','','.p-account-trade-form'),(490831,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(490832,'furniture-mobile','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(490834,'furniture-mobile','.w-personal-gift-status-bar .inform','text-transform','uppercase','','','.w-personal-gift-status-bar'),(490835,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(490836,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','text-transform','uppercase','','','.p-account-subscription-historyinfo'),(490837,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','text-transform','uppercase','','','.p-account-subscription-historyinfo'),(490838,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','text-transform','uppercase','','','.p-account-trade-form'),(490839,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','text-transform','none','','','.b-products-listing'),(490840,'furniture-mobile','.w-blog-widget-tag-cloud a','text-transform','uppercase','','','.w-blog-widget-tag-cloud'),(490841,'furniture-mobile','.w-blog-widget-related-posts-by-category .post_content a','text-transform','uppercase','','','.w-blog-widget-related-posts-by-category'),(490842,'furniture-mobile','.w-blog-widget-post-title h1','text-transform','none','','','.w-blog-widget-post-title'),(490843,'furniture-mobile','.w-blog-widget-post-listing .post_name a','text-transform','uppercase','','','.w-blog-widget-post-listing'),(490845,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','text-transform','uppercase','','','.p-account-trade-form'),(490846,'furniture-mobile','.w-top-categories h2.name','text-transform','uppercase','','','.w-top-categories'),(490847,'furniture-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','text-transform','none','','','.w-taxable'),(490848,'furniture-mobile','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','text-transform','none','','','.w-taxable'),(490849,'furniture-mobile','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','text-transform','inherit','','',''),(490850,'furniture-mobile','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','text-transform','inherit','','','.b-h-inline'),(490851,'furniture-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(490852,'furniture-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(490855,'furniture-mobile','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(490856,'furniture-mobile','.b-info .info strong','text-transform','uppercase','','','.b-info'),(490857,'furniture-mobile','.p-account-subscription-historyinfo .order_history_table h2','text-transform','uppercase','','','.p-account-subscription-historyinfo'),(490858,'furniture-mobile','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','text-transform','uppercase','','','.w-cart-listing'),(490859,'furniture-mobile','.w-cart .multicart .title','text-transform','uppercase','','','.w-cart'),(490860,'furniture-mobile','.w-tabs .accordion-heading','text-transform','uppercase','','','.w-tabs'),(490861,'furniture-mobile','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(490862,'furniture-mobile','.blogsidebar .heading-title','text-transform','uppercase','','','.blogsidebar'),(490863,'furniture-mobile','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(490864,'furniture-mobile','.p-account-trade-form .widget h3, .p-account-trade-form .widget h4','text-transform','uppercase','','','.p-account-trade-form'),(490865,'furniture-mobile','.p-account-trade-form .widget h3','text-transform','uppercase','','','.p-account-trade-form'),(490866,'furniture-mobile','.batchPr .batchSelect .checkbox','text-transform','uppercase','','','.batchPr'),(490867,'furniture-mobile','.w-account-personal-catalog .list-switcher a','text-transform','uppercase','','','.w-account-personal-catalog'),(490868,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','text-transform','uppercase','','','.b-menu-style-1'),(490869,'furniture-mobile','.b-products-listing .products-listing .name a','text-transform','uppercase','','','.b-products-listing'),(490870,'furniture-mobile','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','text-transform','none','','','.b-products-listing'),(490871,'furniture-mobile','.w-quote .multicart .title','text-transform','uppercase','','','.w-quote'),(490872,'furniture-mobile','.w-product-personal-catalog-button .btn','text-transform','none','','','.w-product-personal-catalog-button'),(490873,'furniture-mobile','.w-files-catalog-widgets-files-catalog .name','text-transform','uppercase','','','.w-files-catalog-widgets-files-catalog'),(490874,'furniture-mobile','.w-files-catalog-widgets-files-list .name','text-transform','uppercase','','','.w-files-catalog-widgets-files-list'),(490875,'furniture-mobile','.w-sample .multicart .title','text-transform','uppercase','','','.w-sample'),(490876,'furniture-mobile','.w-cart-discount-coupon .btn','text-transform','none','','','.w-cart-discount-coupon'),(490877,'furniture-mobile','.w-cart-up-sell .products-listing .name a','text-transform','none','','','.w-cart-up-sell'),(490878,'furniture-mobile','.w-cart-order-reference .btn','text-transform','none','','','.w-cart-order-reference'),(490879,'furniture-mobile','.w-cart-gift-certificate .btn','text-transform','none','','','.w-cart-gift-certificate'),(490880,'furniture-mobile','.w-cart-shipping-estimator .btn','text-transform','none','','','.w-cart-shipping-estimator'),(490881,'furniture-mobile','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','text-transform','inherit','','','.b-products-listing'),(490882,'furniture-mobile','.w-rma-returns-history .column .title','text-transform','uppercase','','','.w-rma-returns-history'),(490883,'furniture-mobile','.w-rma-returns-history .tableTitle','text-transform','uppercase','','','.w-rma-returns-history'),(490884,'furniture-mobile','.w-predefined-promotion .heading-3','text-transform','uppercase','','','.w-predefined-promotion'),(490885,'furniture-mobile','.account-address-book .address_book h2','text-transform','uppercase','','','.account-address-book'),(490886,'furniture-mobile','.account-address-book .address_book_row h2 a','text-transform','none','','','.account-address-book'),(490887,'furniture-mobile','.account-address-book .leftMes div','text-transform','uppercase','','','.account-address-book'),(490888,'furniture-mobile','.account-order-history .not_fully_paid_td','text-transform','uppercase','','','.account-order-history'),(490889,'furniture-mobile','.account-order-history .order_history_table h2','text-transform','uppercase','','','.account-order-history'),(490890,'furniture-mobile','.account-order-history .order_history_table th','text-transform','none','','','.account-order-history'),(490891,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','text-transform','uppercase','','','.account-order-history-info'),(490892,'furniture-mobile','.account-order-history-info .not_fully_paid_td','text-transform','uppercase','','','.account-order-history-info'),(490893,'furniture-mobile','.account-index .date_title','text-transform','uppercase','','','.account-index'),(490894,'furniture-mobile','.account-index .leftMes div','text-transform','uppercase','','','.account-index'),(490895,'furniture-mobile','.account-index .not_fully_paid_td','text-transform','uppercase','','','.account-index'),(490896,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-transform','uppercase','','','.account-order-pay'),(490897,'furniture-mobile','.account-order-pay .not_fully_paid_td','text-transform','uppercase','','','.account-order-pay'),(490898,'furniture-mobile','.account-samples .not_fully_paid_td','text-transform','uppercase','','','.account-samples'),(490899,'furniture-mobile','.account-samples .order_history_table h2','text-transform','uppercase','','','.account-samples'),(490900,'furniture-mobile','.account-samples .order_history_table th','text-transform','none','','','.account-samples'),(490901,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-transform','uppercase','','','.account-sample-info'),(490902,'furniture-mobile','.account-sample-info .not_fully_paid_td','text-transform','uppercase','','','.account-sample-info'),(490903,'furniture-mobile','.catalog-product-wrap .pn-direction','text-transform','uppercase','','','.catalog-product-wrap'),(490904,'furniture-mobile','.checkout-success-wrap .page-success .text-1','text-transform','uppercase','','','.checkout-success-wrap'),(490905,'furniture-mobile','.checkout-success-wrap .page-success .text-2','text-transform','uppercase','','','.checkout-success-wrap'),(490906,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_color','#222','','','.b-fancybox'),(490907,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left','0','','','.b-fancybox'),(490908,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left_measure','','','','.b-fancybox'),(490909,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size','2','','','.b-fancybox'),(490910,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size_measure','px','','','.b-fancybox'),(490911,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top','1','','','.b-fancybox'),(490912,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top_measure','px','','','.b-fancybox'),(490913,'furniture-mobile','.b-pass-strength .pass-strength span','top','6','','','.b-pass-strength'),(490914,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(490915,'furniture-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','top','0','','','.b-switch'),(490916,'furniture-mobile','.p-wedding-registry-view h1','top','-4','3','','.p-wedding-registry-view'),(490917,'furniture-mobile','.w-promotions .prom-multi-discount > .heading','top','2','3','','.w-promotions'),(490918,'furniture-mobile','.w-promotions .promo-date','top','-10','','','.w-promotions'),(490919,'furniture-mobile','.w-account .account-dropdown','top','100','','','.w-account'),(490920,'furniture-mobile','.p-wedding-registry-view h1','top','-4','4','','.p-wedding-registry-view'),(490921,'furniture-mobile','.p-wedding-registry-view h1','top','-4','3','','.p-wedding-registry-view'),(490922,'furniture-mobile','.w-wedding-registry-widgets-share-link a','top','-1','4','','.w-wedding-registry-widgets-share-link'),(490923,'furniture-mobile','.w-wedding-registry-widgets-products .remove','top','0','','','.w-wedding-registry-widgets-products'),(490924,'furniture-mobile','.w-promo-code .holder','top','2','2906,3','','.w-promo-code'),(490925,'furniture-mobile','.testimonials .rating','top','2','','',''),(490926,'furniture-mobile','.testimonials .heading-3','top','0','3','',''),(490927,'furniture-mobile','.testimonials .reviews-list span','top','2','','',''),(490928,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(490929,'furniture-mobile','.w-promotions .prom-multi-discount .products','top','-13','','','.w-promotions'),(490930,'furniture-mobile','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','top','2','3','','.w-promotions'),(490931,'furniture-mobile','.w-promotions .promo-cart-discount .slave .content','top','-17','','','.w-promotions'),(490932,'furniture-mobile','.w-promotions .promo-cart-discount .promo-min-qty','top','-19','','','.w-promotions'),(490933,'furniture-mobile','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','top','2','3','','.w-promotions'),(490934,'furniture-mobile','.b-preloader .preloader','top','calc(50% - 20px)','3','','.b-preloader'),(490935,'furniture-mobile','.b-preloader .preloader','top','0','','','.b-preloader'),(490936,'furniture-mobile','.b-messages .messBtnMenuDelete','top','3','3','','.b-messages'),(490937,'furniture-mobile','.b-messages span.starred::before','top','3','','','.b-messages'),(490938,'furniture-mobile','.b-messages .messBtnMenuStarred','top','3','3','','.b-messages'),(490939,'furniture-mobile','.b-messages .messBtnMenuUnread','top','3','3','','.b-messages'),(490940,'furniture-mobile','.w-sale .badge','top','10','','','.w-sale'),(490941,'furniture-mobile','.b-messages .select2-container-multi .select2-choices .select2-search-choice','top','5','','','.b-messages'),(490942,'furniture-mobile','.w-text .customer-service','top','5','3','','.w-text'),(490943,'furniture-mobile','.w-search .suggest','top','51','','','.w-search'),(490944,'furniture-mobile','.p-blog-index .author .avatar','top','-2','','','.p-blog-index'),(490945,'furniture-mobile','.p-payer-order-confirmation .order-ico','top','7','3','','.p-payer-order-confirmation'),(490946,'furniture-mobile','.p-payer-order-confirmation .discount-ico','top','3','3','','.p-payer-order-confirmation'),(490947,'furniture-mobile','.p-payer-order-confirmation .comment-ico','top','7','3','','.p-payer-order-confirmation'),(490948,'furniture-mobile','.p-payer-order-pay .order-ico','top','7','3','','.p-payer-order-pay'),(490949,'furniture-mobile','.p-payer-order-pay .discount-ico','top','3','3','','.p-payer-order-pay'),(490950,'furniture-mobile','.p-payer-order-pay .comment-ico','top','7','3','','.p-payer-order-pay'),(490951,'furniture-mobile','.w-checkout-terms .required-message','top','40','','','.w-checkout-terms'),(490952,'furniture-mobile','.w-checkout-terms input[type=\"checkbox\"]','top','2','','','.w-checkout-terms'),(490953,'furniture-mobile','.p-blog-index .author .avatar','top','-2','','','.p-blog-index'),(490954,'furniture-mobile','.b-info .info','top','3','3','','.b-info'),(490955,'furniture-mobile','.w-checkout-shipping-address .genders-title input','top','2','','','.w-checkout-shipping-address'),(490956,'furniture-mobile','.b-fancybox #fancybox-loading','top','50','','','.b-fancybox'),(490957,'furniture-mobile','.b-form .form-buttons','top','10','','','.b-form'),(490958,'furniture-mobile','.w-menu-style-1 ul ul ul','top','0','','','.w-menu-style-1'),(490960,'furniture-mobile','.b-rating .glyphicon','top','1','','','.b-rating'),(490961,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(490962,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-remove','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(490963,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(490964,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(490965,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(490966,'furniture-mobile','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(490967,'furniture-mobile','.w-menu-slider > ul > li > ul','top','100','','','.w-menu-slider'),(490968,'furniture-mobile','.w-menu-slider .close','top','10','','','.w-menu-slider'),(490969,'furniture-mobile','.heading-settings .heading-4','top','2','3','','.heading-settings'),(490970,'furniture-mobile','.b-info .info','top','3','3','','.b-info'),(490971,'furniture-mobile','.b-form .shipping-method .input input','top','2','','','.b-form'),(490972,'furniture-mobile','.w-languages .current','top','1','3','','.w-languages'),(490973,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','top','8','','','.b-switch'),(490974,'furniture-mobile','.b-fancybox .fancybox-tmp','top','-99999','','','.b-fancybox'),(490975,'furniture-mobile','.w-filters .ui-slider-handle','top','-5','','','.w-filters'),(490976,'furniture-mobile','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','top','-1','3','','.order-summary'),(490977,'furniture-mobile','.view-all','top','50','3','',''),(490978,'furniture-mobile','.w-menu-style-1 > ul > li > ul','top','100','','','.w-menu-style-1'),(490979,'furniture-mobile','.w-menu-slider > ul > li > ul','top','100','','','.w-menu-slider'),(490980,'furniture-mobile','.b-products-listing .products-listing .btn-buy','top','3','3','','.b-products-listing'),(490981,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','top','-2','','','.b-switch'),(490982,'furniture-mobile','.b-switch .candlestick-wrapper','top','-2','','','.b-switch'),(490983,'furniture-mobile','.p-wedding-registry-view h1','top','-4','3','','.p-wedding-registry-view'),(490984,'furniture-mobile','.closeable-heading','top','0','3','',''),(490985,'furniture-mobile','.b-bottom .footerTitle','top','8','2876,4','','.b-bottom'),(490986,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(490988,'furniture-mobile','.b-info-popup .info-popup div','top','15','3','','.b-info-popup'),(490989,'furniture-mobile','.b-form .form-inputs div.required-message','top','-15','','','.b-form'),(490990,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(490991,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top','0','','','.b-select-suggest'),(490992,'furniture-mobile','.b-form .hide-billing-address','top','0','','','.b-form'),(490993,'furniture-mobile','.b-select-suggest .select2-measure-scrollbar','top','-10000','','','.b-select-suggest'),(490994,'furniture-mobile','.w-socials .post_item > div','top','10','3','','.w-socials'),(490995,'furniture-mobile','.w-cart-compare .atr-col','top','0','3','','.w-cart-compare'),(490996,'furniture-mobile','.b-info-popup .info-popup.top-left div','top','auto','3','','.b-info-popup'),(490997,'furniture-mobile','.b-info-popup .info-popup div','top','-12','','','.b-info-popup'),(490998,'furniture-mobile','.bell-ico .heading-2','top','5','3','','.bell-ico'),(490999,'furniture-mobile','.p-wedding-registry-view h1','top','-4','4','','.p-wedding-registry-view'),(491000,'furniture-mobile','.p-wedding-registry-view h1','top','-4','3','','.p-wedding-registry-view'),(491002,'furniture-mobile','.heading-ordered-items .heading-4','top','2','3','','.heading-ordered-items'),(491003,'furniture-mobile','.w-socials .post_item > div','top','10','3','','.w-socials'),(491004,'furniture-mobile','.w-socials .post_item > div','top','10','3','','.w-socials'),(491005,'furniture-mobile','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(491006,'furniture-mobile','.w-menu-style-1 > ul > li > ul','top','100','','','.w-menu-style-1'),(491007,'furniture-mobile','.w-menu-style-1 ul ul ul','top','0','','','.w-menu-style-1'),(491008,'furniture-mobile','.w-text .customer-service','top','5','3','','.w-text'),(491009,'furniture-mobile','.w-socials .post_item > div','top','10','3','','.w-socials'),(491010,'furniture-mobile','.w-account-address-book .btn-del','top','0','','','.w-account-address-book'),(491011,'furniture-mobile','.message.success','top','3','3','',''),(491012,'furniture-mobile','.b-form .middle-form .required-message','top','-15','','','.b-form'),(491013,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(491014,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(491015,'furniture-mobile','.w-socials .post_item > div','top','10','3','','.w-socials'),(491016,'furniture-mobile','.w-menu-slider .close','top','10','','','.w-menu-slider'),(491017,'furniture-mobile','.w-menu-slider .close','top','10','','','.w-menu-slider'),(491018,'furniture-mobile','.b-info-popup .info-popup.top-left div','top','auto','','','.b-info-popup'),(491019,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(491020,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','top','8','','','.b-switch'),(491022,'furniture-mobile','.b-form .radio-button input[type=\"radio\"]','top','2','','','.b-form'),(491023,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(491024,'furniture-mobile','.w-personal-gift-status-bar .end-date','top','4','3','','.w-personal-gift-status-bar'),(491025,'furniture-mobile','.savings-ico .heading-2','top','5','3','','.savings-ico'),(491026,'furniture-mobile','.w-text .customer-service','top','5','3','','.w-text'),(491027,'furniture-mobile','.w-multi-cart-actions .cart-actions','top','-3','','','.w-multi-cart-actions'),(491028,'furniture-mobile','.w-sale .badge','top','10','','','.w-sale'),(491029,'furniture-mobile','.w-banner .image-text-banner.top-left .text-banner','top','0','','','.w-banner'),(491030,'furniture-mobile','.b-fancybox .fancybox-overlay','top','0','','','.b-fancybox'),(491031,'furniture-mobile','.w-sale .badge','top','10','','','.w-sale'),(491032,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(491033,'furniture-mobile','.b-info .info','top','3','3','','.b-info'),(491034,'furniture-mobile','.p-wedding-registry-view h1','top','-4','4','','.p-wedding-registry-view'),(491035,'furniture-mobile','.p-wedding-registry-view h1','top','-4','3','','.p-wedding-registry-view'),(491036,'furniture-mobile','.w-promo-code .holder','top','19','3','','.w-promo-code'),(491037,'furniture-mobile','.w-promo-code .holder','top','2','2906,3','','.w-promo-code'),(491038,'furniture-mobile','.w-reviews .review','top','-16','3','','.w-reviews'),(491039,'furniture-mobile','.w-reviews .heading-3','top','0','3','','.w-reviews'),(491041,'furniture-mobile','.w-banner .carousel-text','top','0','','','.w-banner'),(491042,'furniture-mobile','.w-banner .image-text-banner.bottom-center .text-banner','top','auto','','','.w-banner'),(491043,'furniture-mobile','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','top','0','','','.w-banner'),(491044,'furniture-mobile','.b-info .info','top','3','3','','.b-info'),(491045,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','top','4','3','','.b-switch'),(491046,'furniture-mobile','.w-menu-horizontal ul ul ul','top','0','','','.w-menu-horizontal'),(491047,'furniture-mobile','.w-languages .select','top','46','2885','','.w-languages'),(491048,'furniture-mobile','.w-languages .select','top','31','','','.w-languages'),(491049,'furniture-mobile','.w-menu-style-1 ul ul ul','top','0','','','.w-menu-style-1'),(491050,'furniture-mobile','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(491051,'furniture-mobile','.b-form .payment-method .item-radio input','top','5','','','.b-form'),(491052,'furniture-mobile','.p-wedding-registry-view h1','top','-4','4','','.p-wedding-registry-view'),(491053,'furniture-mobile','.w-checkout-billing-address .genders-title input','top','2','','','.w-checkout-billing-address'),(491054,'furniture-mobile','.w-promo-code .holder','top','2','2906,3','','.w-promo-code'),(491055,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(491056,'furniture-mobile','.w-menu-horizontal > ul > li > ul','top','100','','','.w-menu-horizontal'),(491057,'furniture-mobile','.w-menu-slider > ul > li > ul','top','100','','','.w-menu-slider'),(491058,'furniture-mobile','.w-menu-slider .close','top','10','','','.w-menu-slider'),(491059,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(491060,'furniture-mobile','.p-wedding-registry-view h1','top','-4','3','','.p-wedding-registry-view'),(491061,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(491062,'furniture-mobile','.b-info-popup .info-popup','top','4','3','','.b-info-popup'),(491063,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','top','1','3','','.b-form'),(491064,'furniture-mobile','.w-promo-code .holder','top','2','2906,3','','.w-promo-code'),(491065,'furniture-mobile','.w-personal-gift-status-bar .inform','top','3','4','','.w-personal-gift-status-bar'),(491066,'furniture-mobile','.b-upload-files .attach-active-holder .attach-file','top','-200','','','.b-upload-files'),(491067,'furniture-mobile','.w-promo-code .holder','top','2','2906,3','','.w-promo-code'),(491068,'furniture-mobile','.b-fancybox .fancybox-close','top','10','','','.b-fancybox'),(491069,'furniture-mobile','.w-product-customers-activity .close','top','5','','','.w-product-customers-activity'),(491070,'furniture-mobile','.w-reviews-content .review','top','-16','3','','.w-reviews-content'),(491071,'furniture-mobile','.w-text .customer-service','top','5','3','','.w-text'),(491072,'furniture-mobile','.w-cart-compare .remove-cart','top','0','','','.w-cart-compare'),(491073,'furniture-mobile','.w-promo-code .holder','top','19','3','','.w-promo-code'),(491074,'furniture-mobile','.w-promo-code .holder','top','19','3','','.w-promo-code'),(491075,'furniture-mobile','.w-menu-style-1 ul ul ul','top','0','','','.w-menu-style-1'),(491076,'furniture-mobile','.w-promo-code .holder','top','2','2906,3','','.w-promo-code'),(491077,'furniture-mobile','.w-checkout-shipping-choice input','top','-200','','','.w-checkout-shipping-choice'),(491078,'furniture-mobile','.w-text .customer-service','top','5','3','','.w-text'),(491079,'furniture-mobile','.w-socials .post_item > div','top','10','3','','.w-socials'),(491080,'furniture-mobile','.w-product-reviews .reviews-list span','top','2','','','.w-product-reviews'),(491081,'furniture-mobile','.w-wedding-registry-widgets-delete-link a','top','-1','4','','.w-wedding-registry-widgets-delete-link'),(491082,'furniture-mobile','.b-select-suggest .select2-search-choice-close','top','4','','','.b-select-suggest'),(491083,'furniture-mobile','.w-image-maps .svg-wrap svg','top','0','','','.w-image-maps'),(491084,'furniture-mobile','.w-neighbour-checkout .bootstrap-switch','top','-2','','','.w-neighbour-checkout'),(491085,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','top','0','','','.b-select-suggest'),(491086,'furniture-mobile','.b-select-suggest .select2-drop-mask','top','0','','','.b-select-suggest'),(491087,'furniture-mobile','.b-select-suggest .select2-drop','top','100','','','.b-select-suggest'),(491088,'furniture-mobile','.w-text .customer-service','top','5','3','','.w-text'),(491089,'furniture-mobile','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(491090,'furniture-mobile','.w-menu-style-1 ul ul ul','top','0','','','.w-menu-style-1'),(491091,'furniture-mobile','.w-menu-style-1 > ul > li > ul','top','100','','','.w-menu-style-1'),(491092,'furniture-mobile','.w-menu-slider > ul > li > ul','top','100','','','.w-menu-slider'),(491093,'furniture-mobile','.p-blog-index .author .avatar','top','-2','','','.p-blog-index'),(491094,'furniture-mobile','.w-menu-style-1 ul ul ul','top','0','','','.w-menu-style-1'),(491095,'furniture-mobile','.w-menu-slider > ul > li > ul','top','100','','','.w-menu-slider'),(491096,'furniture-mobile','.heading-saved-lists .heading-4','top','2','3','','.heading-saved-lists'),(491097,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','top','4','3','','.b-switch'),(491098,'furniture-mobile','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(491099,'furniture-mobile','.p-wedding-registry-view h1','top','-4','4','','.p-wedding-registry-view'),(491100,'furniture-mobile','.w-menu-style-1 > ul > li > ul','top','100','','','.w-menu-style-1'),(491101,'furniture-mobile','.w-checkout-create-account .account-benefits strong','top','3','3','','.w-checkout-create-account'),(491102,'furniture-mobile','.w-promo-code .holder','top','19','3','','.w-promo-code'),(491103,'furniture-mobile','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(491104,'furniture-mobile','.w-account-addresses-list .address-fields input[type=\"radio\"]','top','4','','','.w-account-addresses-list'),(491105,'furniture-mobile','.b-products-listing .products-listing .promos-info','top','0','','','.b-products-listing'),(491106,'furniture-mobile','.b-products-listing .hover-box-content','top','-10','3','','.b-products-listing'),(491107,'furniture-mobile','.b-products-listing .hover-box-content','top','40','','','.b-products-listing'),(491108,'furniture-mobile','.b-products-listing .loader','top','calc(50% - 15px)','4','','.b-products-listing'),(491109,'furniture-mobile','.b-products-listing .loader','top','0','3','','.b-products-listing'),(491110,'furniture-mobile','.b-products-listing .products-listing .qty-input.hidden','top','0','3','','.b-products-listing'),(491111,'furniture-mobile','.b-products-listing .promo','top','0','','','.b-products-listing'),(491112,'furniture-mobile','.w-blog-widget-post-share','top','15','2906,4','','.w-blog-widget-post-share'),(491113,'furniture-mobile','.w-blog-widget-post-share ','top','0','4','','.w-blog-widget-post-share'),(491114,'furniture-mobile','.w-blog-widget-post-listing .post_comment','top','0','3','','.w-blog-widget-post-listing'),(491115,'furniture-mobile','.w-blog-widget-post-comments-count span','top','2','3','','.w-blog-widget-post-comments-count'),(491116,'furniture-mobile','.w-blog-widget-most-popular-posts a','top','5','3','','.w-blog-widget-most-popular-posts'),(491117,'furniture-mobile','.w-blog-widget-categories-list a','top','5','3','','.w-blog-widget-categories-list'),(491118,'furniture-mobile','.w-currencies .current','top','10','2885,3','','.w-currencies'),(491119,'furniture-mobile','.w-currencies .select','top','46','2885','','.w-currencies'),(491120,'furniture-mobile','.w-currencies .select','top','31','','','.w-currencies'),(491121,'furniture-mobile','.w-currencies .current','top','1','3','','.w-currencies'),(491122,'furniture-mobile','.w-promo-code .holder','top','19','3','','.w-promo-code'),(491123,'furniture-mobile','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(491124,'furniture-mobile','.w-checkout-gdpr .candlestick-wrapper','top','0','','','.w-checkout-gdpr'),(491125,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(491126,'furniture-mobile','.w-sale .badge','top','10','','','.w-sale'),(491127,'furniture-mobile','.w-menu-slider .close','top','10','','','.w-menu-slider'),(491128,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(491129,'furniture-mobile','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(491130,'furniture-mobile','.p-blog-index .author .avatar','top','-2','','','.p-blog-index'),(491131,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','top','0','','','.b-switch'),(491132,'furniture-mobile','.b-form .eye-password','top','5','','','.b-form'),(491133,'furniture-mobile','.w-taxable input[type=\"radio\"]','top','2','','','.w-taxable'),(491134,'furniture-mobile','.w-taxable input[type=\"checkbox\"]','top','2','','','.w-taxable'),(491135,'furniture-mobile','.b-form .radio-button + .required-message-wrap .required-message','top','-5','','','.b-form'),(491137,'furniture-mobile','.w-sale .badge','top','10','','','.w-sale'),(491138,'furniture-mobile','.b-info .info','top','3','3','','.b-info'),(491139,'furniture-mobile','.b-products-listing .products-listing .radio-attributes input','top','2','','','.b-products-listing'),(491140,'furniture-mobile','.w-search .button-search','top','0','','','.w-search'),(491141,'furniture-mobile','.w-languages .current','top','10','2885,3','','.w-languages'),(491142,'furniture-mobile','.w-sale .badge','top','10','','','.w-sale'),(491143,'furniture-mobile','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(491144,'furniture-mobile','.w-promo-code .holder','top','19','3','','.w-promo-code'),(491145,'furniture-mobile','.b-info .info','top','3','3','','.b-info'),(491146,'furniture-mobile','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(491147,'furniture-mobile','.w-menu-slider > ul > li > ul','top','100','','','.w-menu-slider'),(491148,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top','0','','','.w-catalog-paging'),(491149,'furniture-mobile','.w-cart-listing .remove-btn span','top','-7','2885','','.w-cart-listing'),(491150,'furniture-mobile','.w-cart .multicart .switch-cart','top','14','','','.w-cart'),(491151,'furniture-mobile','.b-upload-file .upload-remove','top','5','','','.b-upload-file'),(491152,'furniture-mobile','.b-fancybox .fancybox-nav span','top','50','','','.b-fancybox'),(491153,'furniture-mobile','.b-fancybox .fancybox-nav','top','0','','','.b-fancybox'),(491154,'furniture-mobile','.b-form .addresses .address-item input[type=\"radio\"]','top','4','','','.b-form'),(491155,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(491156,'furniture-mobile','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(491157,'furniture-mobile','.w-banner .image-text-banner.top-right .text-banner','top','0','','','.w-banner'),(491158,'furniture-mobile','.b-bottom .pop-up-close','top','7','','','.b-bottom'),(491159,'furniture-mobile','.p-blog-index .author .avatar','top','-2','','','.p-blog-index'),(491160,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container','top','0','','','.b-switch'),(491161,'furniture-mobile','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(491162,'furniture-mobile','.w-menu-style-1 > ul > li > ul','top','100','','','.w-menu-style-1'),(491163,'furniture-mobile','.w-menu-style-1 > ul > li > ul','top','100','','','.w-menu-style-1'),(491164,'furniture-mobile','.w-menu-slider .close','top','10','','','.w-menu-slider'),(491165,'furniture-mobile','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(491166,'furniture-mobile','.b-fancybox .fancybox-wrap','top','0','','','.b-fancybox'),(491167,'furniture-mobile','.w-menu-big > ul > li > ul','top','100','','','.w-menu-big'),(491168,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','top','8','','','.b-select-suggest'),(491169,'furniture-mobile','.w-filters .mobileCollapse','top','1','','','.w-filters'),(491170,'furniture-mobile','.p-blog-index .author .avatar','top','-2','','','.p-blog-index'),(491171,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','top','0','','','.w-image-maps'),(491172,'furniture-mobile','.p-wedding-registry-view h1','top','-4','4','','.p-wedding-registry-view'),(491173,'furniture-mobile','.w-banner .banner img + img','top','0','','','.w-banner'),(491174,'furniture-mobile','.b-product-images .media-popup .mp-close','top','20','','','.b-product-images'),(491175,'furniture-mobile','.b-product-images .mp-shadow, .b-product-images .media-popup','top','0','','','.b-product-images'),(491176,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top','100','','','.b-menu-lev_display-down'),(491177,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top','100','','','.b-menu-lev_display-down'),(491178,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top','100','','','.b-menu-lev_display-down'),(491179,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top','100','','','.b-menu-lev_display-down'),(491180,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top','100','','','.b-menu-lev_display-down'),(491181,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','top','0','','','.b-menu-lev_display-left'),(491182,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','top','0','','','.b-menu-lev_display-left'),(491183,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','top','0','','','.b-menu-lev_display-left'),(491184,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','top','0','','','.b-menu-lev_display-left'),(491185,'furniture-mobile','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','top','0','','','.b-menu-lev_display-left'),(491186,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','top','0','','','.b-menu-lev_display-lra'),(491187,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','top','0','','','.b-menu-lev_display-lra'),(491188,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','top','0','','','.b-menu-lev_display-lra'),(491189,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','top','0','','','.b-menu-lev_display-lra'),(491190,'furniture-mobile','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','top','0','','','.b-menu-lev_display-lra'),(491191,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','top','0','','','.b-menu-lev_display-right'),(491192,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','top','0','','','.b-menu-lev_display-right'),(491193,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','top','0','','','.b-menu-lev_display-right'),(491194,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','top','0','','','.b-menu-lev_display-right'),(491195,'furniture-mobile','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','top','0','','','.b-menu-lev_display-right'),(491196,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','top','0','','','.b-menu-lev_display-slide'),(491197,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','top','0','','','.b-menu-lev_display-slide'),(491198,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','top','0','','','.b-menu-lev_display-slide'),(491199,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','top','0','','','.b-menu-lev_display-slide'),(491200,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','top','0','','','.b-menu-lev_display-slide'),(491201,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','top','0','','','.b-menu-open_from-left'),(491202,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','top','0','','','.b-menu-style-2'),(491203,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','top','50','3','','.b-menu-style-2'),(491204,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','top','0','','','.b-menu-style-2'),(491205,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','top','50','3','','.b-menu-style-2'),(491206,'furniture-mobile','.batchPr .batchSelect','top','15','','','.batchPr'),(491207,'furniture-mobile','.batchPr .btn-batch-remove','top','10','','','.batchPr'),(491208,'furniture-mobile','.tripleBanner .w-html_box','top','0','3','','.tripleBanner'),(491209,'furniture-mobile','.w-currencies .current','top','5','2906,3','','.w-currencies'),(491210,'furniture-mobile','.w-languages .current','top','5','2906,3','','.w-languages'),(491211,'furniture-mobile','.b-slick .slick-track','top','0','','','.b-slick'),(491212,'furniture-mobile','.b-slick .slick-vertical button.slick-next','top','auto','','','.b-slick'),(491213,'furniture-mobile','.b-slick .slick-vertical button.slick-prev','top','0','','','.b-slick'),(491214,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','top','50','','','.b-slick'),(491215,'furniture-mobile','.menu-header .w-menu','top','-50','2885','','.menu-header'),(491216,'furniture-mobile','.w-search .suggest-js','top','100','2885','','.w-search'),(491217,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li','top','16','2885,3','','.b-menu-style-3'),(491218,'furniture-mobile','.header','top','0','2885','',''),(491219,'furniture-mobile','.b-products-listing .del-from-personal-catalog','top','2','3','','.b-products-listing'),(491220,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','top','100','','','.b-products-listing'),(491221,'furniture-mobile','.w-quote .multicart .switch-cart','top','14','','','.w-quote'),(491222,'furniture-mobile','.w-cart .qty','top','-1','4','','.w-cart'),(491223,'furniture-mobile','h1, .heading-1','top','-10','3','',''),(491224,'furniture-mobile','h1, .heading-1','top','-10','4','',''),(491225,'furniture-mobile','.warrantyProduct .warranty','top','50','3','','.warrantyProduct'),(491226,'furniture-mobile','.warrantyProduct .delivery','top','50','3','','.warrantyProduct'),(491227,'furniture-mobile','.w-files-catalog-widgets-files-list .file','top','-1','3','','.w-files-catalog-widgets-files-list'),(491228,'furniture-mobile','.w-sample .multicart .switch-cart','top','14','','','.w-sample'),(491229,'furniture-mobile','.w-sample .qty','top','-1','4','','.w-sample'),(491230,'furniture-mobile','.w-cart-listing .points-earn','top','0','4','','.w-cart-listing'),(491231,'furniture-mobile','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(491232,'furniture-mobile','.w-product-inventory input[type=\"radio\"]','top','1','','','.w-product-inventory'),(491233,'furniture-mobile','.w-account-address-book .add_item a','top','-4','3','','.w-account-address-book'),(491234,'furniture-mobile','.heading-2','top','-10','3','',''),(491235,'furniture-mobile','.heading-2','top','-10','4','',''),(491236,'furniture-mobile','.w-product-properties-filters-widgets-chosen-filters .remove','top','2','3','','.w-product-properties-filters-widgets-chosen-filters'),(491237,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','top','-10','3','','.p-quote-checkout-index'),(491238,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','top','-10','4','','.p-quote-checkout-index'),(491239,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','top','-10','3','','.p-sample-checkout-index'),(491240,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','top','-10','4','','.p-sample-checkout-index'),(491241,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','top','5','4','','.w-account-personal-catalog'),(491242,'furniture-mobile','.w-account-customer-additional-field .field-type-radio input','top','1','','','.w-account-customer-additional-field'),(491243,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input','top','-50','','','.w-questionnaire-widgets-questionnaire'),(491244,'furniture-mobile','.w-sale-category .badge','top','10','','','.w-sale-category'),(491245,'furniture-mobile','.w-product-wedding-registry-button .btn','top','50','3','','.w-product-wedding-registry-button'),(491246,'furniture-mobile','.w-product-wedding-registry-button .btn','top','50','4','','.w-product-wedding-registry-button'),(491247,'furniture-mobile','.w-product-properties-icons .hover-box-content','top','50','','','.w-product-properties-icons'),(491248,'furniture-mobile','.w-product-designer-designer .productDesignerBox input','top','0','','','.w-product-designer-designer'),(491249,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .goto-button','top','8','','','.b-menu-style-1'),(491250,'furniture-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner','top','0','','','.w-banner'),(491251,'furniture-mobile','.w-product-configurator .pc-item label input','top','5','','','.w-product-configurator'),(491252,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .products','top','-13','','','.w-predefined-promotion'),(491253,'furniture-mobile','.w-predefined-promotion .prom-multi-discount > .heading','top','2','3','','.w-predefined-promotion'),(491254,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','top','2','3','','.w-predefined-promotion'),(491255,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .promo-min-qty','top','-19','','','.w-predefined-promotion'),(491256,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .content','top','-17','','','.w-predefined-promotion'),(491257,'furniture-mobile','.w-predefined-promotion .promo-date','top','-10','','','.w-predefined-promotion'),(491258,'furniture-mobile','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','top','2','3','','.w-predefined-promotion'),(491259,'furniture-mobile','.mainBanner .topBox > .right','top','50','4','','.mainBanner'),(491260,'furniture-mobile','.mainBanner .w-banner .banner-text','top','0','','','.mainBanner'),(491261,'furniture-mobile','.order-summary .icon','top','0','3','','.order-summary'),(491262,'furniture-mobile','.w-search .background','top','0','','','.w-search'),(491263,'furniture-mobile','.w-search .opened','top','0','3','','.w-search'),(491264,'furniture-mobile','.w-search .suggest','top','0','4','','.w-search'),(491265,'furniture-mobile','.account-order-history .not_fully_paid_td','top','19','','','.account-order-history'),(491266,'furniture-mobile','.account-order-history .view_link','top','4','4','','.account-order-history'),(491267,'furniture-mobile','.account-order-history-info .historyInfoColumn h2, .account-order-history-info h2.product_details, .account-order-history-info h2.o_history_info','top','2','3','','.account-order-history-info'),(491268,'furniture-mobile','.account-order-history-info .not_fully_paid_td','top','19','','','.account-order-history-info'),(491269,'furniture-mobile','.account-index .account_page h4','top','-4','3','','.account-index'),(491270,'furniture-mobile','.account-index .not_fully_paid_td','top','19','','','.account-index'),(491271,'furniture-mobile','.account-index .topAccount > li > div','top','4','3','','.account-index'),(491272,'furniture-mobile','.account-index .view_link','top','4','4','','.account-index'),(491273,'furniture-mobile','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','top','2','3','','.account-order-pay'),(491274,'furniture-mobile','.account-order-pay .not_fully_paid_td','top','19','','','.account-order-pay'),(491275,'furniture-mobile','.account-samples .not_fully_paid_td','top','19','','','.account-samples'),(491276,'furniture-mobile','.account-samples .view_link','top','4','4','','.account-samples'),(491277,'furniture-mobile','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','top','2','3','','.account-sample-info'),(491278,'furniture-mobile','.account-sample-info .not_fully_paid_td','top','19','','','.account-sample-info'),(491279,'furniture-mobile','.catalog-product-wrap .pn-image','top','120','3','','.catalog-product-wrap'),(491280,'furniture-mobile','.catalog-product-wrap .prev-next-product','top','calc(50% - 200px)','','','.catalog-product-wrap'),(491281,'furniture-mobile','.shopping-cart-index .gift-code .heading-4','top','0','4','','.shopping-cart-index'),(491282,'furniture-mobile','.checkout-index-wrap .order-ico','top','7','3','','.checkout-index-wrap'),(491283,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','top','-10','3','','.checkout-index-wrap'),(491284,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','top','-10','4','','.checkout-index-wrap'),(491285,'furniture-mobile','.checkout-order-confirmation .comment-ico','top','7','3','','.checkout-order-confirmation'),(491286,'furniture-mobile','.checkout-order-confirmation .discount-ico','top','3','3','','.checkout-order-confirmation'),(491287,'furniture-mobile','.checkout-order-confirmation .order-ico','top','7','3','','.checkout-order-confirmation'),(491288,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top_important','important','','','.b-select-suggest'),(491289,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top_important','important','','','.w-catalog-paging'),(491290,'furniture-mobile','.heading-2','top_important','important','3','',''),(491291,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(491292,'furniture-mobile','.w-account .account-dropdown','top_measure','%','','','.w-account'),(491293,'furniture-mobile','.b-fancybox #fancybox-loading','top_measure','%','','','.b-fancybox'),(491294,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(491295,'furniture-mobile','.w-menu-slider > ul > li > ul','top_measure','%','','','.w-menu-slider'),(491296,'furniture-mobile','.w-menu-slider > ul > li > ul','top_measure','%','','','.w-menu-slider'),(491297,'furniture-mobile','.view-all','top_measure','%','3','',''),(491298,'furniture-mobile','.w-menu-style-1 > ul > li > ul','top_measure','%','','','.w-menu-style-1'),(491299,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(491300,'furniture-mobile','.w-menu-slider > ul > li > ul','top_measure','%','','','.w-menu-slider'),(491301,'furniture-mobile','.w-menu-style-1 > ul > li > ul','top_measure','%','','','.w-menu-style-1'),(491302,'furniture-mobile','.w-menu-style-1 > ul > li > ul','top_measure','%','','','.w-menu-style-1'),(491303,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(491304,'furniture-mobile','.w-menu-style-1 > ul > li > ul','top_measure','%','','','.w-menu-style-1'),(491305,'furniture-mobile','.w-menu-horizontal > ul > li > ul','top_measure','%','','','.w-menu-horizontal'),(491306,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(491307,'furniture-mobile','.b-select-suggest .select2-drop','top_measure','%','','','.b-select-suggest'),(491308,'furniture-mobile','.w-menu-slider > ul > li > ul','top_measure','%','','','.w-menu-slider'),(491309,'furniture-mobile','.w-menu-slider > ul > li > ul','top_measure','%','','','.w-menu-slider'),(491310,'furniture-mobile','.w-menu-style-1 > ul > li > ul','top_measure','%','','','.w-menu-style-1'),(491311,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(491312,'furniture-mobile','.b-fancybox .fancybox-nav span','top_measure','%','','','.b-fancybox'),(491313,'furniture-mobile','.w-menu-style-1 > ul > li > ul','top_measure','%','','','.w-menu-style-1'),(491314,'furniture-mobile','.w-menu-slider > ul > li > ul','top_measure','%','','','.w-menu-slider'),(491315,'furniture-mobile','.w-menu-big > ul > li > ul','top_measure','%','','','.w-menu-big'),(491316,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top_measure','%','','','.b-menu-lev_display-down'),(491317,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top_measure','%','','','.b-menu-lev_display-down'),(491318,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top_measure','%','','','.b-menu-lev_display-down'),(491319,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top_measure','%','','','.b-menu-lev_display-down'),(491320,'furniture-mobile','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top_measure','%','','','.b-menu-lev_display-down'),(491321,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','top_measure','%','3','','.b-menu-style-2'),(491322,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','top_measure','%','3','','.b-menu-style-2'),(491323,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','top_measure','%','','','.b-slick'),(491324,'furniture-mobile','.w-search .suggest-js','top_measure','%','2885','','.w-search'),(491325,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','top_measure','%','','','.b-products-listing'),(491326,'furniture-mobile','.warrantyProduct .warranty','top_measure','%','3','','.warrantyProduct'),(491327,'furniture-mobile','.warrantyProduct .delivery','top_measure','%','3','','.warrantyProduct'),(491328,'furniture-mobile','.w-product-wedding-registry-button .btn','top_measure','%','3','','.w-product-wedding-registry-button'),(491329,'furniture-mobile','.w-product-wedding-registry-button .btn','top_measure','%','4','','.w-product-wedding-registry-button'),(491330,'furniture-mobile','.w-product-properties-icons .hover-box-content','top_measure','%','','','.w-product-properties-icons'),(491331,'furniture-mobile','.mainBanner .topBox > .right','top_measure','%','4','','.mainBanner'),(491332,'furniture-mobile','.b-slick .slick-slider','touch-action','pan-y','','','.b-slick'),(491333,'furniture-mobile','.b-products-listing .hover-box-content','transform','rotate( 45deg )','3','','.b-products-listing'),(491334,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container','transform','translate3d(0, 0, 0)','','','.b-switch'),(491335,'furniture-mobile','.b-product-images .media-popup .mp-close','transform','scale(1.5)','1','','.b-product-images'),(491336,'furniture-mobile','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','transform','scale(1.2)','1','','.b-product-images'),(491337,'furniture-mobile','.b-product-images .media-popup .slick-list:first-child .slick-track','transform','none','','','.b-product-images'),(491338,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','transform','scale(1.5)','1','','.b-product-images'),(491339,'furniture-mobile','.b-menu-lev_display-slide .menu-style .slide-parent','transform','translateX(-100vw)','','','.b-menu-lev_display-slide'),(491340,'furniture-mobile','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','transform','translate3d(0, 0, 0)','','','.b-slick'),(491341,'furniture-mobile','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','transform','translate(-50%, 0)','','','.mainBanner'),(491342,'furniture-mobile','.b-product-images .media-popup .slick-list:first-child .slick-track','transform_important','important','','','.b-product-images'),(491343,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','transition','0.3s','','','.b-switch'),(491344,'furniture-mobile','.b-switch .bootstrap-switch','transition','border-color ease-in-out .15s, box-shadow ease-in-out .15s','','','.b-switch'),(491345,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-animate .bootstrap-switch-container','transition','margin-left 0.5s','','','.b-switch'),(491346,'furniture-mobile','.b-product-images .media-popup .mp-close','transition','transform 0.3s, color 0.3s','','','.b-product-images'),(491347,'furniture-mobile','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','transition','transform 0.3s','','','.b-product-images'),(491348,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','transition','transform 0.3s, color 0.3s','','','.b-product-images'),(491349,'furniture-mobile','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','transition','max-height 1s','','','.b-menu-burger_icon'),(491350,'furniture-mobile','.b-menu-lev_display-slide .menu-style ul','transition','visibility 300ms, transform 300ms','','','.b-menu-lev_display-slide'),(491351,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','transition','left 300ms','','','.b-menu-open_from-left'),(491352,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','user-select','none','','','.b-select-suggest'),(491353,'furniture-mobile','.b-select-suggest .select2-results .select2-result-label','user-select','none','','','.b-select-suggest'),(491354,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','user-select','none','','','.b-select-suggest'),(491355,'furniture-mobile','.b-slick .slick-slider','user-select','none','','','.b-slick'),(491357,'furniture-mobile','.b-email .name','vertical-align','top','','','.b-email'),(491358,'furniture-mobile','.w-compare-box-item .checkbox','vertical-align','top','','','.w-compare-box-item'),(491359,'furniture-mobile','.w-compare-box-item .checkbox + span','vertical-align','middle','','','.w-compare-box-item'),(491360,'furniture-mobile','.w-tabs .tab-li.tab-cart a','vertical-align','middle','3','','.w-tabs'),(491361,'furniture-mobile','.w-compare-box-item .checkbox','vertical-align','top','','','.w-compare-box-item'),(491362,'furniture-mobile','.w-compare-box-item .checkbox + span','vertical-align','middle','','','.w-compare-box-item'),(491363,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.p-quick-order-index'),(491364,'furniture-mobile','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.p-quick-order-index'),(491365,'furniture-mobile','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','vertical-align','middle','','','.w-banner'),(491366,'furniture-mobile','.p-reviews-info .review_by span','vertical-align','middle','','','.p-reviews-info'),(491367,'furniture-mobile','.b-email .model','vertical-align','top','','','.b-email'),(491368,'furniture-mobile','.w-compare-box-item .checkbox','vertical-align','top','','','.w-compare-box-item'),(491369,'furniture-mobile','.w-compare-box-item .checkbox + span','vertical-align','middle','','','.w-compare-box-item'),(491370,'furniture-mobile','.w-categories .item','vertical-align','top','','','.w-categories'),(491371,'furniture-mobile','.w-promotions .heading-3','vertical-align','top','','','.w-promotions'),(491372,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','vertical-align','top','','','.b-warehouses-popup'),(491373,'furniture-mobile','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(491374,'furniture-mobile','.b-upload-file .upload-file-template','vertical-align','top','','','.b-upload-file'),(491375,'furniture-mobile','.p-reviews-info .review_by span','vertical-align','middle','','','.p-reviews-info'),(491376,'furniture-mobile','.b-messages .msv_to_cc div span','vertical-align','middle','','','.b-messages'),(491377,'furniture-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','vertical-align','middle','','','.w-menu-style-1'),(491378,'furniture-mobile','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(491379,'furniture-mobile','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(491380,'furniture-mobile','.w-menu-slider .close','vertical-align','20px','','','.w-menu-slider'),(491381,'furniture-mobile','.w-menu-slider > ul > li > ul > li','vertical-align','top','','','.w-menu-slider'),(491382,'furniture-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(491383,'furniture-mobile','.b-email .price','vertical-align','top','','','.b-email'),(491384,'furniture-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','vertical-align','middle','','','.w-menu-style-1'),(491386,'furniture-mobile','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(491387,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(491388,'furniture-mobile','.b-switch .bootstrap-switch','vertical-align','middle','','','.b-switch'),(491389,'furniture-mobile','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','vertical-align','middle','','','.w-menu-horizontal'),(491390,'furniture-mobile','.w-menu-slider > ul > li','vertical-align','top','','','.w-menu-slider'),(491391,'furniture-mobile','.w-menu-slider > ul > li > ul > li','vertical-align','top','','','.w-menu-slider'),(491392,'furniture-mobile','.w-menu-slider .close','vertical-align','20px','','','.w-menu-slider'),(491393,'furniture-mobile','.w-filters .input-checkbox:checked + .checkbox-span','vertical-align','middle','','','.w-filters'),(491394,'furniture-mobile','.b-email .name','vertical-align','top','','','.b-email'),(491395,'furniture-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(491396,'furniture-mobile','.b-email .image','vertical-align','top','','','.b-email'),(491397,'furniture-mobile','.b-form .checkbox-style:checked + .checkbox-span','vertical-align','middle','','','.b-form'),(491398,'furniture-mobile','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','vertical-align','middle','','','.b-form'),(491399,'furniture-mobile','.w-menu-slider .close','vertical-align','20px','','','.w-menu-slider'),(491400,'furniture-mobile','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(491401,'furniture-mobile','.w-menu-slider > ul > li','vertical-align','top','','','.w-menu-slider'),(491402,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','vertical-align','top','','','.b-switch'),(491403,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','vertical-align','middle','','','.b-switch'),(491404,'furniture-mobile','.b-switch .candlestick-wrapper','vertical-align','middle','','','.b-switch'),(491405,'furniture-mobile','.w-compare-box-item .checkbox + span','vertical-align','middle','','','.w-compare-box-item'),(491406,'furniture-mobile','.order-summary .price-row.ot_gv .title','vertical-align','top','3','','.order-summary'),(491407,'furniture-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(491408,'furniture-mobile','.w-catalog-paging .prev-pages','vertical-align','top','','','.w-catalog-paging'),(491409,'furniture-mobile','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(491410,'furniture-mobile','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(491411,'furniture-mobile','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(491412,'furniture-mobile','.p-reviews-info .review_by span','vertical-align','middle','','','.p-reviews-info'),(491413,'furniture-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','vertical-align','middle','','','.w-menu-style-1'),(491414,'furniture-mobile','.w-tabs .tab-li.tab-wishlist a','vertical-align','middle','3','','.w-tabs'),(491415,'furniture-mobile','.w-tabs .tab-li','vertical-align','bottom','','','.w-tabs'),(491416,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(491418,'furniture-mobile','.w-catalog-paging .next','vertical-align','top','','','.w-catalog-paging'),(491419,'furniture-mobile','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(491420,'furniture-mobile','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(491421,'furniture-mobile','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(491422,'furniture-mobile','.w-menu-slider > ul > li > ul > li','vertical-align','top','','','.w-menu-slider'),(491423,'furniture-mobile','.w-menu-slider .close','vertical-align','20px','','','.w-menu-slider'),(491424,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(491425,'furniture-mobile','.b-email .image','vertical-align','top','','','.b-email'),(491426,'furniture-mobile','.w-checkout-billing-address .genders-title > div','vertical-align','top','','','.w-checkout-billing-address'),(491427,'furniture-mobile','.w-checkout-shipping-address .genders-title > div','vertical-align','top','','','.w-checkout-shipping-address'),(491428,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','vertical-align','middle','','','.b-form'),(491429,'furniture-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(491430,'furniture-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(491431,'furniture-mobile','.b-email .price','vertical-align','top','','','.b-email'),(491432,'furniture-mobile','.b-email .price','vertical-align','top','','','.b-email'),(491433,'furniture-mobile','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(491434,'furniture-mobile','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(491435,'furniture-mobile','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(491436,'furniture-mobile','.w-top-categories .item','vertical-align','top','','','.w-top-categories'),(491437,'furniture-mobile','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(491438,'furniture-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(491439,'furniture-mobile','.b-email .name','vertical-align','top','','','.b-email'),(491440,'furniture-mobile','.b-email .model','vertical-align','top','','','.b-email'),(491441,'furniture-mobile','.b-email .price','vertical-align','top','','','.b-email'),(491442,'furniture-mobile','.b-email .image','vertical-align','top','','','.b-email'),(491443,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(491444,'furniture-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','vertical-align','middle','','','.w-menu-style-1'),(491445,'furniture-mobile','.w-cart-discount-coupon .btn','vertical-align','top','','','.w-cart-discount-coupon'),(491446,'furniture-mobile','.w-compare-box-item .checkbox','vertical-align','top','','','.w-compare-box-item'),(491447,'furniture-mobile','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(491448,'furniture-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','vertical-align','middle','','','.w-menu-style-1'),(491449,'furniture-mobile','.w-menu-slider > ul > li > ul > li','vertical-align','top','','','.w-menu-slider'),(491450,'furniture-mobile','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(491451,'furniture-mobile','.p-reviews-info .review_by span','vertical-align','middle','','','.p-reviews-info'),(491452,'furniture-mobile','.b-email .price','vertical-align','top','','','.b-email'),(491453,'furniture-mobile','.b-email .model','vertical-align','top','','','.b-email'),(491454,'furniture-mobile','.b-email .model','vertical-align','top','','','.b-email'),(491456,'furniture-mobile','.w-menu-slider > ul > li','vertical-align','top','','','.w-menu-slider'),(491457,'furniture-mobile','.w-compare-box-item .checkbox','vertical-align','top','','','.w-compare-box-item'),(491458,'furniture-mobile','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(491459,'furniture-mobile','.w-catalog-paging .next-pages','vertical-align','top','','','.w-catalog-paging'),(491460,'furniture-mobile','.b-email .model','vertical-align','top','','','.b-email'),(491461,'furniture-mobile','.b-compare .compare_select_items','vertical-align','middle','','','.b-compare'),(491462,'furniture-mobile','.b-email .name','vertical-align','top','','','.b-email'),(491463,'furniture-mobile','.b-email .image','vertical-align','top','','','.b-email'),(491464,'furniture-mobile','.w-tabs .tab-li.tab-quote a','vertical-align','middle','3','','.w-tabs'),(491465,'furniture-mobile','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(491466,'furniture-mobile','.b-email .price','vertical-align','top','','','.b-email'),(491467,'furniture-mobile','.w-cart-compare .product-label','vertical-align','bottom','','','.w-cart-compare'),(491469,'furniture-mobile','.w-product-available-in-warehouses .warehouse-item','vertical-align','top','','','.w-product-available-in-warehouses'),(491470,'furniture-mobile','.p-reviews-info .review_by span','vertical-align','middle','','','.p-reviews-info'),(491471,'furniture-mobile','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(491472,'furniture-mobile','.w-compare-box-item .checkbox + span','vertical-align','middle','','','.w-compare-box-item'),(491473,'furniture-mobile','.w-compare-box-item .checkbox','vertical-align','top','','','.w-compare-box-item'),(491474,'furniture-mobile','.w-cart-compare .product-actions .dropdown-toggle','vertical-align','middle','3','','.w-cart-compare'),(491475,'furniture-mobile','.w-menu-slider > ul > li','vertical-align','top','','','.w-menu-slider'),(491476,'furniture-mobile','.w-menu-big li li','vertical-align','top','','','.w-menu-big'),(491477,'furniture-mobile','.w-cart-compare .product-cell','vertical-align','top','','','.w-cart-compare'),(491478,'furniture-mobile','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(491479,'furniture-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(491480,'furniture-mobile','.p-reviews-info .review_by span','vertical-align','middle','','','.p-reviews-info'),(491481,'furniture-mobile','.w-compare-box-item .checkbox + span','vertical-align','middle','','','.w-compare-box-item'),(491482,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.b-data-table'),(491483,'furniture-mobile','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.b-data-table'),(491484,'furniture-mobile','.b-products-listing .products-listing .item','vertical-align','top','','','.b-products-listing'),(491485,'furniture-mobile','.w-blog-widget-post-share a, .w-blog-widget-post-share span','vertical-align','middle','','','.w-blog-widget-post-share'),(491486,'furniture-mobile','.checkbox input + span','vertical-align','middle','','',''),(491487,'furniture-mobile','.w-catalog-paging .prev','vertical-align','top','','','.w-catalog-paging'),(491488,'furniture-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(491489,'furniture-mobile','.b-email .name','vertical-align','top','','','.b-email'),(491490,'furniture-mobile','.b-email .image','vertical-align','top','','','.b-email'),(491491,'furniture-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(491492,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(491493,'furniture-mobile','.w-menu-slider .close','vertical-align','20px','','','.w-menu-slider'),(491494,'furniture-mobile','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(491495,'furniture-mobile','.order-summary .price-row.ot_coupon .title','vertical-align','top','3','','.order-summary'),(491496,'furniture-mobile','.w-tabs .tab-li.tab-sample a','vertical-align','middle','3','','.w-tabs'),(491497,'furniture-mobile','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(491498,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','','','.w-communication-new-topic'),(491499,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','3','','.w-communication-new-topic'),(491500,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','vertical-align','top','','','.w-communication-new-topic'),(491501,'furniture-mobile','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','vertical-align','bottom','','','.w-communication-new-topic'),(491502,'furniture-mobile','.w-quote .no-text','vertical-align','top','','','.w-quote'),(491503,'furniture-mobile','.w-menu-slider > ul > li > ul > li','vertical-align','top','','','.w-menu-slider'),(491504,'furniture-mobile','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(491505,'furniture-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(491506,'furniture-mobile','.b-email .name','vertical-align','top','','','.b-email'),(491507,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','vertical-align','top','','','.w-catalog-paging'),(491508,'furniture-mobile','.w-catalog-paging .page-number','vertical-align','top','','','.w-catalog-paging'),(491509,'furniture-mobile','.b-email .image','vertical-align','top','','','.b-email'),(491510,'furniture-mobile','.w-catalog-listing-look .grid','vertical-align','top','','','.w-catalog-listing-look'),(491511,'furniture-mobile','.w-catalog-listing-look .b2b','vertical-align','top','','','.w-catalog-listing-look'),(491512,'furniture-mobile','.w-catalog-listing-look .list','vertical-align','top','','','.w-catalog-listing-look'),(491513,'furniture-mobile','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(491514,'furniture-mobile','.w-cart .no-text','vertical-align','top','','','.w-cart'),(491515,'furniture-mobile','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','vertical-align','top','','','.b-fancybox'),(491516,'furniture-mobile','.b-email .model','vertical-align','top','','','.b-email'),(491517,'furniture-mobile','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(491518,'furniture-mobile','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','vertical-align','middle','','','.w-menu-style-1'),(491519,'furniture-mobile','.w-menu-slider .close','vertical-align','20px','','','.w-menu-slider'),(491520,'furniture-mobile','.w-menu-slider > ul > li','vertical-align','top','','','.w-menu-slider'),(491521,'furniture-mobile','.w-catalog-paging ','vertical-align','top','2','','.w-catalog-paging'),(491522,'furniture-mobile','.order-summary .price-row.ot_bonus_points .title','vertical-align','top','3','','.order-summary'),(491523,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align','top','','','.b-switch'),(491524,'furniture-mobile','.w-menu-slider > ul > li > ul > li','vertical-align','top','','','.w-menu-slider'),(491525,'furniture-mobile','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','vertical-align','top','','','.b-fancybox'),(491526,'furniture-mobile','.w-menu-big li a, .w-menu-big li .no-link','vertical-align','middle','','','.w-menu-big'),(491527,'furniture-mobile','.w-menu-slider > ul > li','vertical-align','top','','','.w-menu-slider'),(491529,'furniture-mobile','.b-email .qty','vertical-align','top','','','.b-email'),(491530,'furniture-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','vertical-align','middle','','','.w-filters'),(491531,'furniture-mobile','.b-product-images .media-popup .mp-small-images .item','vertical-align','top','','','.b-product-images'),(491532,'furniture-mobile','.batchPr .checkbox input + span','vertical-align','middle','','','.batchPr'),(491533,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','vertical-align','middle','3','','.w-catalog-compare'),(491534,'furniture-mobile','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','vertical-align','middle','','','.b-cookie-notice'),(491535,'furniture-mobile','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(491536,'furniture-mobile','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(491537,'furniture-mobile','.b-quantity .qty-box input','vertical-align','top','','','.b-quantity'),(491538,'furniture-mobile','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(491539,'furniture-mobile','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(491540,'furniture-mobile','.w-sample .no-text','vertical-align','top','','','.w-sample'),(491541,'furniture-mobile','.w-cart-order-reference .btn','vertical-align','top','','','.w-cart-order-reference'),(491542,'furniture-mobile','.w-cart-gift-certificate .btn','vertical-align','top','','','.w-cart-gift-certificate'),(491543,'furniture-mobile','.w-cart-shipping-estimator .btn','vertical-align','top','','','.w-cart-shipping-estimator'),(491544,'furniture-mobile','.w-account-address-book .add_item a','vertical-align','middle','3','','.w-account-address-book'),(491545,'furniture-mobile','.b-pagination .pagination .next-pages','vertical-align','top','','','.b-pagination'),(491546,'furniture-mobile','.b-pagination .pagination .page-number','vertical-align','top','','','.b-pagination'),(491547,'furniture-mobile','.b-pagination .pagination .prev-pages','vertical-align','top','','','.b-pagination'),(491548,'furniture-mobile','.b-pagination .pagination a.next, .b-pagination .pagination span.next','vertical-align','top','','','.b-pagination'),(491549,'furniture-mobile','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','vertical-align','top','','','.b-pagination'),(491550,'furniture-mobile','.b-pagination .pagination span','vertical-align','top','2','','.b-pagination'),(491551,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .active a','vertical-align','top','','','.w-wedding-registry-widgets-search-paging'),(491552,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination li span','vertical-align','top','','','.w-wedding-registry-widgets-search-paging'),(491553,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .next span','vertical-align','top','','','.w-wedding-registry-widgets-search-paging'),(491554,'furniture-mobile','.w-wedding-registry-widgets-search-paging .pagination .prev a, .w-wedding-registry-widgets-search-paging .pagination .prev span','vertical-align','top','','','.w-wedding-registry-widgets-search-paging'),(491555,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','vertical-align','top','','','.w-rma-returns-history'),(491556,'furniture-mobile','.w-product-configurator .item-content > div','vertical-align','top','','','.w-product-configurator'),(491557,'furniture-mobile','.w-predefined-promotion .heading-3','vertical-align','top','','','.w-predefined-promotion'),(491558,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','vertical-align','middle','','','.w-filters'),(491559,'furniture-mobile','.mainBanner .topBox > .left','vertical-align','middle','','','.mainBanner'),(491560,'furniture-mobile','.mainBanner .topBox > .right','vertical-align','middle','','','.mainBanner'),(491561,'furniture-mobile','.mainBanner .topBox > .right','vertical-align','middle','3','','.mainBanner'),(491562,'furniture-mobile','.mainBanner .topBox > .right','vertical-align','middle','4','','.mainBanner'),(491563,'furniture-mobile','.account-order-history .view_link','vertical-align','middle','4','','.account-order-history'),(491564,'furniture-mobile','.account-index .view_link','vertical-align','middle','4','','.account-index'),(491565,'furniture-mobile','.account-index td.acc_wish_remove','vertical-align','middle','','','.account-index'),(491566,'furniture-mobile','.account-samples .view_link','vertical-align','middle','4','','.account-samples'),(491567,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align_important','important','','','.b-switch'),(491568,'furniture-mobile','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(491569,'furniture-mobile','.w-compare-box-item .checkbox:not(checked)','visibility','hidden','','','.w-compare-box-item'),(491570,'furniture-mobile','.w-compare-box-item .checkbox:not(checked)','visibility','hidden','','','.w-compare-box-item'),(491571,'furniture-mobile','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(491572,'furniture-mobile','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(491573,'furniture-mobile','.b-fancybox .fancybox-tmp','visibility','hidden','','','.b-fancybox'),(491574,'furniture-mobile','.w-compare-box-item .checkbox:not(checked)','visibility','hidden','','','.w-compare-box-item'),(491575,'furniture-mobile','.w-compare-box-item .checkbox:not(checked)','visibility','hidden','','','.w-compare-box-item'),(491576,'furniture-mobile','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(491577,'furniture-mobile','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(491578,'furniture-mobile','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(491579,'furniture-mobile','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(491580,'furniture-mobile','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(491581,'furniture-mobile','.w-compare-box-item .checkbox:not(checked)','visibility','hidden','','','.w-compare-box-item'),(491582,'furniture-mobile','.w-compare-box-item .checkbox:not(checked)','visibility','hidden','','','.w-compare-box-item'),(491583,'furniture-mobile','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(491584,'furniture-mobile','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(491585,'furniture-mobile','.b-upload-files .attach-active-holder .attach-file','visibility','hidden','','','.b-upload-files'),(491586,'furniture-mobile','.b-fancybox .fancybox-nav:hover span','visibility','visible','','','.b-fancybox'),(491587,'furniture-mobile','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(491588,'furniture-mobile','.b-fancybox .fancybox-opened .fancybox-title','visibility','visible','','','.b-fancybox'),(491589,'furniture-mobile','.checkbox input','visibility','hidden','','',''),(491590,'furniture-mobile','.b-fancybox .fancybox-title','visibility','hidden','','','.b-fancybox'),(491591,'furniture-mobile','.b-fancybox .fancybox-nav span','visibility','hidden','','','.b-fancybox'),(491592,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no','visibility','hidden','','','.b-form'),(491593,'furniture-mobile','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(491594,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','visibility','hidden','','','.b-menu-lev_display-slide'),(491595,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-1 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(491596,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','visibility','hidden','','','.b-menu-lev_display-slide'),(491597,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','visibility','hidden','','','.b-menu-lev_display-slide'),(491598,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','visibility','hidden','','','.b-menu-lev_display-slide'),(491599,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','visibility','hidden','','','.b-menu-lev_display-slide'),(491600,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-2 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(491601,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-4 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(491602,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-5 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(491603,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-3 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(491604,'furniture-mobile','.batchPr .checkbox input','visibility','hidden','','','.batchPr'),(491605,'furniture-mobile','.b-slick .slick-loading .slick-slide','visibility','hidden','','','.b-slick'),(491606,'furniture-mobile','.b-slick .slick-loading .slick-track','visibility','hidden','','','.b-slick'),(491607,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no input','visibility','hidden','','','.w-questionnaire-widgets-questionnaire'),(491608,'furniture-mobile','.w-menu-style-1 > ul','white-space','nowrap','','','.w-menu-style-1'),(491609,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap .child','white-space','nowrap','','','.b-fancybox'),(491610,'furniture-mobile','.w-menu-style-1 > ul','white-space','nowrap','','','.w-menu-style-1'),(491611,'furniture-mobile','.w-menu-style-1 > ul','white-space','nowrap','','','.w-menu-style-1'),(491612,'furniture-mobile','.w-menu-style-1 > ul','white-space','nowrap','','','.w-menu-style-1'),(491613,'furniture-mobile','.w-checkout-shipping-choice span','white-space','nowrap','2906','','.w-checkout-shipping-choice'),(491614,'furniture-mobile','.b-select-suggest .select2-container .select2-choice > .select2-chosen','white-space','nowrap','','','.b-select-suggest'),(491615,'furniture-mobile','.w-menu-horizontal > ul','white-space','nowrap','','','.w-menu-horizontal'),(491616,'furniture-mobile','.w-menu-horizontal > ul','white-space','normal','2885','','.w-menu-horizontal'),(491617,'furniture-mobile','.b-fancybox .fancybox-error','white-space','nowrap','','','.b-fancybox'),(491618,'furniture-mobile','.w-catalog-sorting .before','white-space','nowrap','','','.w-catalog-sorting'),(491619,'furniture-mobile','.b-select-suggest .select2-search','white-space','nowrap','','','.b-select-suggest'),(491620,'furniture-mobile','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','white-space','nowrap','','','.b-select-suggest'),(491621,'furniture-mobile','.b-select-suggest .select2-container .select2-choice','white-space','nowrap','','','.b-select-suggest'),(491622,'furniture-mobile','.w-cart-listing .remove-btn','white-space','nowrap','2885','','.w-cart-listing'),(491623,'furniture-mobile','.w-menu-style-1 > ul','white-space','nowrap','','','.w-menu-style-1'),(491624,'furniture-mobile','.w-menu-style-1 > ul','white-space','nowrap','','','.w-menu-style-1'),(491625,'furniture-mobile','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(491626,'furniture-mobile','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','white-space','nowrap','','','.w-cart-listing'),(491627,'furniture-mobile','.account-order-history .view_link','white-space','nowrap','','','.account-order-history'),(491628,'furniture-mobile','.account-index .view_link','white-space','nowrap','','','.account-index'),(491629,'furniture-mobile','.account-samples .view_link','white-space','nowrap','','','.account-samples'),(491630,'furniture-mobile','.w-communication-new-topic .model','width','100','','','.w-communication-new-topic'),(491631,'furniture-mobile','.w-communication-new-topic .date-purchased','width','130','','','.w-communication-new-topic'),(491632,'furniture-mobile','.w-communication-new-topic .request-type','width','150','','','.w-communication-new-topic'),(491633,'furniture-mobile','.w-communication-new-topic .return-reason','width','150','','','.w-communication-new-topic'),(491634,'furniture-mobile','.b-form .col-left','width','48','','','.b-form'),(491635,'furniture-mobile','.w-blog-widget-related-posts-by-category .post','width','50','','','.w-blog-widget-related-posts-by-category'),(491636,'furniture-mobile','.b-email img','width','60','','','.b-email'),(491637,'furniture-mobile','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(491638,'furniture-mobile','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(491639,'furniture-mobile','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(491640,'furniture-mobile','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(491641,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width','49','','','.p-account-trade-form'),(491642,'furniture-mobile','.w-compare-box-item .checkbox','width','22','','','.w-compare-box-item'),(491643,'furniture-mobile','.w-compare-box-item .checkbox + span','width','24','','','.w-compare-box-item'),(491644,'furniture-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(491645,'furniture-mobile','.p-blog-index .nav-previous','width','50','','','.p-blog-index'),(491646,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width','48','','','.p-account-trade-form'),(491647,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width','49','','','.p-account-trade-form'),(491648,'furniture-mobile','.w-product-images-additional .item','width','80','2906','','.w-product-images-additional'),(491649,'furniture-mobile','.w-cart .image','width','70','','','.w-cart'),(491650,'furniture-mobile','.b-email .totals-value','width','30','','','.b-email'),(491651,'furniture-mobile','.w-promotions .prom-multi-discount .image img','width','auto','','','.w-promotions'),(491652,'furniture-mobile','.w-promotions .promo-salemaker > div','width','50','','','.w-promotions'),(491653,'furniture-mobile','.w-promotions .promo-cart-discount > div','width','50','','','.w-promotions'),(491654,'furniture-mobile','.w-menu .hided.menu ul li','width','auto','','','.w-menu'),(491655,'furniture-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width','55','','','.p-account-trade-form'),(491656,'furniture-mobile','.p-blog-index .nav-previous','width','50','','','.p-blog-index'),(491657,'furniture-mobile','.w-account .account-dropdown','width','330','','','.w-account'),(491658,'furniture-mobile','.w-account .logged-ul','width','200','','','.w-account'),(491659,'furniture-mobile','.w-account input','width','100','','','.w-account'),(491660,'furniture-mobile','.p-reviews-info .review-info-image','width','24','','','.p-reviews-info'),(491661,'furniture-mobile','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width','100','','','.p-sample-checkout-login'),(491662,'furniture-mobile','.p-blog-index .post-thumbnail','width','200','','','.p-blog-index'),(491663,'furniture-mobile','.p-blog-index .nav-previous','width','50','','','.p-blog-index'),(491664,'furniture-mobile','.p-blog-index .nav-next','width','50','','','.p-blog-index'),(491665,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width','48','','','.p-account-trade-form'),(491666,'furniture-mobile','.b-email .image','width','100','','','.b-email'),(491667,'furniture-mobile','.p-blog-index .nav-next','width','100','2906','','.p-blog-index'),(491668,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(491669,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','width','22','','','.w-compare-box-item'),(491670,'furniture-mobile','.w-compare-box-item .checkbox + span','width','24','','','.w-compare-box-item'),(491671,'furniture-mobile','.w-compare-box-item .checkbox','width','22','','','.w-compare-box-item'),(491672,'furniture-mobile','.w-categories .item','width','25','','','.w-categories'),(491673,'furniture-mobile','.w-promotions .prom-multi-discount .list','width','100','','','.w-promotions'),(491674,'furniture-mobile','.w-promotions .nextdiscount .item-holder .image','width','40','','','.w-promotions'),(491675,'furniture-mobile','.w-promotions .nextdiscount .item-holder .name','width','60','','','.w-promotions'),(491676,'furniture-mobile','.w-promotions .icon','width','45','','','.w-promotions'),(491677,'furniture-mobile','.w-promotions .promo-salemaker .image img','width','auto','','','.w-promotions'),(491678,'furniture-mobile','.w-promotions .promo-salemaker .item','width','50','','','.w-promotions'),(491679,'furniture-mobile','.w-promotions .promo-cart-discount .slave .item','width','calc(50% - 4px)','','','.w-promotions'),(491680,'furniture-mobile','.w-promotions .promo-cart-discount .image img','width','auto','','','.w-promotions'),(491681,'furniture-mobile','.b-warehouses-popup .warehouses-popup','width','570','','','.b-warehouses-popup'),(491682,'furniture-mobile','.b-warehouses-popup .warehouses-popup .warehouse-item','width','230','','','.b-warehouses-popup'),(491683,'furniture-mobile','.b-preloader .preloader','width','40','3','','.b-preloader'),(491684,'furniture-mobile','.b-preloader .preloader','width','100','','','.b-preloader'),(491685,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block','width','47','','','.b-products-listing'),(491686,'furniture-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(491687,'furniture-mobile','.w-brands .brands-listing > div','width','16','','','.w-brands'),(491688,'furniture-mobile','.w-cart-continue-btn a','width','100','2876','','.w-cart-continue-btn'),(491689,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','width','180','','','.w-wedding-registry-widgets-photos'),(491690,'furniture-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(491691,'furniture-mobile','.order-summary .price-row.ot_gv .title','width','32','3','','.order-summary'),(491692,'furniture-mobile','.w-brands .brands-listing > div','width','16','','','.w-brands'),(491693,'furniture-mobile','.w-login-block .returning','width','50','','','.w-login-block'),(491694,'furniture-mobile','.p-blog-index .post-thumbnail','width','200','','','.p-blog-index'),(491695,'furniture-mobile','.w-product-images-additional .item','width','80','2906','','.w-product-images-additional'),(491696,'furniture-mobile','.w-menu-style-1 .menu-ico','width','54','','','.w-menu-style-1'),(491697,'furniture-mobile','.w-product-images-additional .additional-images','width','80','2906','','.w-product-images-additional'),(491698,'furniture-mobile','.b-products-listing .select-attributes select','width','66','','','.b-products-listing'),(491699,'furniture-mobile','.b-messages .box-block.type-6 > .block:nth-child(1)','width','25','','','.b-messages'),(491700,'furniture-mobile','.b-messages .msv_to_cc div span.msv_to_cc_bold','width','100','','','.b-messages'),(491701,'furniture-mobile','.b-messages .messages-sidebar .btn-2','width','100','','','.b-messages'),(491702,'furniture-mobile','.b-messages .pre_upload','width','auto','','','.b-messages'),(491703,'furniture-mobile','.b-messages .email-line input','width','100','','','.b-messages'),(491704,'furniture-mobile','.w-sale .holder-1','width','25','','','.w-sale'),(491705,'furniture-mobile','.b-messages .email-line label','width','150','','','.b-messages'),(491706,'furniture-mobile','.b-messages #DataTables_Table_0_wrapper table.dataTable thead td:last-child, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td:last-child','width','200','','','.b-messages'),(491707,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul > li','width','25','','','.w-sitemap-delivery-location'),(491708,'furniture-mobile','.w-search .button-search','width','30','','','.w-search'),(491709,'furniture-mobile','.w-sale .image','width','50','','','.w-sale'),(491710,'furniture-mobile','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(491711,'furniture-mobile','.b-bottom .terms-info-popup','width','1000','','','.b-bottom'),(491712,'furniture-mobile','.p-blog-index .post-thumbnail','width','200','','','.p-blog-index'),(491713,'furniture-mobile','.p-blog-index .comment-form p label','width','100','','','.p-blog-index'),(491714,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width','48','','','.p-account-trade-form'),(491715,'furniture-mobile','.b-form .col-right','width','100','2885','','.b-form'),(491716,'furniture-mobile','.p-payer-order-confirmation .order-summary2 .btn-2','width','100','','','.p-payer-order-confirmation'),(491717,'furniture-mobile','.p-payer-order-confirmation .dob-hide > div','width','48','','','.p-payer-order-confirmation'),(491718,'furniture-mobile','.p-payer-order-pay .order-summary2 .btn-2','width','100','','','.p-payer-order-pay'),(491719,'furniture-mobile','.p-payer-order-pay .dob-hide > div','width','48','','','.p-payer-order-pay'),(491720,'furniture-mobile','.w-checkout-terms .required-message','width','100','','','.w-checkout-terms'),(491721,'furniture-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(491722,'furniture-mobile','.p-blog-index .comment-form p label','width','100','','','.p-blog-index'),(491723,'furniture-mobile','.w-checkout-create-btn .btn-2','width','260','','','.w-checkout-create-btn'),(491724,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','width','15','','','.b-switch'),(491725,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-toggle','width','40','','','.b-switch'),(491726,'furniture-mobile','.b-fancybox #fancybox-loading div','width','44','','','.b-fancybox'),(491727,'furniture-mobile','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','width','79','','','.b-datepicker'),(491728,'furniture-mobile','.b-email .image','width','100','','','.b-email'),(491729,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','width','25','3','','.w-checkout-contact-information'),(491730,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','width','100','','','.b-switch'),(491731,'furniture-mobile','.w-menu-slider > ul > li > ul','width','100','','','.w-menu-slider'),(491732,'furniture-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width','55','','','.p-account-trade-form'),(491733,'furniture-mobile','.p-account-trade-form .wl-td select','width','55','','','.p-account-trade-form'),(491734,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width','49','','','.p-account-trade-form'),(491735,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width','49','','','.p-account-trade-form'),(491736,'furniture-mobile','.p-account-trade-form .wl-td label','width','40','','','.p-account-trade-form'),(491737,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width','48','','','.p-account-trade-form'),(491738,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width','48','','','.p-account-trade-form'),(491739,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','width','15','','','.b-switch'),(491740,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width','20','3','','.b-switch'),(491741,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','width','150','','','.w-upload-customer-id-upload-customer-id-form'),(491742,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(491743,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(491744,'furniture-mobile','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(491745,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','width','144','','','.w-wedding-registry-widgets-photos'),(491746,'furniture-mobile','.b-email .image','width','100','','','.b-email'),(491747,'furniture-mobile','.w-checkout-bonus-points .btn-remove','width','25','','','.w-checkout-bonus-points'),(491748,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(491749,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(491750,'furniture-mobile','.w-login-block .input','width','100','','','.w-login-block'),(491751,'furniture-mobile','.w-login-block .guest','width','50','','','.w-login-block'),(491752,'furniture-mobile','.w-login-block .new','width','50','','','.w-login-block'),(491753,'furniture-mobile','.w-menu-horizontal li','width','auto','','','.w-menu-horizontal'),(491754,'furniture-mobile','.w-menu-slider > ul > li > ul','width','100','','','.w-menu-slider'),(491755,'furniture-mobile','.w-menu-slider .menu-ico','width','54','','','.w-menu-slider'),(491756,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width','48','','','.p-account-trade-form'),(491757,'furniture-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(491758,'furniture-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(491759,'furniture-mobile','.w-login-block .input','width','100','','','.w-login-block'),(491760,'furniture-mobile','.b-form .checkbox-style:checked + .checkbox-span','width','15','','','.b-form'),(491762,'furniture-mobile','.w-delayed-despatch-checkout #delivery_date','width','150','','','.w-delayed-despatch-checkout'),(491763,'furniture-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(491764,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','100','2906','','.p-blog-index'),(491765,'furniture-mobile','.p-blog-index .nav-previous','width','100','2906','','.p-blog-index'),(491766,'furniture-mobile','.w-product-images-additional .item-div','width','80','2906','','.w-product-images-additional'),(491767,'furniture-mobile','.w-product-wishlist-button .btn','width','100','2876','','.w-product-wishlist-button'),(491768,'furniture-mobile','.p-blog-index .nav-next','width','50','','','.p-blog-index'),(491769,'furniture-mobile','.p-account-trade-form .wl-td select','width','55','','','.p-account-trade-form'),(491770,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','100','2906','','.p-blog-index'),(491771,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width','49','','','.p-account-trade-form'),(491772,'furniture-mobile','.b-fancybox .fancybox-lock','width','auto','','','.b-fancybox'),(491773,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','width','15','','','.b-switch'),(491774,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','width','10','','','.b-switch'),(491775,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','width','10','','','.b-switch'),(491776,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs','width','30','','','.b-switch'),(491777,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-toggle','width','15','','','.b-switch'),(491778,'furniture-mobile','.w-menu .hided.menu ul ul','width','auto','','','.w-menu'),(491779,'furniture-mobile','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(491780,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width','48','','','.p-account-trade-form'),(491781,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width','48','','','.p-account-trade-form'),(491782,'furniture-mobile','.w-promo-code .promo-code-form','width','100','2885','','.w-promo-code'),(491783,'furniture-mobile','.b-email .totals-value','width','30','','','.b-email'),(491784,'furniture-mobile','.b-email .totals-title','width','70','','','.b-email'),(491785,'furniture-mobile','.w-filters .ui-slider-handle','width','15','','','.w-filters'),(491786,'furniture-mobile','.p-blog-index .comment-form p label','width','100','','','.p-blog-index'),(491787,'furniture-mobile','.pop-up-content .buttons .btn-2','width','100','2885','',''),(491788,'furniture-mobile','.pop-up-content .buttons .btn','width','100','2885','',''),(491789,'furniture-mobile','.pop-up-content .buttons .left-buttons','width','100','2885','',''),(491790,'furniture-mobile','.pop-up-content .buttons .right-buttons','width','100','2885','',''),(491791,'furniture-mobile','.w-menu-slider .menu-ico','width','54','','','.w-menu-slider'),(491792,'furniture-mobile','.w-menu-style-1 li','width','auto','','','.w-menu-style-1'),(491793,'furniture-mobile','.w-menu .hided.menu ul ul','width','auto','','','.w-menu'),(491794,'furniture-mobile','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(491795,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','width','22','','','.w-compare-box-item'),(491796,'furniture-mobile','.w-login-block .returning','width','50','','','.w-login-block'),(491797,'furniture-mobile','.w-languages .lang-link','width','61','2885','','.w-languages'),(491798,'furniture-mobile','.w-sale .left-text-right','width','24','','','.w-sale'),(491799,'furniture-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(491800,'furniture-mobile','.w-sale .left-text-left','width','24','','','.w-sale'),(491801,'furniture-mobile','.w-menu .hided.menu ul ul','width','auto','','','.w-menu'),(491802,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(491803,'furniture-mobile','.b-products-listing .btn-choose-options','width','100','','','.b-products-listing'),(491804,'furniture-mobile','.w-filters .input-checkbox:checked + .checkbox-span','width','24','','','.w-filters'),(491805,'furniture-mobile','.w-filters .ui-slider','width','100','','','.w-filters'),(491806,'furniture-mobile','.w-checkout-shipping-choice input:checked + span:before','width','10','','','.w-checkout-shipping-choice'),(491807,'furniture-mobile','.b-switch .candlestick-wrapper','width','60','','','.b-switch'),(491808,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','width','20','3','','.b-switch'),(491809,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(491810,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width','49','','','.p-account-trade-form'),(491811,'furniture-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width','55','','','.p-account-trade-form'),(491812,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width','48','','','.p-account-trade-form'),(491813,'furniture-mobile','.p-blog-index .comment-form p label','width','100','','','.p-blog-index'),(491814,'furniture-mobile','.b-email .image','width','100','','','.b-email'),(491815,'furniture-mobile','.b-email .totals-value','width','30','','','.b-email'),(491816,'furniture-mobile','.b-email .heading-image','width','100','','','.b-email'),(491817,'furniture-mobile','.b-email .products-table','width','100','','','.b-email'),(491818,'furniture-mobile','.b-form .login-col-1','width','25','','','.b-form'),(491819,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box-full','width','auto','','','.w-wedding-registry-widgets-photos'),(491820,'furniture-mobile','.w-compare-box-item .checkbox','width','22','','','.w-compare-box-item'),(491821,'furniture-mobile','.b-select-suggest .select2-container','width','100','','','.b-select-suggest'),(491822,'furniture-mobile','.b-select-suggest .select2-measure-scrollbar','width','100','','','.b-select-suggest'),(491823,'furniture-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(491824,'furniture-mobile','.b-form .middle-form .dob-input input[type=\"text\"]','width','48','','','.b-form'),(491825,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width','1','','','.b-select-suggest'),(491826,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(491827,'furniture-mobile','.w-brands .brands-listing > div','width','16','','','.w-brands'),(491828,'furniture-mobile','.w-compare-box-item .checkbox + span','width','24','','','.w-compare-box-item'),(491829,'furniture-mobile','.w-compare-box-item .checkbox','width','22','','','.w-compare-box-item'),(491830,'furniture-mobile','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(491831,'furniture-mobile','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(491832,'furniture-mobile','.w-socials .post_item_img','width','100','','','.w-socials'),(491833,'furniture-mobile','.w-search .suggest','width','100','','','.w-search'),(491834,'furniture-mobile','.b-info-popup .info-popup div','width','250','','','.b-info-popup'),(491835,'furniture-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','2885','','.w-promo-code'),(491836,'furniture-mobile','.p-blog-index .comment-form p label','width','100','','','.p-blog-index'),(491837,'furniture-mobile','.w-wedding-registry-widgets-products .products-listing .item','width','33','2885','','.w-wedding-registry-widgets-products'),(491838,'furniture-mobile','.w-brands .brands-listing > div','width','16','','','.w-brands'),(491839,'furniture-mobile','.w-cart-listing .right-area','width','100','2885','','.w-cart-listing'),(491840,'furniture-mobile','.w-product-images-additional .additional-images','width','80','2906','','.w-product-images-additional'),(491841,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','50','2885','','.p-blog-index'),(491842,'furniture-mobile','.w-promo-code .promo-text','width','100','2885','','.w-promo-code'),(491843,'furniture-mobile','.w-product-wishlist-button .btn','width','100','2876','','.w-product-wishlist-button'),(491844,'furniture-mobile','.w-cart-continue-btn a','width','100','2876','','.w-cart-continue-btn'),(491845,'furniture-mobile','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(491846,'furniture-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(491847,'furniture-mobile','.w-cart-order-total.box','width','100','2876','','.w-cart-order-total'),(491848,'furniture-mobile','.w-sale .left-text-left','width','24','','','.w-sale'),(491849,'furniture-mobile','.b-info-popup .info-popup div','width','20','3','','.b-info-popup'),(491850,'furniture-mobile','.b-email .totals-value','width','30','','','.b-email'),(491851,'furniture-mobile','.b-email .heading-image','width','100','','','.b-email'),(491852,'furniture-mobile','.b-email .heading-image','width','100','','','.b-email'),(491853,'furniture-mobile','.view-all','width','100','3','',''),(491854,'furniture-mobile','.w-sale .left-text-right','width','24','','','.w-sale'),(491855,'furniture-mobile','.p-blog-index .nav-previous','width','100','2906','','.p-blog-index'),(491856,'furniture-mobile','.w-promo-code .promo-code-form','width','100','2885','','.w-promo-code'),(491857,'furniture-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','2885','','.w-promo-code'),(491858,'furniture-mobile','.w-menu-style-1 .menu-ico','width','54','','','.w-menu-style-1'),(491859,'furniture-mobile','.w-menu-style-1 li','width','auto','','','.w-menu-style-1'),(491860,'furniture-mobile','.w-search .search-input','width','100','','','.w-search'),(491861,'furniture-mobile','.b-form .columns .col-2','width','48','','','.b-form'),(491862,'furniture-mobile','.b-bottom .popup-box.popupCompare','width','80','','','.b-bottom'),(491863,'furniture-mobile','.p-blog-index .nav-previous','width','100','2906','','.p-blog-index'),(491864,'furniture-mobile','.w-promo-code .promo-code-form','width','100','2885','','.w-promo-code'),(491865,'furniture-mobile','.w-cart-continue-btn a','width','100','2876','','.w-cart-continue-btn'),(491866,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width','48','','','.p-account-trade-form'),(491867,'furniture-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(491869,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(491870,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(491871,'furniture-mobile','.w-sale .holder-2','width','25','','','.w-sale'),(491872,'furniture-mobile','.w-sale .holder-1','width','25','','','.w-sale'),(491873,'furniture-mobile','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(491874,'furniture-mobile','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(491875,'furniture-mobile','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(491876,'furniture-mobile','.p-account-trade-form .wl-td select','width','55','','','.p-account-trade-form'),(491877,'furniture-mobile','.w-checkout-guest-btn .btn-2','width','260','','','.w-checkout-guest-btn'),(491878,'furniture-mobile','.w-menu-slider > ul > li > ul','width','100','','','.w-menu-slider'),(491879,'furniture-mobile','textarea','width','100','','',''),(491880,'furniture-mobile','.w-menu-slider > ul > li > ul','width','100','','','.w-menu-slider'),(491881,'furniture-mobile','.w-menu-slider .menu-ico','width','54','','','.w-menu-slider'),(491882,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(491883,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','width','100','','','.b-switch'),(491884,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','width','100','','','.b-switch'),(491885,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-label','width','30','','','.b-switch'),(491886,'furniture-mobile','.w-menu .hided.menu ul li','width','auto','','','.w-menu'),(491887,'furniture-mobile','.w-menu-slider > ul > li > ul','width','100','','','.w-menu-slider'),(491888,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(491889,'furniture-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(491890,'furniture-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(491891,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','width','100','','','.b-switch'),(491893,'furniture-mobile','.b-form .checkbox-style','width','0','','','.b-form'),(491894,'furniture-mobile','.b-email .image','width','100','','','.b-email'),(491895,'furniture-mobile','.b-email .totals-title','width','70','','','.b-email'),(491896,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','width','25','3','','.w-checkout-contact-information'),(491897,'furniture-mobile','.b-form .addresses .address-item','width','48','','','.b-form'),(491898,'furniture-mobile','.w-categories .item','width','50','2876','','.w-categories'),(491899,'furniture-mobile','.order-summary .btn-2, .order-summary .btn-3','width','100','','','.order-summary'),(491900,'furniture-mobile','.w-cart-bonus-points .bonus_points_amount','width','150','','','.w-cart-bonus-points'),(491901,'furniture-mobile','.w-cart-bonus-points .btn-remove','width','25','','','.w-cart-bonus-points'),(491902,'furniture-mobile','.order-summary .price-box .price','width','auto','','','.order-summary'),(491903,'furniture-mobile','.b-email .totals-table','width','100','','','.b-email'),(491904,'furniture-mobile','.w-socials .post_item_img','width','100','','','.w-socials'),(491905,'furniture-mobile','.p-blog-index .nav-next','width','50','','','.p-blog-index'),(491906,'furniture-mobile','.w-menu-style-1 li','width','auto','','','.w-menu-style-1'),(491907,'furniture-mobile','.w-list-b2b .select-attributes','width','47','','','.w-list-b2b'),(491908,'furniture-mobile','.w-sale .holder-2','width','25','','','.w-sale'),(491909,'furniture-mobile','.w-sale .badge','width','80','','','.w-sale'),(491910,'furniture-mobile','.w-promo-code .promo-text','width','100','2885','','.w-promo-code'),(491911,'furniture-mobile','.w-checkout-shipping-choice label','width','50','','','.w-checkout-shipping-choice'),(491912,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents','width','306','','','.b-switch'),(491913,'furniture-mobile','.b-email .products-table','width','100','','','.b-email'),(491914,'furniture-mobile','.w-checkout-shipping-choice label','width','auto','2906','','.w-checkout-shipping-choice'),(491915,'furniture-mobile','.w-checkout-create-account .col-2','width','100','2885','','.w-checkout-create-account'),(491916,'furniture-mobile','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(491917,'furniture-mobile','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(491918,'furniture-mobile','.w-top-categories .item','width','25','','','.w-top-categories'),(491919,'furniture-mobile','.w-checkout-billing-address .addresses .address-item','width','50','','','.w-checkout-billing-address'),(491920,'furniture-mobile','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(491921,'furniture-mobile','.w-sale .badge','width','80','','','.w-sale'),(491922,'furniture-mobile','.w-sale .holder-2','width','25','','','.w-sale'),(491923,'furniture-mobile','.w-sale .image','width','50','','','.w-sale'),(491924,'furniture-mobile','.w-sale .holder-1','width','25','','','.w-sale'),(491925,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width','49','','','.p-account-trade-form'),(491926,'furniture-mobile','.w-cart-give-away .ga_attributes select','width','100','','','.w-cart-give-away'),(491927,'furniture-mobile','.w-cart-checkout-btn a','width','100','2876','','.w-cart-checkout-btn'),(491928,'furniture-mobile','.b-autocomplete .ui-autocomplete','width','200','','','.b-autocomplete'),(491929,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(491930,'furniture-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(491931,'furniture-mobile','.w-socials .post_item_img','width','100','','','.w-socials'),(491932,'furniture-mobile','.w-account-address-book .item','width','48','','','.w-account-address-book'),(491933,'furniture-mobile','.b-email .totals-value','width','30','','','.b-email'),(491934,'furniture-mobile','.b-email .totals-table','width','100','','','.b-email'),(491935,'furniture-mobile','.b-email .totals-title','width','70','','','.b-email'),(491936,'furniture-mobile','.b-email .heading-image','width','100','','','.b-email'),(491937,'furniture-mobile','.b-email img','width','60','','','.b-email'),(491938,'furniture-mobile','.b-email .products-table','width','100','','','.b-email'),(491939,'furniture-mobile','.b-email .image','width','100','','','.b-email'),(491940,'furniture-mobile','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width','100','','','.p-quote-checkout-login'),(491941,'furniture-mobile','.b-form .col-right','width','48','','','.b-form'),(491942,'furniture-mobile','.b-email img','width','60','','','.b-email'),(491943,'furniture-mobile','.w-cart-continue-btn a','width','100','2876','','.w-cart-continue-btn'),(491944,'furniture-mobile','.w-product-wishlist-button .btn','width','100','2876','','.w-product-wishlist-button'),(491945,'furniture-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','2885','','.w-promo-code'),(491946,'furniture-mobile','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(491947,'furniture-mobile','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(491948,'furniture-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(491949,'furniture-mobile','.w-promo-code .promo-code-form','width','100','2885','','.w-promo-code'),(491950,'furniture-mobile','.w-promo-code .promo-text','width','100','2885','','.w-promo-code'),(491951,'furniture-mobile','.b-form .columns .col-2','width','100','2906','','.b-form'),(491952,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width','49','','','.p-account-trade-form'),(491953,'furniture-mobile','.b-select-suggest .select2-container .select2-choice abbr','width','12','','','.b-select-suggest'),(491954,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(491955,'furniture-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(491957,'furniture-mobile','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(491958,'furniture-mobile','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(491959,'furniture-mobile','.w-banner .carousel-text','width','100','','','.w-banner'),(491960,'furniture-mobile','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width','100','','','.w-banner'),(491961,'furniture-mobile','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(491962,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','width','20','','','.b-switch'),(491963,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','width','28','','','.b-switch'),(491964,'furniture-mobile','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(491965,'furniture-mobile','.w-menu-style-1 li','width','auto','','','.w-menu-style-1'),(491966,'furniture-mobile','.w-sale .left-text-right','width','24','','','.w-sale'),(491967,'furniture-mobile','.w-sale .left-count','width','23','','','.w-sale'),(491968,'furniture-mobile','.w-login-block .new','width','50','','','.w-login-block'),(491969,'furniture-mobile','.w-sale .left-text-left','width','24','','','.w-sale'),(491970,'furniture-mobile','.w-login-block .guest','width','50','','','.w-login-block'),(491971,'furniture-mobile','.w-login-block .input','width','100','','','.w-login-block'),(491972,'furniture-mobile','.w-login-block .returning','width','50','','','.w-login-block'),(491973,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(491974,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(491975,'furniture-mobile','.p-blog-index .nav-next','width','100','2906','','.p-blog-index'),(491976,'furniture-mobile','div.cart-popup','width','850','','',''),(491977,'furniture-mobile','.w-cart-give-away .ga_column','width','46','','','.w-cart-give-away'),(491978,'furniture-mobile','.w-cart-give-away .ga_attributes > div','width','48','','','.w-cart-give-away'),(491979,'furniture-mobile','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width','100','','','.b-form'),(491980,'furniture-mobile','.w-wedding-registry-widgets-share-url input','width','100','','','.w-wedding-registry-widgets-share-url'),(491981,'furniture-mobile','.b-products-listing .products-listing .buyButton .btn','width','100','','','.b-products-listing'),(491982,'furniture-mobile','.w-image-maps .svg-wrap svg','width','100','','','.w-image-maps'),(491983,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(491984,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','width','22','','','.w-compare-box-item'),(491985,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(491986,'furniture-mobile','.w-login-block .guest','width','50','','','.w-login-block'),(491987,'furniture-mobile','.w-login-block .new','width','50','','','.w-login-block'),(491988,'furniture-mobile','.w-cart-shipping-estimator .right-area','width','48','','','.w-cart-shipping-estimator'),(491989,'furniture-mobile','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(491990,'furniture-mobile','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(491991,'furniture-mobile','.w-menu-style-1 .menu-ico','width','54','','','.w-menu-style-1'),(491992,'furniture-mobile','.w-menu .hided.menu ul li','width','auto','','','.w-menu'),(491993,'furniture-mobile','.w-checkout-credit-amount .btn-remove','width','25','','','.w-checkout-credit-amount'),(491994,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(491995,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','width','22','','','.w-compare-box-item'),(491996,'furniture-mobile','.p-blog-index .nav-next','width','50','','','.p-blog-index'),(491997,'furniture-mobile','.p-account-trade-form .wl-td select','width','55','','','.p-account-trade-form'),(491998,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width','49','','','.p-account-trade-form'),(491999,'furniture-mobile','.w-sale .left-text-left','width','24','','','.w-sale'),(492000,'furniture-mobile','.w-checkout-credit-amount .cot_gv_amount','width','150','','','.w-checkout-credit-amount'),(492001,'furniture-mobile','.p-quick-order-index .all-scroll-div','width','100','','','.p-quick-order-index'),(492002,'furniture-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(492003,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(492004,'furniture-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(492005,'furniture-mobile','.b-form .col-left','width','100','2885','','.b-form'),(492006,'furniture-mobile','.b-email .totals-title','width','70','','','.b-email'),(492007,'furniture-mobile','.b-email .totals-table','width','100','','','.b-email'),(492008,'furniture-mobile','.w-product-images-additional .additional-images','width','80','2906','','.w-product-images-additional'),(492009,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','100','2906','','.p-blog-index'),(492010,'furniture-mobile','.w-product-images-additional .item','width','80','2906','','.w-product-images-additional'),(492011,'furniture-mobile','.b-bottom .cart-options .option-item','width','50','','','.b-bottom'),(492012,'furniture-mobile','.w-promotions .promo-cart-discount .master .item','width','calc(50% - 24px)','','','.w-promotions'),(492013,'furniture-mobile','.w-sale .left-text-right','width','24','','','.w-sale'),(492014,'furniture-mobile','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(492015,'furniture-mobile','.w-sale .left-count','width','23','','','.w-sale'),(492016,'furniture-mobile','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(492017,'furniture-mobile','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(492018,'furniture-mobile','.w-menu-style-1 li','width','auto','','','.w-menu-style-1'),(492019,'furniture-mobile','.b-bottom .cart-options .cart-item','width','100','','','.b-bottom'),(492020,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(492021,'furniture-mobile','.w-cart-shipping-estimator .left-area','width','48','','','.w-cart-shipping-estimator'),(492022,'furniture-mobile','.w-menu .hided.menu ul li','width','auto','','','.w-menu'),(492023,'furniture-mobile','.w-login-block .returning','width','50','','','.w-login-block'),(492024,'furniture-mobile','.w-sale .badge','width','80','','','.w-sale'),(492025,'furniture-mobile','.w-sale .holder-2','width','25','','','.w-sale'),(492027,'furniture-mobile','.p-blog-index .nav-previous','width','100','2906','','.p-blog-index'),(492028,'furniture-mobile','.p-blog-index .comment-form p label','width','100','','','.p-blog-index'),(492029,'furniture-mobile','.p-blog-index .nav-next','width','100','2906','','.p-blog-index'),(492030,'furniture-mobile','.p-blog-index .post-thumbnail','width','200','','','.p-blog-index'),(492032,'furniture-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(492033,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(492034,'furniture-mobile','.b-email img','width','60','','','.b-email'),(492035,'furniture-mobile','.b-form .col-3','width','31.33','','','.b-form'),(492036,'furniture-mobile','.b-email .products-table','width','100','','','.b-email'),(492037,'furniture-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(492038,'furniture-mobile','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width','100','','','.b-form'),(492039,'furniture-mobile','.w-login-block .input','width','100','','','.w-login-block'),(492040,'furniture-mobile','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','width','35','','','.b-products-listing'),(492041,'furniture-mobile','.w-login-block .guest','width','50','','','.w-login-block'),(492042,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width','49','','','.p-account-trade-form'),(492043,'furniture-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(492044,'furniture-mobile','.w-product-wishlist-button .btn','width','100','2876','','.w-product-wishlist-button'),(492045,'furniture-mobile','.w-product-images-additional .item-div','width','80','2906','','.w-product-images-additional'),(492046,'furniture-mobile','.b-bottom .popup-box','width','530','','','.b-bottom'),(492047,'furniture-mobile','.b-email .totals-table','width','100','','','.b-email'),(492048,'furniture-mobile','.b-email img','width','60','','','.b-email'),(492049,'furniture-mobile','.b-form .login-col-2','width','50','','','.b-form'),(492050,'furniture-mobile','.b-fancybox .fancybox-close','width','40','','','.b-fancybox'),(492051,'furniture-mobile','.w-cart-compare .product .image','width','50','','','.w-cart-compare'),(492052,'furniture-mobile','.w-product-customers-activity .customers-activity','width','255','','','.w-product-customers-activity'),(492053,'furniture-mobile','.w-product-customers-activity .close','width','30','','','.w-product-customers-activity'),(492054,'furniture-mobile','.b-form .hide-billing-address','width','100','','','.b-form'),(492055,'furniture-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width','55','','','.p-account-trade-form'),(492056,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width','49','','','.p-account-trade-form'),(492057,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(492058,'furniture-mobile','.p-blog-index .nav-next','width','50','','','.p-blog-index'),(492059,'furniture-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(492060,'furniture-mobile','.w-top-categories .item','width','50','2876','','.w-top-categories'),(492061,'furniture-mobile','.w-personal-gift-status-bar .progress-bar','width','230','','','.w-personal-gift-status-bar'),(492062,'furniture-mobile','.w-sale .left-text-left','width','24','','','.w-sale'),(492063,'furniture-mobile','.w-sale .badge','width','80','','','.w-sale'),(492064,'furniture-mobile','.w-sale .left-text-right','width','24','','','.w-sale'),(492065,'furniture-mobile','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(492066,'furniture-mobile','.w-compare-box-item .checkbox','width','22','','','.w-compare-box-item'),(492067,'furniture-mobile','.w-compare-box-item .checkbox + span','width','24','','','.w-compare-box-item'),(492069,'furniture-mobile','.p-blog-index .nav-previous','width','100','2906','','.p-blog-index'),(492070,'furniture-mobile','.w-checkout-billing-address .addresses.address-main .address-item','width','100','','','.w-checkout-billing-address'),(492071,'furniture-mobile','.w-checkout-bonus-points .bonus_points_amount','width','150','','','.w-checkout-bonus-points'),(492072,'furniture-mobile','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width','150','','','.w-coupons-and-vauchers-checkout'),(492073,'furniture-mobile','.w-checkout-shipping-address .addresses.address-main .address-item','width','100','','','.w-checkout-shipping-address'),(492074,'furniture-mobile','.w-checkout-shipping-choice #shippingchoice-choice','width','430','','','.w-checkout-shipping-choice'),(492075,'furniture-mobile','.w-product-images-additional .item-div','width','80','2906','','.w-product-images-additional'),(492076,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','100','2906','','.p-blog-index'),(492077,'furniture-mobile','.w-product-images-additional .item','width','80','2906','','.w-product-images-additional'),(492078,'furniture-mobile','.w-product-images-additional .additional-images','width','80','2906','','.w-product-images-additional'),(492079,'furniture-mobile','.w-cart-order-total.box','width','100','2876','','.w-cart-order-total'),(492080,'furniture-mobile','.p-blog-index .nav-next','width','100','2906','','.p-blog-index'),(492081,'furniture-mobile','.w-product-wishlist-button .btn','width','100','2876','','.w-product-wishlist-button'),(492082,'furniture-mobile','.w-promo-code .promo-code-form','width','100','2885','','.w-promo-code'),(492083,'furniture-mobile','.w-cart-checkout-btn ','width','100','2876','','.w-cart-checkout-btn'),(492084,'furniture-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','2885','','.w-promo-code'),(492085,'furniture-mobile','.w-cart-continue-btn a','width','100','2876','','.w-cart-continue-btn'),(492086,'furniture-mobile','.w-promo-code .promo-text','width','100','2885','','.w-promo-code'),(492087,'furniture-mobile','.w-cart-order-total.box','width','100','2876','','.w-cart-order-total'),(492088,'furniture-mobile','.p-blog-index .nav-previous','width','100','2906','','.p-blog-index'),(492089,'furniture-mobile','.w-product-images-additional .item-div','width','80','2906','','.w-product-images-additional'),(492090,'furniture-mobile','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(492091,'furniture-mobile','.p-reviews-info .review-info-image','width','24','','','.p-reviews-info'),(492092,'furniture-mobile','.w-wedding-registry-widgets-products .products-listing .item','width','100','2906','','.w-wedding-registry-widgets-products'),(492093,'furniture-mobile','.p-blog-index .post-thumbnail','width','200','','','.p-blog-index'),(492094,'furniture-mobile','.p-account-trade-form .wl-td label','width','40','','','.p-account-trade-form'),(492095,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width','49','','','.p-account-trade-form'),(492096,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width','48','','','.p-account-trade-form'),(492097,'furniture-mobile','.b-select-suggest .select2-search-choice-close','width','12','','','.b-select-suggest'),(492098,'furniture-mobile','.w-menu-slider .menu-ico','width','54','','','.w-menu-slider'),(492099,'furniture-mobile','.b-select-suggest .select2-search input','width','100','','','.b-select-suggest'),(492100,'furniture-mobile','.b-select-suggest .select2-search','width','100','','','.b-select-suggest'),(492101,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow','width','18','','','.b-select-suggest'),(492102,'furniture-mobile','.b-select-suggest .select2-drop-auto-width','width','auto','','','.b-select-suggest'),(492103,'furniture-mobile','.b-select-suggest .select2-drop','width','100','','','.b-select-suggest'),(492104,'furniture-mobile','.b-select-suggest .select2-drop-mask','width','auto','','','.b-select-suggest'),(492105,'furniture-mobile','.w-sale .badge','width','80','','','.w-sale'),(492106,'furniture-mobile','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(492107,'furniture-mobile','.w-menu-style-1 li','width','auto','','','.w-menu-style-1'),(492108,'furniture-mobile','.w-menu-style-1 .menu-ico','width','54','','','.w-menu-style-1'),(492109,'furniture-mobile','.w-socials .post_item_img','width','100','','','.w-socials'),(492110,'furniture-mobile','.w-tabs .tab-navigation','width','100','','','.w-tabs'),(492111,'furniture-mobile','.w-menu .hided.menu ul ul','width','auto','','','.w-menu'),(492112,'furniture-mobile','.w-login-block .returning','width','50','','','.w-login-block'),(492113,'furniture-mobile','.w-menu .hided.menu ul li','width','auto','','','.w-menu'),(492114,'furniture-mobile','.p-reviews-info .review-info-image','width','24','','','.p-reviews-info'),(492115,'furniture-mobile','.w-categories .item','width','100','2906','','.w-categories'),(492116,'furniture-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(492117,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width','20','3','','.b-switch'),(492118,'furniture-mobile','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(492119,'furniture-mobile','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(492120,'furniture-mobile','.w-socials .post_item_img','width','100','','','.w-socials'),(492121,'furniture-mobile','.p-reviews-info .review-info-image','width','24','','','.p-reviews-info'),(492122,'furniture-mobile','.w-account .acc-new','width','49','','','.w-account'),(492123,'furniture-mobile','.w-login-block .guest','width','50','','','.w-login-block'),(492124,'furniture-mobile','.w-login-block .returning','width','50','','','.w-login-block'),(492125,'furniture-mobile','.w-menu-style-1 .menu-ico','width','54','','','.w-menu-style-1'),(492126,'furniture-mobile','.w-menu-big li','width','auto','','','.w-menu-big'),(492127,'furniture-mobile','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(492128,'furniture-mobile','.w-cart-listing .links','width','19','','','.w-cart-listing'),(492129,'furniture-mobile','.w-sale .image','width','50','','','.w-sale'),(492130,'furniture-mobile','.w-sale .left-count','width','23','','','.w-sale'),(492131,'furniture-mobile','.w-cart-order-total.box','width','100','2876','','.w-cart-order-total'),(492132,'furniture-mobile','.w-account-addresses-list .addsess-suggestion-item','width','50','','','.w-account-addresses-list'),(492133,'furniture-mobile','.w-account-customer-additional-field .field-type-checkbox label','width','40','','','.w-account-customer-additional-field'),(492134,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','width','100','','','.b-products-listing'),(492135,'furniture-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width','80','','','.b-products-listing'),(492136,'furniture-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width','60','','','.b-products-listing'),(492137,'furniture-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width','40','','','.b-products-listing'),(492138,'furniture-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width','20','','','.b-products-listing'),(492139,'furniture-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width','40','','','.b-products-listing'),(492140,'furniture-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width','20','','','.b-products-listing'),(492141,'furniture-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width','60','','','.b-products-listing'),(492142,'furniture-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width','60','','','.b-products-listing'),(492143,'furniture-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width','20','','','.b-products-listing'),(492144,'furniture-mobile','.b-products-listing .BlockBox.type-14 > .col','width','25','','','.b-products-listing'),(492145,'furniture-mobile','.b-products-listing .BlockBox.type-15 > .col','width','20','','','.b-products-listing'),(492146,'furniture-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width','50','','','.b-products-listing'),(492147,'furniture-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(492148,'furniture-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(492149,'furniture-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width','33.33','','','.b-products-listing'),(492150,'furniture-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width','50','','','.b-products-listing'),(492151,'furniture-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(492152,'furniture-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width','66.66','','','.b-products-listing'),(492153,'furniture-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width','66.66','','','.b-products-listing'),(492154,'furniture-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(492155,'furniture-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width','25','','','.b-products-listing'),(492156,'furniture-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width','25','','','.b-products-listing'),(492157,'furniture-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width','75','','','.b-products-listing'),(492158,'furniture-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width','75','','','.b-products-listing'),(492159,'furniture-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width','25','','','.b-products-listing'),(492160,'furniture-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width','50','','','.b-products-listing'),(492161,'furniture-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width','25','','','.b-products-listing'),(492162,'furniture-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width','20','','','.b-products-listing'),(492163,'furniture-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width','80','','','.b-products-listing'),(492164,'furniture-mobile','.b-products-listing .btn-preloader','width','24','3','','.b-products-listing'),(492165,'furniture-mobile','.b-products-listing .hover-box-content','width','20','3','','.b-products-listing'),(492166,'furniture-mobile','.b-products-listing .loader','width','30','4','','.b-products-listing'),(492167,'furniture-mobile','.b-products-listing .loader','width','100','3','','.b-products-listing'),(492168,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block > span','width','100','','','.b-products-listing'),(492169,'furniture-mobile','.b-products-listing .products-listing .attributes select','width','100','','','.b-products-listing'),(492170,'furniture-mobile','.b-products-listing .products-listing .btn-buy','width','100','','','.b-products-listing'),(492171,'furniture-mobile','.w-catalog-b2b-add-button ','width','100','','','.w-catalog-b2b-add-button'),(492172,'furniture-mobile','.b-products-listing .products-listing .item','width','25','','','.b-products-listing'),(492173,'furniture-mobile','.b-products-listing .products-listing .qty-input.hidden','width','100','3','','.b-products-listing'),(492174,'furniture-mobile','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','width','auto','','','.b-products-listing'),(492175,'furniture-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width','100','','','.b-products-listing'),(492176,'furniture-mobile','.checkbox input:not(checked) + span:before','width','22','','',''),(492177,'furniture-mobile','.w-blog-widget-related-posts button.slick-prev, .w-blog-widget-related-posts button.slick-next','width','35','','','.w-blog-widget-related-posts'),(492178,'furniture-mobile','.w-blog-widget-related-posts .post','width','50','','','.w-blog-widget-related-posts'),(492179,'furniture-mobile','.w-blog-widget-post-title ','width','100','2876','','.w-blog-widget-post-title'),(492180,'furniture-mobile','.w-blog-widget-post-share ','width','1','4','','.w-blog-widget-post-share'),(492181,'furniture-mobile','.w-blog-widget-post-listing .post','width','100','2906','','.w-blog-widget-post-listing'),(492182,'furniture-mobile','.w-blog-widget-post-listing .post','width','50','2885','','.w-blog-widget-post-listing'),(492183,'furniture-mobile','.w-blog-widget-post-listing .post','width','33.33','','','.w-blog-widget-post-listing'),(492184,'furniture-mobile','.w-blog-widget-post-image ','width','100','2876','','.w-blog-widget-post-image'),(492185,'furniture-mobile','.w-blog-widget-post-date ','width','100','2876','','.w-blog-widget-post-date'),(492186,'furniture-mobile','.checkbox input + span','width','24','','',''),(492187,'furniture-mobile','.p-account-trade-form .wl-td select','width','55','','','.p-account-trade-form'),(492188,'furniture-mobile','.w-currencies .select','width','100','','','.w-currencies'),(492189,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width','100','','','.b-select-suggest'),(492190,'furniture-mobile','.w-sale .left-count','width','23','','','.w-sale'),(492191,'furniture-mobile','.b-products-listing .products-listing .in-cart','width','100','','','.b-products-listing'),(492192,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-toggle','width','10','','','.b-switch'),(492193,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','width','10','','','.b-switch'),(492194,'furniture-mobile','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','width','25','3','','.w-checkout-contact-information'),(492195,'furniture-mobile','.b-form .radio-button input[type=\"radio\"].no + span','width','30','3','','.b-form'),(492196,'furniture-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width','100','','','.b-fancybox'),(492197,'furniture-mobile','.b-email .heading-image','width','100','','','.b-email'),(492198,'furniture-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(492199,'furniture-mobile','.w-product-images-additional .additional-images','width','80','2906','','.w-product-images-additional'),(492200,'furniture-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','2885','','.w-promo-code'),(492201,'furniture-mobile','.p-account-trade-form .wl-td label','width','40','','','.p-account-trade-form'),(492202,'furniture-mobile','.p-account-trade-form .wl-td select','width','55','','','.p-account-trade-form'),(492203,'furniture-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width','55','','','.p-account-trade-form'),(492204,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','50','2885','','.p-blog-index'),(492205,'furniture-mobile','.w-socials .post_item_img','width','100','','','.w-socials'),(492206,'furniture-mobile','.w-sale .image','width','50','','','.w-sale'),(492207,'furniture-mobile','.w-sale .holder-1','width','25','','','.w-sale'),(492208,'furniture-mobile','.w-sale .left-count','width','23','','','.w-sale'),(492209,'furniture-mobile','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(492210,'furniture-mobile','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(492211,'furniture-mobile','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(492212,'furniture-mobile','.w-cart-credit-amount .btn-remove','width','25','','','.w-cart-credit-amount'),(492213,'furniture-mobile','.w-coupons-and-vauchers-checkout .btn-remove','width','25','','','.w-coupons-and-vauchers-checkout'),(492214,'furniture-mobile','.p-wedding-registry-search .search-list input','width','100','','','.p-wedding-registry-search'),(492215,'furniture-mobile','.w-compare-box-item .checkbox + span','width','24','','','.w-compare-box-item'),(492216,'furniture-mobile','.order-summary .price-row.ot_coupon .title','width','32','3','','.order-summary'),(492217,'furniture-mobile','.p-blog-index .nav-previous','width','50','','','.p-blog-index'),(492218,'furniture-mobile','.p-account-trade-form .wl-td label','width','40','','','.p-account-trade-form'),(492219,'furniture-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterSku\"]','width','60','','','.w-communication-new-topic'),(492220,'furniture-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterOrderId\"]','width','60','','','.w-communication-new-topic'),(492221,'furniture-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterName\"]','width','100','','','.w-communication-new-topic'),(492222,'furniture-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateFrom\"]','width','60','','','.w-communication-new-topic'),(492223,'furniture-mobile','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateTo\"]','width','60','','','.w-communication-new-topic'),(492224,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','width','36','','','.w-communication-new-topic'),(492225,'furniture-mobile','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','width','36','','','.w-communication-new-topic'),(492226,'furniture-mobile','.w-communication-new-topic .middle-form select','width','100','','','.w-communication-new-topic'),(492227,'furniture-mobile','.w-login-block .input','width','100','','','.w-login-block'),(492229,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item','width','50','','','.w-checkout-shipping-address'),(492230,'furniture-mobile','.b-form .checkbox-style:not(checked) + .checkbox-span','width','15','','','.b-form'),(492231,'furniture-mobile','.w-checkout-shipping-choice #shippingchoice-choice','width','auto','2906','','.w-checkout-shipping-choice'),(492232,'furniture-mobile','.b-email img','width','60','','','.b-email'),(492233,'furniture-mobile','.w-cart-continue-btn a','width','100','2876','','.w-cart-continue-btn'),(492234,'furniture-mobile','.b-bottom .popup-credit-amount .popup-box','width','100','','','.b-bottom'),(492235,'furniture-mobile','.w-product-images-additional .item','width','80','2906','','.w-product-images-additional'),(492236,'furniture-mobile','.w-promo-code .promo-code-form','width','100','2885','','.w-promo-code'),(492237,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','50','2885','','.p-blog-index'),(492238,'furniture-mobile','.w-sale .holder-2','width','25','','','.w-sale'),(492239,'furniture-mobile','.w-sale .holder-1','width','25','','','.w-sale'),(492240,'furniture-mobile','.b-email .products-table','width','100','','','.b-email'),(492241,'furniture-mobile','.b-email .totals-title','width','70','','','.b-email'),(492242,'furniture-mobile','.w-menu-slider .menu-ico','width','54','','','.w-menu-slider'),(492243,'furniture-mobile','.w-login-block .new','width','50','','','.w-login-block'),(492244,'furniture-mobile','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(492245,'furniture-mobile','.b-email-editor img','width','auto','','','.b-email-editor'),(492246,'furniture-mobile','.b-email .heading-image','width','100','','','.b-email'),(492247,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','50','2885','','.p-blog-index'),(492248,'furniture-mobile','.w-sale .left-text-right','width','24','','','.w-sale'),(492249,'furniture-mobile','.w-sale .left-text-left','width','24','','','.w-sale'),(492250,'furniture-mobile','.w-sale .badge','width','80','','','.w-sale'),(492251,'furniture-mobile','.w-sale .left-count','width','23','','','.w-sale'),(492252,'furniture-mobile','.w-sale .image','width','50','','','.w-sale'),(492253,'furniture-mobile','.w-sale .holder-1','width','25','','','.w-sale'),(492254,'furniture-mobile','.w-sale .holder-2','width','25','','','.w-sale'),(492255,'furniture-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(492256,'furniture-mobile','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(492257,'furniture-mobile','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(492258,'furniture-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(492259,'furniture-mobile','.b-compare .col-two label','width','20','','','.b-compare'),(492260,'furniture-mobile','.p-blog-index .nav-next','width','100','2906','','.p-blog-index'),(492261,'furniture-mobile','.w-cart-order-total.box','width','100','2876','','.w-cart-order-total'),(492262,'furniture-mobile','.w-promo-code .promo-text','width','100','2885','','.w-promo-code'),(492263,'furniture-mobile','.w-menu-horizontal .menu-ico','width','54','','','.w-menu-horizontal'),(492264,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(492265,'furniture-mobile','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(492266,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','50','2885','','.p-blog-index'),(492267,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width','35','','','.w-catalog-paging'),(492268,'furniture-mobile','.w-catalog-listing-look .grid','width','35','','','.w-catalog-listing-look'),(492269,'furniture-mobile','.w-catalog-listing-look .b2b','width','35','','','.w-catalog-listing-look'),(492270,'furniture-mobile','.w-catalog-listing-look .list','width','35','','','.w-catalog-listing-look'),(492273,'furniture-mobile','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','width','130','','','.w-cart-listing'),(492274,'furniture-mobile','.w-cart-listing .remove-btn','width','30','','','.w-cart-listing'),(492275,'furniture-mobile','.w-cart-listing .right-area','width','35','','','.w-cart-listing'),(492276,'furniture-mobile','.w-cart-listing .item .image','width','80','2885','','.w-cart-listing'),(492277,'furniture-mobile','.w-cart-listing .item .remove','width','100','2885','','.w-cart-listing'),(492278,'furniture-mobile','.w-cart-give-away .ga_img','width','30','','','.w-cart-give-away'),(492279,'furniture-mobile','.w-cart-give-away .ga_column','width','100','2876','','.w-cart-give-away'),(492280,'furniture-mobile','.w-cart-discount-coupon input[type=\"text\"]','width','100','','','.w-cart-discount-coupon'),(492281,'furniture-mobile','.w-cart-discount-coupon .btn-remove','width','25','','','.w-cart-discount-coupon'),(492282,'furniture-mobile','.w-cart .cart-box.hover-box .cart-content','width','410','','','.w-cart'),(492283,'furniture-mobile','.w-brands .brands-listing > div','width','16','','','.w-brands'),(492284,'furniture-mobile','.b-upload-file .snapshot','width','38','','','.b-upload-file'),(492285,'furniture-mobile','.b-fancybox .fancybox-nav span','width','40','','','.b-fancybox'),(492286,'furniture-mobile','.b-fancybox .fancybox-nav','width','40','','','.b-fancybox'),(492287,'furniture-mobile','.b-email .totals-table','width','100','','','.b-email'),(492288,'furniture-mobile','.w-product-images-additional .item','width','80','2906','','.w-product-images-additional'),(492289,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','100','2906','','.p-blog-index'),(492290,'furniture-mobile','.b-upload-file .upload-file-template','width','150','','','.b-upload-file'),(492291,'furniture-mobile','.w-menu-slider .menu-ico','width','54','','','.w-menu-slider'),(492292,'furniture-mobile','.w-sale .image','width','50','','','.w-sale'),(492293,'furniture-mobile','.w-menu-style-1 .menu-ico','width','54','','','.w-menu-style-1'),(492294,'furniture-mobile','.w-menu-slider > ul > li > ul','width','100','','','.w-menu-slider'),(492295,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(492296,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(492297,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(492298,'furniture-mobile','.w-catalog-paging .paging-holder','width','150','','','.w-catalog-paging'),(492299,'furniture-mobile','.w-wedding-registry-widgets-products .products-listing .item','width','50','2876','','.w-wedding-registry-widgets-products'),(492300,'furniture-mobile','.p-blog-index .nav-previous','width','50','','','.p-blog-index'),(492301,'furniture-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width','55','','','.p-account-trade-form'),(492302,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width','48','','','.p-account-trade-form'),(492303,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(492304,'furniture-mobile','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(492305,'furniture-mobile','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(492306,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-sm','width','45','','','.b-switch'),(492307,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','width','40','','','.b-switch'),(492308,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(492309,'furniture-mobile','.p-blog-index .post-thumbnail','width','200','','','.p-blog-index'),(492310,'furniture-mobile','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(492311,'furniture-mobile','.w-compare-box-item .checkbox','width','22','','','.w-compare-box-item'),(492312,'furniture-mobile','.w-compare-box-item .checkbox + span','width','24','','','.w-compare-box-item'),(492313,'furniture-mobile','.w-menu .hided.menu ul ul','width','auto','','','.w-menu'),(492314,'furniture-mobile','.w-login-block .new','width','50','','','.w-login-block'),(492315,'furniture-mobile','.w-filters .handle-to','width','50','','','.w-filters'),(492316,'furniture-mobile','.w-filters .handle-from','width','50','','','.w-filters'),(492317,'furniture-mobile','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','2885','','.w-promo-code'),(492318,'furniture-mobile','.p-account-trade-form .wl-td label','width','40','','','.p-account-trade-form'),(492319,'furniture-mobile','.order-summary .price-row.ot_bonus_points .title','width','32','3','','.order-summary'),(492320,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','width','22','','','.w-compare-box-item'),(492321,'furniture-mobile','.w-filters .input-checkbox','width','0','','','.w-filters'),(492322,'furniture-mobile','.b-bottom .pop-up-close','width','31','','','.b-bottom'),(492323,'furniture-mobile','.w-product-images-additional .item-div','width','80','2906','','.w-product-images-additional'),(492324,'furniture-mobile','.w-promo-code .promo-text','width','100','2885','','.w-promo-code'),(492325,'furniture-mobile','.w-product-images-additional .additional-images','width','80','2906','','.w-product-images-additional'),(492326,'furniture-mobile','.w-product-images-additional .item-div','width','80','2906','','.w-product-images-additional'),(492327,'furniture-mobile','.p-blog-index .nav-next','width','100','2906','','.p-blog-index'),(492328,'furniture-mobile','.w-cart-order-total.box','width','100','2876','','.w-cart-order-total'),(492329,'furniture-mobile','.b-compare .col-two select','width','80','','','.b-compare'),(492330,'furniture-mobile','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(492332,'furniture-mobile','.w-product-wishlist-button .btn','width','100','2876','','.w-product-wishlist-button'),(492333,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(492334,'furniture-mobile','.w-login-block .new','width','50','','','.w-login-block'),(492335,'furniture-mobile','.w-login-block .input','width','100','','','.w-login-block'),(492336,'furniture-mobile','.w-login-block .guest','width','50','','','.w-login-block'),(492337,'furniture-mobile','.b-products-listing .products-listing .btn-preloader','width','100','','','.b-products-listing'),(492338,'furniture-mobile','.w-communication-new-topic .btn-submit','width','200','','','.w-communication-new-topic'),(492339,'furniture-mobile','.p-reviews-info .review-info-image','width','24','','','.p-reviews-info'),(492340,'furniture-mobile','.w-compare-box-item .checkbox:not(checked) + span:before','width','22','','','.w-compare-box-item'),(492341,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(492342,'furniture-mobile','.w-menu .hided.menu ul li','width','auto','','','.w-menu'),(492343,'furniture-mobile','.w-cart-credit-amount input[type=\"text\"]','width','150','','','.w-cart-credit-amount'),(492344,'furniture-mobile','.w-menu .hided.menu ul ul','width','auto','','','.w-menu'),(492345,'furniture-mobile','.p-reviews-info .review-info-image','width','24','','','.p-reviews-info'),(492346,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg','width','120','','','.b-switch'),(492347,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','width','40','','','.b-switch'),(492348,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','width','40','','','.b-switch'),(492349,'furniture-mobile','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(492351,'furniture-mobile','.b-email .products-table','width','100','','','.b-email'),(492352,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','50','2885','','.p-blog-index'),(492353,'furniture-mobile','.b-email .totals-value','width','30','','','.b-email'),(492354,'furniture-mobile','.b-email .totals-title','width','70','','','.b-email'),(492355,'furniture-mobile','.b-email .totals-table','width','100','','','.b-email'),(492356,'furniture-mobile','.p-blog-index .nav-previous','width','50','','','.p-blog-index'),(492357,'furniture-mobile','.p-blog-index .nav-next','width','50','','','.p-blog-index'),(492358,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width','100','2906','','.p-blog-index'),(492359,'furniture-mobile','.w-filters .mobileCollapse','width','17','','','.w-filters'),(492360,'furniture-mobile','.w-filters .input-txt-keywords','width','100','','','.w-filters'),(492361,'furniture-mobile','.w-filters .input-txt','width','60','','','.w-filters'),(492362,'furniture-mobile','.p-account-trade-form .wl-td label','width','40','','','.p-account-trade-form'),(492363,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','width','250','','','.w-image-maps'),(492364,'furniture-mobile','.w-filters .input-checkbox:not(checked) + .checkbox-span','width','24','','','.w-filters'),(492365,'furniture-mobile','.w-brands .brands-listing > div','width','16','','','.w-brands'),(492366,'furniture-mobile','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','width','auto','','','.b-product-images'),(492367,'furniture-mobile','.b-product-images .media-popup .mp-close','width','100','','','.b-product-images'),(492368,'furniture-mobile','.b-product-images .media-popup .mp-small-images .item','width','150','','','.b-product-images'),(492369,'furniture-mobile','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','width','100','','','.b-product-images'),(492370,'furniture-mobile','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','width','30','','','.b-menu-burger_icon'),(492371,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width','100','','','.b-menu-lev_display-slide'),(492372,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width','100','','','.b-menu-lev_display-slide'),(492373,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width','100','','','.b-menu-lev_display-slide'),(492374,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width','100','','','.b-menu-lev_display-slide'),(492375,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width','100','','','.b-menu-lev_display-slide'),(492376,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(492377,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(492378,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(492379,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(492380,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(492381,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width','100','','','.b-menu-open_from-left'),(492382,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(492383,'furniture-mobile','.b-menu-style-1 .menu-style[data-lev2_display=\"width\"] .level-2 > li','width','300','','','.b-menu-style-1'),(492384,'furniture-mobile','.b-menu-style-1 .menu-style[data-lev2_display=\"width_cont\"] .level-2 > li','width','300','','','.b-menu-style-1'),(492385,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','width','40','','','.b-menu-style-2'),(492386,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','width','50','','','.b-menu-style-2'),(492387,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','width','36','','','.b-menu-style-2'),(492388,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','width','40','','','.b-menu-style-2'),(492389,'furniture-mobile','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','width','36','','','.b-menu-style-2'),(492390,'furniture-mobile','.b-trade-approval .steps-bar','width','100','','','.b-trade-approval'),(492391,'furniture-mobile','.b-trade-approval .col-right','width','48','','','.b-trade-approval'),(492392,'furniture-mobile','.b-trade-approval .col-left','width','48','','','.b-trade-approval'),(492393,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width','100','','','.b-trade-approval'),(492394,'furniture-mobile','.b-trade-approval .col-3','width','31.33','','','.b-trade-approval'),(492395,'furniture-mobile','.batchPr .w-batch-products .products-listing .attribute-qty-block','width','100','','','.batchPr'),(492396,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(2)','width','auto','','','.batchPr'),(492397,'furniture-mobile','.batchPr .checkbox input + span','width','80','','','.batchPr'),(492398,'furniture-mobile','.batchPr .batchSelect .checkbox','width','80','','','.batchPr'),(492399,'furniture-mobile','.batchPr .box-block.type-5 > .block:nth-child(1), .batchPr .box-block.type-5 > .block:nth-child(2)','width','50','','','.batchPr'),(492400,'furniture-mobile','.batchPr .checkbox input + span','width','32','','','.batchPr'),(492401,'furniture-mobile','.batchPr .w-batch-selected-products .products-listing .BlockBox.type-5 > .col:nth-child(1)','width','40','','','.batchPr'),(492402,'furniture-mobile','.batchPr .checkbox input:not(checked) + span:before','width','30','','','.batchPr'),(492403,'furniture-mobile','.batchPr .btn-batch-remove','width','20','','','.batchPr'),(492404,'furniture-mobile','.w-account-personal-catalog .list-switcher','width','100','','','.w-account-personal-catalog'),(492405,'furniture-mobile','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','width','auto','','','.w-catalog-compare'),(492406,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','width','50','','','.w-catalog-compare'),(492407,'furniture-mobile','.w-product-images .additional-vertical .produst-image','width','calc(100% - 100px)','','','.w-product-images'),(492408,'furniture-mobile','.w-product-images .additional-vertical .additional-images','width','100','','','.w-product-images'),(492409,'furniture-mobile','.w-cart .cart-box-link','width','48','3','','.w-cart'),(492410,'furniture-mobile','.w-cart .cart-box-link','width','10','4','','.w-cart'),(492411,'furniture-mobile','.w-account .my-acc-link','width','10','4','','.w-account'),(492412,'furniture-mobile','.w-account .my-acc-link','width','48','3','','.w-account'),(492413,'furniture-mobile','.w-account .account-dropdown','width','50','3','','.w-account'),(492414,'furniture-mobile','.w-account .col-left, .w-account .col-right','width','100','','','.w-account'),(492415,'furniture-mobile','.tripleBanner .w-html_box','width','80','3','','.tripleBanner'),(492416,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .BlockBox.type-2 > .col:nth-child(1)','width','100','','','.b-products-listing'),(492417,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .BlockBox.type-2 > .col:nth-child(2)','width','100','','','.b-products-listing'),(492418,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','width','40','','','.b-slick'),(492419,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','width','45','2885','','.b-slick'),(492420,'furniture-mobile','.w-account .my-acc-link','width','40','2885,3','','.w-account'),(492421,'furniture-mobile','.w-cart .cart-box-link','width','40','2885,3','','.w-cart'),(492422,'furniture-mobile','.w-search ','width','calc(100% - 950px)','','','.w-search'),(492423,'furniture-mobile','.w-search ','width','calc(100% - 750px)','2890','','.w-search'),(492424,'furniture-mobile','.w-search .search-ico','width','40','2885,3','','.w-search'),(492425,'furniture-mobile','.w-search ','width','auto','2885','','.w-search'),(492426,'furniture-mobile','.menu-header .burger-icon','width','40','2885','','.menu-header'),(492427,'furniture-mobile','.w-search .suggest-js','width','100','2885','','.w-search'),(492428,'furniture-mobile','.tripleBanner > .block','width','100','2885','','.tripleBanner'),(492429,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li','width','100','2890','','.b-menu-style-3'),(492430,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li','width','100','','','.b-menu-style-3'),(492431,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li:nth-child(1) > ul > li, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li:nth-child(2) > ul > li','width','50','','','.b-menu-style-3'),(492432,'furniture-mobile','.b-products-listing .item-nav > div','width','33.333','','','.b-products-listing'),(492433,'furniture-mobile','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','width','13','','','.w-filters'),(492434,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-content','width','100','4','','.b-products-listing'),(492435,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','width','100','','','.b-products-listing'),(492436,'furniture-mobile','.w-quote .cart-box-link','width','48','3','','.w-quote'),(492437,'furniture-mobile','.w-quote .image','width','70','','','.w-quote'),(492438,'furniture-mobile','.w-quote .cart-box-link','width','40','2885,3','','.w-quote'),(492439,'furniture-mobile','.b-quantity .qty-box .bigger','width','35','','','.b-quantity'),(492440,'furniture-mobile','.b-quantity .qty-box .smaller','width','35','','','.b-quantity'),(492441,'furniture-mobile','.b-quantity .qty-box input','width','60','','','.b-quantity'),(492442,'furniture-mobile','.b-quantity .qty-input input','width','40','','','.b-quantity'),(492443,'furniture-mobile','.w-product-sale-ends .left-count','width','23','','','.w-product-sale-ends'),(492444,'furniture-mobile','.w-product-sale-ends .left-text-left','width','24','','','.w-product-sale-ends'),(492445,'furniture-mobile','.w-product-sale-ends .left-text-right','width','24','','','.w-product-sale-ends'),(492446,'furniture-mobile','h1, .heading-1','width','100','3','',''),(492447,'furniture-mobile','h1, .heading-1','width','100','4','',''),(492448,'furniture-mobile','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(492449,'furniture-mobile','.w-product-quantity .qty-box .smaller, .w-product-quantity .qty-box .bigger','width','46','','','.w-product-quantity'),(492450,'furniture-mobile','.w-product-quantity .qty-input input[type=\'text\']','width','77','','','.w-product-quantity'),(492451,'furniture-mobile','.w-product-bonus-points > div > div','width','100','','','.w-product-bonus-points'),(492452,'furniture-mobile','.warrantyProduct .warranty','width','35','3','','.warrantyProduct'),(492453,'furniture-mobile','.warrantyProduct .delivery','width','37','3','','.warrantyProduct'),(492454,'furniture-mobile','.w-compare .image','width','70','','','.w-compare'),(492455,'furniture-mobile','.w-files-catalog-widgets-files-catalog .item','width','18','','','.w-files-catalog-widgets-files-catalog'),(492456,'furniture-mobile','.w-files-catalog-widgets-files-catalog .item','width','23','2890','','.w-files-catalog-widgets-files-catalog'),(492457,'furniture-mobile','.w-files-catalog-widgets-files-catalog .item','width','31','2885','','.w-files-catalog-widgets-files-catalog'),(492458,'furniture-mobile','.w-files-catalog-widgets-files-catalog .item','width','48','2876','','.w-files-catalog-widgets-files-catalog'),(492459,'furniture-mobile','.w-sample .cart-box-link','width','10','4','','.w-sample'),(492460,'furniture-mobile','.w-sample .cart-box-link','width','48','3','','.w-sample'),(492461,'furniture-mobile','.w-sample .image','width','70','','','.w-sample'),(492462,'furniture-mobile','.w-sample .cart-box-link','width','40','2885,3','','.w-sample'),(492463,'furniture-mobile','.w-quote .cart-box.hover-box .cart-content','width','410','','','.w-quote'),(492464,'furniture-mobile','.w-sample .cart-box .cart-content','width','410','','','.w-sample'),(492465,'furniture-mobile','.w-cart-listing .points-earn','width','80','','','.w-cart-listing'),(492466,'furniture-mobile','.w-cart-listing .points-earn','width','0','4','','.w-cart-listing'),(492467,'furniture-mobile','.w-cart-sub-total .price-row','width','100','','','.w-cart-sub-total'),(492468,'furniture-mobile','.w-cart-sub-total .price-row > div','width','50','','','.w-cart-sub-total'),(492469,'furniture-mobile','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(492470,'furniture-mobile','.w-cart-gift-certificate .input-apple','width','100','','','.w-cart-gift-certificate'),(492471,'furniture-mobile','.w-cart-gift-certificate .input-apple div','width','100','','','.w-cart-gift-certificate'),(492472,'furniture-mobile','.w-cart-order-reference .input-apple','width','100','','','.w-cart-order-reference'),(492473,'furniture-mobile','.w-cart-order-reference .input-apple div','width','100','','','.w-cart-order-reference'),(492474,'furniture-mobile','.w-cart-order-reference .input-apple div input','width','100','','','.w-cart-order-reference'),(492475,'furniture-mobile','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(492476,'furniture-mobile','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(492477,'furniture-mobile','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(492478,'furniture-mobile','.w-product-bundle .bundle_item','width','30','','','.w-product-bundle'),(492479,'furniture-mobile','.w-product-bundle .bundle_item','width','48','2885','','.w-product-bundle'),(492480,'furniture-mobile','.w-product-bundle .bundle_item','width','100','2876','','.w-product-bundle'),(492481,'furniture-mobile','.w-product-in-bundles .attributes-item','width','48','','','.w-product-in-bundles'),(492482,'furniture-mobile','.w-product-in-bundles .attributes-select','width','100','','','.w-product-in-bundles'),(492483,'furniture-mobile','.w-product-in-bundles .bundle_item','width','48','2885','','.w-product-in-bundles'),(492484,'furniture-mobile','.w-product-in-bundles .bundle_item','width','100','2876','','.w-product-in-bundles'),(492485,'furniture-mobile','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(492486,'furniture-mobile','.w-product-in-bundles .bundle_item','width','30','','','.w-product-in-bundles'),(492487,'furniture-mobile','.w-product-quantity-discounts .count','width','80','','','.w-product-quantity-discounts'),(492488,'furniture-mobile','.w-catalog-additional-images img','width','auto','','','.w-catalog-additional-images'),(492489,'furniture-mobile','.w-catalog-additional-images picture','width','150','','','.w-catalog-additional-images'),(492490,'furniture-mobile','.heading-2','width','100','3','',''),(492491,'furniture-mobile','.heading-2','width','100','4','',''),(492492,'furniture-mobile','.w-product-quantity-discounts .item','width','48','','','.w-product-quantity-discounts'),(492493,'furniture-mobile','.w-product-quantity-discounts .item','width','100','2885','','.w-product-quantity-discounts'),(492494,'furniture-mobile','.w-product-multi-inventory .select-box:nth-child(2n)','width','48','','','.w-product-multi-inventory'),(492495,'furniture-mobile','.w-product-multi-inventory .select-box:nth-child(2n+1)','width','48','','','.w-product-multi-inventory'),(492496,'furniture-mobile','.p-quote-checkout-index .datepicker-inline','width','280','','','.p-quote-checkout-index'),(492497,'furniture-mobile','.p-sample-checkout-index .datepicker-inline','width','280','','','.p-sample-checkout-index'),(492498,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','width','100','3','','.p-quote-checkout-index'),(492499,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','width','100','4','','.p-quote-checkout-index'),(492500,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','width','100','3','','.p-sample-checkout-index'),(492501,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','width','100','4','','.p-sample-checkout-index'),(492502,'furniture-mobile','.w-account-order-download table','width','100','','','.w-account-order-download'),(492503,'furniture-mobile','.w-product-multi-inventory .radio-attributes > label','width','33.3333','','','.w-product-multi-inventory'),(492504,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','width','100','','','.w-product-multi-inventory'),(492505,'furniture-mobile','.w-product-multi-inventory .radio-attributes > label','width','50','2890','','.w-product-multi-inventory'),(492506,'furniture-mobile','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','width','100','','','.w-account-personal-catalog'),(492507,'furniture-mobile','.w-account-personal-catalog .w-cart-listing .item .image','width','110','2876','','.w-account-personal-catalog'),(492508,'furniture-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width','65','2890','','.b-products-listing'),(492509,'furniture-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width','35','2890','','.b-products-listing'),(492510,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','width','100','','','.b-products-listing'),(492511,'furniture-mobile','.b-products-listing .products-listing .radio-attributes > label','width','50','','','.b-products-listing'),(492512,'furniture-mobile','.w-product-collection .chosen-products','width','48','','','.w-product-collection'),(492513,'furniture-mobile','.w-product-collection .current-product','width','25','','','.w-product-collection'),(492514,'furniture-mobile','.w-product-collection .right-area','width','25','','','.w-product-collection'),(492515,'furniture-mobile','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(492516,'furniture-mobile','.w-account-customer-additional-field .field-type-text label, .w-account-customer-additional-field .field-type-file label','width','40','','','.w-account-customer-additional-field'),(492517,'furniture-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select, .w-account-customer-additional-field .files','width','60','','','.w-account-customer-additional-field'),(492518,'furniture-mobile','.w-product-collection .current-product, .w-product-collection .chosen-products','width','100','2885','','.w-product-collection'),(492519,'furniture-mobile','.w-product-collection .right-area','width','100','2885','','.w-product-collection'),(492520,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','width','100','','','.w-product-attributes'),(492521,'furniture-mobile','.w-product-attributes .radio-attributes > label','width','33.3333','','','.w-product-attributes'),(492522,'furniture-mobile','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(492523,'furniture-mobile','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(492524,'furniture-mobile','.w-product-attributes .radio-attributes > label','width','50','2890','','.w-product-attributes'),(492525,'furniture-mobile','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(492526,'furniture-mobile','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(492527,'furniture-mobile','.w-product-properties li','width','50','','','.w-product-properties'),(492528,'furniture-mobile','.w-questionnaire-widgets-questionnaire .answer-yes-no span','width','40','','','.w-questionnaire-widgets-questionnaire'),(492529,'furniture-mobile','.w-product-groups .radioBox label','width','50','','','.w-product-groups'),(492530,'furniture-mobile','.w-product-groups .radioBox label','width','100','2906','','.w-product-groups'),(492531,'furniture-mobile','.b-products-listing .mix-attributes .mult-qty-input .qty-box > span','width','35','','','.b-products-listing'),(492532,'furniture-mobile','.b-products-listing .mix-attributes .mult-qty-input .qty-box > input','width','60','','','.b-products-listing'),(492533,'furniture-mobile','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(492534,'furniture-mobile','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(492535,'furniture-mobile','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(492536,'furniture-mobile','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(492537,'furniture-mobile','.w-product-custom-bundle .chosen-products','width','100','2885','','.w-product-custom-bundle'),(492538,'furniture-mobile','.w-product-custom-bundle .right-area','width','100','2885','','.w-product-custom-bundle'),(492539,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width','25','','','.w-catalog-pages-category-pages-last-list'),(492540,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width','33.33','2885','','.w-catalog-pages-category-pages-last-list'),(492541,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width','50','2876','','.w-catalog-pages-category-pages-last-list'),(492542,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width','25','','','.w-catalog-pages-category-pages-last-list-block'),(492543,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','width','48','','','.w-delivery-location-top-location-list'),(492544,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(492545,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width','33.33','2885','','.w-catalog-pages-category-pages-last-list-block'),(492546,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width','50','2876','','.w-catalog-pages-category-pages-last-list-block'),(492547,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','width','31.333','2885','','.w-delivery-location-location-list'),(492548,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','width','48','2876','','.w-delivery-location-location-list'),(492549,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','width','100','2876','','.w-delivery-location-top-location-list'),(492550,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li','width','48','','','.w-delivery-location-featured-list'),(492551,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li','width','100','2906','','.w-delivery-location-featured-list'),(492552,'furniture-mobile','.w-wedding-registry-widgets-search-form .col-3','width','48','2885','','.w-wedding-registry-widgets-search-form'),(492553,'furniture-mobile','.w-wedding-registry-widgets-search-form .col-3:nth-child(3)','width','100','2885','','.w-wedding-registry-widgets-search-form'),(492554,'furniture-mobile','.w-wedding-registry-widgets-search-form .col-3','width','100','2906','','.w-wedding-registry-widgets-search-form'),(492555,'furniture-mobile','.w-sale-category .badge','width','80','','','.w-sale-category'),(492556,'furniture-mobile','.w-sale-category .holder-1','width','25','','','.w-sale-category'),(492557,'furniture-mobile','.w-sale-category .holder-2','width','25','','','.w-sale-category'),(492558,'furniture-mobile','.w-sale-category .image','width','50','','','.w-sale-category'),(492559,'furniture-mobile','.w-sale-category .left-count','width','23','','','.w-sale-category'),(492560,'furniture-mobile','.w-sale-category .left-text-left','width','24','','','.w-sale-category'),(492561,'furniture-mobile','.w-sale-category .left-text-right','width','24','','','.w-sale-category'),(492562,'furniture-mobile','.w-product-wedding-registry-button .btn','width','18','3','','.w-product-wedding-registry-button'),(492563,'furniture-mobile','.w-product-wedding-registry-button .btn','width','18','4','','.w-product-wedding-registry-button'),(492564,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width','25','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(492565,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width','50','2876','','.w-catalog-pages-category-pages-last-list-by-catalog'),(492566,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width','25','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(492567,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width','50','2876','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(492568,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width','33.33','2885','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(492569,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width','33.33','2885','','.w-catalog-pages-category-pages-last-list-by-catalog'),(492570,'furniture-mobile','.w-delivery-location-list-by-page .item','width','31.333','','','.w-delivery-location-list-by-page'),(492571,'furniture-mobile','.w-delivery-location-list-by-page .item','width','48','2885','','.w-delivery-location-list-by-page'),(492572,'furniture-mobile','.w-delivery-location-list-by-page .item','width','100','2906','','.w-delivery-location-list-by-page'),(492573,'furniture-mobile','.w-product-properties-icons .hover-box-content','width','100','','','.w-product-properties-icons'),(492574,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','width','200','','','.w-product-properties-icons'),(492575,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','width','100','2906','','.w-product-properties-icons'),(492576,'furniture-mobile','.w-delivery-location-cross-pages .item','width','31.333','','','.w-delivery-location-cross-pages'),(492577,'furniture-mobile','.w-delivery-location-cross-pages .item','width','48','2885','','.w-delivery-location-cross-pages'),(492578,'furniture-mobile','.w-delivery-location-cross-pages .item','width','100','2906','','.w-delivery-location-cross-pages'),(492579,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','width','25','','','.w-delivery-location-product-categories'),(492580,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','width','33.3333','2885','','.w-delivery-location-product-categories'),(492581,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','width','100','2906','','.w-delivery-location-product-categories'),(492582,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','width','50','2876','','.w-delivery-location-product-categories'),(492583,'furniture-mobile','.w-catalog-delivery-locations .item','width','48','','','.w-catalog-delivery-locations'),(492584,'furniture-mobile','.w-catalog-delivery-locations .item','width','100','2876','','.w-catalog-delivery-locations'),(492585,'furniture-mobile','.delivery-options-popup .datepicker-inline','width','220','','',''),(492586,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','width','156','2890','','.w-wedding-registry-widgets-photos'),(492587,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-container','width','120','2890','','.w-wedding-registry-widgets-photos'),(492588,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','width','100','','','.w-product-bonus-points'),(492589,'furniture-mobile','.w-product-designer-designer .productDesignerBox input','width','100','','','.w-product-designer-designer'),(492590,'furniture-mobile','.w-product-designer-designer .prodDesignerType label','width','82','','','.w-product-designer-designer'),(492591,'furniture-mobile','.w-product-designer-designer .prodDesignerType','width','100','','','.w-product-designer-designer'),(492592,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','width','30','','','.w-press-reviews-widgets-press-reviews-small'),(492593,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small .small-press-review','width','70','','','.w-press-reviews-widgets-press-reviews-small'),(492594,'furniture-mobile','.w-press-reviews-widgets-press-reviews .sub-box','width','300','','','.w-press-reviews-widgets-press-reviews'),(492595,'furniture-mobile','.w-gift-wrap-message-checkout .text','width','calc(100$ - 100px)','','','.w-gift-wrap-message-checkout'),(492596,'furniture-mobile','.w-support-system-listing .product_icon','width','40','','','.w-support-system-listing'),(492597,'furniture-mobile','.w-rma-returns-history .content-messages .messages-table .bottom select','width','auto','','','.w-rma-returns-history'),(492598,'furniture-mobile','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','width','35','','','.w-rma-returns-history'),(492599,'furniture-mobile','.w-rma-returns-history input[type=\'text\'], .w-rma-returns-history input[type=\'password\'], .w-rma-returns-history input[type=\'number\'], .w-rma-returns-history input[type=\'email\'], .w-rma-returns-history input[type=\'search\'], .w-rma-returns-history select','width','100','','','.w-rma-returns-history'),(492600,'furniture-mobile','.w-rma-returns-history thead tr td:first-child','width','300','','','.w-rma-returns-history'),(492601,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','width','100','','','.b-menu-style-1'),(492602,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(492603,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(492604,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(492605,'furniture-mobile','.w-banner .image-text-banner.bottom-center .text-banner','width','100','','','.w-banner'),(492606,'furniture-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner','width','100','','','.w-banner'),(492607,'furniture-mobile','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(492608,'furniture-mobile','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(492609,'furniture-mobile','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(492610,'furniture-mobile','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(492611,'furniture-mobile','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(492612,'furniture-mobile','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(492613,'furniture-mobile','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(492614,'furniture-mobile','.w-product-configurator .item-content','width','100','2885','','.w-product-configurator'),(492615,'furniture-mobile','.w-product-configurator .pc_item','width','100','2885','','.w-product-configurator'),(492616,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','width','100','','','.b-products-listing'),(492617,'furniture-mobile','.b-products-listing .promo-icon','width','60','','','.b-products-listing'),(492618,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width','25','','','.w-catalog-pages-category-pages-list'),(492619,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width','33.33','2885','','.w-catalog-pages-category-pages-list'),(492620,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width','50','2876','','.w-catalog-pages-category-pages-list'),(492621,'furniture-mobile','.w-predefined-promotion .icon','width','45','','','.w-predefined-promotion'),(492622,'furniture-mobile','.w-predefined-promotion .nextdiscount .item-holder .image','width','40','','','.w-predefined-promotion'),(492623,'furniture-mobile','.w-predefined-promotion .nextdiscount .item-holder .name','width','60','','','.w-predefined-promotion'),(492624,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .image img','width','auto','','','.w-predefined-promotion'),(492625,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .list','width','100','','','.w-predefined-promotion'),(492626,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .image img','width','auto','','','.w-predefined-promotion'),(492627,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .master .item','width','calc(50% - 24px)','','','.w-predefined-promotion'),(492628,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .item','width','calc(50% - 4px)','','','.w-predefined-promotion'),(492629,'furniture-mobile','.w-predefined-promotion .promo-cart-discount > div','width','50','','','.w-predefined-promotion'),(492630,'furniture-mobile','.w-predefined-promotion .promo-salemaker .image img','width','auto','','','.w-predefined-promotion'),(492631,'furniture-mobile','.w-predefined-promotion .promo-salemaker .item','width','50','','','.w-predefined-promotion'),(492632,'furniture-mobile','.w-predefined-promotion .promo-salemaker > div','width','50','','','.w-predefined-promotion'),(492633,'furniture-mobile','.w-filters .fsl_handle > div','width','50','','','.w-filters'),(492634,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','width','0','','','.w-filters'),(492635,'furniture-mobile','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','width','24','','','.w-filters'),(492636,'furniture-mobile','.mainBanner .bottomBox .elf','width','100','','','.mainBanner'),(492637,'furniture-mobile','.mainBanner .title','width','4.5','3','','.mainBanner'),(492638,'furniture-mobile','.mainBanner .title','width','100','','','.mainBanner'),(492639,'furniture-mobile','.mainBanner .topBox > .right','width','30','3','','.mainBanner'),(492640,'furniture-mobile','.mainBanner .w-banner .image-text-banner.middle-right .text-banner-1','width','100','','','.mainBanner'),(492641,'furniture-mobile','.mainBanner .title','width','7.5','2876,3','','.mainBanner'),(492642,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner.middle-right .text-banner-1','width','100','','','.lowestPricedBox'),(492643,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','width','100','','','.lowestPricedBox'),(492644,'furniture-mobile','.lowestPricedBox .w-banner .ybg','width','20','3','','.lowestPricedBox'),(492645,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','width','100','','','.lowestPricedBox'),(492646,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner:nth-child(1) .ybg:before','width','15','2890','','.lowestPricedBox'),(492647,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner:nth-child(2) .ybg:before','width','15','2890','','.lowestPricedBox'),(492648,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','width','33.333','','','.shopByCollectionBox'),(492649,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','width','calc(50% - 20px)','2885','','.shopByCollectionBox'),(492650,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','width','100','2906','','.shopByCollectionBox'),(492651,'furniture-mobile','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','width','40','','','.mainBanner'),(492652,'furniture-mobile','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','width','40','','','.mainBanner'),(492653,'furniture-mobile','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','width','40','','','.mainBanner'),(492654,'furniture-mobile','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','width','65','2876','','.mainBanner'),(492655,'furniture-mobile','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','width','65','2876','','.mainBanner'),(492656,'furniture-mobile','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','width','65','2876','','.mainBanner'),(492657,'furniture-mobile','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','width','80','2906','','.mainBanner'),(492658,'furniture-mobile','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','width','80','2906','','.mainBanner'),(492659,'furniture-mobile','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','width','80','2906','','.mainBanner'),(492660,'furniture-mobile','.w-cart-shipping-estimator .left-area','width','100','2876','','.w-cart-shipping-estimator'),(492661,'furniture-mobile','.w-cart-shipping-estimator .right-area','width','100','2876','','.w-cart-shipping-estimator'),(492662,'furniture-mobile','.w-search .products','width','100','','','.w-search'),(492663,'furniture-mobile','.w-search .name','width','calc(100% - 40px)','','','.w-search'),(492664,'furniture-mobile','.w-search .wrap','width','100','','','.w-search'),(492665,'furniture-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','width','48','','','.account-address-book'),(492666,'furniture-mobile','.account-address-book .address_book_row .column','width','100','2876','','.account-address-book'),(492667,'furniture-mobile','.account-address-book .address_book_row .column + .column','width','100','2876','','.account-address-book'),(492668,'furniture-mobile','.account-address-book .topInfo > div','width','100','2876','','.account-address-book'),(492669,'furniture-mobile','.account-address-book .topInfo > div + div','width','100','2876','','.account-address-book'),(492670,'furniture-mobile','.account-order-history .not_fully_paid_td','width','300','','','.account-order-history'),(492671,'furniture-mobile','.account-order-history .orders-table .hidden','width','130','2885','','.account-order-history'),(492672,'furniture-mobile','.account-order-history .orders-table .td-alignright','width','100','2885','','.account-order-history'),(492673,'furniture-mobile','.account-order-history-info .history_info > div','width','33.3','','','.account-order-history-info'),(492674,'furniture-mobile','.account-order-history-info .not_fully_paid_td','width','300','','','.account-order-history-info'),(492675,'furniture-mobile','.account-order-history-info .history_info > div','width','100','2885','','.account-order-history-info'),(492676,'furniture-mobile','.account-index .account_info li','width','30.33','','','.account-index'),(492677,'furniture-mobile','.account-index .ai_title','width','40','','','.account-index'),(492678,'furniture-mobile','.account-index .not_fully_paid_td','width','300','','','.account-index'),(492679,'furniture-mobile','.account-index .remove-btn','width','30','','','.account-index'),(492680,'furniture-mobile','.account-index .topAccount > li','width','20','','','.account-index'),(492681,'furniture-mobile','.account-index .topInfo > div','width','48','','','.account-index'),(492682,'furniture-mobile','.account-index .orders-table .hidden','width','130','2885','','.account-index'),(492683,'furniture-mobile','.account-index .orders-table .links','width','100','2885','','.account-index'),(492684,'furniture-mobile','.account-index .account_info li','width','100','2876','','.account-index'),(492685,'furniture-mobile','.account-index .topAccount > li','width','100','2876','','.account-index'),(492686,'furniture-mobile','.account-order-pay .history_info > div','width','33.3','','','.account-order-pay'),(492687,'furniture-mobile','.account-order-pay .not_fully_paid_td','width','300','','','.account-order-pay'),(492688,'furniture-mobile','.account-order-pay .history_info > div','width','100','2885','','.account-order-pay'),(492689,'furniture-mobile','.account-samples .not_fully_paid_td','width','300','','','.account-samples'),(492690,'furniture-mobile','.account-samples .orders-table .hidden','width','130','2885','','.account-samples'),(492691,'furniture-mobile','.account-samples .orders-table .td-alignright','width','100','2885','','.account-samples'),(492692,'furniture-mobile','.account-sample-info .history_info > div','width','33.3','','','.account-sample-info'),(492693,'furniture-mobile','.account-sample-info .not_fully_paid_td','width','300','','','.account-sample-info'),(492694,'furniture-mobile','.account-sample-info .history_info > div','width','100','2885','','.account-sample-info'),(492695,'furniture-mobile','.catalog-product-wrap .pn-image','width','24','3','','.catalog-product-wrap'),(492696,'furniture-mobile','.catalog-product-wrap .prev-next-product','width','190','','','.catalog-product-wrap'),(492697,'furniture-mobile','.catalog-product-wrap .next-product','width','60','2885','','.catalog-product-wrap'),(492698,'furniture-mobile','.catalog-product-wrap .prev-product','width','60','2885','','.catalog-product-wrap'),(492699,'furniture-mobile','.checkout-index-wrap .datepicker-inline','width','280','','','.checkout-index-wrap'),(492700,'furniture-mobile','.checkout-index-wrap .dob-hide > div','width','48','','','.checkout-index-wrap'),(492701,'furniture-mobile','.checkout-index-wrap .edit-address-popup','width','1000','','','.checkout-index-wrap'),(492702,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .address-item','width','33','','','.checkout-index-wrap'),(492703,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons','width','100','','','.checkout-index-wrap'),(492704,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','width','100','3','','.checkout-index-wrap'),(492705,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','width','100','4','','.checkout-index-wrap'),(492706,'furniture-mobile','.checkout-index-wrap .order-summary2 .btn-2','width','100','','','.checkout-index-wrap'),(492707,'furniture-mobile','.checkout-order-confirmation .order-summary2 .btn-2','width','100','','','.checkout-order-confirmation'),(492708,'furniture-mobile','.checkout-login-wrap .col-left, .checkout-login-wrap .col-right','width','100','','','.checkout-login-wrap'),(492709,'furniture-mobile','.checkout-login-wrap .middle-form .btn-2','width','100','','','.checkout-login-wrap'),(492710,'furniture-mobile','.b-warehouses-popup .warehouses-popup','width_important','important','','','.b-warehouses-popup'),(492711,'furniture-mobile','.w-menu .hided.menu ul li','width_important','important','','','.w-menu'),(492712,'furniture-mobile','.w-menu .hided.menu ul li','width_important','important','','','.w-menu'),(492713,'furniture-mobile','.b-messages .pre_upload','width_important','important','','','.b-messages'),(492714,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width_important','important','3','','.b-switch'),(492715,'furniture-mobile','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width_important','important','','','.w-catalog-paging'),(492716,'furniture-mobile','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width_important','important','3','','.b-switch'),(492717,'furniture-mobile','.w-menu .hided.menu ul ul','width_important','important','','','.w-menu'),(492718,'furniture-mobile','.w-menu .hided.menu ul ul','width_important','important','','','.w-menu'),(492719,'furniture-mobile','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width_important','important','','','.b-select-suggest'),(492720,'furniture-mobile','.w-checkout-credit-amount .cot_gv_amount','width_important','important','','','.w-checkout-credit-amount'),(492721,'furniture-mobile','.w-menu .hided.menu ul ul','width_important','important','','','.w-menu'),(492722,'furniture-mobile','.w-menu .hided.menu ul li','width_important','important','','','.w-menu'),(492723,'furniture-mobile','.w-checkout-bonus-points .bonus_points_amount','width_important','important','','','.w-checkout-bonus-points'),(492724,'furniture-mobile','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width_important','important','','','.w-coupons-and-vauchers-checkout'),(492725,'furniture-mobile','.w-menu .hided.menu ul ul','width_important','important','','','.w-menu'),(492726,'furniture-mobile','.w-menu .hided.menu ul li','width_important','important','','','.w-menu'),(492727,'furniture-mobile','.w-menu .hided.menu ul ul','width_important','important','','','.w-menu'),(492728,'furniture-mobile','.w-menu .hided.menu ul li','width_important','important','','','.w-menu'),(492729,'furniture-mobile','.w-cart-discount-coupon input[type=\"text\"]','width_important','important','','','.w-cart-discount-coupon'),(492730,'furniture-mobile','.w-cart-credit-amount input[type=\"text\"]','width_important','important','','','.w-cart-credit-amount'),(492731,'furniture-mobile','.w-menu .hided.menu ul li','width_important','important','','','.w-menu'),(492732,'furniture-mobile','.w-menu .hided.menu ul ul','width_important','important','','','.w-menu'),(492733,'furniture-mobile','.menu-header .burger-icon','width_important','important','2885','','.menu-header'),(492734,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_important','important','','','.b-menu-open_from-left'),(492735,'furniture-mobile','.tripleBanner > .block','width_important','important','2885','','.tripleBanner'),(492736,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li','width_important','important','2890','','.b-menu-style-3'),(492737,'furniture-mobile','.w-cart-bonus-points .bonus_points_amount','width_important','important','','','.w-cart-bonus-points'),(492738,'furniture-mobile','.w-rma-returns-history thead tr td:first-child','width_important','important','','','.w-rma-returns-history'),(492739,'furniture-mobile','.checkout-index-wrap .edit-address-popup','width_important','important','','','.checkout-index-wrap'),(492740,'furniture-mobile','.b-form .col-right','width_measure','%','2885','','.b-form'),(492741,'furniture-mobile','.b-form .login-col-2','width_measure','%','','','.b-form'),(492742,'furniture-mobile','.p-account-trade-form .wl-td label','width_measure','%','','','.p-account-trade-form'),(492743,'furniture-mobile','.order-summary .btn-2, .order-summary .btn-3','width_measure','%','','','.order-summary'),(492744,'furniture-mobile','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(492745,'furniture-mobile','.w-promotions .promo-salemaker > div','width_measure','%','','','.w-promotions'),(492746,'furniture-mobile','.w-promotions .promo-cart-discount > div','width_measure','%','','','.w-promotions'),(492747,'furniture-mobile','.w-search .search-input','width_measure','%','','','.w-search'),(492748,'furniture-mobile','.w-account input','width_measure','%','','','.w-account'),(492749,'furniture-mobile','.p-reviews-info .review-info-image','width_measure','%','','','.p-reviews-info'),(492750,'furniture-mobile','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width_measure','%','','','.p-sample-checkout-login'),(492751,'furniture-mobile','.p-blog-index .nav-previous','width_measure','%','','','.p-blog-index'),(492752,'furniture-mobile','.p-blog-index .nav-next','width_measure','%','','','.p-blog-index'),(492753,'furniture-mobile','.w-promotions .prom-multi-discount .list','width_measure','%','','','.w-promotions'),(492754,'furniture-mobile','.w-promotions .nextdiscount .item-holder .name','width_measure','%','','','.w-promotions'),(492755,'furniture-mobile','.w-promotions .nextdiscount .item-holder .image','width_measure','%','','','.w-promotions'),(492756,'furniture-mobile','.w-promotions .promo-salemaker .item','width_measure','%','','','.w-promotions'),(492757,'furniture-mobile','.b-preloader .preloader','width_measure','%','','','.b-preloader'),(492758,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block','width_measure','%','','','.b-products-listing'),(492759,'furniture-mobile','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(492760,'furniture-mobile','.w-cart-continue-btn a','width_measure','%','2876','','.w-cart-continue-btn'),(492761,'furniture-mobile','.w-cart-checkout-btn ','width_measure','%','2876','','.w-cart-checkout-btn'),(492762,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(492763,'furniture-mobile','.w-wedding-registry-widgets-products .products-listing .item','width_measure','%','2906','','.w-wedding-registry-widgets-products'),(492764,'furniture-mobile','.p-reviews-info .review-info-image','width_measure','%','','','.p-reviews-info'),(492765,'furniture-mobile','.p-account-trade-form .wl-td select','width_measure','%','','','.p-account-trade-form'),(492766,'furniture-mobile','.p-blog-index .nav-next','width_measure','%','','','.p-blog-index'),(492767,'furniture-mobile','.b-messages .box-block.type-6 > .block:nth-child(1)','width_measure','%','','','.b-messages'),(492768,'furniture-mobile','.b-messages .messages-sidebar .btn-2','width_measure','%','','','.b-messages'),(492769,'furniture-mobile','.b-messages .email-line input','width_measure','%','','','.b-messages'),(492770,'furniture-mobile','.w-sitemap-delivery-location > ul > li > ul > li','width_measure','%','','','.w-sitemap-delivery-location'),(492771,'furniture-mobile','.w-sale .left-text-left','width_measure','%','','','.w-sale'),(492772,'furniture-mobile','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(492773,'furniture-mobile','.p-account-trade-form .wl-td label','width_measure','%','','','.p-account-trade-form'),(492774,'furniture-mobile','.w-menu-slider > ul > li > ul','width_measure','%','','','.w-menu-slider'),(492775,'furniture-mobile','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(492776,'furniture-mobile','.p-payer-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-confirmation'),(492777,'furniture-mobile','.p-payer-order-confirmation .dob-hide > div','width_measure','%','','','.p-payer-order-confirmation'),(492778,'furniture-mobile','.p-payer-order-pay .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-pay'),(492779,'furniture-mobile','.p-payer-order-pay .dob-hide > div','width_measure','%','','','.p-payer-order-pay'),(492780,'furniture-mobile','.w-checkout-terms .required-message','width_measure','%','','','.w-checkout-terms'),(492781,'furniture-mobile','.p-account-trade-form .wl-td select','width_measure','%','','','.p-account-trade-form'),(492782,'furniture-mobile','.b-form .checkbox-style:checked + .checkbox-span','width_measure','x','','','.b-form'),(492783,'furniture-mobile','.p-account-trade-form .wl-td label','width_measure','%','','','.p-account-trade-form'),(492784,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(492785,'furniture-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width_measure','%','','','.p-account-trade-form'),(492786,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(492787,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(492788,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(492789,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(492790,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(492791,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .dz-details','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(492792,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(492793,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(492794,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(492795,'furniture-mobile','.w-login-block .input','width_measure','%','','','.w-login-block'),(492796,'furniture-mobile','.w-login-block .guest','width_measure','%','','','.w-login-block'),(492797,'furniture-mobile','.w-login-block .new','width_measure','%','','','.w-login-block'),(492798,'furniture-mobile','.w-login-block .returning','width_measure','%','','','.w-login-block'),(492799,'furniture-mobile','.w-menu-slider > ul > li > ul','width_measure','%','','','.w-menu-slider'),(492800,'furniture-mobile','.w-product-wishlist-button .btn','width_measure','%','2876','','.w-product-wishlist-button'),(492801,'furniture-mobile','.p-blog-index .nav-previous','width_measure','%','2906','','.p-blog-index'),(492802,'furniture-mobile','.w-cart-order-total.box','width_measure','%','2876','','.w-cart-order-total'),(492803,'furniture-mobile','.w-sale .left-text-right','width_measure','%','','','.w-sale'),(492804,'furniture-mobile','.w-cart-give-away .ga_attributes select','width_measure','%','','','.w-cart-give-away'),(492805,'furniture-mobile','.w-categories .item','width_measure','%','2876','','.w-categories'),(492806,'furniture-mobile','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(492807,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(492808,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(492809,'furniture-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(492810,'furniture-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(492811,'furniture-mobile','.w-login-block .input','width_measure','%','','','.w-login-block'),(492812,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(492813,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(492814,'furniture-mobile','.p-account-trade-form .wl-td select','width_measure','%','','','.p-account-trade-form'),(492815,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(492816,'furniture-mobile','.p-blog-index .nav-previous','width_measure','%','2906','','.p-blog-index'),(492817,'furniture-mobile','.w-cart-order-total.box','width_measure','%','2876','','.w-cart-order-total'),(492818,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(492819,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(492820,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(492821,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(492822,'furniture-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width_measure','%','','','.p-account-trade-form'),(492823,'furniture-mobile','.p-blog-index .nav-next','width_measure','%','','','.p-blog-index'),(492824,'furniture-mobile','.p-blog-index .nav-previous','width_measure','%','','','.p-blog-index'),(492825,'furniture-mobile','.p-reviews-info .review-info-image','width_measure','%','','','.p-reviews-info'),(492826,'furniture-mobile','.pop-up-content .buttons .btn','width_measure','%','2885','',''),(492827,'furniture-mobile','.pop-up-content .buttons .right-buttons','width_measure','%','2885','',''),(492828,'furniture-mobile','.pop-up-content .buttons .btn-2','width_measure','%','2885','',''),(492829,'furniture-mobile','.pop-up-content .buttons .left-buttons','width_measure','%','2885','',''),(492830,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(492831,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(492832,'furniture-mobile','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(492833,'furniture-mobile','.w-login-block .input','width_measure','%','','','.w-login-block'),(492834,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(492835,'furniture-mobile','.w-filters .ui-slider','width_measure','%','','','.w-filters'),(492836,'furniture-mobile','.w-cart-give-away .ga_column','width_measure','%','','','.w-cart-give-away'),(492837,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','2906','','.p-blog-index'),(492838,'furniture-mobile','.p-blog-index .nav-previous','width_measure','%','2906','','.p-blog-index'),(492839,'furniture-mobile','.w-product-wishlist-button .btn','width_measure','%','2876','','.w-product-wishlist-button'),(492840,'furniture-mobile','.w-sale .image','width_measure','%','','','.w-sale'),(492841,'furniture-mobile','.w-search .suggest','width_measure','%','','','.w-search'),(492842,'furniture-mobile','.w-promo-code .promo-text','width_measure','%','2885','','.w-promo-code'),(492843,'furniture-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width_measure','%','','','.p-account-trade-form'),(492844,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(492845,'furniture-mobile','.w-tabs .tab-navigation','width_measure','%','','','.w-tabs'),(492846,'furniture-mobile','.w-wedding-registry-widgets-products .products-listing .item','width_measure','%','2876','','.w-wedding-registry-widgets-products'),(492847,'furniture-mobile','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width_measure','%','','','.p-quote-checkout-login'),(492848,'furniture-mobile','.b-products-listing .select-attributes select','width_measure','%','','','.b-products-listing'),(492849,'furniture-mobile','.w-cart-listing .right-area','width_measure','%','2885','','.w-cart-listing'),(492850,'furniture-mobile','.p-quick-order-index .all-scroll-div','width_measure','%','','','.p-quick-order-index'),(492851,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','2906','','.p-blog-index'),(492852,'furniture-mobile','.w-sale .holder-1','width_measure','%','','','.w-sale'),(492853,'furniture-mobile','.w-sale .image','width_measure','%','','','.w-sale'),(492854,'furniture-mobile','.w-cart-order-total.box','width_measure','%','2876','','.w-cart-order-total'),(492855,'furniture-mobile','.view-all','width_measure','%','3','',''),(492856,'furniture-mobile','.b-form .columns .col-2','width_measure','%','','','.b-form'),(492857,'furniture-mobile','.w-wedding-registry-widgets-share-url input','width_measure','%','','','.w-wedding-registry-widgets-share-url'),(492858,'furniture-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(492859,'furniture-mobile','.w-sale .left-count','width_measure','%','','','.w-sale'),(492860,'furniture-mobile','.w-cart-checkout-btn a','width_measure','%','2876','','.w-cart-checkout-btn'),(492861,'furniture-mobile','.w-cart-order-total.box','width_measure','%','2876','','.w-cart-order-total'),(492862,'furniture-mobile','.w-top-categories .item','width_measure','%','','','.w-top-categories'),(492863,'furniture-mobile','.w-account-address-book .item','width_measure','%','','','.w-account-address-book'),(492864,'furniture-mobile','.b-bottom .popup-box.popupCompare','width_measure','%','','','.b-bottom'),(492865,'furniture-mobile','.w-cart-order-total.box','width_measure','%','2876','','.w-cart-order-total'),(492866,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','2906','','.p-blog-index'),(492867,'furniture-mobile','.w-promo-code .promo-text','width_measure','%','2885','','.w-promo-code'),(492868,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','2885','','.p-blog-index'),(492869,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(492870,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(492871,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(492872,'furniture-mobile','.w-sale .holder-1','width_measure','%','','','.w-sale'),(492873,'furniture-mobile','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(492874,'furniture-mobile','.p-reviews-info .review-info-image','width_measure','%','','','.p-reviews-info'),(492875,'furniture-mobile','.w-menu-slider > ul > li > ul','width_measure','%','','','.w-menu-slider'),(492876,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','2885','','.p-blog-index'),(492877,'furniture-mobile','.b-form .login-col-1','width_measure','%','','','.b-form'),(492878,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(492879,'furniture-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(492880,'furniture-mobile','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(492881,'furniture-mobile','.w-list-b2b .select-attributes','width_measure','%','','','.w-list-b2b'),(492882,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','2885','','.p-blog-index'),(492883,'furniture-mobile','.w-sale .holder-2','width_measure','%','','','.w-sale'),(492884,'furniture-mobile','.w-sale .left-count','width_measure','%','','','.w-sale'),(492885,'furniture-mobile','.w-sale .image','width_measure','%','','','.w-sale'),(492886,'furniture-mobile','.w-sale .holder-1','width_measure','%','','','.w-sale'),(492887,'furniture-mobile','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(492888,'furniture-mobile','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(492889,'furniture-mobile','.w-checkout-shipping-choice label','width_measure','%','','','.w-checkout-shipping-choice'),(492890,'furniture-mobile','.b-products-listing .btn-choose-options','width_measure','%','','','.b-products-listing'),(492891,'furniture-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(492892,'furniture-mobile','.w-checkout-create-account .col-2','width_measure','%','2885','','.w-checkout-create-account'),(492893,'furniture-mobile','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(492894,'furniture-mobile','.w-sale .holder-2','width_measure','%','','','.w-sale'),(492895,'furniture-mobile','.w-sale .image','width_measure','%','','','.w-sale'),(492896,'furniture-mobile','.w-sale .holder-1','width_measure','%','','','.w-sale'),(492897,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(492898,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','2906','','.p-blog-index'),(492899,'furniture-mobile','.p-blog-index .nav-next','width_measure','%','2906','','.p-blog-index'),(492900,'furniture-mobile','.w-product-wishlist-button .btn','width_measure','%','2876','','.w-product-wishlist-button'),(492901,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(492902,'furniture-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(492903,'furniture-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(492904,'furniture-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(492905,'furniture-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(492906,'furniture-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(492907,'furniture-mobile','.p-reviews-info .review-info-image','width_measure','%','','','.p-reviews-info'),(492908,'furniture-mobile','.w-cart-continue-btn a','width_measure','%','2876','','.w-cart-continue-btn'),(492909,'furniture-mobile','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(492910,'furniture-mobile','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(492911,'furniture-mobile','.w-promo-code .promo-code-form','width_measure','%','2885','','.w-promo-code'),(492912,'furniture-mobile','.w-promo-code .promo-text','width_measure','%','2885','','.w-promo-code'),(492913,'furniture-mobile','.b-form .columns .col-2','width_measure','%','2906','','.b-form'),(492914,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(492915,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(492916,'furniture-mobile','.w-banner .carousel-text','width_measure','%','','','.w-banner'),(492917,'furniture-mobile','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width_measure','%','','','.w-banner'),(492918,'furniture-mobile','.w-sale .left-count','width_measure','%','','','.w-sale'),(492919,'furniture-mobile','.w-login-block .input','width_measure','%','','','.w-login-block'),(492920,'furniture-mobile','.w-sale .left-text-right','width_measure','%','','','.w-sale'),(492921,'furniture-mobile','.w-sale .left-text-left','width_measure','%','','','.w-sale'),(492922,'furniture-mobile','.w-login-block .returning','width_measure','%','','','.w-login-block'),(492923,'furniture-mobile','.w-login-block .new','width_measure','%','','','.w-login-block'),(492924,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(492925,'furniture-mobile','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(492926,'furniture-mobile','.w-login-block .guest','width_measure','%','','','.w-login-block'),(492927,'furniture-mobile','.b-form .col-left','width_measure','%','','','.b-form'),(492928,'furniture-mobile','.w-cart-give-away .ga_attributes > div','width_measure','%','','','.w-cart-give-away'),(492929,'furniture-mobile','.w-image-maps .svg-wrap svg','width_measure','%','','','.w-image-maps'),(492930,'furniture-mobile','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width_measure','%','','','.b-form'),(492931,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(492932,'furniture-mobile','.w-cart-listing .links','width_measure','%','','','.w-cart-listing'),(492933,'furniture-mobile','.w-login-block .returning','width_measure','%','','','.w-login-block'),(492934,'furniture-mobile','.w-menu-slider > ul > li > ul','width_measure','%','','','.w-menu-slider'),(492935,'furniture-mobile','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(492936,'furniture-mobile','.w-login-block .guest','width_measure','%','','','.w-login-block'),(492937,'furniture-mobile','.w-login-block .new','width_measure','%','','','.w-login-block'),(492938,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(492939,'furniture-mobile','.w-cart-shipping-estimator .left-area','width_measure','%','','','.w-cart-shipping-estimator'),(492940,'furniture-mobile','.b-form .col-right','width_measure','%','','','.b-form'),(492941,'furniture-mobile','.p-blog-index .nav-next','width_measure','%','2906','','.p-blog-index'),(492942,'furniture-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(492943,'furniture-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(492944,'furniture-mobile','.b-bottom .cart-options .option-item','width_measure','%','','','.b-bottom'),(492945,'furniture-mobile','.p-blog-index .nav-next','width_measure','%','2906','','.p-blog-index'),(492946,'furniture-mobile','.w-sale .left-text-left','width_measure','%','','','.w-sale'),(492947,'furniture-mobile','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(492948,'furniture-mobile','.w-sale .holder-2','width_measure','%','','','.w-sale'),(492949,'furniture-mobile','.b-bottom .cart-options .cart-item','width_measure','%','','','.b-bottom'),(492950,'furniture-mobile','.w-login-block .guest','width_measure','%','','','.w-login-block'),(492951,'furniture-mobile','.p-reviews-info .review-info-image','width_measure','%','','','.p-reviews-info'),(492952,'furniture-mobile','.w-sale .left-text-left','width_measure','%','','','.w-sale'),(492953,'furniture-mobile','.p-blog-index .nav-previous','width_measure','%','2906','','.p-blog-index'),(492954,'furniture-mobile','.p-blog-index .nav-next','width_measure','%','2906','','.p-blog-index'),(492955,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(492956,'furniture-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(492957,'furniture-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(492958,'furniture-mobile','.w-promo-code .promo-text','width_measure','%','2885','','.w-promo-code'),(492959,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(492960,'furniture-mobile','.w-login-block .returning','width_measure','%','','','.w-login-block'),(492961,'furniture-mobile','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(492962,'furniture-mobile','.w-sale .image','width_measure','%','','','.w-sale'),(492963,'furniture-mobile','.w-sale .left-text-right','width_measure','%','','','.w-sale'),(492964,'furniture-mobile','.w-cart-continue-btn a','width_measure','%','2876','','.w-cart-continue-btn'),(492965,'furniture-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(492966,'furniture-mobile','.b-form .col-left','width_measure','%','2885','','.b-form'),(492967,'furniture-mobile','.b-form .middle-form .dob-input input[type=\"text\"]','width_measure','%','','','.b-form'),(492968,'furniture-mobile','.p-account-trade-form .wl-td select','width_measure','%','','','.p-account-trade-form'),(492969,'furniture-mobile','.w-top-categories .item','width_measure','%','2876','','.w-top-categories'),(492970,'furniture-mobile','.w-categories .item','width_measure','%','2906','','.w-categories'),(492971,'furniture-mobile','.w-sale .left-count','width_measure','%','','','.w-sale'),(492972,'furniture-mobile','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(492973,'furniture-mobile','.w-checkout-billing-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-billing-address'),(492974,'furniture-mobile','.w-checkout-shipping-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-shipping-address'),(492975,'furniture-mobile','.w-cart-order-total.box','width_measure','%','2876','','.w-cart-order-total'),(492976,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','2906','','.p-blog-index'),(492977,'furniture-mobile','.p-blog-index .nav-previous','width_measure','%','2906','','.p-blog-index'),(492978,'furniture-mobile','.p-blog-index .nav-next','width_measure','%','2906','','.p-blog-index'),(492979,'furniture-mobile','.w-product-wishlist-button .btn','width_measure','%','2876','','.w-product-wishlist-button'),(492980,'furniture-mobile','.w-cart-continue-btn a','width_measure','%','2876','','.w-cart-continue-btn'),(492981,'furniture-mobile','.w-promo-code .promo-text','width_measure','%','2885','','.w-promo-code'),(492982,'furniture-mobile','.w-promo-code .promo-code-form','width_measure','%','2885','','.w-promo-code'),(492983,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','2885','','.p-blog-index'),(492984,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(492985,'furniture-mobile','.w-promo-code .promo-text','width_measure','%','2885','','.w-promo-code'),(492986,'furniture-mobile','.w-checkout-billing-address .addresses .address-item','width_measure','%','','','.w-checkout-billing-address'),(492987,'furniture-mobile','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(492988,'furniture-mobile','.p-account-trade-form .wl-td select','width_measure','%','','','.p-account-trade-form'),(492989,'furniture-mobile','.p-blog-index .nav-previous','width_measure','%','','','.p-blog-index'),(492990,'furniture-mobile','.b-products-listing .products-listing .buyButton .btn','width_measure','%','','','.b-products-listing'),(492991,'furniture-mobile','.b-select-suggest .select2-search input','width_measure','%','','','.b-select-suggest'),(492992,'furniture-mobile','.b-select-suggest .select2-search','width_measure','%','','','.b-select-suggest'),(492993,'furniture-mobile','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width_measure','%','','','.b-select-suggest'),(492994,'furniture-mobile','.b-select-suggest .select2-drop','width_measure','%','','','.b-select-suggest'),(492995,'furniture-mobile','.w-sale .holder-1','width_measure','%','','','.w-sale'),(492996,'furniture-mobile','.w-sale .holder-2','width_measure','%','','','.w-sale'),(492997,'furniture-mobile','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(492998,'furniture-mobile','.w-login-block .input','width_measure','%','','','.w-login-block'),(492999,'furniture-mobile','.w-login-block .new','width_measure','%','','','.w-login-block'),(493000,'furniture-mobile','.p-account-trade-form .wl-td label','width_measure','%','','','.p-account-trade-form'),(493001,'furniture-mobile','.w-wedding-registry-widgets-products .products-listing .item','width_measure','%','2885','','.w-wedding-registry-widgets-products'),(493002,'furniture-mobile','.p-account-trade-form .wl-td label','width_measure','%','','','.p-account-trade-form'),(493003,'furniture-mobile','.w-login-block .returning','width_measure','%','','','.w-login-block'),(493004,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(493005,'furniture-mobile','.w-account .acc-new','width_measure','%','','','.w-account'),(493006,'furniture-mobile','.w-login-block .returning','width_measure','%','','','.w-login-block'),(493007,'furniture-mobile','.w-sale .left-count','width_measure','%','','','.w-sale'),(493008,'furniture-mobile','.w-cart-continue-btn a','width_measure','%','2876','','.w-cart-continue-btn'),(493009,'furniture-mobile','.p-blog-index .nav-next','width_measure','%','2906','','.p-blog-index'),(493010,'furniture-mobile','.w-product-wishlist-button .btn','width_measure','%','2876','','.w-product-wishlist-button'),(493011,'furniture-mobile','.w-account-addresses-list .addsess-suggestion-item','width_measure','%','','','.w-account-addresses-list'),(493012,'furniture-mobile','.w-account-customer-additional-field .field-type-checkbox label','width_measure','%','','','.w-account-customer-additional-field'),(493013,'furniture-mobile','.b-products-listing .products-listing a.btn.view-button','width_measure','%','','','.b-products-listing'),(493014,'furniture-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493015,'furniture-mobile','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493016,'furniture-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493017,'furniture-mobile','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493018,'furniture-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493019,'furniture-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493020,'furniture-mobile','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493021,'furniture-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493022,'furniture-mobile','.b-products-listing .BlockBox.type-14 > .col','width_measure','%','','','.b-products-listing'),(493023,'furniture-mobile','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(493024,'furniture-mobile','.b-products-listing .BlockBox.type-15 > .col','width_measure','%','','','.b-products-listing'),(493025,'furniture-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493026,'furniture-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493027,'furniture-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493028,'furniture-mobile','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493029,'furniture-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493030,'furniture-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493031,'furniture-mobile','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493032,'furniture-mobile','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(493033,'furniture-mobile','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493034,'furniture-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493035,'furniture-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493036,'furniture-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493037,'furniture-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493038,'furniture-mobile','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493039,'furniture-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493040,'furniture-mobile','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(493041,'furniture-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493042,'furniture-mobile','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493043,'furniture-mobile','.b-products-listing .loader','width_measure','%','3','','.b-products-listing'),(493044,'furniture-mobile','.b-products-listing .products-listing .attribute-qty-block > span','width_measure','%','','','.b-products-listing'),(493045,'furniture-mobile','.b-products-listing .products-listing .attributes select','width_measure','%','','','.b-products-listing'),(493046,'furniture-mobile','.b-products-listing .products-listing .btn-buy','width_measure','%','','','.b-products-listing'),(493047,'furniture-mobile','.b-products-listing .products-listing .item','width_measure','%','','','.b-products-listing'),(493048,'furniture-mobile','.w-catalog-b2b-add-button ','width_measure','%','','','.w-catalog-b2b-add-button'),(493049,'furniture-mobile','.b-products-listing .products-listing .qty-input.hidden','width_measure','%','3','','.b-products-listing'),(493050,'furniture-mobile','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width_measure','%','','','.b-products-listing'),(493051,'furniture-mobile','.w-blog-widget-related-posts-by-category .post','width_measure','%','','','.w-blog-widget-related-posts-by-category'),(493052,'furniture-mobile','.w-blog-widget-related-posts .post','width_measure','%','','','.w-blog-widget-related-posts'),(493053,'furniture-mobile','.w-blog-widget-post-title ','width_measure','%','2876','','.w-blog-widget-post-title'),(493054,'furniture-mobile','.w-blog-widget-post-listing .post','width_measure','%','2906','','.w-blog-widget-post-listing'),(493055,'furniture-mobile','.w-blog-widget-post-listing .post','width_measure','%','2885','','.w-blog-widget-post-listing'),(493056,'furniture-mobile','.w-blog-widget-post-listing .post','width_measure','%','','','.w-blog-widget-post-listing'),(493057,'furniture-mobile','.w-blog-widget-post-image ','width_measure','%','2876','','.w-blog-widget-post-image'),(493058,'furniture-mobile','.w-blog-widget-post-date ','width_measure','%','2876','','.w-blog-widget-post-date'),(493059,'furniture-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width_measure','%','','','.p-account-trade-form'),(493060,'furniture-mobile','.w-currencies .select','width_measure','%','','','.w-currencies'),(493061,'furniture-mobile','.w-sale .holder-2','width_measure','%','','','.w-sale'),(493062,'furniture-mobile','.b-products-listing .products-listing .in-cart','width_measure','%','','','.b-products-listing'),(493063,'furniture-mobile','.b-select-suggest .select2-container','width_measure','%','','','.b-select-suggest'),(493064,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(493065,'furniture-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(493066,'furniture-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(493067,'furniture-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(493068,'furniture-mobile','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width_measure','%','','','.b-fancybox'),(493069,'furniture-mobile','.w-promo-code .promo-code-form','width_measure','%','2885','','.w-promo-code'),(493070,'furniture-mobile','.p-account-trade-form .wl-td label','width_measure','%','','','.p-account-trade-form'),(493071,'furniture-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width_measure','%','','','.p-account-trade-form'),(493072,'furniture-mobile','.w-sale .left-text-left','width_measure','%','','','.w-sale'),(493073,'furniture-mobile','.w-sale .left-text-right','width_measure','%','','','.w-sale'),(493074,'furniture-mobile','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(493075,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(493076,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(493077,'furniture-mobile','.p-account-trade-form .wl-td input[type=\"text\"]','width_measure','%','','','.p-account-trade-form'),(493078,'furniture-mobile','.w-communication-new-topic .middle-form select','width_measure','%','','','.w-communication-new-topic'),(493079,'furniture-mobile','.b-form .hide-billing-address','width_measure','%','','','.b-form'),(493080,'furniture-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(493081,'furniture-mobile','.b-email .products-table','width_measure','%','','','.b-email'),(493082,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n)','width_measure','%','','','.p-account-trade-form'),(493083,'furniture-mobile','.b-bottom .popup-credit-amount .popup-box','width_measure','%','','','.b-bottom'),(493084,'furniture-mobile','.w-promo-code .promo-code-form','width_measure','%','2885','','.w-promo-code'),(493085,'furniture-mobile','.w-login-block .new','width_measure','%','','','.w-login-block'),(493086,'furniture-mobile','.w-menu-slider > ul > li > ul','width_measure','%','','','.w-menu-slider'),(493087,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','2885','','.p-blog-index'),(493088,'furniture-mobile','.w-sale .left-text-left','width_measure','%','','','.w-sale'),(493089,'furniture-mobile','.w-sale .left-text-right','width_measure','%','','','.w-sale'),(493090,'furniture-mobile','.w-sale .image','width_measure','%','','','.w-sale'),(493091,'furniture-mobile','.w-sale .left-count','width_measure','%','','','.w-sale'),(493092,'furniture-mobile','.w-sale .holder-1','width_measure','%','','','.w-sale'),(493093,'furniture-mobile','.w-sale .holder-2','width_measure','%','','','.w-sale'),(493094,'furniture-mobile','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(493095,'furniture-mobile','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(493096,'furniture-mobile','.b-compare .col-two label','width_measure','%','','','.b-compare'),(493097,'furniture-mobile','.b-form .addresses .address-item','width_measure','%','','','.b-form'),(493098,'furniture-mobile','.w-cart-continue-btn a','width_measure','%','2876','','.w-cart-continue-btn'),(493099,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(493100,'furniture-mobile','.w-cart-shipping-estimator .right-area','width_measure','%','','','.w-cart-shipping-estimator'),(493101,'furniture-mobile','.w-cart-listing .right-area','width_measure','%','','','.w-cart-listing'),(493102,'furniture-mobile','.w-cart-listing .item .remove','width_measure','%','2885','','.w-cart-listing'),(493103,'furniture-mobile','.w-cart-give-away .ga_img','width_measure','%','','','.w-cart-give-away'),(493104,'furniture-mobile','.w-cart-give-away .ga_column','width_measure','%','2876','','.w-cart-give-away'),(493105,'furniture-mobile','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(493106,'furniture-mobile','.b-fancybox .fancybox-nav','width_measure','%','','','.b-fancybox'),(493107,'furniture-mobile','.p-blog-index .nav-previous','width_measure','%','2906','','.p-blog-index'),(493108,'furniture-mobile','.w-promo-code .promo-code-form','width_measure','%','2885','','.w-promo-code'),(493109,'furniture-mobile','.w-sale .left-text-right','width_measure','%','','','.w-sale'),(493110,'furniture-mobile','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(493111,'furniture-mobile','.w-menu-slider > ul > li > ul','width_measure','%','','','.w-menu-slider'),(493112,'furniture-mobile','.w-login-block .input','width_measure','%','','','.w-login-block'),(493113,'furniture-mobile','.w-login-block .new','width_measure','%','','','.w-login-block'),(493114,'furniture-mobile','.w-login-block .guest','width_measure','%','','','.w-login-block'),(493115,'furniture-mobile','.p-blog-index .nav-previous','width_measure','%','','','.p-blog-index'),(493116,'furniture-mobile','.p-blog-index .nav-next','width_measure','%','','','.p-blog-index'),(493117,'furniture-mobile','.p-account-trade-form .wl-td select','width_measure','%','','','.p-account-trade-form'),(493118,'furniture-mobile','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(493119,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(493120,'furniture-mobile','.p-account-trade-form .wd-line-row-2 > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(493121,'furniture-mobile','.w-checkout-shipping-address .addresses .address-item','width_measure','%','','','.w-checkout-shipping-address'),(493122,'furniture-mobile','.w-login-block .guest','width_measure','%','','','.w-login-block'),(493123,'furniture-mobile','.w-filters .handle-from','width_measure','%','','','.w-filters'),(493124,'furniture-mobile','.w-promo-code .promo-code-form','width_measure','%','2885','','.w-promo-code'),(493125,'furniture-mobile','.p-blog-index .nav-next','width_measure','%','','','.p-blog-index'),(493126,'furniture-mobile','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(493127,'furniture-mobile','.p-account-trade-form .address-wrapp > div:nth-child(2n+1)','width_measure','%','','','.p-account-trade-form'),(493128,'furniture-mobile','.w-filters .handle-to','width_measure','%','','','.w-filters'),(493129,'furniture-mobile','.w-categories .item','width_measure','%','','','.w-categories'),(493130,'furniture-mobile','.p-wedding-registry-search .search-list input','width_measure','%','','','.p-wedding-registry-search'),(493131,'furniture-mobile','.b-compare .col-two select','width_measure','%','','','.b-compare'),(493132,'furniture-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(493133,'furniture-mobile','.b-form .col-3','width_measure','%','','','.b-form'),(493134,'furniture-mobile','.p-blog-index .nav-previous','width_measure','%','','','.p-blog-index'),(493135,'furniture-mobile','textarea','width_measure','%','','',''),(493136,'furniture-mobile','.w-product-wishlist-button .btn','width_measure','%','2876','','.w-product-wishlist-button'),(493137,'furniture-mobile','.b-products-listing .products-listing .btn-preloader','width_measure','%','','','.b-products-listing'),(493138,'furniture-mobile','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width_measure','%','','','.b-form'),(493139,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','2885','','.p-blog-index'),(493140,'furniture-mobile','.b-email .totals-title','width_measure','%','','','.b-email'),(493141,'furniture-mobile','.b-email .totals-value','width_measure','%','','','.b-email'),(493142,'furniture-mobile','.b-email .totals-table','width_measure','%','','','.b-email'),(493143,'furniture-mobile','.p-blog-index .nav-previous','width_measure','%','','','.p-blog-index'),(493144,'furniture-mobile','.p-blog-index .nav-next','width_measure','%','','','.p-blog-index'),(493145,'furniture-mobile','.p-blog-index .w-blog-sidebar .wp-widget','width_measure','%','2906','','.p-blog-index'),(493146,'furniture-mobile','.w-filters .input-txt-keywords','width_measure','%','','','.w-filters'),(493147,'furniture-mobile','.w-filters .input-txt','width_measure','%','','','.w-filters'),(493148,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width_measure','vw','','','.b-menu-lev_display-slide'),(493149,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width_measure','vw','','','.b-menu-lev_display-slide'),(493150,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width_measure','vw','','','.b-menu-lev_display-slide'),(493151,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width_measure','vw','','','.b-menu-lev_display-slide'),(493152,'furniture-mobile','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width_measure','vw','','','.b-menu-lev_display-slide'),(493153,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_measure','vw','','','.b-menu-open_from-left'),(493154,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(493155,'furniture-mobile','.b-trade-approval .steps-bar','width_measure','%','','','.b-trade-approval'),(493156,'furniture-mobile','.b-trade-approval .col-right','width_measure','%','','','.b-trade-approval'),(493157,'furniture-mobile','.b-trade-approval .col-left','width_measure','%','','','.b-trade-approval'),(493158,'furniture-mobile','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width_measure','%','','','.b-trade-approval'),(493159,'furniture-mobile','.b-trade-approval .col-3','width_measure','%','','','.b-trade-approval'),(493160,'furniture-mobile','.batchPr .w-batch-products .products-listing .attribute-qty-block','width_measure','%','','','.batchPr'),(493161,'furniture-mobile','.batchPr .box-block.type-5 > .block:nth-child(1), .batchPr .box-block.type-5 > .block:nth-child(2)','width_measure','%','','','.batchPr'),(493162,'furniture-mobile','.w-account-personal-catalog .list-switcher','width_measure','%','','','.w-account-personal-catalog'),(493163,'furniture-mobile','.w-catalog-compare .cross-box .different-all > div','width_measure','%','','','.w-catalog-compare'),(493164,'furniture-mobile','.w-account .col-left, .w-account .col-right','width_measure','%','','','.w-account'),(493165,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .BlockBox.type-2 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(493166,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .BlockBox.type-2 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(493167,'furniture-mobile','.w-search .suggest-js','width_measure','%','2885','','.w-search'),(493168,'furniture-mobile','.tripleBanner > .block','width_measure','%','2885','','.tripleBanner'),(493169,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li','width_measure','%','2890','','.b-menu-style-3'),(493170,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li','width_measure','%','','','.b-menu-style-3'),(493171,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li:nth-child(1) > ul > li, .b-menu-style-3 .menu-style[data-style=\"3\"] .level-1 > li:nth-child(2) > ul > li','width_measure','%','','','.b-menu-style-3'),(493172,'furniture-mobile','.b-products-listing .item-nav > div','width_measure','%','','','.b-products-listing'),(493173,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-content','width_measure','%','4','','.b-products-listing'),(493174,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','width_measure','%','','','.b-products-listing'),(493175,'furniture-mobile','.w-product-sale-ends .left-count','width_measure','%','','','.w-product-sale-ends'),(493176,'furniture-mobile','.w-product-sale-ends .left-text-left','width_measure','%','','','.w-product-sale-ends'),(493177,'furniture-mobile','.w-product-sale-ends .left-text-right','width_measure','%','','','.w-product-sale-ends'),(493178,'furniture-mobile','h1, .heading-1','width_measure','%','3','',''),(493179,'furniture-mobile','h1, .heading-1','width_measure','%','4','',''),(493180,'furniture-mobile','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(493181,'furniture-mobile','.w-product-bonus-points > div > div','width_measure','%','','','.w-product-bonus-points'),(493182,'furniture-mobile','.w-files-catalog-widgets-files-catalog .item','width_measure','%','','','.w-files-catalog-widgets-files-catalog'),(493183,'furniture-mobile','.w-files-catalog-widgets-files-catalog .item','width_measure','%','2890','','.w-files-catalog-widgets-files-catalog'),(493184,'furniture-mobile','.w-files-catalog-widgets-files-catalog .item','width_measure','%','2885','','.w-files-catalog-widgets-files-catalog'),(493185,'furniture-mobile','.w-files-catalog-widgets-files-catalog .item','width_measure','%','2876','','.w-files-catalog-widgets-files-catalog'),(493186,'furniture-mobile','.w-cart-discount-coupon input[type=\"text\"]','width_measure','%','','','.w-cart-discount-coupon'),(493187,'furniture-mobile','.w-cart-sub-total .price-row','width_measure','%','','','.w-cart-sub-total'),(493188,'furniture-mobile','.w-cart-sub-total .price-row > div','width_measure','%','','','.w-cart-sub-total'),(493189,'furniture-mobile','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(493190,'furniture-mobile','.w-cart-gift-certificate .input-apple','width_measure','%','','','.w-cart-gift-certificate'),(493191,'furniture-mobile','.w-cart-gift-certificate .input-apple div','width_measure','%','','','.w-cart-gift-certificate'),(493192,'furniture-mobile','.w-cart-order-reference .input-apple','width_measure','%','','','.w-cart-order-reference'),(493193,'furniture-mobile','.w-cart-order-reference .input-apple div','width_measure','%','','','.w-cart-order-reference'),(493194,'furniture-mobile','.w-cart-order-reference .input-apple div input','width_measure','%','','','.w-cart-order-reference'),(493195,'furniture-mobile','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(493196,'furniture-mobile','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(493197,'furniture-mobile','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(493198,'furniture-mobile','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(493199,'furniture-mobile','.w-product-bundle .bundle_item','width_measure','%','2885','','.w-product-bundle'),(493200,'furniture-mobile','.w-product-bundle .bundle_item','width_measure','%','2876','','.w-product-bundle'),(493201,'furniture-mobile','.w-product-in-bundles .attributes-item','width_measure','%','','','.w-product-in-bundles'),(493202,'furniture-mobile','.w-product-in-bundles .attributes-select','width_measure','%','','','.w-product-in-bundles'),(493203,'furniture-mobile','.w-product-in-bundles .bundle_item','width_measure','%','2885','','.w-product-in-bundles'),(493204,'furniture-mobile','.w-product-in-bundles .bundle_item','width_measure','%','2876','','.w-product-in-bundles'),(493205,'furniture-mobile','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(493206,'furniture-mobile','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(493207,'furniture-mobile','.heading-2','width_measure','%','3','',''),(493208,'furniture-mobile','.heading-2','width_measure','%','4','',''),(493209,'furniture-mobile','.w-product-quantity-discounts .item','width_measure','%','','','.w-product-quantity-discounts'),(493210,'furniture-mobile','.w-product-quantity-discounts .item','width_measure','%','2885','','.w-product-quantity-discounts'),(493211,'furniture-mobile','.w-product-multi-inventory .select-box:nth-child(2n)','width_measure','%','','','.w-product-multi-inventory'),(493212,'furniture-mobile','.w-product-multi-inventory .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-multi-inventory'),(493213,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','width_measure','%','3','','.p-quote-checkout-index'),(493214,'furniture-mobile','.p-quote-checkout-index .order-summary .heading-2','width_measure','%','4','','.p-quote-checkout-index'),(493215,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','width_measure','%','3','','.p-sample-checkout-index'),(493216,'furniture-mobile','.p-sample-checkout-index .order-summary .heading-2','width_measure','%','4','','.p-sample-checkout-index'),(493217,'furniture-mobile','.w-account-order-download table','width_measure','%','','','.w-account-order-download'),(493218,'furniture-mobile','.w-product-multi-inventory .radio-attributes > label','width_measure','%','','','.w-product-multi-inventory'),(493219,'furniture-mobile','.w-product-multi-inventory .radio-attributes .option-item','width_measure','%','','','.w-product-multi-inventory'),(493220,'furniture-mobile','.w-product-multi-inventory .radio-attributes > label','width_measure','%','2890','','.w-product-multi-inventory'),(493221,'furniture-mobile','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','width_measure','%','','','.w-account-personal-catalog'),(493222,'furniture-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width_measure','%','2890','','.b-products-listing'),(493223,'furniture-mobile','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width_measure','%','2890','','.b-products-listing'),(493224,'furniture-mobile','.b-products-listing .products-listing .radio-attributes .option','width_measure','%','','','.b-products-listing'),(493225,'furniture-mobile','.b-products-listing .products-listing .radio-attributes > label','width_measure','%','','','.b-products-listing'),(493226,'furniture-mobile','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(493227,'furniture-mobile','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(493228,'furniture-mobile','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(493229,'furniture-mobile','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(493230,'furniture-mobile','.w-account-customer-additional-field .field-type-text label, .w-account-customer-additional-field .field-type-file label','width_measure','%','','','.w-account-customer-additional-field'),(493231,'furniture-mobile','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select, .w-account-customer-additional-field .files','width_measure','%','','','.w-account-customer-additional-field'),(493232,'furniture-mobile','.w-product-collection .current-product, .w-product-collection .chosen-products','width_measure','%','2885','','.w-product-collection'),(493233,'furniture-mobile','.w-product-collection .right-area','width_measure','%','2885','','.w-product-collection'),(493234,'furniture-mobile','.w-product-attributes .radio-attributes .option-item','width_measure','%','','','.w-product-attributes'),(493235,'furniture-mobile','.w-product-attributes .radio-attributes > label','width_measure','%','','','.w-product-attributes'),(493236,'furniture-mobile','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(493237,'furniture-mobile','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(493238,'furniture-mobile','.w-product-attributes .radio-attributes > label','width_measure','%','2890','','.w-product-attributes'),(493239,'furniture-mobile','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(493240,'furniture-mobile','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(493241,'furniture-mobile','.w-product-properties li','width_measure','%','','','.w-product-properties'),(493242,'furniture-mobile','.w-product-groups .radioBox label','width_measure','%','','','.w-product-groups'),(493243,'furniture-mobile','.w-product-groups .radioBox label','width_measure','%','2906','','.w-product-groups'),(493244,'furniture-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(493245,'furniture-mobile','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(493246,'furniture-mobile','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(493247,'furniture-mobile','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(493248,'furniture-mobile','.w-product-custom-bundle .chosen-products','width_measure','%','2885','','.w-product-custom-bundle'),(493249,'furniture-mobile','.w-product-custom-bundle .right-area','width_measure','%','2885','','.w-product-custom-bundle'),(493250,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width_measure','%','','','.w-catalog-pages-category-pages-last-list'),(493251,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width_measure','%','2885','','.w-catalog-pages-category-pages-last-list'),(493252,'furniture-mobile','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width_measure','%','2876','','.w-catalog-pages-category-pages-last-list'),(493253,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width_measure','%','','','.w-catalog-pages-category-pages-last-list-block'),(493254,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(493255,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(493256,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width_measure','%','2885','','.w-catalog-pages-category-pages-last-list-block'),(493257,'furniture-mobile','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width_measure','%','2876','','.w-catalog-pages-category-pages-last-list-block'),(493258,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','width_measure','%','2885','','.w-delivery-location-location-list'),(493259,'furniture-mobile','.w-delivery-location-location-list .deliveryList li','width_measure','%','2876','','.w-delivery-location-location-list'),(493260,'furniture-mobile','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','2876','','.w-delivery-location-top-location-list'),(493261,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li','width_measure','%','','','.w-delivery-location-featured-list'),(493262,'furniture-mobile','.w-delivery-location-featured-list .deliveryList > ul > li','width_measure','%','2906','','.w-delivery-location-featured-list'),(493263,'furniture-mobile','.w-wedding-registry-widgets-search-form .col-3','width_measure','%','2885','','.w-wedding-registry-widgets-search-form'),(493264,'furniture-mobile','.w-wedding-registry-widgets-search-form .col-3:nth-child(3)','width_measure','%','2885','','.w-wedding-registry-widgets-search-form'),(493265,'furniture-mobile','.w-wedding-registry-widgets-search-form .col-3','width_measure','%','2906','','.w-wedding-registry-widgets-search-form'),(493266,'furniture-mobile','.w-sale-category .holder-1','width_measure','%','','','.w-sale-category'),(493267,'furniture-mobile','.w-sale-category .holder-2','width_measure','%','','','.w-sale-category'),(493268,'furniture-mobile','.w-sale-category .image','width_measure','%','','','.w-sale-category'),(493269,'furniture-mobile','.w-sale-category .left-count','width_measure','%','','','.w-sale-category'),(493270,'furniture-mobile','.w-sale-category .left-text-left','width_measure','%','','','.w-sale-category'),(493271,'furniture-mobile','.w-sale-category .left-text-right','width_measure','%','','','.w-sale-category'),(493272,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width_measure','%','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(493273,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width_measure','%','2876','','.w-catalog-pages-category-pages-last-list-by-catalog'),(493274,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width_measure','%','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(493275,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width_measure','%','2876','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(493276,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width_measure','%','2885','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(493277,'furniture-mobile','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width_measure','%','2885','','.w-catalog-pages-category-pages-last-list-by-catalog'),(493278,'furniture-mobile','.w-delivery-location-list-by-page .item','width_measure','%','','','.w-delivery-location-list-by-page'),(493279,'furniture-mobile','.w-delivery-location-list-by-page .item','width_measure','%','2885','','.w-delivery-location-list-by-page'),(493280,'furniture-mobile','.w-delivery-location-list-by-page .item','width_measure','%','2906','','.w-delivery-location-list-by-page'),(493281,'furniture-mobile','.w-product-properties-icons .hover-box-content','width_measure','%','','','.w-product-properties-icons'),(493282,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','width_measure','%','2906','','.w-product-properties-icons'),(493283,'furniture-mobile','.w-delivery-location-cross-pages .item','width_measure','%','','','.w-delivery-location-cross-pages'),(493284,'furniture-mobile','.w-delivery-location-cross-pages .item','width_measure','%','2885','','.w-delivery-location-cross-pages'),(493285,'furniture-mobile','.w-delivery-location-cross-pages .item','width_measure','%','2906','','.w-delivery-location-cross-pages'),(493286,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','width_measure','%','','','.w-delivery-location-product-categories'),(493287,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','width_measure','%','2885','','.w-delivery-location-product-categories'),(493288,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','width_measure','%','2906','','.w-delivery-location-product-categories'),(493289,'furniture-mobile','.w-delivery-location-product-categories .item.category-link','width_measure','%','2876','','.w-delivery-location-product-categories'),(493290,'furniture-mobile','.w-catalog-delivery-locations .item','width_measure','%','','','.w-catalog-delivery-locations'),(493291,'furniture-mobile','.w-catalog-delivery-locations .item','width_measure','%','2876','','.w-catalog-delivery-locations'),(493292,'furniture-mobile','.w-product-bonus-points .bonus-points-cost','width_measure','%','','','.w-product-bonus-points'),(493293,'furniture-mobile','.w-product-designer-designer .prodDesignerType','width_measure','%','','','.w-product-designer-designer'),(493294,'furniture-mobile','.w-product-designer-designer .productDesignerBox input','width_measure','%','','','.w-product-designer-designer'),(493295,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','width_measure','%','','','.w-press-reviews-widgets-press-reviews-small'),(493296,'furniture-mobile','.w-press-reviews-widgets-press-reviews-small .small-press-review','width_measure','%','','','.w-press-reviews-widgets-press-reviews-small'),(493297,'furniture-mobile','.w-support-system-listing .product_icon','width_measure','%','','','.w-support-system-listing'),(493298,'furniture-mobile','.w-rma-returns-history input[type=\'text\'], .w-rma-returns-history input[type=\'password\'], .w-rma-returns-history input[type=\'number\'], .w-rma-returns-history input[type=\'email\'], .w-rma-returns-history input[type=\'search\'], .w-rma-returns-history select','width_measure','%','','','.w-rma-returns-history'),(493299,'furniture-mobile','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 .no-link','width_measure','%','','','.b-menu-style-1'),(493300,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(493301,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(493302,'furniture-mobile','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(493303,'furniture-mobile','.w-banner .image-text-banner.bottom-center .text-banner','width_measure','%','','','.w-banner'),(493304,'furniture-mobile','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner','width_measure','%','','','.w-banner'),(493305,'furniture-mobile','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(493306,'furniture-mobile','.w-product-configurator .item-content','width_measure','%','2885','','.w-product-configurator'),(493307,'furniture-mobile','.w-product-configurator .pc_item','width_measure','%','2885','','.w-product-configurator'),(493308,'furniture-mobile','.b-products-listing .products-listing .bonus-points-cost','width_measure','%','','','.b-products-listing'),(493309,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width_measure','%','','','.w-catalog-pages-category-pages-list'),(493310,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width_measure','%','2885','','.w-catalog-pages-category-pages-list'),(493311,'furniture-mobile','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width_measure','%','2876','','.w-catalog-pages-category-pages-list'),(493312,'furniture-mobile','.w-predefined-promotion .nextdiscount .item-holder .image','width_measure','%','','','.w-predefined-promotion'),(493313,'furniture-mobile','.w-predefined-promotion .nextdiscount .item-holder .name','width_measure','%','','','.w-predefined-promotion'),(493314,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .list','width_measure','%','','','.w-predefined-promotion'),(493315,'furniture-mobile','.w-predefined-promotion .promo-cart-discount > div','width_measure','%','','','.w-predefined-promotion'),(493316,'furniture-mobile','.w-predefined-promotion .promo-salemaker .item','width_measure','%','','','.w-predefined-promotion'),(493317,'furniture-mobile','.w-predefined-promotion .promo-salemaker > div','width_measure','%','','','.w-predefined-promotion'),(493318,'furniture-mobile','.w-filters .fsl_handle > div','width_measure','%','','','.w-filters'),(493319,'furniture-mobile','.mainBanner .bottomBox .elf','width_measure','%','','','.mainBanner'),(493320,'furniture-mobile','.mainBanner .title','width_measure','vw','3','','.mainBanner'),(493321,'furniture-mobile','.mainBanner .title','width_measure','%','','','.mainBanner'),(493322,'furniture-mobile','.mainBanner .w-banner .image-text-banner.middle-right .text-banner-1','width_measure','%','','','.mainBanner'),(493323,'furniture-mobile','.mainBanner .title','width_measure','vw','2876,3','','.mainBanner'),(493324,'furniture-mobile','.lowestPricedBox .w-banner .image-text-banner.middle-right .text-banner-1','width_measure','%','','','.lowestPricedBox'),(493325,'furniture-mobile','.lowestPricedBox .w-banner .text-banner','width_measure','%','','','.lowestPricedBox'),(493326,'furniture-mobile','.lowestPricedBox .w-banner .ybg .btn','width_measure','%','','','.lowestPricedBox'),(493327,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','width_measure','%','','','.shopByCollectionBox'),(493328,'furniture-mobile','.shopByCollectionBox .w-banner .image-text-banner','width_measure','%','2906','','.shopByCollectionBox'),(493329,'furniture-mobile','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','width_measure','%','','','.mainBanner'),(493330,'furniture-mobile','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','width_measure','%','','','.mainBanner'),(493331,'furniture-mobile','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','width_measure','%','','','.mainBanner'),(493332,'furniture-mobile','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','width_measure','%','2876','','.mainBanner'),(493333,'furniture-mobile','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','width_measure','%','2876','','.mainBanner'),(493334,'furniture-mobile','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','width_measure','%','2876','','.mainBanner'),(493335,'furniture-mobile','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','width_measure','%','2906','','.mainBanner'),(493336,'furniture-mobile','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','width_measure','%','2906','','.mainBanner'),(493337,'furniture-mobile','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','width_measure','%','2906','','.mainBanner'),(493338,'furniture-mobile','.w-cart-shipping-estimator .left-area','width_measure','%','2876','','.w-cart-shipping-estimator'),(493339,'furniture-mobile','.w-cart-shipping-estimator .right-area','width_measure','%','2876','','.w-cart-shipping-estimator'),(493340,'furniture-mobile','.w-search .products','width_measure','%','','','.w-search'),(493341,'furniture-mobile','.w-search .wrap','width_measure','%','','','.w-search'),(493342,'furniture-mobile','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','width_measure','%','','','.account-address-book'),(493343,'furniture-mobile','.account-address-book .address_book_row .column','width_measure','%','2876','','.account-address-book'),(493344,'furniture-mobile','.account-address-book .address_book_row .column + .column','width_measure','%','2876','','.account-address-book'),(493345,'furniture-mobile','.account-address-book .topInfo > div','width_measure','%','2876','','.account-address-book'),(493346,'furniture-mobile','.account-address-book .topInfo > div + div','width_measure','%','2876','','.account-address-book'),(493347,'furniture-mobile','.account-order-history .orders-table .td-alignright','width_measure','%','2885','','.account-order-history'),(493348,'furniture-mobile','.account-order-history-info .history_info > div','width_measure','%','','','.account-order-history-info'),(493349,'furniture-mobile','.account-order-history-info .history_info > div','width_measure','%','2885','','.account-order-history-info'),(493350,'furniture-mobile','.account-index .account_info li','width_measure','%','','','.account-index'),(493351,'furniture-mobile','.account-index .ai_title','width_measure','%','','','.account-index'),(493352,'furniture-mobile','.account-index .topAccount > li','width_measure','%','','','.account-index'),(493353,'furniture-mobile','.account-index .topInfo > div','width_measure','%','','','.account-index'),(493354,'furniture-mobile','.account-index .orders-table .links','width_measure','%','2885','','.account-index'),(493355,'furniture-mobile','.account-index .account_info li','width_measure','%','2876','','.account-index'),(493356,'furniture-mobile','.account-index .topAccount > li','width_measure','%','2876','','.account-index'),(493357,'furniture-mobile','.account-order-pay .history_info > div','width_measure','%','','','.account-order-pay'),(493358,'furniture-mobile','.account-order-pay .history_info > div','width_measure','%','2885','','.account-order-pay'),(493359,'furniture-mobile','.account-samples .orders-table .td-alignright','width_measure','%','2885','','.account-samples'),(493360,'furniture-mobile','.account-sample-info .history_info > div','width_measure','%','','','.account-sample-info'),(493361,'furniture-mobile','.account-sample-info .history_info > div','width_measure','%','2885','','.account-sample-info'),(493362,'furniture-mobile','.checkout-index-wrap .dob-hide > div','width_measure','%','','','.checkout-index-wrap'),(493363,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .address-item','width_measure','%','','','.checkout-index-wrap'),(493364,'furniture-mobile','.checkout-index-wrap .edit-address-popup .addresses .buttons','width_measure','%','','','.checkout-index-wrap'),(493365,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','width_measure','%','3','','.checkout-index-wrap'),(493366,'furniture-mobile','.checkout-index-wrap .order-summary .heading-2','width_measure','%','4','','.checkout-index-wrap'),(493367,'furniture-mobile','.checkout-index-wrap .order-summary2 .btn-2','width_measure','%','','','.checkout-index-wrap'),(493368,'furniture-mobile','.checkout-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.checkout-order-confirmation'),(493369,'furniture-mobile','.checkout-login-wrap .col-left, .checkout-login-wrap .col-right','width_measure','%','','','.checkout-login-wrap'),(493370,'furniture-mobile','.checkout-login-wrap .middle-form .btn-2','width_measure','%','','','.checkout-login-wrap'),(493371,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_measure_important','important','','','.b-menu-open_from-left'),(493372,'furniture-mobile','.tripleBanner > .block','width_measure_important','important','2885','','.tripleBanner'),(493373,'furniture-mobile','.b-menu-style-3 .menu-style[data-style=\"3\"] .level-2 > li','width_measure_important','important','2890','','.b-menu-style-3'),(493374,'furniture-mobile','.w-cart-discount-coupon input[type=\"text\"]','width_measure_important','important','','','.w-cart-discount-coupon'),(493375,'furniture-mobile','.b-form .same-address','z-index','80','','','.b-form'),(493376,'furniture-mobile','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','z-index','-1','','','.b-switch'),(493377,'furniture-mobile','.b-fancybox .filter-listing-loader','z-index','100000','','','.b-fancybox'),(493378,'furniture-mobile','.b-fancybox .filter-listing-preloader','z-index','100001','','','.b-fancybox'),(493379,'furniture-mobile','.w-promotions .prom-multi-discount .promo-range','z-index','1','','','.w-promotions'),(493380,'furniture-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(493381,'furniture-mobile','.w-account .account-top','z-index','91','','','.w-account'),(493382,'furniture-mobile','.w-account .my-acc-link','z-index','1','','','.w-account'),(493383,'furniture-mobile','.p-sample-checkout-success .page-success > div','z-index','1','','','.p-sample-checkout-success'),(493384,'furniture-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(493385,'furniture-mobile','.b-preloader .preloader','z-index','10','','','.b-preloader'),(493386,'furniture-mobile','.w-menu-slider > ul > li > ul','z-index','100','','','.w-menu-slider'),(493387,'furniture-mobile','.b-messages .messMenuButton span','z-index','1','','','.b-messages'),(493388,'furniture-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(493389,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-style-1'),(493390,'furniture-mobile','.w-menu-style-1 > ul > li > ul','z-index','22','','','.w-menu-style-1'),(493391,'furniture-mobile','.b-fancybox #fancybox-loading','z-index','8060','','','.b-fancybox'),(493392,'furniture-mobile','.b-fancybox .fancybox-wrap','z-index','8020','','','.b-fancybox'),(493393,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-style-1'),(493394,'furniture-mobile','.w-menu-style-1 > ul','z-index','21','','','.w-menu-style-1'),(493395,'furniture-mobile','.w-upload-customer-id-upload-customer-id-form .upload-file','z-index','10','','','.w-upload-customer-id-upload-customer-id-form'),(493396,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-horizontal'),(493397,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-horizontal'),(493398,'furniture-mobile','.w-menu-horizontal > ul > li > ul > li > ul','z-index','23','','','.w-menu-horizontal'),(493399,'furniture-mobile','.w-menu-slider > ul > li > ul','z-index','100','','','.w-menu-slider'),(493400,'furniture-mobile','.w-quote .cart-box-link','z-index','1','','','.w-quote'),(493401,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul','z-index','23','','','.w-menu-style-1'),(493402,'furniture-mobile','.w-menu-style-1 > ul > li > ul','z-index','22','','','.w-menu-style-1'),(493403,'furniture-mobile','.b-switch .bootstrap-switch','z-index','0','','','.b-switch'),(493404,'furniture-mobile','.w-menu-slider > ul > li > ul','z-index','100','','','.w-menu-slider'),(493405,'furniture-mobile','.w-menu-style-1 > ul','z-index','21','','','.w-menu-style-1'),(493406,'furniture-mobile','.w-menu-style-1 > ul > li > ul','z-index','22','','','.w-menu-style-1'),(493407,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-style-1'),(493408,'furniture-mobile','.w-search .suggest','z-index','500','','','.w-search'),(493409,'furniture-mobile','.b-info-popup .info-popup div','z-index','1000','','','.b-info-popup'),(493410,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(493411,'furniture-mobile','.w-menu-style-1 > ul','z-index','21','','','.w-menu-style-1'),(493412,'furniture-mobile','.w-menu-style-1 > ul > li > ul','z-index','22','','','.w-menu-style-1'),(493413,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul','z-index','23','','','.w-menu-style-1'),(493414,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-style-1'),(493415,'furniture-mobile','.edit-link','z-index','1','','',''),(493416,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(493417,'furniture-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(493418,'furniture-mobile','.w-menu-slider > ul > li > ul','z-index','100','','','.w-menu-slider'),(493419,'furniture-mobile','.w-menu-style-1 > ul','z-index','21','','','.w-menu-style-1'),(493420,'furniture-mobile','.w-menu-style-1 > ul > li > ul','z-index','22','','','.w-menu-style-1'),(493421,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-style-1'),(493422,'furniture-mobile','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','z-index','0','','','.b-switch'),(493423,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-label','z-index','100','','','.b-switch'),(493424,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul','z-index','23','','','.w-menu-style-1'),(493425,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(493426,'furniture-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(493427,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(493428,'furniture-mobile','.w-menu-style-1 > ul > li > ul','z-index','22','','','.w-menu-style-1'),(493429,'furniture-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(493430,'furniture-mobile','.b-fancybox .fancybox-overlay','z-index','8010','','','.b-fancybox'),(493431,'furniture-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(493432,'furniture-mobile','.w-menu-horizontal > ul','z-index','21','','','.w-menu-horizontal'),(493433,'furniture-mobile','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','z-index','1','','','.b-switch'),(493434,'furniture-mobile','.w-languages .select','z-index','100','','','.w-languages'),(493435,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul','z-index','23','','','.w-menu-style-1'),(493436,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-style-1'),(493437,'furniture-mobile','.w-menu .hided.menu > ul','z-index','100','','','.w-menu'),(493438,'furniture-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(493439,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul','z-index','23','','','.w-menu-style-1'),(493440,'furniture-mobile','.w-promotions .promo-cart-discount .slave .condition','z-index','1','','','.w-promotions'),(493441,'furniture-mobile','.w-menu-horizontal > ul > li > ul','z-index','22','','','.w-menu-horizontal'),(493442,'furniture-mobile','.w-menu .hided.menu > ul','z-index','100','','','.w-menu'),(493443,'furniture-mobile','.w-menu .hided.menu > ul','z-index','100','','','.w-menu'),(493444,'furniture-mobile','.w-menu-style-1 > ul','z-index','21','','','.w-menu-style-1'),(493445,'furniture-mobile','.w-menu-slider > ul > li > ul','z-index','100','','','.w-menu-slider'),(493446,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-style-1'),(493447,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(493448,'furniture-mobile','.b-fancybox .fancybox-close','z-index','8040','','','.b-fancybox'),(493449,'furniture-mobile','.b-fancybox .fancybox-opened','z-index','8030','','','.b-fancybox'),(493450,'furniture-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(493451,'furniture-mobile','.w-menu-slider > ul > li > ul','z-index','100','','','.w-menu-slider'),(493452,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-style-1'),(493453,'furniture-mobile','.b-datepicker .datepicker-dropdown','z-index','1000','','','.b-datepicker'),(493454,'furniture-mobile','.w-quote .cart-box','z-index','100','','','.w-quote'),(493455,'furniture-mobile','.p-sample-checkout-success .page-success','z-index','-1','','','.p-sample-checkout-success'),(493456,'furniture-mobile','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','z-index','1','','','.b-switch'),(493457,'furniture-mobile','.b-select-suggest .select2-search','z-index','10000','','','.b-select-suggest'),(493458,'furniture-mobile','.b-select-suggest .select2-drop-mask','z-index','9998','','','.b-select-suggest'),(493459,'furniture-mobile','.b-select-suggest .select2-drop','z-index','9999','','','.b-select-suggest'),(493460,'furniture-mobile','.w-menu .hided.menu > ul','z-index','100','','','.w-menu'),(493461,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul','z-index','23','','','.w-menu-style-1'),(493462,'furniture-mobile','.w-menu .hided.menu > ul','z-index','100','','','.w-menu'),(493463,'furniture-mobile','.w-menu-big li','z-index','20','','','.w-menu-big'),(493464,'furniture-mobile','.b-bottom .pop-up-close','z-index','1','','','.b-bottom'),(493465,'furniture-mobile','.w-catalog-b2b-add-button ','z-index','1','','','.w-catalog-b2b-add-button'),(493466,'furniture-mobile','.b-products-listing .promos-info','z-index','1','','','.b-products-listing'),(493467,'furniture-mobile','.b-autocomplete .ui-autocomplete','z-index','1000','','','.b-autocomplete'),(493468,'furniture-mobile','.w-currencies .select','z-index','10','','','.w-currencies'),(493469,'furniture-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(493470,'furniture-mobile','.b-form .form-inputs div.required-message','z-index','1','','','.b-form'),(493471,'furniture-mobile','.b-fancybox .fancybox-title','z-index','8050','','','.b-fancybox'),(493472,'furniture-mobile','.b-fancybox .fancybox-title-float-wrap','z-index','8050','','','.b-fancybox'),(493473,'furniture-mobile','.w-menu-style-1 > ul','z-index','21','','','.w-menu-style-1'),(493474,'furniture-mobile','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(493475,'furniture-mobile','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(493476,'furniture-mobile','.b-form .eye-password-wrap','z-index','1','','','.b-form'),(493477,'furniture-mobile','.b-form .eye-password','z-index','1','','','.b-form'),(493478,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-style-1'),(493479,'furniture-mobile','.b-form .hide-billing-address','z-index','70','','','.b-form'),(493480,'furniture-mobile','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(493481,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-style-1'),(493482,'furniture-mobile','.w-cart .cart-box','z-index','91','','','.w-cart'),(493483,'furniture-mobile','.w-cart .cart-box-link','z-index','1','','','.w-cart'),(493484,'furniture-mobile','.b-fancybox .fancybox-nav span','z-index','8040','','','.b-fancybox'),(493485,'furniture-mobile','.b-fancybox .fancybox-nav','z-index','8040','','','.b-fancybox'),(493486,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-style-1'),(493487,'furniture-mobile','.w-menu .hided.menu > ul','z-index','100','','','.w-menu'),(493488,'furniture-mobile','.w-menu-style-1 > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-style-1'),(493489,'furniture-mobile','.w-menu-big > ul > li > ul','z-index','100','','','.w-menu-big'),(493490,'furniture-mobile','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','z-index','1000','','','.w-image-maps'),(493491,'furniture-mobile','.w-banner .banner img + img','z-index','-1','','','.w-banner'),(493492,'furniture-mobile','.b-product-images .media-popup .mp-close','z-index','1','','','.b-product-images'),(493493,'furniture-mobile','.b-product-images .mp-shadow, .b-product-images .media-popup','z-index','1000','','','.b-product-images'),(493494,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(493495,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(493496,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(493497,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(493498,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(493499,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(493500,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(493501,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(493502,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(493503,'furniture-mobile','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(493504,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(493505,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(493506,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(493507,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(493508,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(493509,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(493510,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(493511,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(493512,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(493513,'furniture-mobile','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(493514,'furniture-mobile','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','z-index','1000','','','.b-menu-open_from-left'),(493515,'furniture-mobile','.batchPr .batchSelect','z-index','1','','','.batchPr'),(493516,'furniture-mobile','.w-currencies ','z-index','101','','','.w-currencies'),(493517,'furniture-mobile','.b-slick button.slick-prev, .b-slick button.slick-next','z-index','1','','','.b-slick'),(493518,'furniture-mobile','.header','z-index','100','2885','',''),(493519,'furniture-mobile','.b-products-listing .products-listing.list-productlisting .item-nav','z-index','9','','','.b-products-listing'),(493520,'furniture-mobile','.w-compare ','z-index','100','','','.w-compare'),(493521,'furniture-mobile','.w-sample .cart-box','z-index','100','','','.w-sample'),(493522,'furniture-mobile','.w-sample .cart-box-link','z-index','1','','','.w-sample'),(493523,'furniture-mobile','.w-account-personal-catalog .list-row-action ul','z-index','1','','','.w-account-personal-catalog'),(493524,'furniture-mobile','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','z-index','1','','','.w-account-personal-catalog'),(493525,'furniture-mobile','.w-wedding-registry-widgets-photos .avatar-box','z-index','1','','','.w-wedding-registry-widgets-photos'),(493526,'furniture-mobile','.w-product-properties-icons .hover-box:hover .hover-box-content','z-index','9','','','.w-product-properties-icons'),(493527,'furniture-mobile','.w-wedding-registry-widgets-products .remove','z-index','2','','','.w-wedding-registry-widgets-products'),(493528,'furniture-mobile','.w-product-designer-designer .productDesignerBox input','z-index','1','','','.w-product-designer-designer'),(493529,'furniture-mobile','.w-predefined-promotion .prom-multi-discount .promo-range','z-index','1','','','.w-predefined-promotion'),(493530,'furniture-mobile','.w-predefined-promotion .promo-cart-discount .slave .condition','z-index','1','','','.w-predefined-promotion'),(493531,'furniture-mobile','.w-search .background','z-index','100','','','.w-search'),(493532,'furniture-mobile','.w-search .opened','z-index','2','3','','.w-search'),(493533,'furniture-mobile','.w-search form','z-index','101','','','.w-search'),(493534,'furniture-mobile','.w-search .products','z-index','2','','','.w-search'),(493535,'furniture-mobile','.checkout-success-wrap .page-success','z-index','-1','','','.checkout-success-wrap'),(493536,'furniture-mobile','.checkout-success-wrap .page-success > div','z-index','1','','','.checkout-success-wrap'),(493587,'furniture-mobile','.w-checkout-totals .price-row','align-items','center','','','.w-checkout-totals'),(493588,'furniture-mobile','.w-checkout-totals .price-row','justify-content','space-between','','','.w-checkout-totals'),(493589,'furniture-mobile','.w-checkout-totals .price-row','display','flex','','','.w-checkout-totals'),(493699,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','height','auto','','','.b-multi-page-checkout'),(493700,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','height_important','important','','','.b-multi-page-checkout'),(493701,'furniture-mobile','.b-multi-page-checkout .messageBox .info','text-align','left','','','.b-multi-page-checkout'),(493702,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout','padding-top','20','','','.b-multi-page-checkout'),(493703,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading','color','$color-font-7','','','.b-multi-page-checkout'),(493704,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','background-color','$background-2','','','.b-multi-page-checkout'),(493705,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','color','$color-font-1','','','.b-multi-page-checkout'),(493706,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(493707,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(493708,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(493709,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(493710,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-color','$border-color-5','','','.b-multi-page-checkout'),(493711,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-color','$border-color-5','','','.b-multi-page-checkout'),(493712,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-color','$border-color-5','','','.b-multi-page-checkout'),(493713,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-color','$border-color-5','','','.b-multi-page-checkout'),(493714,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-top','0','','','.b-multi-page-checkout'),(493715,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-right','0','','','.b-multi-page-checkout'),(493716,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-bottom','0','','','.b-multi-page-checkout'),(493717,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','padding-left','0','','','.b-multi-page-checkout'),(493718,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-top','0','','','.b-multi-page-checkout'),(493719,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-right','0','','','.b-multi-page-checkout'),(493720,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-bottom','0','','','.b-multi-page-checkout'),(493721,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .buttons','margin-left','0','','','.b-multi-page-checkout'),(493722,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','border-top-width','1','','','.b-multi-page-checkout'),(493723,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-top','20','','','.b-multi-page-checkout'),(493724,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-right','10','','','.b-multi-page-checkout'),(493725,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-bottom','20','','','.b-multi-page-checkout'),(493726,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-left','10','','','.b-multi-page-checkout'),(493727,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','clear','both','4','','.b-multi-page-checkout'),(493728,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','content','\\_','4','','.b-multi-page-checkout'),(493729,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','display','block','4','','.b-multi-page-checkout'),(493730,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','color','$color-font-3','','','.b-multi-page-checkout'),(493731,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-size','24','','','.b-multi-page-checkout'),(493732,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','text-transform','uppercase','','','.b-multi-page-checkout'),(493733,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-family','$font-1','','','.b-multi-page-checkout'),(493734,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-top','8','','','.b-multi-page-checkout'),(493735,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-right','10','','','.b-multi-page-checkout'),(493736,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-bottom','6','','','.b-multi-page-checkout'),(493737,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-left','10','','','.b-multi-page-checkout'),(493738,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','height','33','','','.b-multi-page-checkout'),(493739,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','text-align','center','','','.b-multi-page-checkout'),(493740,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','width','33','','','.b-multi-page-checkout'),(493741,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line-height','31','','','.b-multi-page-checkout'),(493742,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line_height_measure','px','','','.b-multi-page-checkout'),(493743,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','display','inline-block','','','.b-multi-page-checkout'),(493744,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(493745,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(493746,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(493747,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(493748,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-color','$border-color-4','','','.b-multi-page-checkout'),(493749,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-color','$border-color-4','','','.b-multi-page-checkout'),(493750,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-color','$border-color-4','','','.b-multi-page-checkout'),(493751,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-color','$border-color-4','','','.b-multi-page-checkout'),(493752,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-left-radius','50','','','.b-multi-page-checkout'),(493753,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_1_measure','%','','','.b-multi-page-checkout'),(493754,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-right-radius','50','','','.b-multi-page-checkout'),(493755,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_2_measure','%','','','.b-multi-page-checkout'),(493756,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-right-radius','50','','','.b-multi-page-checkout'),(493757,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_3_measure','%','','','.b-multi-page-checkout'),(493758,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-left-radius','50','','','.b-multi-page-checkout'),(493759,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_4_measure','%','','','.b-multi-page-checkout'),(493760,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading .edit','display','none','','','.b-multi-page-checkout'),(493761,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading > .block','display','inline-block','','','.b-multi-page-checkout'),(493762,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-width','1','','','.b-multi-page-checkout'),(493763,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-width','1','','','.b-multi-page-checkout'),(493764,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-width','1','','','.b-multi-page-checkout'),(493765,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-width','1','','','.b-multi-page-checkout'),(493766,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-color','$border-color-4','','','.b-multi-page-checkout'),(493767,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-color','$border-color-4','','','.b-multi-page-checkout'),(493768,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-color','$border-color-4','','','.b-multi-page-checkout'),(493769,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-color','$border-color-4','','','.b-multi-page-checkout'),(493770,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','margin-bottom','5','','','.b-multi-page-checkout'),(493771,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-step','box-shadow','0 2px 9px 0 rgba(0, 0, 0, 0.2)','2','','.b-multi-page-checkout'),(493772,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','background-color','$background-4','3','','.b-multi-page-checkout'),(493773,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','$color-font-1','3','','.b-multi-page-checkout'),(493774,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-weight','normal','3','','.b-multi-page-checkout'),(493775,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','height','35','3','','.b-multi-page-checkout'),(493776,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','text-align','center','3','','.b-multi-page-checkout'),(493777,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','vertical-align','middle','3','','.b-multi-page-checkout'),(493778,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','width','35','3','','.b-multi-page-checkout'),(493779,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line-height','35','3','','.b-multi-page-checkout'),(493780,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line_height_measure','px','3','','.b-multi-page-checkout'),(493781,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','content','\\f00c','3','','.b-multi-page-checkout'),(493782,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','display','inline-block','3','','.b-multi-page-checkout'),(493783,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-family','$font-icons-1','3','','.b-multi-page-checkout'),(493784,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-left-radius','50','3','','.b-multi-page-checkout'),(493785,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_1_measure','%','3','','.b-multi-page-checkout'),(493786,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-right-radius','50','3','','.b-multi-page-checkout'),(493787,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_2_measure','%','3','','.b-multi-page-checkout'),(493788,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-right-radius','50','3','','.b-multi-page-checkout'),(493789,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_3_measure','%','3','','.b-multi-page-checkout'),(493790,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-left-radius','50','3','','.b-multi-page-checkout'),(493791,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_4_measure','%','3','','.b-multi-page-checkout'),(493792,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','$color-font-8','','','.b-multi-page-checkout'),(493793,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .count','display','none','','','.b-multi-page-checkout'),(493794,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','$color-font-8','','','.b-multi-page-checkout'),(493795,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','cursor','pointer','','','.b-multi-page-checkout'),(493796,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','float','right','','','.b-multi-page-checkout'),(493797,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','text-transform','none','','','.b-multi-page-checkout'),(493798,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','block','','','.b-multi-page-checkout'),(493799,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','$color-font-7','4','','.b-multi-page-checkout'),(493800,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-size','0.7','4','','.b-multi-page-checkout'),(493801,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font_size_measure','em','4','','.b-multi-page-checkout'),(493802,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','position','relative','4','','.b-multi-page-checkout'),(493803,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','top','-2','4','','.b-multi-page-checkout'),(493804,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','content','\\e917','4','','.b-multi-page-checkout'),(493805,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','inline-block','4','','.b-multi-page-checkout'),(493806,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-family','trueloaded','4','','.b-multi-page-checkout'),(493807,'furniture-mobile','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','margin-left','15','4','','.b-multi-page-checkout'),(494197,'watch-mobile','body','background_color','','','',''),(494198,'watch-mobile','body','background_position','','','',''),(494199,'watch-mobile','body','background_repeat','','','',''),(494200,'watch-mobile','body','background_size','','','',''),(494201,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-heading > .block','display','inline-block','','','.b-multi-page-checkout'),(494202,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','height','100','','','.b-multi-page-checkout'),(494203,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','height_measure','%','','','.b-multi-page-checkout'),(494204,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','height_important','important','','','.b-multi-page-checkout'),(494205,'watch-mobile','.b-multi-page-checkout .multi-page-checkout .checkout-content','height_measure_important','important','','','.b-multi-page-checkout'),(884224,'splash','.scale img','-moz-box-shadow','-1px -1px 21px 0px rgba(255, 255, 255, 0.1)','','','.scale'),(884225,'splash','.scale img','-webkit-box-shadow','-1px -1px 21px 0px rgba(255, 255, 255, 0.1)','','','.scale'),(884226,'splash','.w-banner .banner-item.text-bottom-center .banner-text','align-items','end','','','.w-banner'),(884227,'splash','.w-banner .banner-item.text-bottom-left .banner-text','align-items','end','','','.w-banner'),(884228,'splash','.w-banner .banner-item.text-bottom-right .banner-text','align-items','end','','','.w-banner'),(884229,'splash','.w-banner .banner-item.text-middle-center .banner-text','align-items','center','','','.w-banner'),(884230,'splash','.w-banner .banner-item.text-middle-left .banner-text','align-items','center','','','.w-banner'),(884231,'splash','.w-banner .banner-item.text-middle-right .banner-text','align-items','center','','','.w-banner'),(884232,'splash','.w-banner .banner-item.text-top-center .banner-text','align-items','start','','','.w-banner'),(884233,'splash','.w-banner .banner-item.text-top-left .banner-text','align-items','start','','','.w-banner'),(884234,'splash','.w-banner .banner-item.text-top-right .banner-text','align-items','start','','','.w-banner'),(884235,'splash','.b-slick .slick-dots li','background-color','#cccccc','3','','.b-slick'),(884236,'splash','.b-slick .slick-dots li.slick-active','background-color','#212121','3','','.b-slick'),(884237,'splash','.mainbg ','background-repeat','repeat-y','','(max-height:850px)','.mainbg'),(884238,'splash','.mainbg ','background-repeat_important','important','','(max-height:850px)','.mainbg'),(884239,'splash','.mainbg ','background-size','cover','','','.mainbg'),(884240,'splash','.mainbg ','background-size','auto','','(max-height:850px)','.mainbg'),(884241,'splash','.mainbg ','background-size_important','important','','','.mainbg'),(884242,'splash','.mainbg ','background-size_important','important','','(max-height:850px)','.mainbg'),(884243,'splash','.scale img','border-bottom-left-radius','10','','','.scale'),(884244,'splash','.b-slick .slick-dots li','border-bottom-left-radius','50','3','','.b-slick'),(884245,'splash','.scale img','border-bottom-right-radius','10','','','.scale'),(884246,'splash','.b-slick .slick-dots li','border-bottom-right-radius','50','3','','.b-slick'),(884247,'splash','.scale img','border-top-left-radius','10','','','.scale'),(884248,'splash','.b-slick .slick-dots li','border-top-left-radius','50','3','','.b-slick'),(884249,'splash','.scale img','border-top-right-radius','10','','','.scale'),(884250,'splash','.b-slick .slick-dots li','border-top-right-radius','50','3','','.b-slick'),(884251,'splash','.scale img','border_radius_1_measure','px','','','.scale'),(884252,'splash','.b-slick .slick-dots li','border_radius_1_measure','%','3','','.b-slick'),(884253,'splash','.scale img','border_radius_2_measure','px','','','.scale'),(884254,'splash','.b-slick .slick-dots li','border_radius_2_measure','%','3','','.b-slick'),(884255,'splash','.scale img','border_radius_3_measure','px','','','.scale'),(884256,'splash','.b-slick .slick-dots li','border_radius_3_measure','%','3','','.b-slick'),(884257,'splash','.scale img','border_radius_4_measure','px','','','.scale'),(884258,'splash','.b-slick .slick-dots li','border_radius_4_measure','%','3','','.b-slick'),(884259,'splash','.scale img','box-shadow','-1px -1px 21px 0px rgba(255, 255, 255, 0.1)','','','.scale'),(884260,'splash','.b-form .captcha-holder','clear','both','','','.b-form'),(884261,'splash','.b-info .danger-message','color','$attention-color','','','.b-info'),(884262,'splash','.b-info .info-message','color','$message-color','','','.b-info'),(884263,'splash','.b-info .success-message','color','$success-color','','','.b-info'),(884264,'splash','.b-info .warning-message','color','$warning-color','','','.b-info'),(884265,'splash','.b-slick .slick-dots li','content','\\_','3','','.b-slick'),(884266,'splash','.b-slick .slick-dots li','cursor','pointer','','','.b-slick'),(884267,'splash','.b-slick .slick-dots','display','flex','','','.b-slick'),(884268,'splash','.b-slick .slick-dots li','display','block','3','','.b-slick'),(884269,'splash','.b-slick .slick-dots button','display','none','','','.b-slick'),(884270,'splash','.w-banner .banner-item','display','grid','','','.w-banner'),(884271,'splash','.w-banner .banner-text','display','flex','','','.w-banner'),(884272,'splash','.w-categories .categories','display','flex','','','.w-categories'),(884273,'splash','.b-form .captcha-holder','display','flex','','','.b-form'),(884274,'splash','.w-categories .categories','flex-wrap','wrap','','','.w-categories'),(884275,'splash','.mainbg h1','font-size','24','','','.mainbg'),(884276,'splash','.mainbg h1','font-size','18','5109','','.mainbg'),(884277,'splash','.w-banner .banner-image','grid-column','1','','','.w-banner'),(884278,'splash','.w-banner .banner-text','grid-column','1','','','.w-banner'),(884279,'splash','.w-banner .banner-image','grid-row','1','','','.w-banner'),(884280,'splash','.w-banner .banner-item.text-bottom-text .banner-text','grid-row','2','','','.w-banner'),(884281,'splash','.w-banner .banner-text','grid-row','1','','','.w-banner'),(884282,'splash','.mainbg ','height','auto','5108','','.mainbg'),(884283,'splash','.mainbg ','height','auto','','(max-height:850px)','.mainbg'),(884284,'splash','.mainbg ','height','100','','','.mainbg'),(884285,'splash','.b-slick .slick-dots li','height','10','3','','.b-slick'),(884286,'splash','.mainbg ','height_important','important','5108','','.mainbg'),(884287,'splash','.mainbg ','height_important','important','','(max-height:850px)','.mainbg'),(884288,'splash','.mainbg ','height_measure','vh','','','.mainbg'),(884289,'splash','.b-slick .slick-dots','justify-content','center','','','.b-slick'),(884290,'splash','.w-banner .banner-item.text-bottom-center .banner-text','justify-content','center','','','.w-banner'),(884291,'splash','.w-banner .banner-item.text-bottom-left .banner-text','justify-content','start','','','.w-banner'),(884292,'splash','.w-banner .banner-item.text-bottom-right .banner-text','justify-content','end','','','.w-banner'),(884293,'splash','.w-banner .banner-item.text-middle-center .banner-text','justify-content','center','','','.w-banner'),(884294,'splash','.w-banner .banner-item.text-middle-left .banner-text','justify-content','start','','','.w-banner'),(884295,'splash','.w-banner .banner-item.text-middle-right .banner-text','justify-content','end','','','.w-banner'),(884296,'splash','.w-banner .banner-item.text-top-center .banner-text','justify-content','center','','','.w-banner'),(884297,'splash','.w-banner .banner-item.text-top-left .banner-text','justify-content','start','','','.w-banner'),(884298,'splash','.w-banner .banner-item.text-top-right .banner-text','justify-content','end','','','.w-banner'),(884299,'splash','.b-slick .slick-dots','list-style','none','','','.b-slick'),(884300,'splash','.mainbg h1','margin-bottom','10','','','.mainbg'),(884301,'splash','.scale img','margin-bottom','0','5109','','.scale'),(884302,'splash','.b-slick .slick-dots li','margin-bottom','0','','','.b-slick'),(884303,'splash','.mainbg h1','margin-left','0','','','.mainbg'),(884304,'splash','.scale img','margin-left','5','5109','','.scale'),(884305,'splash','.b-slick .slick-dots li','margin-left','5','','','.b-slick'),(884306,'splash','.mainbg h1','margin-right','0','','','.mainbg'),(884307,'splash','.scale img','margin-right','5','5109','','.scale'),(884308,'splash','.b-slick .slick-dots li','margin-right','5','','','.b-slick'),(884309,'splash','.mainbg h1','margin-top','0','','','.mainbg'),(884310,'splash','.scale img','margin-top','0','5109','','.scale'),(884311,'splash','.b-slick .slick-dots li','margin-top','0','','','.b-slick'),(884312,'splash','.scale img','margin_left_measure','%','5109','','.scale'),(884313,'splash','.scale img','margin_right_measure','%','5109','','.scale'),(884314,'splash','.scale img','max-height','37','','','.scale'),(884315,'splash','.scale img','max-width','350','','','.scale'),(884316,'splash','.scale img','max-width','90','5109','','.scale'),(884317,'splash','.w-banner .banner-item.text-bottom-text .banner-text-holder','max-width','100','','','.w-banner'),(884318,'splash','.w-banner .banner-text-holder','max-width','500','','','.w-banner'),(884319,'splash','.scale img','max_height_measure','vh','','','.scale'),(884320,'splash','.scale img','max_width_measure','%','5109','','.scale'),(884321,'splash','.w-banner .banner-item.text-bottom-text .banner-text-holder','max_width_measure','%','','','.w-banner'),(884322,'splash','.b-slick .slick-dots li','padding-bottom','5','','','.b-slick'),(884323,'splash','.w-banner .banner-text','padding-bottom','20','','','.w-banner'),(884324,'splash','.b-slick .slick-dots li','padding-left','5','','','.b-slick'),(884325,'splash','.w-banner .banner-text','padding-left','20','','','.w-banner'),(884326,'splash','.b-slick .slick-dots li','padding-right','5','','','.b-slick'),(884327,'splash','.w-banner .banner-text','padding-right','20','','','.w-banner'),(884328,'splash','.b-slick .slick-dots li','padding-top','5','','','.b-slick'),(884329,'splash','.w-banner .banner-text','padding-top','20','','','.w-banner'),(884330,'splash','.scale img','transform','scale(1.1)','1','','.scale'),(884331,'splash','.scale img','transition','0.5s','','','.scale'),(884332,'splash','.b-slick .slick-dots li','width','10','3','','.b-slick'),(884333,'splash','.w-banner .banner-text-holder','width','100','','','.w-banner'),(884334,'splash','.w-banner video','width','100','','','.w-banner'),(884335,'splash','.b-form .captcha-holder','width','48','','','.b-form'),(884336,'splash','.w-banner .banner-text-holder','width_measure','%','','','.w-banner'),(884337,'splash','.w-banner video','width_measure','%','','','.w-banner'),(884338,'splash','.b-form .captcha-holder','width_measure','%','','','.b-form'),(884339,'splash','.w-banner .banner-text','z-index','1','','','.w-banner'),(884340,'splash-mobile','.w-banner .banner-item.text-bottom-center .banner-text','align-items','end','','','.w-banner'),(884341,'splash-mobile','.w-banner .banner-item.text-bottom-left .banner-text','align-items','end','','','.w-banner'),(884342,'splash-mobile','.w-banner .banner-item.text-bottom-right .banner-text','align-items','end','','','.w-banner'),(884343,'splash-mobile','.w-banner .banner-item.text-middle-center .banner-text','align-items','center','','','.w-banner'),(884344,'splash-mobile','.w-banner .banner-item.text-middle-left .banner-text','align-items','center','','','.w-banner'),(884345,'splash-mobile','.w-banner .banner-item.text-middle-right .banner-text','align-items','center','','','.w-banner'),(884346,'splash-mobile','.w-banner .banner-item.text-top-center .banner-text','align-items','start','','','.w-banner'),(884347,'splash-mobile','.w-banner .banner-item.text-top-left .banner-text','align-items','start','','','.w-banner'),(884348,'splash-mobile','.w-banner .banner-item.text-top-right .banner-text','align-items','start','','','.w-banner'),(884349,'splash-mobile','.b-slick .slick-dots li','background-color','#cccccc','3','','.b-slick'),(884350,'splash-mobile','.b-slick .slick-dots li.slick-active','background-color','#212121','3','','.b-slick'),(884351,'splash-mobile','.b-slick .slick-dots li','border-bottom-left-radius','50','3','','.b-slick'),(884352,'splash-mobile','.b-slick .slick-dots li','border-bottom-right-radius','50','3','','.b-slick'),(884353,'splash-mobile','.b-slick .slick-dots li','border-top-left-radius','50','3','','.b-slick'),(884354,'splash-mobile','.b-slick .slick-dots li','border-top-right-radius','50','3','','.b-slick'),(884355,'splash-mobile','.b-slick .slick-dots li','border_radius_1_measure','%','3','','.b-slick'),(884356,'splash-mobile','.b-slick .slick-dots li','border_radius_2_measure','%','3','','.b-slick'),(884357,'splash-mobile','.b-slick .slick-dots li','border_radius_3_measure','%','3','','.b-slick'),(884358,'splash-mobile','.b-slick .slick-dots li','border_radius_4_measure','%','3','','.b-slick'),(884359,'splash-mobile','.b-info .danger-message','color','$attention-color','','','.b-info'),(884360,'splash-mobile','.b-info .info-message','color','$message-color','','','.b-info'),(884361,'splash-mobile','.b-info .success-message','color','$success-color','','','.b-info'),(884362,'splash-mobile','.b-info .warning-message','color','$warning-color','','','.b-info'),(884363,'splash-mobile','.b-slick .slick-dots li','content','\\_','3','','.b-slick'),(884364,'splash-mobile','.b-slick .slick-dots li','cursor','pointer','','','.b-slick'),(884365,'splash-mobile','.b-slick .slick-dots','display','flex','','','.b-slick'),(884366,'splash-mobile','.b-slick .slick-dots li','display','block','3','','.b-slick'),(884367,'splash-mobile','.b-slick .slick-dots button','display','none','','','.b-slick'),(884368,'splash-mobile','.w-banner .banner-item','display','grid','','','.w-banner'),(884369,'splash-mobile','.w-banner .banner-text','display','flex','','','.w-banner'),(884370,'splash-mobile','.w-banner .banner-image','grid-column','1','','','.w-banner'),(884371,'splash-mobile','.w-banner .banner-text','grid-column','1','','','.w-banner'),(884372,'splash-mobile','.w-banner .banner-image','grid-row','1','','','.w-banner'),(884373,'splash-mobile','.w-banner .banner-item.text-bottom-text .banner-text','grid-row','2','','','.w-banner'),(884374,'splash-mobile','.w-banner .banner-text','grid-row','1','','','.w-banner'),(884375,'splash-mobile','.b-slick .slick-dots li','height','10','3','','.b-slick'),(884376,'splash-mobile','.b-slick .slick-dots','justify-content','center','','','.b-slick'),(884377,'splash-mobile','.w-banner .banner-item.text-bottom-center .banner-text','justify-content','center','','','.w-banner'),(884378,'splash-mobile','.w-banner .banner-item.text-bottom-left .banner-text','justify-content','start','','','.w-banner'),(884379,'splash-mobile','.w-banner .banner-item.text-bottom-right .banner-text','justify-content','end','','','.w-banner'),(884380,'splash-mobile','.w-banner .banner-item.text-middle-center .banner-text','justify-content','center','','','.w-banner'),(884381,'splash-mobile','.w-banner .banner-item.text-middle-left .banner-text','justify-content','start','','','.w-banner'),(884382,'splash-mobile','.w-banner .banner-item.text-middle-right .banner-text','justify-content','end','','','.w-banner'),(884383,'splash-mobile','.w-banner .banner-item.text-top-center .banner-text','justify-content','center','','','.w-banner'),(884384,'splash-mobile','.w-banner .banner-item.text-top-left .banner-text','justify-content','start','','','.w-banner'),(884385,'splash-mobile','.w-banner .banner-item.text-top-right .banner-text','justify-content','end','','','.w-banner'),(884386,'splash-mobile','.b-slick .slick-dots','list-style','none','','','.b-slick'),(884387,'splash-mobile','.b-slick .slick-dots li','margin-bottom','0','','','.b-slick'),(884388,'splash-mobile','.b-slick .slick-dots li','margin-left','5','','','.b-slick'),(884389,'splash-mobile','.b-slick .slick-dots li','margin-right','5','','','.b-slick'),(884390,'splash-mobile','.b-slick .slick-dots li','margin-top','0','','','.b-slick'),(884391,'splash-mobile','.w-banner .banner-item.text-bottom-text .banner-text-holder','max-width','100','','','.w-banner'),(884392,'splash-mobile','.w-banner .banner-text-holder','max-width','500','','','.w-banner'),(884393,'splash-mobile','.w-banner .banner-item.text-bottom-text .banner-text-holder','max_width_measure','%','','','.w-banner'),(884394,'splash-mobile','.b-slick .slick-dots li','padding-bottom','5','','','.b-slick'),(884395,'splash-mobile','.w-banner .banner-text','padding-bottom','20','','','.w-banner'),(884396,'splash-mobile','.b-slick .slick-dots li','padding-left','5','','','.b-slick'),(884397,'splash-mobile','.w-banner .banner-text','padding-left','20','','','.w-banner'),(884398,'splash-mobile','.b-slick .slick-dots li','padding-right','5','','','.b-slick'),(884399,'splash-mobile','.w-banner .banner-text','padding-right','20','','','.w-banner'),(884400,'splash-mobile','.b-slick .slick-dots li','padding-top','5','','','.b-slick'),(884401,'splash-mobile','.w-banner .banner-text','padding-top','20','','','.w-banner'),(884402,'splash-mobile','.b-slick .slick-dots li','width','10','3','','.b-slick'),(884403,'splash-mobile','.w-banner .banner-text-holder','width','100','','','.w-banner'),(884404,'splash-mobile','.w-banner video','width','100','','','.w-banner'),(884405,'splash-mobile','.w-banner .banner-text-holder','width_measure','%','','','.w-banner'),(884406,'splash-mobile','.w-banner video','width_measure','%','','','.w-banner'),(884407,'splash-mobile','.w-banner .banner-text','z-index','1','','','.w-banner'),(884872,'furniture','.b-slick .slick-slider','-khtml-user-select','none','','','.b-slick'),(884873,'furniture','.b-fancybox .fancybox-skin','-moz-border-radius','4px','','','.b-fancybox'),(884874,'furniture','.b-fancybox .fancybox-title-float-wrap .child','-moz-border-radius','15px','','','.b-fancybox'),(884875,'furniture','.b-fancybox .fancybox-opened .fancybox-skin','-moz-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(884876,'furniture','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-moz-box-sizing','border-box','','','.b-select-suggest'),(884877,'furniture','.b-rating .glyphicon','-moz-osx-font-smoothing','grayscale','','','.b-rating'),(884878,'furniture','.b-products-listing .hover-box-content','-moz-transform','rotate( 45deg )','3','','.b-products-listing'),(884879,'furniture','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-moz-transform','translate3d(0, 0, 0)','','','.b-slick'),(884880,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-moz-user-select','none','','','.b-select-suggest'),(884881,'furniture','.b-select-suggest .select2-container .select2-choice','-moz-user-select','none','','','.b-select-suggest'),(884882,'furniture','.b-select-suggest .select2-results .select2-result-label','-moz-user-select','none','','','.b-select-suggest'),(884883,'furniture','.b-slick .slick-slider','-moz-user-select','none','','','.b-slick'),(884884,'furniture','.b-slick .slick-slider','-ms-touch-action','pan-y','','','.b-slick'),(884885,'furniture','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(884886,'furniture','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(884887,'furniture','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(884888,'furniture','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(884889,'furniture','.b-products-listing .hover-box-content','-ms-transform','rotate( 45deg )','3','','.b-products-listing'),(884891,'furniture','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-ms-transform','translate3d(0, 0, 0)','','','.b-slick'),(884893,'furniture','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(884894,'furniture','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(884895,'furniture','.w-sample .cart-box-link','-ms-transform','rotate(45deg)','4','','.w-sample'),(884896,'furniture','.b-select-suggest .select2-container .select2-choice','-ms-user-select','none','','','.b-select-suggest'),(884897,'furniture','.b-select-suggest .select2-results .select2-result-label','-ms-user-select','none','','','.b-select-suggest'),(884898,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-ms-user-select','none','','','.b-select-suggest'),(884899,'furniture','.b-slick .slick-slider','-ms-user-select','none','','','.b-slick'),(884900,'furniture','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-o-transform','translate3d(0, 0, 0)','','','.b-slick'),(884901,'furniture','.b-fancybox .fancybox-title-float-wrap .child','-webkit-border-radius','15px','','','.b-fancybox'),(884902,'furniture','.b-fancybox .fancybox-skin','-webkit-border-radius','4px','','','.b-fancybox'),(884903,'furniture','.b-fancybox .fancybox-opened .fancybox-skin','-webkit-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(884904,'furniture','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-webkit-box-sizing','border-box','','','.b-select-suggest'),(884905,'furniture','.b-rating .glyphicon','-webkit-font-smoothing','antialiased','','','.b-rating'),(884906,'furniture','.b-fancybox .fancybox-type-iframe .fancybox-inner','-webkit-overflow-scrolling','touch','','','.b-fancybox'),(884907,'furniture','.b-fancybox .fancybox-nav','-webkit-tap-highlight-color','rgba(0,0,0,0)','','','.b-fancybox'),(884908,'furniture','.b-select-suggest .select2-results','-webkit-tap-highlight-color','rgba(0, 0, 0, 0)','','','.b-select-suggest'),(884909,'furniture','.b-slick .slick-slider','-webkit-tap-highlight-color','transparent','','','.b-slick'),(884910,'furniture','.b-select-suggest .select2-container .select2-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(884911,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(884912,'furniture','.b-select-suggest .select2-results .select2-result-label','-webkit-touch-callout','none','','','.b-select-suggest'),(884913,'furniture','.b-slick .slick-slider','-webkit-touch-callout','none','','','.b-slick'),(884914,'furniture','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(884915,'furniture','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(884916,'furniture','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(884917,'furniture','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(884918,'furniture','.b-products-listing .hover-box-content','-webkit-transform','rotate( 45deg )','3','','.b-products-listing'),(884920,'furniture','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-webkit-transform','translate3d(0, 0, 0)','','','.b-slick'),(884922,'furniture','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(884923,'furniture','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(884924,'furniture','.w-sample .cart-box-link','-webkit-transform','rotate(45deg)','4','','.w-sample'),(884925,'furniture','.b-select-suggest .select2-container .select2-choice','-webkit-user-select','none','','','.b-select-suggest'),(884926,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-user-select','none','','','.b-select-suggest'),(884927,'furniture','.b-select-suggest .select2-results .select2-result-label','-webkit-user-select','none','','','.b-select-suggest'),(884928,'furniture','.b-slick .slick-slider','-webkit-user-select','none','','','.b-slick'),(884929,'furniture','.w-promotions .promo-cart-discount','align-items','flex-start','','','.w-promotions'),(884930,'furniture','.b-messages .email-line','align-items','center','','','.b-messages'),(884931,'furniture','.p-quick-order-index .quick-order-total','align-items','center','','','.p-quick-order-index'),(884932,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(884933,'furniture','.b-products-listing .select-attributes','align-items','center','','','.b-products-listing'),(884934,'furniture','.order-summary .price-row','align-items','baseline','','','.order-summary'),(884935,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(884936,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(884937,'furniture','.w-personal-gift-status-bar .timeline','align-items','center','','','.w-personal-gift-status-bar'),(884938,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(884939,'furniture','.b-products-listing .products-listing .attribute-qty-block','align-items','center','','','.b-products-listing'),(884940,'furniture','.b-products-listing .promos-info .promo-item','align-items','center','','','.b-products-listing'),(884941,'furniture','.w-taxable form','align-items','center','','','.w-taxable'),(884942,'furniture','.w-cart-listing .item .gift-wrap label','align-items','center','','','.w-cart-listing'),(884943,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(884944,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(884945,'furniture','.b-product-images .media-popup .mp-big-images .item','align-items','center','','','.b-product-images'),(884946,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(884947,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .languages','align-items','center','','','.b-menu-style-2'),(884948,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','align-items','center','','','.b-menu-style-2'),(884949,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies','align-items','center','','','.b-menu-style-2'),(884950,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','align-items','center','','','.b-menu-style-2'),(884951,'furniture','.w-account-subscription .subscription-variant','align-items','center','','','.w-account-subscription'),(884952,'furniture','.w-catalog-compare .cross-box .different-all','align-items','flex-end','','','.w-catalog-compare'),(884953,'furniture','.w-product-images .img-holder','align-items','center','','','.w-product-images'),(884956,'furniture','.w-quote .cart-box-link','align-items','center','','','.w-quote'),(884957,'furniture','.w-product-images .additional-vertical','align-items','stretch','','','.w-product-images'),(884958,'furniture','.w-files-catalog-widgets-files-catalog .image','align-items','center','','','.w-files-catalog-widgets-files-catalog'),(884959,'furniture','.w-sample .cart-box-link','align-items','center','','','.w-sample'),(884960,'furniture','.w-filters-simple .filter-row','align-items','flex-end','','','.w-filters-simple'),(884961,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(884962,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(884963,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(884964,'furniture','.w-predefined-promotion .promo-cart-discount','align-items','flex-start','','','.w-predefined-promotion'),(884965,'furniture','.w-supplier-purchase-supplier-products .item','align-items','center','','','.w-supplier-purchase-supplier-products'),(884966,'furniture','.w-supplier-purchase-supplier-products .qty_col','align-items','center','','','.w-supplier-purchase-supplier-products'),(884967,'furniture','.w-product-quantity-discounts .item','align-items','center','','','.w-product-quantity-discounts'),(884969,'furniture','.checkout-order-confirmation .price-row','align-items','baseline','','','.checkout-order-confirmation'),(884970,'furniture','.w-checkout-totals .price-row','align-items','center','','','.w-checkout-totals'),(884971,'furniture','.success-page .order_totals .price-row','align-items','baseline','','','.success-page'),(884972,'furniture','.success-page .price-row','align-items','baseline','','','.success-page'),(884973,'furniture','.mainBanner .w-banner .banner-text-holder','align-items','center','','','.mainBanner'),(884974,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','align-items','center','','','.menu-header'),(884975,'furniture','.w-account-customer-additional-field .field-type-text','align-items','center','','','.w-account-customer-additional-field'),(884976,'furniture','.w-banner .banner-item.text-bottom-center .banner-text','align-items','end','','','.w-banner'),(884977,'furniture','.w-banner .banner-item.text-bottom-left .banner-text','align-items','end','','','.w-banner'),(884978,'furniture','.w-banner .banner-item.text-bottom-right .banner-text','align-items','end','','','.w-banner'),(884979,'furniture','.w-banner .banner-item.text-middle-center .banner-text','align-items','center','','','.w-banner'),(884980,'furniture','.w-banner .banner-item.text-middle-left .banner-text','align-items','center','','','.w-banner'),(884981,'furniture','.w-banner .banner-item.text-middle-right .banner-text','align-items','center','','','.w-banner'),(884982,'furniture','.w-banner .banner-item.text-top-center .banner-text','align-items','start','','','.w-banner'),(884983,'furniture','.w-banner .banner-item.text-top-left .banner-text','align-items','start','','','.w-banner'),(884984,'furniture','.w-banner .banner-item.text-top-right .banner-text','align-items','start','','','.w-banner'),(884985,'furniture','.w-banner .carousel .bottom-center','align-items','flex-end','','','.w-banner'),(884986,'furniture','.w-banner .carousel .bottom-left','align-items','flex-end','','','.w-banner'),(884987,'furniture','.w-banner .carousel .bottom-right','align-items','flex-end','','','.w-banner'),(884988,'furniture','.w-banner .carousel .middle-center','align-items','center','','','.w-banner'),(884989,'furniture','.w-banner .carousel .middle-left','align-items','center','','','.w-banner'),(884990,'furniture','.w-banner .carousel .middle-right','align-items','center','','','.w-banner'),(884991,'furniture','.w-banner .carousel .top-center','align-items','flex-start','','','.w-banner'),(884992,'furniture','.w-banner .carousel .top-left','align-items','flex-start','','','.w-banner'),(884993,'furniture','.w-banner .carousel .top-right','align-items','flex-start','','','.w-banner'),(884994,'furniture','.w-cart-listing .remove','align-self','center','','','.w-cart-listing'),(884995,'furniture','.b-preloader .preloader','animation','load8 1.5s infinite linear','3','','.b-preloader'),(884996,'furniture','.w-product-customers-activity .customers-activity','animation','customers-activity-show 4s ease-in-out','','','.w-product-customers-activity'),(884997,'furniture','.w-product-customers-activity .customers-activity.closed','animation','customers-activity-hide 2s ease-in-out','','','.w-product-customers-activity'),(884998,'furniture','.b-products-listing .btn-preloader','animation','load8 1.5s infinite linear','3','','.b-products-listing'),(884999,'furniture','.b-products-listing .loader','animation','load8 1.5s infinite linear','4','','.b-products-listing'),(885000,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.p-quick-order-index'),(885001,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(885002,'furniture','.b-fancybox .fancybox-title-float-wrap .child','background','transparent','','','.b-fancybox'),(885003,'furniture','.w-filters .ui-slider','background','none','','','.w-filters'),(885004,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','background','none','','','.b-select-suggest'),(885005,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.p-quick-order-index'),(885006,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(885007,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(885008,'furniture','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','background','none','','','.b-products-listing'),(885009,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(885010,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background','transparent','','','.b-select-suggest'),(885011,'furniture','.b-select-suggest .select2-results .select2-highlighted em','background','transparent','','','.b-select-suggest'),(885012,'furniture','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','background','transparent','','','.b-select-suggest'),(885013,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(885014,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.b-data-table'),(885015,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(885016,'furniture','.w-filters .ui-slider-range','background','none','','','.w-filters'),(885017,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.b-data-table'),(885018,'furniture','.w-top-categories .categories h2','background','none','','','.w-top-categories'),(885019,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','background','none','','','.b-product-images'),(885020,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','background','none','','','.b-menu-style-2'),(885021,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','background','none','','','.b-menu-style-2'),(885022,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','background','none','','','.w-catalog-compare'),(885023,'furniture','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','background','none','','','.b-products-listing'),(885024,'furniture','.b-products-listing .products-listing a.btn.view-button','background','none','','','.b-products-listing'),(885025,'furniture','.w-product-personal-catalog-button .btn','background','none','','','.w-product-personal-catalog-button'),(885026,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','background','none','','','.b-products-listing'),(885027,'furniture','.w-product-designer-designer .prodDesignerType','background','none','','','.w-product-designer-designer'),(885028,'furniture','.w-communication-post .btn.refresh','background','none','','','.w-communication-post'),(885029,'furniture','.w-rma-returns-history .column:last-child .title','background','transparent','','','.w-rma-returns-history'),(885030,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','background','none','','','.w-rma-returns-history'),(885031,'furniture','.mainBanner .bottomBox .btn','background','none','','','.mainBanner'),(885032,'furniture','.mainBanner .topBox > .right','background','linear-gradient( 90deg, rgba(200,199,212,1) 0%, rgba(181,186,205,1) 22%, rgba(193,193,207,1) 50%, rgba(173,177,197,1) 100%)','','','.mainBanner'),(885033,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','background','none','','','.w-promotions-widgets-promotion-icons-desc'),(885034,'furniture','.lowestPricedBox .w-banner .ybg .btn','background','none','','','.lowestPricedBox'),(885035,'furniture','.b-select-suggest .select2-container .select2-choice','background-clip','padding-box','','','.b-select-suggest'),(885036,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','background-clip','padding-box','','','.b-select-suggest'),(885037,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow','background-clip','padding-box','','','.b-select-suggest'),(885038,'furniture','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(885039,'furniture','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(885040,'furniture','.b-fancybox .filter-listing-loader','background-color','$fancybox-bg-1','','','.b-fancybox'),(885041,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','$content-bg-2','','','.p-quick-order-index'),(885042,'furniture','.w-promotions .promo-item','background-color','$content-bg-2','','','.w-promotions'),(885044,'furniture','.testimonials .review','background-color','$content-bg-2','','',''),(885045,'furniture','.w-chat .w-chat-box','background-color','$highlight-box-bg-2','','','.w-chat'),(885046,'furniture','.w-promotions .prom-multi-discount .promo-range','background-color','$content-bg-1','','','.w-promotions'),(885047,'furniture','.w-promotions .prom-multi-discount .promo-product','background-color','$content-bg-1','','','.w-promotions'),(885048,'furniture','.w-promotions .nextdiscount .promo-for-each','background-color','$content-bg-2','','','.w-promotions'),(885049,'furniture','.w-promotions .nextdiscount .content > div','background-color','$content-bg-1','','','.w-promotions'),(885050,'furniture','.w-promotions .promo-salemaker .item','background-color','$content-bg-1','','','.w-promotions'),(885051,'furniture','.w-promotions .promo-salemaker .discount','background-color','$content-bg-1','','','.w-promotions'),(885052,'furniture','.w-promotions .promo-cart-discount .slave .item','background-color','$content-bg-1','','','.w-promotions'),(885053,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','background-color','$content-bg-1','','','.w-promotions'),(885054,'furniture','.b-preloader .preloader','background-color','$content-bg-1','','','.b-preloader'),(885055,'furniture','.w-cart-compare .attributes-cell','background-color','$highlight-box-bg-1','','','.w-cart-compare'),(885056,'furniture','.w-cart-checkout-btn + .w-image','background-color','$content-bg-2','','','.w-cart-checkout-btn'),(885057,'furniture','.b-messages .msv_history','background-color','$content-bg-2','','','.b-messages'),(885058,'furniture','.b-messages .email-heading','background-color','$content-bg-2','','','.b-messages'),(885059,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','background-color','$content-bg-2','','','.b-messages'),(885060,'furniture','.w-reviews .author','background-color','$content-bg-1','','','.w-reviews'),(885061,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.p-quick-order-index'),(885062,'furniture','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','background-color','$content-bg-2','','','.order-summary'),(885063,'furniture','.b-fancybox .fancybox-close','background-color','$fancybox-bg-1','','','.b-fancybox'),(885064,'furniture','.b-messages .msv_to_cc','background-color','$content-bg-2','','','.b-messages'),(885065,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','background-color','$transparent','3','','.b-switch'),(885066,'furniture','.w-checkout-shipping-choice input:checked + span:before','background-color','$highlight-box-bg-2','','','.w-checkout-shipping-choice'),(885067,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','background-color','$content-bg-2','','','.w-upload-customer-id-upload-customer-id-form'),(885068,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-details','background-color','$content-bg-1','','','.w-upload-customer-id-upload-customer-id-form'),(885069,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','background-color','$switch-nc-bg-1','3','','.b-switch'),(885071,'furniture','.w-menu-horizontal > ul > li > ul > li > ul','background-color','$content-bg-1','','','.w-menu-horizontal'),(885072,'furniture','.b-fancybox .fancybox-title-float-wrap .child','background-color','$fancybox-bg-1','','','.b-fancybox'),(885073,'furniture','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(885074,'furniture','.b-info-popup .info-popup div','background-color','$content-bg-1','','','.b-info-popup'),(885076,'furniture','.w-filters .ui-slider','background-color','$highlight-box-bg-2','','','.w-filters'),(885077,'furniture','.b-switch .candlestick-wrapper .candlestick-bg','background-color','$switch-nc-bg-1','','','.b-switch'),(885078,'furniture','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(885079,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-color','$content-bg-2','','','.b-select-suggest'),(885080,'furniture','.w-reviews .review','background-color','$content-bg-1','','','.w-reviews'),(885082,'furniture','.p-quick-order-index .all-scroll-div','background-color','$highlight-box-bg-2','','','.p-quick-order-index'),(885084,'furniture','.btn-1','background-color','$btn-bg-2','','',''),(885085,'furniture','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(885086,'furniture','.order-summary > div','background-color','$content-bg-1','','','.order-summary'),(885087,'furniture','.b-fancybox .fancybox-overlay','background-color','$fancybox-bg-1','','','.b-fancybox'),(885088,'furniture','.b-bottom .popup-box.popupCompare','background-color','$content-bg-2','','','.b-bottom'),(885090,'furniture','.w-checkout-billing-address .same-address','background-color','$content-bg-2','','','.w-checkout-billing-address'),(885091,'furniture','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(885092,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','background-color','$switch-off-bg-2','','','.b-switch'),(885093,'furniture','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(885094,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','background-color','$transparent','4','','.b-switch'),(885095,'furniture','.b-form .required-message','background-color','$attention-background','','','.b-form'),(885096,'furniture','.b-switch .candlestick-wrapper .candlestick-bg.off','background-color','$switch-off-bg-2','','','.b-switch'),(885097,'furniture','.b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-off','background-color','$switch-off-bg-2','3','','.b-switch'),(885098,'furniture','.b-switch .candlestick-wrapper .candlestick-bg.on','background-color','$switch-on-bg-1','','','.b-switch'),(885099,'furniture','.b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-on','background-color','$switch-off-bg-2','4','','.b-switch'),(885100,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','background-color','$switch-handle-bg-3','','','.b-switch'),(885101,'furniture','.b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-on','background-color','$switch-on-bg-1','4','','.b-switch'),(885102,'furniture','.b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-off','background-color','$switch-on-bg-1','3','','.b-switch'),(885103,'furniture','.w-product-reviews .reviews-list .review','background-color','$content-bg-2','','','.w-product-reviews'),(885104,'furniture','.b-fancybox .fancybox-skin','background-color','$fancybox-bg-1','','','.b-fancybox'),(885105,'furniture','.b-info-popup .info-popup div','background-color','$content-bg-1','3','','.b-info-popup'),(885106,'furniture','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(885107,'furniture','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(885108,'furniture','.btn','background-color','$btn-bg-1','','',''),(885109,'furniture','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(885110,'furniture','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(885111,'furniture','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','background-color','$content-bg-2','','','.b-select-suggest'),(885112,'furniture','.w-personal-gift-status-bar .timeline','background-color','$content-bg-2','','','.w-personal-gift-status-bar'),(885113,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','background-color','$switch-off-bg-2','','','.b-switch'),(885114,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label','background-color','$switch-handle-bg-3','3','','.b-switch'),(885115,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','background-color','$switch-nc-bg-1','4','','.b-switch'),(885116,'furniture','.b-form .hide-billing-address','background-color','$content-bg-1','','','.b-form'),(885117,'furniture','.w-reviews-content .author','background-color','$content-bg-2','','','.w-reviews-content'),(885119,'furniture','.w-personal-gift-status-bar .progress-bar-content','background-color','$highlight-box-bg-2','','','.w-personal-gift-status-bar'),(885120,'furniture','.w-cart-compare .price-cell','background-color','$highlight-box-bg-1','','','.w-cart-compare'),(885121,'furniture','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(885122,'furniture','.b-compare .popupCompare .pop-up-content','background-color','$content-bg-2','','','.b-compare'),(885123,'furniture','.w-promotions .promo-cart-discount .master .item','background-color','$content-bg-1','','','.w-promotions'),(885124,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','background-color','$content-bg-1','','','.w-promotions'),(885125,'furniture','.b-bottom .around-pop-up','background-color','$shadow-bg-1','','','.b-bottom'),(885126,'furniture','.w-cart-compare .price-block + .attributes-block .attributes-cell','background-color','$content-bg-1','','','.w-cart-compare'),(885127,'furniture','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(885128,'furniture','.b-bottom .pop-up-content','background-color','$content-bg-1','','','.b-bottom'),(885130,'furniture','.b-bottom .popup-box','background-color','$content-bg-1','','','.b-bottom'),(885131,'furniture','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(885132,'furniture','.w-product-customers-activity .customers-activity','background-color','$content-bg-2','','','.w-product-customers-activity'),(885134,'furniture','.w-checkout-shipping-choice input:checked + span','background-color','$highlight-box-bg-2','','','.w-checkout-shipping-choice'),(885135,'furniture','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(885136,'furniture','.b-autocomplete .ui-autocomplete li','background-color','$content-bg-2','1','','.b-autocomplete'),(885137,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label','background-color','$switch-handle-bg-3','3','','.b-switch'),(885138,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','background-color','$switch-on-bg-1','','','.b-switch'),(885139,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-color','$content-bg-2','','','.b-select-suggest'),(885140,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus','background-color','$content-bg-2','','','.b-select-suggest'),(885141,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color','$content-bg-1','','','.b-select-suggest'),(885142,'furniture','.b-select-suggest .select2-container-multi .select2-choices','background-color','$content-bg-1','','','.b-select-suggest'),(885143,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-color','$content-bg-2','','','.b-select-suggest'),(885144,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-color','$content-bg-2','','','.b-select-suggest'),(885145,'furniture','.b-select-suggest .select2-results .select2-highlighted ul','background-color','$content-bg-1','','','.b-select-suggest'),(885146,'furniture','.b-select-suggest .select2-more-results','background-color','$content-bg-2','','','.b-select-suggest'),(885147,'furniture','.b-select-suggest .select2-more-results.select2-active','background-color','$content-bg-2','','','.b-select-suggest'),(885148,'furniture','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','background-color','$content-bg-2','','','.b-select-suggest'),(885149,'furniture','.b-select-suggest .select2-results .select2-highlighted','background-color','$content-bg-2','','','.b-select-suggest'),(885150,'furniture','.b-select-suggest .select2-results .select2-disabled','background-color','$content-bg-2','','','.b-select-suggest'),(885151,'furniture','.b-select-suggest .select2-results li em','background-color','$content-bg-1','','','.b-select-suggest'),(885152,'furniture','.w-menu-horizontal > ul > li > ul','background-color','$highlight-box-bg-2','','','.w-menu-horizontal'),(885153,'furniture','.b-select-suggest .select2-search input','background-color','$content-bg-1','','','.b-select-suggest'),(885154,'furniture','.b-select-suggest .select2-search input.select2-active','background-color','$content-bg-1','','','.b-select-suggest'),(885155,'furniture','.b-select-suggest .select2-drop-mask','background-color','$content-bg-1','','','.b-select-suggest'),(885156,'furniture','.b-select-suggest .select2-drop','background-color','$content-bg-1','','','.b-select-suggest'),(885159,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','$content-bg-2','','','.b-data-table'),(885160,'furniture','.b-products-listing .loader','background-color','$content-bg-1','3','','.b-products-listing'),(885161,'furniture','.w-catalog-b2b-add-button ','background-color','$highlight-box-bg-2','','','.w-catalog-b2b-add-button'),(885162,'furniture','.b-products-listing .products-listing .qty-input.hidden','background-color','$content-bg-1','3','','.b-products-listing'),(885163,'furniture','.checkbox input:checked + span','background-color','$checkbox-bg-1','','',''),(885164,'furniture','.checkbox input + span','background-color','$checkbox-bg-1','','',''),(885165,'furniture','.b-autocomplete .ui-autocomplete','background-color','$content-bg-1','','','.b-autocomplete'),(885167,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','background-color','$switch-handle-bg-3','3','','.b-switch'),(885168,'furniture','.b-compare .compare-box-item','background-color','$content-bg-2','','','.b-compare'),(885170,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','background-color','$content-bg-1','','','.w-communication-new-topic'),(885171,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','background-color','$content-bg-1','','','.w-communication-new-topic'),(885172,'furniture','.b-datepicker .datepicker-dropdown','background-color','$content-bg-1','','','.b-datepicker'),(885173,'furniture','.b-bottom .popup-heading','background-color','$content-bg-2','','','.b-bottom'),(885174,'furniture','.w-personal-gift-status-bar .progress-bar','background-color','$content-bg-1','','','.w-personal-gift-status-bar'),(885176,'furniture','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(885177,'furniture','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(885178,'furniture','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(885179,'furniture','.b-compare .vary td','background-color','$highlight-box-bg-1','','','.b-compare'),(885182,'furniture','.b-fancybox .fancybox-nav span','background-color','$fancybox-bg-1','','','.b-fancybox'),(885183,'furniture','.w-tabs .tab-a','background-color','$tab-nav-bg-1','2','','.w-tabs'),(885186,'furniture','.w-filters .head-filter-widget','background-color','$highlight-box-bg-2','5140','','.w-filters'),(885187,'furniture','.w-filters .ui-slider-range','background-color','$highlight-box-bg-2','','','.w-filters'),(885188,'furniture','body','background-color','$content-bg-1','','',''),(885189,'furniture','.w-reviews-content .review','background-color','$content-bg-2','','','.w-reviews-content'),(885190,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.b-data-table'),(885191,'furniture','.b-compare .popupCompare table','background-color','$content-bg-1','','','.b-compare'),(885193,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','background-color','$content-bg-1','','','.w-image-maps'),(885194,'furniture','.b-product-images .mp-shadow','background-color','$image-popup-bg-1','','','.b-product-images'),(885195,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .menu-content','background-color','$header-menu-bg-1','','','.b-menu-style-2'),(885196,'furniture','.b-trade-approval .steps-bar','background-color','$content-bg-2','','','.b-trade-approval'),(885197,'furniture','.b-trade-approval .steps-bar li.current a','background-color','$highlight-box-bg-2','','','.b-trade-approval'),(885198,'furniture','.w-account-personal-catalog .list-switcher a','background-color','$content-bg-1','2','','.w-account-personal-catalog'),(885199,'furniture','.w-catalog-compare tr','background-color','$content-bg-2','1','','.w-catalog-compare'),(885200,'furniture','.w-catalog-compare .compare .checkbox input:checked + span','background-color','$content-bg-1','','','.w-catalog-compare'),(885201,'furniture','.w-catalog-compare .compare-fix-bar','background-color','$content-bg-1','','','.w-catalog-compare'),(885202,'furniture','.w-catalog-compare .cross-box .different-all > div','background-color','$content-bg-1','2','','.w-catalog-compare'),(885203,'furniture','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','background-color','$content-bg-1','','','.w-delivery-day'),(885204,'furniture','.w-delivery-day .left-count','background-color','$highlight-box-bg-2','','','.w-delivery-day'),(885205,'furniture','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','background-color','$highlight-box-bg-1','','','.b-cookie-notice'),(885211,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','background-color','$content-bg-2','','','.b-slick'),(885212,'furniture','.menu-header .burger-icon','background-color','$header-menu-bg-4','5140','','.menu-header'),(885213,'furniture','.btn-2','background-color','$btn-bg-3','','',''),(885214,'furniture','.cartTitle span','background-color','$content-bg-1','','','.cartTitle'),(885215,'furniture','.w-catalog-listing-look .b2b','background-color','$highlight-box-bg-2','2','','.w-catalog-listing-look'),(885216,'furniture','.w-catalog-listing-look .grid','background-color','$highlight-box-bg-2','2','','.w-catalog-listing-look'),(885217,'furniture','.w-catalog-listing-look .list','background-color','$highlight-box-bg-2','2','','.w-catalog-listing-look'),(885218,'furniture','.LeftCategories ul li a','background-color','$content-bg-2','1','','.LeftCategories'),(885219,'furniture','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','background-color','$content-bg-2','','','.w-filters'),(885220,'furniture','.b-products-listing .products-listing.list-productlisting .item-content','background-color','$content-bg-2','4','','.b-products-listing'),(885221,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','background-color','$content-bg-1','','','.b-products-listing'),(885222,'furniture','.w-subscribers .btn-submit','background-color','$highlight-box-bg-1','','','.w-subscribers'),(885223,'furniture','.w-quote .cart-box-link','background-color','$highlight-box-bg-1','3','','.w-quote'),(885224,'furniture','.w-quote .cart-content','background-color','$content-bg-1','','','.w-quote'),(885225,'furniture','.w-quote .current-multi-cart.item','background-color','$highlight-box-bg-1','','','.w-quote'),(885226,'furniture','.w-quote .multicart a.name','background-color','$content-bg-2','1','','.w-quote'),(885227,'furniture','.w-product-sale-ends .left-count','background-color','$highlight-box-bg-1','','','.w-product-sale-ends'),(885228,'furniture','.w-product-sale-ends .left-count-days','background-color','$content-bg-1','','','.w-product-sale-ends'),(885229,'furniture','.w-product-sale-ends .left-count-hours','background-color','$content-bg-1','','','.w-product-sale-ends'),(885230,'furniture','h1, .heading-1','background-color','$content-bg-2','3','',''),(885231,'furniture','h1, .heading-1','background-color','$content-bg-2','4','',''),(885232,'furniture','.w-compare ','background-color','$content-bg-1','','','.w-compare'),(885233,'furniture','.w-files-catalog-widgets-files-catalog .name','background-color','$highlight-box-bg-2','','','.w-files-catalog-widgets-files-catalog'),(885234,'furniture','.w-sample .cart-box-link','background-color','$highlight-box-bg-1','3','','.w-sample'),(885235,'furniture','.w-sample .cart-content','background-color','$content-bg-1','','','.w-sample'),(885236,'furniture','.w-sample .current-multi-cart.item','background-color','$highlight-box-bg-1','','','.w-sample'),(885237,'furniture','.w-sample .multicart a.name','background-color','$content-bg-2','1','','.w-sample'),(885238,'furniture','.w-cart-listing .points-earn','background-color','$content-bg-2','','','.w-cart-listing'),(885239,'furniture','.w-cart-discount-coupon .btn','background-color','$content-bg-1','','','.w-cart-discount-coupon'),(885240,'furniture','.w-cart-order-reference .btn','background-color','$content-bg-1','','','.w-cart-order-reference'),(885241,'furniture','.w-cart-gift-certificate .btn','background-color','$content-bg-1','','','.w-cart-gift-certificate'),(885242,'furniture','.w-cart-shipping-estimator .btn','background-color','$content-bg-1','','','.w-cart-shipping-estimator'),(885243,'furniture','.heading-2','background-color','$content-bg-2','3','',''),(885244,'furniture','.heading-2','background-color','$content-bg-2','4','',''),(885245,'furniture','.b-pagination .pagination span','background-color','$highlight-box-bg-2','2','','.b-pagination'),(885246,'furniture','.w-product-properties-filters-widgets-chosen-filters .item','background-color','$highlight-box-bg-1','','','.w-product-properties-filters-widgets-chosen-filters'),(885247,'furniture','.w-tabs .tab-a','background-color','$tab-nav-bg-2','','','.w-tabs'),(885248,'furniture','.p-quote-checkout-index .order-summary .heading-2','background-color','$content-bg-2','3','','.p-quote-checkout-index'),(885249,'furniture','.p-quote-checkout-index .order-summary .heading-2','background-color','$content-bg-2','4','','.p-quote-checkout-index'),(885250,'furniture','.p-sample-checkout-index .order-summary .heading-2','background-color','$content-bg-2','3','','.p-sample-checkout-index'),(885251,'furniture','.p-sample-checkout-index .order-summary .heading-2','background-color','$content-bg-2','4','','.p-sample-checkout-index'),(885252,'furniture','.w-account-personal-catalog .list-row-action ul','background-color','$content-bg-1','','','.w-account-personal-catalog'),(885253,'furniture','.w-delivery-location-location-list .deliveryListParrent a','background-color','$highlight-box-bg-1','','','.w-delivery-location-location-list'),(885254,'furniture','.w-sale-category .badge','background-color','$highlight-box-bg-2','','','.w-sale-category'),(885255,'furniture','.w-sale-category .left-count','background-color','$highlight-box-bg-2','','','.w-sale-category'),(885256,'furniture','.w-sale-category .left-count-days','background-color','$content-bg-1','','','.w-sale-category'),(885257,'furniture','.w-sale-category .left-count-hours','background-color','$content-bg-1','','','.w-sale-category'),(885258,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','background-color','$content-bg-1','','','.w-product-properties-icons'),(885259,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content:before','background-color','$content-bg-1','','','.w-product-properties-icons'),(885260,'furniture','.w-delivery-location-product-categories .name','background-color','$highlight-box-bg-1','','','.w-delivery-location-product-categories'),(885261,'furniture','.w-product-bonus-points .bonus-points-cost','background-color','$content-bg-2','','','.w-product-bonus-points'),(885262,'furniture','.w-product-designer-designer .grnamebox .title-sortable','background-color','$highlight-box-bg-1','','','.w-product-designer-designer'),(885263,'furniture','.w-press-reviews-widgets-press-reviews ','background-color','$content-bg-1','','','.w-press-reviews-widgets-press-reviews'),(885264,'furniture','.w-press-reviews-widgets-press-reviews-list .item','background-color','$content-bg-1','','','.w-press-reviews-widgets-press-reviews-list'),(885265,'furniture','.w-support-system-listing .support-head','background-color','$content-bg-1','','','.w-support-system-listing'),(885266,'furniture','.w-support-system-listing .product_icon','background-color','$content-bg-1','','','.w-support-system-listing'),(885267,'furniture','.w-rma-returns-history .column .title','background-color','$highlight-box-bg-2','','','.w-rma-returns-history'),(885268,'furniture','.w-rma-returns-history table.dataTable tbody tr.odd, .w-rma-returns-history table.dataTable.display tbody tr.odd','background-color','$content-bg-1','','','.w-rma-returns-history'),(885269,'furniture','.w-rma-returns-history thead tr','background-color','$highlight-box-bg-2','','','.w-rma-returns-history'),(885270,'furniture','.b-products-listing .products-listing .bonus-points-cost','background-color','$content-bg-2','','','.b-products-listing'),(885271,'furniture','.b-products-listing .promos-info .promo-name-span','background-color','$highlight-box-bg-1','','','.b-products-listing'),(885272,'furniture','.w-predefined-promotion .nextdiscount .content > div','background-color','$content-bg-1','','','.w-predefined-promotion'),(885273,'furniture','.w-predefined-promotion .nextdiscount .promo-for-each','background-color','$content-bg-2','','','.w-predefined-promotion'),(885274,'furniture','.w-predefined-promotion .prom-multi-discount .promo-product','background-color','$content-bg-1','','','.w-predefined-promotion'),(885275,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','background-color','$content-bg-1','','','.w-predefined-promotion'),(885276,'furniture','.w-predefined-promotion .promo-cart-discount .master .item','background-color','$content-bg-1','','','.w-predefined-promotion'),(885277,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','background-color','$content-bg-1','','','.w-predefined-promotion'),(885278,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','background-color','$content-bg-1','','','.w-predefined-promotion'),(885279,'furniture','.w-predefined-promotion .promo-cart-discount .slave .item','background-color','$content-bg-1','','','.w-predefined-promotion'),(885280,'furniture','.w-predefined-promotion .promo-item','background-color','$content-bg-2','','','.w-predefined-promotion'),(885281,'furniture','.w-predefined-promotion .promo-salemaker .discount','background-color','$content-bg-1','','','.w-predefined-promotion'),(885282,'furniture','.w-predefined-promotion .promo-salemaker .item','background-color','$content-bg-1','','','.w-predefined-promotion'),(885283,'furniture','.w-cart-discount-coupon .discount-box','background-color','$content-bg-2','','','.w-cart-discount-coupon'),(885284,'furniture','.w-cart-listing .promos-info .promo-name','background-color','$highlight-box-bg-1','','','.w-cart-listing'),(885285,'furniture','.w-product-promotion-icons .promos-info .promo-name','background-color','$highlight-box-bg-1','','','.w-product-promotion-icons'),(885286,'furniture','.w-product-quantity-discounts .count','background-color','$content-bg-2','','','.w-product-quantity-discounts'),(885292,'furniture','.b-product-images .media-popup .mp-small-images img','background-color','$image-popup-bg-2','','','.b-product-images'),(885296,'furniture','.account-samples .orders-table th','background-color','$content-bg-2','','','.account-samples'),(885297,'furniture','.account-samples .order_history_table th','background-color','$content-bg-2','','','.account-samples'),(885298,'furniture','.catalog-product-wrap .prev-next-product','background-color','$content-bg-1','','','.catalog-product-wrap'),(885299,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','background-color','$highlight-box-bg-1','','','.checkout-index-wrap'),(885300,'furniture','.checkout-index-wrap .hiding-box .checkout-cart-listing','background-color','$content-bg-1','','','.checkout-index-wrap'),(885301,'furniture','.checkout-index-wrap .order-summary .heading-2','background-color','$content-bg-2','3','','.checkout-index-wrap'),(885302,'furniture','.checkout-index-wrap .order-summary .heading-2','background-color','$content-bg-2','4','','.checkout-index-wrap'),(885303,'furniture','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','background-color','$highlight-box-bg-2','','','.b-multi-page-checkout'),(885304,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','background-color','$highlight-box-bg-2','3','','.b-multi-page-checkout'),(885305,'furniture','.success-page .w-cart-listing .qty','background-color','$highlight-box-bg-1','','','.success-page'),(885306,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2','background-color','$header-menu-bg-2','','','.menu-header'),(885307,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 > li:hover > a','background-color','$header-menu-bg-3','','','.menu-header'),(885308,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-3','background-color','$header-menu-bg-2','','','.menu-header'),(885309,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-3 > li:hover > a','background-color','$header-menu-bg-3','','','.menu-header'),(885310,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-4','background-color','$header-menu-bg-2','','','.menu-header'),(885311,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-4 > li:hover > a','background-color','$header-menu-bg-3','','','.menu-header'),(885312,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-5','background-color','$header-menu-bg-2','','','.menu-header'),(885313,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-5 > li:hover > a','background-color','$header-menu-bg-3','','','.menu-header'),(885314,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-6','background-color','$header-menu-bg-3','','','.menu-header'),(885316,'furniture','.btn-3','background-color','$btn-bg-4','','',''),(885317,'furniture','.lowestPricedBox .w-banner .banner-item:nth-child(1) .ybg:before','background-color','$additional-banner-bg-2','','','.lowestPricedBox'),(885318,'furniture','.lowestPricedBox .w-banner .banner-item:nth-child(2) .ybg:before','background-color','$additional-banner-bg-2','','','.lowestPricedBox'),(885319,'furniture','.lowestPricedBox .w-banner .banner-text-holder','background-color','$additional-banner-bg-1','','','.lowestPricedBox'),(885320,'furniture','.lowestPricedBox .w-banner .ybg','background-color','$additional-banner-bg-2','3','','.lowestPricedBox'),(885321,'furniture','.tripleBanner .w-html_box','background-color','$additional-banner-bg-3','','','.tripleBanner'),(885322,'furniture','.tripleBanner .w-html_box','background-color','$additional-banner-bg-1','3','','.tripleBanner'),(885323,'furniture','.shopByCollectionBox .content','background-color','$additional-banner-bg-1','','','.shopByCollectionBox'),(885324,'furniture','.w-catalog-paging ','background-color','$highlight-box-bg-2','2','','.w-catalog-paging'),(885325,'furniture','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','background-color','$image-popup-bg-2','','','.b-product-images'),(885326,'furniture','.w-compare-box-item .checkbox:checked + span:before','background-color','$highlight-box-bg-3','','','.w-compare-box-item'),(885327,'furniture','.w-compare-box-item .checkbox:not(checked) + span:before','background-color','$content-bg-1','','','.w-compare-box-item'),(885328,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.p-quick-order-index'),(885329,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color_important','important','','','.b-select-suggest'),(885330,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.b-data-table'),(885331,'furniture','.b-select-suggest .select2-container .select2-choice abbr','background-image','url(\'\')','','','.b-select-suggest'),(885332,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-image','none','','','.b-select-suggest'),(885333,'furniture','.b-select-suggest .select2-search input','background-image','url(\'\')','','','.b-select-suggest'),(885334,'furniture','.b-select-suggest .select2-more-results.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(885335,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(885336,'furniture','.b-select-suggest .select2-search input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(885337,'furniture','.b-select-suggest .select2-search-choice-close','background-image','url(\'\')','','','.b-select-suggest'),(885338,'furniture','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-image','url(\'\')','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(885339,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-image','none','','','.b-select-suggest'),(885340,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-image','none','','','.b-select-suggest'),(885341,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-image','none','','','.b-select-suggest'),(885342,'furniture','.b-select-suggest .select2-results li','background-image','none','','','.b-select-suggest'),(885346,'furniture','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.account-order-pay'),(885347,'furniture','.account-samples .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.account-samples'),(885348,'furniture','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.account-sample-info'),(885349,'furniture','.b-select-suggest .select2-search input','background-position','100% -21px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(885350,'furniture','.b-select-suggest .select2-container .select2-choice abbr','background-position','right -11px','1','','.b-select-suggest'),(885351,'furniture','.w-top-categories .image','background-position','50% 50%','','','.w-top-categories'),(885352,'furniture','.b-select-suggest .select2-container .select2-choice abbr','background-position','top right','','','.b-select-suggest'),(885353,'furniture','.w-categories .image','background-position','50% 50%','','','.w-categories'),(885354,'furniture','.b-select-suggest .select2-search input','background-position','100% -22px','','','.b-select-suggest'),(885355,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close','background-position','right -11px','','','.b-select-suggest'),(885356,'furniture','.b-select-suggest .select2-search-choice-close','background-position','top right','','','.b-select-suggest'),(885357,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close','background-position','right -11px','1','','.b-select-suggest'),(885358,'furniture','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow b','background-position','-18px 1px','','','.b-select-suggest'),(885359,'furniture','.tripleBanner .w-html_box','background-position','50% 50%','3','','.tripleBanner'),(885360,'furniture','.mainBanner .buttonBox','background-position-x','27%','','','.mainBanner'),(885361,'furniture','.b-select-suggest .select2-search input','background-position_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(885362,'furniture','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(885363,'furniture','.b-select-suggest .select2-container .select2-choice abbr','background-repeat','no-repeat','','','.b-select-suggest'),(885364,'furniture','.b-select-suggest .select2-search-choice-close','background-repeat','no-repeat','','','.b-select-suggest'),(885365,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(885366,'furniture','.b-select-suggest .select2-more-results.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(885367,'furniture','.b-select-suggest .select2-search input','background-repeat','no-repeat','','','.b-select-suggest'),(885368,'furniture','.b-select-suggest .select2-search input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(885369,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','','.b-select-suggest'),(885370,'furniture','.mainBanner .bottomBox','background-repeat','no-repeat','','','.mainBanner'),(885371,'furniture','.mainBanner .buttonBox','background-repeat','no-repeat','','','.mainBanner'),(885372,'furniture','.mainBanner .title','background-repeat','no-repeat','3','','.mainBanner'),(885373,'furniture','.mainBanner .topBox > .right','background-repeat','no-repeat','3','','.mainBanner'),(885374,'furniture','.tripleBanner .w-html_box','background-repeat','no-repeat','3','','.tripleBanner'),(885375,'furniture','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(885376,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat_important','important','','','.b-select-suggest'),(885377,'furniture','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size','60px 40px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(885378,'furniture','.w-top-categories .image','background-size','cover','','','.w-top-categories'),(885379,'furniture','.w-categories .image','background-size','cover','','','.w-categories'),(885380,'furniture','.mainBanner .bottomBox','background-size','contain','','','.mainBanner'),(885381,'furniture','.mainBanner .buttonBox','background-size','12vw','','','.mainBanner'),(885382,'furniture','.mainBanner .topBox > .right','background-size','90%','5145,3','','.mainBanner'),(885383,'furniture','.mainBanner .buttonBox','background-size','15vw','5131','','.mainBanner'),(885384,'furniture','.mainBanner .topBox > .right','background-size','75%','5131,3','','.mainBanner'),(885385,'furniture','.mainBanner .buttonBox','background-size','21vw','5161','','.mainBanner'),(885386,'furniture','.mainBanner .buttonBox','background-size','192px','5206','','.mainBanner'),(885387,'furniture','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(885388,'furniture','.warrantyProduct .warranty','background_image','themes/furniture/img/calendar.webp','3','','.warrantyProduct'),(885389,'furniture','.warrantyProduct .delivery','background_image','themes/furniture/img/wallet.webp','3','','.warrantyProduct'),(885390,'furniture','.mainBanner .bottomBox','background_image','themes/furniture/img/ybg.webp','','','.mainBanner'),(885391,'furniture','.mainBanner .buttonBox','background_image','themes/furniture/img/everyday.webp','','','.mainBanner'),(885392,'furniture','.mainBanner .title','background_image','themes/furniture/img/elf.svg','3','','.mainBanner'),(885393,'furniture','.mainBanner .topBox > .right','background_image','themes/furniture/img/collection.webp','3','','.mainBanner'),(885395,'furniture','.tripleBanner .track.w-html_box','background_image','themes/furniture/img/track.webp','3','','.tripleBanner'),(885396,'furniture','.tripleBanner .warranty.w-html_box','background_image','themes/furniture/img/warranty.webp','3','','.tripleBanner'),(885397,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.p-quick-order-index'),(885398,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background_important','important','','','.b-select-suggest'),(885399,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.b-data-table'),(885400,'furniture','.w-product-designer-designer .prodDesignerType','background_important','important','','','.w-product-designer-designer'),(885401,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','background_important','important','','','.w-rma-returns-history'),(885402,'furniture','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(885403,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','1','','.p-quick-order-index'),(885404,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.p-quick-order-index'),(885405,'furniture','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(885406,'furniture','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(885407,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(885408,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.p-quick-order-index'),(885409,'furniture','.b-messages .select2-container-multi input.select2-input','border','none','','','.b-messages'),(885410,'furniture','.b-messages .emailLineTextArea textarea','border','none','','','.b-messages'),(885411,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border','none','3','','.b-switch'),(885412,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(885413,'furniture','.b-switch .candlestick-wrapper .candlestick-bg','border','none','','','.b-switch'),(885414,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(885415,'furniture','.b-autocomplete .ui-autocomplete li','border','none','','','.b-autocomplete'),(885416,'furniture','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(885417,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(885418,'furniture','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(885419,'furniture','.w-cart-cart-tabs .w-tabs > .block','border','none','','','.w-cart-cart-tabs'),(885420,'furniture','.b-bottom .popup-box.popupCompare','border','none','','','.b-bottom'),(885421,'furniture','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(885422,'furniture','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(885423,'furniture','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(885424,'furniture','.w-top-categories .categories h2','border','none','','','.w-top-categories'),(885425,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border','none','4','','.b-switch'),(885426,'furniture','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(885427,'furniture','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(885428,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border','none','','','.b-switch'),(885429,'furniture','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(885430,'furniture','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(885431,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(885432,'furniture','.b-form .checkbox-style','border','none','','','.b-form'),(885433,'furniture','.b-sub-totals .historyTotal table','border','none','','','.b-sub-totals'),(885434,'furniture','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(885435,'furniture','.b-bottom .cart-options .heading-4','border','none','','','.b-bottom'),(885436,'furniture','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(885437,'furniture','.b-products-listing .products-listing .wishlistButton .checkbox input + span','border','none','','','.b-products-listing'),(885438,'furniture','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','border','none','','','.b-products-listing'),(885439,'furniture','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(885440,'furniture','.b-compare .compare-head','border','none','','','.b-compare'),(885441,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.p-quick-order-index'),(885442,'furniture','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(885443,'furniture','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(885444,'furniture','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(885445,'furniture','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(885446,'furniture','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(885447,'furniture','.b-sub-totals .historyTotal td','border','none','','','.b-sub-totals'),(885448,'furniture','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(885449,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.b-data-table'),(885450,'furniture','.b-products-listing .products-listing a.btn.view-button','border','none','','','.b-products-listing'),(885451,'furniture','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(885452,'furniture','.w-checkout-gdpr .privacy-row','border','none','','','.w-checkout-gdpr'),(885453,'furniture','.b-autocomplete .ui-autocomplete li','border','none','1','','.b-autocomplete'),(885454,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','border','none','','','.w-communication-new-topic'),(885455,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','border','none','','','.w-communication-new-topic'),(885456,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','border','none','','','.w-communication-new-topic'),(885457,'furniture','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(885458,'furniture','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(885459,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(885460,'furniture','.w-filters .input-checkbox','border','none','','','.w-filters'),(885461,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','border','none','','',''),(885462,'furniture','.b-data-table table.dataTable thead td','border','none','','','.b-data-table'),(885463,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.b-data-table'),(885464,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.b-data-table'),(885465,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border','none','','','.b-product-images'),(885466,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','border','none','','','.b-menu-style-2'),(885467,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','border','none','','','.b-menu-style-2'),(885468,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','border','none','','','.b-menu-style-2'),(885469,'furniture','.b-trade-approval .w-login-block .heading-3','border','none','','','.b-trade-approval'),(885470,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','border','none','','','.w-catalog-compare'),(885471,'furniture','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','border','none','','','.b-cookie-notice'),(885472,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','border','none','','','.b-slick'),(885473,'furniture','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border','none','','','.b-products-listing'),(885474,'furniture','.w-product-personal-catalog-button .btn','border','none','','','.w-product-personal-catalog-button'),(885475,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','border','none','','','.b-products-listing'),(885476,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','border','none','','','.w-rma-returns-history'),(885477,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','border','none','','','.w-filters'),(885478,'furniture','.order-summary .w-cart-listing .headings','border','none','','','.order-summary'),(885479,'furniture','.order-summary .w-cart-listing .item','border','none','','','.order-summary'),(885483,'furniture','.account-samples .orders-table tr:first-child','border','none','','','.account-samples'),(885484,'furniture','.w-compare-box-item .checkbox','border','none','','','.w-compare-box-item'),(885485,'furniture','.w-promotions .heading-3','border-bottom','none','','','.w-promotions'),(885486,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable.no-footer','border-bottom','none','','','.b-messages'),(885487,'furniture','.w-cart-shipping-estimator .addresses','border-bottom','none','','','.w-cart-shipping-estimator'),(885488,'furniture','.w-account-personal-catalog .list-switcher a','border-bottom','none','2','','.w-account-personal-catalog'),(885489,'furniture','.w-catalog-compare .cross-box .different-all > div','border-bottom','none','2','','.w-catalog-compare'),(885490,'furniture','.w-tabs .tab-li','border-bottom','none','2','','.w-tabs'),(885491,'furniture','.w-predefined-promotion .heading-3','border-bottom','none','','','.w-predefined-promotion'),(885493,'furniture','.b-upload-file .upload-file-template','border-bottom-color','$content-border-1','','','.b-upload-file'),(885494,'furniture','.w-promotions .prom-multi-discount .promo-range','border-bottom-color','$warning-border','','','.w-promotions'),(885495,'furniture','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(885497,'furniture','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(885498,'furniture','.testimonials .review','border-bottom-color','transparent','3','',''),(885499,'furniture','.w-promotions .promo-salemaker .discount','border-bottom-color','$warning-border','','','.w-promotions'),(885500,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-color','$warning-border','','','.w-promotions'),(885501,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-color','$warning-border','','','.w-promotions'),(885502,'furniture','.w-cart-give-away .ga_column','border-bottom-color','$content-border-1','','','.w-cart-give-away'),(885503,'furniture','.w-cart-compare .cart-cell > div','border-bottom-color','$content-border-1','','','.w-cart-compare'),(885504,'furniture','.b-messages .msv_btn','border-bottom-color','$content-border-1','','','.b-messages'),(885505,'furniture','.b-messages .content_management_attach button','border-bottom-color','$content-border-2','','','.b-messages'),(885506,'furniture','.b-messages .content_management_attach','border-bottom-color','$content-border-1','','','.b-messages'),(885507,'furniture','.b-messages .email-heading','border-bottom-color','$content-border-1','','','.b-messages'),(885508,'furniture','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-color','$content-border-1','','','.b-messages'),(885509,'furniture','.b-messages .msv_to_cc','border-bottom-color','$content-border-1','','','.b-messages'),(885510,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-color','$content-border-1','','','.b-messages'),(885511,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-bottom-color','$content-border-1','','',''),(885512,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-color','$content-border-1','','','.b-messages'),(885513,'furniture','.b-messages .dataTables_wrapper > .bottom','border-bottom-color','$content-border-1','','','.b-messages'),(885514,'furniture','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(885515,'furniture','.w-product-reviews .reviews-list .review','border-bottom-color','$transparent','3','','.w-product-reviews'),(885516,'furniture','.b-form .required-error','border-bottom-color','$attention-border','','','.b-form'),(885517,'furniture','.p-payer-order-confirmation .input-wrapper','border-bottom-color','$content-border-1','','','.p-payer-order-confirmation'),(885518,'furniture','.p-payer-order-pay .input-wrapper','border-bottom-color','$content-border-1','','','.p-payer-order-pay'),(885519,'furniture','.b-upload-file .snapshot','border-bottom-color','$content-border-2','','','.b-upload-file'),(885520,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-color','$switch-nc-border-1','','','.b-switch'),(885521,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(885522,'furniture','.w-filters .filter-box-head','border-bottom-color','$content-border-1','','','.w-filters'),(885523,'furniture','.b-upload-file .upload-file-template div','border-bottom-color','$content-border-1','','','.b-upload-file'),(885524,'furniture','.w-checkout-shipping-choice span','border-bottom-color','$highlight-box-border-2','','','.w-checkout-shipping-choice'),(885525,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(885526,'furniture','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(885527,'furniture','.b-info-popup .info-popup div','border-bottom-color','$content-border-1','','','.b-info-popup'),(885528,'furniture','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(885529,'furniture','.w-tabs > .block','border-bottom-color','$tab-content-border-1','','','.w-tabs'),(885530,'furniture','.w-tabs .accordion-heading','border-bottom-color','$tab-nav-border-1','2','','.w-tabs'),(885531,'furniture','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(885532,'furniture','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(885533,'furniture','.w-cart-compare .compare-table','border-bottom-color','$content-border-1','','','.w-cart-compare'),(885534,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-color','$switch-handle-bg-3','','','.b-switch'),(885535,'furniture','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(885536,'furniture','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(885537,'furniture','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(885538,'furniture','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(885539,'furniture','.w-reviews-content .review','border-bottom-color','$content-border-1','3','','.w-reviews-content'),(885540,'furniture','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(885541,'furniture','.b-select-suggest .select2-container.select2-drop-above .select2-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(885542,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-color','$switch-nc-border-1','4','','.b-switch'),(885544,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-color','$checkbox-border-1','3','','.b-form'),(885545,'furniture','.w-cart-products .checkout-attention-message','border-bottom-color','$warning-border','','','.w-cart-products'),(885546,'furniture','.w-cart-products .checkout-attention-message','border-bottom-color','$warning-border','','','.w-cart-products'),(885547,'furniture','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-bottom-color','$content-border-1','','','.b-bottom'),(885548,'furniture','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(885549,'furniture','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-bottom-color','$border-color-9','','','.b-bottom'),(885550,'furniture','textarea','border-bottom-color','$content-border-1','','',''),(885551,'furniture','.b-bottom .popup-box','border-bottom-color','$content-border-1','','','.b-bottom'),(885552,'furniture','.w-product-customers-activity .customers-activity','border-bottom-color','$content-border-1','','','.w-product-customers-activity'),(885553,'furniture','.w-tabs .accordion-heading','border-bottom-color','$tab-nav-border-2','','','.w-tabs'),(885554,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-color','$content-border-1','','','.b-select-suggest'),(885555,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(885556,'furniture','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-color','$content-border-1','','','.b-select-suggest'),(885557,'furniture','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-color','$content-border-1','','','.b-select-suggest'),(885558,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(885559,'furniture','.b-select-suggest .select2-dropdown-open .select2-choice','border-bottom-color','$transparent','','','.b-select-suggest'),(885560,'furniture','.b-select-suggest .select2-drop-active','border-bottom-color','$content-border-1','','','.b-select-suggest'),(885561,'furniture','.b-select-suggest .select2-drop','border-bottom-color','$content-border-1','','','.b-select-suggest'),(885562,'furniture','.w-cart-products .checkout-attention-message','border-bottom-color','$warning-border','','','.w-cart-products'),(885563,'furniture','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(885564,'furniture','.b-form input.required-error','border-bottom-color','$attention-border','','','.b-form'),(885565,'furniture','.w-communication-post .communication-post','border-bottom-color','$content-border-1','','','.w-communication-post'),(885566,'furniture','.checkbox input + span','border-bottom-color','$content-border-1','','',''),(885567,'furniture','.checkbox input:checked + span','border-bottom-color','$checkbox-border-1','','',''),(885568,'furniture','.b-autocomplete .ui-autocomplete','border-bottom-color','$content-border-1','','','.b-autocomplete'),(885571,'furniture','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(885572,'furniture','.b-select-suggest .select2-container .select2-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(885573,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-color','$switch-nc-border-1','3','','.b-switch'),(885574,'furniture','.w-reviews .review','border-bottom-color','$content-bg-1','3','','.w-reviews'),(885575,'furniture','.w-reviews-content .item','border-bottom-color','$content-border-1','','','.w-reviews-content'),(885576,'furniture','.b-upload-files .upload-files','border-bottom-color','$content-border-1','','','.b-upload-files'),(885577,'furniture','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(885578,'furniture','.w-reviews .item','border-bottom-color','$content-border-1','','','.w-reviews'),(885579,'furniture','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(885580,'furniture','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(885581,'furniture','.b-select-suggest .select2-search input','border-bottom-color','$content-border-1','','','.b-select-suggest'),(885582,'furniture','.w-cart-products .checkout-attention-message','border-bottom-color','$warning-border','','','.w-cart-products'),(885583,'furniture','.w-cart-listing .item .gift-wrap label','border-bottom-color','$content-border-1','','','.w-cart-listing'),(885584,'furniture','.w-cart-listing .item','border-bottom-color','$content-border-1','5140','','.w-cart-listing'),(885588,'furniture','.w-cart-products .checkout-attention-message','border-bottom-color','$warning-border','','','.w-cart-products'),(885589,'furniture','.b-data-table table.dataTable.no-footer','border-bottom-color','$content-border-1','','','.b-data-table'),(885590,'furniture','.w-cart-products .checkout-attention-message','border-bottom-color','$warning-border','','','.w-cart-products'),(885591,'furniture','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-color','$content-border-2','','','.b-compare'),(885592,'furniture','.b-compare .compare_pagination','border-bottom-color','$content-border-1','','','.b-compare'),(885593,'furniture','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-bottom-color','$image-popup-border-1','','','.b-product-images'),(885594,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-bottom-color','$header-menu-border-1','','','.b-menu-style-2'),(885595,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','border-bottom-color','$header-menu-border-1','','','.b-menu-style-2'),(885596,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-bottom-color','$header-menu-border-1','','','.b-menu-style-2'),(885597,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-bottom-color','$header-menu-border-1','','','.b-menu-style-2'),(885598,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-bottom-color','$header-menu-border-1','','','.b-menu-style-2'),(885599,'furniture','.b-trade-approval .orders-table th','border-bottom-color','$content-border-1','','','.b-trade-approval'),(885600,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-color','$content-border-1','','','.b-trade-approval'),(885601,'furniture','.w-account-personal-catalog .list-switcher a','border-bottom-color','$content-border-1','','','.w-account-personal-catalog'),(885602,'furniture','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-color','$content-bg-1','','','.w-catalog-compare'),(885603,'furniture','.w-catalog-compare .cross-box .different-all > div','border-bottom-color','$content-border-1','','','.w-catalog-compare'),(885604,'furniture','.w-delivery-day .left-text-left','border-bottom-color','$content-border-1','','','.w-delivery-day'),(885605,'furniture','.w-delivery-day .left-text-right','border-bottom-color','$content-border-1','','','.w-delivery-day'),(885609,'furniture','.w-cart-listing .item, .w-cart-listing .headings','border-bottom-color','$content-border-1','','','.w-cart-listing'),(885610,'furniture','.b-products-listing .products-listing .compare input + span','border-bottom-color','$content-border-2','','','.b-products-listing'),(885611,'furniture','.w-filters .filter-widget','border-bottom-color','$content-border-1','','','.w-filters'),(885612,'furniture','.w-quote .cart-content','border-bottom-color','$content-border-1','','','.w-quote'),(885613,'furniture','.w-quote .cart-total','border-bottom-color','$content-border-1','','','.w-quote'),(885614,'furniture','.w-quote .multicart .item','border-bottom-color','$content-border-1','','','.w-quote'),(885615,'furniture','.b-product-images .additional-images .active img','border-bottom-color','$highlight-box-color-1','','','.b-product-images'),(885616,'furniture','.b-product-images .additional-images img','border-bottom-color','$content-border-1','','','.b-product-images'),(885617,'furniture','.b-quantity .qty-box .bigger','border-bottom-color','$content-border-1','','','.b-quantity'),(885618,'furniture','.b-quantity .qty-box .smaller','border-bottom-color','$content-border-1','','','.b-quantity'),(885619,'furniture','.w-product-sale-ends .left-text-left','border-bottom-color','$content-border-1','','','.w-product-sale-ends'),(885620,'furniture','.w-product-sale-ends .left-text-right','border-bottom-color','$content-border-1','','','.w-product-sale-ends'),(885621,'furniture','.w-product-quantity .qty_packs .qty-input','border-bottom-color','$content-border-1','','','.w-product-quantity'),(885622,'furniture','.w-sample .cart-box-link','border-bottom-color','$content-border-2','4','','.w-sample'),(885623,'furniture','.w-sample .cart-content','border-bottom-color','$content-border-1','','','.w-sample'),(885624,'furniture','.w-sample .cart-total','border-bottom-color','$content-border-1','','','.w-sample'),(885625,'furniture','.w-sample .multicart .item','border-bottom-color','$content-border-1','','','.w-sample'),(885626,'furniture','.w-cart-listing .points-earn','border-bottom-color','transparent','4','','.w-cart-listing'),(885627,'furniture','.w-cart-discount-coupon .btn','border-bottom-color','$content-border-2','','','.w-cart-discount-coupon'),(885628,'furniture','.w-product-video .item img, .w-product-video .item video','border-bottom-color','$image-popup-border-1','','','.w-product-video'),(885629,'furniture','.w-product-video .item.active img, .w-product-video .item.active video','border-bottom-color','$highlight-box-border-1','','','.w-product-video'),(885630,'furniture','.shipping-ico .heading-3','border-bottom-color','$content-border-1','','','.shipping-ico'),(885631,'furniture','.w-cart-order-reference .btn','border-bottom-color','$content-border-2','','','.w-cart-order-reference'),(885632,'furniture','.w-cart-gift-certificate .btn','border-bottom-color','$content-border-2','','','.w-cart-gift-certificate'),(885633,'furniture','.w-cart-shipping-estimator .btn','border-bottom-color','$content-border-2','','','.w-cart-shipping-estimator'),(885635,'furniture','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-bottom-color','$content-border-2','','','.b-pagination'),(885636,'furniture','.b-pagination .pagination .next-pages','border-bottom-color','$content-border-1','','','.b-pagination'),(885637,'furniture','.b-pagination .pagination .page-number','border-bottom-color','$content-border-1','','','.b-pagination'),(885638,'furniture','.b-pagination .pagination .prev-pages','border-bottom-color','$content-border-1','','','.b-pagination'),(885639,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-bottom-color','$content-border-1','','','.b-pagination'),(885640,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-bottom-color','$content-border-1','','','.b-pagination'),(885641,'furniture','.b-pagination .pagination span','border-bottom-color','$highlight-box-border-2','2','','.b-pagination'),(885642,'furniture','.w-tabs .tab-li','border-bottom-color','$tab-nav-border-2','','','.w-tabs'),(885643,'furniture','.w-product-multi-inventory .radio-attributes','border-bottom-color','$content-border-1','','','.w-product-multi-inventory'),(885644,'furniture','.w-product-multi-inventory .radio-attributes .option-item','border-bottom-color','$content-border-1','','','.w-product-multi-inventory'),(885645,'furniture','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-bottom-color','$content-border-2','','','.w-product-multi-inventory'),(885646,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-bottom-color','$content-border-1','','','.w-account-personal-catalog'),(885647,'furniture','.w-account-personal-catalog .list-row-action ul','border-bottom-color','$content-border-1','','','.w-account-personal-catalog'),(885648,'furniture','.b-products-listing .products-listing .radio-attributes','border-bottom-color','$content-border-1','','','.b-products-listing'),(885649,'furniture','.b-products-listing .products-listing .radio-attributes .option','border-bottom-color','$content-border-1','','','.b-products-listing'),(885650,'furniture','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-bottom-color','$content-border-2','','','.b-products-listing'),(885651,'furniture','.w-product-attributes .radio-attributes','border-bottom-color','$content-border-1','','','.w-product-attributes'),(885652,'furniture','.w-product-attributes .radio-attributes .option-item','border-bottom-color','$content-border-1','','','.w-product-attributes'),(885653,'furniture','.w-product-attributes .radio-attributes input:checked + .option-item','border-bottom-color','$content-border-2','','','.w-product-attributes'),(885654,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(885655,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-bottom-color','$attention-border','','','.w-questionnaire-widgets-questionnaire'),(885656,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-bottom-color','$message-border','','','.w-questionnaire-widgets-questionnaire'),(885657,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-bottom-color','$attention-border','1','','.w-questionnaire-widgets-questionnaire'),(885658,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-bottom-color','$message-border','1','','.w-questionnaire-widgets-questionnaire'),(885659,'furniture','.w-product-groups .radioBox label .containerBlock','border-bottom-color','$content-border-1','','','.w-product-groups'),(885660,'furniture','.w-product-groups .radioBox label .containerBlock.selected','border-bottom-color','$content-border-2','','','.w-product-groups'),(885661,'furniture','.w-product-groups .radioBox label input:checked + .containerBlock','border-bottom-color','$content-border-2','','','.w-product-groups'),(885662,'furniture','.w-delivery-location-top-location-list .deliveryName','border-bottom-color','$content-border-1','','','.w-delivery-location-top-location-list'),(885663,'furniture','.w-delivery-location-location-list .deliveryName','border-bottom-color','$content-border-1','','','.w-delivery-location-location-list'),(885664,'furniture','.w-delivery-location-location-list .deliveryList li a','border-bottom-color','$content-border-1','','','.w-delivery-location-location-list'),(885665,'furniture','.w-delivery-location-location-list .deliveryList li a','border-bottom-color','$content-border-2','1','','.w-delivery-location-location-list'),(885666,'furniture','.w-sale-category .left-text-left','border-bottom-color','$content-border-1','','','.w-sale-category'),(885667,'furniture','.w-sale-category .left-text-right','border-bottom-color','$content-border-1','','','.w-sale-category'),(885668,'furniture','.w-sale-category .sale-holder','border-bottom-color','$content-border-1','','','.w-sale-category'),(885669,'furniture','.w-catalog-delivery-locations .name','border-bottom-color','$content-border-1','','','.w-catalog-delivery-locations'),(885670,'furniture','.w-product-designer-designer .prodDesignerType label','border-bottom-color','$content-border-1','','','.w-product-designer-designer'),(885671,'furniture','.w-press-reviews-widgets-press-reviews-small ','border-bottom-color','$content-border-1','','','.w-press-reviews-widgets-press-reviews-small'),(885672,'furniture','.b-products-listing .productGroup label a','border-bottom-color','$content-border-2','','','.b-products-listing'),(885673,'furniture','.w-support-system-listing .support-head','border-bottom-color','$content-border-1','','','.w-support-system-listing'),(885674,'furniture','.w-support-system-listing .product_icon','border-bottom-color','$content-border-1','','','.w-support-system-listing'),(885675,'furniture','.w-rma-returns-history .topRow','border-bottom-color','$content-border-1','','','.w-rma-returns-history'),(885676,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-color','$warning-border','','','.w-predefined-promotion'),(885677,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-color','$warning-border','','','.w-predefined-promotion'),(885678,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-color','$warning-border','','','.w-predefined-promotion'),(885679,'furniture','.w-predefined-promotion .promo-salemaker .discount','border-bottom-color','$warning-border','','','.w-predefined-promotion'),(885680,'furniture','.w-supplier-purchase-supplier-products .item','border-bottom-color','$content-border-1','','','.w-supplier-purchase-supplier-products'),(885681,'furniture','.mainBanner .bottomBox .btn','border-bottom-color','$main-banner-border-1','','','.mainBanner'),(885682,'furniture','.mainBanner .bottomBox .btn','border-bottom-color','$main-banner-border-1','5145','','.mainBanner'),(885683,'furniture','.mainBanner .bottomBox .btn','border-bottom-color','$main-banner-border-1','5131','','.mainBanner'),(885684,'furniture','.mainBanner .bottomBox .btn','border-bottom-color','$main-banner-border-1','5161','','.mainBanner'),(885685,'furniture','.mainBanner .bottomBox .btn','border-bottom-color','$main-banner-border-1','5206','','.mainBanner'),(885686,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','border-bottom-color','$content-border-1','','','.w-promotions-widgets-promotion-icons-desc'),(885687,'furniture','.w-product-quantity-discounts .item','border-bottom-color','$content-border-1','','','.w-product-quantity-discounts'),(885691,'furniture','.account-samples .orders-table .item','border-bottom-color','$content-border-1','5140','','.account-samples'),(885692,'furniture','.catalog-product-wrap .pn-image','border-bottom-color','$content-border-1','3','','.catalog-product-wrap'),(885693,'furniture','.checkout-index-wrap .input-wrapper','border-bottom-color','$content-border-1','','','.checkout-index-wrap'),(885694,'furniture','.shopping-cart-index .btn-3','border-bottom-color','$content-border-2','','','.shopping-cart-index'),(885695,'furniture','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-color','$content-color-2','','','.b-multi-page-checkout'),(885696,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-color','$content-border-1','','','.b-multi-page-checkout'),(885697,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-color','$content-border-1','','','.b-multi-page-checkout'),(885698,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','border-bottom-color','$footer-menu-border-1','5140','','.footer-menu'),(885699,'furniture','.lowestPricedBox .w-banner .ybg .btn','border-bottom-color','$additional-banner-border-1','','','.lowestPricedBox'),(885700,'furniture','.shopByCollectionBox .bannerButton a','border-bottom-color','$additional-banner-border-1','','','.shopByCollectionBox'),(885701,'furniture','.shopByCollectionBox .bannerButton a','border-bottom-color','$additional-banner-border-1','5145','','.shopByCollectionBox'),(885702,'furniture','.w-catalog-paging ','border-bottom-color','$content-border-1','2','','.w-catalog-paging'),(885703,'furniture','.w-catalog-paging .next','border-bottom-color','$content-border-1','','','.w-catalog-paging'),(885704,'furniture','.w-catalog-paging .next-pages','border-bottom-color','$content-border-1','','','.w-catalog-paging'),(885705,'furniture','.w-catalog-paging .page-number','border-bottom-color','$content-border-1','','','.w-catalog-paging'),(885706,'furniture','.w-catalog-paging .prev','border-bottom-color','$content-border-1','','','.w-catalog-paging'),(885707,'furniture','.w-catalog-paging .prev-pages','border-bottom-color','$content-border-1','','','.w-catalog-paging'),(885708,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-color','$content-border-1','','','.w-catalog-paging'),(885709,'furniture','.w-compare-box-item .checkbox + span','border-bottom-color','$content-border-1','','','.w-compare-box-item'),(885710,'furniture','.w-compare-box-item .checkbox:checked + span','border-bottom-color','$highlight-box-border-3','','','.w-compare-box-item'),(885711,'furniture','.b-data-table table.dataTable.no-footer','border-bottom-color_important','important','','','.b-data-table'),(885712,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-left-radius','15','4','','.b-switch'),(885713,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.p-quick-order-index'),(885714,'furniture','.w-promotions .prom-multi-discount .promo-range','border-bottom-left-radius','12','','','.w-promotions'),(885715,'furniture','.w-promotions .promo-salemaker .discount','border-bottom-left-radius','12','','','.w-promotions'),(885716,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-left-radius','12','','','.w-promotions'),(885717,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-left-radius','12','','','.w-promotions'),(885718,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.p-quick-order-index'),(885719,'furniture','.w-personal-gift-status-bar .progress-bar','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(885720,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-left-radius','5','','','.b-messages'),(885721,'furniture','.b-fancybox .fancybox-close','border-bottom-left-radius','50','','','.b-fancybox'),(885722,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-left-radius','25','','','.b-switch'),(885723,'furniture','.b-upload-file .snapshot','border-bottom-left-radius','50','','','.b-upload-file'),(885724,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-left-radius','15','3','','.b-switch'),(885725,'furniture','.b-switch .candlestick-wrapper .candlestick-bg','border-bottom-left-radius','15','','','.b-switch'),(885726,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(885727,'furniture','.w-checkout-shipping-choice label:last-child span','border-bottom-left-radius','0','','','.w-checkout-shipping-choice'),(885728,'furniture','.w-checkout-shipping-choice label:first-child span','border-bottom-left-radius','16','','','.w-checkout-shipping-choice'),(885729,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-bottom-left-radius','0','4','','.b-switch'),(885730,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-bottom-left-radius','0','3','','.b-switch'),(885731,'furniture','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-left-radius','15','','','.b-fancybox'),(885732,'furniture','.b-fancybox .fancybox-skin','border-bottom-left-radius','4','','','.b-fancybox'),(885733,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-bottom-left-radius','50','3','','.b-switch'),(885734,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-left-radius','50','3','','.b-form'),(885735,'furniture','.b-fancybox .fancybox-nav span','border-bottom-left-radius','50','','','.b-fancybox'),(885736,'furniture','.w-product-customers-activity .customers-activity','border-bottom-left-radius','0','','','.w-product-customers-activity'),(885737,'furniture','.w-product-customers-activity .close','border-bottom-left-radius','50','','','.w-product-customers-activity'),(885738,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(885739,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.b-data-table'),(885740,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.b-data-table'),(885741,'furniture','.b-products-listing .promos-info .promo-name','border-bottom-left-radius','0','','','.b-products-listing'),(885742,'furniture','.w-personal-gift-status-bar .progress-bar-content','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(885743,'furniture','.b-switch .bootstrap-switch','border-bottom-left-radius','14','','','.b-switch'),(885744,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-left-radius','25','','','.b-switch'),(885745,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-bottom-left-radius','0','','','.b-product-images'),(885746,'furniture','.b-trade-approval .steps-bar','border-bottom-left-radius','18','','','.b-trade-approval'),(885747,'furniture','.w-delivery-day .left-count','border-bottom-left-radius','3','','','.w-delivery-day'),(885748,'furniture','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-left-radius','3','','','.w-delivery-day'),(885752,'furniture','.menu-header .burger-icon','border-bottom-left-radius','50','5140','','.menu-header'),(885753,'furniture','.w-quote .cart-box-link','border-bottom-left-radius','50','3','','.w-quote'),(885754,'furniture','.w-product-sale-ends .left-count','border-bottom-left-radius','3','','','.w-product-sale-ends'),(885755,'furniture','.w-product-sale-ends .left-count-days','border-bottom-left-radius','3','','','.w-product-sale-ends'),(885756,'furniture','.w-product-sale-ends .left-count-hours','border-bottom-left-radius','3','','','.w-product-sale-ends'),(885757,'furniture','.w-sample .cart-box-link','border-bottom-left-radius','50','3','','.w-sample'),(885758,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-left-radius','50','','','.w-questionnaire-widgets-questionnaire'),(885759,'furniture','.w-sale-category .badge','border-bottom-left-radius','50','','','.w-sale-category'),(885760,'furniture','.w-sale-category .left-count','border-bottom-left-radius','3','','','.w-sale-category'),(885761,'furniture','.w-sale-category .left-count-days','border-bottom-left-radius','3','','','.w-sale-category'),(885762,'furniture','.w-sale-category .left-count-hours','border-bottom-left-radius','3','','','.w-sale-category'),(885763,'furniture','.b-products-listing .productGroup label a','border-bottom-left-radius','3','','','.b-products-listing'),(885764,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-left-radius','12','','','.w-predefined-promotion'),(885765,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-left-radius','12','','','.w-predefined-promotion'),(885766,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-left-radius','12','','','.w-predefined-promotion'),(885767,'furniture','.w-predefined-promotion .promo-salemaker .discount','border-bottom-left-radius','12','','','.w-predefined-promotion'),(885768,'furniture','.w-cart-listing .promos-info .promo-name','border-bottom-left-radius','0','','','.w-cart-listing'),(885769,'furniture','.w-product-promotion-icons .promos-info .promo-name','border-bottom-left-radius','0','','','.w-product-promotion-icons'),(885771,'furniture','.catalog-product-wrap .pn-image','border-bottom-left-radius','50','3','','.catalog-product-wrap'),(885772,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-left-radius','50','','','.b-multi-page-checkout'),(885773,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-left-radius','50','3','','.b-multi-page-checkout'),(885774,'furniture','.success-page .w-cart-listing .qty','border-bottom-left-radius','50','','','.success-page'),(885775,'furniture','.lowestPricedBox .w-banner .ybg','border-bottom-left-radius','50','3','','.lowestPricedBox'),(885776,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-left-radius','0','','','.w-catalog-paging'),(885777,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-bottom-right-radius','0','4','','.b-switch'),(885778,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-right-radius','15','4','','.b-switch'),(885779,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.p-quick-order-index'),(885780,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.p-quick-order-index'),(885781,'furniture','.w-promotions .prom-multi-discount .promo-range','border-bottom-right-radius','12','','','.w-promotions'),(885782,'furniture','.w-promotions .promo-salemaker .discount','border-bottom-right-radius','12','','','.w-promotions'),(885783,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-right-radius','12','','','.w-promotions'),(885784,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-right-radius','12','','','.w-promotions'),(885785,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-right-radius','5','','','.b-messages'),(885786,'furniture','.b-fancybox .fancybox-close','border-bottom-right-radius','50','','','.b-fancybox'),(885787,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-right-radius','25','','','.b-switch'),(885788,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-bottom-right-radius','0','3','','.b-switch'),(885789,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-right-radius','15','3','','.b-switch'),(885790,'furniture','.b-switch .candlestick-wrapper .candlestick-bg','border-bottom-right-radius','15','','','.b-switch'),(885791,'furniture','.w-checkout-shipping-choice label:last-child span','border-bottom-right-radius','16','','','.w-checkout-shipping-choice'),(885792,'furniture','.w-checkout-shipping-choice label:first-child span','border-bottom-right-radius','0','','','.w-checkout-shipping-choice'),(885793,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(885794,'furniture','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-right-radius','15','','','.b-fancybox'),(885795,'furniture','.b-fancybox .fancybox-skin','border-bottom-right-radius','4','','','.b-fancybox'),(885796,'furniture','.b-upload-file .snapshot','border-bottom-right-radius','50','','','.b-upload-file'),(885797,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-bottom-right-radius','50','3','','.b-switch'),(885798,'furniture','.b-fancybox .fancybox-nav span','border-bottom-right-radius','50','','','.b-fancybox'),(885799,'furniture','.w-product-customers-activity .close','border-bottom-right-radius','50','','','.w-product-customers-activity'),(885800,'furniture','.w-product-customers-activity .customers-activity','border-bottom-right-radius','0','','','.w-product-customers-activity'),(885801,'furniture','.w-personal-gift-status-bar .progress-bar','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(885802,'furniture','.b-switch .bootstrap-switch','border-bottom-right-radius','14','','','.b-switch'),(885803,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.b-data-table'),(885804,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.b-data-table'),(885805,'furniture','.b-products-listing .promos-info .promo-name','border-bottom-right-radius','8','','','.b-products-listing'),(885806,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(885807,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-right-radius','50','3','','.b-form'),(885808,'furniture','.w-personal-gift-status-bar .progress-bar-content','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(885809,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-right-radius','25','','','.b-switch'),(885810,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-bottom-right-radius','0','','','.b-product-images'),(885811,'furniture','.b-trade-approval .steps-bar','border-bottom-right-radius','18','','','.b-trade-approval'),(885812,'furniture','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-right-radius','3','','','.w-delivery-day'),(885813,'furniture','.w-delivery-day .left-count','border-bottom-right-radius','3','','','.w-delivery-day'),(885817,'furniture','.menu-header .burger-icon','border-bottom-right-radius','50','5140','','.menu-header'),(885818,'furniture','.w-quote .cart-box-link','border-bottom-right-radius','50','3','','.w-quote'),(885819,'furniture','.w-product-sale-ends .left-count','border-bottom-right-radius','3','','','.w-product-sale-ends'),(885820,'furniture','.w-product-sale-ends .left-count-days','border-bottom-right-radius','3','','','.w-product-sale-ends'),(885821,'furniture','.w-product-sale-ends .left-count-hours','border-bottom-right-radius','3','','','.w-product-sale-ends'),(885822,'furniture','.w-sample .cart-box-link','border-bottom-right-radius','50','3','','.w-sample'),(885823,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-right-radius','50','','','.w-questionnaire-widgets-questionnaire'),(885824,'furniture','.w-sale-category .badge','border-bottom-right-radius','50','','','.w-sale-category'),(885825,'furniture','.w-sale-category .left-count','border-bottom-right-radius','3','','','.w-sale-category'),(885826,'furniture','.w-sale-category .left-count-days','border-bottom-right-radius','3','','','.w-sale-category'),(885827,'furniture','.w-sale-category .left-count-hours','border-bottom-right-radius','3','','','.w-sale-category'),(885828,'furniture','.b-products-listing .productGroup label a','border-bottom-right-radius','3','','','.b-products-listing'),(885829,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-right-radius','12','','','.w-predefined-promotion'),(885830,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-right-radius','12','','','.w-predefined-promotion'),(885831,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-right-radius','12','','','.w-predefined-promotion'),(885832,'furniture','.w-predefined-promotion .promo-salemaker .discount','border-bottom-right-radius','12','','','.w-predefined-promotion'),(885833,'furniture','.w-cart-listing .promos-info .promo-name','border-bottom-right-radius','8','','','.w-cart-listing'),(885834,'furniture','.w-product-promotion-icons .promos-info .promo-name','border-bottom-right-radius','8','','','.w-product-promotion-icons'),(885836,'furniture','.catalog-product-wrap .pn-image','border-bottom-right-radius','50','3','','.catalog-product-wrap'),(885837,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-right-radius','50','','','.b-multi-page-checkout'),(885838,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-right-radius','50','3','','.b-multi-page-checkout'),(885839,'furniture','.success-page .w-cart-listing .qty','border-bottom-right-radius','50','','','.success-page'),(885840,'furniture','.lowestPricedBox .w-banner .ybg','border-bottom-right-radius','50','3','','.lowestPricedBox'),(885841,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-right-radius','0','','','.w-catalog-paging'),(885842,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(885843,'furniture','.b-upload-file .upload-file-template div','border-bottom-style','dotted','','','.b-upload-file'),(885844,'furniture','.mainBanner .title','border-bottom-style','dashed','','','.mainBanner'),(885845,'furniture','.w-promotions .prom-multi-discount .promo-range','border-bottom-width','1','','','.w-promotions'),(885847,'furniture','.testimonials .review','border-bottom-width','7','3','',''),(885848,'furniture','.w-promotions .promo-salemaker .discount','border-bottom-width','1','','','.w-promotions'),(885849,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-width','1','','','.w-promotions'),(885850,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-width','1','','','.w-promotions'),(885851,'furniture','.b-upload-file .upload-file-template div','border-bottom-width','1','','','.b-upload-file'),(885852,'furniture','.w-cart-compare .cart-cell > div','border-bottom-width','1','','','.w-cart-compare'),(885853,'furniture','.w-filters .filter-box-head','border-bottom-width','1','','','.w-filters'),(885854,'furniture','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-bottom-width','1','','','.b-bottom'),(885855,'furniture','.b-messages .msv_btn','border-bottom-width','1','','','.b-messages'),(885856,'furniture','.b-messages .email-heading','border-bottom-width','1','','','.b-messages'),(885857,'furniture','.b-messages .content_management_attach button','border-bottom-width','1','','','.b-messages'),(885858,'furniture','.b-messages .content_management_attach','border-bottom-width','1','','','.b-messages'),(885859,'furniture','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-width','2','','','.b-messages'),(885860,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-width','1','','','.b-messages'),(885861,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-width','1','','','.b-messages'),(885862,'furniture','.b-messages .dataTables_wrapper > .bottom','border-bottom-width','1','','','.b-messages'),(885863,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-bottom-width','2','','',''),(885864,'furniture','.p-payer-order-confirmation .input-wrapper','border-bottom-width','2','','','.p-payer-order-confirmation'),(885865,'furniture','.p-payer-order-pay .input-wrapper','border-bottom-width','2','','','.p-payer-order-pay'),(885866,'furniture','.b-messages .msv_to_cc','border-bottom-width','1','','','.b-messages'),(885867,'furniture','.w-product-reviews .reviews-list .review','border-bottom-width','7','3','','.w-product-reviews'),(885868,'furniture','.w-reviews .review','border-bottom-width','8','3','','.w-reviews'),(885869,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(885870,'furniture','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(885871,'furniture','.w-tabs .accordion-heading','border-bottom-width','1','','','.w-tabs'),(885872,'furniture','.b-form .required-error','border-bottom-width','1','','','.b-form'),(885873,'furniture','.w-socials > li','border-bottom-width','1','','','.w-socials'),(885874,'furniture','.b-bottom .popup-heading','border-bottom-width','1','','','.b-bottom'),(885875,'furniture','.w-checkout-shipping-choice span','border-bottom-width','2','','','.w-checkout-shipping-choice'),(885876,'furniture','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(885877,'furniture','.w-socials > li','border-bottom-width','1','','','.w-socials'),(885880,'furniture','.b-info-popup .info-popup div','border-bottom-width','1','','','.b-info-popup'),(885881,'furniture','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(885882,'furniture','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(885883,'furniture','.w-tabs > .block','border-bottom-width','1','','','.w-tabs'),(885884,'furniture','.w-tabs .accordion-heading','border-bottom-width','3','2','','.w-tabs'),(885885,'furniture','.w-socials > li','border-bottom-width','1','','','.w-socials'),(885886,'furniture','.w-cart-give-away .ga_column','border-bottom-width','1','','','.w-cart-give-away'),(885887,'furniture','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(885888,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-width','4','','','.b-switch'),(885889,'furniture','.w-filters .ui-slider-handle','border-bottom-width','0','','','.w-filters'),(885890,'furniture','.w-filters .ui-slider','border-bottom-width','0','','','.w-filters'),(885891,'furniture','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(885892,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-width','2','3','','.b-form'),(885893,'furniture','.b-upload-file .upload-file-template','border-bottom-width','1','','','.b-upload-file'),(885894,'furniture','.w-socials > li','border-bottom-width','1','','','.w-socials'),(885895,'furniture','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(885896,'furniture','.w-reviews .item','border-bottom-width','1','','','.w-reviews'),(885897,'furniture','.b-select-suggest .select2-container .select2-choice','border-bottom-width','2','','','.b-select-suggest'),(885898,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-width','2','4','','.b-switch'),(885900,'furniture','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(885901,'furniture','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-width','1','','','.b-compare'),(885902,'furniture','.w-cart-compare .compare-table','border-bottom-width','1','','','.w-cart-compare'),(885903,'furniture','.w-reviews-content .review','border-bottom-width','8','3','','.w-reviews-content'),(885904,'furniture','textarea','border-bottom-width','2','','',''),(885905,'furniture','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-bottom-width','1','','','.b-bottom'),(885906,'furniture','.b-bottom .footerTitle','border-bottom-width','1','5131','','.b-bottom'),(885907,'furniture','.w-socials > li','border-bottom-width','1','','','.w-socials'),(885908,'furniture','.b-bottom .popup-box','border-bottom-width','1','','','.b-bottom'),(885909,'furniture','.w-product-customers-activity .customers-activity','border-bottom-width','1','','','.w-product-customers-activity'),(885910,'furniture','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(885911,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(885912,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(885913,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(885914,'furniture','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(885915,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-width','1','','','.b-select-suggest'),(885916,'furniture','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(885917,'furniture','.b-select-suggest .select2-search input','border-bottom-width','1','','','.b-select-suggest'),(885918,'furniture','.b-select-suggest .select2-drop-active','border-bottom-width','1','','','.b-select-suggest'),(885919,'furniture','.b-select-suggest .select2-drop','border-bottom-width','1','','','.b-select-suggest'),(885920,'furniture','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(885921,'furniture','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(885922,'furniture','.w-communication-post .communication-post','border-bottom-width','1','','','.w-communication-post'),(885923,'furniture','.checkbox input:checked + span','border-bottom-width','1','','',''),(885924,'furniture','.checkbox input + span','border-bottom-width','1','','',''),(885925,'furniture','.b-autocomplete .ui-autocomplete','border-bottom-width','1','','','.b-autocomplete'),(885928,'furniture','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(885929,'furniture','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(885930,'furniture','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(885931,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-width','2','3','','.b-switch'),(885932,'furniture','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(885933,'furniture','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(885934,'furniture','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(885935,'furniture','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(885936,'furniture','.w-cart-listing .item .gift-wrap label','border-bottom-width','1','','','.w-cart-listing'),(885937,'furniture','.w-cart-listing .item','border-bottom-width','1','5140','','.w-cart-listing'),(885940,'furniture','.w-socials > li','border-bottom-width','1','','','.w-socials'),(885942,'furniture','.w-reviews-content .item','border-bottom-width','1','','','.w-reviews-content'),(885943,'furniture','.w-filters .ui-slider-range','border-bottom-width','0','','','.w-filters'),(885944,'furniture','.b-upload-files .upload-files','border-bottom-width','1','','','.b-upload-files'),(885945,'furniture','.b-compare .compare_pagination','border-bottom-width','1','','','.b-compare'),(885946,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-width','3','','','.b-switch'),(885947,'furniture','.b-upload-file .snapshot','border-bottom-width','1','','','.b-upload-file'),(885948,'furniture','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-bottom-width','2','','','.b-product-images'),(885949,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','border-bottom-width','1','','','.b-menu-style-2'),(885950,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-bottom-width','1','','','.b-menu-style-2'),(885951,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-bottom-width','3','','','.b-menu-style-2'),(885952,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-bottom-width','1','','','.b-menu-style-2'),(885953,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-bottom-width','3','','','.b-menu-style-2'),(885954,'furniture','.b-trade-approval .orders-table th','border-bottom-width','1','','','.b-trade-approval'),(885955,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-width','2','','','.b-trade-approval'),(885956,'furniture','.w-account-personal-catalog .list-switcher a','border-bottom-width','1','','','.w-account-personal-catalog'),(885957,'furniture','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-width','1','','','.w-catalog-compare'),(885958,'furniture','.w-catalog-compare .cross-box .different-all > div','border-bottom-width','1','','','.w-catalog-compare'),(885959,'furniture','.w-delivery-day .left-text-right','border-bottom-width','2','','','.w-delivery-day'),(885960,'furniture','.w-delivery-day .left-text-left','border-bottom-width','2','','','.w-delivery-day'),(885963,'furniture','.b-slick .slick-vertical .slick-slide','border-bottom-width','1','','','.b-slick'),(885964,'furniture','.w-cart-listing .item, .w-cart-listing .headings','border-bottom-width','1','','','.w-cart-listing'),(885965,'furniture','.b-products-listing .products-listing .compare input + span','border-bottom-width','1','','','.b-products-listing'),(885966,'furniture','.w-filters .filter-widget','border-bottom-width','1','','','.w-filters'),(885967,'furniture','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-bottom-width','0','','','.w-filters'),(885968,'furniture','.w-quote .cart-content','border-bottom-width','1','','','.w-quote'),(885969,'furniture','.w-quote .cart-total','border-bottom-width','1','','','.w-quote'),(885970,'furniture','.w-quote .multicart .item','border-bottom-width','1','','','.w-quote'),(885971,'furniture','.b-product-images .additional-images .active img','border-bottom-width','2','','','.b-product-images'),(885972,'furniture','.b-product-images .additional-images img','border-bottom-width','2','','','.b-product-images'),(885973,'furniture','.b-quantity .qty-box .bigger','border-bottom-width','2','','','.b-quantity'),(885974,'furniture','.b-quantity .qty-box .smaller','border-bottom-width','2','','','.b-quantity'),(885975,'furniture','.w-product-sale-ends .left-text-left','border-bottom-width','2','','','.w-product-sale-ends'),(885976,'furniture','.w-product-sale-ends .left-text-right','border-bottom-width','2','','','.w-product-sale-ends'),(885977,'furniture','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(885978,'furniture','.warrantyProduct .warranty, .warrantyProduct .delivery','border-bottom-width','1','','','.warrantyProduct'),(885979,'furniture','.w-sample .cart-box-link','border-bottom-width','1','4','','.w-sample'),(885980,'furniture','.w-sample .cart-content','border-bottom-width','1','','','.w-sample'),(885981,'furniture','.w-sample .cart-total','border-bottom-width','1','','','.w-sample'),(885982,'furniture','.w-sample .multicart .item','border-bottom-width','1','','','.w-sample'),(885983,'furniture','.w-cart-listing .points-earn','border-bottom-width','17','4','','.w-cart-listing'),(885984,'furniture','.w-cart-discount-coupon .btn','border-bottom-width','2','','','.w-cart-discount-coupon'),(885985,'furniture','.w-product-video .item img, .w-product-video .item video','border-bottom-width','2','','','.w-product-video'),(885986,'furniture','.w-product-video .item.active img, .w-product-video .item.active video','border-bottom-width','2','','','.w-product-video'),(885987,'furniture','.shipping-ico .heading-3','border-bottom-width','1','','','.shipping-ico'),(885988,'furniture','.w-cart-order-reference .btn','border-bottom-width','2','','','.w-cart-order-reference'),(885989,'furniture','.w-cart-gift-certificate .btn','border-bottom-width','2','','','.w-cart-gift-certificate'),(885990,'furniture','.w-cart-shipping-estimator .btn','border-bottom-width','2','','','.w-cart-shipping-estimator'),(885992,'furniture','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-bottom-width','1','','','.b-pagination'),(885993,'furniture','.b-pagination .pagination .next-pages','border-bottom-width','1','','','.b-pagination'),(885994,'furniture','.b-pagination .pagination .page-number','border-bottom-width','1','','','.b-pagination'),(885995,'furniture','.b-pagination .pagination .prev-pages','border-bottom-width','1','','','.b-pagination'),(885996,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-bottom-width','1','','','.b-pagination'),(885997,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-bottom-width','1','','','.b-pagination'),(885998,'furniture','.b-pagination .pagination span','border-bottom-width','1','2','','.b-pagination'),(885999,'furniture','.w-tabs .tab-li','border-bottom-width','1','','','.w-tabs'),(886000,'furniture','.w-product-multi-inventory .radio-attributes','border-bottom-width','1','','','.w-product-multi-inventory'),(886001,'furniture','.w-product-multi-inventory .radio-attributes .option-item','border-bottom-width','2','','','.w-product-multi-inventory'),(886002,'furniture','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-bottom-width','2','','','.w-product-multi-inventory'),(886003,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-bottom-width','1','','','.w-account-personal-catalog'),(886004,'furniture','.w-account-personal-catalog .list-row-action ul','border-bottom-width','1','','','.w-account-personal-catalog'),(886005,'furniture','.b-products-listing .products-listing .radio-attributes','border-bottom-width','1','','','.b-products-listing'),(886006,'furniture','.b-products-listing .products-listing .radio-attributes .option','border-bottom-width','2','','','.b-products-listing'),(886007,'furniture','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-bottom-width','2','','','.b-products-listing'),(886008,'furniture','.w-product-attributes .radio-attributes','border-bottom-width','1','','','.w-product-attributes'),(886009,'furniture','.w-product-attributes .radio-attributes .option-item','border-bottom-width','2','','','.w-product-attributes'),(886010,'furniture','.w-product-attributes .radio-attributes input:checked + .option-item','border-bottom-width','2','','','.w-product-attributes'),(886011,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-width','2','','','.w-questionnaire-widgets-questionnaire'),(886012,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-bottom-width','2','','','.w-questionnaire-widgets-questionnaire'),(886013,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-bottom-width','2','','','.w-questionnaire-widgets-questionnaire'),(886014,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-bottom-width','2','1','','.w-questionnaire-widgets-questionnaire'),(886015,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-bottom-width','2','1','','.w-questionnaire-widgets-questionnaire'),(886016,'furniture','.w-product-groups .radioBox label .containerBlock','border-bottom-width','2','','','.w-product-groups'),(886017,'furniture','.w-product-groups .radioBox label .containerBlock.selected','border-bottom-width','2','','','.w-product-groups'),(886018,'furniture','.w-product-groups .radioBox label input:checked + .containerBlock','border-bottom-width','2','','','.w-product-groups'),(886019,'furniture','.w-delivery-location-top-location-list .deliveryName','border-bottom-width','1','','','.w-delivery-location-top-location-list'),(886020,'furniture','.w-delivery-location-location-list .deliveryName','border-bottom-width','1','','','.w-delivery-location-location-list'),(886021,'furniture','.w-delivery-location-location-list .deliveryList li a','border-bottom-width','2','','','.w-delivery-location-location-list'),(886022,'furniture','.w-delivery-location-location-list .deliveryList li a','border-bottom-width','2','1','','.w-delivery-location-location-list'),(886023,'furniture','.w-sale-category .left-text-left','border-bottom-width','2','','','.w-sale-category'),(886024,'furniture','.w-sale-category .left-text-right','border-bottom-width','2','','','.w-sale-category'),(886025,'furniture','.w-sale-category .sale-holder','border-bottom-width','2','','','.w-sale-category'),(886026,'furniture','.w-catalog-delivery-locations .name','border-bottom-width','1','','','.w-catalog-delivery-locations'),(886027,'furniture','.w-product-designer-designer .prodDesignerType label','border-bottom-width','1','','','.w-product-designer-designer'),(886028,'furniture','.w-press-reviews-widgets-press-reviews-small ','border-bottom-width','1','','','.w-press-reviews-widgets-press-reviews-small'),(886029,'furniture','.b-products-listing .productGroup label a','border-bottom-width','1','','','.b-products-listing'),(886030,'furniture','.w-support-system-listing .support-head','border-bottom-width','1','','','.w-support-system-listing'),(886031,'furniture','.w-support-system-listing .product_icon','border-bottom-width','1','','','.w-support-system-listing'),(886032,'furniture','.w-rma-returns-history .topRow','border-bottom-width','1','','','.w-rma-returns-history'),(886033,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-width','1','','','.w-predefined-promotion'),(886034,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-width','1','','','.w-predefined-promotion'),(886035,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-width','1','','','.w-predefined-promotion'),(886036,'furniture','.w-predefined-promotion .promo-salemaker .discount','border-bottom-width','1','','','.w-predefined-promotion'),(886037,'furniture','.w-supplier-purchase-supplier-products .item','border-bottom-width','1','','','.w-supplier-purchase-supplier-products'),(886038,'furniture','.mainBanner .bottomBox .btn','border-bottom-width','0.21','','','.mainBanner'),(886039,'furniture','.mainBanner .title','border-bottom-width','2','','','.mainBanner'),(886040,'furniture','.mainBanner .topBox > .right','border-bottom-width','23','4','','.mainBanner'),(886041,'furniture','.mainBanner .bottomBox .btn','border-bottom-width','2','5145','','.mainBanner'),(886042,'furniture','.mainBanner .topBox > .right','border-bottom-width','20','5145,4','','.mainBanner'),(886043,'furniture','.mainBanner .bottomBox .btn','border-bottom-width','3','5131','','.mainBanner'),(886044,'furniture','.mainBanner .topBox > .right','border-bottom-width','15','5131,4','','.mainBanner'),(886045,'furniture','.mainBanner .bottomBox .btn','border-bottom-width','2','5161','','.mainBanner'),(886046,'furniture','.mainBanner .bottomBox .btn','border-bottom-width','3','5206','','.mainBanner'),(886047,'furniture','.order-summary .cart-listing.w-cart-listing.type-2.summary-listing','border-bottom-width','1','','','.order-summary'),(886048,'furniture','.order-summary .checkout-cart-listing','border-bottom-width','1','','','.order-summary'),(886049,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','border-bottom-width','1','','','.w-promotions-widgets-promotion-icons-desc'),(886050,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item:last-of-type','border-bottom-width','0','','','.w-promotions-widgets-promotion-icons-desc'),(886051,'furniture','.w-product-quantity-discounts .item','border-bottom-width','1','','','.w-product-quantity-discounts'),(886054,'furniture','.account-address-book .address_book h1','border-bottom-width','1','','','.account-address-book'),(886055,'furniture','.account-address-book .address_book h2','border-bottom-width','1','','','.account-address-book'),(886058,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','border-bottom-width','1','','','.account-order-pay'),(886059,'furniture','.account-samples .orders-table .item','border-bottom-width','1','5140','','.account-samples'),(886060,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','border-bottom-width','1','','','.account-sample-info'),(886061,'furniture','.catalog-product-wrap .pn-image','border-bottom-width','2','3','','.catalog-product-wrap'),(886062,'furniture','.catalog-product-wrap .prev-next-product','border-bottom-width','1','','','.catalog-product-wrap'),(886063,'furniture','.checkout-index-wrap .input-wrapper','border-bottom-width','2','','','.checkout-index-wrap'),(886064,'furniture','.shopping-cart-index .btn-3','border-bottom-width','2','','','.shopping-cart-index'),(886065,'furniture','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(886066,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(886067,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-width','1','','','.b-multi-page-checkout'),(886068,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','border-bottom-width','1','5140','','.footer-menu'),(886069,'furniture','.lowestPricedBox .w-banner .ybg .btn','border-bottom-width','2','','','.lowestPricedBox'),(886070,'furniture','.shopByCollectionBox .bannerButton a','border-bottom-width','2','','','.shopByCollectionBox'),(886071,'furniture','.shopByCollectionBox .bannerButton a','border-bottom-width','2','5145','','.shopByCollectionBox'),(886072,'furniture','.w-catalog-paging ','border-bottom-width','1','2','','.w-catalog-paging'),(886073,'furniture','.w-catalog-paging .next','border-bottom-width','1','','','.w-catalog-paging'),(886074,'furniture','.w-catalog-paging .next-pages','border-bottom-width','1','','','.w-catalog-paging'),(886075,'furniture','.w-catalog-paging .page-number','border-bottom-width','1','','','.w-catalog-paging'),(886076,'furniture','.w-catalog-paging .prev','border-bottom-width','1','','','.w-catalog-paging'),(886077,'furniture','.w-catalog-paging .prev-pages','border-bottom-width','1','','','.w-catalog-paging'),(886078,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-width','1','','','.w-catalog-paging'),(886079,'furniture','.w-compare-box-item .checkbox + span','border-bottom-width','1','','','.w-compare-box-item'),(886080,'furniture','.w-compare-box-item .checkbox:checked + span','border-bottom-width','1','','','.w-compare-box-item'),(886081,'furniture','.b-compare .popupCompare table','border-collapse','collapse','','','.b-compare'),(886082,'furniture','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','border-left','none','','','.b-select-suggest'),(886083,'furniture','.w-promotions .prom-multi-discount .promo-range','border-left-color','$warning-border','','','.w-promotions'),(886084,'furniture','.w-cart-compare .attributes-block td:nth-child(1)','border-left-color','$content-border-1','','','.w-cart-compare'),(886086,'furniture','.w-promotions .promo-salemaker .discount','border-left-color','$warning-border','','','.w-promotions'),(886087,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-color','$warning-border','','','.w-promotions'),(886088,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border-left-color','$warning-border','','','.w-promotions'),(886089,'furniture','.w-cart-compare .cart-cell > div','border-left-color','$content-border-1','','','.w-cart-compare'),(886090,'furniture','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(886091,'furniture','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-left-color','$content-border-1','','','.b-bottom'),(886092,'furniture','.b-messages .content_management_attach button','border-left-color','$content-border-2','','','.b-messages'),(886093,'furniture','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-color','$content-border-1','','','.b-messages'),(886094,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-left-color','$content-border-1','','',''),(886095,'furniture','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(886096,'furniture','.w-cart-products .checkout-attention-message','border-left-color','$warning-border','','','.w-cart-products'),(886097,'furniture','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(886098,'furniture','.p-payer-order-confirmation .input-wrapper','border-left-color','$content-border-1','','','.p-payer-order-confirmation'),(886099,'furniture','.p-payer-order-pay .input-wrapper','border-left-color','$content-border-1','','','.p-payer-order-pay'),(886100,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-left-color','$switch-nc-border-1','','','.b-switch'),(886101,'furniture','.w-cart-products .checkout-attention-message','border-left-color','$warning-border','','','.w-cart-products'),(886102,'furniture','.w-cart-products .checkout-attention-message','border-left-color','$warning-border','','','.w-cart-products'),(886103,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(886104,'furniture','.b-info-popup .info-popup div','border-left-color','$content-border-1','3','','.b-info-popup'),(886105,'furniture','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-color','$content-border-2','','','.b-compare'),(886106,'furniture','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(886107,'furniture','.b-form .required-error','border-left-color','$attention-border','','','.b-form'),(886108,'furniture','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(886109,'furniture','.b-info-popup .info-popup div','border-left-color','$content-border-1','','','.b-info-popup'),(886110,'furniture','.w-checkout-shipping-choice label:first-child span','border-left-color','$highlight-box-border-2','','','.w-checkout-shipping-choice'),(886111,'furniture','.w-product-reviews .reviews-list .review','border-left-color','$content-border-1','3','','.w-product-reviews'),(886112,'furniture','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(886113,'furniture','.w-tabs > .block','border-left-color','$tab-content-border-1','','','.w-tabs'),(886114,'furniture','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(886115,'furniture','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(886116,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-left-color','$switch-handle-bg-3','','','.b-switch'),(886117,'furniture','.w-reviews .review','border-left-color','$content-bg-1','3','','.w-reviews'),(886118,'furniture','.w-reviews-content .review','border-left-color','$content-border-1','3','','.w-reviews-content'),(886119,'furniture','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(886120,'furniture','.b-select-suggest .select2-container .select2-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(886121,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-left-color','$switch-nc-border-1','4','','.b-switch'),(886123,'furniture','.w-cart-products .checkout-attention-message','border-left-color','$warning-border','','','.w-cart-products'),(886124,'furniture','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(886125,'furniture','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-left-color','$border-color-9','','','.b-bottom'),(886126,'furniture','textarea','border-left-color','$content-border-1','','',''),(886127,'furniture','.b-bottom .popup-box','border-left-color','$content-border-1','','','.b-bottom'),(886128,'furniture','.w-product-customers-activity .customers-activity','border-left-color','$content-border-1','','','.w-product-customers-activity'),(886129,'furniture','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(886130,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border-left-color','$checkbox-border-1','3','','.b-form'),(886131,'furniture','.w-cart-compare .price-block td:nth-child(1)','border-left-color','$content-border-1','','','.w-cart-compare'),(886132,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(886133,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-color','$content-border-1','','','.b-select-suggest'),(886134,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(886135,'furniture','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-color','$content-border-1','','','.b-select-suggest'),(886136,'furniture','.b-select-suggest .select2-container-multi .select2-choices','border-left-color','$content-border-1','','','.b-select-suggest'),(886137,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(886138,'furniture','.b-select-suggest .select2-search input','border-left-color','$content-border-1','','','.b-select-suggest'),(886139,'furniture','.b-select-suggest .select2-drop','border-left-color','$content-border-1','','','.b-select-suggest'),(886140,'furniture','.b-select-suggest .select2-drop-active','border-left-color','$content-border-1','','','.b-select-suggest'),(886141,'furniture','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(886142,'furniture','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(886143,'furniture','.b-form input.required-error','border-left-color','$attention-border','','','.b-form'),(886144,'furniture','.checkbox input:checked + span','border-left-color','$checkbox-border-1','','',''),(886145,'furniture','.checkbox input + span','border-left-color','$content-border-1','','',''),(886146,'furniture','.b-autocomplete .ui-autocomplete','border-left-color','$content-border-1','','','.b-autocomplete'),(886149,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-left-color','$switch-nc-border-1','3','','.b-switch'),(886150,'furniture','.b-upload-file .snapshot','border-left-color','$content-border-2','','','.b-upload-file'),(886151,'furniture','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(886152,'furniture','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(886153,'furniture','.b-upload-files .upload-files','border-left-color','$content-border-1','','','.b-upload-files'),(886154,'furniture','.b-upload-file .upload-file-template','border-left-color','$content-border-1','','','.b-upload-file'),(886155,'furniture','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(886156,'furniture','.w-cart-products .checkout-attention-message','border-left-color','$warning-border','','','.w-cart-products'),(886157,'furniture','.w-cart-listing .item .gift-wrap label','border-left-color','$content-border-1','','','.w-cart-listing'),(886158,'furniture','.w-cart-listing .item','border-left-color','$content-border-1','5140','','.w-cart-listing'),(886160,'furniture','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(886161,'furniture','.w-cart-products .checkout-attention-message','border-left-color','$warning-border','','','.w-cart-products'),(886162,'furniture','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(886163,'furniture','.w-cart-compare .product-block td:nth-child(1)','border-left-color','$content-border-1','','','.w-cart-compare'),(886164,'furniture','.b-data-table table.dataTable.no-footer','border-left-color','$content-border-1','','','.b-data-table'),(886165,'furniture','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-left-color','$image-popup-border-1','','','.b-product-images'),(886166,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-left-color','$header-menu-border-1','','','.b-menu-style-2'),(886167,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-left-color','$header-menu-border-1','','','.b-menu-style-2'),(886168,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-left-color','$header-menu-border-1','','','.b-menu-style-2'),(886169,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-left-color','$header-menu-border-1','','','.b-menu-style-2'),(886170,'furniture','.b-trade-approval .steps-bar li ~ li a','border-left-color','$highlight-box-border-1','','','.b-trade-approval'),(886171,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-color','$content-border-1','','','.b-trade-approval'),(886172,'furniture','.w-account-personal-catalog .list-switcher a','border-left-color','$content-border-1','2','','.w-account-personal-catalog'),(886173,'furniture','.w-catalog-compare .compare .checkbox input:checked + span','border-left-color','$content-bg-1','','','.w-catalog-compare'),(886174,'furniture','.w-catalog-compare .cross-box .different-all > div','border-left-color','$content-border-1','2','','.w-catalog-compare'),(886176,'furniture','.b-products-listing .products-listing .compare input + span','border-left-color','$content-border-2','','','.b-products-listing'),(886177,'furniture','.w-filters .filter-widget','border-left-color','$content-border-1','','','.w-filters'),(886178,'furniture','.w-quote .cart-content','border-left-color','$content-border-1','','','.w-quote'),(886179,'furniture','.b-product-images .additional-images .active img','border-left-color','$highlight-box-color-1','','','.b-product-images'),(886180,'furniture','.b-product-images .additional-images img','border-left-color','$content-border-1','','','.b-product-images'),(886181,'furniture','.b-quantity .qty-box .bigger','border-left-color','$content-border-1','','','.b-quantity'),(886182,'furniture','.b-quantity .qty-box .smaller','border-left-color','$content-border-1','','','.b-quantity'),(886183,'furniture','.w-sample .cart-content','border-left-color','$content-border-1','','','.w-sample'),(886184,'furniture','.w-cart-listing .points-earn','border-left-color','$content-border-1','4','','.w-cart-listing'),(886185,'furniture','.w-cart-discount-coupon .btn','border-left-color','$content-border-2','','','.w-cart-discount-coupon'),(886186,'furniture','.w-product-video .item img, .w-product-video .item video','border-left-color','$image-popup-border-1','','','.w-product-video'),(886187,'furniture','.w-product-video .item.active img, .w-product-video .item.active video','border-left-color','$highlight-box-border-1','','','.w-product-video'),(886188,'furniture','.w-cart-order-reference .btn','border-left-color','$content-border-2','','','.w-cart-order-reference'),(886189,'furniture','.w-cart-gift-certificate .btn','border-left-color','$content-border-2','','','.w-cart-gift-certificate'),(886190,'furniture','.w-cart-shipping-estimator .btn','border-left-color','$content-border-2','','','.w-cart-shipping-estimator'),(886192,'furniture','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-left-color','$content-border-2','','','.b-pagination'),(886193,'furniture','.b-pagination .pagination .next-pages','border-left-color','$content-border-1','','','.b-pagination'),(886194,'furniture','.b-pagination .pagination .page-number','border-left-color','$content-border-1','','','.b-pagination'),(886195,'furniture','.b-pagination .pagination .prev-pages','border-left-color','$content-border-1','','','.b-pagination'),(886196,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-left-color','$content-border-1','','','.b-pagination'),(886197,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-left-color','$content-border-1','','','.b-pagination'),(886198,'furniture','.b-pagination .pagination span','border-left-color','$highlight-box-border-2','2','','.b-pagination'),(886199,'furniture','.w-tabs .tab-li','border-left-color','$tab-nav-border-2','2','','.w-tabs'),(886200,'furniture','.w-product-multi-inventory .radio-attributes .option-item','border-left-color','$content-border-1','','','.w-product-multi-inventory'),(886201,'furniture','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-left-color','$content-border-2','','','.w-product-multi-inventory'),(886202,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-left-color','$content-border-1','','','.w-account-personal-catalog'),(886203,'furniture','.w-account-personal-catalog .list-row-action ul','border-left-color','$content-border-1','','','.w-account-personal-catalog'),(886204,'furniture','.b-products-listing .products-listing .radio-attributes .option','border-left-color','$content-border-1','','','.b-products-listing'),(886205,'furniture','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-left-color','$content-border-2','','','.b-products-listing'),(886206,'furniture','.w-product-attributes .radio-attributes .option-item','border-left-color','$content-border-1','','','.w-product-attributes'),(886207,'furniture','.w-product-attributes .radio-attributes input:checked + .option-item','border-left-color','$content-border-2','','','.w-product-attributes'),(886208,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-left-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(886209,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-left-color','$attention-border','','','.w-questionnaire-widgets-questionnaire'),(886210,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-left-color','$message-border','','','.w-questionnaire-widgets-questionnaire'),(886211,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-left-color','$attention-border','1','','.w-questionnaire-widgets-questionnaire'),(886212,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-left-color','$message-border','1','','.w-questionnaire-widgets-questionnaire'),(886213,'furniture','.w-product-groups .radioBox label .containerBlock','border-left-color','$content-border-1','','','.w-product-groups'),(886214,'furniture','.w-product-groups .radioBox label .containerBlock.selected','border-left-color','$content-border-2','','','.w-product-groups'),(886215,'furniture','.w-product-groups .radioBox label input:checked + .containerBlock','border-left-color','$content-border-2','','','.w-product-groups'),(886216,'furniture','.w-delivery-location-location-list .deliveryList li a','border-left-color','$content-border-1','','','.w-delivery-location-location-list'),(886217,'furniture','.w-delivery-location-location-list .deliveryList li a','border-left-color','$content-border-2','1','','.w-delivery-location-location-list'),(886218,'furniture','.w-sale-category .sale-holder','border-left-color','$content-border-1','','','.w-sale-category'),(886219,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-left-color','$content-border-1','','','.w-product-properties-icons'),(886220,'furniture','.w-product-designer-designer .prodDesignerType label','border-left-color','$content-border-1','','','.w-product-designer-designer'),(886221,'furniture','.b-products-listing .productGroup label a','border-left-color','$content-border-2','','','.b-products-listing'),(886222,'furniture','.w-support-system-listing .support-head','border-left-color','$content-border-1','','','.w-support-system-listing'),(886223,'furniture','.w-support-system-listing .product_icon','border-left-color','$content-border-1','','','.w-support-system-listing'),(886224,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border-left-color','$warning-border','','','.w-predefined-promotion'),(886225,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-left-color','$warning-border','','','.w-predefined-promotion'),(886226,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-left-color','$warning-border','','','.w-predefined-promotion'),(886227,'furniture','.w-predefined-promotion .promo-salemaker .discount','border-left-color','$warning-border','','','.w-predefined-promotion'),(886228,'furniture','.w-supplier-purchase-supplier-products .item','border-left-color','$content-border-1','','','.w-supplier-purchase-supplier-products'),(886229,'furniture','.mainBanner .bottomBox .btn','border-left-color','$main-banner-border-1','','','.mainBanner'),(886230,'furniture','.mainBanner .bottomBox .btn','border-left-color','$main-banner-border-1','5145','','.mainBanner'),(886231,'furniture','.mainBanner .bottomBox .btn','border-left-color','$main-banner-border-1','5131','','.mainBanner'),(886232,'furniture','.mainBanner .bottomBox .btn','border-left-color','$main-banner-border-1','5161','','.mainBanner'),(886233,'furniture','.mainBanner .bottomBox .btn','border-left-color','$main-banner-border-1','5206','','.mainBanner'),(886234,'furniture','.w-product-quantity-discounts .item','border-left-color','$content-border-1','','','.w-product-quantity-discounts'),(886237,'furniture','.account-samples .orders-table .item','border-left-color','$content-border-1','5140','','.account-samples'),(886238,'furniture','.catalog-product-wrap .pn-image','border-left-color','$content-border-1','3','','.catalog-product-wrap'),(886239,'furniture','.checkout-index-wrap .input-wrapper','border-left-color','$content-border-1','','','.checkout-index-wrap'),(886240,'furniture','.shopping-cart-index .btn-3','border-left-color','$content-border-2','','','.shopping-cart-index'),(886241,'furniture','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-color','$content-color-2','','','.b-multi-page-checkout'),(886242,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-color','$content-border-1','','','.b-multi-page-checkout'),(886243,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-color','$content-border-1','','','.b-multi-page-checkout'),(886244,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li + li','border-left-color','$footer-menu-border-1','5198','','.footer-menu'),(886245,'furniture','.lowestPricedBox .w-banner .ybg .btn','border-left-color','$additional-banner-border-1','','','.lowestPricedBox'),(886246,'furniture','.shopByCollectionBox .bannerButton a','border-left-color','$additional-banner-border-1','','','.shopByCollectionBox'),(886247,'furniture','.shopByCollectionBox .bannerButton a','border-left-color','$additional-banner-border-1','5145','','.shopByCollectionBox'),(886248,'furniture','.w-catalog-paging ','border-left-color','$content-border-1','2','','.w-catalog-paging'),(886249,'furniture','.w-catalog-paging .next','border-left-color','$content-border-1','','','.w-catalog-paging'),(886250,'furniture','.w-catalog-paging .next-pages','border-left-color','$content-border-1','','','.w-catalog-paging'),(886251,'furniture','.w-catalog-paging .page-number','border-left-color','$content-border-1','','','.w-catalog-paging'),(886252,'furniture','.w-catalog-paging .prev','border-left-color','$content-border-1','','','.w-catalog-paging'),(886253,'furniture','.w-catalog-paging .prev-pages','border-left-color','$content-border-1','','','.w-catalog-paging'),(886254,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-color','$content-border-1','','','.w-catalog-paging'),(886255,'furniture','.w-compare-box-item .checkbox + span','border-left-color','$content-border-1','','','.w-compare-box-item'),(886256,'furniture','.w-compare-box-item .checkbox:checked + span','border-left-color','$highlight-box-border-3','','','.w-compare-box-item'),(886257,'furniture','.b-data-table table.dataTable.no-footer','border-left-color_important','important','','','.b-data-table'),(886258,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(886259,'furniture','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(886260,'furniture','.w-promotions .prom-multi-discount .promo-range','border-left-width','1','','','.w-promotions'),(886261,'furniture','.w-cart-compare .attributes-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(886264,'furniture','.testimonials .review','border-left-width','10','3','',''),(886265,'furniture','.w-promotions .promo-salemaker .discount','border-left-width','1','','','.w-promotions'),(886266,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-width','1','','','.w-promotions'),(886267,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border-left-width','1','','','.w-promotions'),(886268,'furniture','.b-messages .content_management_attach button','border-left-width','1','','','.b-messages'),(886269,'furniture','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-width','2','','','.b-messages'),(886270,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-left-width','2','','',''),(886271,'furniture','.p-payer-order-confirmation .input-wrapper','border-left-width','2','','','.p-payer-order-confirmation'),(886272,'furniture','.p-payer-order-pay .input-wrapper','border-left-width','2','','','.p-payer-order-pay'),(886273,'furniture','.w-product-reviews .reviews-list .review','border-left-width','10','3','','.w-product-reviews'),(886274,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(886275,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border-left-width','2','3','','.b-form'),(886276,'furniture','.b-info-popup .info-popup div','border-left-width','1','3','','.b-info-popup'),(886277,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-left-width','2','3','','.b-switch'),(886278,'furniture','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(886279,'furniture','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(886280,'furniture','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-left-width','1','','','.b-bottom'),(886281,'furniture','.w-socials > li','border-left-width','1','','','.w-socials'),(886283,'furniture','.w-cart-compare .cart-cell > div','border-left-width','1','','','.w-cart-compare'),(886284,'furniture','.b-info-popup .info-popup div','border-left-width','1','','','.b-info-popup'),(886285,'furniture','.w-tabs > .block','border-left-width','1','','','.w-tabs'),(886286,'furniture','.w-socials > li','border-left-width','1','','','.w-socials'),(886287,'furniture','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(886288,'furniture','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(886289,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-left-width','4','','','.b-switch'),(886290,'furniture','.w-filters .ui-slider-handle','border-left-width','0','','','.w-filters'),(886291,'furniture','.w-filters .ui-slider','border-left-width','0','','','.w-filters'),(886292,'furniture','.w-socials > li','border-left-width','1','','','.w-socials'),(886293,'furniture','.w-reviews .review','border-left-width','12','3','','.w-reviews'),(886295,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-left-width','3','','','.b-switch'),(886296,'furniture','.w-reviews-content .review','border-left-width','12','3','','.w-reviews-content'),(886297,'furniture','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(886298,'furniture','.w-socials > li','border-left-width','1','','','.w-socials'),(886299,'furniture','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(886300,'furniture','.b-select-suggest .select2-container .select2-choice','border-left-width','2','','','.b-select-suggest'),(886301,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-left-width','2','4','','.b-switch'),(886303,'furniture','.b-form .required-error','border-left-width','1','','','.b-form'),(886304,'furniture','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(886305,'furniture','textarea','border-left-width','2','','',''),(886306,'furniture','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(886307,'furniture','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-left-width','1','','','.b-bottom'),(886308,'furniture','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(886309,'furniture','.w-cart-compare .product-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(886310,'furniture','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(886311,'furniture','.b-bottom .popup-box','border-left-width','1','','','.b-bottom'),(886312,'furniture','.w-product-customers-activity .customers-activity','border-left-width','1','','','.w-product-customers-activity'),(886313,'furniture','.w-cart-compare .price-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(886314,'furniture','.w-socials > li','border-left-width','1','','','.w-socials'),(886315,'furniture','.w-socials > li','border-left-width','1','','','.w-socials'),(886316,'furniture','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(886317,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(886318,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-width','1','','','.b-select-suggest'),(886319,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(886320,'furniture','.b-select-suggest .select2-container-multi .select2-choices','border-left-width','1','','','.b-select-suggest'),(886321,'furniture','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-width','1','','','.b-select-suggest'),(886322,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','border-left-width','0','','','.b-select-suggest'),(886323,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-width','1','','','.b-select-suggest'),(886324,'furniture','.b-select-suggest .select2-search input','border-left-width','1','','','.b-select-suggest'),(886325,'furniture','.b-select-suggest .select2-drop-active','border-left-width','1','','','.b-select-suggest'),(886326,'furniture','.b-select-suggest .select2-drop','border-left-width','1','','','.b-select-suggest'),(886327,'furniture','.b-upload-file .upload-file-template','border-left-width','1','','','.b-upload-file'),(886328,'furniture','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(886329,'furniture','.checkbox input:checked + span','border-left-width','1','','',''),(886330,'furniture','.checkbox input + span','border-left-width','1','','',''),(886331,'furniture','.b-autocomplete .ui-autocomplete','border-left-width','1','','','.b-autocomplete'),(886334,'furniture','.w-checkout-shipping-choice label:first-child span','border-left-width','2','','','.w-checkout-shipping-choice'),(886335,'furniture','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(886336,'furniture','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(886337,'furniture','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(886338,'furniture','.w-cart-listing .item .gift-wrap label','border-left-width','1','','','.w-cart-listing'),(886339,'furniture','.w-cart-listing .item','border-left-width','1','5140','','.w-cart-listing'),(886341,'furniture','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(886342,'furniture','.w-filters .ui-slider-range','border-left-width','0','','','.w-filters'),(886343,'furniture','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(886344,'furniture','.b-upload-files .upload-files','border-left-width','1','','','.b-upload-files'),(886345,'furniture','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-width','1','','','.b-compare'),(886346,'furniture','.b-upload-file .snapshot','border-left-width','1','','','.b-upload-file'),(886347,'furniture','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-left-width','2','','','.b-product-images'),(886348,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-left-width','1','','','.b-menu-style-2'),(886349,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-left-width','3','','','.b-menu-style-2'),(886350,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-left-width','1','','','.b-menu-style-2'),(886351,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-left-width','3','','','.b-menu-style-2'),(886352,'furniture','.b-trade-approval .steps-bar li ~ li a','border-left-width','1','','','.b-trade-approval'),(886353,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-width','2','','','.b-trade-approval'),(886354,'furniture','.w-account-personal-catalog .list-switcher a','border-left-width','1','2','','.w-account-personal-catalog'),(886355,'furniture','.w-catalog-compare .compare .checkbox input:checked + span','border-left-width','1','','','.w-catalog-compare'),(886356,'furniture','.w-catalog-compare .cross-box .different-all > div','border-left-width','1','2','','.w-catalog-compare'),(886357,'furniture','.b-slick .slick-vertical .slick-slide','border-left-width','1','','','.b-slick'),(886358,'furniture','.b-products-listing .products-listing .compare input + span','border-left-width','1','','','.b-products-listing'),(886359,'furniture','.w-filters .filter-widget','border-left-width','1','','','.w-filters'),(886360,'furniture','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-left-width','0','','','.w-filters'),(886361,'furniture','.w-quote .cart-content','border-left-width','1','','','.w-quote'),(886362,'furniture','.b-product-images .additional-images .active img','border-left-width','2','','','.b-product-images'),(886363,'furniture','.b-product-images .additional-images img','border-left-width','2','','','.b-product-images'),(886364,'furniture','.b-quantity .qty-box .bigger','border-left-width','2','','','.b-quantity'),(886365,'furniture','.b-quantity .qty-box .smaller','border-left-width','2','','','.b-quantity'),(886366,'furniture','.w-sample .cart-content','border-left-width','1','','','.w-sample'),(886367,'furniture','.w-cart-listing .points-earn','border-left-width','12','4','','.w-cart-listing'),(886368,'furniture','.w-cart-discount-coupon .btn','border-left-width','2','','','.w-cart-discount-coupon'),(886369,'furniture','.w-product-video .item img, .w-product-video .item video','border-left-width','2','','','.w-product-video'),(886370,'furniture','.w-product-video .item.active img, .w-product-video .item.active video','border-left-width','2','','','.w-product-video'),(886371,'furniture','.w-cart-order-reference .btn','border-left-width','2','','','.w-cart-order-reference'),(886372,'furniture','.w-cart-gift-certificate .btn','border-left-width','2','','','.w-cart-gift-certificate'),(886373,'furniture','.w-cart-shipping-estimator .btn','border-left-width','2','','','.w-cart-shipping-estimator'),(886375,'furniture','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-left-width','1','','','.b-pagination'),(886376,'furniture','.b-pagination .pagination .next-pages','border-left-width','1','','','.b-pagination'),(886377,'furniture','.b-pagination .pagination .page-number','border-left-width','1','','','.b-pagination'),(886378,'furniture','.b-pagination .pagination .prev-pages','border-left-width','1','','','.b-pagination'),(886379,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-left-width','1','','','.b-pagination'),(886380,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-left-width','1','','','.b-pagination'),(886381,'furniture','.b-pagination .pagination span','border-left-width','1','2','','.b-pagination'),(886382,'furniture','.w-tabs .tab-li','border-left-width','1','2','','.w-tabs'),(886383,'furniture','.w-product-multi-inventory .radio-attributes .option-item','border-left-width','2','','','.w-product-multi-inventory'),(886384,'furniture','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-left-width','2','','','.w-product-multi-inventory'),(886385,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-left-width','1','','','.w-account-personal-catalog'),(886386,'furniture','.w-account-personal-catalog .list-row-action ul','border-left-width','1','','','.w-account-personal-catalog'),(886387,'furniture','.b-products-listing .products-listing .radio-attributes .option','border-left-width','2','','','.b-products-listing'),(886388,'furniture','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-left-width','2','','','.b-products-listing'),(886389,'furniture','.w-product-attributes .radio-attributes .option-item','border-left-width','2','','','.w-product-attributes'),(886390,'furniture','.w-product-attributes .radio-attributes input:checked + .option-item','border-left-width','2','','','.w-product-attributes'),(886391,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-left-width','2','','','.w-questionnaire-widgets-questionnaire'),(886392,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-left-width','2','','','.w-questionnaire-widgets-questionnaire'),(886393,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-left-width','2','','','.w-questionnaire-widgets-questionnaire'),(886394,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-left-width','2','1','','.w-questionnaire-widgets-questionnaire'),(886395,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-left-width','2','1','','.w-questionnaire-widgets-questionnaire'),(886396,'furniture','.w-product-groups .radioBox label .containerBlock','border-left-width','2','','','.w-product-groups'),(886397,'furniture','.w-product-groups .radioBox label .containerBlock.selected','border-left-width','2','','','.w-product-groups'),(886398,'furniture','.w-product-groups .radioBox label input:checked + .containerBlock','border-left-width','2','','','.w-product-groups'),(886399,'furniture','.w-delivery-location-location-list .deliveryList li a','border-left-width','2','','','.w-delivery-location-location-list'),(886400,'furniture','.w-delivery-location-location-list .deliveryList li a','border-left-width','2','1','','.w-delivery-location-location-list'),(886401,'furniture','.w-sale-category .sale-holder','border-left-width','2','','','.w-sale-category'),(886402,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-left-width','1','','','.w-product-properties-icons'),(886403,'furniture','.w-product-designer-designer .prodDesignerType label','border-left-width','1','','','.w-product-designer-designer'),(886404,'furniture','.b-products-listing .productGroup label a','border-left-width','1','','','.b-products-listing'),(886405,'furniture','.w-support-system-listing .support-head','border-left-width','1','','','.w-support-system-listing'),(886406,'furniture','.w-support-system-listing .product_icon','border-left-width','1','','','.w-support-system-listing'),(886407,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border-left-width','1','','','.w-predefined-promotion'),(886408,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-left-width','1','','','.w-predefined-promotion'),(886409,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-left-width','1','','','.w-predefined-promotion'),(886410,'furniture','.w-predefined-promotion .promo-salemaker .discount','border-left-width','1','','','.w-predefined-promotion'),(886411,'furniture','.w-supplier-purchase-supplier-products .item','border-left-width','1','','','.w-supplier-purchase-supplier-products'),(886412,'furniture','.mainBanner .bottomBox .btn','border-left-width','0.21','','','.mainBanner'),(886413,'furniture','.mainBanner .topBox > .right','border-left-width','4','4','','.mainBanner'),(886414,'furniture','.mainBanner .bottomBox .btn','border-left-width','2','5145','','.mainBanner'),(886415,'furniture','.mainBanner .bottomBox .btn','border-left-width','3','5131','','.mainBanner'),(886416,'furniture','.mainBanner .bottomBox .btn','border-left-width','2','5161','','.mainBanner'),(886417,'furniture','.mainBanner .bottomBox .btn','border-left-width','3','5206','','.mainBanner'),(886418,'furniture','.w-product-quantity-discounts .item','border-left-width','1','','','.w-product-quantity-discounts'),(886421,'furniture','.account-samples .orders-table .item','border-left-width','1','5140','','.account-samples'),(886422,'furniture','.catalog-product-wrap .next-product','border-left-width','1','','','.catalog-product-wrap'),(886423,'furniture','.catalog-product-wrap .pn-image','border-left-width','2','3','','.catalog-product-wrap'),(886424,'furniture','.checkout-index-wrap .input-wrapper','border-left-width','2','','','.checkout-index-wrap'),(886425,'furniture','.shopping-cart-index .btn-3','border-left-width','2','','','.shopping-cart-index'),(886426,'furniture','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(886427,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(886428,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-width','1','','','.b-multi-page-checkout'),(886429,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li + li','border-left-width','1','5198','','.footer-menu'),(886430,'furniture','.lowestPricedBox .w-banner .ybg .btn','border-left-width','2','','','.lowestPricedBox'),(886431,'furniture','.shopByCollectionBox .bannerButton a','border-left-width','2','','','.shopByCollectionBox'),(886432,'furniture','.shopByCollectionBox .bannerButton a','border-left-width','2','5145','','.shopByCollectionBox'),(886433,'furniture','.w-catalog-paging ','border-left-width','1','2','','.w-catalog-paging'),(886434,'furniture','.w-catalog-paging .next','border-left-width','1','','','.w-catalog-paging'),(886435,'furniture','.w-catalog-paging .next-pages','border-left-width','1','','','.w-catalog-paging'),(886436,'furniture','.w-catalog-paging .page-number','border-left-width','1','','','.w-catalog-paging'),(886437,'furniture','.w-catalog-paging .prev','border-left-width','1','','','.w-catalog-paging'),(886438,'furniture','.w-catalog-paging .prev-pages','border-left-width','1','','','.w-catalog-paging'),(886439,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-width','1','','','.w-catalog-paging'),(886440,'furniture','.w-compare-box-item .checkbox + span','border-left-width','1','','','.w-compare-box-item'),(886441,'furniture','.w-compare-box-item .checkbox:checked + span','border-left-width','1','','','.w-compare-box-item'),(886442,'furniture','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(886443,'furniture','.w-cart-products .checkout-attention-message','border-right-color','$warning-border','','','.w-cart-products'),(886444,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border-right-color','$checkbox-border-1','3','','.b-form'),(886445,'furniture','.w-promotions .prom-multi-discount .promo-range','border-right-color','$warning-border','','','.w-promotions'),(886446,'furniture','.w-cart-compare .attributes-block td','border-right-color','$content-border-1','','','.w-cart-compare'),(886448,'furniture','.testimonials .review','border-right-color','transparent','3','',''),(886449,'furniture','.w-promotions .promo-salemaker .discount','border-right-color','$warning-border','','','.w-promotions'),(886450,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-color','$warning-border','','','.w-promotions'),(886451,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border-right-color','$warning-border','','','.w-promotions'),(886452,'furniture','.w-cart-compare .cart-cell > div','border-right-color','$content-border-1','','','.w-cart-compare'),(886453,'furniture','.w-cart-compare .price-block td','border-right-color','$content-border-1','','','.w-cart-compare'),(886454,'furniture','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-right-color','$content-border-1','','','.b-bottom'),(886455,'furniture','.b-messages .content_management_attach button','border-right-color','$content-border-2','','','.b-messages'),(886456,'furniture','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-color','$content-border-1','','','.b-messages'),(886457,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-right-color','$content-border-1','','',''),(886458,'furniture','.w-cart-products .checkout-attention-message','border-right-color','$warning-border','','','.w-cart-products'),(886459,'furniture','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(886460,'furniture','.p-payer-order-confirmation .input-wrapper','border-right-color','$content-border-1','','','.p-payer-order-confirmation'),(886461,'furniture','.p-payer-order-pay .input-wrapper','border-right-color','$content-border-1','','','.p-payer-order-pay'),(886462,'furniture','.b-upload-file .upload-file-template','border-right-color','$content-border-1','','','.b-upload-file'),(886463,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-right-color','$switch-nc-border-1','','','.b-switch'),(886464,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(886465,'furniture','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(886466,'furniture','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-color','$content-border-2','','','.b-compare'),(886467,'furniture','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(886468,'furniture','.w-cart-products .checkout-attention-message','border-right-color','$warning-border','','','.w-cart-products'),(886469,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(886470,'furniture','.w-checkout-shipping-choice label:last-child span','border-right-color','$highlight-box-border-2','','','.w-checkout-shipping-choice'),(886471,'furniture','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(886472,'furniture','.b-info-popup .info-popup div','border-right-color','$content-border-1','','','.b-info-popup'),(886473,'furniture','.w-cart-compare .product-block td','border-right-color','$content-border-1','','','.w-cart-compare'),(886474,'furniture','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(886475,'furniture','.w-reviews .review','border-right-color','$transparent','3','','.w-reviews'),(886476,'furniture','.w-tabs > .block','border-right-color','$tab-content-border-1','','','.w-tabs'),(886477,'furniture','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(886478,'furniture','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(886479,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-right-color','$switch-handle-bg-3','','','.b-switch'),(886480,'furniture','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(886481,'furniture','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(886482,'furniture','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(886483,'furniture','.w-reviews-content .review','border-right-color','$transparent','3','','.w-reviews-content'),(886484,'furniture','.b-select-suggest .select2-container .select2-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(886485,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-right-color','$switch-nc-border-1','4','','.b-switch'),(886487,'furniture','.w-cart-products .checkout-attention-message','border-right-color','$warning-border','','','.w-cart-products'),(886488,'furniture','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(886489,'furniture','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-right-color','$border-color-9','','','.b-bottom'),(886490,'furniture','textarea','border-right-color','$content-border-1','','',''),(886491,'furniture','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(886492,'furniture','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(886493,'furniture','.b-bottom .popup-box','border-right-color','$content-border-1','','','.b-bottom'),(886494,'furniture','.w-product-customers-activity .customers-activity','border-right-color','$content-border-1','','','.w-product-customers-activity'),(886495,'furniture','.w-product-reviews .reviews-list .review','border-right-color','$transparent','3','','.w-product-reviews'),(886496,'furniture','.w-cart-products .checkout-attention-message','border-right-color','$warning-border','','','.w-cart-products'),(886497,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-color','$content-border-1','','','.b-select-suggest'),(886498,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(886499,'furniture','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-color','$content-border-1','','','.b-select-suggest'),(886500,'furniture','.b-select-suggest .select2-container-multi .select2-choices','border-right-color','$content-border-1','','','.b-select-suggest'),(886501,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(886502,'furniture','.b-select-suggest .select2-search input','border-right-color','$content-border-1','','','.b-select-suggest'),(886503,'furniture','.b-select-suggest .select2-drop-active','border-right-color','$content-border-1','','','.b-select-suggest'),(886504,'furniture','.b-select-suggest .select2-drop','border-right-color','$content-border-1','','','.b-select-suggest'),(886505,'furniture','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(886506,'furniture','.b-form input.required-error','border-right-color','$attention-border','','','.b-form'),(886507,'furniture','.checkbox input:checked + span','border-right-color','$checkbox-border-1','','',''),(886508,'furniture','.checkbox input + span','border-right-color','$content-border-1','','',''),(886509,'furniture','.b-autocomplete .ui-autocomplete','border-right-color','$content-border-1','','','.b-autocomplete'),(886512,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-right-color','$switch-nc-border-1','3','','.b-switch'),(886513,'furniture','.b-upload-file .snapshot','border-right-color','$content-border-2','','','.b-upload-file'),(886514,'furniture','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(886515,'furniture','.b-upload-files .upload-files','border-right-color','$content-border-1','','','.b-upload-files'),(886516,'furniture','.b-form .required-error','border-right-color','$attention-border','','','.b-form'),(886517,'furniture','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(886518,'furniture','.w-cart-products .checkout-attention-message','border-right-color','$warning-border','','','.w-cart-products'),(886519,'furniture','.w-cart-listing .item .gift-wrap label','border-right-color','$content-border-1','','','.w-cart-listing'),(886520,'furniture','.w-cart-listing .item','border-right-color','$content-border-1','5140','','.w-cart-listing'),(886521,'furniture','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(886523,'furniture','.b-data-table table.dataTable.no-footer','border-right-color','$content-border-1','','','.b-data-table'),(886524,'furniture','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-right-color','$image-popup-border-1','','','.b-product-images'),(886525,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-right-color','$header-menu-border-1','','','.b-menu-style-2'),(886526,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-right-color','$header-menu-border-1','','','.b-menu-style-2'),(886527,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-right-color','$header-menu-border-1','','','.b-menu-style-2'),(886528,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-right-color','$header-menu-border-1','','','.b-menu-style-2'),(886529,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-color','$content-border-1','','','.b-trade-approval'),(886530,'furniture','.w-account-personal-catalog .list-switcher a','border-right-color','$content-border-1','2','','.w-account-personal-catalog'),(886531,'furniture','.w-catalog-compare .compare .checkbox input:checked + span','border-right-color','$content-bg-1','','','.w-catalog-compare'),(886532,'furniture','.w-catalog-compare .cross-box .different-all > div','border-right-color','$content-border-1','2','','.w-catalog-compare'),(886533,'furniture','.w-catalog-compare td:first-child','border-right-color','$content-border-1','','','.w-catalog-compare'),(886537,'furniture','.b-products-listing .products-listing .compare input + span','border-right-color','$content-border-2','','','.b-products-listing'),(886538,'furniture','.w-filters .filter-widget','border-right-color','$content-border-1','','','.w-filters'),(886539,'furniture','.w-quote .cart-content','border-right-color','$content-border-1','','','.w-quote'),(886540,'furniture','.b-product-images .additional-images .active img','border-right-color','$highlight-box-color-1','','','.b-product-images'),(886541,'furniture','.b-product-images .additional-images img','border-right-color','$content-border-1','','','.b-product-images'),(886542,'furniture','.b-quantity .qty-box .bigger','border-right-color','$content-border-1','','','.b-quantity'),(886543,'furniture','.b-quantity .qty-box .smaller','border-right-color','$content-border-1','','','.b-quantity'),(886544,'furniture','.w-sample .cart-box-link','border-right-color','$content-border-2','4','','.w-sample'),(886545,'furniture','.w-sample .cart-content','border-right-color','$content-border-1','','','.w-sample'),(886546,'furniture','.w-cart-listing .points-earn','border-right-color','transparent','4','','.w-cart-listing'),(886547,'furniture','.w-cart-discount-coupon .btn','border-right-color','$content-border-2','','','.w-cart-discount-coupon'),(886548,'furniture','.w-product-video .item img, .w-product-video .item video','border-right-color','$image-popup-border-1','','','.w-product-video'),(886549,'furniture','.w-product-video .item.active img, .w-product-video .item.active video','border-right-color','$highlight-box-border-1','','','.w-product-video'),(886550,'furniture','.w-cart-order-reference .btn','border-right-color','$content-border-2','','','.w-cart-order-reference'),(886551,'furniture','.w-cart-gift-certificate .btn','border-right-color','$content-border-2','','','.w-cart-gift-certificate'),(886552,'furniture','.w-cart-shipping-estimator .btn','border-right-color','$content-border-2','','','.w-cart-shipping-estimator'),(886554,'furniture','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-right-color','$content-border-2','','','.b-pagination'),(886555,'furniture','.b-pagination .pagination .next-pages','border-right-color','$content-border-1','','','.b-pagination'),(886556,'furniture','.b-pagination .pagination .page-number','border-right-color','$content-border-1','','','.b-pagination'),(886557,'furniture','.b-pagination .pagination .prev-pages','border-right-color','$content-border-1','','','.b-pagination'),(886558,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-right-color','$content-border-1','','','.b-pagination'),(886559,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-right-color','$content-border-1','','','.b-pagination'),(886560,'furniture','.b-pagination .pagination span','border-right-color','$highlight-box-border-2','2','','.b-pagination'),(886561,'furniture','.w-tabs .tab-li','border-right-color','$tab-nav-border-2','2','','.w-tabs'),(886562,'furniture','.w-product-multi-inventory .radio-attributes .option-item','border-right-color','$content-border-1','','','.w-product-multi-inventory'),(886563,'furniture','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-right-color','$content-border-2','','','.w-product-multi-inventory'),(886564,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-right-color','$content-border-1','','','.w-account-personal-catalog'),(886565,'furniture','.w-account-personal-catalog .list-row-action ul','border-right-color','$content-border-1','','','.w-account-personal-catalog'),(886566,'furniture','.b-products-listing .products-listing .radio-attributes .option','border-right-color','$content-border-1','','','.b-products-listing'),(886567,'furniture','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-right-color','$content-border-2','','','.b-products-listing'),(886568,'furniture','.w-product-attributes .radio-attributes .option-item','border-right-color','$content-border-1','','','.w-product-attributes'),(886569,'furniture','.w-product-attributes .radio-attributes input:checked + .option-item','border-right-color','$content-border-2','','','.w-product-attributes'),(886570,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-right-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(886571,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-right-color','$attention-border','','','.w-questionnaire-widgets-questionnaire'),(886572,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-right-color','$message-border','','','.w-questionnaire-widgets-questionnaire'),(886573,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-right-color','$attention-border','1','','.w-questionnaire-widgets-questionnaire'),(886574,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-right-color','$message-border','1','','.w-questionnaire-widgets-questionnaire'),(886575,'furniture','.w-product-groups .radioBox label .containerBlock','border-right-color','$content-border-1','','','.w-product-groups'),(886576,'furniture','.w-product-groups .radioBox label .containerBlock.selected','border-right-color','$content-border-2','','','.w-product-groups'),(886577,'furniture','.w-product-groups .radioBox label input:checked + .containerBlock','border-right-color','$content-border-2','','','.w-product-groups'),(886578,'furniture','.w-delivery-location-location-list .deliveryList li a','border-right-color','$content-border-1','','','.w-delivery-location-location-list'),(886579,'furniture','.w-delivery-location-location-list .deliveryList li a','border-right-color','$content-border-2','1','','.w-delivery-location-location-list'),(886580,'furniture','.w-sale-category .sale-holder','border-right-color','$content-border-1','','','.w-sale-category'),(886581,'furniture','.w-product-designer-designer .prodDesignerType label','border-right-color','$content-border-1','','','.w-product-designer-designer'),(886582,'furniture','.b-products-listing .productGroup label a','border-right-color','$content-border-2','','','.b-products-listing'),(886583,'furniture','.w-support-system-listing .support-head','border-right-color','$content-border-1','','','.w-support-system-listing'),(886584,'furniture','.w-support-system-listing .product_icon','border-right-color','$content-border-1','','','.w-support-system-listing'),(886585,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border-right-color','$warning-border','','','.w-predefined-promotion'),(886586,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-right-color','$warning-border','','','.w-predefined-promotion'),(886587,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-right-color','$warning-border','','','.w-predefined-promotion'),(886588,'furniture','.w-predefined-promotion .promo-salemaker .discount','border-right-color','$warning-border','','','.w-predefined-promotion'),(886589,'furniture','.w-supplier-purchase-supplier-products .item','border-right-color','$content-border-1','','','.w-supplier-purchase-supplier-products'),(886590,'furniture','.mainBanner .bottomBox .btn','border-right-color','$main-banner-border-1','','','.mainBanner'),(886591,'furniture','.mainBanner .topBox > .right','border-right-color','transparent','4','','.mainBanner'),(886592,'furniture','.mainBanner .bottomBox .btn','border-right-color','$main-banner-border-1','5145','','.mainBanner'),(886593,'furniture','.mainBanner .bottomBox .btn','border-right-color','$main-banner-border-1','5131','','.mainBanner'),(886594,'furniture','.mainBanner .bottomBox .btn','border-right-color','$main-banner-border-1','5161','','.mainBanner'),(886595,'furniture','.mainBanner .bottomBox .btn','border-right-color','$main-banner-border-1','5206','','.mainBanner'),(886596,'furniture','.w-product-quantity-discounts .item','border-right-color','$content-border-1','','','.w-product-quantity-discounts'),(886599,'furniture','.account-samples .orders-table .item','border-right-color','$content-border-1','5140','','.account-samples'),(886600,'furniture','.catalog-product-wrap .pn-image','border-right-color','$content-border-1','3','','.catalog-product-wrap'),(886601,'furniture','.checkout-index-wrap .input-wrapper','border-right-color','$content-border-1','','','.checkout-index-wrap'),(886602,'furniture','.shopping-cart-index .btn-3','border-right-color','$content-border-2','','','.shopping-cart-index'),(886603,'furniture','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-color','$content-color-2','','','.b-multi-page-checkout'),(886604,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-color','$content-border-1','','','.b-multi-page-checkout'),(886605,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-color','$content-border-1','','','.b-multi-page-checkout'),(886606,'furniture','.lowestPricedBox .w-banner .ybg .btn','border-right-color','$additional-banner-border-1','','','.lowestPricedBox'),(886607,'furniture','.shopByCollectionBox .bannerButton a','border-right-color','$additional-banner-border-1','','','.shopByCollectionBox'),(886608,'furniture','.shopByCollectionBox .bannerButton a','border-right-color','$additional-banner-border-1','5145','','.shopByCollectionBox'),(886609,'furniture','.w-catalog-paging ','border-right-color','$content-border-1','2','','.w-catalog-paging'),(886610,'furniture','.w-catalog-paging .next','border-right-color','$content-border-1','','','.w-catalog-paging'),(886611,'furniture','.w-catalog-paging .next-pages','border-right-color','$content-border-1','','','.w-catalog-paging'),(886612,'furniture','.w-catalog-paging .page-number','border-right-color','$content-border-1','','','.w-catalog-paging'),(886613,'furniture','.w-catalog-paging .prev','border-right-color','$content-border-1','','','.w-catalog-paging'),(886614,'furniture','.w-catalog-paging .prev-pages','border-right-color','$content-border-1','','','.w-catalog-paging'),(886615,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-color','$content-border-1','','','.w-catalog-paging'),(886616,'furniture','.w-compare-box-item .checkbox + span','border-right-color','$content-border-1','','','.w-compare-box-item'),(886617,'furniture','.w-compare-box-item .checkbox:checked + span','border-right-color','$highlight-box-border-3','','','.w-compare-box-item'),(886618,'furniture','.b-data-table table.dataTable.no-footer','border-right-color_important','important','','','.b-data-table'),(886619,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(886620,'furniture','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(886621,'furniture','.w-promotions .prom-multi-discount .promo-range','border-right-width','1','','','.w-promotions'),(886622,'furniture','.w-cart-compare .attributes-block td','border-right-width','1','','','.w-cart-compare'),(886624,'furniture','.testimonials .review','border-right-width','10','3','',''),(886625,'furniture','.w-promotions .promo-salemaker .discount','border-right-width','1','','','.w-promotions'),(886626,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-width','1','','','.w-promotions'),(886627,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border-right-width','1','','','.w-promotions'),(886628,'furniture','.w-cart-compare .cart-cell > div','border-right-width','1','','','.w-cart-compare'),(886629,'furniture','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-right-width','1','','','.b-bottom'),(886630,'furniture','.b-messages .content_management_attach button','border-right-width','1','','','.b-messages'),(886631,'furniture','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-width','2','','','.b-messages'),(886632,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-right-width','2','','',''),(886633,'furniture','.w-socials > li','border-right-width','1','','','.w-socials'),(886634,'furniture','.p-payer-order-confirmation .input-wrapper','border-right-width','2','','','.p-payer-order-confirmation'),(886635,'furniture','.p-payer-order-pay .input-wrapper','border-right-width','2','','','.p-payer-order-pay'),(886636,'furniture','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(886637,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(886638,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border-right-width','2','3','','.b-form'),(886639,'furniture','.w-socials > li','border-right-width','1','','','.w-socials'),(886640,'furniture','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(886641,'furniture','.w-socials > li','border-right-width','1','','','.w-socials'),(886644,'furniture','.b-info-popup .info-popup div','border-right-width','1','','','.b-info-popup'),(886645,'furniture','.w-checkout-shipping-choice label:last-child span','border-right-width','2','','','.w-checkout-shipping-choice'),(886646,'furniture','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(886647,'furniture','.w-tabs > .block','border-right-width','1','','','.w-tabs'),(886648,'furniture','.w-socials > li','border-right-width','1','','','.w-socials'),(886649,'furniture','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(886650,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-right-width','4','','','.b-switch'),(886651,'furniture','.w-filters .ui-slider-handle','border-right-width','0','','','.w-filters'),(886652,'furniture','.w-filters .ui-slider','border-right-width','0','','','.w-filters'),(886653,'furniture','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(886654,'furniture','.w-socials > li','border-right-width','1','','','.w-socials'),(886655,'furniture','.w-reviews .review','border-right-width','12','3','','.w-reviews'),(886656,'furniture','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(886657,'furniture','.w-product-reviews .reviews-list .review','border-right-width','10','3','','.w-product-reviews'),(886658,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-right-width','3','','','.b-switch'),(886659,'furniture','.w-reviews-content .review','border-right-width','12','3','','.w-reviews-content'),(886660,'furniture','.w-socials > li','border-right-width','1','','','.w-socials'),(886661,'furniture','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(886662,'furniture','.b-select-suggest .select2-container .select2-choice','border-right-width','2','','','.b-select-suggest'),(886663,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-right-width','2','4','','.b-switch'),(886665,'furniture','.w-cart-compare .product-block td','border-right-width','1','','','.w-cart-compare'),(886666,'furniture','.b-form .required-error','border-right-width','1','','','.b-form'),(886667,'furniture','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(886668,'furniture','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(886669,'furniture','textarea','border-right-width','2','','',''),(886670,'furniture','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-right-width','1','','','.b-bottom'),(886671,'furniture','.b-bottom .popup-box','border-right-width','1','','','.b-bottom'),(886672,'furniture','.w-product-customers-activity .customers-activity','border-right-width','1','','','.w-product-customers-activity'),(886673,'furniture','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(886674,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(886675,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-width','1','','','.b-select-suggest'),(886676,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(886677,'furniture','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-width','1','','','.b-select-suggest'),(886678,'furniture','.b-select-suggest .select2-container-multi .select2-choices','border-right-width','1','','','.b-select-suggest'),(886679,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-width','1','','','.b-select-suggest'),(886680,'furniture','.b-select-suggest .select2-search input','border-right-width','1','','','.b-select-suggest'),(886681,'furniture','.b-select-suggest .select2-drop','border-right-width','1','','','.b-select-suggest'),(886682,'furniture','.b-select-suggest .select2-drop-active','border-right-width','1','','','.b-select-suggest'),(886683,'furniture','.w-cart-compare .price-block td','border-right-width','1','','','.w-cart-compare'),(886684,'furniture','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-width','1','','','.b-compare'),(886685,'furniture','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(886686,'furniture','.checkbox input:checked + span','border-right-width','1','','',''),(886687,'furniture','.checkbox input + span','border-right-width','1','','',''),(886688,'furniture','.b-autocomplete .ui-autocomplete','border-right-width','1','','','.b-autocomplete'),(886691,'furniture','.b-upload-file .upload-file-template','border-right-width','1','','','.b-upload-file'),(886692,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-right-width','2','3','','.b-switch'),(886693,'furniture','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(886694,'furniture','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(886695,'furniture','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(886696,'furniture','.w-cart-listing .item .gift-wrap label','border-right-width','1','','','.w-cart-listing'),(886697,'furniture','.w-cart-listing .item','border-right-width','1','5140','','.w-cart-listing'),(886699,'furniture','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(886700,'furniture','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(886701,'furniture','.w-filters .ui-slider-range','border-right-width','0','','','.w-filters'),(886702,'furniture','.b-upload-files .upload-files','border-right-width','1','','','.b-upload-files'),(886703,'furniture','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(886704,'furniture','.b-upload-file .snapshot','border-right-width','1','','','.b-upload-file'),(886705,'furniture','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-right-width','2','','','.b-product-images'),(886706,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-right-width','1','','','.b-menu-style-2'),(886707,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-right-width','3','','','.b-menu-style-2'),(886708,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-right-width','1','','','.b-menu-style-2'),(886709,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-right-width','3','','','.b-menu-style-2'),(886710,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-width','2','','','.b-trade-approval'),(886711,'furniture','.w-account-personal-catalog .list-switcher a','border-right-width','1','2','','.w-account-personal-catalog'),(886712,'furniture','.w-catalog-compare .compare .checkbox input:checked + span','border-right-width','1','','','.w-catalog-compare'),(886713,'furniture','.w-catalog-compare td:first-child','border-right-width','1','','','.w-catalog-compare'),(886714,'furniture','.w-catalog-compare .cross-box .different-all > div','border-right-width','1','2','','.w-catalog-compare'),(886717,'furniture','.b-slick .slick-vertical .slick-slide','border-right-width','1','','','.b-slick'),(886718,'furniture','.b-products-listing .products-listing .compare input + span','border-right-width','1','','','.b-products-listing'),(886719,'furniture','.w-filters .filter-widget','border-right-width','1','','','.w-filters'),(886720,'furniture','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-right-width','0','','','.w-filters'),(886721,'furniture','.w-quote .cart-content','border-right-width','1','','','.w-quote'),(886722,'furniture','.b-product-images .additional-images .active img','border-right-width','2','','','.b-product-images'),(886723,'furniture','.b-product-images .additional-images img','border-right-width','2','','','.b-product-images'),(886724,'furniture','.b-quantity .qty-box .bigger','border-right-width','2','','','.b-quantity'),(886725,'furniture','.b-quantity .qty-box .smaller','border-right-width','2','','','.b-quantity'),(886726,'furniture','.w-sample .cart-box-link','border-right-width','1','4','','.w-sample'),(886727,'furniture','.w-sample .cart-content','border-right-width','1','','','.w-sample'),(886728,'furniture','.w-cart-listing .points-earn','border-right-width','0','4','','.w-cart-listing'),(886729,'furniture','.w-cart-discount-coupon .btn','border-right-width','2','','','.w-cart-discount-coupon'),(886730,'furniture','.w-product-video .item img, .w-product-video .item video','border-right-width','2','','','.w-product-video'),(886731,'furniture','.w-product-video .item.active img, .w-product-video .item.active video','border-right-width','2','','','.w-product-video'),(886732,'furniture','.w-cart-order-reference .btn','border-right-width','2','','','.w-cart-order-reference'),(886733,'furniture','.w-cart-gift-certificate .btn','border-right-width','2','','','.w-cart-gift-certificate'),(886734,'furniture','.w-cart-shipping-estimator .btn','border-right-width','2','','','.w-cart-shipping-estimator'),(886736,'furniture','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-right-width','1','','','.b-pagination'),(886737,'furniture','.b-pagination .pagination .next-pages','border-right-width','1','','','.b-pagination'),(886738,'furniture','.b-pagination .pagination .page-number','border-right-width','1','','','.b-pagination'),(886739,'furniture','.b-pagination .pagination .prev-pages','border-right-width','1','','','.b-pagination'),(886740,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-right-width','1','','','.b-pagination'),(886741,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-right-width','1','','','.b-pagination'),(886742,'furniture','.b-pagination .pagination span','border-right-width','1','2','','.b-pagination'),(886743,'furniture','.w-tabs .tab-li','border-right-width','1','2','','.w-tabs'),(886744,'furniture','.w-product-multi-inventory .radio-attributes .option-item','border-right-width','2','','','.w-product-multi-inventory'),(886745,'furniture','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-right-width','2','','','.w-product-multi-inventory'),(886746,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-right-width','1','','','.w-account-personal-catalog'),(886747,'furniture','.w-account-personal-catalog .list-row-action ul','border-right-width','1','','','.w-account-personal-catalog'),(886748,'furniture','.b-products-listing .products-listing .radio-attributes .option','border-right-width','2','','','.b-products-listing'),(886749,'furniture','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-right-width','2','','','.b-products-listing'),(886750,'furniture','.w-product-attributes .radio-attributes .option-item','border-right-width','2','','','.w-product-attributes'),(886751,'furniture','.w-product-attributes .radio-attributes input:checked + .option-item','border-right-width','2','','','.w-product-attributes'),(886752,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-right-width','2','','','.w-questionnaire-widgets-questionnaire'),(886753,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-right-width','2','','','.w-questionnaire-widgets-questionnaire'),(886754,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-right-width','2','','','.w-questionnaire-widgets-questionnaire'),(886755,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-right-width','2','1','','.w-questionnaire-widgets-questionnaire'),(886756,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-right-width','2','1','','.w-questionnaire-widgets-questionnaire'),(886757,'furniture','.w-product-groups .radioBox label .containerBlock','border-right-width','2','','','.w-product-groups'),(886758,'furniture','.w-product-groups .radioBox label .containerBlock.selected','border-right-width','2','','','.w-product-groups'),(886759,'furniture','.w-product-groups .radioBox label input:checked + .containerBlock','border-right-width','2','','','.w-product-groups'),(886760,'furniture','.w-delivery-location-location-list .deliveryList li a','border-right-width','2','','','.w-delivery-location-location-list'),(886761,'furniture','.w-delivery-location-location-list .deliveryList li a','border-right-width','2','1','','.w-delivery-location-location-list'),(886762,'furniture','.w-sale-category .sale-holder','border-right-width','2','','','.w-sale-category'),(886763,'furniture','.w-product-designer-designer .prodDesignerType label','border-right-width','1','','','.w-product-designer-designer'),(886764,'furniture','.b-products-listing .productGroup label a','border-right-width','1','','','.b-products-listing'),(886765,'furniture','.w-support-system-listing .support-head','border-right-width','1','','','.w-support-system-listing'),(886766,'furniture','.w-support-system-listing .product_icon','border-right-width','1','','','.w-support-system-listing'),(886767,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border-right-width','1','','','.w-predefined-promotion'),(886768,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-right-width','1','','','.w-predefined-promotion'),(886769,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-right-width','1','','','.w-predefined-promotion'),(886770,'furniture','.w-predefined-promotion .promo-salemaker .discount','border-right-width','1','','','.w-predefined-promotion'),(886771,'furniture','.w-supplier-purchase-supplier-products .item','border-right-width','1','','','.w-supplier-purchase-supplier-products'),(886772,'furniture','.mainBanner .bottomBox .btn','border-right-width','0.21','','','.mainBanner'),(886773,'furniture','.mainBanner .topBox > .right','border-right-width','14','4','','.mainBanner'),(886774,'furniture','.mainBanner .bottomBox .btn','border-right-width','2','5145','','.mainBanner'),(886775,'furniture','.mainBanner .bottomBox .btn','border-right-width','3','5131','','.mainBanner'),(886776,'furniture','.mainBanner .bottomBox .btn','border-right-width','2','5161','','.mainBanner'),(886777,'furniture','.mainBanner .bottomBox .btn','border-right-width','3','5206','','.mainBanner'),(886778,'furniture','.w-product-quantity-discounts .item','border-right-width','1','','','.w-product-quantity-discounts'),(886781,'furniture','.account-samples .orders-table .item','border-right-width','1','5140','','.account-samples'),(886782,'furniture','.catalog-product-wrap .pn-image','border-right-width','2','3','','.catalog-product-wrap'),(886783,'furniture','.catalog-product-wrap .prev-product','border-right-width','1','','','.catalog-product-wrap'),(886784,'furniture','.checkout-index-wrap .input-wrapper','border-right-width','2','','','.checkout-index-wrap'),(886785,'furniture','.shopping-cart-index .btn-3','border-right-width','2','','','.shopping-cart-index'),(886786,'furniture','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(886787,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(886788,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-width','1','','','.b-multi-page-checkout'),(886789,'furniture','.lowestPricedBox .w-banner .ybg .btn','border-right-width','2','','','.lowestPricedBox'),(886790,'furniture','.shopByCollectionBox .bannerButton a','border-right-width','2','','','.shopByCollectionBox'),(886791,'furniture','.shopByCollectionBox .bannerButton a','border-right-width','2','5145','','.shopByCollectionBox'),(886792,'furniture','.w-catalog-paging ','border-right-width','1','2','','.w-catalog-paging'),(886793,'furniture','.w-catalog-paging .next','border-right-width','1','','','.w-catalog-paging'),(886794,'furniture','.w-catalog-paging .next-pages','border-right-width','1','','','.w-catalog-paging'),(886795,'furniture','.w-catalog-paging .page-number','border-right-width','1','','','.w-catalog-paging'),(886796,'furniture','.w-catalog-paging .prev','border-right-width','1','','','.w-catalog-paging'),(886797,'furniture','.w-catalog-paging .prev-pages','border-right-width','1','','','.w-catalog-paging'),(886798,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-width','1','','','.w-catalog-paging'),(886799,'furniture','.w-compare-box-item .checkbox + span','border-right-width','1','','','.w-compare-box-item'),(886800,'furniture','.w-compare-box-item .checkbox:checked + span','border-right-width','1','','','.w-compare-box-item'),(886801,'furniture','.b-select-suggest .select2-drop-active','border-top','none','','','.b-select-suggest'),(886802,'furniture','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','border-top','none','','','.order-summary'),(886803,'furniture','.order-summary .price-row.ot_gv + .price-row, .order-summary .price-row.ot_coupon + .price-row, .order-summary .price-row.ot_bonus_points + .price-row','border-top','none','','','.order-summary'),(886806,'furniture','.account-samples .orders-table','border-top','none','','','.account-samples'),(886807,'furniture','.catalog-product-wrap .pn-image','border-top','none','5140','','.catalog-product-wrap'),(886808,'furniture','.w-communication-new-topic td','border-top-color','$content-border-1','','','.w-communication-new-topic'),(886809,'furniture','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(886810,'furniture','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(886811,'furniture','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(886812,'furniture','.w-promotions .prom-multi-discount .promo-range','border-top-color','$warning-border','','','.w-promotions'),(886813,'furniture','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(886814,'furniture','.w-cart-compare .attributes-block td','border-top-color','$content-border-1','','','.w-cart-compare'),(886816,'furniture','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(886817,'furniture','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(886818,'furniture','.w-promotions .promo-salemaker .discount','border-top-color','$warning-border','','','.w-promotions'),(886819,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-color','$warning-border','','','.w-promotions'),(886820,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border-top-color','$warning-border','','','.w-promotions'),(886821,'furniture','.w-cart-compare .cart-cell > div','border-top-color','$content-border-1','','','.w-cart-compare'),(886822,'furniture','.w-cart-products .checkout-attention-message','border-top-color','$warning-border','','','.w-cart-products'),(886823,'furniture','.b-upload-file .upload-file-template','border-top-color','$content-border-1','','','.b-upload-file'),(886824,'furniture','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-top-color','$content-border-1','','','.b-bottom'),(886825,'furniture','.b-messages .messMenuButtonTop','border-top-color','$content-border-1','','','.b-messages'),(886826,'furniture','.b-messages .msv_btn','border-top-color','$content-border-1','','','.b-messages'),(886827,'furniture','.b-messages .email-heading','border-top-color','$content-border-1','','','.b-messages'),(886828,'furniture','.b-messages .dataTable','border-top-color','$content-border-1','','','.b-messages'),(886829,'furniture','.b-messages .messages-menu li + li','border-top-color','$content-border-1','','','.b-messages'),(886830,'furniture','.b-messages .content_management_attach button','border-top-color','$content-border-2','','','.b-messages'),(886831,'furniture','.b-messages .content_management_attach','border-top-color','$content-border-1','','','.b-messages'),(886832,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-top-color','$content-border-1','','',''),(886833,'furniture','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(886834,'furniture','.p-payer-order-confirmation .input-wrapper','border-top-color','$content-border-1','','','.p-payer-order-confirmation'),(886835,'furniture','.p-payer-order-pay .input-wrapper','border-top-color','$content-border-1','','','.p-payer-order-pay'),(886836,'furniture','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(886837,'furniture','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(886838,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-color','$switch-nc-border-1','','','.b-switch'),(886839,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(886840,'furniture','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(886841,'furniture','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(886842,'furniture','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-color','$content-border-2','','','.b-compare'),(886843,'furniture','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(886844,'furniture','.w-cart-products .checkout-attention-message','border-top-color','$warning-border','','','.w-cart-products'),(886845,'furniture','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(886846,'furniture','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(886847,'furniture','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(886848,'furniture','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(886849,'furniture','.w-checkout-shipping-choice span','border-top-color','$highlight-box-border-2','','','.w-checkout-shipping-choice'),(886850,'furniture','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(886851,'furniture','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(886852,'furniture','.b-info-popup .info-popup div','border-top-color','$content-border-1','','','.b-info-popup'),(886853,'furniture','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(886854,'furniture','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(886855,'furniture','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(886856,'furniture','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(886857,'furniture','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(886859,'furniture','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(886861,'furniture','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(886862,'furniture','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(886863,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-color','$switch-handle-bg-3','','','.b-switch'),(886864,'furniture','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-color','$content-border-1','','','.b-messages'),(886865,'furniture','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(886866,'furniture','.w-reviews .review','border-top-color','$transparent','3','','.w-reviews'),(886867,'furniture','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(886868,'furniture','.w-reviews-content .review','border-top-color','$transparent','3','','.w-reviews-content'),(886870,'furniture','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(886871,'furniture','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(886872,'furniture','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(886873,'furniture','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(886874,'furniture','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(886875,'furniture','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(886876,'furniture','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(886877,'furniture','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(886878,'furniture','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(886879,'furniture','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(886880,'furniture','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(886881,'furniture','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(886882,'furniture','.w-checkout-shipping .sub-item + .sub-item','border-top-color','$content-border-1','','','.w-checkout-shipping'),(886883,'furniture','.b-form .required-error','border-top-color','$attention-border','','','.b-form'),(886884,'furniture','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(886885,'furniture','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(886886,'furniture','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(886887,'furniture','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(886888,'furniture','.b-select-suggest .select2-container .select2-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(886890,'furniture','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(886891,'furniture','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(886892,'furniture','textarea','border-top-color','$content-border-1','','',''),(886893,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-color','$switch-nc-border-1','4','','.b-switch'),(886894,'furniture','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(886895,'furniture','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(886897,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border-top-color','$checkbox-border-1','3','','.b-form'),(886898,'furniture','.w-cart-products .checkout-attention-message','border-top-color','$warning-border','','','.w-cart-products'),(886899,'furniture','.w-cart-products .checkout-attention-message','border-top-color','$warning-border','','','.w-cart-products'),(886900,'furniture','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(886901,'furniture','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(886902,'furniture','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(886903,'furniture','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(886904,'furniture','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(886905,'furniture','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-top-color','$border-color-9','','','.b-bottom'),(886907,'furniture','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(886908,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(886909,'furniture','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(886910,'furniture','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(886911,'furniture','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(886912,'furniture','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(886913,'furniture','.w-cart-compare .product-block td','border-top-color','$content-border-1','','','.w-cart-compare'),(886914,'furniture','.b-bottom .popup-box','border-top-color','$content-border-1','','','.b-bottom'),(886915,'furniture','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(886916,'furniture','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(886917,'furniture','.w-product-customers-activity .customers-activity','border-top-color','$content-border-1','','','.w-product-customers-activity'),(886918,'furniture','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(886919,'furniture','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(886920,'furniture','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(886921,'furniture','.w-cart-compare .price-block td','border-top-color','$content-border-1','','','.w-cart-compare'),(886922,'furniture','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(886923,'furniture','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(886924,'furniture','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(886925,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-color','$content-border-1','','','.b-select-suggest'),(886926,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(886927,'furniture','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-color','$content-border-1','','','.b-select-suggest'),(886928,'furniture','.b-select-suggest .select2-container-multi .select2-choices','border-top-color','$content-border-1','','','.b-select-suggest'),(886929,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(886931,'furniture','.b-select-suggest .select2-search input','border-top-color','$content-border-1','','','.b-select-suggest'),(886932,'furniture','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-color','$content-border-1','','','.b-select-suggest'),(886933,'furniture','.b-select-suggest .select2-drop.select2-drop-above','border-top-color','$content-border-1','','','.b-select-suggest'),(886934,'furniture','.b-select-suggest .select2-drop-active','border-top-color','$content-border-1','','','.b-select-suggest'),(886935,'furniture','.b-select-suggest .select2-drop','border-top-color','$content-border-1','','','.b-select-suggest'),(886936,'furniture','.b-select-suggest .select2-drop-auto-width','border-top-color','$content-border-1','','','.b-select-suggest'),(886938,'furniture','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(886939,'furniture','.b-form input.required-error','border-top-color','$attention-border','','','.b-form'),(886940,'furniture','.w-communication-post .communication-post','border-top-color','$content-border-1','','','.w-communication-post'),(886941,'furniture','.checkbox input:checked + span','border-top-color','$checkbox-border-1','','',''),(886942,'furniture','.checkbox input + span','border-top-color','$content-border-1','','',''),(886943,'furniture','.b-autocomplete .ui-autocomplete','border-top-color','$content-border-1','','','.b-autocomplete'),(886946,'furniture','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(886947,'furniture','.b-info-popup .info-popup div','border-top-color','$content-border-1','3','','.b-info-popup'),(886948,'furniture','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(886949,'furniture','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(886950,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-color','$switch-nc-border-1','3','','.b-switch'),(886951,'furniture','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(886952,'furniture','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(886953,'furniture','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(886954,'furniture','.w-product-reviews .reviews-list .review','border-top-color','$content-border-1','3','','.w-product-reviews'),(886955,'furniture','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(886956,'furniture','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(886957,'furniture','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(886958,'furniture','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(886959,'furniture','.w-cart-products .checkout-attention-message','border-top-color','$warning-border','','','.w-cart-products'),(886960,'furniture','.w-cart-listing .item .gift-wrap label','border-top-color','$content-border-1','','','.w-cart-listing'),(886961,'furniture','.w-cart-listing .item','border-top-color','$content-border-1','5140','','.w-cart-listing'),(886963,'furniture','.w-cart-products .checkout-attention-message','border-top-color','$warning-border','','','.w-cart-products'),(886964,'furniture','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(886965,'furniture','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(886966,'furniture','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(886967,'furniture','.b-upload-files .added-file','border-top-color','$content-border-1','','','.b-upload-files'),(886968,'furniture','.b-data-table table.dataTable.no-footer','border-top-color','$content-border-1','','','.b-data-table'),(886969,'furniture','.b-data-table table.dataTable tbody td','border-top-color','$content-border-1','','','.b-data-table'),(886970,'furniture','.b-upload-files .upload-files','border-top-color','$content-border-1','','','.b-upload-files'),(886971,'furniture','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(886972,'furniture','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(886973,'furniture','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(886974,'furniture','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(886975,'furniture','.b-upload-file .snapshot','border-top-color','$content-border-2','','','.b-upload-file'),(886976,'furniture','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-top-color','$image-popup-border-1','','','.b-product-images'),(886977,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-top-color','$header-menu-border-1','','','.b-menu-style-2'),(886978,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-top-color','$header-menu-border-1','','','.b-menu-style-2'),(886979,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','border-top-color','$header-menu-border-1','','','.b-menu-style-2'),(886980,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-top-color','$header-menu-border-1','','','.b-menu-style-2'),(886981,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-top-color','$header-menu-border-1','','','.b-menu-style-2'),(886982,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-color','$content-border-1','','','.b-trade-approval'),(886983,'furniture','.w-account-personal-catalog .list-switcher a','border-top-color','$content-border-2','2','','.w-account-personal-catalog'),(886984,'furniture','.w-account-subscription .subscription-variant + .subscription-variant','border-top-color','$content-border-1','','','.w-account-subscription'),(886985,'furniture','.w-catalog-compare .compare .checkbox input:checked + span','border-top-color','$content-bg-1','','','.w-catalog-compare'),(886986,'furniture','.w-catalog-compare .cross-box .different-all > div','border-top-color','$content-border-2','2','','.w-catalog-compare'),(886987,'furniture','.w-delivery-day .left-text-left','border-top-color','$content-border-1','','','.w-delivery-day'),(886988,'furniture','.w-delivery-day .left-text-right','border-top-color','$content-border-1','','','.w-delivery-day'),(886990,'furniture','.cartTitle >div','border-top-color','$content-border-1','3','','.cartTitle'),(886991,'furniture','.b-products-listing .products-listing .compare input + span','border-top-color','$content-border-2','','','.b-products-listing'),(886992,'furniture','.w-filters .filter-widget','border-top-color','$content-border-1','','','.w-filters'),(886993,'furniture','.w-quote .cart-content','border-top-color','$content-border-1','','','.w-quote'),(886994,'furniture','.b-product-images .additional-images .active img','border-top-color','$highlight-box-color-1','','','.b-product-images'),(886995,'furniture','.b-product-images .additional-images img','border-top-color','$content-border-1','','','.b-product-images'),(886996,'furniture','.b-quantity .qty-box .bigger','border-top-color','$content-border-1','','','.b-quantity'),(886997,'furniture','.b-quantity .qty-box .smaller','border-top-color','$content-border-1','','','.b-quantity'),(886998,'furniture','.w-product-sale-ends .left-text-left','border-top-color','$content-border-1','','','.w-product-sale-ends'),(886999,'furniture','.w-product-sale-ends .left-text-right','border-top-color','$content-border-1','','','.w-product-sale-ends'),(887000,'furniture','.w-files-catalog-widgets-files-list .item + .item','border-top-color','$content-border-1','','','.w-files-catalog-widgets-files-list'),(887001,'furniture','.w-sample .cart-content','border-top-color','$content-border-1','','','.w-sample'),(887002,'furniture','.w-cart-listing .points-earn','border-top-color','transparent','4','','.w-cart-listing'),(887003,'furniture','.w-cart-discount-coupon .btn','border-top-color','$content-border-2','','','.w-cart-discount-coupon'),(887004,'furniture','.w-product-video .item img, .w-product-video .item video','border-top-color','$image-popup-border-1','','','.w-product-video'),(887005,'furniture','.w-product-video .item.active img, .w-product-video .item.active video','border-top-color','$highlight-box-border-1','','','.w-product-video'),(887006,'furniture','.w-cart-order-reference .btn','border-top-color','$content-border-2','','','.w-cart-order-reference'),(887007,'furniture','.w-cart-gift-certificate .btn','border-top-color','$content-border-2','','','.w-cart-gift-certificate'),(887008,'furniture','.w-cart-shipping-estimator .btn','border-top-color','$content-border-2','','','.w-cart-shipping-estimator'),(887009,'furniture','.w-product-bundle .bundle_item:nth-child(3) ~ .bundle_item','border-top-color','$content-border-1','','','.w-product-bundle'),(887010,'furniture','.w-product-bundle .bundle-total-price','border-top-color','$content-border-1','','','.w-product-bundle'),(887011,'furniture','.w-product-bundle .bundle_item:nth-child(2) ~ .bundle_item','border-top-color','$content-border-1','5140','','.w-product-bundle'),(887012,'furniture','.w-product-bundle .bundle_item:nth-child(1) ~ .bundle_item','border-top-color','$content-border-1','5131','','.w-product-bundle'),(887013,'furniture','.w-product-in-bundles .bundle-total-price','border-top-color','$content-border-1','','','.w-product-in-bundles'),(887014,'furniture','.w-product-in-bundles .bundle_item:nth-child(3) ~ .bundle_item','border-top-color','$content-border-1','','','.w-product-in-bundles'),(887015,'furniture','.w-product-in-bundles .bundle_item:nth-child(2) ~ .bundle_item','border-top-color','$content-border-1','5140','','.w-product-in-bundles'),(887016,'furniture','.w-product-in-bundles .bundle_item:nth-child(1) ~ .bundle_item','border-top-color','$content-border-1','5131','','.w-product-in-bundles'),(887018,'furniture','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-top-color','$content-border-2','','','.b-pagination'),(887019,'furniture','.b-pagination .pagination .next-pages','border-top-color','$content-border-1','','','.b-pagination'),(887020,'furniture','.b-pagination .pagination .page-number','border-top-color','$content-border-1','','','.b-pagination'),(887021,'furniture','.b-pagination .pagination .prev-pages','border-top-color','$content-border-1','','','.b-pagination'),(887022,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-top-color','$content-border-1','','','.b-pagination'),(887023,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-top-color','$content-border-1','','','.b-pagination'),(887024,'furniture','.b-pagination .pagination span','border-top-color','$highlight-box-border-2','2','','.b-pagination'),(887025,'furniture','.w-product-quantity-discounts .item + .item + .item','border-top-color','$content-border-1','','','.w-product-quantity-discounts'),(887026,'furniture','.w-tabs .tab-li','border-top-color','$tab-nav-border-1','2','','.w-tabs'),(887028,'furniture','.w-product-multi-inventory .radio-attributes .option-item','border-top-color','$content-border-1','','','.w-product-multi-inventory'),(887029,'furniture','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-top-color','$content-border-2','','','.w-product-multi-inventory'),(887030,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-top-color','$content-border-1','','','.w-account-personal-catalog'),(887031,'furniture','.w-account-personal-catalog .list-row-action ul','border-top-color','$content-border-1','','','.w-account-personal-catalog'),(887032,'furniture','.b-products-listing .products-listing .radio-attributes .option','border-top-color','$content-border-1','','','.b-products-listing'),(887033,'furniture','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-top-color','$content-border-2','','','.b-products-listing'),(887034,'furniture','.w-product-collection .choose-products','border-top-color','$content-border-1','','','.w-product-collection'),(887035,'furniture','.w-product-attributes .radio-attributes .option-item','border-top-color','$content-border-1','','','.w-product-attributes'),(887036,'furniture','.w-product-attributes .radio-attributes input:checked + .option-item','border-top-color','$content-border-2','','','.w-product-attributes'),(887037,'furniture','.w-questionnaire-widgets-questionnaire .question + .question','border-top-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(887038,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(887039,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-top-color','$attention-border','','','.w-questionnaire-widgets-questionnaire'),(887040,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-top-color','$message-border','','','.w-questionnaire-widgets-questionnaire'),(887041,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-top-color','$attention-border','1','','.w-questionnaire-widgets-questionnaire'),(887042,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-top-color','$message-border','1','','.w-questionnaire-widgets-questionnaire'),(887043,'furniture','.w-product-groups .radioBox label .containerBlock','border-top-color','$content-border-1','','','.w-product-groups'),(887044,'furniture','.w-product-groups .radioBox label .containerBlock.selected','border-top-color','$content-border-2','','','.w-product-groups'),(887045,'furniture','.w-product-groups .radioBox label input:checked + .containerBlock','border-top-color','$content-border-2','','','.w-product-groups'),(887046,'furniture','.w-product-custom-bundle .choose-products','border-top-color','$content-border-1','','','.w-product-custom-bundle'),(887047,'furniture','.w-product-custom-bundle .right-area .price','border-top-color','$content-border-1','5140','','.w-product-custom-bundle'),(887048,'furniture','.w-delivery-location-location-list .deliveryList li a','border-top-color','$content-border-1','','','.w-delivery-location-location-list'),(887049,'furniture','.w-delivery-location-location-list .deliveryList li a','border-top-color','$content-border-2','1','','.w-delivery-location-location-list'),(887050,'furniture','.w-sale-category .left-text-left','border-top-color','$content-border-1','','','.w-sale-category'),(887051,'furniture','.w-sale-category .left-text-right','border-top-color','$content-border-1','','','.w-sale-category'),(887052,'furniture','.w-sale-category .sale-holder','border-top-color','$content-border-1','','','.w-sale-category'),(887053,'furniture','.w-delivery-location-list-by-page .item','border-top-color','$content-border-1','','','.w-delivery-location-list-by-page'),(887054,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-top-color','$content-border-1','','','.w-product-properties-icons'),(887055,'furniture','.w-delivery-location-cross-pages .item','border-top-color','$content-border-1','','','.w-delivery-location-cross-pages'),(887056,'furniture','.w-product-designer-designer .prodDesignerType label','border-top-color','$content-border-1','','','.w-product-designer-designer'),(887057,'furniture','.w-press-reviews-widgets-press-reviews .press-reviews-button','border-top-color','$content-border-1','','','.w-press-reviews-widgets-press-reviews'),(887058,'furniture','.b-products-listing .productGroup label a','border-top-color','$content-border-2','','','.b-products-listing'),(887059,'furniture','.w-support-system-listing .support-head','border-top-color','$content-border-1','','','.w-support-system-listing'),(887060,'furniture','.w-support-system-listing .product_icon','border-top-color','$content-border-1','','','.w-support-system-listing'),(887061,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-color','$warning-border','','','.w-predefined-promotion'),(887062,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-color','$warning-border','','','.w-predefined-promotion'),(887063,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-color','$warning-border','','','.w-predefined-promotion'),(887064,'furniture','.w-predefined-promotion .promo-salemaker .discount','border-top-color','$warning-border','','','.w-predefined-promotion'),(887065,'furniture','.w-supplier-purchase-supplier-products .item','border-top-color','$content-border-1','','','.w-supplier-purchase-supplier-products'),(887066,'furniture','.mainBanner .bottomBox .btn','border-top-color','$main-banner-border-1','','','.mainBanner'),(887067,'furniture','.mainBanner .bottomBox .btn','border-top-color','$main-banner-border-1','5145','','.mainBanner'),(887068,'furniture','.mainBanner .bottomBox .btn','border-top-color','$main-banner-border-1','5131','','.mainBanner'),(887069,'furniture','.mainBanner .bottomBox .btn','border-top-color','$main-banner-border-1','5161','','.mainBanner'),(887070,'furniture','.mainBanner .bottomBox .btn','border-top-color','$main-banner-border-1','5206','','.mainBanner'),(887071,'furniture','.order-summary .price-row + .price-row','border-top-color','$content-border-1','','','.order-summary'),(887072,'furniture','.w-product-quantity-discounts .item','border-top-color','$content-border-1','','','.w-product-quantity-discounts'),(887075,'furniture','.account-samples .orders-table .item','border-top-color','$content-border-1','5140','','.account-samples'),(887076,'furniture','.catalog-product-wrap .pn-image','border-top-color','$content-border-1','3','','.catalog-product-wrap'),(887077,'furniture','.checkout-index-wrap .input-wrapper','border-top-color','$content-border-1','','','.checkout-index-wrap'),(887078,'furniture','.shopping-cart-index .btn-3','border-top-color','$content-border-2','','','.shopping-cart-index'),(887079,'furniture','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-color','$content-color-2','','','.b-multi-page-checkout'),(887080,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-color','$content-border-1','','','.b-multi-page-checkout'),(887081,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-color','$content-border-1','','','.b-multi-page-checkout'),(887082,'furniture','.lowestPricedBox .w-banner .ybg .btn','border-top-color','$additional-banner-border-1','','','.lowestPricedBox'),(887083,'furniture','.shopByCollectionBox .bannerButton a','border-top-color','$additional-banner-border-1','','','.shopByCollectionBox'),(887084,'furniture','.shopByCollectionBox .bannerButton a','border-top-color','$additional-banner-border-1','5145','','.shopByCollectionBox'),(887085,'furniture','.w-catalog-paging ','border-top-color','$content-border-1','2','','.w-catalog-paging'),(887086,'furniture','.w-catalog-paging .next','border-top-color','$content-border-1','','','.w-catalog-paging'),(887087,'furniture','.w-catalog-paging .next-pages','border-top-color','$content-border-1','','','.w-catalog-paging'),(887088,'furniture','.w-catalog-paging .page-number','border-top-color','$content-border-1','','','.w-catalog-paging'),(887089,'furniture','.w-catalog-paging .prev','border-top-color','$content-border-1','','','.w-catalog-paging'),(887090,'furniture','.w-catalog-paging .prev-pages','border-top-color','$content-border-1','','','.w-catalog-paging'),(887091,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-color','$content-border-1','','','.w-catalog-paging'),(887092,'furniture','.w-compare-box-item .checkbox + span','border-top-color','$content-border-1','','','.w-compare-box-item'),(887093,'furniture','.w-compare-box-item .checkbox:checked + span','border-top-color','$highlight-box-border-3','','','.w-compare-box-item'),(887094,'furniture','.b-data-table table.dataTable.no-footer','border-top-color_important','important','','','.b-data-table'),(887095,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-top-left-radius','0','4','','.b-switch'),(887096,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.p-quick-order-index'),(887097,'furniture','.w-promotions .prom-multi-discount .promo-range','border-top-left-radius','12','','','.w-promotions'),(887098,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.p-quick-order-index'),(887099,'furniture','.w-promotions .promo-salemaker .discount','border-top-left-radius','12','','','.w-promotions'),(887100,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-left-radius','12','','','.w-promotions'),(887101,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border-top-left-radius','12','','','.w-promotions'),(887102,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-left-radius','5','','','.b-messages'),(887103,'furniture','.b-fancybox .fancybox-close','border-top-left-radius','50','','','.b-fancybox'),(887104,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-left-radius','25','','','.b-switch'),(887105,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-top-left-radius','0','3','','.b-switch'),(887106,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-left-radius','15','3','','.b-switch'),(887107,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(887108,'furniture','.b-switch .bootstrap-switch','border-top-left-radius','14','','','.b-switch'),(887109,'furniture','.b-switch .candlestick-wrapper .candlestick-bg','border-top-left-radius','15','','','.b-switch'),(887110,'furniture','.w-checkout-shipping-choice label:first-child span','border-top-left-radius','16','','','.w-checkout-shipping-choice'),(887111,'furniture','.w-checkout-shipping-choice label:last-child span','border-top-left-radius','0','','','.w-checkout-shipping-choice'),(887112,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-left-radius','25','','','.b-switch'),(887113,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border-top-left-radius','50','3','','.b-form'),(887114,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-top-left-radius','50','3','','.b-switch'),(887115,'furniture','.b-fancybox .fancybox-title-float-wrap .child','border-top-left-radius','15','','','.b-fancybox'),(887116,'furniture','.b-fancybox .fancybox-skin','border-top-left-radius','4','','','.b-fancybox'),(887117,'furniture','.w-personal-gift-status-bar .progress-bar','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(887118,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-left-radius','15','4','','.b-switch'),(887119,'furniture','.w-personal-gift-status-bar .progress-bar-content','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(887120,'furniture','.b-fancybox .fancybox-nav span','border-top-left-radius','50','','','.b-fancybox'),(887121,'furniture','.w-product-customers-activity .close','border-top-left-radius','50','','','.w-product-customers-activity'),(887122,'furniture','.w-product-customers-activity .customers-activity','border-top-left-radius','10','','','.w-product-customers-activity'),(887123,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.b-data-table'),(887124,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.b-data-table'),(887125,'furniture','.b-products-listing .promos-info .promo-name','border-top-left-radius','0','','','.b-products-listing'),(887126,'furniture','.b-upload-file .snapshot','border-top-left-radius','50','','','.b-upload-file'),(887127,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(887128,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-top-left-radius','0','','','.b-product-images'),(887129,'furniture','.b-trade-approval .steps-bar','border-top-left-radius','18','','','.b-trade-approval'),(887130,'furniture','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-left-radius','3','','','.w-delivery-day'),(887131,'furniture','.w-delivery-day .left-count','border-top-left-radius','3','','','.w-delivery-day'),(887135,'furniture','.menu-header .burger-icon','border-top-left-radius','50','5140','','.menu-header'),(887136,'furniture','.w-quote .cart-box-link','border-top-left-radius','50','3','','.w-quote'),(887137,'furniture','.w-product-sale-ends .left-count','border-top-left-radius','3','','','.w-product-sale-ends'),(887138,'furniture','.w-product-sale-ends .left-count-days','border-top-left-radius','3','','','.w-product-sale-ends'),(887139,'furniture','.w-product-sale-ends .left-count-hours','border-top-left-radius','3','','','.w-product-sale-ends'),(887140,'furniture','.w-sample .cart-box-link','border-top-left-radius','50','3','','.w-sample'),(887141,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-left-radius','50','','','.w-questionnaire-widgets-questionnaire'),(887142,'furniture','.w-sale-category .badge','border-top-left-radius','50','','','.w-sale-category'),(887143,'furniture','.w-sale-category .left-count','border-top-left-radius','3','','','.w-sale-category'),(887144,'furniture','.w-sale-category .left-count-days','border-top-left-radius','3','','','.w-sale-category'),(887145,'furniture','.w-sale-category .left-count-hours','border-top-left-radius','3','','','.w-sale-category'),(887146,'furniture','.b-products-listing .productGroup label a','border-top-left-radius','3','','','.b-products-listing'),(887147,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-left-radius','12','','','.w-predefined-promotion'),(887148,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-left-radius','12','','','.w-predefined-promotion'),(887149,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-left-radius','12','','','.w-predefined-promotion'),(887150,'furniture','.w-predefined-promotion .promo-salemaker .discount','border-top-left-radius','12','','','.w-predefined-promotion'),(887151,'furniture','.w-cart-listing .promos-info .promo-name','border-top-left-radius','0','','','.w-cart-listing'),(887152,'furniture','.w-product-promotion-icons .promos-info .promo-name','border-top-left-radius','0','','','.w-product-promotion-icons'),(887154,'furniture','.catalog-product-wrap .pn-image','border-top-left-radius','50','3','','.catalog-product-wrap'),(887155,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-left-radius','50','','','.b-multi-page-checkout'),(887156,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-left-radius','50','3','','.b-multi-page-checkout'),(887157,'furniture','.success-page .w-cart-listing .qty','border-top-left-radius','50','','','.success-page'),(887158,'furniture','.lowestPricedBox .w-banner .ybg','border-top-left-radius','50','3','','.lowestPricedBox'),(887159,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-left-radius','0','','','.w-catalog-paging'),(887160,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-top-right-radius','0','4','','.b-switch'),(887161,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.p-quick-order-index'),(887162,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.p-quick-order-index'),(887163,'furniture','.w-promotions .prom-multi-discount .promo-range','border-top-right-radius','12','','','.w-promotions'),(887164,'furniture','.w-promotions .promo-salemaker .discount','border-top-right-radius','12','','','.w-promotions'),(887165,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-right-radius','12','','','.w-promotions'),(887166,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border-top-right-radius','12','','','.w-promotions'),(887167,'furniture','.b-upload-file .snapshot','border-top-right-radius','50','','','.b-upload-file'),(887168,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-right-radius','5','','','.b-messages'),(887169,'furniture','.w-personal-gift-status-bar .progress-bar','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(887170,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border-top-right-radius','50','3','','.b-form'),(887171,'furniture','.b-fancybox .fancybox-close','border-top-right-radius','50','','','.b-fancybox'),(887172,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-right-radius','25','','','.b-switch'),(887173,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-top-right-radius','0','3','','.b-switch'),(887174,'furniture','.b-switch .bootstrap-switch','border-top-right-radius','14','','','.b-switch'),(887175,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-right-radius','15','3','','.b-switch'),(887176,'furniture','.b-switch .candlestick-wrapper .candlestick-bg','border-top-right-radius','15','','','.b-switch'),(887177,'furniture','.w-checkout-shipping-choice label:last-child span','border-top-right-radius','16','','','.w-checkout-shipping-choice'),(887178,'furniture','.w-checkout-shipping-choice label:first-child span','border-top-right-radius','0','','','.w-checkout-shipping-choice'),(887179,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-right-radius','25','','','.b-switch'),(887180,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-top-right-radius','50','3','','.b-switch'),(887181,'furniture','.b-fancybox .fancybox-title-float-wrap .child','border-top-right-radius','15','','','.b-fancybox'),(887182,'furniture','.b-fancybox .fancybox-skin','border-top-right-radius','4','','','.b-fancybox'),(887183,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-right-radius','15','4','','.b-switch'),(887184,'furniture','.b-fancybox .fancybox-nav span','border-top-right-radius','50','','','.b-fancybox'),(887185,'furniture','.w-product-customers-activity .close','border-top-right-radius','50','','','.w-product-customers-activity'),(887186,'furniture','.w-product-customers-activity .customers-activity','border-top-right-radius','10','','','.w-product-customers-activity'),(887187,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.b-data-table'),(887188,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.b-data-table'),(887189,'furniture','.b-products-listing .promos-info .promo-name','border-top-right-radius','8','','','.b-products-listing'),(887190,'furniture','.w-personal-gift-status-bar .progress-bar-content','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(887191,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(887192,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(887193,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-top-right-radius','0','','','.b-product-images'),(887194,'furniture','.b-trade-approval .steps-bar','border-top-right-radius','18','','','.b-trade-approval'),(887195,'furniture','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-right-radius','3','','','.w-delivery-day'),(887196,'furniture','.w-delivery-day .left-count','border-top-right-radius','3','','','.w-delivery-day'),(887200,'furniture','.menu-header .burger-icon','border-top-right-radius','50','5140','','.menu-header'),(887201,'furniture','.w-quote .cart-box-link','border-top-right-radius','50','3','','.w-quote'),(887202,'furniture','.w-product-sale-ends .left-count','border-top-right-radius','3','','','.w-product-sale-ends'),(887203,'furniture','.w-product-sale-ends .left-count-days','border-top-right-radius','3','','','.w-product-sale-ends'),(887204,'furniture','.w-product-sale-ends .left-count-hours','border-top-right-radius','3','','','.w-product-sale-ends'),(887205,'furniture','.w-sample .cart-box-link','border-top-right-radius','50','3','','.w-sample'),(887206,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-right-radius','50','','','.w-questionnaire-widgets-questionnaire'),(887207,'furniture','.w-sale-category .badge','border-top-right-radius','50','','','.w-sale-category'),(887208,'furniture','.w-sale-category .left-count','border-top-right-radius','3','','','.w-sale-category'),(887209,'furniture','.w-sale-category .left-count-days','border-top-right-radius','3','','','.w-sale-category'),(887210,'furniture','.w-sale-category .left-count-hours','border-top-right-radius','3','','','.w-sale-category'),(887211,'furniture','.b-products-listing .productGroup label a','border-top-right-radius','3','','','.b-products-listing'),(887212,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-right-radius','12','','','.w-predefined-promotion'),(887213,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-right-radius','12','','','.w-predefined-promotion'),(887214,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-right-radius','12','','','.w-predefined-promotion'),(887215,'furniture','.w-predefined-promotion .promo-salemaker .discount','border-top-right-radius','12','','','.w-predefined-promotion'),(887216,'furniture','.w-cart-listing .promos-info .promo-name','border-top-right-radius','8','','','.w-cart-listing'),(887217,'furniture','.w-product-promotion-icons .promos-info .promo-name','border-top-right-radius','8','','','.w-product-promotion-icons'),(887219,'furniture','.catalog-product-wrap .pn-image','border-top-right-radius','50','3','','.catalog-product-wrap'),(887220,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-right-radius','50','','','.b-multi-page-checkout'),(887221,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-right-radius','50','3','','.b-multi-page-checkout'),(887222,'furniture','.success-page .w-cart-listing .qty','border-top-right-radius','50','','','.success-page'),(887223,'furniture','.lowestPricedBox .w-banner .ybg','border-top-right-radius','50','3','','.lowestPricedBox'),(887224,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-right-radius','0','','','.w-catalog-paging'),(887225,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(887226,'furniture','.w-communication-new-topic td','border-top-width','1','','','.w-communication-new-topic'),(887227,'furniture','.w-promotions .prom-multi-discount .promo-range','border-top-width','1','','','.w-promotions'),(887230,'furniture','.w-cart-compare .attributes-block td','border-top-width','1','','','.w-cart-compare'),(887232,'furniture','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(887233,'furniture','.b-email .qty','border-top-width','1','','','.b-email'),(887234,'furniture','.b-email .name','border-top-width','1','','','.b-email'),(887235,'furniture','.b-email .totals-table','border-top-width','1','','','.b-email'),(887236,'furniture','.testimonials .review','border-top-width','7','3','',''),(887237,'furniture','.w-promotions .promo-salemaker .discount','border-top-width','1','','','.w-promotions'),(887238,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-width','1','','','.w-promotions'),(887239,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border-top-width','1','','','.w-promotions'),(887240,'furniture','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(887241,'furniture','.b-messages .messMenuButtonTop','border-top-width','1','','','.b-messages'),(887242,'furniture','.b-messages .msv_btn','border-top-width','1','','','.b-messages'),(887243,'furniture','.b-messages .email-heading','border-top-width','1','','','.b-messages'),(887244,'furniture','.b-messages .dataTable','border-top-width','1','','','.b-messages'),(887245,'furniture','.b-messages .messages-menu li + li','border-top-width','1','','','.b-messages'),(887246,'furniture','.b-messages .content_management_attach button','border-top-width','1','','','.b-messages'),(887247,'furniture','.b-messages .content_management_attach','border-top-width','1','','','.b-messages'),(887248,'furniture','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-width','2','','','.b-messages'),(887249,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-top-width','2','','',''),(887250,'furniture','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(887251,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border-top-width','2','3','','.b-form'),(887252,'furniture','.w-socials > li','border-top-width','1','','','.w-socials'),(887253,'furniture','.p-payer-order-confirmation .input-wrapper','border-top-width','2','','','.p-payer-order-confirmation'),(887254,'furniture','.p-payer-order-pay .input-wrapper','border-top-width','2','','','.p-payer-order-pay'),(887255,'furniture','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(887256,'furniture','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(887257,'furniture','.b-email .price','border-top-width','1','','','.b-email'),(887258,'furniture','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(887259,'furniture','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(887260,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(887261,'furniture','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(887262,'furniture','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(887263,'furniture','.b-email .model','border-top-width','1','','','.b-email'),(887264,'furniture','.b-email .model','border-top-width','1','','','.b-email'),(887265,'furniture','.b-email .price','border-top-width','1','','','.b-email'),(887266,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-width','2','3','','.b-switch'),(887267,'furniture','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(887268,'furniture','.w-filters .ui-slider','border-top-width','0','','','.w-filters'),(887269,'furniture','.w-filters .ui-slider-handle','border-top-width','0','','','.w-filters'),(887270,'furniture','.b-email .name','border-top-width','1','','','.b-email'),(887271,'furniture','.b-email .qty','border-top-width','1','','','.b-email'),(887272,'furniture','.b-email .totals-table','border-top-width','1','','','.b-email'),(887273,'furniture','.w-checkout-shipping-choice span','border-top-width','2','','','.w-checkout-shipping-choice'),(887274,'furniture','.w-socials > li','border-top-width','1','','','.w-socials'),(887276,'furniture','.w-cart-compare .product-block td','border-top-width','1','','','.w-cart-compare'),(887277,'furniture','.b-info-popup .info-popup div','border-top-width','1','','','.b-info-popup'),(887278,'furniture','.b-email .qty','border-top-width','1','','','.b-email'),(887279,'furniture','.w-socials > li','border-top-width','1','','','.w-socials'),(887280,'furniture','.b-bottom .popup-buttons','border-top-width','1','','','.b-bottom'),(887281,'furniture','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(887282,'furniture','.totals-line','border-top-width','1','','',''),(887283,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-width','4','','','.b-switch'),(887284,'furniture','.b-email .name','border-top-width','1','','','.b-email'),(887285,'furniture','.b-email .totals-table','border-top-width','1','','','.b-email'),(887286,'furniture','.b-email .name','border-top-width','1','','','.b-email'),(887287,'furniture','.order-summary .price-row + .price-row','border-top-width','1','','','.order-summary'),(887288,'furniture','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(887290,'furniture','.w-reviews .review','border-top-width','8','3','','.w-reviews'),(887292,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-width','3','','','.b-switch'),(887293,'furniture','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(887294,'furniture','.b-email .image','border-top-width','1','','','.b-email'),(887295,'furniture','.b-email .image','border-top-width','1','','','.b-email'),(887296,'furniture','.b-email .model','border-top-width','1','','','.b-email'),(887297,'furniture','.w-socials > li','border-top-width','1','','','.w-socials'),(887298,'furniture','.b-email .image','border-top-width','1','','','.b-email'),(887299,'furniture','.b-email .price','border-top-width','1','','','.b-email'),(887300,'furniture','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(887301,'furniture','.b-email .name','border-top-width','1','','','.b-email'),(887302,'furniture','.b-email .qty','border-top-width','1','','','.b-email'),(887303,'furniture','.b-email .model','border-top-width','1','','','.b-email'),(887304,'furniture','.b-email .totals-table','border-top-width','1','','','.b-email'),(887305,'furniture','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(887306,'furniture','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(887307,'furniture','.b-form .shipping-method .item + .item','border-top-width','1','','','.b-form'),(887308,'furniture','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(887309,'furniture','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(887310,'furniture','.b-select-suggest .select2-container .select2-choice','border-top-width','2','','','.b-select-suggest'),(887311,'furniture','.view-all','border-top-width','1','3','',''),(887312,'furniture','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(887313,'furniture','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(887314,'furniture','textarea','border-top-width','2','','',''),(887315,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-width','2','4','','.b-switch'),(887316,'furniture','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(887317,'furniture','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(887319,'furniture','.w-cart-compare .cart-cell > div','border-top-width','1','','','.w-cart-compare'),(887321,'furniture','.b-form .form-buttons','border-top-width','1','','','.b-form'),(887322,'furniture','.b-form .required-error','border-top-width','1','','','.b-form'),(887323,'furniture','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(887324,'furniture','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(887325,'furniture','.b-email .totals-table','border-top-width','1','','','.b-email'),(887327,'furniture','.b-email .model','border-top-width','1','','','.b-email'),(887328,'furniture','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-top-width','1','','','.b-bottom'),(887329,'furniture','.b-email .model','border-top-width','1','','','.b-email'),(887330,'furniture','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(887331,'furniture','.b-upload-files .upload-files','border-top-width','1','','','.b-upload-files'),(887332,'furniture','.b-upload-files .added-file','border-top-width','1','','','.b-upload-files'),(887333,'furniture','.b-bottom .popup-box','border-top-width','1','','','.b-bottom'),(887334,'furniture','.b-email .image','border-top-width','1','','','.b-email'),(887335,'furniture','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(887336,'furniture','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(887337,'furniture','.w-product-customers-activity .customers-activity','border-top-width','1','','','.w-product-customers-activity'),(887338,'furniture','.b-form .privacy-row','border-top-width','1','','','.b-form'),(887339,'furniture','.w-reviews-content .review','border-top-width','8','3','','.w-reviews-content'),(887340,'furniture','.w-cart-compare .price-block td','border-top-width','1','','','.w-cart-compare'),(887341,'furniture','.w-socials > li','border-top-width','1','','','.w-socials'),(887342,'furniture','.w-product-reviews .reviews-list .review','border-top-width','7','3','','.w-product-reviews'),(887343,'furniture','.b-upload-file .upload-file-template','border-top-width','1','','','.b-upload-file'),(887344,'furniture','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(887345,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(887346,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-width','1','','','.b-select-suggest'),(887347,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(887348,'furniture','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-width','1','','','.b-select-suggest'),(887349,'furniture','.b-select-suggest .select2-container-multi .select2-choices','border-top-width','1','','','.b-select-suggest'),(887350,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-width','1','','','.b-select-suggest'),(887351,'furniture','.b-select-suggest .select2-search input','border-top-width','1','','','.b-select-suggest'),(887352,'furniture','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-width','1','','','.b-select-suggest'),(887353,'furniture','.b-select-suggest .select2-drop.select2-drop-above','border-top-width','1','','','.b-select-suggest'),(887354,'furniture','.b-select-suggest .select2-drop-active','border-top-width','1','','','.b-select-suggest'),(887355,'furniture','.b-select-suggest .select2-drop-auto-width','border-top-width','1','','','.b-select-suggest'),(887356,'furniture','.w-socials > li','border-top-width','1','','','.w-socials'),(887357,'furniture','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(887359,'furniture','.b-form .payment-method .item + .item','border-top-width','1','','','.b-form'),(887360,'furniture','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(887361,'furniture','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(887363,'furniture','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-top-width','1','','','.b-bottom'),(887364,'furniture','.w-communication-post .communication-post','border-top-width','1','','','.w-communication-post'),(887365,'furniture','.checkbox input:checked + span','border-top-width','1','','',''),(887366,'furniture','.checkbox input + span','border-top-width','1','','',''),(887367,'furniture','.b-autocomplete .ui-autocomplete','border-top-width','1','','','.b-autocomplete'),(887370,'furniture','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(887371,'furniture','.b-info-popup .info-popup div','border-top-width','1','3','','.b-info-popup'),(887372,'furniture','.b-email .price','border-top-width','1','','','.b-email'),(887373,'furniture','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(887374,'furniture','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(887375,'furniture','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(887376,'furniture','.b-email .image','border-top-width','1','','','.b-email'),(887377,'furniture','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(887378,'furniture','.b-email .price','border-top-width','1','','','.b-email'),(887379,'furniture','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(887381,'furniture','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(887382,'furniture','.w-checkout-shipping .sub-item + .sub-item','border-top-width','1','','','.w-checkout-shipping'),(887383,'furniture','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(887384,'furniture','.w-cart-listing .item .gift-wrap label','border-top-width','1','','','.w-cart-listing'),(887385,'furniture','.w-cart-listing .item','border-top-width','1','5140','','.w-cart-listing'),(887387,'furniture','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(887388,'furniture','.b-email .image','border-top-width','1','','','.b-email'),(887389,'furniture','.b-email .price','border-top-width','1','','','.b-email'),(887390,'furniture','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(887391,'furniture','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(887392,'furniture','.w-filters .ui-slider-range','border-top-width','0','','','.w-filters'),(887393,'furniture','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(887394,'furniture','.b-email .qty','border-top-width','1','','','.b-email'),(887395,'furniture','.b-email .name','border-top-width','1','','','.b-email'),(887396,'furniture','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(887397,'furniture','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(887398,'furniture','.b-data-table table.dataTable tbody td','border-top-width','1','','','.b-data-table'),(887399,'furniture','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-width','1','','','.b-compare'),(887400,'furniture','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(887401,'furniture','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(887402,'furniture','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(887403,'furniture','.b-email .totals-table','border-top-width','1','','','.b-email'),(887404,'furniture','.b-email .qty','border-top-width','1','','','.b-email'),(887405,'furniture','.b-upload-file .snapshot','border-top-width','1','','','.b-upload-file'),(887406,'furniture','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-top-width','2','','','.b-product-images'),(887407,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','border-top-width','1','','','.b-menu-style-2'),(887408,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','border-top-width','3','','','.b-menu-style-2'),(887409,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','border-top-width','1','','','.b-menu-style-2'),(887410,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','border-top-width','1','','','.b-menu-style-2'),(887411,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','border-top-width','3','','','.b-menu-style-2'),(887412,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-width','2','','','.b-trade-approval'),(887413,'furniture','.w-account-personal-catalog .list-switcher a','border-top-width','3','2','','.w-account-personal-catalog'),(887414,'furniture','.w-account-subscription .subscription-variant + .subscription-variant','border-top-width','1','','','.w-account-subscription'),(887415,'furniture','.w-catalog-compare .compare .checkbox input:checked + span','border-top-width','1','','','.w-catalog-compare'),(887416,'furniture','.w-catalog-compare .cross-box .different-all > div','border-top-width','3','2','','.w-catalog-compare'),(887417,'furniture','.w-delivery-day .left-text-left','border-top-width','2','','','.w-delivery-day'),(887418,'furniture','.w-delivery-day .left-text-right','border-top-width','2','','','.w-delivery-day'),(887419,'furniture','.b-slick .slick-vertical .slick-slide','border-top-width','1','','','.b-slick'),(887420,'furniture','.cartTitle >div','border-top-width','1','3','','.cartTitle'),(887421,'furniture','.b-products-listing .products-listing .compare input + span','border-top-width','1','','','.b-products-listing'),(887422,'furniture','.w-filters .filter-widget','border-top-width','1','','','.w-filters'),(887423,'furniture','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-top-width','0','','','.w-filters'),(887424,'furniture','.b-products-listing .products-listing.list-rows .item:first-of-type .BlockBox.item-holder','border-top-width','0','','','.b-products-listing'),(887425,'furniture','.w-quote .cart-content','border-top-width','1','','','.w-quote'),(887426,'furniture','.b-product-images .additional-images .active img','border-top-width','2','','','.b-product-images'),(887427,'furniture','.b-product-images .additional-images img','border-top-width','2','','','.b-product-images'),(887428,'furniture','.b-quantity .qty-box .bigger','border-top-width','2','','','.b-quantity'),(887429,'furniture','.b-quantity .qty-box .smaller','border-top-width','2','','','.b-quantity'),(887430,'furniture','.w-product-sale-ends .left-text-left','border-top-width','2','','','.w-product-sale-ends'),(887431,'furniture','.w-product-sale-ends .left-text-right','border-top-width','2','','','.w-product-sale-ends'),(887432,'furniture','.w-files-catalog-widgets-files-list .item + .item','border-top-width','1','','','.w-files-catalog-widgets-files-list'),(887433,'furniture','.w-sample .cart-content','border-top-width','1','','','.w-sample'),(887434,'furniture','.w-cart-listing .points-earn','border-top-width','17','4','','.w-cart-listing'),(887435,'furniture','.w-cart-discount-coupon .btn','border-top-width','2','','','.w-cart-discount-coupon'),(887436,'furniture','.w-product-video .item img, .w-product-video .item video','border-top-width','2','','','.w-product-video'),(887437,'furniture','.w-product-video .item.active img, .w-product-video .item.active video','border-top-width','2','','','.w-product-video'),(887438,'furniture','.w-cart-order-reference .btn','border-top-width','2','','','.w-cart-order-reference'),(887439,'furniture','.w-cart-gift-certificate .btn','border-top-width','2','','','.w-cart-gift-certificate'),(887440,'furniture','.w-cart-shipping-estimator .btn','border-top-width','2','','','.w-cart-shipping-estimator'),(887441,'furniture','.w-product-bundle .bundle_item:nth-child(3) ~ .bundle_item','border-top-width','1','','','.w-product-bundle'),(887442,'furniture','.w-product-bundle .bundle-total-price','border-top-width','1','','','.w-product-bundle'),(887443,'furniture','.w-product-bundle .bundle_item:nth-child(2) ~ .bundle_item','border-top-width','1','5140','','.w-product-bundle'),(887444,'furniture','.w-product-bundle .bundle_item:nth-child(1) ~ .bundle_item','border-top-width','1','5131','','.w-product-bundle'),(887445,'furniture','.w-product-in-bundles .bundle-total-price','border-top-width','1','','','.w-product-in-bundles'),(887446,'furniture','.w-product-in-bundles .bundle_item:nth-child(3) ~ .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(887447,'furniture','.w-product-in-bundles .bundle_item:nth-child(2) ~ .bundle_item','border-top-width','1','5140','','.w-product-in-bundles'),(887448,'furniture','.w-product-in-bundles .bundle_item:nth-child(1) ~ .bundle_item','border-top-width','1','5131','','.w-product-in-bundles'),(887450,'furniture','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-top-width','1','','','.b-pagination'),(887451,'furniture','.b-pagination .pagination .next-pages','border-top-width','1','','','.b-pagination'),(887452,'furniture','.b-pagination .pagination .page-number','border-top-width','1','','','.b-pagination'),(887453,'furniture','.b-pagination .pagination .prev-pages','border-top-width','1','','','.b-pagination'),(887454,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-top-width','1','','','.b-pagination'),(887455,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-top-width','1','','','.b-pagination'),(887456,'furniture','.b-pagination .pagination span','border-top-width','1','2','','.b-pagination'),(887457,'furniture','.w-product-quantity-discounts .item + .item + .item','border-top-width','1','','','.w-product-quantity-discounts'),(887458,'furniture','.w-tabs .tab-li','border-top-width','3','2','','.w-tabs'),(887460,'furniture','.w-product-multi-inventory .radio-attributes .option-item','border-top-width','2','','','.w-product-multi-inventory'),(887461,'furniture','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-top-width','2','','','.w-product-multi-inventory'),(887462,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-top-width','1','','','.w-account-personal-catalog'),(887463,'furniture','.w-account-personal-catalog .list-row-action ul','border-top-width','1','','','.w-account-personal-catalog'),(887464,'furniture','.b-products-listing .products-listing .radio-attributes .option','border-top-width','2','','','.b-products-listing'),(887465,'furniture','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-top-width','2','','','.b-products-listing'),(887466,'furniture','.w-product-collection .choose-products','border-top-width','1','','','.w-product-collection'),(887467,'furniture','.w-product-attributes .radio-attributes .option-item','border-top-width','2','','','.w-product-attributes'),(887468,'furniture','.w-product-attributes .radio-attributes input:checked + .option-item','border-top-width','2','','','.w-product-attributes'),(887469,'furniture','.w-questionnaire-widgets-questionnaire .question + .question','border-top-width','1','','','.w-questionnaire-widgets-questionnaire'),(887470,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-width','2','','','.w-questionnaire-widgets-questionnaire'),(887471,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-top-width','2','','','.w-questionnaire-widgets-questionnaire'),(887472,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-top-width','2','','','.w-questionnaire-widgets-questionnaire'),(887473,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-top-width','2','1','','.w-questionnaire-widgets-questionnaire'),(887474,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-top-width','2','1','','.w-questionnaire-widgets-questionnaire'),(887475,'furniture','.w-product-groups .radioBox label .containerBlock','border-top-width','2','','','.w-product-groups'),(887476,'furniture','.w-product-groups .radioBox label .containerBlock.selected','border-top-width','2','','','.w-product-groups'),(887477,'furniture','.w-product-groups .radioBox label input:checked + .containerBlock','border-top-width','2','','','.w-product-groups'),(887478,'furniture','.w-product-custom-bundle .choose-products','border-top-width','1','','','.w-product-custom-bundle'),(887479,'furniture','.w-product-custom-bundle .right-area .price','border-top-width','1','5140','','.w-product-custom-bundle'),(887480,'furniture','.w-delivery-location-location-list .deliveryList li a','border-top-width','2','','','.w-delivery-location-location-list'),(887481,'furniture','.w-delivery-location-location-list .deliveryList li a','border-top-width','2','1','','.w-delivery-location-location-list'),(887482,'furniture','.w-sale-category .left-text-left','border-top-width','2','','','.w-sale-category'),(887483,'furniture','.w-sale-category .left-text-right','border-top-width','2','','','.w-sale-category'),(887484,'furniture','.w-sale-category .sale-holder','border-top-width','2','','','.w-sale-category'),(887485,'furniture','.w-delivery-location-list-by-page .item','border-top-width','1','','','.w-delivery-location-list-by-page'),(887486,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-top-width','1','','','.w-product-properties-icons'),(887487,'furniture','.w-delivery-location-cross-pages .item','border-top-width','1','','','.w-delivery-location-cross-pages'),(887488,'furniture','.w-product-designer-designer .prodDesignerType label','border-top-width','1','','','.w-product-designer-designer'),(887489,'furniture','.w-press-reviews-widgets-press-reviews .press-reviews-button','border-top-width','1','','','.w-press-reviews-widgets-press-reviews'),(887490,'furniture','.b-products-listing .productGroup label a','border-top-width','1','','','.b-products-listing'),(887491,'furniture','.w-support-system-listing .support-head','border-top-width','1','','','.w-support-system-listing'),(887492,'furniture','.w-support-system-listing .product_icon','border-top-width','1','','','.w-support-system-listing'),(887493,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-width','1','','','.w-predefined-promotion'),(887494,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-width','1','','','.w-predefined-promotion'),(887495,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-width','1','','','.w-predefined-promotion'),(887496,'furniture','.w-predefined-promotion .promo-salemaker .discount','border-top-width','1','','','.w-predefined-promotion'),(887497,'furniture','.w-supplier-purchase-supplier-products .item','border-top-width','1','','','.w-supplier-purchase-supplier-products'),(887498,'furniture','.mainBanner .bottomBox .btn','border-top-width','0.21','','','.mainBanner'),(887499,'furniture','.mainBanner .topBox > .right','border-top-width','23','4','','.mainBanner'),(887500,'furniture','.mainBanner .bottomBox .btn','border-top-width','2','5145','','.mainBanner'),(887501,'furniture','.mainBanner .topBox > .right','border-top-width','20','5145,4','','.mainBanner'),(887502,'furniture','.mainBanner .bottomBox .btn','border-top-width','3','5131','','.mainBanner'),(887503,'furniture','.mainBanner .topBox > .right','border-top-width','15','5131,4','','.mainBanner'),(887504,'furniture','.mainBanner .bottomBox .btn','border-top-width','2','5161','','.mainBanner'),(887505,'furniture','.mainBanner .bottomBox .btn','border-top-width','3','5206','','.mainBanner'),(887506,'furniture','.w-product-quantity-discounts .item','border-top-width','1','','','.w-product-quantity-discounts'),(887512,'furniture','.account-samples .orders-table .item','border-top-width','1','5140','','.account-samples'),(887513,'furniture','.account-samples .orders-table .td-alignright','border-top-width','1','5140','','.account-samples'),(887514,'furniture','.catalog-product-wrap .pn-image','border-top-width','2','3','','.catalog-product-wrap'),(887515,'furniture','.catalog-product-wrap .pn-image','border-top-width','1','','','.catalog-product-wrap'),(887516,'furniture','.catalog-product-wrap .pn-name','border-top-width','1','','','.catalog-product-wrap'),(887517,'furniture','.catalog-product-wrap .prev-next-product','border-top-width','1','','','.catalog-product-wrap'),(887518,'furniture','.checkout-index-wrap .input-wrapper','border-top-width','2','','','.checkout-index-wrap'),(887519,'furniture','.shopping-cart-index .btn-3','border-top-width','2','','','.shopping-cart-index'),(887520,'furniture','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(887521,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-content','border-top-width','1','','','.b-multi-page-checkout'),(887522,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(887523,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-width','1','','','.b-multi-page-checkout'),(887524,'furniture','.lowestPricedBox .w-banner .ybg .btn','border-top-width','2','','','.lowestPricedBox'),(887525,'furniture','.shopByCollectionBox .bannerButton a','border-top-width','2','','','.shopByCollectionBox'),(887526,'furniture','.shopByCollectionBox .bannerButton a','border-top-width','2','5145','','.shopByCollectionBox'),(887527,'furniture','.w-catalog-paging ','border-top-width','1','2','','.w-catalog-paging'),(887528,'furniture','.w-catalog-paging .next','border-top-width','1','','','.w-catalog-paging'),(887529,'furniture','.w-catalog-paging .next-pages','border-top-width','1','','','.w-catalog-paging'),(887530,'furniture','.w-catalog-paging .page-number','border-top-width','1','','','.w-catalog-paging'),(887531,'furniture','.w-catalog-paging .prev','border-top-width','1','','','.w-catalog-paging'),(887532,'furniture','.w-catalog-paging .prev-pages','border-top-width','1','','','.w-catalog-paging'),(887533,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-width','1','','','.w-catalog-paging'),(887534,'furniture','.w-compare-box-item .checkbox + span','border-top-width','1','','','.w-compare-box-item'),(887535,'furniture','.w-compare-box-item .checkbox:checked + span','border-top-width','1','','','.w-compare-box-item'),(887536,'furniture','.mainBanner .bottomBox .btn','border_bottom_width_measure','vw','','','.mainBanner'),(887537,'furniture','.b-autocomplete .ui-autocomplete li','border_important','important','','','.b-autocomplete'),(887538,'furniture','.b-data-table table.dataTable thead td','border_important','important','','','.b-data-table'),(887539,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','border_important','important','','','.w-rma-returns-history'),(887540,'furniture','.mainBanner .bottomBox .btn','border_left_width_measure','vw','','','.mainBanner'),(887541,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_1_measure','px','4','','.b-switch'),(887542,'furniture','.w-personal-gift-status-bar .progress-bar-content','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(887543,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.p-quick-order-index'),(887544,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.p-quick-order-index'),(887545,'furniture','.w-promotions .prom-multi-discount .promo-range','border_radius_1_measure','px','','','.w-promotions'),(887546,'furniture','.w-promotions .promo-salemaker .discount','border_radius_1_measure','px','','','.w-promotions'),(887547,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_1_measure','px','','','.w-promotions'),(887548,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_1_measure','px','','','.w-promotions'),(887549,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_1_measure','px','','','.b-messages'),(887550,'furniture','.b-fancybox .fancybox-close','border_radius_1_measure','%','','','.b-fancybox'),(887551,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_1_measure','px','','','.b-switch'),(887552,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_1_measure','px','3','','.b-switch'),(887553,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_1_measure','px','3','','.b-switch'),(887554,'furniture','.b-switch .bootstrap-switch','border_radius_1_measure','px','','','.b-switch'),(887555,'furniture','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_1_measure','px','','','.b-switch'),(887556,'furniture','.w-checkout-shipping-choice label:last-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(887557,'furniture','.w-checkout-shipping-choice label:first-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(887558,'furniture','.w-personal-gift-status-bar .progress-bar','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(887559,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_1_measure','px','','','.b-switch'),(887560,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_1_measure','%','3','','.b-switch'),(887561,'furniture','.b-fancybox .fancybox-title-float-wrap .child','border_radius_1_measure','px','','','.b-fancybox'),(887562,'furniture','.b-fancybox .fancybox-skin','border_radius_1_measure','px','','','.b-fancybox'),(887563,'furniture','.b-fancybox .fancybox-nav span','border_radius_1_measure','%','','','.b-fancybox'),(887564,'furniture','.w-product-customers-activity .close','border_radius_1_measure','%','','','.w-product-customers-activity'),(887565,'furniture','.w-product-customers-activity .customers-activity','border_radius_1_measure','px','','','.w-product-customers-activity'),(887566,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_1_measure','px','4','','.b-switch'),(887567,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.b-data-table'),(887568,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.b-data-table'),(887569,'furniture','.b-products-listing .promos-info .promo-name','border_radius_1_measure','px','','','.b-products-listing'),(887570,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(887571,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_1_measure','%','3','','.b-form'),(887572,'furniture','.b-upload-file .snapshot','border_radius_1_measure','%','','','.b-upload-file'),(887573,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(887574,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_1_measure','px','','','.b-product-images'),(887575,'furniture','.b-trade-approval .steps-bar','border_radius_1_measure','px','','','.b-trade-approval'),(887576,'furniture','.w-delivery-day .left-count','border_radius_1_measure','px','','','.w-delivery-day'),(887577,'furniture','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_1_measure','px','','','.w-delivery-day'),(887581,'furniture','.menu-header .burger-icon','border_radius_1_measure','%','5140','','.menu-header'),(887582,'furniture','.w-quote .cart-box-link','border_radius_1_measure','%','3','','.w-quote'),(887583,'furniture','.w-product-sale-ends .left-count','border_radius_1_measure','px','','','.w-product-sale-ends'),(887584,'furniture','.w-product-sale-ends .left-count-days','border_radius_1_measure','px','','','.w-product-sale-ends'),(887585,'furniture','.w-product-sale-ends .left-count-hours','border_radius_1_measure','px','','','.w-product-sale-ends'),(887586,'furniture','.w-sample .cart-box-link','border_radius_1_measure','%','3','','.w-sample'),(887587,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_1_measure','%','','','.w-questionnaire-widgets-questionnaire'),(887588,'furniture','.w-sale-category .badge','border_radius_1_measure','%','','','.w-sale-category'),(887589,'furniture','.w-sale-category .left-count','border_radius_1_measure','px','','','.w-sale-category'),(887590,'furniture','.w-sale-category .left-count-days','border_radius_1_measure','px','','','.w-sale-category'),(887591,'furniture','.w-sale-category .left-count-hours','border_radius_1_measure','px','','','.w-sale-category'),(887592,'furniture','.b-products-listing .productGroup label a','border_radius_1_measure','px','','','.b-products-listing'),(887593,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_1_measure','px','','','.w-predefined-promotion'),(887594,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_1_measure','px','','','.w-predefined-promotion'),(887595,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_1_measure','px','','','.w-predefined-promotion'),(887596,'furniture','.w-predefined-promotion .promo-salemaker .discount','border_radius_1_measure','px','','','.w-predefined-promotion'),(887597,'furniture','.w-cart-listing .promos-info .promo-name','border_radius_1_measure','px','','','.w-cart-listing'),(887598,'furniture','.w-product-promotion-icons .promos-info .promo-name','border_radius_1_measure','px','','','.w-product-promotion-icons'),(887600,'furniture','.catalog-product-wrap .pn-image','border_radius_1_measure','%','3','','.catalog-product-wrap'),(887601,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_1_measure','%','','','.b-multi-page-checkout'),(887602,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_1_measure','%','3','','.b-multi-page-checkout'),(887603,'furniture','.success-page .w-cart-listing .qty','border_radius_1_measure','%','','','.success-page'),(887604,'furniture','.lowestPricedBox .w-banner .ybg','border_radius_1_measure','%','3','','.lowestPricedBox'),(887605,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_1_measure','px','','','.w-catalog-paging'),(887606,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_2_measure','px','4','','.b-switch'),(887607,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_2_measure','px','','','.b-switch'),(887608,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.p-quick-order-index'),(887609,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.p-quick-order-index'),(887610,'furniture','.w-promotions .prom-multi-discount .promo-range','border_radius_2_measure','px','','','.w-promotions'),(887611,'furniture','.w-promotions .promo-salemaker .discount','border_radius_2_measure','px','','','.w-promotions'),(887612,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_2_measure','px','','','.w-promotions'),(887613,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_2_measure','px','','','.w-promotions'),(887614,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_2_measure','px','4','','.b-switch'),(887615,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_2_measure','px','','','.b-messages'),(887616,'furniture','.b-fancybox .fancybox-close','border_radius_2_measure','%','','','.b-fancybox'),(887617,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_2_measure','px','','','.b-switch'),(887618,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_2_measure','px','3','','.b-switch'),(887619,'furniture','.b-switch .bootstrap-switch','border_radius_2_measure','px','','','.b-switch'),(887620,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_2_measure','px','3','','.b-switch'),(887621,'furniture','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_2_measure','px','','','.b-switch'),(887622,'furniture','.w-checkout-shipping-choice label:last-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(887623,'furniture','.w-checkout-shipping-choice label:first-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(887624,'furniture','.w-personal-gift-status-bar .progress-bar-content','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(887625,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_2_measure','%','3','','.b-switch'),(887626,'furniture','.b-fancybox .fancybox-title-float-wrap .child','border_radius_2_measure','px','','','.b-fancybox'),(887627,'furniture','.b-fancybox .fancybox-skin','border_radius_2_measure','px','','','.b-fancybox'),(887628,'furniture','.b-upload-file .snapshot','border_radius_2_measure','%','','','.b-upload-file'),(887629,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_2_measure','%','3','','.b-form'),(887630,'furniture','.b-fancybox .fancybox-nav span','border_radius_2_measure','%','','','.b-fancybox'),(887631,'furniture','.w-product-customers-activity .close','border_radius_2_measure','%','','','.w-product-customers-activity'),(887632,'furniture','.w-product-customers-activity .customers-activity','border_radius_2_measure','px','','','.w-product-customers-activity'),(887633,'furniture','.w-personal-gift-status-bar .progress-bar','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(887634,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.b-data-table'),(887635,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.b-data-table'),(887636,'furniture','.b-products-listing .promos-info .promo-name','border_radius_2_measure','px','','','.b-products-listing'),(887637,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(887638,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(887639,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_2_measure','px','','','.b-product-images'),(887640,'furniture','.b-trade-approval .steps-bar','border_radius_2_measure','px','','','.b-trade-approval'),(887641,'furniture','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_2_measure','px','','','.w-delivery-day'),(887642,'furniture','.w-delivery-day .left-count','border_radius_2_measure','px','','','.w-delivery-day'),(887646,'furniture','.menu-header .burger-icon','border_radius_2_measure','%','5140','','.menu-header'),(887647,'furniture','.w-quote .cart-box-link','border_radius_2_measure','%','3','','.w-quote'),(887648,'furniture','.w-product-sale-ends .left-count','border_radius_2_measure','px','','','.w-product-sale-ends'),(887649,'furniture','.w-product-sale-ends .left-count-days','border_radius_2_measure','px','','','.w-product-sale-ends'),(887650,'furniture','.w-product-sale-ends .left-count-hours','border_radius_2_measure','px','','','.w-product-sale-ends'),(887651,'furniture','.w-sample .cart-box-link','border_radius_2_measure','%','3','','.w-sample'),(887652,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_2_measure','%','','','.w-questionnaire-widgets-questionnaire'),(887653,'furniture','.w-sale-category .badge','border_radius_2_measure','%','','','.w-sale-category'),(887654,'furniture','.w-sale-category .left-count','border_radius_2_measure','px','','','.w-sale-category'),(887655,'furniture','.w-sale-category .left-count-days','border_radius_2_measure','px','','','.w-sale-category'),(887656,'furniture','.w-sale-category .left-count-hours','border_radius_2_measure','px','','','.w-sale-category'),(887657,'furniture','.b-products-listing .productGroup label a','border_radius_2_measure','px','','','.b-products-listing'),(887658,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_2_measure','px','','','.w-predefined-promotion'),(887659,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_2_measure','px','','','.w-predefined-promotion'),(887660,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_2_measure','px','','','.w-predefined-promotion'),(887661,'furniture','.w-predefined-promotion .promo-salemaker .discount','border_radius_2_measure','px','','','.w-predefined-promotion'),(887662,'furniture','.w-cart-listing .promos-info .promo-name','border_radius_2_measure','px','','','.w-cart-listing'),(887663,'furniture','.w-product-promotion-icons .promos-info .promo-name','border_radius_2_measure','px','','','.w-product-promotion-icons'),(887665,'furniture','.catalog-product-wrap .pn-image','border_radius_2_measure','%','3','','.catalog-product-wrap'),(887666,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_2_measure','%','','','.b-multi-page-checkout'),(887667,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_2_measure','%','3','','.b-multi-page-checkout'),(887668,'furniture','.success-page .w-cart-listing .qty','border_radius_2_measure','%','','','.success-page'),(887669,'furniture','.lowestPricedBox .w-banner .ybg','border_radius_2_measure','%','3','','.lowestPricedBox'),(887670,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_2_measure','px','','','.w-catalog-paging'),(887671,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_3_measure','px','4','','.b-switch'),(887672,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_3_measure','px','4','','.b-switch'),(887673,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.p-quick-order-index'),(887674,'furniture','.w-promotions .prom-multi-discount .promo-range','border_radius_3_measure','px','','','.w-promotions'),(887675,'furniture','.w-promotions .promo-salemaker .discount','border_radius_3_measure','px','','','.w-promotions'),(887676,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_3_measure','px','','','.w-promotions'),(887677,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_3_measure','px','','','.w-promotions'),(887678,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_3_measure','px','','','.b-messages'),(887679,'furniture','.b-fancybox .fancybox-close','border_radius_3_measure','%','','','.b-fancybox'),(887680,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_3_measure','px','','','.b-switch'),(887681,'furniture','.w-personal-gift-status-bar .progress-bar-content','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(887682,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_3_measure','px','3','','.b-switch'),(887683,'furniture','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_3_measure','px','','','.b-switch'),(887684,'furniture','.w-personal-gift-status-bar .progress-bar','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(887685,'furniture','.w-checkout-shipping-choice label:last-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(887686,'furniture','.w-checkout-shipping-choice label:first-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(887687,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_3_measure','%','3','','.b-form'),(887688,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_3_measure','px','3','','.b-switch'),(887689,'furniture','.b-fancybox .fancybox-title-float-wrap .child','border_radius_3_measure','px','','','.b-fancybox'),(887690,'furniture','.b-fancybox .fancybox-skin','border_radius_3_measure','px','','','.b-fancybox'),(887691,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_3_measure','%','3','','.b-switch'),(887692,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.p-quick-order-index'),(887693,'furniture','.b-fancybox .fancybox-nav span','border_radius_3_measure','%','','','.b-fancybox'),(887694,'furniture','.w-product-customers-activity .close','border_radius_3_measure','%','','','.w-product-customers-activity'),(887695,'furniture','.w-product-customers-activity .customers-activity','border_radius_3_measure','px','','','.w-product-customers-activity'),(887696,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(887697,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.b-data-table'),(887698,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.b-data-table'),(887699,'furniture','.b-products-listing .promos-info .promo-name','border_radius_3_measure','px','','','.b-products-listing'),(887700,'furniture','.b-upload-file .snapshot','border_radius_3_measure','%','','','.b-upload-file'),(887701,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(887702,'furniture','.b-switch .bootstrap-switch','border_radius_3_measure','px','','','.b-switch'),(887703,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_3_measure','px','','','.b-switch'),(887704,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_3_measure','px','','','.b-product-images'),(887705,'furniture','.b-trade-approval .steps-bar','border_radius_3_measure','px','','','.b-trade-approval'),(887706,'furniture','.w-delivery-day .left-count','border_radius_3_measure','px','','','.w-delivery-day'),(887707,'furniture','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_3_measure','px','','','.w-delivery-day'),(887711,'furniture','.menu-header .burger-icon','border_radius_3_measure','%','5140','','.menu-header'),(887712,'furniture','.w-quote .cart-box-link','border_radius_3_measure','%','3','','.w-quote'),(887713,'furniture','.w-product-sale-ends .left-count','border_radius_3_measure','px','','','.w-product-sale-ends'),(887714,'furniture','.w-product-sale-ends .left-count-days','border_radius_3_measure','px','','','.w-product-sale-ends'),(887715,'furniture','.w-product-sale-ends .left-count-hours','border_radius_3_measure','px','','','.w-product-sale-ends'),(887716,'furniture','.w-sample .cart-box-link','border_radius_3_measure','%','3','','.w-sample'),(887717,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_3_measure','%','','','.w-questionnaire-widgets-questionnaire'),(887718,'furniture','.w-sale-category .badge','border_radius_3_measure','%','','','.w-sale-category'),(887719,'furniture','.w-sale-category .left-count','border_radius_3_measure','px','','','.w-sale-category'),(887720,'furniture','.w-sale-category .left-count-days','border_radius_3_measure','px','','','.w-sale-category'),(887721,'furniture','.w-sale-category .left-count-hours','border_radius_3_measure','px','','','.w-sale-category'),(887722,'furniture','.b-products-listing .productGroup label a','border_radius_3_measure','px','','','.b-products-listing'),(887723,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_3_measure','px','','','.w-predefined-promotion'),(887724,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_3_measure','px','','','.w-predefined-promotion'),(887725,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_3_measure','px','','','.w-predefined-promotion'),(887726,'furniture','.w-predefined-promotion .promo-salemaker .discount','border_radius_3_measure','px','','','.w-predefined-promotion'),(887727,'furniture','.w-cart-listing .promos-info .promo-name','border_radius_3_measure','px','','','.w-cart-listing'),(887728,'furniture','.w-product-promotion-icons .promos-info .promo-name','border_radius_3_measure','px','','','.w-product-promotion-icons'),(887730,'furniture','.catalog-product-wrap .pn-image','border_radius_3_measure','%','3','','.catalog-product-wrap'),(887731,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_3_measure','%','','','.b-multi-page-checkout'),(887732,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_3_measure','%','3','','.b-multi-page-checkout'),(887733,'furniture','.success-page .w-cart-listing .qty','border_radius_3_measure','%','','','.success-page'),(887734,'furniture','.lowestPricedBox .w-banner .ybg','border_radius_3_measure','%','3','','.lowestPricedBox'),(887735,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_3_measure','px','','','.w-catalog-paging'),(887736,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_4_measure','px','4','','.b-switch'),(887737,'furniture','.b-upload-file .snapshot','border_radius_4_measure','%','','','.b-upload-file'),(887738,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.p-quick-order-index'),(887739,'furniture','.w-promotions .prom-multi-discount .promo-range','border_radius_4_measure','px','','','.w-promotions'),(887740,'furniture','.w-promotions .promo-salemaker .discount','border_radius_4_measure','px','','','.w-promotions'),(887741,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_4_measure','px','','','.w-promotions'),(887742,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.p-quick-order-index'),(887743,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_4_measure','px','','','.w-promotions'),(887744,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_4_measure','px','','','.b-messages'),(887745,'furniture','.b-fancybox .fancybox-close','border_radius_4_measure','%','','','.b-fancybox'),(887746,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_4_measure','px','','','.b-switch'),(887747,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_4_measure','px','3','','.b-switch'),(887748,'furniture','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_4_measure','px','','','.b-switch'),(887749,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(887750,'furniture','.w-checkout-shipping-choice label:last-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(887751,'furniture','.w-checkout-shipping-choice label:first-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(887752,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_4_measure','px','4','','.b-switch'),(887753,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_4_measure','px','3','','.b-switch'),(887754,'furniture','.b-fancybox .fancybox-title-float-wrap .child','border_radius_4_measure','px','','','.b-fancybox'),(887755,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_4_measure','%','3','','.b-form'),(887756,'furniture','.w-personal-gift-status-bar .progress-bar-content','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(887757,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_4_measure','%','3','','.b-switch'),(887758,'furniture','.w-personal-gift-status-bar .progress-bar','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(887759,'furniture','.b-fancybox .fancybox-nav span','border_radius_4_measure','%','','','.b-fancybox'),(887760,'furniture','.w-product-customers-activity .customers-activity','border_radius_4_measure','px','','','.w-product-customers-activity'),(887761,'furniture','.w-product-customers-activity .close','border_radius_4_measure','%','','','.w-product-customers-activity'),(887762,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(887763,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.b-data-table'),(887764,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.b-data-table'),(887765,'furniture','.b-products-listing .promos-info .promo-name','border_radius_4_measure','px','','','.b-products-listing'),(887766,'furniture','.b-fancybox .fancybox-skin','border_radius_4_measure','px','','','.b-fancybox'),(887767,'furniture','.b-switch .bootstrap-switch','border_radius_4_measure','px','','','.b-switch'),(887768,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_4_measure','px','','','.b-switch'),(887769,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_4_measure','px','','','.b-product-images'),(887770,'furniture','.b-trade-approval .steps-bar','border_radius_4_measure','px','','','.b-trade-approval'),(887771,'furniture','.w-delivery-day .left-count','border_radius_4_measure','px','','','.w-delivery-day'),(887772,'furniture','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_4_measure','px','','','.w-delivery-day'),(887776,'furniture','.menu-header .burger-icon','border_radius_4_measure','%','5140','','.menu-header'),(887777,'furniture','.w-quote .cart-box-link','border_radius_4_measure','%','3','','.w-quote'),(887778,'furniture','.w-product-sale-ends .left-count','border_radius_4_measure','px','','','.w-product-sale-ends'),(887779,'furniture','.w-product-sale-ends .left-count-days','border_radius_4_measure','px','','','.w-product-sale-ends'),(887780,'furniture','.w-product-sale-ends .left-count-hours','border_radius_4_measure','px','','','.w-product-sale-ends'),(887781,'furniture','.w-sample .cart-box-link','border_radius_4_measure','%','3','','.w-sample'),(887782,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_4_measure','%','','','.w-questionnaire-widgets-questionnaire'),(887783,'furniture','.w-sale-category .badge','border_radius_4_measure','%','','','.w-sale-category'),(887784,'furniture','.w-sale-category .left-count','border_radius_4_measure','px','','','.w-sale-category'),(887785,'furniture','.w-sale-category .left-count-days','border_radius_4_measure','px','','','.w-sale-category'),(887786,'furniture','.w-sale-category .left-count-hours','border_radius_4_measure','px','','','.w-sale-category'),(887787,'furniture','.b-products-listing .productGroup label a','border_radius_4_measure','px','','','.b-products-listing'),(887788,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_4_measure','px','','','.w-predefined-promotion'),(887789,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_4_measure','px','','','.w-predefined-promotion'),(887790,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_4_measure','px','','','.w-predefined-promotion'),(887791,'furniture','.w-predefined-promotion .promo-salemaker .discount','border_radius_4_measure','px','','','.w-predefined-promotion'),(887792,'furniture','.w-cart-listing .promos-info .promo-name','border_radius_4_measure','px','','','.w-cart-listing'),(887793,'furniture','.w-product-promotion-icons .promos-info .promo-name','border_radius_4_measure','px','','','.w-product-promotion-icons'),(887795,'furniture','.catalog-product-wrap .pn-image','border_radius_4_measure','%','3','','.catalog-product-wrap'),(887796,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_4_measure','%','','','.b-multi-page-checkout'),(887797,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_4_measure','%','3','','.b-multi-page-checkout'),(887798,'furniture','.success-page .w-cart-listing .qty','border_radius_4_measure','%','','','.success-page'),(887799,'furniture','.lowestPricedBox .w-banner .ybg','border_radius_4_measure','%','3','','.lowestPricedBox'),(887800,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_4_measure','px','','','.w-catalog-paging'),(887801,'furniture','.mainBanner .bottomBox .btn','border_right_width_measure','vw','','','.mainBanner'),(887802,'furniture','.mainBanner .bottomBox .btn','border_top_width_measure','vw','','','.mainBanner'),(887803,'furniture','.testimonials .review','bottom','-13','3','',''),(887804,'furniture','.w-checkout-shipping-choice input:checked + span:before','bottom','-7','','','.w-checkout-shipping-choice'),(887805,'furniture','.b-fancybox .fancybox-title-over-wrap','bottom','0','','','.b-fancybox'),(887806,'furniture','.b-info-popup .info-popup.top-left div','bottom','30','','','.b-info-popup'),(887807,'furniture','.b-info-popup .info-popup.top-left div','bottom','-11','3','','.b-info-popup'),(887808,'furniture','.b-upload-file .snapshot','bottom','5','','','.b-upload-file'),(887809,'furniture','.w-product-reviews .reviews-list .review','bottom','-13','3','','.w-product-reviews'),(887810,'furniture','.b-fancybox .fancybox-overlay-fixed','bottom','0','','','.b-fancybox'),(887811,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','bottom','0','','','.b-switch'),(887812,'furniture','.w-product-customers-activity .customers-activity','bottom','0','','','.w-product-customers-activity'),(887813,'furniture','.w-product-customers-activity .customers-activity.closed','bottom','-1000','','','.w-product-customers-activity'),(887814,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','bottom','0','','','.b-switch'),(887815,'furniture','.w-catalog-b2b-add-button ','bottom','0','','','.w-catalog-b2b-add-button'),(887816,'furniture','.b-fancybox .fancybox-title-float-wrap','bottom','0','','','.b-fancybox'),(887817,'furniture','.p-quick-order-index .all-scroll-div','bottom','0','','','.p-quick-order-index'),(887818,'furniture','.w-cart-listing .item .remove','bottom','0','5140','','.w-cart-listing'),(887819,'furniture','.b-product-images .mp-shadow, .b-product-images .media-popup','bottom','0','','','.b-product-images'),(887820,'furniture','.b-slick .slick-vertical button.slick-next','bottom','0','','','.b-slick'),(887821,'furniture','.b-slick .slick-vertical button.slick-prev','bottom','auto','','','.b-slick'),(887822,'furniture','.w-compare ','bottom','0','','','.w-compare'),(887823,'furniture','.w-compare .remove','bottom','10','','','.w-compare'),(887831,'furniture','.account-samples .orders-table .order-total','bottom','45','5140','','.account-samples'),(887832,'furniture','.account-samples .orders-table .status-name','bottom','7','5140','','.account-samples'),(887833,'furniture','.account-samples .orders-table .td-alignright','bottom','0','5140','','.account-samples'),(887834,'furniture','.w-banner .image-text-banner.bottom-center .text-banner','bottom','0','','','.w-banner'),(887835,'furniture','.w-banner .image-text-banner.bottom-left .text-banner','bottom','0','','','.w-banner'),(887836,'furniture','.w-banner .image-text-banner.bottom-right .text-banner','bottom','0','','','.w-banner'),(887837,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(887839,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(887840,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(887842,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(887843,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(887844,'furniture','.b-fancybox .fancybox-opened .fancybox-skin','box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(887847,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(887848,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','box-shadow','0 0 4px rgba(75,75,75,0.5)','3','','.b-switch'),(887851,'furniture','.w-catalog-compare .compare-fix-bar.fix-bar-fix','box-shadow','0 10px 10px -10px #cccccc','','','.w-catalog-compare'),(887852,'furniture','.b-products-listing .products-listing.list-productlisting .item:hover .item-wrapper','box-shadow','0 0 20px rgb(0 0 0 / 15%)','','','.b-products-listing'),(887853,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','box-shadow','0 10px 10px rgb(0 0 0 / 15%)','','','.b-products-listing'),(887855,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-step','box-shadow','0 2px 9px 0 rgba(0, 0, 0, 0.2)','2','','.b-multi-page-checkout'),(887856,'furniture','.b-fancybox .filter-listing-loader','box-sizing','content-box','','','.b-fancybox'),(887857,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','box-sizing','border-box','','','.b-switch'),(887858,'furniture','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','box-sizing','border-box','','','.b-select-suggest'),(887859,'furniture','.b-slick .slick-slider','box-sizing','border-box','','','.b-slick'),(887860,'furniture','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(887861,'furniture','.w-support-system-listing .support-head','box-sizing','border-box','','','.w-support-system-listing'),(887862,'furniture','.b-info-popup .info-popup div','box_shadow_blur','10','','','.b-info-popup'),(887863,'furniture','.w-product-customers-activity .customers-activity','box_shadow_blur','20','','','.w-product-customers-activity'),(887864,'furniture','.b-datepicker .datepicker-dropdown','box_shadow_blur','10','','','.b-datepicker'),(887865,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur','5','','','.w-image-maps'),(887866,'furniture','.w-compare ','box_shadow_blur','20','','','.w-compare'),(887867,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_blur','10','','','.w-product-properties-icons'),(887868,'furniture','.b-info-popup .info-popup div','box_shadow_blur_measure','px','','','.b-info-popup'),(887869,'furniture','.b-datepicker .datepicker-dropdown','box_shadow_blur_measure','px','','','.b-datepicker'),(887870,'furniture','.w-product-customers-activity .customers-activity','box_shadow_blur_measure','px','','','.w-product-customers-activity'),(887871,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur_measure','px','','','.w-image-maps'),(887872,'furniture','.w-compare ','box_shadow_blur_measure','px','','','.w-compare'),(887873,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_blur_measure','px','','','.w-product-properties-icons'),(887874,'furniture','.b-info-popup .info-popup div','box_shadow_color','#ccc','','','.b-info-popup'),(887875,'furniture','.b-datepicker .datepicker-dropdown','box_shadow_color','#ccc','','','.b-datepicker'),(887876,'furniture','.w-product-customers-activity .customers-activity','box_shadow_color','#eee','','','.w-product-customers-activity'),(887877,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_color','#ccc','','','.w-image-maps'),(887878,'furniture','.w-compare ','box_shadow_color','#cccc','','','.w-compare'),(887879,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_color','#bdbdbd','','','.w-product-properties-icons'),(887880,'furniture','.b-info-popup .info-popup div','box_shadow_left','0','','','.b-info-popup'),(887881,'furniture','.b-datepicker .datepicker-dropdown','box_shadow_left','0','','','.b-datepicker'),(887882,'furniture','.w-product-customers-activity .customers-activity','box_shadow_left','0','','','.w-product-customers-activity'),(887883,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left','0','','','.w-image-maps'),(887884,'furniture','.w-compare ','box_shadow_left','0','','','.w-compare'),(887885,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_left','1','','','.w-product-properties-icons'),(887886,'furniture','.b-info-popup .info-popup div','box_shadow_left_measure','','','','.b-info-popup'),(887887,'furniture','.b-datepicker .datepicker-dropdown','box_shadow_left_measure','','','','.b-datepicker'),(887888,'furniture','.w-product-customers-activity .customers-activity','box_shadow_left_measure','','','','.w-product-customers-activity'),(887889,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left_measure','','','','.w-image-maps'),(887890,'furniture','.w-compare ','box_shadow_left_measure','','','','.w-compare'),(887891,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_left_measure','px','','','.w-product-properties-icons'),(887892,'furniture','.b-info-popup .info-popup div','box_shadow_top','0','','','.b-info-popup'),(887893,'furniture','.w-product-customers-activity .customers-activity','box_shadow_top','0','','','.w-product-customers-activity'),(887894,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top','0','','','.w-image-maps'),(887895,'furniture','.b-datepicker .datepicker-dropdown','box_shadow_top','0','','','.b-datepicker'),(887896,'furniture','.w-compare ','box_shadow_top','0','','','.w-compare'),(887897,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_top','1','','','.w-product-properties-icons'),(887898,'furniture','.b-info-popup .info-popup div','box_shadow_top_measure','','','','.b-info-popup'),(887899,'furniture','.w-product-customers-activity .customers-activity','box_shadow_top_measure','','','','.w-product-customers-activity'),(887900,'furniture','.b-datepicker .datepicker-dropdown','box_shadow_top_measure','','','','.b-datepicker'),(887901,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top_measure','','','','.w-image-maps'),(887902,'furniture','.w-compare ','box_shadow_top_measure','','','','.w-compare'),(887903,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_top_measure','px','','','.w-product-properties-icons'),(887904,'furniture','.b-form .addresses .address-item:nth-child(2n + 1)','clear','left','','','.b-form'),(887905,'furniture','.w-checkout-billing-address .btn-cancel','clear','both','','','.w-checkout-billing-address'),(887906,'furniture','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(887908,'furniture','.b-form .col-full','clear','both','','','.b-form'),(887909,'furniture','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(887912,'furniture','.w-promotions .prom-multi-discount','clear','both','4','','.w-promotions'),(887913,'furniture','.w-product-available-in-warehouses .content','clear','both','4','','.w-product-available-in-warehouses'),(887914,'furniture','.b-products-listing .products-listing .mix-attributes','clear','bpth','4','','.b-products-listing'),(887915,'furniture','.w-cart-compare .product .name','clear','right','','','.w-cart-compare'),(887916,'furniture','.b-messages .dataTables_wrapper > .top','clear','both','4','','.b-messages'),(887917,'furniture','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(887918,'furniture','.b-messages .dataTables_wrapper > .bottom','clear','both','4','','.b-messages'),(887919,'furniture','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(887920,'furniture','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(887921,'furniture','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(887922,'furniture','.w-login-block .buttons','clear','none','','','.w-login-block'),(887923,'furniture','.w-login-block .cols','clear','both','4','','.w-login-block'),(887924,'furniture','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(887925,'furniture','.w-login-block .guest','clear','right','','','.w-login-block'),(887926,'furniture','.w-menu-horizontal li','clear','none','','','.w-menu-horizontal'),(887927,'furniture','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(887928,'furniture','.b-form .col-left','clear','left','','','.b-form'),(887929,'furniture','.buttons','clear','both','','',''),(887930,'furniture','.buttons','clear','both','4','',''),(887931,'furniture','.w-cart-give-away .ga_column:nth-child(2n + 1)','clear','both','','','.w-cart-give-away'),(887932,'furniture','.w-top-categories .categories','clear','both','4','','.w-top-categories'),(887933,'furniture','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(887934,'furniture','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(887935,'furniture','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(887936,'furniture','.w-checkout-billing-address .addresses','clear','both','4','','.w-checkout-billing-address'),(887937,'furniture','.w-cart-listing .right-area','clear','both','5140','','.w-cart-listing'),(887938,'furniture','.w-checkout-shipping-address .addresses','clear','both','4','','.w-checkout-shipping-address'),(887939,'furniture','.w-checkout-shipping-address .btn-cancel','clear','both','','','.w-checkout-shipping-address'),(887940,'furniture','.b-form .addresses','clear','both','4','','.b-form'),(887941,'furniture','.w-top-categories .item:nth-child(4n + 1)','clear','both','','','.w-top-categories'),(887942,'furniture','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(887943,'furniture','.b-form .newsletter-row','clear','both','4','','.b-form'),(887944,'furniture','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(887945,'furniture','.w-login-block .cols','clear','both','4','','.w-login-block'),(887946,'furniture','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(887947,'furniture','.w-login-block .guest','clear','right','','','.w-login-block'),(887948,'furniture','.w-login-block .guest','clear','right','','','.w-login-block'),(887949,'furniture','.w-list-b2b .attributes','clear','both','4','','.w-list-b2b'),(887951,'furniture','.w-cart-shipping-estimator .item .row: after','clear','both','','','.w-cart-shipping-estimator'),(887952,'furniture','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(887953,'furniture','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(887954,'furniture','.w-login-block .guest','clear','right','','','.w-login-block'),(887955,'furniture','.w-login-block .buttons','clear','none','','','.w-login-block'),(887956,'furniture','.w-login-block .cols','clear','both','4','','.w-login-block'),(887957,'furniture','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(887958,'furniture','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(887959,'furniture','.b-form .col-right','clear','right','','','.b-form'),(887960,'furniture','.w-cart-compare .product','clear','both','4','','.w-cart-compare'),(887961,'furniture','.w-login-block .buttons','clear','none','','','.w-login-block'),(887962,'furniture','.b-bottom .cart-options .option-item:nth-child(2n + 1)','clear','both','','','.b-bottom'),(887963,'furniture','.b-bottom .cart-options .heading-4','clear','both','','','.b-bottom'),(887964,'furniture','.b-bottom .cart-options .cart-item:nth-child(2n + 1)','clear','both','','','.b-bottom'),(887965,'furniture','.b-bottom .cart-options .options','clear','both','','','.b-bottom'),(887966,'furniture','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(887967,'furniture','.w-login-block .guest','clear','right','','','.w-login-block'),(887968,'furniture','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(887969,'furniture','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-billing-address'),(887970,'furniture','.b-form .center-buttons','clear','both','','','.b-form'),(887971,'furniture','.w-list-b2b .mix-attributes','clear','both','','','.w-list-b2b'),(887972,'furniture','.w-cart-shipping-estimator .address-item .lastname','clear','both','4','','.w-cart-shipping-estimator'),(887973,'furniture','.w-login-block .buttons','clear','none','','','.w-login-block'),(887974,'furniture','.w-cart-compare .product .image','clear','both','','','.w-cart-compare'),(887975,'furniture','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(887976,'furniture','.w-login-block .cols','clear','both','4','','.w-login-block'),(887977,'furniture','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(887978,'furniture','.w-product-reviews .reviews-list','clear','right','','','.w-product-reviews'),(887979,'furniture','.w-cart-compare .buttons','clear','none','','','.w-cart-compare'),(887980,'furniture','.w-menu-big li','clear','none','','','.w-menu-big'),(887981,'furniture','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(887982,'furniture','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(887983,'furniture','.w-login-block .cols','clear','both','4','','.w-login-block'),(887984,'furniture','.w-login-block .guest','clear','right','','','.w-login-block'),(887985,'furniture','.w-login-block .buttons','clear','none','','','.w-login-block'),(887986,'furniture','.b-products-listing .BlockBox','clear','both','4','','.b-products-listing'),(887987,'furniture','.b-products-listing .products-listing','clear','both','4','','.b-products-listing'),(887989,'furniture','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(887990,'furniture','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(887991,'furniture','.w-categories .categories','clear','both','4','','.w-categories'),(887992,'furniture','.b-form .password-forgotten-link','clear','both','','','.b-form'),(887993,'furniture','.b-form .requiredM','clear','both','','','.b-form'),(887994,'furniture','.w-login-block .cols','clear','both','4','','.w-login-block'),(887995,'furniture','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(887996,'furniture','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-shipping-address'),(887997,'furniture','.w-categories .item:nth-child(4n + 1)','clear','both','','','.w-categories'),(887998,'furniture','.w-cart-give-away .ga_name','clear','both','4','','.w-cart-give-away'),(887999,'furniture','.b-form .login_btns','clear','both','','','.b-form'),(888000,'furniture','.w-login-block .buttons','clear','none','','','.w-login-block'),(888001,'furniture','.w-filters .fsl_handle','clear','both','4','','.w-filters'),(888002,'furniture','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(888003,'furniture','.w-cart-shipping-estimator .shipping-estimator','clear','both','4','','.w-cart-shipping-estimator'),(888004,'furniture','.b-form .col-right + .col-left','clear','both','','','.b-form'),(888005,'furniture','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(888006,'furniture','.w-cart-shipping-estimator .item .row','clear','both','','','.w-cart-shipping-estimator'),(888007,'furniture','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(888008,'furniture','.b-trade-approval .col-right','clear','right','','','.b-trade-approval'),(888009,'furniture','.b-trade-approval .col-left','clear','left','','','.b-trade-approval'),(888010,'furniture','.b-trade-approval .center-buttons','clear','both','','','.b-trade-approval'),(888011,'furniture','.b-trade-approval .columns','clear','both','4','','.b-trade-approval'),(888012,'furniture','.w-catalog-compare .BlockBox','clear','both','','','.w-catalog-compare'),(888013,'furniture','.w-social-links ','clear','both','','','.w-social-links'),(888014,'furniture','.b-slick .slick-slide','clear','none','','','.b-slick'),(888015,'furniture','.b-slick .slick-track','clear','both','4','','.b-slick'),(888016,'furniture','.w-quote a.item','clear','both','4','','.w-quote'),(888017,'furniture','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(888018,'furniture','.w-product-bonus-points > div','clear','both','4','','.w-product-bonus-points'),(888019,'furniture','.w-compare .compare-button','clear','both','','','.w-compare'),(888020,'furniture','.w-sample a.item','clear','both','4','','.w-sample'),(888021,'furniture','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(888022,'furniture','.b-products-listing .products-listing .radio-attributes','clear','both','4','','.b-products-listing'),(888023,'furniture','.b-pagination .pagination','clear','both','4','','.b-pagination'),(888024,'furniture','.w-product-multi-inventory .select-box:nth-child(2n+1)','clear','both','','','.w-product-multi-inventory'),(888025,'furniture','.w-product-multi-inventory .select-box:last-of-type:after','clear','both','','','.w-product-multi-inventory'),(888026,'furniture','.w-product-multi-inventory .radio-attributes','clear','both','','','.w-product-multi-inventory'),(888027,'furniture','.w-product-multi-inventory #product-attributes','clear','both','4','','.w-product-multi-inventory'),(888028,'furniture','.w-product-multi-inventory .radio-attributes','clear','both','4','','.w-product-multi-inventory'),(888029,'furniture','.w-product-quantity-discounts .quantity-discounts','clear','both','4','','.w-product-quantity-discounts'),(888030,'furniture','.b-products-listing .products-listing .radio-attributes','clear','both','','','.b-products-listing'),(888031,'furniture','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(888032,'furniture','.w-product-attributes #product-attributes','clear','both','4','','.w-product-attributes'),(888033,'furniture','.w-product-attributes .radio-attributes','clear','both','','','.w-product-attributes'),(888034,'furniture','.w-product-attributes .radio-attributes','clear','both','4','','.w-product-attributes'),(888035,'furniture','.w-product-attributes .select-box:last-of-type:after','clear','both','','','.w-product-attributes'),(888036,'furniture','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(888037,'furniture','.w-product-groups .prop-group-swatch','clear','both','4','','.w-product-groups'),(888038,'furniture','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(888039,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list'),(888040,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list-block'),(888041,'furniture','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(888042,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li:nth-child(2n+1)','clear','both','5131','','.w-catalog-pages-category-pages-last-list'),(888043,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li:nth-child(2n+1)','clear','both','5131','','.w-catalog-pages-category-pages-last-list-block'),(888044,'furniture','.w-delivery-location-featured-list .deliveryList ul','clear','both','4','','.w-delivery-location-featured-list'),(888045,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list-by-catalog'),(888046,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(888047,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li:nth-child(2n+1)','clear','both','5131','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(888048,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li:nth-child(2n+1)','clear','both','5131','','.w-catalog-pages-category-pages-last-list-by-catalog'),(888049,'furniture','.w-delivery-location-list-by-page .page-list','clear','both','4','','.w-delivery-location-list-by-page'),(888050,'furniture','.w-delivery-location-top-location-list .deliveryList','clear','both','4','','.w-delivery-location-top-location-list'),(888051,'furniture','.w-delivery-location-list-by-page .item:nth-child(3n+1)','clear','left','','','.w-delivery-location-list-by-page'),(888052,'furniture','.w-delivery-location-list-by-page .item:nth-child(3n+1)','clear','none','5140','','.w-delivery-location-list-by-page'),(888053,'furniture','.w-delivery-location-list-by-page .item:nth-child(2n+1)','clear','left','5140','','.w-delivery-location-list-by-page'),(888054,'furniture','.w-delivery-location-cross-pages .item:nth-child(3n+1)','clear','left','','','.w-delivery-location-cross-pages'),(888055,'furniture','.w-delivery-location-cross-pages .page-list','clear','both','4','','.w-delivery-location-cross-pages'),(888056,'furniture','.w-delivery-location-cross-pages .item:nth-child(2n+1)','clear','left','5140','','.w-delivery-location-cross-pages'),(888057,'furniture','.w-delivery-location-cross-pages .item:nth-child(3n+1)','clear','none','5140','','.w-delivery-location-cross-pages'),(888058,'furniture','.w-catalog-delivery-locations .item:nth-child(2n+1)','clear','left','','','.w-catalog-delivery-locations'),(888059,'furniture','.delivery-options-popup','clear','both','4','',''),(888060,'furniture','.w-gift-wrap-message-checkout .gift_message-comment-box','clear','both','','','.w-gift-wrap-message-checkout'),(888061,'furniture','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(888062,'furniture','.w-product-configurator .pc_attr','clear','both','5131','','.w-product-configurator'),(888063,'furniture','.w-product-configurator .pc_qty','clear','both','5131','','.w-product-configurator'),(888064,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-list'),(888065,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li:nth-child(2n+1)','clear','both','5131','','.w-catalog-pages-category-pages-list'),(888066,'furniture','.w-predefined-promotion .prom-multi-discount','clear','both','4','','.w-predefined-promotion'),(888067,'furniture','.mainBanner .buttonBox','clear','both','4','','.mainBanner'),(888069,'furniture','.account-address-book .address_book_row','clear','both','','','.account-address-book'),(888070,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-content','clear','both','4','','.b-multi-page-checkout'),(888071,'furniture','.shopByCollectionBox .content','clear','both','4','','.shopByCollectionBox'),(888072,'furniture','.w-menu-horizontal li','clear_important','important','','','.w-menu-horizontal'),(888073,'furniture','.w-menu-big li','clear_important','important','','','.w-menu-big'),(888074,'furniture','.b-slick .slick-slide','clear_important','important','','','.b-slick'),(888075,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip','rect(0 0 0 0)','','','.b-select-suggest'),(888076,'furniture','.w-product-bonus-points .bonus-points-cost','clip-path','polygon( 0% 0%, calc(100% - 1.1em) 0%, 100% 50%, calc(100% - 1.1em) 100%, 0% 100%)','','','.w-product-bonus-points'),(888077,'furniture','.b-products-listing .products-listing .bonus-points-cost','clip-path','polygon( 0% 0%, calc(100% - 1.1em) 0%, 100% 50%, calc(100% - 1.1em) 100%, 0% 100%)','','','.b-products-listing'),(888078,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip_important','important','','','.b-select-suggest'),(888079,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-on i','color','$switch-off-color-2','','','.b-switch'),(888080,'furniture','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(888081,'furniture','.b-rating .glyphicon','color','$fade-color-1','','','.b-rating'),(888082,'furniture','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(888083,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(888084,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','$content-color-1','','','.p-quick-order-index'),(888085,'furniture','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .specials_category .promo-conditions','color','$warning-color','3','','.w-promotions'),(888086,'furniture','.w-promotions .promo-salemaker .content a','color','$content-color-1','','','.w-promotions'),(888087,'furniture','.w-promotions .promo-cart-discount .item a','color','$content-color-1','','','.w-promotions'),(888088,'furniture','.w-promotions .prom-multi-discount .promo-range','color','$attention-color','','','.w-promotions'),(888089,'furniture','.w-personal-gift-status-bar .end-label','color','$content-color-1','','','.w-personal-gift-status-bar'),(888090,'furniture','.p-sample-checkout-success .page-success .text-3','color','$attention-color','','','.p-sample-checkout-success'),(888091,'furniture','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(888092,'furniture','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(888093,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(888094,'furniture','.testimonials .reviews-list .date','color','$fade-color-1','','',''),(888095,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-1','3','','.w-contact-contacts'),(888096,'furniture','.w-chat .w-chat-box a','color','$highlight-box-color-2','3','','.w-chat'),(888097,'furniture','.w-promotions .prom-multi-discount .promo-range, .w-promotions .prom-multi-discount > .heading','color','$attention-color','3','','.w-promotions'),(888098,'furniture','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','color','$content-color-1','','','.w-promotions'),(888099,'furniture','.w-promotions .cart_discount .promo-date','color','$warning-color','3','','.w-promotions'),(888100,'furniture','.w-promotions .multidiscount .promo-date, .w-promotions .multidiscount .heading-3','color','$attention-color','','','.w-promotions'),(888101,'furniture','.w-promotions .cart_discount .heading-3','color','$warning-color','','','.w-promotions'),(888102,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','$content-color-1','','','.p-quick-order-index'),(888103,'furniture','.w-promotions .specials_category .promo-salemaker .content a, .w-promotions .specials_category .promo-date','color','$warning-color','3','','.w-promotions'),(888104,'furniture','.w-promotions .specials_category .heading-3','color','$warning-color','','','.w-promotions'),(888105,'furniture','.w-promotions .promo-salemaker .discount','color','$warning-color','','','.w-promotions'),(888106,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','color','$attention-color','','','.w-promotions'),(888107,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','color','$attention-color','','','.w-promotions'),(888108,'furniture','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','color','$warning-color','3','','.w-promotions'),(888109,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','color','$content-color-1','','','.b-warehouses-popup'),(888110,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','color','$attention-color','','','.b-warehouses-popup'),(888111,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','color','$message-color','','','.b-warehouses-popup'),(888112,'furniture','.b-warehouses-popup a.warehouses-popup-link','color','$content-color-1','','','.b-warehouses-popup'),(888113,'furniture','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(888114,'furniture','.p-payer-order-confirmation .ship-ico','color','$content-color-1','3','','.p-payer-order-confirmation'),(888115,'furniture','.b-bottom .closeable-heading','color','$content-color-1','3','','.b-bottom'),(888116,'furniture','.b-messages .messMenuButton span','color','$content-color-1','','','.b-messages'),(888117,'furniture','.b-messages .messages-menu li a','color','$content-color-1','','','.b-messages'),(888118,'furniture','.b-messages .content_management_attach','color','$content-color-1','','','.b-messages'),(888119,'furniture','.b-messages .content_management_attach button','color','$content-color-1','','','.b-messages'),(888120,'furniture','.b-messages .select2-search-choice-close','color','$fade-color-1','3','','.b-messages'),(888121,'furniture','.w-text .customer-service b','color','$content-color-1','','','.w-text'),(888122,'furniture','.w-socials .post_item > div.tw_post_item','color','$content-color-1','3','','.w-socials'),(888123,'furniture','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(888124,'furniture','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(888125,'furniture','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(888126,'furniture','.w-text .customer-service','color','$content-color-1','3','','.w-text'),(888127,'furniture','.p-payer-order-confirmation .pay-ico','color','$content-color-1','3','','.p-payer-order-confirmation'),(888128,'furniture','.p-payer-order-confirmation .order-ico','color','$content-color-1','3','','.p-payer-order-confirmation'),(888129,'furniture','.p-payer-order-confirmation .discount-ico','color','$content-color-1','3','','.p-payer-order-confirmation'),(888130,'furniture','.p-payer-order-confirmation .comment-ico','color','$content-color-1','3','','.p-payer-order-confirmation'),(888131,'furniture','.p-payer-order-pay .ship-ico','color','$content-color-1','3','','.p-payer-order-pay'),(888132,'furniture','.p-payer-order-pay .pay-ico','color','$content-color-1','3','','.p-payer-order-pay'),(888133,'furniture','.p-payer-order-pay .order-ico','color','$content-color-1','3','','.p-payer-order-pay'),(888134,'furniture','.p-payer-order-pay .discount-ico','color','$content-color-1','3','','.p-payer-order-pay'),(888135,'furniture','.p-payer-order-pay .comment-ico','color','$content-color-1','3','','.p-payer-order-pay'),(888136,'furniture','.b-form .inputRequirement','color','$attention-color','','','.b-form'),(888137,'furniture','.b-fancybox .fancybox-close','color','$fancybox-color-1','','','.b-fancybox'),(888138,'furniture','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(888139,'furniture','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(888140,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','$content-color-1','1','','.p-quick-order-index');
INSERT INTO `themes_styles` VALUES (888141,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-remove','color','$attention-color','','','.w-upload-customer-id-upload-customer-id-form'),(888142,'furniture','.w-menu-horizontal a','color','inherit','','','.w-menu-horizontal'),(888143,'furniture','.order-summary .price-row.ot_bonus_points .title','color','$message-color','3','','.order-summary'),(888144,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-1','3','','.w-contact-contacts'),(888145,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','color','$checkbox-color-1','3','','.b-form'),(888146,'furniture','.w-coupons-and-vauchers-checkout #credit_modules_message','color','$message-color','','','.w-coupons-and-vauchers-checkout'),(888147,'furniture','.b-fancybox .fancybox-title-outside-wrap','color','$fancybox-color-1','','','.b-fancybox'),(888148,'furniture','.b-fancybox .fancybox-title-over-wrap','color','$fancybox-color-1','','','.b-fancybox'),(888149,'furniture','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(888150,'furniture','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(888151,'furniture','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(888152,'furniture','.w-social-links .twitter','color','$content-color-1','3','','.w-social-links'),(888153,'furniture','.w-social-links .stumbleupon','color','$attention-color','3','','.w-social-links'),(888154,'furniture','.w-social-links .facebook','color','$content-color-1','3','','.w-social-links'),(888155,'furniture','.w-social-links .pinterest','color','$attention-color','3','','.w-social-links'),(888156,'furniture','.btn-1','color','$btn-color-2','','',''),(888157,'furniture','.price .specials','color','$price-special-1','','',''),(888159,'furniture','.w-socials .post_item > div.tw_post_item','color','$content-color-1','3','','.w-socials'),(888160,'furniture','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(888161,'furniture','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(888162,'furniture','.w-filters .input-checkbox:checked + .checkbox-span:before','color','$content-color-1','','','.w-filters'),(888163,'furniture','.w-cart-compare .product .name a','color','$content-color-1','','','.w-cart-compare'),(888164,'furniture','.w-personal-gift-status-bar .inform','color','$content-color-1','4','','.w-personal-gift-status-bar'),(888165,'furniture','.w-reviews .date','color','$fade-color-1','','','.w-reviews'),(888166,'furniture','.w-checkout-shipping-choice span','color','$content-color-1','','','.w-checkout-shipping-choice'),(888167,'furniture','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(888168,'furniture','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(888169,'furniture','.w-socials .post_item > div.tw_post_item','color','$content-color-1','3','','.w-socials'),(888170,'furniture','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(888172,'furniture','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(888173,'furniture','.b-rating .glyphicon.coloron ~ .glyphicon-star','color','$content-color-1','','','.b-rating'),(888174,'furniture','.w-image-maps .default-links .item .description','color','$content-color-1','','','.w-image-maps'),(888175,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-1','3','','.w-contact-contacts'),(888176,'furniture','.w-personal-gift-status-bar .end-date','color','$content-color-1','3','','.w-personal-gift-status-bar'),(888177,'furniture','.price .special','color','$price-special-1','','',''),(888178,'furniture','.w-reviews-content .date','color','$fade-color-1','','','.w-reviews-content'),(888179,'furniture','.b-delete-account .delete-box .delete-message','color','$attention-color','','','.b-delete-account'),(888180,'furniture','.b-form .radio-button input[type=\"radio\"]:checked + span:before','color','$checkbox-color-1','','','.b-form'),(888181,'furniture','.w-multi-cart-actions .cart-actions .dropdown-toggle','color','$fade-color-1','3','','.w-multi-cart-actions'),(888182,'furniture','.w-text .customer-service b','color','$content-color-1','','','.w-text'),(888183,'furniture','.w-text .customer-service','color','$content-color-1','3','','.w-text'),(888184,'furniture','.w-tabs .tab-a','color','$content-color-1','2','','.w-tabs'),(888185,'furniture','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(888186,'furniture','.w-socials .post_item > div.tw_post_item','color','$content-color-1','3','','.w-socials'),(888187,'furniture','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(888188,'furniture','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(888189,'furniture','.btn-edit','color','$content-color-1','3','',''),(888190,'furniture','.w-tabs a.tab-a','color','$content-color-1','','','.w-tabs'),(888191,'furniture','.w-tabs .tab-li:hover a.tab-a','color','$content-color-1','','','.w-tabs'),(888192,'furniture','.w-cart-credit-amount #credit_modules_message.error','color','$attention-color','','','.w-cart-credit-amount'),(888193,'furniture','.w-cart-credit-amount #credit_modules_message','color','$message-color','','','.w-cart-credit-amount'),(888194,'furniture','.w-cart-listing .attention_mark','color','$attention-color','','','.w-cart-listing'),(888195,'furniture','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(888196,'furniture','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(888197,'furniture','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(888198,'furniture','.w-personal-gift-status-bar .start-label','color','$content-color-1','','','.w-personal-gift-status-bar'),(888199,'furniture','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(888200,'furniture','a.btn-2','color','$btn-color-1','','',''),(888201,'furniture','.btn-2','color','$btn-color-4','','',''),(888202,'furniture','.heading-4 .edit, h4 .edit','color','$link-color-1','','',''),(888203,'furniture','.w-cart-compare .delete-cart','color','$content-color-1','3','','.w-cart-compare'),(888204,'furniture','.w-cart-compare .cart-name a','color','$content-color-1','','','.w-cart-compare'),(888205,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','color','$switch-on-color-1','','','.b-switch'),(888206,'furniture','.p-sample-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-sample-checkout-success'),(888207,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-1','3','','.w-contact-contacts'),(888208,'furniture','.w-top-categories .categories h2','color','inherit','','','.w-top-categories'),(888209,'furniture','.out-stock','color','$attention-color','','',''),(888210,'furniture','.transit','color','$highlight-color-2','','',''),(888211,'furniture','.in-stock','color','$message-color','','',''),(888212,'furniture','.heading-3 .edit, h3 .edit','color','$link-color-1','','',''),(888213,'furniture','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(888214,'furniture','.b-bottom .header-error','color','$attention-color','','','.b-bottom'),(888215,'furniture','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(888216,'furniture','.savings-ico .heading-2','color','$message-color','3','','.savings-ico'),(888217,'furniture','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(888218,'furniture','.w-text .customer-service b','color','$content-color-1','','','.w-text'),(888219,'furniture','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(888220,'furniture','.testimonials .date','color','$fade-color-1','','',''),(888221,'furniture','.js-stock','color','$message-color','','',''),(888222,'furniture','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(888223,'furniture','.b-fancybox .fancybox-title-float-wrap .child','color','$fancybox-color-1','','','.b-fancybox'),(888224,'furniture','.w-reviews-content .product-name a','color','$content-color-1','','','.w-reviews-content'),(888225,'furniture','.b-fancybox .fancybox-skin','color','$fancybox-color-1','','','.b-fancybox'),(888226,'furniture','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(888227,'furniture','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(888228,'furniture','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(888229,'furniture','.w-socials .post_item > div.tw_post_item','color','$content-color-1','3','','.w-socials'),(888230,'furniture','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(888231,'furniture','.main-content a','color','inherit','','',''),(888232,'furniture','.btn','color','$btn-color-1','','',''),(888235,'furniture','.message.success','color','$message-color','','',''),(888236,'furniture','.b-form .required-message','color','$attention-color','','','.b-form'),(888237,'furniture','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(888238,'furniture','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(888239,'furniture','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(888240,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(888241,'furniture','.w-reviews .heading-3','color','$content-color-1','3','','.w-reviews'),(888242,'furniture','.w-reviews .product-name a','color','$content-color-1','','','.w-reviews'),(888243,'furniture','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','color','$content-color-1','','','.b-select-suggest'),(888244,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span:before','color','$checkbox-color-1','','','.b-form'),(888245,'furniture','.w-social-links .linkedin','color','$content-color-1','3','','.w-social-links'),(888246,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','color','$switch-off-color-2','','','.b-switch'),(888247,'furniture','a','color','inherit','','',''),(888248,'furniture','.w-text .customer-service b','color','$content-color-1','','','.w-text'),(888249,'furniture','a.btn','color','$btn-color-1','','',''),(888251,'furniture','.b-form .checkbox-style:checked + .checkbox-span:before','color','$checkbox-color-1','','','.b-form'),(888252,'furniture','.btn-del','color','$attention-color','4','',''),(888253,'furniture','.b-form .required','color','$attention-color','','','.b-form'),(888254,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(888255,'furniture','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(888257,'furniture','.b-rating .glyphicon-star.coloron','color','$content-color-1','3','','.b-rating'),(888258,'furniture','.w-social-links .instagram','color','$attention-color','3','','.w-social-links'),(888259,'furniture','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(888260,'furniture','.b-pass-strength span.good-pass','color','$message-color','','','.b-pass-strength'),(888261,'furniture','.b-pass-strength span.strong-pass, .b-pass-strength span.pass-match','color','$message-color','','','.b-pass-strength'),(888262,'furniture','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(888263,'furniture','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(888264,'furniture','.w-text .customer-service','color','$content-color-1','3','','.w-text'),(888265,'furniture','.w-text .customer-service b','color','$content-color-1','','','.w-text'),(888266,'furniture','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(888267,'furniture','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(888268,'furniture','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(888270,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(888271,'furniture','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(888272,'furniture','.b-bottom .pop-up-close','color','$content-color-1','1','','.b-bottom'),(888273,'furniture','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','color','$fade-color-1','3','','.order-summary'),(888274,'furniture','.order-summary .price-row.ot_gv .title','color','$message-color','3','','.order-summary'),(888275,'furniture','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','color','$message-color','','','.b-products-listing'),(888276,'furniture','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','color','$message-color','','','.b-products-listing'),(888277,'furniture','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(888278,'furniture','.w-text .customer-service','color','$content-color-1','3','','.w-text'),(888279,'furniture','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(888280,'furniture','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(888281,'furniture','.w-social-links .google-plus','color','$attention-color','3','','.w-social-links'),(888282,'furniture','.b-form .privacy-row a','color','$content-color-1','','','.b-form'),(888283,'furniture','.w-text .customer-service b','color','$content-color-1','','','.w-text'),(888284,'furniture','.w-text .customer-service','color','$content-color-1','3','','.w-text'),(888285,'furniture','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(888286,'furniture','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(888287,'furniture','.w-image-maps .categories-items .item .description','color','$content-color-1','','','.w-image-maps'),(888288,'furniture','.w-checkout-shipping-choice input:checked + span','color','$highlight-box-color-2','','','.w-checkout-shipping-choice'),(888289,'furniture','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(888290,'furniture','.w-tabs .accordion-heading','color','$content-color-1','2','','.w-tabs'),(888291,'furniture','.w-categories h2.name','color','$content-color-1','','','.w-categories'),(888292,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on i, .b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-off i','color','$switch-on-color-1','','','.b-switch'),(888293,'furniture','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(888294,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','color','$content-color-1','','','.b-select-suggest'),(888295,'furniture','.b-select-suggest .select2-default','color','$fade-color-1','','','.b-select-suggest'),(888296,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','color','$content-color-1','','','.b-select-suggest'),(888297,'furniture','.b-select-suggest .select2-results .select2-highlighted ul','color','$content-color-1','','','.b-select-suggest'),(888298,'furniture','.b-select-suggest .select2-results .select2-highlighted','color','$content-color-1','','','.b-select-suggest'),(888299,'furniture','.b-select-suggest .select2-drop','color','$content-color-1','','','.b-select-suggest'),(888301,'furniture','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(888302,'furniture','.w-menu-big a','color','inherit','','','.w-menu-big'),(888304,'furniture','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(888306,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','$content-color-1','','','.b-data-table'),(888307,'furniture','.b-products-listing .products-listing .bonus-points span:first-child','color','$content-color-1','','','.b-products-listing'),(888308,'furniture','.b-products-listing .products-listing .bonus-points-price','color','$content-color-1','3','','.b-products-listing'),(888309,'furniture','.b-products-listing .products-listing .bonus-points-cost','color','$content-color-1','3','','.b-products-listing'),(888310,'furniture','.w-catalog-b2b-add-button ','color','$highlight-box-color-2','','','.w-catalog-b2b-add-button'),(888314,'furniture','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(888315,'furniture','.b-select-suggest .select2-container .select2-choice','color','$content-color-1','','','.b-select-suggest'),(888316,'furniture','.b-upload-file .snapshot','color','$fade-color-1','','','.b-upload-file'),(888317,'furniture','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(888318,'furniture','.w-top-categories h2.name','color','$content-color-1','','','.w-top-categories'),(888319,'furniture','.w-text .customer-service','color','$content-color-1','3','','.w-text'),(888320,'furniture','.w-coupons-and-vauchers-checkout #credit_modules_message.error','color','$attention-color','','','.w-coupons-and-vauchers-checkout'),(888321,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-1','3','','.w-contact-contacts'),(888322,'furniture','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','color','$highlight-box-color-2','','','.w-taxable'),(888323,'furniture','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','color','$highlight-box-color-2','','','.w-taxable'),(888324,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','color','$content-color-1','','','.w-communication-new-topic'),(888325,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','color','$content-color-1','','','.w-communication-new-topic'),(888326,'furniture','.b-form .middle-form label','color','$content-color-1','','','.b-form'),(888327,'furniture','.btn-3','color','$btn-color-4','','',''),(888328,'furniture','.order-summary .price-row.ot_coupon .title','color','$message-color','3','','.order-summary'),(888329,'furniture','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(888330,'furniture','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(888331,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(888332,'furniture','.w-cart-compare .product-actions .dropdown-toggle','color','$fade-color-1','','','.w-cart-compare'),(888333,'furniture','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(888334,'furniture','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(888335,'furniture','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(888336,'furniture','.w-catalog-listing-look .grid','color','$fade-color-1','','','.w-catalog-listing-look'),(888337,'furniture','.w-catalog-listing-look .b2b','color','$highlight-box-color-2','2','','.w-catalog-listing-look'),(888338,'furniture','.w-catalog-listing-look .b2b','color','$content-color-1','','','.w-catalog-listing-look'),(888339,'furniture','.w-catalog-listing-look .list','color','$content-color-1','','','.w-catalog-listing-look'),(888340,'furniture','.w-catalog-listing-look .grid','color','$highlight-box-color-2','2','','.w-catalog-listing-look'),(888341,'furniture','.w-catalog-listing-look .list','color','$highlight-box-color-2','2','','.w-catalog-listing-look'),(888342,'furniture','.checkbox input:checked + span:before','color','$checkbox-color-1','','',''),(888343,'furniture','.p-quick-order-index .all-scroll-div','color','$highlight-box-color-2','','','.p-quick-order-index'),(888344,'furniture','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','color','$fade-color-1','','','.w-cart-listing'),(888345,'furniture','.w-cart-listing .actions a','color','$fade-color-1','','','.w-cart-listing'),(888346,'furniture','.w-cart-listing .points-redeem','color','$message-color','','','.w-cart-listing'),(888347,'furniture','.w-cart-listing .remove-btn','color','$fade-color-1','','','.w-cart-listing'),(888348,'furniture','.w-cart-discount-coupon #credit_modules_message.error','color','$attention-color','','','.w-cart-discount-coupon'),(888352,'furniture','.w-cart-discount-coupon #credit_modules_message','color','$message-color','','','.w-cart-discount-coupon'),(888353,'furniture','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(888354,'furniture','.w-image-maps .float-items .item .description','color','$content-color-1','','','.w-image-maps'),(888355,'furniture','.b-fancybox .fancybox-nav span','color','$fancybox-color-1','','','.b-fancybox'),(888356,'furniture','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(888357,'furniture','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(888358,'furniture','.w-socials .post_item > div.tw_post_item','color','$content-color-1','3','','.w-socials'),(888359,'furniture','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(888360,'furniture','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(888361,'furniture','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(888362,'furniture','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(888363,'furniture','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(888364,'furniture','.w-filters .open','color','$content-color-1','3','','.w-filters'),(888365,'furniture','.w-filters .head-filter-widget','color','$highlight-box-color-2','5140','','.w-filters'),(888366,'furniture','.w-filters .filter-box-head','color','$content-color-1','','','.w-filters'),(888367,'furniture','.w-filters .view_more','color','$content-color-1','','','.w-filters'),(888368,'furniture','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(888369,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-1','3','','.w-contact-contacts'),(888370,'furniture','.b-bottom .pop-up-close','color','$content-color-1','','','.b-bottom'),(888371,'furniture','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(888372,'furniture','.b-pass-strength span.bad-pass','color','$warning-color','','','.b-pass-strength'),(888373,'furniture','.w-product-reviews .reviews-list .date','color','$fade-color-1','','','.w-product-reviews'),(888374,'furniture','.b-upload-files .remove-file','color','$attention-color','3','','.b-upload-files'),(888375,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','$content-color-1','1','','.b-data-table'),(888376,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','$content-color-1','','','.b-data-table'),(888378,'furniture','a.btn-3','color','$btn-color-1','','',''),(888379,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.off .candlestick-off','color','$switch-handle-bg-3','4','','.b-switch'),(888380,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.on .candlestick-on','color','$switch-handle-bg-3','4','','.b-switch'),(888381,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.default .candlestick-nc','color','$switch-handle-bg-3','4','','.b-switch'),(888382,'furniture','.b-pass-strength .short-pass, .b-pass-strength .pass-strength, .b-pass-strength .pass-no-match','color','$attention-color','','','.b-pass-strength'),(888383,'furniture','.b-form .message.error','color','$attention-color','','','.b-form'),(888384,'furniture','a.btn-1','color','$btn-color-1','','',''),(888385,'furniture','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','color','$fade-color-1','','','.w-filters'),(888386,'furniture','.b-product-images .media-popup .mp-close','color','$image-popup-color-2','','','.b-product-images'),(888387,'furniture','.b-product-images .media-popup .mp-close','color','$image-popup-color-1','1','','.b-product-images'),(888388,'furniture','.b-product-images .media-popup .slick-dots li','color','$image-popup-color-2','','','.b-product-images'),(888389,'furniture','.b-product-images .media-popup .slick-dots li.slick-active','color','$image-popup-color-1','','','.b-product-images'),(888390,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','color','$image-popup-color-2','','','.b-product-images'),(888391,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','color','$image-popup-color-1','1','','.b-product-images'),(888392,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','color','$header-menu-color-4','','','.b-menu-style-2'),(888393,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','color','$header-menu-color-3','','','.b-menu-style-2'),(888394,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','color','$header-menu-color-4','','','.b-menu-style-2'),(888395,'furniture','.b-personal-catalog-popup #personal_catalog_popup .show-all-lists','color','$content-color-1','','','.b-personal-catalog-popup'),(888396,'furniture','.b-trade-approval .steps-bar li.current a','color','$highlight-box-color-2','','','.b-trade-approval'),(888397,'furniture','.b-trade-approval .middle-form label','color','$content-color-1','','','.b-trade-approval'),(888398,'furniture','.w-account-personal-catalog .list-switcher a','color','$content-color-1','2','','.w-account-personal-catalog'),(888399,'furniture','.w-catalog-compare .checkbox input:checked + span:before','color','$fade-color-1','','','.w-catalog-compare'),(888400,'furniture','.w-catalog-compare span.btn-preloader','color','$content-color-1','3','','.w-catalog-compare'),(888401,'furniture','.w-catalog-compare .cross-box .different-all > div','color','$content-color-1','2','','.w-catalog-compare'),(888402,'furniture','.w-catalog-compare .cross-box .return','color','$content-color-1','','','.w-catalog-compare'),(888403,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','color','$content-color-1','3','','.w-catalog-compare'),(888404,'furniture','.w-delivery-day .ends','color','$attention-color','','','.w-delivery-day'),(888405,'furniture','.w-delivery-day .left-count-days-text, .w-delivery-day .left-count-hours-text, .w-delivery-day .left-count-minutes-text, .w-delivery-day .left-count-seconds-text','color','$highlight-box-color-2','','','.w-delivery-day'),(888410,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','color','$content-color-1','','','.b-slick'),(888411,'furniture','.menu-header .burger-icon','color','$content-color-1','5140','','.menu-header'),(888412,'furniture','.menu-header .burger-icon','color','$content-color-1','5140,3','','.menu-header'),(888413,'furniture','.b-products-listing .del-from-personal-catalog','color','$message-color','3','','.b-products-listing'),(888414,'furniture','.price .old','color','$price-old-1','','',''),(888415,'furniture','.w-filters .head-filter-widget','color','$content-color-1','','','.w-filters'),(888416,'furniture','.w-subscribers .btn-submit','color','$highlight-box-color-1','','','.w-subscribers'),(888417,'furniture','.w-quote .cart-box-link','color','$highlight-box-color-1','3','','.w-quote'),(888418,'furniture','.w-quote .multicart .count','color','$fade-color-1','','','.w-quote'),(888419,'furniture','.w-quote .multicart .item.current-multi-cart .switch-cart','color','$content-color-1','3','','.w-quote'),(888420,'furniture','.w-quote .multicart .switch-cart','color','$fade-color-1','','','.w-quote'),(888421,'furniture','.w-quote .multicart a.switch-cart','color','$attention-color','1','','.w-quote'),(888424,'furniture','.b-quantity .qty-box .bigger','color','$content-color-1','','','.b-quantity'),(888425,'furniture','.b-quantity .qty-box .smaller','color','$content-color-1','','','.b-quantity'),(888426,'furniture','.w-product-sale-ends .ends','color','$attention-color','','','.w-product-sale-ends'),(888427,'furniture','.w-product-sale-ends .left-count-days-text','color','$content-color-1','','','.w-product-sale-ends'),(888428,'furniture','.w-product-sale-ends .left-count-hours-text','color','$content-color-1','','','.w-product-sale-ends'),(888429,'furniture','.w-product-quantity .qty_packs .price_1','color','$fade-color-1','4','','.w-product-quantity'),(888430,'furniture','.w-product-quantity .qty-input input[type=\'text\']','color','$content-color-1','','','.w-product-quantity'),(888431,'furniture','.w-product-bonus-points > div > div','color','$content-color-1','','','.w-product-bonus-points'),(888432,'furniture','.warrantyProduct div','color','$content-color-1','','','.warrantyProduct'),(888433,'furniture','.w-files-catalog-widgets-files-catalog .name a','color','$highlight-box-color-2','','','.w-files-catalog-widgets-files-catalog'),(888434,'furniture','.w-files-catalog-widgets-files-list .file','color','$content-color-1','3','','.w-files-catalog-widgets-files-list'),(888435,'furniture','.w-sample .cart-box-link','color','$highlight-box-color-1','3','','.w-sample'),(888436,'furniture','.w-sample .cart-content','color','$content-color-1','','','.w-sample'),(888437,'furniture','.w-sample .multicart .count','color','$fade-color-1','','','.w-sample'),(888438,'furniture','.w-sample .multicart .item.current-multi-cart .switch-cart','color','$content-color-1','3','','.w-sample'),(888439,'furniture','.w-sample .multicart .switch-cart','color','$fade-color-1','','','.w-sample'),(888440,'furniture','.w-sample .multicart a.switch-cart','color','$attention-color','1','','.w-sample'),(888441,'furniture','.w-cart-gift-certificate .gift-certificate .heading-4','color','$content-color-1','3','','.w-cart-gift-certificate'),(888443,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','color','inherit','','','.b-products-listing'),(888444,'furniture','.b-pagination .pagination span','color','$highlight-box-color-2','2','','.b-pagination'),(888445,'furniture','.b-products-listing .products-listing.list-rows .stock','color','$message-color','','','.b-products-listing'),(888446,'furniture','.b-products-listing .products-listing.list-b2b .stock','color','$message-color','','','.b-products-listing'),(888447,'furniture','.w-product-collection .save','color','$message-color','','','.w-product-collection'),(888448,'furniture','.w-product-collection .right-area .separate-text, .w-product-collection .right-area .separate','color','$content-color-1','','','.w-product-collection'),(888449,'furniture','.w-product-collection .together','color','$content-color-1','','','.w-product-collection'),(888450,'furniture','.w-product-collection .choose-products .heading-3','color','$content-color-1','','','.w-product-collection'),(888451,'furniture','.price .special-promote','color','$price-special-1','','',''),(888452,'furniture','.w-product-in-bundles .bundle_price .old','color','$content-color-1','','','.w-product-in-bundles'),(888453,'furniture','.w-product-in-bundles .bundle_price .specials','color','$attention-color','','','.w-product-in-bundles'),(888454,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','color','$fade-color-1','','','.w-questionnaire-widgets-questionnaire'),(888455,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','color','$attention-color','','','.w-questionnaire-widgets-questionnaire'),(888456,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','color','$message-color','','','.w-questionnaire-widgets-questionnaire'),(888457,'furniture','.w-product-groups .radioBox label input:checked + div .val1','color','$content-color-1','','','.w-product-groups'),(888458,'furniture','.w-product-groups .val1','color','$content-color-1','','','.w-product-groups'),(888459,'furniture','.w-product-groups .val2','color','$content-color-1','','','.w-product-groups'),(888460,'furniture','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(888461,'furniture','.w-product-custom-bundle .right-area .separate','color','$attention-color','','','.w-product-custom-bundle'),(888462,'furniture','.w-delivery-location-location-list .deliveryList li a','color','$content-color-1','1','','.w-delivery-location-location-list'),(888463,'furniture','.w-sale-category .badge','color','$highlight-box-color-2','','','.w-sale-category'),(888464,'furniture','.w-sale-category .ends','color','$attention-color','','','.w-sale-category'),(888465,'furniture','.w-sale-category .left-count-days-text','color','$highlight-box-color-2','','','.w-sale-category'),(888466,'furniture','.w-sale-category .left-count-hours-text','color','$highlight-box-color-2','','','.w-sale-category'),(888467,'furniture','.w-sale-category .special-price','color','$attention-color','','','.w-sale-category'),(888468,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','color','$content-color-1','','','.w-product-properties-icons'),(888469,'furniture','.w-product-properties-icons .hover-box-content','color','transparent','','','.w-product-properties-icons'),(888470,'furniture','.w-delivery-location-product-categories .name','color','$highlight-box-color-1','','','.w-delivery-location-product-categories'),(888471,'furniture','.w-product-designer-designer .grnamebox .title-sortable','color','$highlight-box-color-1','','','.w-product-designer-designer'),(888472,'furniture','.w-product-designer-designer .prodDesignerType label','color','$content-color-1','','','.w-product-designer-designer'),(888473,'furniture','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','color','$content-color-1','','','.w-press-reviews-widgets-press-reviews-small'),(888474,'furniture','.w-press-reviews-widgets-press-reviews .date','color','$fade-color-1','','','.w-press-reviews-widgets-press-reviews'),(888475,'furniture','.w-press-reviews-widgets-press-reviews .full-review a','color','$content-color-1','','','.w-press-reviews-widgets-press-reviews'),(888476,'furniture','.w-press-reviews-widgets-press-reviews-list .date-added','color','$fade-color-1','','','.w-press-reviews-widgets-press-reviews-list'),(888477,'furniture','.w-press-reviews-widgets-press-reviews-list .out-link a','color','$content-color-1','','','.w-press-reviews-widgets-press-reviews-list'),(888478,'furniture','.b-products-listing .productGroup label a','color','$content-color-1','','','.b-products-listing'),(888479,'furniture','.w-gift-wrap-message-checkout .error','color','$attention-color','','','.w-gift-wrap-message-checkout'),(888480,'furniture','.w-support-system-listing .support-head','color','$content-color-1','','','.w-support-system-listing'),(888481,'furniture','.w-rma-returns-history .column .title','color','$highlight-box-color-2','','','.w-rma-returns-history'),(888482,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','color','transparent','','','.w-rma-returns-history'),(888483,'furniture','.w-rma-returns-history .icons .excel','color','$message-color','3','','.w-rma-returns-history'),(888484,'furniture','.w-rma-returns-history .icons .print','color','$content-color-1','','','.w-rma-returns-history'),(888485,'furniture','.w-rma-returns-history .linkButton','color','$content-color-1','','','.w-rma-returns-history'),(888486,'furniture','.w-rma-returns-history .linkButton','color','$content-color-1','1','','.w-rma-returns-history'),(888487,'furniture','.w-rma-returns-history thead tr','color','$highlight-box-color-2','','','.w-rma-returns-history'),(888488,'furniture','.w-rma-returns-history thead tr td','color','$highlight-box-color-2','','','.w-rma-returns-history'),(888489,'furniture','.b-products-listing .promos-info .promo-name-span','color','$attention-color','','','.b-products-listing'),(888490,'furniture','.w-predefined-promotion .cart_discount .heading-3','color','$warning-color','','','.w-predefined-promotion'),(888491,'furniture','.w-predefined-promotion .cart_discount .promo-date','color','$warning-color','3','','.w-predefined-promotion'),(888492,'furniture','.w-predefined-promotion .multidiscount .promo-date, .w-predefined-promotion .multidiscount .heading-3','color','$attention-color','','','.w-predefined-promotion'),(888493,'furniture','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','color','$content-color-1','','','.w-predefined-promotion'),(888494,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','color','$attention-color','','','.w-predefined-promotion'),(888495,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range, .w-predefined-promotion .prom-multi-discount > .heading','color','$attention-color','3','','.w-predefined-promotion'),(888496,'furniture','.w-predefined-promotion .promo-cart-discount .item a','color','$content-color-1','','','.w-predefined-promotion'),(888497,'furniture','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','color','$warning-color','3','','.w-predefined-promotion'),(888498,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','color','$attention-color','','','.w-predefined-promotion'),(888499,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','color','$attention-color','','','.w-predefined-promotion'),(888500,'furniture','.w-predefined-promotion .promo-salemaker .content a','color','$content-color-1','','','.w-predefined-promotion'),(888501,'furniture','.w-predefined-promotion .promo-salemaker .discount','color','$warning-color','','','.w-predefined-promotion'),(888502,'furniture','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .specials_category .promo-conditions','color','$warning-color','3','','.w-predefined-promotion'),(888503,'furniture','.w-predefined-promotion .specials_category .heading-3','color','$warning-color','','','.w-predefined-promotion'),(888504,'furniture','.w-predefined-promotion .specials_category .promo-salemaker .content a, .w-predefined-promotion .specials_category .promo-date','color','$warning-color','3','','.w-predefined-promotion'),(888505,'furniture','.w-supplier-purchase-supplier-products .active .select_item > div:before','color','$message-color','','','.w-supplier-purchase-supplier-products'),(888506,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','color','$content-color-1','','','.w-filters'),(888507,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','color','$content-color-1','','','.w-filters'),(888508,'furniture','.w-cart-listing .promos-info .promo-name','color','$attention-color','','','.w-cart-listing'),(888509,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','color','$content-color-1','','','.w-promotions-widgets-promotion-icons-desc'),(888510,'furniture','.w-product-promotion-icons .promos-info .promo-name','color','$attention-color','','','.w-product-promotion-icons'),(888525,'furniture','.account-address-book .leftMes div','color','$attention-color','','','.account-address-book'),(888526,'furniture','.account-address-book .leftMes ul','color','$attention-color','','','.account-address-book'),(888527,'furniture','.account-address-book .rightMes ul','color','$attention-color','','','.account-address-book'),(888533,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','color','$content-color-1','3','','.account-order-pay'),(888534,'furniture','.account-order-pay .not_fully_paid_td','color','$attention-color','','','.account-order-pay'),(888535,'furniture','.account-samples .moduleRowDue td','color','$fade-color-1','','','.account-samples'),(888536,'furniture','.account-samples .not_fully_paid_td','color','$attention-color','','','.account-samples'),(888537,'furniture','.account-samples .view_link','color','$content-color-1','','','.account-samples'),(888538,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','color','$content-color-1','3','','.account-sample-info'),(888539,'furniture','.account-sample-info .not_fully_paid_td','color','$attention-color','','','.account-sample-info'),(888540,'furniture','.catalog-product-wrap .pn-direction','color','$content-color-1','','','.catalog-product-wrap'),(888541,'furniture','.catalog-product-wrap .pn-image','color','$fade-color-1','3','','.catalog-product-wrap'),(888542,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','color','$highlight-box-color-1','','','.checkout-index-wrap'),(888543,'furniture','.checkout-index-wrap .edit-address-popup .edit-ab','color','$content-color-1','','','.checkout-index-wrap'),(888544,'furniture','.checkout-index-wrap .order-ico','color','$content-color-1','3','','.checkout-index-wrap'),(888545,'furniture','.checkout-index-wrap .pay-ico','color','$content-color-1','3','','.checkout-index-wrap'),(888546,'furniture','.checkout-index-wrap .ship-ico','color','$content-color-1','3','','.checkout-index-wrap'),(888547,'furniture','.checkout-order-confirmation .comment-ico','color','$content-color-1','3','','.checkout-order-confirmation'),(888548,'furniture','.checkout-order-confirmation .discount-ico','color','$content-color-1','3','','.checkout-order-confirmation'),(888549,'furniture','.checkout-order-confirmation .order-ico','color','$content-color-1','3','','.checkout-order-confirmation'),(888550,'furniture','.checkout-order-confirmation .ship-ico','color','$content-color-1','3','','.checkout-order-confirmation'),(888551,'furniture','.checkout-success-wrap .page-success .text-1','color','$content-color-1','3','','.checkout-success-wrap'),(888552,'furniture','.checkout-success-wrap .page-success .text-3','color','$attention-color','','','.checkout-success-wrap'),(888553,'furniture','.b-bottom .btn-cancel, .b-bottom .add-ab','color','$content-color-1','','','.b-bottom'),(888554,'furniture','.b-info .info','color','$attention-color','','','.b-info'),(888555,'furniture','.b-info .info a','color','$content-color-1','','','.b-info'),(888556,'furniture','.b-info .info-plus','color','$message-color','','','.b-info'),(888557,'furniture','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading','color','$content-color-1','','','.b-multi-page-checkout'),(888558,'furniture','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','color','$highlight-box-color-2','','','.b-multi-page-checkout'),(888559,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading','color','$fade-color-1','','','.b-multi-page-checkout'),(888560,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','$highlight-box-color-2','3','','.b-multi-page-checkout'),(888561,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','$content-color-1','','','.b-multi-page-checkout'),(888562,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','$content-color-1','','','.b-multi-page-checkout'),(888563,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','$content-color-1','4','','.b-multi-page-checkout'),(888564,'furniture','body','color','$content-color-1','','',''),(888565,'furniture','.success-page .check-ico-block','color','$content-color-1','3','','.success-page'),(888566,'furniture','.success-page .comment-ico','color','$content-color-1','3','','.success-page'),(888567,'furniture','.success-page .discount-ico','color','$content-color-1','3','','.success-page'),(888568,'furniture','.success-page .order-ico','color','$content-color-1','3','','.success-page'),(888569,'furniture','.success-page .page-success .text-1','color','$content-color-1','3','','.success-page'),(888570,'furniture','.success-page .page-success .text-3','color','$attention-color','','','.success-page'),(888571,'furniture','.success-page .pay-ico','color','$content-color-1','3','','.success-page'),(888572,'furniture','.success-page .prod-ico','color','$content-color-1','3','','.success-page'),(888573,'furniture','.success-page .ship-ico','color','$content-color-1','3','','.success-page'),(888574,'furniture','.success-page .w-cart-listing .name a','color','$content-color-1','','','.success-page'),(888575,'furniture','.success-page .w-cart-listing .qty','color','$highlight-box-color-1','','','.success-page'),(888576,'furniture','.menu-header .menu-style[data-style=\"1\"] .goto-button a','color','$header-menu-color-2','','','.menu-header'),(888577,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > li > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > li > .no-link','color','$header-menu-color-1','','','.menu-header'),(888578,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2','color','$header-menu-color-2','','','.menu-header'),(888580,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li','color','$footer-menu-color-2','3','','.footer-menu'),(888581,'furniture','.footer-menu .menu-style[data-style=\"3\"] li > a, .footer-menu .menu-style[data-style=\"3\"] .no-link','color','$footer-menu-color-1','','','.footer-menu'),(888582,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','color','$footer-menu-color-3','5140,3','','.footer-menu'),(888583,'furniture','.price','color','$price-current-1','','',''),(888584,'furniture','.w-catalog-paging ','color','$highlight-box-color-2','2','','.w-catalog-paging'),(888586,'furniture','.w-compare-box-item .checkbox:checked + span:before','color','$highlight-box-color-3','','','.w-compare-box-item'),(888587,'furniture','.w-files-catalog-widgets-files-catalog .name','color','$highlight-box-color-2','','','.w-files-catalog-widgets-files-catalog'),(888588,'furniture','.w-sale-category .left-count','color','$highlight-box-color-2','','','.w-sale-category'),(888589,'furniture','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','color','$highlight-box-color-1','','','.b-cookie-notice'),(888590,'furniture','.w-cart-compare .attributes-cell','color','$highlight-box-color-1','','','.w-cart-compare'),(888591,'furniture','.w-cart-compare .price-cell','color','$highlight-box-color-1','','','.w-cart-compare'),(888592,'furniture','.w-delivery-location-location-list .deliveryListParrent a','color','$highlight-box-color-1','','','.w-delivery-location-location-list'),(888593,'furniture','.w-product-properties-filters-widgets-chosen-filters .item','color','$highlight-box-color-1','','','.w-product-properties-filters-widgets-chosen-filters'),(888594,'furniture','.w-product-sale-ends .left-count','color','$highlight-box-color-1','','','.w-product-sale-ends'),(888595,'furniture','.w-quote .current-multi-cart.item','color','$highlight-box-color-1','','','.w-quote'),(888596,'furniture','.w-sample .current-multi-cart.item','color','$highlight-box-color-1','','','.w-sample'),(888597,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.p-quick-order-index'),(888598,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.p-quick-order-index'),(888599,'furniture','a.btn-2','color_important','important','','',''),(888600,'furniture','a.btn-3','color_important','important','','',''),(888601,'furniture','a.btn-1','color_important','important','','',''),(888602,'furniture','a.btn','color_important','important','','',''),(888603,'furniture','.b-select-suggest .select2-default','color_important','important','','','.b-select-suggest'),(888604,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.b-data-table'),(888605,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.b-data-table'),(888606,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','color_important','important','','','.w-rma-returns-history'),(888607,'furniture','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','content','\\f003','3','','.w-checkout-contact-information'),(888608,'furniture','.heading-4 .edit, h4 .edit','content','\\e917','4','',''),(888609,'furniture','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(888610,'furniture','.message.success','content','\\e918','3','',''),(888612,'furniture','.p-quick-order-index .paginate_button.next','content','\\f105','3','','.p-quick-order-index'),(888613,'furniture','.p-quick-order-index .paginate_button.previous','content','\\f104','3','','.p-quick-order-index'),(888614,'furniture','.w-promotions .prom-multi-discount .promo-range .promo-prod-qty','content',',','4','','.w-promotions'),(888615,'furniture','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','content','\\_','3','','.w-promotions'),(888616,'furniture','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(888617,'furniture','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(888618,'furniture','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(888621,'furniture','.p-sample-checkout-success .page-success','content','\\_','0,3','','.p-sample-checkout-success'),(888622,'furniture','.p-sample-checkout-success .page-success .text-1','content','\\e916','3','','.p-sample-checkout-success'),(888623,'furniture','.w-promotions .prom-multi-discount','content','\\_','4','','.w-promotions'),(888624,'furniture','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(888625,'furniture','.testimonials .review','content','\\_','3','',''),(888626,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(888627,'furniture','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(888628,'furniture','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(888629,'furniture','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(888630,'furniture','.w-promotions .prom-multi-discount > .heading','content','\\_','3','','.w-promotions'),(888631,'furniture','.w-promotions .nextdiscount .heading','content','\\f07a','3','','.w-promotions'),(888632,'furniture','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','content','\\_','3','','.w-promotions'),(888633,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','content','\\f041','3','','.b-warehouses-popup'),(888634,'furniture','.b-warehouses-popup .warehouses-popup-link','content','\\f041','3','','.b-warehouses-popup'),(888635,'furniture','.b-preloader .preloader','content','\\f110','3','','.b-preloader'),(888636,'furniture','.w-product-available-in-warehouses .content','content','\\_','4','','.w-product-available-in-warehouses'),(888637,'furniture','.b-products-listing .products-listing .mix-attributes','content','\\_','4','','.b-products-listing'),(888639,'furniture','.order-summary .price-row.ot_gv .title','content','\\e99f','3','','.order-summary'),(888640,'furniture','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(888641,'furniture','.b-messages .messBtnMenuUnread','content','\\f097','3','','.b-messages'),(888642,'furniture','.b-messages .messBtnMenuDelete','content','\\e913','3','','.b-messages'),(888643,'furniture','.b-messages span.starred::before','content','\\e90e','','','.b-messages'),(888644,'furniture','.b-messages .dataTables_wrapper > .top','content','\\_','4','','.b-messages'),(888645,'furniture','.b-messages .messBtnMenuStarred','content','\\e90e','3','','.b-messages'),(888646,'furniture','.b-messages .icon-circle-with-cross::before','content','×','','','.b-messages'),(888648,'furniture','.b-messages .dataTables_wrapper > .bottom','content','\\_','4','','.b-messages'),(888649,'furniture','.w-text .customer-service','content','\\e907','3','','.w-text'),(888650,'furniture','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(888651,'furniture','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(888652,'furniture','.p-payer-order-confirmation .ship-ico','content','\\e94e','3','','.p-payer-order-confirmation'),(888653,'furniture','.p-payer-order-confirmation .order-ico','content','\\e922','3','','.p-payer-order-confirmation'),(888654,'furniture','.p-payer-order-confirmation .pay-ico','content','\\e99e','3','','.p-payer-order-confirmation'),(888655,'furniture','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(888656,'furniture','.p-payer-order-confirmation .discount-ico','content','\\e95e','3','','.p-payer-order-confirmation'),(888657,'furniture','.p-payer-order-confirmation .comment-ico','content','\\e99d','3','','.p-payer-order-confirmation'),(888658,'furniture','.p-payer-order-pay .ship-ico','content','\\e94e','3','','.p-payer-order-pay'),(888659,'furniture','.p-payer-order-pay .pay-ico','content','\\e99e','3','','.p-payer-order-pay'),(888660,'furniture','.p-payer-order-pay .order-ico','content','\\e922','3','','.p-payer-order-pay'),(888661,'furniture','.p-payer-order-pay .discount-ico','content','\\e95e','3','','.p-payer-order-pay'),(888662,'furniture','.p-payer-order-pay .comment-ico','content','\\e99d','3','','.p-payer-order-pay'),(888663,'furniture','.b-fancybox .fancybox-close','content','\\f00d','3','','.b-fancybox'),(888664,'furniture','.b-messages .select2-search-choice-close','content','\\e913','3','','.b-messages'),(888665,'furniture','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','content','\\f095','3','','.w-checkout-contact-information'),(888666,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','content','ttr(data-content','4','','.b-switch'),(888667,'furniture','.b-rating .glyphicon-chevron-left','content','\\f104','3','','.b-rating'),(888668,'furniture','.w-product-reviews .reviews-list .review','content','\\_','3','','.w-product-reviews'),(888669,'furniture','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(888670,'furniture','.b-rating .glyphicon-chevron-right','content','\\f105','3','','.b-rating'),(888671,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-remove','content','\\f1f8','3','','.w-upload-customer-id-upload-customer-id-form'),(888672,'furniture','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(888673,'furniture','.w-coupons-and-vauchers-checkout .btn-remove','content','\\e913','3','','.w-coupons-and-vauchers-checkout'),(888674,'furniture','.w-login-block .cols','content','\\_','4','','.w-login-block'),(888675,'furniture','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(888677,'furniture','.order-summary .price-row.ot_bonus_points .title','content','\\e9a9','3','','.order-summary'),(888678,'furniture','.b-bottom .closeable-heading','content','\\f068','3','','.b-bottom'),(888679,'furniture','.b-bottom .closeable-heading.closed','content','\\f067','3','','.b-bottom'),(888680,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','content','\\f00c','3','','.b-form'),(888681,'furniture','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(888682,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','content',' ','3','','.b-switch'),(888683,'furniture','.w-social-links .stumbleupon','content','\\f1a4','3','','.w-social-links'),(888684,'furniture','.buttons','content','\\_','4','',''),(888685,'furniture','.out-stock-icon','content','\\f10c','3','',''),(888686,'furniture','.in-stock-icon','content','\\f00c','3','',''),(888687,'furniture','.transit-icon','content','\\f133','3','',''),(888690,'furniture','.w-cart-compare .atr-col','content','\\f070','3','','.w-cart-compare'),(888691,'furniture','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(888692,'furniture','.b-rating .glyphicon-chevron-up','content','\\f106','3','','.b-rating'),(888694,'furniture','.w-tabs .tab-li.tab-sample a','content','\\e984','3','','.w-tabs'),(888695,'furniture','.b-upload-file .upload-file-wrap .upload-remove','content','\\e913','3','','.b-upload-file'),(888696,'furniture','.w-chat .w-chat-box a','content','\\f075','3','','.w-chat'),(888697,'furniture','.b-bottom .footerTitle','content','\\f067','5131,4','','.b-bottom'),(888698,'furniture','.closeable-heading','content','\\f067','3','',''),(888699,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow b','content','\\25be','3','','.b-select-suggest'),(888701,'furniture','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(888702,'furniture','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(888703,'furniture','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(888704,'furniture','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(888705,'furniture','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(888707,'furniture','.w-top-categories .categories','content','\\_','4','','.w-top-categories'),(888708,'furniture','.w-checkout-billing-address .addresses','content','\\_','4','','.w-checkout-billing-address'),(888709,'furniture','.w-text .customer-service','content','\\e907','3','','.w-text'),(888710,'furniture','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(888711,'furniture','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(888712,'furniture','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(888714,'furniture','.view-all .btn','content','\\f054','4','',''),(888715,'furniture','.view-all','content','\\_','3','',''),(888716,'furniture','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(888717,'furniture','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(888718,'furniture','.b-form .newsletter-row','content','\\_','4','','.b-form'),(888719,'furniture','.w-checkout-shipping-address .addresses','content','\\_','4','','.w-checkout-shipping-address'),(888720,'furniture','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(888721,'furniture','.w-quote .cart-box-link','content','\\e90d','3','','.w-quote'),(888722,'furniture','.w-tabs .tab-li.tab-wishlist a','content','\\e992','3','','.w-tabs'),(888723,'furniture','.w-multi-cart-actions .cart-actions .dropdown-toggle','content','\\f013','3','','.w-multi-cart-actions'),(888724,'furniture','.w-text .customer-service','content','\\e907','3','','.w-text'),(888725,'furniture','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(888726,'furniture','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(888727,'furniture','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(888728,'furniture','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(888729,'furniture','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(888730,'furniture','.btn-edit','content','\\e917','3','',''),(888731,'furniture','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(888732,'furniture','.w-login-block .cols','content','\\_','4','','.w-login-block'),(888733,'furniture','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(888734,'furniture','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(888735,'furniture','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(888736,'furniture','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(888737,'furniture','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(888738,'furniture','.b-rating .glyphicon-time','content','\\f017','3','','.b-rating'),(888739,'furniture','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(888741,'furniture','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(888742,'furniture','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(888743,'furniture','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(888744,'furniture','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(888747,'furniture','.w-checkout-shipping-choice input:checked + span:before','content','\\_','','','.w-checkout-shipping-choice'),(888748,'furniture','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(888749,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(888750,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(888751,'furniture','.w-filters .input-checkbox:checked + .checkbox-span:before','content','\\f058','','','.w-filters'),(888752,'furniture','.heading-3 .edit, h3 .edit','content','\\e917','4','',''),(888753,'furniture','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(888754,'furniture','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(888755,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','content','ttr(data-content','4','','.b-switch'),(888756,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','content',' ','3','','.b-switch'),(888757,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','content','ttr(data-content','4','','.b-switch'),(888758,'furniture','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(888759,'furniture','.w-cart-bonus-points .btn-remove','content','\\e913','3','','.w-cart-bonus-points'),(888760,'furniture','.savings-ico .heading-2','content','\\e95e','3','','.savings-ico'),(888761,'furniture','.w-cart-compare .product-actions .dropdown-toggle','content','\\f013','3','','.w-cart-compare'),(888762,'furniture','.w-text .customer-service','content','\\e907','3','','.w-text'),(888763,'furniture','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(888764,'furniture','.w-text .customer-service','content','\\e907','3','','.w-text'),(888765,'furniture','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(888766,'furniture','.w-reviews .review','content','\\_','3','','.w-reviews'),(888767,'furniture','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(888768,'furniture','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(888769,'furniture','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(888770,'furniture','.js-stock-icon','content','\\f00c','3','',''),(888771,'furniture','.testimonials .heading-3','content','\\e908','3','',''),(888772,'furniture','.b-switch .candlestick-wrapper .fa-check','content','\\f00c','3','','.b-switch'),(888773,'furniture','.b-switch .candlestick-wrapper .fa-times','content','\\f00d','3','','.b-switch'),(888774,'furniture','.b-fancybox .fancybox-prev span','content','\\e900','3','','.b-fancybox'),(888775,'furniture','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(888776,'furniture','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(888777,'furniture','.w-list-b2b .attributes','content','\\_','4','','.w-list-b2b'),(888778,'furniture','.w-personal-gift-status-bar .inform','content','\\e6a0','4','','.w-personal-gift-status-bar'),(888779,'furniture','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(888780,'furniture','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(888781,'furniture','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(888782,'furniture','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(888783,'furniture','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(888784,'furniture','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(888785,'furniture','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(888786,'furniture','.w-reviews .heading-3','content','\\e908','3','','.w-reviews'),(888787,'furniture','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(888788,'furniture','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(888789,'furniture','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(888790,'furniture','.w-social-links .instagram','content','\\f16d','3','','.w-social-links'),(888791,'furniture','.w-social-links .linkedin','content','\\f0e1','3','','.w-social-links'),(888792,'furniture','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(888793,'furniture','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(888794,'furniture','.w-login-block .cols','content','\\_','4','','.w-login-block'),(888795,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span:before','content','\\f1db','','','.b-form'),(888796,'furniture','.w-cart-compare .product','content','\\_','4','','.w-cart-compare'),(888797,'furniture','.btn-del','content','\\f1f8','4','',''),(888798,'furniture','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(888799,'furniture','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(888801,'furniture','.w-checkout-bonus-points .btn-remove','content','\\e913','3','','.w-checkout-bonus-points'),(888802,'furniture','.b-rating .glyphicon-star.coloron','content','\\f005','3','','.b-rating'),(888803,'furniture','.w-cart-compare .delete-cart','content','\\2573','3','','.w-cart-compare'),(888804,'furniture','.w-cart-shipping-estimator .shipping-estimator','content','\\_','4','','.w-cart-shipping-estimator'),(888805,'furniture','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(888806,'furniture','.b-form .checkbox-style:checked + .checkbox-span:before','content','\\f058','','','.b-form'),(888807,'furniture','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(888808,'furniture','.b-form .addresses','content','\\_','4','','.b-form'),(888809,'furniture','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(888810,'furniture','.w-cart-credit-amount .btn-remove','content','\\e913','3','','.w-cart-credit-amount'),(888812,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(888813,'furniture','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(888814,'furniture','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(888816,'furniture','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(888817,'furniture','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(888818,'furniture','.b-info-popup .info-popup','content','\\e918','3','','.b-info-popup'),(888819,'furniture','.w-tabs .tab-li.tab-cart a','content','\\e90d','3','','.w-tabs'),(888820,'furniture','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(888821,'furniture','.b-upload-file .snapshot','content','\\f030','3','','.b-upload-file'),(888822,'furniture','.b-bottom .footerTitle','content','\\f068','5131,2,4','','.b-bottom'),(888823,'furniture','.b-bottom .pop-up-close','content','\\f00d','3','','.b-bottom'),(888824,'furniture','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','content','\\f004','','','.b-products-listing'),(888825,'furniture','.w-cart-shipping-estimator .address-item .lastname','content','\\_','4','','.w-cart-shipping-estimator'),(888826,'furniture','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','content','\\f08a','','','.b-products-listing'),(888827,'furniture','.b-upload-files .remove-file','content','\\f014','3','','.b-upload-files'),(888828,'furniture','.w-reviews-content .review','content','\\_','3','','.w-reviews-content'),(888829,'furniture','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(888830,'furniture','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(888831,'furniture','.w-social-links .facebook','content','\\f09a','3','','.w-social-links'),(888832,'furniture','.b-fancybox .fancybox-next span','content','\\e901','3','','.b-fancybox'),(888833,'furniture','.w-product-customers-activity .close','content','\\2715','3','','.w-product-customers-activity'),(888834,'furniture','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(888835,'furniture','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(888836,'furniture','.w-categories .categories','content','\\_','4','','.w-categories'),(888837,'furniture','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(888838,'furniture','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(888839,'furniture','.w-login-block .cols','content','\\_','4','','.w-login-block'),(888840,'furniture','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(888841,'furniture','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(888842,'furniture','.w-cart-shipping-estimator .item .row: after','content','\\_','','','.w-cart-shipping-estimator'),(888844,'furniture','.w-text .customer-service','content','\\e907','3','','.w-text'),(888845,'furniture','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(888846,'furniture','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(888847,'furniture','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(888850,'furniture','.w-social-links .pinterest','content','\\f0d2','3','','.w-social-links'),(888851,'furniture','.w-social-links .google-plus','content','\\f2b3','3','','.w-social-links'),(888852,'furniture','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(888853,'furniture','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(888854,'furniture','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(888855,'furniture','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(888858,'furniture','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(888859,'furniture','.b-rating .glyphicon-chevron-down','content','\\f107','3','','.b-rating'),(888860,'furniture','.w-social-links .twitter','content','\\f099','3','','.w-social-links'),(888861,'furniture','.w-checkout-create-account .account-benefits strong','content','\\e918','3','','.w-checkout-create-account'),(888862,'furniture','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(888863,'furniture','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(888865,'furniture','.b-products-listing .products-listing .bonus-points-cost','content','\\f219','3','','.b-products-listing'),(888866,'furniture','.b-products-listing .products-listing .bonus-points-price','content','\\f219','3','','.b-products-listing'),(888867,'furniture','.b-products-listing .products-listing a.btn.view-button','content','\\e991','3','','.b-products-listing'),(888868,'furniture','.b-products-listing .BlockBox','content','\\_','4','','.b-products-listing'),(888869,'furniture','.b-products-listing .btn-preloader','content','\\f110','3','','.b-products-listing'),(888870,'furniture','.b-products-listing .hover-box-content','content','\\_','3','','.b-products-listing'),(888871,'furniture','.b-products-listing .loader','content','\\f110','4','','.b-products-listing'),(888872,'furniture','.b-products-listing .products-listing','content','\\_','4','','.b-products-listing'),(888873,'furniture','.b-products-listing .loader','content','\\_','3','','.b-products-listing'),(888874,'furniture','.b-products-listing .products-listing .btn-buy','content','\\e977','3','','.b-products-listing'),(888875,'furniture','.b-products-listing .products-listing .qty-input.hidden','content','\\_','3','','.b-products-listing'),(888876,'furniture','.checkbox input:not(checked) + span:before','content','\\_','','',''),(888879,'furniture','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(888880,'furniture','.b-rating .glyphicon-star','content','\\f006','3','','.b-rating'),(888881,'furniture','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(888882,'furniture','.b-form .hide-box','content','\\_','3','','.b-form'),(888883,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','content','\\_','3','','.b-switch'),(888884,'furniture','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','content','\\f10b','3','','.w-checkout-contact-information'),(888885,'furniture','.b-info-popup .info-popup div','content','\\_','3','','.b-info-popup'),(888886,'furniture','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(888887,'furniture','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(888888,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(888889,'furniture','.order-summary .price-row.ot_coupon .title','content','%','3','','.order-summary'),(888890,'furniture','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(888891,'furniture','.b-form .eye-password.eye-password-showed','content','\\f070','3','','.b-form'),(888892,'furniture','.b-form .eye-password','content','\\f06e','3','','.b-form'),(888893,'furniture','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(888894,'furniture','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(888895,'furniture','.w-tabs .tab-li.tab-quote a','content','\\e9aa','3','','.w-tabs'),(888896,'furniture','.w-login-block .cols','content','\\_','4','','.w-login-block'),(888898,'furniture','.w-personal-gift-status-bar .end-date','content','\\e72b','3','','.w-personal-gift-status-bar'),(888899,'furniture','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','content','\\e913','3','','.order-summary'),(888900,'furniture','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(888901,'furniture','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(888902,'furniture','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(888903,'furniture','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(888904,'furniture','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(888905,'furniture','.w-product-cross-sell .buy-all-checker','content','\\f14a','3','','.w-product-cross-sell'),(888906,'furniture','.w-catalog-listing-look .b2b','content','\\f0c9','3','','.w-catalog-listing-look'),(888907,'furniture','.w-catalog-listing-look .grid','content','\\f009','3','','.w-catalog-listing-look'),(888908,'furniture','.checkbox input:checked + span:before','content','\\f00c','','',''),(888909,'furniture','.w-cart-listing .multi-product-copy','content','\\e922','3','','.w-cart-listing'),(888910,'furniture','.w-cart-listing .multi-product-delete','content','\\e913','3','','.w-cart-listing'),(888911,'furniture','.w-cart-listing .multi-product-move','content','\\e975','3','','.w-cart-listing'),(888912,'furniture','.w-cart-listing .points-redeem','content','\\f219','3','','.w-cart-listing'),(888913,'furniture','.w-cart-listing .item .gift-wrap .value','content',')','4','','.w-cart-listing'),(888914,'furniture','.w-cart-listing .item .gift-wrap .value','content','(','3','','.w-cart-listing'),(888915,'furniture','.w-cart-listing .remove-btn','content','\\f00d','3','','.w-cart-listing'),(888916,'furniture','.w-cart-give-away .ga_name','content','\\_','4','','.w-cart-give-away'),(888920,'furniture','.w-cart-discount-coupon .btn-remove','content','\\e913','3','','.w-cart-discount-coupon'),(888921,'furniture','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(888922,'furniture','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(888923,'furniture','.b-compare .clear_all','content','\\f00d','4','','.b-compare'),(888924,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(888925,'furniture','.w-filters .open','content','\\f056','3','','.w-filters'),(888927,'furniture','.w-checkout-credit-amount .btn-remove','content','\\e913','3','','.w-checkout-credit-amount'),(888928,'furniture','.w-filters .fsl_handle','content','\\_','4','','.w-filters'),(888929,'furniture','.w-filters .view_more','content','\\f061','4','','.w-filters'),(888930,'furniture','.w-filters span.close','content','\\f055','3','','.w-filters'),(888931,'furniture','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(888932,'furniture','.w-catalog-listing-look .list','content','\\f00b','3','','.w-catalog-listing-look'),(888933,'furniture','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(888934,'furniture','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(888935,'furniture','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(888936,'furniture','.w-login-block .cols','content','\\_','4','','.w-login-block'),(888937,'furniture','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(888941,'furniture','.b-rating .glyphicon-calendar','content','\\f073','3','','.b-rating'),(888942,'furniture','.w-filters .mobileCollapse','content','\\f056','2,4','','.w-filters'),(888943,'furniture','.w-filters .mobileCollapse','content','\\f055','4','','.w-filters'),(888944,'furniture','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','content','\\f1db','','','.w-filters'),(888945,'furniture','.b-product-images .media-popup .mp-close','content','\\f00d','3','','.b-product-images'),(888946,'furniture','.b-product-images .media-popup .slick-dots li','content','\\2022','3','','.b-product-images'),(888947,'furniture','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','content','\\f0c9','3','','.b-menu-burger_icon'),(888948,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(888949,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(888950,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(888951,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(888952,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(888953,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(888954,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(888955,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(888956,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(888957,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(888958,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','content','\\f00d','3','','.b-menu-style-2'),(888959,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','content','\\_','3','','.b-menu-style-2'),(888960,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','content','\\f105','3','','.b-menu-style-2'),(888961,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','content','\\_','3','','.b-menu-style-2'),(888962,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','content','\\f104','3','','.b-menu-style-2'),(888963,'furniture','.b-trade-approval .columns','content','\\_','4','','.b-trade-approval'),(888964,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','content','\\e90d','3','','.w-catalog-compare'),(888965,'furniture','.w-catalog-compare td span + span','content','| ','3','','.w-catalog-compare'),(888966,'furniture','.w-catalog-compare .checkbox input:checked + span:before','content','\\f014','','','.w-catalog-compare'),(888970,'furniture','.b-slick .slick-track, .b-slick .slick-track:after','content','\\_','3','','.b-slick'),(888971,'furniture','.b-slick .slick-vertical button.slick-next','content','\\f078','3','','.b-slick'),(888972,'furniture','.b-slick .slick-vertical button.slick-prev','content','\\f077','3','','.b-slick'),(888973,'furniture','.b-slick button.slick-next','content','\\f054','3','','.b-slick'),(888974,'furniture','.b-slick button.slick-prev','content','\\f053','3','','.b-slick'),(888975,'furniture','.b-products-listing .add-to-personal-catalog','content','\\f08a','3','','.b-products-listing'),(888976,'furniture','.b-products-listing .del-from-personal-catalog','content','\\f004','3','','.b-products-listing'),(888977,'furniture','.cartTitle >div','content','\\_','3','','.cartTitle'),(888978,'furniture','.w-bestsellers .products-listing .item','content','\\_','3','','.w-bestsellers'),(888979,'furniture','.b-products-listing .products-listing.list-productlisting .item-content','content','\\_','4','','.b-products-listing'),(888980,'furniture','.w-breadcrumb .breadcrumb-li + .breadcrumb-li','content','/','3','','.w-breadcrumb'),(888981,'furniture','.w-quote .multicart .count','content','(','3','','.w-quote'),(888982,'furniture','.w-quote .multicart .count','content',')','4','','.w-quote'),(888983,'furniture','.w-quote .multicart .item.current-multi-cart .switch-cart','content','\\f058','3','','.w-quote'),(888984,'furniture','.w-quote .multicart .switch-cart','content','\\f111','3','','.w-quote'),(888985,'furniture','.w-quote .qty','content','\\274c','4','','.w-quote'),(888986,'furniture','.w-quote a.item','content','\\_','4','','.w-quote'),(888987,'furniture','.w-product-personal-catalog-button .del_to_personal_catalog','content','\\f004','3','','.w-product-personal-catalog-button'),(888988,'furniture','.w-product-personal-catalog-button .add_to_personal_catalog','content','\\f08a','3','','.w-product-personal-catalog-button'),(888989,'furniture','.b-quantity .qty-box .bigger','content','+','3','','.b-quantity'),(888990,'furniture','.b-quantity .qty-box .smaller','content','-','3','','.b-quantity'),(888991,'furniture','h1, .heading-1','content','\\_','3','',''),(888992,'furniture','h1, .heading-1','content','\\_','4','',''),(888993,'furniture','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','content','\\e90d','3','','.w-product-buttons'),(888994,'furniture','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(888995,'furniture','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(888996,'furniture','.w-product-bonus-points > div','content','\\_','4','','.w-product-bonus-points'),(888997,'furniture','.w-product-bonus-points > div > div','content','\\f219','3','','.w-product-bonus-points'),(888998,'furniture','.warrantyProduct .warranty','content','\\_','3','','.warrantyProduct'),(888999,'furniture','.warrantyProduct .delivery','content','\\_','3','','.warrantyProduct'),(889000,'furniture','.w-compare .remove','content','\\f014','3','','.w-compare'),(889001,'furniture','.w-files-catalog-widgets-files-list .file','content','\\f1c1','3','','.w-files-catalog-widgets-files-list'),(889002,'furniture','.w-sample .cart-box-link','content','\\_','4','','.w-sample'),(889003,'furniture','.w-sample .cart-box-link','content','\\e90d','3','','.w-sample'),(889004,'furniture','.w-sample .multicart .count','content','(','3','','.w-sample'),(889005,'furniture','.w-sample .multicart .count','content',')','4','','.w-sample'),(889006,'furniture','.w-sample .multicart .item.current-multi-cart .switch-cart','content','\\f058','3','','.w-sample'),(889007,'furniture','.w-sample .multicart .switch-cart','content','\\f111','3','','.w-sample'),(889008,'furniture','.w-sample .qty','content','\\f00d ','4','','.w-sample'),(889009,'furniture','.w-sample a.item','content','\\_','4','','.w-sample'),(889010,'furniture','.w-cart-listing .points-earn','content','\\_','4','','.w-cart-listing'),(889011,'furniture','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(889012,'furniture','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(889014,'furniture','.heading-2','content','\\_','3','',''),(889015,'furniture','.heading-2','content','\\_','4','',''),(889016,'furniture','.b-products-listing .products-listing .radio-attributes','content','\\_','4','','.b-products-listing'),(889017,'furniture','.b-pagination .pagination','content','\\_','4','','.b-pagination'),(889018,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','content','\\f105','3','','.b-pagination'),(889019,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','content','\\f104','3','','.b-pagination'),(889020,'furniture','.w-product-multi-inventory .select-box:last-of-type:after','content','\\_','','','.w-product-multi-inventory'),(889021,'furniture','.w-product-properties-filters-widgets-chosen-filters .remove','content','\\2716','3','','.w-product-properties-filters-widgets-chosen-filters'),(889022,'furniture','.w-product-multi-inventory #product-attributes','content','\\_','4','','.w-product-multi-inventory'),(889023,'furniture','.p-quote-checkout-index .order-summary .heading-2','content','\\_','3','','.p-quote-checkout-index'),(889024,'furniture','.p-quote-checkout-index .order-summary .heading-2','content','\\_','4','','.p-quote-checkout-index'),(889025,'furniture','.p-sample-checkout-index .order-summary .heading-2','content','\\_','3','','.p-sample-checkout-index'),(889026,'furniture','.p-sample-checkout-index .order-summary .heading-2','content','\\_','4','','.p-sample-checkout-index'),(889027,'furniture','.w-product-multi-inventory .radio-attributes','content','\\_','4','','.w-product-multi-inventory'),(889028,'furniture','.w-account-personal-catalog .list-row-action ul','content','\\f107','4','','.w-account-personal-catalog'),(889029,'furniture','.w-product-quantity-discounts .quantity-discounts','content','\\_','4','','.w-product-quantity-discounts'),(889030,'furniture','.w-product-collection .right-area .btn','content','\\e90d','3','','.w-product-collection'),(889031,'furniture','.w-product-collection .right-area .btn-2','content','\\e90d','3','','.w-product-collection'),(889032,'furniture','.w-product-attributes #product-attributes','content','\\_','4','','.w-product-attributes'),(889033,'furniture','.w-product-attributes .radio-attributes','content','\\_','4','','.w-product-attributes'),(889034,'furniture','.w-product-attributes .select-box:last-of-type:after','content','\\_','','','.w-product-attributes'),(889035,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','content','\\2714','3','','.w-questionnaire-widgets-questionnaire'),(889036,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','content','\\2718','3','','.w-questionnaire-widgets-questionnaire'),(889037,'furniture','.w-product-groups .prop-group-swatch','content','\\_','4','','.w-product-groups'),(889038,'furniture','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','content','\\e90d','3','','.w-product-custom-bundle'),(889039,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list'),(889040,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list-block'),(889041,'furniture','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(889042,'furniture','.w-delivery-location-featured-list .deliveryList ul','content','\\_','4','','.w-delivery-location-featured-list'),(889043,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list-by-catalog'),(889044,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(889045,'furniture','.w-delivery-location-list-by-page .page-list','content','\\_','4','','.w-delivery-location-list-by-page'),(889046,'furniture','.w-delivery-location-top-location-list .deliveryList','content','\\_','4','','.w-delivery-location-top-location-list'),(889047,'furniture','.w-delivery-location-cross-pages .page-list','content','\\_','4','','.w-delivery-location-cross-pages'),(889048,'furniture','.delivery-options-popup','content','\\_','4','',''),(889049,'furniture','.w-support-system-filter .dd3-content .collapse_span','content','\\f056','3','','.w-support-system-filter'),(889050,'furniture','.w-support-system-filter .dd3-content .collapse_span.clouse','content','\\f055','3','','.w-support-system-filter'),(889051,'furniture','.w-communication-post .btn.refresh','content','\\21bb','3','','.w-communication-post'),(889052,'furniture','.w-rma-returns-history .icons .excel','content','\\f1c3','3','','.w-rma-returns-history'),(889053,'furniture','.w-rma-returns-history .icons .print','content','\\f02f','3','','.w-rma-returns-history'),(889054,'furniture','.w-rma-returns-history .linkButton','content','\\f105','4','','.w-rma-returns-history'),(889055,'furniture','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(889056,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-list'),(889057,'furniture','.w-predefined-promotion .nextdiscount .heading','content','\\f07a','3','','.w-predefined-promotion'),(889058,'furniture','.w-predefined-promotion .prom-multi-discount','content','\\_','4','','.w-predefined-promotion'),(889059,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range .promo-prod-qty','content',',','4','','.w-predefined-promotion'),(889060,'furniture','.w-predefined-promotion .prom-multi-discount > .heading','content','\\_','3','','.w-predefined-promotion'),(889061,'furniture','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','content','\\_','3','','.w-predefined-promotion'),(889062,'furniture','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','content','\\_','3','','.w-predefined-promotion'),(889063,'furniture','.w-supplier-purchase-supplier-products .active .select_item > div:before','content','\\f00c','','','.w-supplier-purchase-supplier-products'),(889064,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','content','\\f1db','','','.w-filters'),(889065,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','content','\\f058','','','.w-filters'),(889066,'furniture','.mainBanner .buttonBox','content','\\_','4','','.mainBanner'),(889067,'furniture','.mainBanner .title','content','\\_','3','','.mainBanner'),(889068,'furniture','.mainBanner .topBox > .right','content','\\_','3','','.mainBanner'),(889069,'furniture','.mainBanner .topBox > .right','content','\\_','4','','.mainBanner'),(889070,'furniture','.order-summary .icon','content','\\f067','3','','.order-summary'),(889071,'furniture','.order-summary .icon.opened','content','\\f068','3','','.order-summary'),(889072,'furniture','.w-cart-discount-coupon .title','content','\\f106','','','.w-cart-discount-coupon'),(889073,'furniture','.w-cart-discount-coupon .title','content','\\f107','4','','.w-cart-discount-coupon'),(889074,'furniture','.w-cart-discount-coupon .title.opened','content','\\f106','4','','.w-cart-discount-coupon'),(889075,'furniture','.w-cart-checkout-btn .with-card','content','\\f283','4','','.w-cart-checkout-btn'),(889098,'furniture','.account-order-pay .historyInfoColumn h2.title-delivery-address, .account-order-pay .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-order-pay'),(889099,'furniture','.account-order-pay .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-order-pay'),(889100,'furniture','.account-order-pay .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-order-pay'),(889101,'furniture','.account-samples .view_link','content','\\e901','4','','.account-samples'),(889102,'furniture','.account-sample-info .historyInfoColumn h2.title-delivery-address, .account-sample-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-sample-info'),(889103,'furniture','.account-sample-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-sample-info'),(889104,'furniture','.account-sample-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-sample-info'),(889105,'furniture','.catalog-product-wrap .next-product .pn-image','content','\\f054','3','','.catalog-product-wrap'),(889106,'furniture','.catalog-product-wrap .prev-product .pn-image','content','\\f053','3','','.catalog-product-wrap'),(889107,'furniture','.checkout-index-wrap .order-ico','content','\\e922','3','','.checkout-index-wrap'),(889108,'furniture','.checkout-index-wrap .order-summary .heading-2','content','\\_','3','','.checkout-index-wrap'),(889109,'furniture','.checkout-index-wrap .order-summary .heading-2','content','\\_','4','','.checkout-index-wrap'),(889110,'furniture','.checkout-index-wrap .pay-ico','content','\\e99e','3','','.checkout-index-wrap'),(889111,'furniture','.checkout-index-wrap .ship-ico','content','\\e94e','3','','.checkout-index-wrap'),(889112,'furniture','.checkout-order-confirmation .comment-ico','content','\\e99d','3','','.checkout-order-confirmation'),(889113,'furniture','.checkout-order-confirmation .discount-ico','content','\\e95e','3','','.checkout-order-confirmation'),(889114,'furniture','.checkout-order-confirmation .order-ico','content','\\e922','3','','.checkout-order-confirmation'),(889115,'furniture','.checkout-order-confirmation .ship-ico','content','\\e94e','3','','.checkout-order-confirmation'),(889116,'furniture','.checkout-success-wrap .page-success','content','\\_','3','','.checkout-success-wrap'),(889117,'furniture','.checkout-success-wrap .page-success .text-1','content','\\e916','3','','.checkout-success-wrap'),(889118,'furniture','.shopping-cart-index .gift-code .heading-4','content','\\f068','2,4','','.shopping-cart-index'),(889119,'furniture','.shopping-cart-index .gift-code .heading-4','content','\\f067','4','','.shopping-cart-index'),(889120,'furniture','.b-info .info','content','\\e918','3','','.b-info'),(889121,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-content','content','\\_','4','','.b-multi-page-checkout'),(889122,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','content','\\f00c','3','','.b-multi-page-checkout'),(889123,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','content','\\e917','4','','.b-multi-page-checkout'),(889124,'furniture','.success-page .check-ico-block','content','\\e916','3','','.success-page'),(889125,'furniture','.success-page .comment-ico','content','\\e99d','3','','.success-page'),(889126,'furniture','.success-page .discount-ico','content','\\e95e','3','','.success-page'),(889127,'furniture','.success-page .order-ico','content','\\e922','3','','.success-page'),(889128,'furniture','.success-page .page-success','content','\\_','3','','.success-page'),(889129,'furniture','.success-page .page-success .text-1','content','\\e916','3','','.success-page'),(889130,'furniture','.success-page .pay-ico','content','\\e99e','3','','.success-page'),(889131,'furniture','.success-page .prod-ico','content','\\e99b','3','','.success-page'),(889132,'furniture','.success-page .ship-ico','content','\\e94e','3','','.success-page'),(889133,'furniture','.menu-header .menu-style[data-style=\"1\"] .goto-button a','content','\\f105 \\f105','4','','.menu-header'),(889134,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > .parent > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','content','\\f107','4','','.menu-header'),(889135,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 .parent > a, .menu-header .menu-style[data-style=\"1\"] .level-2 .parent > .no-link','content','\\f105','4','','.menu-header'),(889136,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li','content','\\2022','3','','.footer-menu'),(889137,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li.component-item','content','\\_','3','','.footer-menu'),(889138,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','content','+','5140,3','','.footer-menu'),(889139,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li.vis-show','content','-','5140,3','','.footer-menu'),(889140,'furniture','.lowestPricedBox .w-banner .ybg','content','\\_','3','','.lowestPricedBox'),(889141,'furniture','.tripleBanner .w-html_box','content','\\_','3','','.tripleBanner'),(889142,'furniture','.shopByCollectionBox .content','content','\\_','4','','.shopByCollectionBox'),(889143,'furniture','.w-catalog-paging .next','content','\\f105','3','','.w-catalog-paging'),(889144,'furniture','.w-catalog-paging .prev','content','\\f104','3','','.w-catalog-paging'),(889145,'furniture','.w-compare-box-item .checkbox:checked + span:before','content','\\f00c','','','.w-compare-box-item'),(889146,'furniture','.w-compare-box-item .checkbox:not(checked) + span:before','content','\\_','','','.w-compare-box-item'),(889147,'furniture','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(889148,'furniture','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(889149,'furniture','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(889150,'furniture','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(889151,'furniture','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(889152,'furniture','.b-rating .glyphicon-chevron-left','content_important','important','3','','.b-rating'),(889153,'furniture','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(889154,'furniture','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(889155,'furniture','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(889156,'furniture','.b-rating .glyphicon-chevron-right','content_important','important','3','','.b-rating'),(889157,'furniture','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(889158,'furniture','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(889159,'furniture','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(889160,'furniture','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(889161,'furniture','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(889162,'furniture','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(889163,'furniture','.b-rating .glyphicon-chevron-up','content_important','important','3','','.b-rating'),(889164,'furniture','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(889165,'furniture','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(889166,'furniture','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(889167,'furniture','.b-rating .glyphicon-chevron-down','content_important','important','3','','.b-rating'),(889168,'furniture','.b-rating .glyphicon-calendar','content_important','important','3','','.b-rating'),(889169,'furniture','.b-rating .glyphicon-time','content_important','important','3','','.b-rating'),(889170,'furniture','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(889171,'furniture','.heading-2','content_important','important','3','',''),(889172,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor','default','','','.b-switch'),(889173,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','cursor','pointer','','','.b-switch'),(889174,'furniture','.p-quick-order-index .filters .clear','cursor','pointer','','','.p-quick-order-index'),(889175,'furniture','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','cursor','pointer','3','','.order-summary'),(889176,'furniture','.b-messages .messMenuButton span','cursor','pointer','','','.b-messages'),(889177,'furniture','.b-fancybox #fancybox-loading','cursor','pointer','','','.b-fancybox'),(889178,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file','cursor','pointer','','','.w-upload-customer-id-upload-customer-id-form'),(889179,'furniture','.b-switch .bootstrap-switch','cursor','pointer','','','.b-switch'),(889180,'furniture','.w-coupons-and-vauchers-checkout .btn-remove','cursor','pointer','','','.w-coupons-and-vauchers-checkout'),(889181,'furniture','.b-autocomplete .ui-autocomplete li','cursor','pointer','','','.b-autocomplete'),(889183,'furniture','.w-filters .open, .w-filters .close','cursor','pointer','','','.w-filters'),(889184,'furniture','.w-checkout-shipping-choice span','cursor','pointer','','','.w-checkout-shipping-choice'),(889185,'furniture','.w-cart-compare .atr-col','cursor','pointer','','','.w-cart-compare'),(889186,'furniture','.w-tabs .tab-a','cursor','pointer','','','.w-tabs'),(889187,'furniture','.w-tabs .tab-a','cursor','default','2','','.w-tabs'),(889188,'furniture','.disabled-area','cursor','not-allowed','','',''),(889189,'furniture','.disabled-area *','cursor','not-allowed','','',''),(889191,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','cursor','pointer','3','','.b-form'),(889192,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','cursor','pointer','','','.b-switch'),(889193,'furniture','.w-cart-bonus-points .btn-remove','cursor','pointer','','','.w-cart-bonus-points'),(889194,'furniture','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','','','.b-select-suggest'),(889195,'furniture','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','1','','.b-select-suggest'),(889196,'furniture','.b-switch .candlestick-wrapper .candlestick-bg.grab:not(.candlestick-disabled ) .candlestick-toggle','cursor','grab','','','.b-switch'),(889197,'furniture','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled','cursor','not-allowed','','','.b-switch'),(889198,'furniture','.b-fancybox .fancybox-close','cursor','pointer','','','.b-fancybox'),(889199,'furniture','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','cursor','default','','','.b-select-suggest'),(889200,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor','default','','','.b-switch'),(889201,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor','default','','','.b-switch'),(889202,'furniture','.w-checkout-bonus-points .btn-remove','cursor','pointer','','','.w-checkout-bonus-points'),(889203,'furniture','.w-checkout-credit-amount .btn-remove','cursor','pointer','','','.w-checkout-credit-amount'),(889204,'furniture','.b-upload-file .snapshot','cursor','pointer','','','.b-upload-file'),(889205,'furniture','.b-form .item-radio label','cursor','pointer','','','.b-form'),(889206,'furniture','.b-bottom .footerTitle','cursor','pointer','5131','','.b-bottom'),(889207,'furniture','.b-products-listing .products-listing .wishlistButton .checkbox','cursor','pointer','','','.b-products-listing'),(889208,'furniture','.w-cart-credit-amount .btn-remove','cursor','pointer','','','.w-cart-credit-amount'),(889209,'furniture','.w-product-customers-activity .close','cursor','pointer','','','.w-product-customers-activity'),(889210,'furniture','.b-form .item-radio.active label','cursor','default','','','.b-form'),(889211,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor','default','','','.b-switch'),(889212,'furniture','.b-fancybox .fancybox-nav','cursor','pointer','','','.b-fancybox'),(889214,'furniture','.closeable-event','cursor','pointer','','',''),(889215,'furniture','.b-form .addresses.address-main .address-item label','cursor','default','','','.b-form'),(889216,'furniture','.w-checkout-shipping-choice input:checked + span','cursor','default','','','.w-checkout-shipping-choice'),(889217,'furniture','.w-tabs .accordion-heading','cursor','default','2','','.w-tabs'),(889218,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','cursor','default','','','.b-select-suggest'),(889219,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-chosen','cursor','default','','','.b-select-suggest'),(889220,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','cursor','default','','','.b-select-suggest'),(889221,'furniture','.b-select-suggest .select2-container-multi .select2-choices','cursor','text','','','.b-select-suggest'),(889222,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','cursor','default','','','.b-select-suggest'),(889223,'furniture','.b-select-suggest .select2-results .select2-disabled','cursor','default','','','.b-select-suggest'),(889224,'furniture','.b-select-suggest .select2-results .select2-result-label','cursor','pointer','','','.b-select-suggest'),(889227,'furniture','.b-form .eye-password','cursor','pointer','','','.b-form'),(889228,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','cursor','pointer','','','.w-communication-new-topic'),(889229,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','cursor','pointer','','','.w-communication-new-topic'),(889230,'furniture','.w-filters .ui-slider-handle','cursor','pointer','','','.w-filters'),(889231,'furniture','.w-cart-discount-coupon .btn-remove','cursor','pointer','','','.w-cart-discount-coupon'),(889232,'furniture','.b-fancybox .fancybox-nav span','cursor','pointer','','','.b-fancybox'),(889233,'furniture','.w-tabs .accordion-heading','cursor','pointer','','','.w-tabs'),(889234,'furniture','.w-filters .filter-box-content ul li.view_items','cursor','pointer','','','.w-filters'),(889235,'furniture','.b-bottom .pop-up-close','cursor','pointer','','','.b-bottom'),(889236,'furniture','.b-upload-files .remove-file','cursor','pointer','','','.b-upload-files'),(889238,'furniture','.w-menu-big .show-all','cursor','pointer','','','.w-menu-big'),(889239,'furniture','.b-form .addresses .address-item label','cursor','pointer','','','.b-form'),(889240,'furniture','.w-filters .mobileCollapse','cursor','pointer','4','','.w-filters'),(889241,'furniture','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','cursor','pointer','','','.b-product-images'),(889242,'furniture','.b-product-images .media-popup .mp-close','cursor','pointer','','','.b-product-images'),(889243,'furniture','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','cursor','pointer','','','.b-product-images'),(889244,'furniture','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','cursor','pointer','','','.b-menu-burger_icon'),(889245,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(889246,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(889247,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(889248,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(889249,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(889250,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','cursor','pointer','','','.b-menu-style-2'),(889251,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','cursor','pointer','','','.b-menu-style-2'),(889252,'furniture','.w-account-personal-catalog .list-switcher a','cursor','pointer','','','.w-account-personal-catalog'),(889253,'furniture','.w-account-personal-catalog .list-switcher a','cursor','default','2','','.w-account-personal-catalog'),(889254,'furniture','.w-catalog-compare .compare label','cursor','pointer','','','.w-catalog-compare'),(889255,'furniture','.w-catalog-compare .cross-box .different-all > div','cursor','pointer','','','.w-catalog-compare'),(889256,'furniture','.w-catalog-compare .cross-box .different-all > div','cursor','default','2','','.w-catalog-compare'),(889257,'furniture','.w-catalog-compare .cross-box .return','cursor','pointer','','','.w-catalog-compare'),(889258,'furniture','.b-slick button.slick-disabled','cursor','default','','','.b-slick'),(889259,'furniture','.w-subscribers .btn-submit','cursor','pointer','','','.w-subscribers'),(889260,'furniture','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(889261,'furniture','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(889262,'furniture','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(889263,'furniture','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(889264,'furniture','.w-compare .clear-compare-button','cursor','pointer','','','.w-compare'),(889265,'furniture','.w-compare .remove','cursor','pointer','','','.w-compare'),(889266,'furniture','.w-product-video .item img, .w-product-video .item video','cursor','pointer','','','.w-product-video'),(889267,'furniture','.w-product-properties-filters-widgets-chosen-filters .remove','cursor','pointer','','','.w-product-properties-filters-widgets-chosen-filters'),(889268,'furniture','.w-product-multi-inventory .radio-attributes input:checked + .option-item','cursor','default','','','.w-product-multi-inventory'),(889269,'furniture','.w-product-multi-inventory .radio-attributes .option-item','cursor','pointer','','','.w-product-multi-inventory'),(889270,'furniture','.b-products-listing .products-listing .radio-attributes .option','cursor','pointer','','','.b-products-listing'),(889271,'furniture','.b-products-listing .products-listing .radio-attributes input:checked + .option','cursor','default','','','.b-products-listing'),(889272,'furniture','.w-product-attributes .radio-attributes .option-item','cursor','pointer','','','.w-product-attributes'),(889273,'furniture','.w-product-attributes .radio-attributes input:checked + .option-item','cursor','default','','','.w-product-attributes'),(889274,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','cursor','pointer','','','.w-questionnaire-widgets-questionnaire'),(889275,'furniture','.w-product-designer-designer .prodDesignerType label','cursor','pointer','','','.w-product-designer-designer'),(889276,'furniture','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','cursor','pointer','','','.w-press-reviews-widgets-press-reviews-small'),(889277,'furniture','.w-support-system-filter .dd3-content .collapse_span','cursor','pointer','3','','.w-support-system-filter'),(889278,'furniture','.w-support-system-listing .pm-head-2','cursor','pointer','','','.w-support-system-listing'),(889279,'furniture','.order-summary .icon','cursor','pointer','','','.order-summary'),(889280,'furniture','.w-cart-discount-coupon .title','cursor','pointer','','','.w-cart-discount-coupon'),(889283,'furniture','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-order-pay'),(889284,'furniture','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-order-pay'),(889285,'furniture','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-sample-info'),(889286,'furniture','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-sample-info'),(889287,'furniture','.shopping-cart-index .gift-code .heading-4','cursor','pointer','5131','','.shopping-cart-index'),(889288,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','cursor','pointer','','','.b-multi-page-checkout'),(889289,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor_important','important','','','.b-switch'),(889290,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor_important','important','','','.b-switch'),(889291,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor_important','important','','','.b-switch'),(889292,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor_important','important','','','.b-switch'),(889293,'furniture','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(889294,'furniture','.b-switch .bootstrap-switch','direction','ltr','','','.b-switch'),(889295,'furniture','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(889296,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(889297,'furniture','.message.success','display','inline-block','3','',''),(889298,'furniture','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(889301,'furniture','.w-filters .mobileCollapse','display','inline-block','5140','','.w-filters'),(889302,'furniture','.p-quick-order-index ul.token-input-list','display','inline-block','','','.p-quick-order-index'),(889303,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.p-quick-order-index'),(889304,'furniture','.w-promotions .promo-salemaker .content a.name','display','block','','','.w-promotions'),(889305,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.p-quick-order-index'),(889306,'furniture','.w-promotions .prom-multi-discount .promo-range > div','display','inline-block','','','.w-promotions'),(889307,'furniture','.w-promotions .promo-salemaker','display','flex','','','.w-promotions'),(889308,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','display','inline-block','','','.w-promotions'),(889309,'furniture','.w-promotions .promo-date > div','display','inline-block','','','.w-promotions'),(889310,'furniture','.w-promotions .promo-cart-discount','display','flex','','','.w-promotions'),(889318,'furniture','.p-sample-checkout-success .page-success .text-1','display','block','3','','.p-sample-checkout-success'),(889319,'furniture','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(889320,'furniture','.w-promotions .prom-multi-discount','display','block','4','','.w-promotions'),(889321,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(889322,'furniture','.testimonials .review','display','block','3','',''),(889323,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(889324,'furniture','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(889325,'furniture','.w-categories .image','display','block','','','.w-categories'),(889326,'furniture','.w-promotions .prom-multi-discount .promo-range','display','inline-block','','','.w-promotions'),(889327,'furniture','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','display','block','','','.w-promotions'),(889328,'furniture','.w-promotions .prom-multi-discount .products','display','grid','','','.w-promotions'),(889329,'furniture','.w-promotions .prom-multi-discount .list','display','grid','','','.w-promotions'),(889330,'furniture','.w-promotions .nextdiscount .promo-for-each','display','inline-block','','','.w-promotions'),(889331,'furniture','.w-promotions .nextdiscount .item-holder','display','flex','','','.w-promotions'),(889332,'furniture','.w-promotions .nextdiscount .content','display','grid','','','.w-promotions'),(889333,'furniture','.w-promotions .heading-3','display','inline-block','','','.w-promotions'),(889334,'furniture','.w-promotions .icon','display','inline-block','','','.w-promotions'),(889335,'furniture','.w-promotions .promo-salemaker .discount','display','inline-block','','','.w-promotions'),(889336,'furniture','.w-promotions .promo-salemaker .content','display','flex','','','.w-promotions'),(889337,'furniture','.w-promotions .promo-content > .personalgift','display','none','','','.w-promotions'),(889338,'furniture','.w-promotions .promo-cart-discount .slave','display','flex','','','.w-promotions'),(889339,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','display','inline-block','','','.w-promotions'),(889340,'furniture','.w-promotions .promo-cart-discount .item a','display','block','','','.w-promotions'),(889341,'furniture','.w-promotions .promo-cart-discount .content','display','flex','','','.w-promotions'),(889342,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','display','inline-block','','','.b-warehouses-popup'),(889343,'furniture','.w-product-available-in-warehouses .content','display','block','4','','.w-product-available-in-warehouses'),(889344,'furniture','.b-preloader .preloader','display','inline-block','3','','.b-preloader'),(889345,'furniture','.w-product-available-in-warehouses .warehouse-item','display','inline-block','','','.w-product-available-in-warehouses'),(889346,'furniture','.b-products-listing .products-listing .mix-attributes','display','block','4','','.b-products-listing'),(889347,'furniture','.b-products-listing .products-listing .attribute-qty-blocks','display','flex','','','.b-products-listing'),(889349,'furniture','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(889350,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(889351,'furniture','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(889352,'furniture','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(889353,'furniture','.b-messages .messBtnMenuDelete','display','inline-block','3','','.b-messages'),(889354,'furniture','.b-messages .messMenuButton span','display','inline-block','','','.b-messages'),(889355,'furniture','.b-messages .msv_to_cc div span','display','inline-block','','','.b-messages'),(889356,'furniture','.b-messages span.starred::before','display','inline-block','','','.b-messages'),(889357,'furniture','.b-messages .dataTables_wrapper > .top','display','block','4','','.b-messages'),(889358,'furniture','.b-messages .messBtnMenuStarred','display','inline-block','3','','.b-messages'),(889359,'furniture','.b-messages .messBtnMenuUnread','display','inline-block','3','','.b-messages'),(889360,'furniture','.b-messages .messages-menu li a','display','block','','','.b-messages'),(889361,'furniture','.b-messages .content_management_attach button','display','inline-block','','','.b-messages'),(889362,'furniture','.b-messages .email-line','display','flex','','','.b-messages'),(889363,'furniture','.b-messages .dataTables_wrapper > .bottom','display','block','4','','.b-messages'),(889364,'furniture','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(889365,'furniture','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(889366,'furniture','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(889367,'furniture','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(889368,'furniture','.order-summary .price-row.ot_gv .title','display','inline-block','3','','.order-summary'),(889369,'furniture','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(889370,'furniture','.w-sitemap-delivery-location > ul > li > ul','display','flex','','','.w-sitemap-delivery-location'),(889371,'furniture','.w-checkout-terms .required-message-wrap','display','inline-block','','','.w-checkout-terms'),(889372,'furniture','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(889373,'furniture','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(889374,'furniture','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(889375,'furniture','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(889376,'furniture','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(889377,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','display','inline-block','','','.b-switch'),(889378,'furniture','.w-product-reviews .reviews-list .review','display','block','3','','.w-product-reviews'),(889379,'furniture','.b-info-popup .info-popup','display','inline-block','','','.b-info-popup'),(889380,'furniture','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(889381,'furniture','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(889382,'furniture','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(889383,'furniture','.p-quick-order-index .quick-order-total','display','flex','','','.p-quick-order-index'),(889384,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-details ~ div','display','none','','','.w-upload-customer-id-upload-customer-id-form'),(889385,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','display','flex','','','.w-upload-customer-id-upload-customer-id-form'),(889386,'furniture','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(889387,'furniture','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(889388,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(889389,'furniture','.w-checkout-bonus-points .btn-remove','display','inline-block','','','.w-checkout-bonus-points'),(889390,'furniture','.w-login-block .cols','display','block','4','','.w-login-block'),(889391,'furniture','.w-login-block .label','display','block','','','.w-login-block'),(889392,'furniture','.w-menu-horizontal li','display','inline-block','','','.w-menu-horizontal'),(889393,'furniture','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','display','inline-block','','','.w-menu-horizontal'),(889394,'furniture','.w-menu-horizontal li li a, .w-menu-horizontal li li .no-link','display','block','','','.w-menu-horizontal'),(889395,'furniture','.w-tabs .tab-navigation','display','table','','','.w-tabs'),(889396,'furniture','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(889397,'furniture','.b-form .payment-method .item-radio label','display','block','','','.b-form'),(889398,'furniture','.w-quote .cart-box-link','display','flex','','','.w-quote'),(889399,'furniture','.w-personal-gift-status-bar .inform','display','inline-block','4','','.w-personal-gift-status-bar'),(889400,'furniture','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(889403,'furniture','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(889404,'furniture','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(889405,'furniture','.w-promo-code .promo-text-2','display','none','5140','','.w-promo-code'),(889406,'furniture','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(889407,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(889408,'furniture','.b-switch .bootstrap-switch','display','inline-block','','','.b-switch'),(889409,'furniture','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(889410,'furniture','.w-social-links .name, .w-social-links .image','display','none','','','.w-social-links'),(889411,'furniture','.buttons','display','block','4','',''),(889412,'furniture','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(889413,'furniture','.w-login-block .label','display','block','','','.w-login-block'),(889414,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(889415,'furniture','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(889416,'furniture','.w-text .customer-service b','display','block','','','.w-text'),(889417,'furniture','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(889418,'furniture','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(889419,'furniture','.w-login-block .cols','display','block','4','','.w-login-block'),(889422,'furniture','.w-filters .input-checkbox:checked + .checkbox-span','display','inline-block','','','.w-filters'),(889423,'furniture','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(889424,'furniture','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(889425,'furniture','.b-switch .candlestick-wrapper','display','inline-block','','','.b-switch'),(889426,'furniture','.w-catalog-listing-look .listing-look-title','display','inline-block','','','.w-catalog-listing-look'),(889427,'furniture','.b-bottom .footerTitle ~ div','display','none','5131','','.b-bottom'),(889428,'furniture','.w-checkout-billing-address .genders-title > div','display','inline-block','','','.w-checkout-billing-address'),(889429,'furniture','.b-select-suggest .select2-display-none','display','none','','','.b-select-suggest'),(889430,'furniture','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(889431,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','3','','.b-select-suggest'),(889434,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','display','none','','','.b-select-suggest'),(889435,'furniture','.w-checkout-shipping-choice span','display','flex','','','.w-checkout-shipping-choice'),(889437,'furniture','.w-menu-big li a, .w-menu-big li .no-link','display','inline-block','','','.w-menu-big'),(889438,'furniture','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(889439,'furniture','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(889440,'furniture','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(889441,'furniture','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(889442,'furniture','.w-cart-compare .product','display','block','4','','.w-cart-compare'),(889443,'furniture','.w-top-categories .categories','display','block','4','','.w-top-categories'),(889444,'furniture','.w-top-categories .categories','display','flex','','','.w-top-categories'),(889445,'furniture','.b-info-popup .info-popup div','display','none','','','.b-info-popup'),(889446,'furniture','.w-checkout-billing-address .addresses','display','block','4','','.w-checkout-billing-address'),(889447,'furniture','.w-promo-code .promo-text-2','display','none','5140','','.w-promo-code'),(889448,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(889450,'furniture','.w-image-maps .default-links .item .description','display','block','','','.w-image-maps'),(889451,'furniture','.w-image-maps .float-items .item','display','block','1','','.w-image-maps'),(889452,'furniture','.w-image-maps .default-links .item .title','display','block','','','.w-image-maps'),(889453,'furniture','.b-upload-file .upload-file-template','display','inline-block','','','.b-upload-file'),(889454,'furniture','.w-checkout-shipping-address .addresses','display','block','4','','.w-checkout-shipping-address'),(889455,'furniture','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(889456,'furniture','.w-quote .cart-box-link','display','inline-block','3','','.w-quote'),(889457,'furniture','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(889458,'furniture','.w-multi-cart-actions .cart-actions .dropdown-toggle','display','inline-block','','','.w-multi-cart-actions'),(889459,'furniture','.w-tabs .tab-li.tab-wishlist a','display','block','3','','.w-tabs'),(889460,'furniture','.w-top-categories .item','display','inline-block','','','.w-top-categories'),(889461,'furniture','.w-text .customer-service b','display','block','','','.w-text'),(889462,'furniture','.w-tabs .tab-a','display','block','','','.w-tabs'),(889463,'furniture','.w-tabs > .block > .box .heading-2, .w-tabs > .block > .box .heading-3, .w-tabs > .block > .box .heading-4','display','none','','','.w-tabs'),(889464,'furniture','.w-tabs .tab-li','display','table-cell','','','.w-tabs'),(889465,'furniture','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(889467,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(889470,'furniture','.b-form .payment-method .item-radio label span','display','block','','','.b-form'),(889471,'furniture','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(889472,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','display','block','3','','.b-switch'),(889473,'furniture','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(889474,'furniture','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(889475,'furniture','.w-login-block .cols','display','block','4','','.w-login-block'),(889476,'furniture','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(889477,'furniture','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(889478,'furniture','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(889479,'furniture','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(889480,'furniture','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(889481,'furniture','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(889482,'furniture','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(889483,'furniture','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(889484,'furniture','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(889485,'furniture','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(889486,'furniture','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(889487,'furniture','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(889488,'furniture','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(889489,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','display','inline-block','','','.b-switch'),(889490,'furniture','.w-login-block .label','display','block','','','.w-login-block'),(889492,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(889493,'furniture','.w-filters .filter-widget-horizontal .content-filter-widget','display','table','','','.w-filters'),(889494,'furniture','.w-filters .filter-widget-horizontal .filter-box','display','table-cell','','','.w-filters'),(889495,'furniture','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(889496,'furniture','.b-products-listing .products-listing .bonus-points','display','flex','','','.b-products-listing'),(889497,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','display','inline-block','','','.b-switch'),(889498,'furniture','.w-checkout-shipping-address .genders-title label','display','inline-block','','','.w-checkout-shipping-address'),(889499,'furniture','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(889500,'furniture','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','display','inline-block','3','','.w-checkout-contact-information'),(889501,'furniture','.order-summary .price-row','display','none','','','.order-summary'),(889502,'furniture','.w-cart-bonus-points .btn-remove','display','inline-block','','','.w-cart-bonus-points'),(889503,'furniture','.w-cart-listing .points-earn','display','inline-block','','','.w-cart-listing'),(889504,'furniture','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(889505,'furniture','.w-text .customer-service b','display','block','','','.w-text'),(889506,'furniture','.w-multi-cart-actions .cart-actions','display','inline-block','','','.w-multi-cart-actions'),(889507,'furniture','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(889508,'furniture','.b-select-suggest .select2-container.select2-allowclear .select2-choice abbr','display','inline-block','','','.b-select-suggest'),(889509,'furniture','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(889510,'furniture','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(889512,'furniture','.w-reviews .item','display','grid','','','.w-reviews'),(889513,'furniture','.w-promo-code .holder','display','block','4','','.w-promo-code'),(889514,'furniture','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(889515,'furniture','.w-image-maps .default-links .item','display','block','1','','.w-image-maps'),(889517,'furniture','.w-checkout-shipping-choice input:checked + span:before','display','block','','','.w-checkout-shipping-choice'),(889519,'furniture','.w-checkout-create-account .columns .col-2:nth-child(2n)','display','none','5140','','.w-checkout-create-account'),(889520,'furniture','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(889521,'furniture','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(889522,'furniture','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(889523,'furniture','.w-top-categories .image','display','block','','','.w-top-categories'),(889524,'furniture','.w-cart-compare .delete-cart','display','inline-block','','','.w-cart-compare'),(889525,'furniture','.b-fancybox .fancybox-overlay','display','none','','','.b-fancybox'),(889526,'furniture','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(889527,'furniture','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(889528,'furniture','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(889529,'furniture','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(889530,'furniture','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(889531,'furniture','.w-list-b2b .attributes','display','block','4','','.w-list-b2b'),(889532,'furniture','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(889533,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(889534,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(889535,'furniture','.w-promo-code .holder','display','block','4','','.w-promo-code'),(889536,'furniture','.w-catalog-sorting .sorting','display','flex','','','.w-catalog-sorting'),(889537,'furniture','.w-promo-code .promo-text-2','display','none','5140','','.w-promo-code'),(889538,'furniture','.b-select-suggest .select2-container .select2-choice abbr','display','none','','','.b-select-suggest'),(889539,'furniture','.b-select-suggest .select2-container .select2-choice > .select2-chosen','display','block','','','.b-select-suggest'),(889540,'furniture','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(889541,'furniture','.b-select-suggest .select2-container .select2-choice','display','block','','','.b-select-suggest'),(889542,'furniture','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','display','list-item','','','.b-select-suggest'),(889543,'furniture','.b-select-suggest .select2-container','display','inline-block','','','.b-select-suggest'),(889544,'furniture','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(889545,'furniture','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(889546,'furniture','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(889547,'furniture','.w-checkout-shipping .sub-item','display','block','','','.w-checkout-shipping'),(889548,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','display','inline-block','','','.b-switch'),(889549,'furniture','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(889550,'furniture','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(889551,'furniture','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(889553,'furniture','.w-login-block .label','display','block','','','.w-login-block'),(889554,'furniture','.w-login-block .cols','display','block','4','','.w-login-block'),(889555,'furniture','.w-cart-shipping-estimator .item .row: after','display','block','','','.w-cart-shipping-estimator'),(889556,'furniture','.w-categories h2.name','display','block','','','.w-categories'),(889558,'furniture','.w-cart-compare .js-cart_totals_container b','display','block','','','.w-cart-compare'),(889559,'furniture','.b-form .middle-form .col-gender label','display','inline-block','','','.b-form'),(889560,'furniture','.b-form .login-cols','display','flex','','','.b-form'),(889561,'furniture','.b-form .payment-method .sub-item span','display','block','','','.b-form'),(889562,'furniture','.b-form .checkbox-style:checked + .checkbox-span','display','inline-block','','','.b-form'),(889563,'furniture','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(889566,'furniture','.w-cart-shipping-estimator .shipping-estimator','display','block','4','','.w-cart-shipping-estimator'),(889567,'furniture','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(889568,'furniture','.b-fancybox .fancybox-title-float-wrap .child','display','inline-block','','','.b-fancybox'),(889569,'furniture','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(889570,'furniture','.w-checkout-credit-amount .btn-remove','display','inline-block','','','.w-checkout-credit-amount'),(889571,'furniture','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(889572,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(889573,'furniture','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(889574,'furniture','.price .old','display','inline-block','','',''),(889575,'furniture','.w-tabs .tab-li.tab-cart a','display','block','3','','.w-tabs'),(889576,'furniture','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(889577,'furniture','.w-checkout-billing-address .genders-title label','display','inline-block','','','.w-checkout-billing-address'),(889578,'furniture','.w-personal-gift-status-bar .end-date','display','inline-block','3','','.w-personal-gift-status-bar'),(889579,'furniture','.w-top-categories h2.name','display','block','','','.w-top-categories'),(889580,'furniture','.w-promo-code .holder','display','block','4','','.w-promo-code'),(889581,'furniture','.w-image-maps .categories-items .item .description','display','block','','','.w-image-maps'),(889582,'furniture','.w-image-maps .categories-items .item .title','display','block','','','.w-image-maps'),(889583,'furniture','.w-quote .no-text','display','none','5140','','.w-quote'),(889584,'furniture','.b-info-popup .info-popup','display','inline-block','3','','.b-info-popup'),(889585,'furniture','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(889586,'furniture','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(889587,'furniture','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(889588,'furniture','.b-upload-files .attach-active-holder','display','block','','','.b-upload-files'),(889589,'furniture','.b-compare .compare_select_items','display','inline-block','','','.b-compare'),(889590,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display','inline-block','','','.b-switch'),(889591,'furniture','.b-form .middle-form label','display','block','','','.b-form'),(889592,'furniture','.b-form .form-inputs label > span','display','inline-block','','','.b-form'),(889593,'furniture','.w-checkout-shipping-address .edit-ab','display','inline-block','','','.w-checkout-shipping-address'),(889594,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(889595,'furniture','.w-cart-shipping-estimator .address-item .lastname','display','block','4','','.w-cart-shipping-estimator'),(889598,'furniture','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(889599,'furniture','.w-promo-code .promo-text-2','display','none','5140','','.w-promo-code'),(889600,'furniture','.b-form .addresses','display','block','4','','.b-form'),(889601,'furniture','.b-datepicker .picker-switch','display','none','','','.b-datepicker'),(889602,'furniture','.w-personal-gift-status-bar .timeline','display','flex','','','.w-personal-gift-status-bar'),(889603,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','display','block','','','.b-switch'),(889604,'furniture','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','display','inline-block','3','','.w-checkout-contact-information'),(889605,'furniture','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','display','inline-block','3','','.w-checkout-contact-information'),(889606,'furniture','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(889607,'furniture','.w-checkout-shipping-address .genders-title > div','display','inline-block','','','.w-checkout-shipping-address'),(889608,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span','display','inline-block','','','.b-form'),(889609,'furniture','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(889610,'furniture','.w-text .customer-service b','display','block','','','.w-text'),(889611,'furniture','.w-categories .categories','display','block','4','','.w-categories'),(889612,'furniture','.w-promo-code .holder','display','block','4','','.w-promo-code'),(889613,'furniture','.w-text .customer-service b','display','block','','','.w-text'),(889614,'furniture','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(889615,'furniture','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(889616,'furniture','.w-menu-big .hide-more.hide-more-disable, .w-menu-big .hide-more.hide-more-disable ~ li:not(.show-all)','display','block','','','.w-menu-big'),(889618,'furniture','.w-image-maps .categories-items .item','display','block','1','','.w-image-maps'),(889619,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(889620,'furniture','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(889621,'furniture','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(889622,'furniture','.w-checkout-billing-address .edit-ab','display','inline-block','','','.w-checkout-billing-address'),(889623,'furniture','.w-checkout-billing-address .addresses .address-item label','display','block','','','.w-checkout-billing-address'),(889624,'furniture','.w-checkout-shipping-choice #shippingchoice-choice','display','flex','','','.w-checkout-shipping-choice'),(889625,'furniture','.w-checkout-shipping-choice input','display','none','','','.w-checkout-shipping-choice'),(889626,'furniture','.w-cart-give-away h2','display','none','','','.w-cart-give-away'),(889627,'furniture','.w-promo-code .promo-text-2','display','none','5140','','.w-promo-code'),(889629,'furniture','.b-pass-strength .pass-strength','display','block','','','.b-pass-strength'),(889630,'furniture','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(889631,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display','inline-block','','','.b-switch'),(889632,'furniture','.w-quote .strong','display','block','','','.w-quote'),(889633,'furniture','.w-cart-up-sell h3','display','none','','','.w-cart-up-sell'),(889634,'furniture','.w-cart-compare .product-actions .dropdown-toggle','display','none','4','','.w-cart-compare'),(889635,'furniture','.b-select-suggest .select2-results li','display','list-item','','','.b-select-suggest'),(889636,'furniture','.b-select-suggest .select2-search-choice-close','display','block','','','.b-select-suggest'),(889637,'furniture','.b-select-suggest .select2-container.select2-container-disabled .select2-choice abbr','display','none','','','.b-select-suggest'),(889638,'furniture','.b-select-suggest .select2-more-results','display','list-item','','','.b-select-suggest'),(889639,'furniture','.b-select-suggest .select2-results .select2-selected','display','none','','','.b-select-suggest'),(889640,'furniture','.b-select-suggest .select2-results .select2-disabled','display','list-item','','','.b-select-suggest'),(889641,'furniture','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','display','list-item','','','.b-select-suggest'),(889642,'furniture','.w-menu-big .hide-more, .w-menu-big .hide-more ~ li:not(.show-all)','display','none','','','.w-menu-big'),(889643,'furniture','.w-checkout-shipping-address .change-ab','display','inline-block','','','.w-checkout-shipping-address'),(889644,'furniture','.w-checkout-shipping-address .addresses .address-item label','display','block','','','.w-checkout-shipping-address'),(889645,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','','','.b-select-suggest'),(889646,'furniture','.b-select-suggest .select2-search','display','inline-block','','','.b-select-suggest'),(889647,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow','display','inline-block','','','.b-select-suggest'),(889648,'furniture','.w-neighbour-checkout .text','display','inline-block','','','.w-neighbour-checkout'),(889649,'furniture','.w-text .customer-service b','display','block','','','.w-text'),(889650,'furniture','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(889651,'furniture','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(889652,'furniture','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(889653,'furniture','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(889655,'furniture','.w-menu-big > ul > li:hover > ul','display','block','','','.w-menu-big'),(889656,'furniture','.w-menu-big li li a, .w-menu-big li li .no-link','display','block','','','.w-menu-big'),(889658,'furniture','.w-menu-big li li li','display','block','','','.w-menu-big'),(889664,'furniture','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(889665,'furniture','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(889666,'furniture','.w-menu-horizontal ul li:hover > ul','display','block','','','.w-menu-horizontal'),(889667,'furniture','.w-menu-big li','display','inline-block','','','.w-menu-big'),(889669,'furniture','.w-cart-listing .points-redeem','display','inline-block','','','.w-cart-listing'),(889670,'furniture','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(889671,'furniture','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(889672,'furniture','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(889673,'furniture','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(889674,'furniture','.w-promo-code .holder','display','block','4','','.w-promo-code'),(889675,'furniture','.w-login-block .label','display','block','','','.w-login-block'),(889676,'furniture','.w-categories .item','display','inline-block','','','.w-categories'),(889677,'furniture','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(889678,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.b-data-table'),(889679,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.b-data-table'),(889681,'furniture','.w-communication-post .communication-post-author','display','flex','','','.w-communication-post'),(889682,'furniture','.b-products-listing .products-listing .compare label','display','inline','','','.b-products-listing'),(889683,'furniture','.b-products-listing .products-listing .compare','display','inline-block','','','.b-products-listing'),(889684,'furniture','.b-products-listing .BlockBox','display','block','4','','.b-products-listing'),(889685,'furniture','.b-products-listing .btn-preloader','display','inline-block','3','','.b-products-listing'),(889686,'furniture','.b-products-listing .hide','display','none','','','.b-products-listing'),(889687,'furniture','.b-products-listing .hover-box-content','display','none','','','.b-products-listing'),(889688,'furniture','.b-products-listing .hover-box:hover .hover-box-content','display','block','','','.b-products-listing'),(889689,'furniture','.b-products-listing .loader','display','inline-block','4','','.b-products-listing'),(889690,'furniture','.b-products-listing .products-listing .attribute-qty-block','display','flex','','','.b-products-listing'),(889691,'furniture','.b-products-listing .products-listing','display','block','4','','.b-products-listing'),(889692,'furniture','.b-products-listing .products-listing .btn-buy','display','inline-block','3','','.b-products-listing'),(889693,'furniture','.w-catalog-b2b-add-button ','display','none','','','.w-catalog-b2b-add-button'),(889694,'furniture','.b-products-listing .products-listing .item','display','inline-block','','','.b-products-listing'),(889695,'furniture','.b-products-listing .products-listing.align-left .item','display','block','','','.b-products-listing'),(889696,'furniture','.b-products-listing .products-listing.align-right .item','display','block','','','.b-products-listing'),(889697,'furniture','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','display','block','','','.b-products-listing'),(889698,'furniture','.b-products-listing .show-ofstock-products .headerStock','display','inline-block','','','.b-products-listing'),(889699,'furniture','.checkbox input','display','none','','',''),(889700,'furniture','.checkbox input + span','display','inline-block','','',''),(889707,'furniture','.b-rating .glyphicon','display','inline-block','','','.b-rating'),(889708,'furniture','.b-form .newsletter-row','display','block','4','','.b-form'),(889709,'furniture','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','display','block','','','.b-fancybox'),(889710,'furniture','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(889711,'furniture','.w-cart-credit-amount .btn-remove','display','inline-block','','','.w-cart-credit-amount'),(889713,'furniture','.w-login-block .label','display','block','','','.w-login-block'),(889714,'furniture','.w-coupons-and-vauchers-checkout .btn-remove','display','inline-block','','','.w-coupons-and-vauchers-checkout'),(889715,'furniture','.order-summary .price-row.ot_coupon .title','display','inline-block','3','','.order-summary'),(889716,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(889717,'furniture','.b-form .eye-password-wrap','display','block','','','.b-form'),(889718,'furniture','.w-taxable form','display','flex','','','.w-taxable'),(889719,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','display','inline-block','','',''),(889720,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','','','.w-communication-new-topic'),(889721,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','3','','.w-communication-new-topic'),(889722,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','display','inline-block','','','.w-communication-new-topic'),(889723,'furniture','.w-communication-new-topic .middle-form .col-2 label > span','display','block','','','.w-communication-new-topic'),(889724,'furniture','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(889725,'furniture','.w-tabs .tab-li.tab-quote a','display','block','3','','.w-tabs'),(889726,'furniture','.w-login-block .cols','display','block','4','','.w-login-block'),(889728,'furniture','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(889729,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(889730,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(889731,'furniture','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','display','inline-block','','','.b-form'),(889732,'furniture','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(889733,'furniture','.w-promo-code .holder','display','block','4','','.w-promo-code'),(889734,'furniture','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(889735,'furniture','.w-menu-horizontal ul ul','display','none','','','.w-menu-horizontal'),(889736,'furniture','.w-menu-horizontal ul ul li','display','block','','','.w-menu-horizontal'),(889737,'furniture','.w-catalog-listing-look .grid','display','inline-block','','','.w-catalog-listing-look'),(889738,'furniture','.w-catalog-listing-look .b2b','display','inline-block','','','.w-catalog-listing-look'),(889739,'furniture','.w-catalog-listing-look .list','display','inline-block','','','.w-catalog-listing-look'),(889740,'furniture','.w-catalog-items-on-page .items-on-page','display','flex','','','.w-catalog-items-on-page'),(889741,'furniture','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(889742,'furniture','.w-cart-listing .item .attributes > div','display','table-row','','','.w-cart-listing'),(889743,'furniture','.w-cart-listing .item .attributes span','display','table-cell','','','.w-cart-listing'),(889744,'furniture','.w-cart-listing .item .attributes','display','table','','','.w-cart-listing'),(889745,'furniture','.w-cart-listing .item .attributes strong','display','table-cell','','','.w-cart-listing'),(889746,'furniture','.w-cart-listing .item .gift-wrap label','display','flex','','','.w-cart-listing'),(889747,'furniture','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','display','block','','','.w-cart-listing'),(889748,'furniture','.w-cart-listing .headings','display','none','5140','','.w-cart-listing'),(889749,'furniture','.w-cart-listing .item .price *','display','inline-block','5140','','.w-cart-listing'),(889750,'furniture','.w-cart-listing .remove-btn span','display','inline-block','5140','','.w-cart-listing'),(889751,'furniture','.w-cart-give-away .ga_name','display','block','4','','.w-cart-give-away'),(889752,'furniture','.w-cart-discount-coupon .btn-remove','display','inline-block','','','.w-cart-discount-coupon'),(889765,'furniture','.w-image-maps .float-items .item .title','display','block','','','.w-image-maps'),(889766,'furniture','.w-image-maps .float-items .item .description','display','block','','','.w-image-maps'),(889767,'furniture','.w-image-maps .products-items .item-holder','display','block','1','','.w-image-maps'),(889768,'furniture','.w-image-maps .svg-wrap','display','inline-block','','','.w-image-maps'),(889769,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','display','none','','','.w-image-maps'),(889770,'furniture','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','display','inline-block','','','.b-compare'),(889771,'furniture','.w-tabs .accordion-heading','display','block','','','.w-tabs'),(889772,'furniture','.w-cart-shipping-estimator .item .row','display','block','','','.w-cart-shipping-estimator'),(889775,'furniture','.w-login-block .cols','display','block','4','','.w-login-block'),(889777,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(889778,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(889779,'furniture','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(889780,'furniture','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(889781,'furniture','.order-summary .price-row.ot_bonus_points .title','display','inline-block','3','','.order-summary'),(889782,'furniture','.w-cart-shipping-estimator .shipping-estimator .heading-2','display','none','','','.w-cart-shipping-estimator'),(889783,'furniture','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(889786,'furniture','.w-reviews-content .item','display','grid','','','.w-reviews-content'),(889787,'furniture','.b-info-popup .info-popup:hover div','display','block','','','.b-info-popup'),(889788,'furniture','.w-filters .content-filter-widget','display','none','5140','','.w-filters'),(889789,'furniture','.w-filters .fsl_handle','display','block','4','','.w-filters'),(889790,'furniture','.w-filters .filter-box-content ul li.view_items','display','block','','','.w-filters'),(889791,'furniture','.w-promo-code .promo-text-2','display','none','5140','','.w-promo-code'),(889792,'furniture','.w-taxable select','display','inline-block','','','.w-taxable'),(889793,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-container','display','inline-block','','','.b-switch'),(889794,'furniture','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(889795,'furniture','.w-tabs .tab-li.tab-sample a','display','block','3','','.w-tabs'),(889800,'furniture','.w-menu-big > ul > li > ul','display','none','','','.w-menu-big'),(889801,'furniture','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(889802,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','display','inline','','','.b-h-inline'),(889803,'furniture','.w-quote .no-text','display','inline-block','','','.w-quote'),(889804,'furniture','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(889806,'furniture','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(889807,'furniture','.w-filters .mobileCollapse','display','none','','','.w-filters'),(889808,'furniture','.w-filters .input-checkbox:not(checked) + .checkbox-span','display','inline-block','','','.w-filters'),(889809,'furniture','.b-product-images .media-popup .mp-big-images .item','display','flex','','','.b-product-images'),(889810,'furniture','.b-product-images .media-popup .mp-big-images .item + .item:not(.slick-slide)','display','none','','','.b-product-images'),(889811,'furniture','.b-product-images .media-popup .mp-small-images .item','display','inline-block','','','.b-product-images'),(889812,'furniture','.b-product-images .media-popup .mp-small-images img','display','inline-block','','','.b-product-images'),(889813,'furniture','.b-product-images .media-popup .slick-dots button','display','none','','','.b-product-images'),(889814,'furniture','.b-product-images .media-popup .slick-dots li','display','inline-block','','','.b-product-images'),(889815,'furniture','.b-menu-burger_icon .menu-style[data-burger_icon] .menu-content','display','none','','','.b-menu-burger_icon'),(889816,'furniture','.b-menu-burger_icon .bi-opened .menu-style[data-burger_icon] .menu-content','display','block','','','.b-menu-burger_icon'),(889817,'furniture','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','display','block','','','.b-menu-burger_icon'),(889818,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','display','block','','','.b-menu-lev_display-slide'),(889819,'furniture','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','display','block','','','.b-menu-lev_display-slide'),(889820,'furniture','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','display','block','','','.b-menu-lev_display-slide'),(889821,'furniture','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','display','block','','','.b-menu-lev_display-slide'),(889822,'furniture','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','display','block','','','.b-menu-lev_display-slide'),(889823,'furniture','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(889824,'furniture','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(889825,'furniture','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(889826,'furniture','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(889827,'furniture','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(889828,'furniture','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(889829,'furniture','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(889830,'furniture','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(889831,'furniture','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(889832,'furniture','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(889833,'furniture','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(889834,'furniture','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(889835,'furniture','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-2','display','none','','','.b-menu-lev_vis'),(889836,'furniture','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(889837,'furniture','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-3','display','none','','','.b-menu-lev_vis'),(889838,'furniture','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(889839,'furniture','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-4','display','none','','','.b-menu-lev_vis'),(889840,'furniture','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(889841,'furniture','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-5','display','none','','','.b-menu-lev_vis'),(889842,'furniture','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(889843,'furniture','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-6','display','none','','','.b-menu-lev_vis'),(889844,'furniture','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(889845,'furniture','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(889846,'furniture','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-2','display','none','','','.b-menu-lev_vis'),(889847,'furniture','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(889848,'furniture','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-3','display','none','','','.b-menu-lev_vis'),(889849,'furniture','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(889850,'furniture','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-4','display','none','','','.b-menu-lev_vis'),(889851,'furniture','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(889852,'furniture','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-5','display','none','','','.b-menu-lev_vis'),(889853,'furniture','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(889854,'furniture','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-6','display','none','','','.b-menu-lev_vis'),(889855,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(889856,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(889857,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-3','display','none','','','.b-menu-lev_vis-click_icon'),(889858,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(889859,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-4','display','none','','','.b-menu-lev_vis-click_icon'),(889860,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(889861,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-5','display','none','','','.b-menu-lev_vis-click_icon'),(889862,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(889863,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-6','display','none','','','.b-menu-lev_vis-click_icon'),(889864,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display','block','','','.b-menu-open_from-left'),(889865,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul','display','flex','','','.b-menu-position'),(889866,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(889867,'furniture','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display','none','','','.b-menu-style'),(889868,'furniture','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display','none','','','.b-menu-style'),(889869,'furniture','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display','none','','','.b-menu-style'),(889870,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','display','block','','','.b-menu-style-2'),(889871,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','display','block','','','.b-menu-style-2'),(889872,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','display','flex','','','.b-menu-style-2'),(889873,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .languages','display','flex','','','.b-menu-style-2'),(889874,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','display','block','','','.b-menu-style-2'),(889875,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies','display','flex','','','.b-menu-style-2'),(889876,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','display','flex','','','.b-menu-style-2'),(889877,'furniture','.b-trade-approval .steps-bar','display','table','','','.b-trade-approval'),(889878,'furniture','.b-trade-approval .steps-bar li','display','table-cell','','','.b-trade-approval'),(889879,'furniture','.b-trade-approval .steps-bar li a','display','block','','','.b-trade-approval'),(889880,'furniture','.b-trade-approval .middle-form label','display','block','','','.b-trade-approval'),(889881,'furniture','.b-trade-approval .columns','display','block','4','','.b-trade-approval'),(889882,'furniture','.w-account-personal-catalog .list-switcher','display','flex','','','.w-account-personal-catalog'),(889883,'furniture','.w-account-subscription .send-email','display','block','','','.w-account-subscription'),(889884,'furniture','.w-account-subscription .subscription-variant','display','flex','','','.w-account-subscription'),(889885,'furniture','.w-catalog-additional-images li','display','inline-block','','','.w-catalog-additional-images'),(889886,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','display','inline-block','3','','.w-catalog-compare'),(889887,'furniture','.w-catalog-compare td span','display','inline','','','.w-catalog-compare'),(889888,'furniture','.w-catalog-compare .product-listing','display','flex','','','.w-catalog-compare'),(889889,'furniture','.w-catalog-compare .promos-info','display','none','','','.w-catalog-compare'),(889890,'furniture','.w-catalog-compare .item .compare a','display','none','','','.w-catalog-compare'),(889891,'furniture','.w-catalog-compare .cross-box .different-all','display','flex','','','.w-catalog-compare'),(889892,'furniture','.w-catalog-compare .cross-box','display','flex','','','.w-catalog-compare'),(889893,'furniture','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','display','block','','','.w-delivery-day'),(889894,'furniture','.w-delivery-day .time-left','display','flex','','','.w-delivery-day'),(889895,'furniture','.w-delivery-day .left-count','display','block','','','.w-delivery-day'),(889896,'furniture','.w-delivery-day .left-text-left','display','block','','','.w-delivery-day'),(889897,'furniture','.w-delivery-day .left-text-right','display','block','','','.w-delivery-day'),(889898,'furniture','.w-product-images .img-holder','display','flex','','','.w-product-images'),(889899,'furniture','.w-product-images .additional-vertical','display','flex','','','.w-product-images'),(889900,'furniture','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','display','inline-block','','','.b-cookie-notice'),(889904,'furniture','.b-products-listing .products-listing .item picture','display','block','','','.b-products-listing'),(889905,'furniture','.b-slick .slick-slide','display','none','','','.b-slick'),(889906,'furniture','.b-slick .slick-arrow.slick-hidden','display','none','','','.b-slick'),(889907,'furniture','.b-slick .slick-initialized .slick-slide','display','block','','','.b-slick'),(889908,'furniture','.b-slick .slick-list','display','block','','','.b-slick'),(889909,'furniture','.b-slick .slick-slide img','display','block','','','.b-slick'),(889910,'furniture','.b-slick .slick-slide.slick-loading img','display','none','','','.b-slick'),(889911,'furniture','.b-slick .slick-slider','display','block','','','.b-slick'),(889912,'furniture','.b-slick .slick-track','display','block','','','.b-slick'),(889913,'furniture','.b-slick .slick-track, .b-slick .slick-track:after','display','table','3','','.b-slick'),(889914,'furniture','.b-slick .slick-vertical .slick-slide','display','block','','','.b-slick'),(889920,'furniture','.menu-header .burger-icon','display','inline-block','5140','','.menu-header'),(889921,'furniture','.w-cart-listing .item, .w-cart-listing .headings','display','grid','','','.w-cart-listing'),(889922,'furniture','.b-products-listing .save-price-box','display','none','','','.b-products-listing'),(889923,'furniture','.b-products-listing .products-listing a.btn.view-button','display','block','3','','.b-products-listing'),(889924,'furniture','.b-products-listing .add-to-personal-catalog','display','block','3','','.b-products-listing'),(889925,'furniture','.b-products-listing .products-listing .compare input + span','display','block','','','.b-products-listing'),(889926,'furniture','.b-products-listing .products-listing .item:hover .item-nav','display','block','','','.b-products-listing'),(889927,'furniture','.LeftCategories .level-2','display','none','','','.LeftCategories'),(889928,'furniture','.LeftCategories .w-menu-simple ul li a','display','block','','','.LeftCategories'),(889929,'furniture','.b-products-listing .products-listing.list-productlisting .item-content','display','block','4','','.b-products-listing'),(889930,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','display','none','','','.b-products-listing'),(889931,'furniture','.b-products-listing .products-listing.slick-slider .item-nav','display','none','','','.b-products-listing'),(889932,'furniture','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','display','none','4','','.b-products-listing'),(889933,'furniture','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(889934,'furniture','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(889935,'furniture','.w-subscribers .sb_ta','display','flex','','','.w-subscribers'),(889936,'furniture','.w-subscribers .btn-submit','display','block','','','.w-subscribers'),(889937,'furniture','.w-quote .multicart .current-text','display','block','','','.w-quote'),(889938,'furniture','.w-quote .multicart .item','display','block','','','.w-quote'),(889939,'furniture','.w-quote .multicart .name','display','block','','','.w-quote'),(889940,'furniture','.w-quote .multicart .sub-total-row','display','block','','','.w-quote'),(889941,'furniture','.w-quote .multicart .title','display','inline-block','','','.w-quote'),(889942,'furniture','.w-quote .name','display','block','','','.w-quote'),(889943,'furniture','.w-quote .price','display','block','','','.w-quote'),(889944,'furniture','.w-quote a.item','display','block','4','','.w-quote'),(889945,'furniture','.w-quote a.item','display','block','','','.w-quote'),(889946,'furniture','.w-quote .cart-box-link','display','none','5140,4','','.w-quote'),(889947,'furniture','.w-social-links a','display','inline-block','','','.w-social-links'),(889948,'furniture','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(889949,'furniture','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(889950,'furniture','.b-products-listing .rating, .b-products-listing .ratingCounts','display','inline-block','','','.b-products-listing'),(889951,'furniture','.rating, .ratingCounts','display','inline-block','','',''),(889952,'furniture','.b-products-listing .promos-info .promo-item','display','flex','','','.b-products-listing'),(889953,'furniture','.w-product-sale-ends .left-count','display','block','','','.w-product-sale-ends'),(889954,'furniture','.w-product-sale-ends .left-count-days','display','block','','','.w-product-sale-ends'),(889955,'furniture','.w-product-sale-ends .left-count-hours','display','block','','','.w-product-sale-ends'),(889956,'furniture','.w-product-sale-ends .left-text-left','display','block','','','.w-product-sale-ends'),(889957,'furniture','.w-product-sale-ends .left-text-right','display','block','','','.w-product-sale-ends'),(889958,'furniture','h1, .heading-1','display','inline-block','3','',''),(889959,'furniture','h1, .heading-1','display','inline-block','4','',''),(889960,'furniture','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','display','inline-block','3','','.w-product-buttons'),(889961,'furniture','.w-product-quantity .product-quantity-label','display','none','','','.w-product-quantity'),(889962,'furniture','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(889963,'furniture','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(889964,'furniture','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(889965,'furniture','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(889966,'furniture','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(889967,'furniture','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(889968,'furniture','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(889969,'furniture','.w-product-bonus-points > div','display','block','4','','.w-product-bonus-points'),(889970,'furniture','.w-product-personal-catalog-button .btn','display','block','3','','.w-product-personal-catalog-button'),(889971,'furniture','.warrantyProduct .warranty','display','inline-block','3','','.warrantyProduct'),(889972,'furniture','.warrantyProduct .delivery','display','inline-block','3','','.warrantyProduct'),(889973,'furniture','.w-compare .compare-button','display','block','','','.w-compare'),(889974,'furniture','.w-files-catalog-widgets-files-catalog ','display','flex','','','.w-files-catalog-widgets-files-catalog'),(889975,'furniture','.w-files-catalog-widgets-files-catalog .image','display','flex','','','.w-files-catalog-widgets-files-catalog'),(889976,'furniture','.w-files-catalog-widgets-files-catalog .item','display','flex','','','.w-files-catalog-widgets-files-catalog'),(889977,'furniture','.w-files-catalog-widgets-files-catalog picture','display','inline-block','','','.w-files-catalog-widgets-files-catalog'),(889978,'furniture','.w-sample .cart-box-link','display','inline-block','4','','.w-sample'),(889979,'furniture','.w-sample .cart-box-link','display','flex','','','.w-sample'),(889980,'furniture','.w-sample .cart-box-link','display','inline-block','3','','.w-sample'),(889981,'furniture','.w-sample .cart-box-link .strong','display','none','','','.w-sample'),(889982,'furniture','.w-sample .multicart .current-text','display','block','','','.w-sample'),(889983,'furniture','.w-sample .multicart .item','display','block','','','.w-sample'),(889984,'furniture','.w-sample .multicart .name','display','block','','','.w-sample'),(889985,'furniture','.w-sample .multicart .sub-total-row','display','block','','','.w-sample'),(889986,'furniture','.w-sample .multicart .title','display','inline-block','','','.w-sample'),(889987,'furniture','.w-sample .name','display','block','','','.w-sample'),(889988,'furniture','.w-sample .no-text','display','inline-block','','','.w-sample'),(889989,'furniture','.w-sample .price','display','block','','','.w-sample'),(889990,'furniture','.w-sample .strong','display','block','','','.w-sample'),(889991,'furniture','.w-sample a.item','display','block','4','','.w-sample'),(889992,'furniture','.w-sample a.item','display','block','','','.w-sample'),(889993,'furniture','.w-sample .cart-box-link','display','none','5140,4','','.w-sample'),(889994,'furniture','.w-sample .no-text','display','none','5140','','.w-sample'),(889995,'furniture','.w-quote .cart-box.hover-box .cart-content','display','none','','','.w-quote'),(889996,'furniture','.w-quote .cart-box.hover-box:hover .cart-content','display','block','','','.w-quote'),(889997,'furniture','.w-sample .cart-box .cart-content','display','none','','','.w-sample'),(889998,'furniture','.w-sample .cart-box:hover .cart-content','display','block','','','.w-sample'),(889999,'furniture','.w-filters-simple .filter-row','display','flex','','','.w-filters-simple'),(890000,'furniture','.w-filters-simple .integrate-price-holder > div','display','inline-block','','','.w-filters-simple'),(890001,'furniture','.w-cart-listing .points-earn','display','inline-block','4','','.w-cart-listing'),(890002,'furniture','.w-cart-discount-coupon .inp','display','none','','','.w-cart-discount-coupon'),(890003,'furniture','.w-cart-sub-total .price-row','display','flex','','','.w-cart-sub-total'),(890004,'furniture','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(890005,'furniture','.w-cart-gift-certificate .input-apple','display','flex','','','.w-cart-gift-certificate'),(890006,'furniture','.w-cart-order-reference .input-apple','display','flex','','','.w-cart-order-reference'),(890007,'furniture','.w-product-attributes .radio-attributes > span','display','block','','','.w-product-attributes'),(890008,'furniture','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(890009,'furniture','.w-product-bundle .bundle-products','display','flex','','','.w-product-bundle'),(890010,'furniture','.w-product-bundle .bundle-total-price .title, .w-product-bundle .bundle-total-price .price','display','inline-block','','','.w-product-bundle'),(890011,'furniture','.w-product-in-bundles .bundle-products','display','flex','','','.w-product-in-bundles'),(890012,'furniture','.w-product-in-bundles .bundle-total-price .title, .w-product-in-bundles .bundle-total-price .price','display','inline-block','','','.w-product-in-bundles'),(890013,'furniture','.w-product-quantity-discounts .count','display','inline-block','','','.w-product-quantity-discounts'),(890014,'furniture','.w-catalog-additional-images picture','display','flex','','','.w-catalog-additional-images'),(890015,'furniture','.w-sample-products .price','display','none','','','.w-sample-products'),(890018,'furniture','.heading-2','display','inline-block','3','',''),(890019,'furniture','.heading-2','display','inline-block','4','',''),(890020,'furniture','.b-products-listing .products-listing .radio-attributes','display','block','4','','.b-products-listing'),(890021,'furniture','.b-pagination .pagination','display','block','4','','.b-pagination'),(890022,'furniture','.b-pagination .pagination .next-pages','display','inline-block','','','.b-pagination'),(890023,'furniture','.b-pagination .pagination .page-number','display','inline-block','','','.b-pagination'),(890024,'furniture','.b-pagination .pagination .paging','display','inline-block','','','.b-pagination'),(890025,'furniture','.b-pagination .pagination .prev-pages','display','inline-block','','','.b-pagination'),(890026,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','display','inline-block','','','.b-pagination'),(890027,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','display','inline-block','','','.b-pagination'),(890028,'furniture','.b-pagination .pagination span','display','inline-block','2','','.b-pagination'),(890029,'furniture','.b-pagination ul.pagination li','display','inline-block','','','.b-pagination'),(890030,'furniture','.w-product-multi-inventory .select-box:last-of-type:after','display','block','','','.w-product-multi-inventory'),(890031,'furniture','.w-product-properties-filters-widgets-chosen-filters .item','display','inline-block','','','.w-product-properties-filters-widgets-chosen-filters'),(890032,'furniture','.w-product-multi-inventory .radio-attributes > label','display','block','','','.w-product-multi-inventory'),(890033,'furniture','.w-cart-listing .no-price .price','display','none','','','.w-cart-listing'),(890034,'furniture','.w-product-multi-inventory #product-attributes','display','block','4','','.w-product-multi-inventory'),(890035,'furniture','.p-quote-checkout-index .heading-2','display','none','3','','.p-quote-checkout-index'),(890036,'furniture','.p-quote-checkout-index .heading-2','display','none','4','','.p-quote-checkout-index'),(890037,'furniture','.p-sample-checkout-index .heading-2','display','none','3','','.p-sample-checkout-index'),(890038,'furniture','.p-sample-checkout-index .heading-2','display','none','4','','.p-sample-checkout-index'),(890039,'furniture','.p-quote-checkout-index .order-summary .heading-2','display','inline-block','3','','.p-quote-checkout-index'),(890040,'furniture','.p-quote-checkout-index .order-summary .heading-2','display','inline-block','4','','.p-quote-checkout-index'),(890041,'furniture','.p-sample-checkout-index .order-summary .heading-2','display','inline-block','3','','.p-sample-checkout-index'),(890042,'furniture','.p-sample-checkout-index .order-summary .heading-2','display','inline-block','4','','.p-sample-checkout-index'),(890045,'furniture','.w-product-multi-inventory .radio-attributes > span','display','block','','','.w-product-multi-inventory'),(890046,'furniture','.w-quote-products .cart-listing .price','display','none','','','.w-quote-products'),(890047,'furniture','.w-product-multi-inventory .radio-attributes .option-item','display','inline-block','','','.w-product-multi-inventory'),(890048,'furniture','.w-product-multi-inventory .radio-attributes > label input','display','none','','','.w-product-multi-inventory'),(890049,'furniture','.w-product-multi-inventory .radio-attributes','display','block','4','','.w-product-multi-inventory'),(890050,'furniture','.w-account-personal-catalog .headings','display','none','','','.w-account-personal-catalog'),(890051,'furniture','.w-account-personal-catalog .list-row-action','display','flex','','','.w-account-personal-catalog'),(890052,'furniture','.w-account-personal-catalog .list-row-action a','display','block','','','.w-account-personal-catalog'),(890053,'furniture','.w-product-quantity-discounts .quantity-discounts','display','block','4','','.w-product-quantity-discounts'),(890054,'furniture','h1, .heading-1','display','none','5140,3','',''),(890055,'furniture','h1, .heading-1','display','none','5140,4','',''),(890056,'furniture','.w-account-personal-catalog .buy-box','display','flex','5131','','.w-account-personal-catalog'),(890057,'furniture','.w-filters .handle_tit','display','block','5145','','.w-filters'),(890058,'furniture','.b-products-listing .products-listing .radio-attributes .option','display','inline-block','','','.b-products-listing'),(890059,'furniture','.b-products-listing .products-listing .radio-attributes > label','display','block','','','.b-products-listing'),(890060,'furniture','.b-products-listing .products-listing .radio-attributes > label input','display','none','','','.b-products-listing'),(890061,'furniture','.b-products-listing .products-listing .radio-attributes > span','display','block','','','.b-products-listing'),(890062,'furniture','.b-products-listing .products-listing .radio-attributes .item-title','display','block','','','.b-products-listing'),(890063,'furniture','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(890064,'furniture','.w-product-collection .together','display','block','','','.w-product-collection'),(890065,'furniture','.w-product-collection .right-area .btn','display','inline-block','3','','.w-product-collection'),(890066,'furniture','.w-product-collection .right-area .btn-2','display','inline-block','3','','.w-product-collection'),(890067,'furniture','.price .special-promote','display','block','','',''),(890068,'furniture','.w-product-attributes #product-attributes','display','block','4','','.w-product-attributes'),(890069,'furniture','.w-product-attributes .radio-attributes','display','block','4','','.w-product-attributes'),(890070,'furniture','.w-product-attributes .radio-attributes .option-item','display','inline-block','','','.w-product-attributes'),(890071,'furniture','.w-product-attributes .radio-attributes > label','display','block','','','.w-product-attributes'),(890072,'furniture','.w-product-attributes .radio-attributes > label input','display','none','','','.w-product-attributes'),(890073,'furniture','.w-product-attributes .select-box:last-of-type:after','display','block','','','.w-product-attributes'),(890074,'furniture','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(890075,'furniture','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(890076,'furniture','.w-product-properties li','display','table-cell','','','.w-product-properties'),(890077,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','display','block','','','.w-questionnaire-widgets-questionnaire'),(890078,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no label','display','inline','','','.w-questionnaire-widgets-questionnaire'),(890079,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no','display','flex','','','.w-questionnaire-widgets-questionnaire'),(890080,'furniture','.w-product-groups .property-category-heading','display','none','','','.w-product-groups'),(890081,'furniture','.w-product-groups .radioBox label','display','block','','','.w-product-groups'),(890082,'furniture','.w-product-groups .radioBox label .containerBlock','display','block','','','.w-product-groups'),(890083,'furniture','.w-product-groups .prop-group-swatch','display','block','4','','.w-product-groups'),(890084,'furniture','.b-products-listing .mix-attributes .mult-qty-input .qty-box','display','block','','','.b-products-listing'),(890085,'furniture','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(890086,'furniture','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(890087,'furniture','.w-product-custom-bundle .right-area .separate-text','display','block','','','.w-product-custom-bundle'),(890088,'furniture','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','display','inline-block','3','','.w-product-custom-bundle'),(890089,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list'),(890090,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list-block'),(890091,'furniture','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(890092,'furniture','.w-delivery-location-location-list .deliveryListParrent a','display','inline-block','','','.w-delivery-location-location-list'),(890093,'furniture','.w-delivery-location-location-list .deliveryList li a','display','block','','','.w-delivery-location-location-list'),(890094,'furniture','.w-delivery-location-featured-list .deliveryList ul','display','block','4','','.w-delivery-location-featured-list'),(890095,'furniture','.w-sale-category .btn','display','block','','','.w-sale-category'),(890096,'furniture','.w-sale-category .left-count','display','block','','','.w-sale-category'),(890097,'furniture','.w-sale-category .left-count-days','display','block','','','.w-sale-category'),(890098,'furniture','.w-sale-category .left-count-hours','display','block','','','.w-sale-category'),(890099,'furniture','.w-sale-category .left-text-left','display','block','','','.w-sale-category'),(890100,'furniture','.w-sale-category .left-text-right','display','block','','','.w-sale-category'),(890101,'furniture','.w-sale-category .special-price','display','block','','','.w-sale-category'),(890102,'furniture','.w-sale-category .special-price-text','display','none','','','.w-sale-category'),(890103,'furniture','.w-sale-category .text','display','block','','','.w-sale-category'),(890104,'furniture','.w-success-download table td','display','block','5161','','.w-success-download'),(890105,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list-by-catalog'),(890106,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(890107,'furniture','.w-delivery-location-list-by-page .page-list','display','block','4','','.w-delivery-location-list-by-page'),(890108,'furniture','.w-delivery-location-top-location-list .deliveryList','display','block','4','','.w-delivery-location-top-location-list'),(890109,'furniture','.w-product-properties-icons ','display','flex','','','.w-product-properties-icons'),(890110,'furniture','.w-product-properties-icons .hover-box-content','display','inline-block','','','.w-product-properties-icons'),(890111,'furniture','.w-product-properties-icons .hover-box','display','block','','','.w-product-properties-icons'),(890112,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','display','inline-block','','','.w-product-properties-icons'),(890113,'furniture','.w-delivery-location-cross-pages .page-list','display','block','4','','.w-delivery-location-cross-pages'),(890114,'furniture','.w-cart-listing .price br','display','none','','','.w-cart-listing'),(890115,'furniture','.w-delivery-location-product-categories .categories','display','flex','','','.w-delivery-location-product-categories'),(890116,'furniture','.w-delivery-location-product-categories .item.category-link','display','block','','','.w-delivery-location-product-categories'),(890117,'furniture','.delivery-options-popup','display','block','4','',''),(890118,'furniture','.w-product-bonus-points .bonus-points-cost','display','inline-block','','','.w-product-bonus-points'),(890119,'furniture','.w-product-designer-designer .groupNamePrDes','display','none','','','.w-product-designer-designer'),(890120,'furniture','.w-product-designer-designer .grnamebox .title-sortable','display','block','','','.w-product-designer-designer'),(890121,'furniture','.w-product-designer-designer .prodDesignerType','display','flex','','','.w-product-designer-designer'),(890122,'furniture','.w-press-reviews-widgets-press-reviews .image a','display','block','','','.w-press-reviews-widgets-press-reviews'),(890123,'furniture','.w-press-reviews-widgets-press-reviews .item','display','block','','','.w-press-reviews-widgets-press-reviews'),(890124,'furniture','.w-press-reviews-widgets-press-reviews .review-box','display','flex','','','.w-press-reviews-widgets-press-reviews'),(890125,'furniture','.w-press-reviews-widgets-press-reviews .title a','display','block','','','.w-press-reviews-widgets-press-reviews'),(890126,'furniture','.w-press-reviews-widgets-press-reviews-list .item','display','flex','','','.w-press-reviews-widgets-press-reviews-list'),(890127,'furniture','.w-press-reviews-widgets-press-reviews-list .review-box','display','flex','','','.w-press-reviews-widgets-press-reviews-list'),(890128,'furniture','.b-products-listing .productGroup label','display','inline-block','','','.b-products-listing'),(890129,'furniture','.b-products-listing .productGroup label a','display','block','','','.b-products-listing'),(890130,'furniture','.w-gift-wrap-message-checkout .max-counter, .w-gift-wrap-message-checkout .max-words','display','inline-block','','','.w-gift-wrap-message-checkout'),(890131,'furniture','.w-communication-post .btn.refresh input','display','none','','','.w-communication-post'),(890132,'furniture','.w-rma-returns-history .column','display','flex','','','.w-rma-returns-history'),(890133,'furniture','.w-rma-returns-history .column .fromTo','display','flex','','','.w-rma-returns-history'),(890134,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','display','inline-block','','','.w-rma-returns-history'),(890135,'furniture','.w-rma-returns-history .filterMessages','display','flex','','','.w-rma-returns-history'),(890136,'furniture','.w-rma-returns-history .fromTo label','display','inline-block','','','.w-rma-returns-history'),(890137,'furniture','.w-rma-returns-history .fromTo label >span','display','block','','','.w-rma-returns-history'),(890138,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul','display','flex','','','.b-menu-position'),(890139,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(890140,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul','display','flex','','','.b-menu-position'),(890141,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(890142,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul','display','flex','','','.b-menu-position'),(890143,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(890144,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > ul','display','none','','','.b-menu-lev_vis-click_icon'),(890145,'furniture','.w-show-inactive-show-inactive .out_stock_wrap','display','flex','','','.w-show-inactive-show-inactive'),(890146,'furniture','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(890147,'furniture','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(890148,'furniture','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(890149,'furniture','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(890150,'furniture','.w-product-configurator .item-content','display','block','5131','','.w-product-configurator'),(890151,'furniture','.w-product-configurator .item-content > div','display','block','5131','','.w-product-configurator'),(890152,'furniture','.w-product-configurator .pc-item label','display','block','','','.w-product-configurator'),(890153,'furniture','.b-products-listing .products-listing .bonus-points-cost','display','inline-block','','','.b-products-listing'),(890154,'furniture','.b-products-listing .promo-icon','display','inline-block','','','.b-products-listing'),(890155,'furniture','.b-products-listing .promos-info .promo-name','display','inline-block','','','.b-products-listing'),(890156,'furniture','.b-products-listing .promos-info .promo-name-span','display','block','','','.b-products-listing'),(890157,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-list'),(890158,'furniture','.w-predefined-promotion .heading-3','display','inline-block','','','.w-predefined-promotion'),(890159,'furniture','.w-predefined-promotion .icon','display','inline-block','','','.w-predefined-promotion'),(890160,'furniture','.w-predefined-promotion .nextdiscount .content','display','grid','','','.w-predefined-promotion'),(890161,'furniture','.w-predefined-promotion .nextdiscount .item-holder','display','flex','','','.w-predefined-promotion'),(890162,'furniture','.w-predefined-promotion .nextdiscount .promo-for-each','display','inline-block','','','.w-predefined-promotion'),(890163,'furniture','.w-predefined-promotion .prom-multi-discount','display','block','4','','.w-predefined-promotion'),(890164,'furniture','.w-predefined-promotion .prom-multi-discount .list','display','grid','','','.w-predefined-promotion'),(890165,'furniture','.w-predefined-promotion .prom-multi-discount .products','display','grid','','','.w-predefined-promotion'),(890166,'furniture','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','display','block','','','.w-predefined-promotion'),(890167,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','display','inline-block','','','.w-predefined-promotion'),(890168,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range > div','display','inline-block','','','.w-predefined-promotion'),(890169,'furniture','.w-predefined-promotion .promo-cart-discount','display','flex','','','.w-predefined-promotion'),(890170,'furniture','.w-predefined-promotion .promo-cart-discount .content','display','flex','','','.w-predefined-promotion'),(890171,'furniture','.w-predefined-promotion .promo-cart-discount .item a','display','block','','','.w-predefined-promotion'),(890172,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','display','inline-block','','','.w-predefined-promotion'),(890173,'furniture','.w-predefined-promotion .promo-cart-discount .slave','display','flex','','','.w-predefined-promotion'),(890174,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','display','inline-block','','','.w-predefined-promotion'),(890175,'furniture','.w-predefined-promotion .promo-content > .personalgift','display','none','','','.w-predefined-promotion'),(890176,'furniture','.w-predefined-promotion .promo-date > div','display','inline-block','','','.w-predefined-promotion'),(890177,'furniture','.w-predefined-promotion .promo-salemaker','display','flex','','','.w-predefined-promotion'),(890178,'furniture','.w-predefined-promotion .promo-salemaker .content','display','flex','','','.w-predefined-promotion'),(890179,'furniture','.w-predefined-promotion .promo-salemaker .content a.name','display','block','','','.w-predefined-promotion'),(890180,'furniture','.w-predefined-promotion .promo-salemaker .discount','display','inline-block','','','.w-predefined-promotion'),(890181,'furniture','.w-supplier-purchase-supplier-products .item','display','flex','','','.w-supplier-purchase-supplier-products'),(890182,'furniture','.w-supplier-purchase-supplier-products .qty_col','display','flex','','','.w-supplier-purchase-supplier-products'),(890183,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','display','inline-block','','','.w-filters'),(890184,'furniture','.mainBanner .bottomBox .elf','display','block','','','.mainBanner'),(890185,'furniture','.mainBanner .buttonBox','display','block','4','','.mainBanner'),(890186,'furniture','.mainBanner .title','display','inline-block','3','','.mainBanner'),(890187,'furniture','.mainBanner .title','display','inline-block','','','.mainBanner'),(890188,'furniture','.mainBanner .title > span','display','block','','','.mainBanner'),(890189,'furniture','.mainBanner .topBox > .left','display','inline-block','','','.mainBanner'),(890190,'furniture','.mainBanner .topBox > .right','display','inline-block','','','.mainBanner'),(890191,'furniture','.mainBanner .topBox > .right','display','inline-block','3','','.mainBanner'),(890192,'furniture','.mainBanner .topBox > .left','display','block','5131','','.mainBanner'),(890193,'furniture','.order-summary .bottom-totals .price-box .icon','display','none','','','.order-summary'),(890194,'furniture','.order-summary .bottom-totals .price-box .price-row.total','display','flex','','','.order-summary'),(890195,'furniture','.order-summary .bottom-totals .price-row:not(.ot_total, .order-summary .bottom-totals .empty_cart)','display','none','','','.order-summary'),(890196,'furniture','.order-summary .checkout-cart-listing.main-listing','display','none','','','.order-summary'),(890197,'furniture','.order-summary .icon','display','block','','','.order-summary'),(890198,'furniture','.order-summary .price-box .price-row.total','display','flex','','','.order-summary'),(890199,'furniture','.order-summary .price-row','display','flex','2','','.order-summary'),(890200,'furniture','.order-summary .top-totals .price-box .price-row.total','display','none','','','.order-summary'),(890201,'furniture','.order-summary .w-cart-listing .item .points','display','none','','','.order-summary'),(890202,'furniture','.order-summary .w-cart-listing .item > div.image','display','none','','','.order-summary'),(890203,'furniture','.w-cart-discount-coupon .title','display','inline-block','4','','.w-cart-discount-coupon'),(890204,'furniture','.w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp','display','flex','','','.w-cart-discount-coupon'),(890205,'furniture','.w-cart-listing .price small','display','block','','','.w-cart-listing'),(890206,'furniture','.w-cart-listing .promos-info .promo-name','display','inline-block','','','.w-cart-listing'),(890207,'furniture','.w-cart-checkout-btn .with-card','display','inline-block','4','','.w-cart-checkout-btn'),(890208,'furniture','.w-checkout-continue-btn .button-hide','display','none','','','.w-checkout-continue-btn'),(890209,'furniture','.w-checkout-continue-btn .or-text','display','none','','','.w-checkout-continue-btn'),(890210,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','display','flex','','','.w-promotions-widgets-promotion-icons-desc'),(890211,'furniture','.w-product-promotion-icons .promos-info .promo-name','display','inline-block','','','.w-product-promotion-icons'),(890212,'furniture','.p-quote-checkout-index .order-summary .icon','display','none','','','.p-quote-checkout-index'),(890213,'furniture','.w-product-quantity-discounts .item','display','flex','','','.w-product-quantity-discounts'),(890214,'furniture','.w-product-quantity-discounts .per-item','display','block','','','.w-product-quantity-discounts'),(890215,'furniture','.w-product-quantity-discounts .quantity-discounts-content','display','flex','','','.w-product-quantity-discounts'),(890254,'furniture','.account-order-pay .history_attr','display','table','','','.account-order-pay'),(890255,'furniture','.account-order-pay .history_attr div','display','table-row','','','.account-order-pay'),(890256,'furniture','.account-order-pay .history_attr div strong, .account-order-pay .history_attr div span','display','table-cell','','','.account-order-pay'),(890257,'furniture','.account-samples .orders-table .hidden','display','none','','','.account-samples'),(890258,'furniture','.account-samples .short-date','display','none','','','.account-samples'),(890259,'furniture','.account-samples .view_link','display','inline-block','4','','.account-samples'),(890260,'furniture','.account-samples .orders-table .headings','display','none','5140','','.account-samples'),(890261,'furniture','.account-samples .orders-table .hidden','display','inline-block','5140','','.account-samples'),(890262,'furniture','.account-samples .orders-table .item','display','block','5140','','.account-samples'),(890263,'furniture','.account-samples .orders-table .item td','display','block','5140','','.account-samples'),(890264,'furniture','.account-samples .orders-table td.name','display','none','5140','','.account-samples'),(890265,'furniture','.account-samples .orders-table, .account-samples .orders-table tbody','display','block','5140','','.account-samples'),(890266,'furniture','.account-sample-info .history_attr','display','table','','','.account-sample-info'),(890267,'furniture','.account-sample-info .history_attr div','display','table-row','','','.account-sample-info'),(890268,'furniture','.account-sample-info .history_attr div strong, .account-sample-info .history_attr div span','display','table-cell','','','.account-sample-info'),(890269,'furniture','.account-sample-info .popup-tracking-number a','display','block','','','.account-sample-info'),(890270,'furniture','.account-sample-info .popup-tracking-number-link','display','block','','','.account-sample-info'),(890271,'furniture','.catalog-product-wrap .pn-image','display','inline-block','3','','.catalog-product-wrap'),(890272,'furniture','.catalog-product-wrap .pn-price','display','none','','','.catalog-product-wrap'),(890273,'furniture','.catalog-product-wrap .prev-next-product','display','none','','','.catalog-product-wrap'),(890274,'furniture','.catalog-product-wrap .prev-next-product > span','display','block','','','.catalog-product-wrap'),(890275,'furniture','.catalog-product-wrap .pn-image img','display','none','5140','','.catalog-product-wrap'),(890276,'furniture','.catalog-product-wrap .pn-name','display','none','5140','','.catalog-product-wrap'),(890277,'furniture','.checkout-index-wrap .edit-address-popup .address-item > label','display','block','','','.checkout-index-wrap'),(890278,'furniture','.checkout-index-wrap .edit-address-popup .addresses','display','flex','','','.checkout-index-wrap'),(890279,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons','display','flex','','','.checkout-index-wrap'),(890280,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons','display','none','4','','.checkout-index-wrap'),(890281,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','display','inline-block','','','.checkout-index-wrap'),(890282,'furniture','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','display','block','','','.checkout-index-wrap'),(890283,'furniture','.checkout-index-wrap .heading-2','display','none','3','','.checkout-index-wrap'),(890284,'furniture','.checkout-index-wrap .heading-2','display','none','4','','.checkout-index-wrap'),(890285,'furniture','.checkout-index-wrap .order-summary .heading-2','display','inline-block','3','','.checkout-index-wrap'),(890286,'furniture','.checkout-index-wrap .order-summary .heading-2','display','inline-block','4','','.checkout-index-wrap'),(890287,'furniture','.checkout-order-confirmation .heading-2.prod-ico','display','none','3','','.checkout-order-confirmation'),(890288,'furniture','.checkout-order-confirmation .heading-2.prod-ico','display','none','4','','.checkout-order-confirmation'),(890289,'furniture','.checkout-order-confirmation .price-row','display','flex','','','.checkout-order-confirmation'),(890290,'furniture','.checkout-success-wrap .page-success .text-1','display','block','3','','.checkout-success-wrap'),(890291,'furniture','.shopping-cart-index .cart-popup .gift-wrap','display','none','','','.shopping-cart-index'),(890292,'furniture','.shopping-cart-index .gift-code .heading-4 ~ *','display','none','5131','','.shopping-cart-index'),(890293,'furniture','.b-form .columns','display','flex','','','.b-form'),(890294,'furniture','.b-form .middle-form form','display','flex','','','.b-form'),(890295,'furniture','.b-info .info','display','inline-block','3','','.b-info'),(890296,'furniture','.w-checkout-totals .price-row','display','flex','','','.w-checkout-totals'),(890297,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-content','display','block','4','','.b-multi-page-checkout'),(890298,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','display','inline-block','','','.b-multi-page-checkout'),(890299,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .edit','display','none','','','.b-multi-page-checkout'),(890300,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading > .block','display','inline-block','','','.b-multi-page-checkout'),(890301,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','display','inline-block','3','','.b-multi-page-checkout'),(890302,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .count','display','none','','','.b-multi-page-checkout'),(890303,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','block','','','.b-multi-page-checkout'),(890304,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','inline-block','4','','.b-multi-page-checkout'),(890305,'furniture','.b-form .formWrapBox','display','flex','','','.b-form'),(890307,'furniture','.success-page .check-ico-block','display','block','3','','.success-page'),(890308,'furniture','.success-page .order_totals .price-row','display','flex','','','.success-page'),(890309,'furniture','.success-page .page-success .text-1','display','inline-block','3','','.success-page'),(890310,'furniture','.success-page .price-row','display','flex','','','.success-page'),(890311,'furniture','.success-page .w-cart-listing .qty.head','display','none','','','.success-page'),(890312,'furniture','.mainBanner .w-banner .banner-text-holder','display','flex','','','.mainBanner'),(890313,'furniture','.preFooter .w-banner .banner-item','display','inline-block','','','.preFooter'),(890314,'furniture','.preFooter .w-banner .banner-image','display','inline-block','','','.preFooter'),(890315,'furniture','.w-checkout-totals div.price-row','display','none','','','.w-checkout-totals'),(890316,'furniture','.w-checkout-totals div.price-row','display','flex','2','','.w-checkout-totals'),(890317,'furniture','.b-form .addresses .address-item .edit-ab','display','block','','','.b-form'),(890318,'furniture','.b-form .ui-helper-hidden-accessible','display','none','','','.b-form'),(890319,'furniture','.menu-header .menu-style[data-style=\"1\"] .component-item','display','none','','','.menu-header'),(890320,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','display','flex','','','.menu-header'),(890321,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1','display','flex','5198','','.footer-menu'),(890322,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2','display','flex','5198','','.footer-menu'),(890323,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li > .no-link','display','block','5140','','.footer-menu'),(890324,'furniture','.lowestPricedBox .w-banner .banner-holder','display','flex','','','.lowestPricedBox'),(890325,'furniture','.lowestPricedBox .w-banner .ybg','display','none','5131','','.lowestPricedBox'),(890326,'furniture','.lowestPricedBox .w-banner .ybg','display','none','5140','','.lowestPricedBox'),(890327,'furniture','.lowestPricedBox .w-banner .ybg','display','block','3','','.lowestPricedBox'),(890328,'furniture','.tripleBanner ','display','flex','','','.tripleBanner'),(890329,'furniture','.tripleBanner .w-html_box','display','inline-block','3','','.tripleBanner'),(890330,'furniture','.shopByCollectionBox .bannerButton a','display','inline-block','','','.shopByCollectionBox'),(890331,'furniture','.shopByCollectionBox .bannerButton a','display','inline-block','5145','','.shopByCollectionBox'),(890332,'furniture','.shopByCollectionBox .content','display','block','4','','.shopByCollectionBox'),(890333,'furniture','.shopByCollectionBox .content .title span','display','block','','','.shopByCollectionBox'),(890334,'furniture','.shopByCollectionBox .w-banner .banner-holder','display','flex','','','.shopByCollectionBox'),(890347,'furniture','.payment-method-tf label','display','block','','','.payment-method-tf'),(890348,'furniture','.w-account-customer-additional-field .field-type-checkbox label','display','inline-block','','','.w-account-customer-additional-field'),(890349,'furniture','.w-account-customer-additional-field .field-type-text','display','flex','','','.w-account-customer-additional-field'),(890350,'furniture','.w-banner .banner-item','display','grid','','','.w-banner'),(890351,'furniture','.w-banner .banner-text','display','flex','','','.w-banner'),(890352,'furniture','.w-banner .carousel-text','display','flex','','','.w-banner'),(890353,'furniture','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','display','table','','','.w-banner'),(890354,'furniture','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','display','table-cell','','','.w-banner'),(890355,'furniture','.w-banner .sliderItems a + a, .w-banner .sliderItems a + img, .w-banner .sliderItems img + a, .w-banner .sliderItems img + img','display','none','','','.w-banner'),(890356,'furniture','.w-catalog-paging ','display','inline-block','2','','.w-catalog-paging'),(890357,'furniture','.w-catalog-paging .next','display','inline-block','','','.w-catalog-paging'),(890358,'furniture','.w-catalog-paging .next-pages','display','inline-block','','','.w-catalog-paging'),(890359,'furniture','.w-catalog-paging .page-number','display','inline-block','','','.w-catalog-paging'),(890360,'furniture','.w-catalog-paging .paging','display','inline-block','','','.w-catalog-paging'),(890361,'furniture','.w-catalog-paging .paging-holder','display','inline-block','','','.w-catalog-paging'),(890362,'furniture','.w-catalog-paging .paging-item','display','inline-block','','','.w-catalog-paging'),(890363,'furniture','.w-catalog-paging .prev','display','inline-block','','','.w-catalog-paging'),(890364,'furniture','.w-catalog-paging .prev-pages','display','inline-block','','','.w-catalog-paging'),(890365,'furniture','.w-compare-box-item .checkbox + span','display','inline-block','','','.w-compare-box-item'),(890366,'furniture','.w-cart-listing .remove-btn span','display_important','important','5140','','.w-cart-listing'),(890367,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display_important','important','','','.b-switch'),(890368,'furniture','.w-menu-horizontal ul ul li','display_important','important','','','.w-menu-horizontal'),(890369,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display_important','important','','','.b-switch'),(890372,'furniture','.w-filters .filter-box-content ul li.view_items','display_important','important','','','.w-filters'),(890373,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display_important','important','','','.b-menu-open_from-left'),(890374,'furniture','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display_important','important','','','.b-menu-style'),(890375,'furniture','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display_important','important','','','.b-menu-style'),(890376,'furniture','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display_important','important','','','.b-menu-style'),(890377,'furniture','.b-products-listing .products-listing.slick-slider .item-nav','display_important','important','','','.b-products-listing'),(890378,'furniture','.w-quote .cart-box.hover-box:hover .cart-content','display_important','important','','','.w-quote'),(890379,'furniture','.w-sample .cart-box:hover .cart-content','display_important','important','','','.w-sample'),(890380,'furniture','.order-summary .bottom-totals .price-box .icon','display_important','important','','','.order-summary'),(890381,'furniture','.order-summary .bottom-totals .price-box .price-row.total','display_important','important','','','.order-summary'),(890382,'furniture','.order-summary .icon','display_important','important','','','.order-summary'),(890383,'furniture','.p-quote-checkout-index .order-summary .icon','display_important','important','','','.p-quote-checkout-index'),(890384,'furniture','.catalog-product-wrap .pn-price','display_important','important','','','.catalog-product-wrap'),(890385,'furniture','.catalog-product-wrap .pn-name','display_important','important','5140','','.catalog-product-wrap'),(890386,'furniture','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','fill','rgba(255, 255, 255, 0)','','','.w-image-maps'),(890387,'furniture','.w-image-maps polygon:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(890388,'furniture','.w-image-maps rect:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(890389,'furniture','.w-image-maps circle:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(890390,'furniture','.w-image-maps rect.no-items, .w-image-maps circle.no-items, .w-image-maps polygon.no-items','fill','rgba(150, 150, 150, 0.7)','','','.w-image-maps'),(890391,'furniture','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','filter','alpha(opacity=0)','','','.b-switch'),(890392,'furniture','.b-select-suggest .select2-container .select2-choice','filter','progid','','','.b-select-suggest'),(890393,'furniture','.b-select-suggest .select2-container.select2-drop-above .select2-choice','filter','progid','','','.b-select-suggest'),(890394,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','filter','alpha(opacity=50)','','','.b-switch'),(890395,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','filter','alpha(opacity=50)','','','.b-switch'),(890396,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','filter','progid','','','.b-select-suggest'),(890397,'furniture','.b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choice, .b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choices','filter','progid','','','.b-select-suggest'),(890398,'furniture','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','filter','none','','','.b-select-suggest'),(890399,'furniture','.b-select-suggest .select2-dropdown-open .select2-choice','filter','progid','','','.b-select-suggest'),(890400,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow','filter','progid','','','.b-select-suggest'),(890401,'furniture','.b-select-suggest .select2-drop-mask','filter','alpha(opacity=0)','','','.b-select-suggest'),(890402,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','filter','alpha(opacity=50)','','','.b-switch'),(890403,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-basis','0','','','.b-menu-position'),(890404,'furniture','.w-promotions .promo-cart-discount .slave','flex-direction','column','','','.w-promotions'),(890405,'furniture','.w-catalog-compare .cross-box','flex-direction','column','','','.w-catalog-compare'),(890406,'furniture','.w-files-catalog-widgets-files-catalog .item','flex-direction','column','','','.w-files-catalog-widgets-files-catalog'),(890407,'furniture','.b-products-listing .products-listing .attribute-qty-block','flex-direction','column','','','.b-products-listing'),(890408,'furniture','.w-product-designer-designer .prodDesignerType','flex-direction','row','','','.w-product-designer-designer'),(890409,'furniture','.w-press-reviews-widgets-press-reviews-list .item','flex-direction','column','','','.w-press-reviews-widgets-press-reviews-list'),(890410,'furniture','.w-rma-returns-history .column','flex-direction','column','','','.w-rma-returns-history'),(890411,'furniture','.w-rma-returns-history .filterMessages','flex-direction','column','','screen and (max-width: 768px)','.w-rma-returns-history'),(890412,'furniture','.w-predefined-promotion .promo-cart-discount .slave','flex-direction','column','','','.w-predefined-promotion'),(890413,'furniture','.w-product-quantity-discounts .item','flex-direction','column','','','.w-product-quantity-discounts'),(890414,'furniture','.lowestPricedBox .w-banner .banner-holder','flex-direction','column','5131','','.lowestPricedBox'),(890415,'furniture','.lowestPricedBox .w-banner .ybg','flex-direction','column','5131','','.lowestPricedBox'),(890416,'furniture','.lowestPricedBox .w-banner .ybg','flex-direction','column','5140','','.lowestPricedBox'),(890417,'furniture','.tripleBanner ','flex-direction','column','5140','','.tripleBanner'),(890418,'furniture','.b-messages .email-line > div','flex-grow','1','','','.b-messages'),(890419,'furniture','.w-promotions .prom-multi-discount .promo-product, .w-promotions .prom-multi-discount .promo-category-item','flex-grow','1','','','.w-promotions'),(890420,'furniture','.w-cart-listing .item .gift-wrap .value','flex-grow','1','','','.w-cart-listing'),(890421,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-grow','1','','','.b-menu-position'),(890422,'furniture','.w-account-personal-catalog .list-switcher a','flex-grow','1','','','.w-account-personal-catalog'),(890423,'furniture','.w-account-subscription .title','flex-grow','1','','','.w-account-subscription'),(890424,'furniture','.w-catalog-compare .product-listing > div','flex-grow','1','','','.w-catalog-compare'),(890425,'furniture','.w-delivery-day .time-left > span','flex-grow','1','','','.w-delivery-day'),(890426,'furniture','.w-files-catalog-widgets-files-catalog .image','flex-grow','1','','','.w-files-catalog-widgets-files-catalog'),(890427,'furniture','.w-filters-simple .system-1','flex-grow','1','','','.w-filters-simple'),(890428,'furniture','.w-predefined-promotion .prom-multi-discount .promo-product, .w-predefined-promotion .prom-multi-discount .promo-category-item','flex-grow','1','','','.w-predefined-promotion'),(890430,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','flex-grow','1','','','.footer-menu'),(890431,'furniture','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-grow','1','','','.w-account-customer-additional-field'),(890432,'furniture','.w-account-customer-additional-field .field-type-text label','flex-grow','1','','','.w-account-customer-additional-field'),(890433,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','flex-shrink','0','','','.w-upload-customer-id-upload-customer-id-form'),(890434,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-shrink','1','','','.b-menu-position'),(890435,'furniture','.w-catalog-compare .cross-box','flex-shrink','0','','','.w-catalog-compare'),(890436,'furniture','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-shrink','0','','','.w-account-customer-additional-field'),(890437,'furniture','.w-account-customer-additional-field .field-type-text label','flex-shrink','0','','','.w-account-customer-additional-field'),(890438,'furniture','.w-promotions .promo-cart-discount .content','flex-wrap','wrap','','','.w-promotions'),(890439,'furniture','.w-promotions .promo-salemaker .content','flex-wrap','wrap','','','.w-promotions'),(890440,'furniture','.b-products-listing .products-listing .attribute-qty-blocks','flex-wrap','wrap','','','.b-products-listing'),(890441,'furniture','.w-top-categories .categories','flex-wrap','wrap','','','.w-top-categories'),(890442,'furniture','.w-files-catalog-widgets-files-catalog ','flex-wrap','wrap','','','.w-files-catalog-widgets-files-catalog'),(890443,'furniture','.w-product-bundle .bundle-products','flex-wrap','wrap','','','.w-product-bundle'),(890444,'furniture','.w-product-in-bundles .bundle-products','flex-wrap','wrap','','','.w-product-in-bundles'),(890446,'furniture','.w-product-properties-icons ','flex-wrap','wrap','','','.w-product-properties-icons'),(890447,'furniture','.w-delivery-location-product-categories .categories','flex-wrap','wrap','','','.w-delivery-location-product-categories'),(890448,'furniture','.w-product-designer-designer .prodDesignerType','flex-wrap','wrap','','','.w-product-designer-designer'),(890449,'furniture','.w-press-reviews-widgets-press-reviews .sub-box','flex-wrap','wrap','','','.w-press-reviews-widgets-press-reviews'),(890450,'furniture','.w-press-reviews-widgets-press-reviews-list .review-box > *','flex-wrap','wrap','','','.w-press-reviews-widgets-press-reviews-list'),(890451,'furniture','.w-press-reviews-widgets-press-reviews-list .review-box','flex-wrap','wrap','5161','','.w-press-reviews-widgets-press-reviews-list'),(890452,'furniture','.w-predefined-promotion .promo-cart-discount .content','flex-wrap','wrap','','','.w-predefined-promotion'),(890453,'furniture','.w-predefined-promotion .promo-salemaker .content','flex-wrap','wrap','','','.w-predefined-promotion'),(890454,'furniture','.w-product-quantity-discounts .quantity-discounts-content','flex-wrap','wrap','','','.w-product-quantity-discounts'),(890455,'furniture','.checkout-index-wrap .edit-address-popup .addresses','flex-wrap','wrap','','','.checkout-index-wrap'),(890456,'furniture','.b-form .columns','flex-wrap','wrap','','','.b-form'),(890457,'furniture','.b-form .middle-form form','flex-wrap','wrap','','','.b-form'),(890458,'furniture','.b-form .formWrapBox','flex-wrap','wrap','','','.b-form'),(890459,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2','flex-wrap','wrap','5198','','.footer-menu'),(890460,'furniture','.shopByCollectionBox .w-banner .banner-holder','flex-wrap','wrap','5140','','.shopByCollectionBox'),(890462,'furniture','.heading-4 .right-text, h4 .right-text','float','right','','',''),(890463,'furniture','.w-checkout-billing-address .btn-cancel','float','left','','','.w-checkout-billing-address'),(890464,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(890465,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(890467,'furniture','.w-socials .post_item_img','float','left','','','.w-socials'),(890470,'furniture','.w-brands .brands-listing > div','float','left','','','.w-brands'),(890471,'furniture','.w-cart-shipping-estimator .left-area','float','left','','','.w-cart-shipping-estimator'),(890472,'furniture','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(890473,'furniture','.b-messages .msv_btn .btn','float','right','','','.b-messages'),(890474,'furniture','.b-messages .messages-menu li span','float','right','','','.b-messages'),(890475,'furniture','.w-checkout-shipping-address .btn-cancel','float','left','','','.w-checkout-shipping-address'),(890476,'furniture','.w-login-block .guest','float','right','','','.w-login-block'),(890477,'furniture','.p-payer-order-confirmation .dob-hide > div','float','right','','','.p-payer-order-confirmation'),(890478,'furniture','.p-payer-order-confirmation .dob-hide label','float','left','','','.p-payer-order-confirmation'),(890479,'furniture','.p-payer-order-pay .dob-hide label','float','left','','','.p-payer-order-pay'),(890480,'furniture','.p-payer-order-pay .dob-hide > div','float','right','','','.p-payer-order-pay'),(890481,'furniture','.b-compare .col-two label, .b-compare .col-two select','float','left','','','.b-compare'),(890482,'furniture','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(890483,'furniture','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(890484,'furniture','.w-login-block .guest','float','right','','','.w-login-block'),(890485,'furniture','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(890486,'furniture','.w-login-block .returning','float','left','','','.w-login-block'),(890487,'furniture','.w-login-block .new','float','right','','','.w-login-block'),(890488,'furniture','.w-menu-horizontal li','float','none','','','.w-menu-horizontal'),(890489,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(890490,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(890491,'furniture','.b-bottom .closeable-heading','float','right','3','','.b-bottom'),(890492,'furniture','.b-form .col-3','float','left','','','.b-form'),(890493,'furniture','.w-checkout-contact-information .btn-save','float','right','','','.w-checkout-contact-information'),(890494,'furniture','.b-form .terms-login .bootstrap-switch','float','right','','','.b-form'),(890495,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(890498,'furniture','.buttons .right-buttons','float','right','','',''),(890499,'furniture','.buttons .left-buttons','float','left','','',''),(890500,'furniture','.w-login-block .returning','float','left','','','.w-login-block'),(890501,'furniture','.w-brands .brands-listing > div','float','left','','','.w-brands'),(890502,'furniture','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(890503,'furniture','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(890505,'furniture','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(890506,'furniture','.message.success','float','left','3','',''),(890507,'furniture','.w-socials > li','float','left','','','.w-socials'),(890508,'furniture','.w-socials .post_item_img','float','left','','','.w-socials'),(890509,'furniture','.w-checkout-billing-address .add-ab','float','left','','','.w-checkout-billing-address'),(890510,'furniture','.w-cart-listing .right-area','float','none','5140','','.w-cart-listing'),(890511,'furniture','.w-checkout-shipping-address .add-ab','float','left','','','.w-checkout-shipping-address'),(890512,'furniture','.w-socials > li','float','left','','','.w-socials'),(890513,'furniture','.w-socials .post_item_img','float','left','','','.w-socials'),(890514,'furniture','.w-socials > li','float','left','','','.w-socials'),(890515,'furniture','.b-form .addresses .address-item input[type=\"radio\"]','float','left','','','.b-form'),(890516,'furniture','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(890517,'furniture','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(890518,'furniture','.w-socials > li','float','left','','','.w-socials'),(890519,'furniture','.heading-4 .edit, h4 .edit','float','right','','',''),(890520,'furniture','.w-login-block .returning','float','left','','','.w-login-block'),(890522,'furniture','.b-info-popup .password-info .info-popup','float','right','','','.b-info-popup'),(890523,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(890524,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(890525,'furniture','.heading-3 .right-text, h3 .right-text','float','right','','',''),(890526,'furniture','.heading-3 .edit, h3 .edit','float','right','','',''),(890527,'furniture','.w-socials .post_item_img','float','left','','','.w-socials'),(890529,'furniture','.w-checkout-billing-address .addresses .address-item','float','left','','','.w-checkout-billing-address'),(890530,'furniture','.w-list-b2b .select-attributes','float','left','','','.w-list-b2b'),(890531,'furniture','.w-socials .post_item_img','float','left','','','.w-socials'),(890532,'furniture','.edit-link','float','right','','',''),(890535,'furniture','.w-socials > li','float','left','','','.w-socials'),(890536,'furniture','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(890537,'furniture','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(890538,'furniture','.w-promo-code .btn','float','right','','','.w-promo-code'),(890539,'furniture','.b-form .shipping-method .cost','float','right','','','.b-form'),(890540,'furniture','.b-form .shipping-method .input','float','left','','','.b-form'),(890541,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(890542,'furniture','.b-sub-totals .historyTotal table','float','right','','','.b-sub-totals'),(890543,'furniture','.w-login-block .returning','float','left','','','.w-login-block'),(890544,'furniture','.w-login-block .guest','float','right','','','.w-login-block'),(890545,'furniture','.w-login-block .new','float','right','','','.w-login-block'),(890546,'furniture','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(890547,'furniture','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(890548,'furniture','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(890549,'furniture','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(890550,'furniture','.b-form .col-right','float','right','','','.b-form'),(890551,'furniture','.b-form .payment-method .item-radio input','float','left','','','.b-form'),(890552,'furniture','.w-cart-listing .actions > div','float','left','','','.w-cart-listing'),(890553,'furniture','.w-login-block .guest','float','right','','','.w-login-block'),(890554,'furniture','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(890555,'furniture','.w-login-block .new','float','right','','','.w-login-block'),(890557,'furniture','.w-brands .brands-listing > div','float','left','','','.w-brands'),(890559,'furniture','.w-cart-shipping-estimator .right-area','float','right','','','.w-cart-shipping-estimator'),(890560,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(890561,'furniture','.w-cart-give-away .ga_attributes > div','float','left','','','.w-cart-give-away'),(890562,'furniture','.b-bottom .cart-options .option-item','float','left','','','.b-bottom'),(890563,'furniture','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(890564,'furniture','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(890565,'furniture','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(890566,'furniture','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(890567,'furniture','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(890568,'furniture','.w-list-b2b .select-attributes:nth-child(2n)','float','right','','','.w-list-b2b'),(890569,'furniture','.b-upload-files .remove-file','float','right','','','.b-upload-files'),(890570,'furniture','.w-login-block .new','float','right','','','.w-login-block'),(890571,'furniture','.w-cart-compare .product .image','float','left','','','.w-cart-compare'),(890572,'furniture','.b-form .col-left','float','left','','','.b-form'),(890573,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(890574,'furniture','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(890575,'furniture','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(890576,'furniture','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(890577,'furniture','.b-form .addresses .address-item','float','left','','','.b-form'),(890578,'furniture','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(890579,'furniture','.w-socials > li','float','left','','','.w-socials'),(890580,'furniture','.w-cart-give-away .ga_column','float','left','','','.w-cart-give-away'),(890581,'furniture','.b-select-suggest .select2-container-multi .select2-choices li','float','left','','','.b-select-suggest'),(890582,'furniture','.w-neighbour-checkout .bootstrap-switch','float','right','','','.w-neighbour-checkout'),(890583,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','float','left','3','','.b-warehouses-popup'),(890584,'furniture','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(890590,'furniture','.w-menu-horizontal .box','float','none','','','.w-menu-horizontal'),(890592,'furniture','.w-login-block .new','float','right','','','.w-login-block'),(890593,'furniture','.w-login-block .guest','float','right','','','.w-login-block'),(890594,'furniture','.w-brands .brands-listing > div','float','left','','','.w-brands'),(890596,'furniture','.w-login-block .guest','float','right','','','.w-login-block'),(890598,'furniture','.w-menu-big li','float','none','','','.w-menu-big'),(890599,'furniture','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(890600,'furniture','.w-promo-code .btn','float','right','','','.w-promo-code'),(890601,'furniture','.w-login-block .new','float','right','','','.w-login-block'),(890602,'furniture','.w-account-addresses-list .address-fields input[type=\"radio\"]','float','left','','','.w-account-addresses-list'),(890603,'furniture','.w-account-addresses-list .addsess-suggestion-item','float','left','','','.w-account-addresses-list'),(890604,'furniture','.b-products-listing .products-listing .bonus-points-price','float','left','3','','.b-products-listing'),(890605,'furniture','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','float','right','','','.b-products-listing'),(890606,'furniture','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','float','right','','','.b-products-listing'),(890607,'furniture','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','float','right','','','.b-products-listing'),(890608,'furniture','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','float','right','','','.b-products-listing'),(890609,'furniture','.b-products-listing .BlockBox.type-7 > .col, .b-products-listing .BlockBox.type-8 > .col, .b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col','float','left','','','.b-products-listing'),(890610,'furniture','.b-products-listing .BlockBox.type-2 > .col, .b-products-listing .BlockBox.type-3 > .col, .b-products-listing .BlockBox.type-4 > .col, .b-products-listing .BlockBox.type-5 > .col, .b-products-listing .BlockBox.type-6 > .col','float','left','','','.b-products-listing'),(890611,'furniture','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','float','right','','','.b-products-listing'),(890612,'furniture','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','float','right','','','.b-products-listing'),(890613,'furniture','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','float','right','','','.b-products-listing'),(890614,'furniture','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','float','right','','','.b-products-listing'),(890615,'furniture','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','float','right','','','.b-products-listing'),(890616,'furniture','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','float','right','','','.b-products-listing'),(890617,'furniture','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','float','right','','','.b-products-listing'),(890618,'furniture','.b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col, .b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockB','float','left','','','.b-products-listing'),(890619,'furniture','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','float','right','','','.b-products-listing'),(890620,'furniture','.b-products-listing .products-listing .item','float','none','','','.b-products-listing'),(890621,'furniture','.b-products-listing .products-listing.align-left .item','float','left','','','.b-products-listing'),(890622,'furniture','.b-products-listing .products-listing.align-right .item','float','right','','','.b-products-listing'),(890623,'furniture','.b-products-listing .wedding-registry-count','float','right','','','.b-products-listing'),(890624,'furniture','.w-checkout-gdpr .candlestick-wrapper','float','right','','','.w-checkout-gdpr'),(890625,'furniture','.b-compare .compare-box-btn','float','right','','','.b-compare'),(890626,'furniture','.w-cart-give-away .ga_img','float','left','','','.w-cart-give-away'),(890627,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(890628,'furniture','.w-cart-compare .product-actions','float','right','','','.w-cart-compare'),(890629,'furniture','.w-socials .post_item_img','float','left','','','.w-socials'),(890630,'furniture','.w-promo-code .btn','float','right','','','.w-promo-code'),(890632,'furniture','.w-login-block .returning','float','left','','','.w-login-block'),(890633,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(890634,'furniture','.w-checkout-create-account .newsletter-switcher .bootstrap-switch','float','right','','','.w-checkout-create-account'),(890635,'furniture','.w-checkout-shipping-address .addresses .address-item','float','left','','','.w-checkout-shipping-address'),(890636,'furniture','.w-checkout-create-account .create-account-switcher','float','right','','','.w-checkout-create-account'),(890637,'furniture','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(890638,'furniture','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(890639,'furniture','.w-login-block .returning','float','left','','','.w-login-block'),(890641,'furniture','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(890642,'furniture','.w-promo-code .btn','float','right','','','.w-promo-code'),(890643,'furniture','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(890644,'furniture','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(890645,'furniture','.b-form .columns .col-2','float','left','','','.b-form'),(890646,'furniture','.w-product-cross-sell .buy-all-checker','float','left','','','.w-product-cross-sell'),(890647,'furniture','.w-cart-listing .item > div','float','left','','','.w-cart-listing'),(890648,'furniture','.w-cart-listing .points-redeem','float','left','3','','.w-cart-listing'),(890649,'furniture','.w-cart-listing .right-area','float','left','','','.w-cart-listing'),(890650,'furniture','.w-cart-listing .item .qty','float','right','5140','','.w-cart-listing'),(890651,'furniture','.w-cart-listing .links','float','left','','','.w-cart-listing'),(890652,'furniture','.w-cart-give-away .ga_price .checkBoxWrap','float','right','','','.w-cart-give-away'),(890655,'furniture','.w-brands .brands-listing > div','float','left','','','.w-brands'),(890656,'furniture','.order-summary .btn-2','float','none','5140','','.order-summary'),(890657,'furniture','.w-promo-code .btn','float','right','','','.w-promo-code'),(890661,'furniture','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(890662,'furniture','.w-checkout-billing-address .bootstrap-switch','float','right','','','.w-checkout-billing-address'),(890663,'furniture','.w-brands .brands-listing > div','float','left','','','.w-brands'),(890666,'furniture','.b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockBox.type-14 > .col, .b-products-listing .BlockBox.type-15 > .col, .b-products-listing .BlockBox.type-16 > .col','float','left','','','.b-products-listing'),(890667,'furniture','.w-product-reviews .write-review-button','float','right','','','.w-product-reviews'),(890668,'furniture','.w-promo-code .btn','float','right','','','.w-promo-code'),(890669,'furniture','.w-filters .handle-to','float','right','','','.w-filters'),(890670,'furniture','.w-filters .handle-from','float','left','','','.w-filters'),(890671,'furniture','.w-cart-compare .js-cart_totals_container','float','left','','','.w-cart-compare'),(890672,'furniture','.w-cart-compare .buttons','float','right','','','.w-cart-compare'),(890673,'furniture','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(890674,'furniture','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(890678,'furniture','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(890679,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(890680,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(890681,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(890682,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(890683,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(890684,'furniture','.b-trade-approval .col-right','float','right','','','.b-trade-approval'),(890685,'furniture','.b-trade-approval .col-left','float','left','','','.b-trade-approval'),(890686,'furniture','.b-trade-approval .col-3','float','left','','','.b-trade-approval'),(890687,'furniture','.w-catalog-compare .compare label','float','right','','','.w-catalog-compare'),(890688,'furniture','.w-catalog-compare .buyButton','float','right','','','.w-catalog-compare'),(890689,'furniture','.w-delivery-day .left-count','float','left','','','.w-delivery-day'),(890690,'furniture','.w-delivery-day .left-text-left','float','left','','','.w-delivery-day'),(890691,'furniture','.w-delivery-day .left-text-right','float','left','','','.w-delivery-day'),(890693,'furniture','.b-products-listing .products-listing.list-productlisting .stock','float','none','','','.b-products-listing'),(890694,'furniture','.b-slick .slick-slide','float','left','','','.b-slick'),(890695,'furniture','.b-slick [dir=\'rtl\'] .slick-slide','float','right','','','.b-slick'),(890696,'furniture','.b-products-listing .item-nav > div','float','left','','','.b-products-listing'),(890697,'furniture','.w-quote .image','float','left','','','.w-quote'),(890698,'furniture','.w-quote .sub-total','float','right','','','.w-quote'),(890699,'furniture','.w-quote .sub-total-text','float','left','','','.w-quote'),(890700,'furniture','.b-quantity .qty-input label','float','left','','','.b-quantity'),(890701,'furniture','.w-product-sale-ends .left-count','float','left','','','.w-product-sale-ends'),(890702,'furniture','.w-product-sale-ends .left-text-left','float','left','','','.w-product-sale-ends'),(890703,'furniture','.w-product-sale-ends .left-text-right','float','left','','','.w-product-sale-ends'),(890704,'furniture','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(890705,'furniture','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(890706,'furniture','.w-product-bonus-points > div > div','float','left','','','.w-product-bonus-points'),(890707,'furniture','.w-compare .compare-list-buttons','float','right','','','.w-compare'),(890708,'furniture','.w-compare .clear-compare-button','float','right','','','.w-compare'),(890709,'furniture','.w-compare .image','float','left','','','.w-compare'),(890710,'furniture','.w-files-catalog-widgets-files-list .file','float','left','3','','.w-files-catalog-widgets-files-list'),(890711,'furniture','.w-sample .image','float','left','','','.w-sample'),(890712,'furniture','.w-sample .sub-total','float','right','','','.w-sample'),(890713,'furniture','.w-sample .sub-total-text','float','left','','','.w-sample'),(890714,'furniture','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(890715,'furniture','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(890716,'furniture','.w-product-bundle .bundle_qty','float','left','','','.w-product-bundle'),(890717,'furniture','.w-product-bundle .bundle_price','float','right','','','.w-product-bundle'),(890718,'furniture','.w-product-in-bundles .attributes-item','float','left','','','.w-product-in-bundles'),(890719,'furniture','.w-product-in-bundles .bundle_qty','float','left','','','.w-product-in-bundles'),(890720,'furniture','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(890721,'furniture','.w-cart-listing .item div.price','float','left','5140','','.w-cart-listing'),(890722,'furniture','.b-pagination .pagination .left-area','float','left','','','.b-pagination'),(890723,'furniture','.b-pagination .pagination .right-area','float','right','','','.b-pagination'),(890724,'furniture','.w-product-multi-inventory .select-box:nth-child(2n)','float','left','','','.w-product-multi-inventory'),(890725,'furniture','.w-product-multi-inventory .select-box:nth-child(2n+1)','float','left','','','.w-product-multi-inventory'),(890726,'furniture','.w-product-multi-inventory .radio-attributes > label','float','left','','','.w-product-multi-inventory'),(890727,'furniture','.b-products-listing .products-listing .radio-attributes > label','float','left','','','.b-products-listing'),(890728,'furniture','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(890729,'furniture','.w-product-collection .current-product','float','left','','','.w-product-collection'),(890730,'furniture','.w-product-collection .right-area','float','left','','','.w-product-collection'),(890731,'furniture','.w-product-collection .current-product, .w-product-collection .chosen-products','float','none','5140','','.w-product-collection'),(890732,'furniture','.w-product-collection .right-area','float','none','5140','','.w-product-collection'),(890733,'furniture','.w-product-attributes .radio-attributes > label','float','left','','','.w-product-attributes'),(890734,'furniture','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(890735,'furniture','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(890736,'furniture','.w-product-groups .radioBox label','float','left','','','.w-product-groups'),(890737,'furniture','.w-product-groups .radioBox label .containerBlock img','float','left','','','.w-product-groups'),(890738,'furniture','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img','float','none','','','.w-product-groups'),(890739,'furniture','.b-products-listing .products-listing .attribute-color','float','left','','','.b-products-listing'),(890740,'furniture','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(890741,'furniture','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(890742,'furniture','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(890743,'furniture','.w-product-custom-bundle .chosen-products','float','none','5140','','.w-product-custom-bundle'),(890744,'furniture','.w-product-custom-bundle .right-area','float','none','5140','','.w-product-custom-bundle'),(890745,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','float','left','','','.w-catalog-pages-category-pages-last-list'),(890746,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','float','left','','','.w-catalog-pages-category-pages-last-list-block'),(890747,'furniture','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(890748,'furniture','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(890749,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li','float','left','','','.w-delivery-location-featured-list'),(890750,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li','float','none','5161','','.w-delivery-location-featured-list'),(890751,'furniture','.w-sale-category .holder-1','float','right','','','.w-sale-category'),(890752,'furniture','.w-sale-category .holder-2','float','left','','','.w-sale-category'),(890753,'furniture','.w-sale-category .image','float','left','','','.w-sale-category'),(890754,'furniture','.w-sale-category .left-count','float','left','','','.w-sale-category'),(890755,'furniture','.w-sale-category .left-text-left','float','left','','','.w-sale-category'),(890756,'furniture','.w-sale-category .left-text-right','float','left','','','.w-sale-category'),(890757,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','float','left','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(890758,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','float','left','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(890759,'furniture','.w-delivery-location-list-by-page .item','float','left','','','.w-delivery-location-list-by-page'),(890760,'furniture','.w-delivery-location-cross-pages .item','float','left','','','.w-delivery-location-cross-pages'),(890761,'furniture','.w-catalog-delivery-locations .item','float','left','','','.w-catalog-delivery-locations'),(890762,'furniture','.w-catalog-delivery-locations .item','float','none','5131','','.w-catalog-delivery-locations'),(890763,'furniture','.w-product-designer-designer .prodDesignerType label','float','left','','','.w-product-designer-designer'),(890764,'furniture','.w-product-designer-designer .prodDesignerType','float','none','','','.w-product-designer-designer'),(890765,'furniture','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','float','right','','','.w-press-reviews-widgets-press-reviews-small'),(890766,'furniture','.w-gift-wrap-message-checkout .text','float','left','','','.w-gift-wrap-message-checkout'),(890767,'furniture','.w-support-system-filter .filter-categories','float','none','','','.w-support-system-filter'),(890768,'furniture','.w-support-system-filter .dd3-content .collapse_span','float','right','','','.w-support-system-filter'),(890769,'furniture','.w-support-system-listing .product_icon','float','left','','','.w-support-system-listing'),(890770,'furniture','.w-rma-returns-history .topRow .icons','float','right','','','.w-rma-returns-history'),(890771,'furniture','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(890772,'furniture','.w-product-configurator .item-content > div','float','left','5131','','.w-product-configurator'),(890773,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','float','left','','','.w-catalog-pages-category-pages-list'),(890774,'furniture','.w-filters .fsl_handle > div','float','left','','','.w-filters'),(890775,'furniture','.mainBanner .bottomBox .btn','float','right','','','.mainBanner'),(890783,'furniture','.account-address-book .address_book h2 strong','float','left','','','.account-address-book'),(890784,'furniture','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','float','left','','','.account-address-book'),(890785,'furniture','.account-address-book .button1','float','right','','','.account-address-book'),(890786,'furniture','.account-address-book .button2','float','left','','','.account-address-book'),(890787,'furniture','.account-address-book .address_book_row .column','float','none','5131','','.account-address-book'),(890788,'furniture','.account-address-book .address_book_row .column + .column','float','none','5131','','.account-address-book'),(890789,'furniture','.account-address-book .topInfo > div','float','none','5131','','.account-address-book'),(890790,'furniture','.account-address-book .topInfo > div + div','float','none','5131','','.account-address-book'),(890792,'furniture','.account-order-pay .history_info > div','float','left','','','.account-order-pay'),(890793,'furniture','.account-sample-info .history_info > div','float','left','','','.account-sample-info'),(890794,'furniture','.checkout-index-wrap .dob-hide > div','float','right','','','.checkout-index-wrap'),(890795,'furniture','.checkout-index-wrap .dob-hide label','float','left','','','.checkout-index-wrap'),(890796,'furniture','.b-form .add-ab','float','right','','','.b-form'),(890797,'furniture','.b-bottom .cart-options .cart-item','float','left','','','.b-bottom'),(890798,'furniture','.b-info .info','float','left','3','','.b-info'),(890799,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','float','right','','','.b-multi-page-checkout'),(890800,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li','float','left','3','','.footer-menu'),(890801,'furniture','.shopByCollectionBox .bannerButton','float','right','','','.shopByCollectionBox'),(890802,'furniture','.shopByCollectionBox .bannerButton','float','right','5145','','.shopByCollectionBox'),(890803,'furniture','.shopByCollectionBox .content .title','float','left','','','.shopByCollectionBox'),(890804,'furniture','.w-compare-box-item .cb_check','float','right','','','.w-compare-box-item'),(890805,'furniture','.w-compare-box-item .cb_title','float','left','','','.w-compare-box-item'),(890806,'furniture','.b-slick .slick-slide','float_important','important','','','.b-slick'),(890807,'furniture','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-family','$font-1','','','.w-communication-new-topic'),(890808,'furniture','.b-upload-file .snapshot','font-family','$font-icons-1','3','','.b-upload-file'),(890809,'furniture','.heading-4 .edit, h4 .edit','font-family','trueloaded','4','',''),(890810,'furniture','.heading-4 .edit, h4 .edit','font-family','$font-1','','',''),(890811,'furniture','.message.success','font-family','trueloaded','3','',''),(890812,'furniture','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(890813,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(890814,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(890815,'furniture','.b-form .checkbox-style:checked + .checkbox-span:before','font-family','FontAwesome','','','.b-form'),(890816,'furniture','.w-filters .filter-box-head','font-family','$font-1','','','.w-filters'),(890817,'furniture','.p-quick-order-index .paginate_button.previous','font-family','$font-icons-1','3','','.p-quick-order-index'),(890818,'furniture','.p-quick-order-index .paginate_button.next','font-family','$font-icons-1','3','','.p-quick-order-index'),(890819,'furniture','.w-cart-compare .cart-name a','font-family','$font-1','','','.w-cart-compare'),(890820,'furniture','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(890822,'furniture','.p-sample-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-sample-checkout-success'),(890823,'furniture','.p-sample-checkout-success .page-success .text-1, .p-sample-checkout-success .page-success .text-2, .p-sample-checkout-success .page-success .text-3','font-family','$font-1','','','.p-sample-checkout-success'),(890824,'furniture','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(890825,'furniture','.testimonials .heading-3','font-family','trueloaded','3','',''),(890826,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(890827,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(890828,'furniture','.w-promotions .nextdiscount .heading','font-family','$font-icons-1','3','','.w-promotions'),(890829,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','font-family','$font-icons-1','3','','.b-warehouses-popup'),(890830,'furniture','.b-warehouses-popup .warehouses-popup-link','font-family','$font-icons-1','3','','.b-warehouses-popup'),(890831,'furniture','.b-preloader .preloader','font-family','$font-icons-1','3','','.b-preloader'),(890832,'furniture','.w-social-links a','font-family','$font-icons-1','','','.w-social-links'),(890833,'furniture','.b-bottom .closeable-heading','font-family','FontAwesome','3','','.b-bottom'),(890834,'furniture','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(890835,'furniture','.b-messages .messBtnMenuUnread','font-family','$font-icons-1','3','','.b-messages'),(890836,'furniture','.b-messages .messBtnMenuDelete','font-family','trueloaded','3','','.b-messages'),(890837,'furniture','.b-messages span.starred::before','font-family','trueloaded','','','.b-messages'),(890838,'furniture','.b-messages .messBtnMenuStarred','font-family','trueloaded','3','','.b-messages'),(890839,'furniture','.b-messages .content_management_attach span','font-family','$font-1','','','.b-messages'),(890840,'furniture','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(890841,'furniture','.p-payer-order-confirmation .ship-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(890842,'furniture','.p-payer-order-confirmation .pay-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(890843,'furniture','.p-payer-order-confirmation .order-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(890844,'furniture','.p-payer-order-confirmation .discount-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(890845,'furniture','.p-payer-order-confirmation .comment-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(890846,'furniture','.p-payer-order-pay .ship-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(890847,'furniture','.p-payer-order-pay .order-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(890848,'furniture','.p-payer-order-pay .pay-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(890849,'furniture','.p-payer-order-pay .discount-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(890850,'furniture','.p-payer-order-pay .comment-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(890851,'furniture','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(890852,'furniture','.b-fancybox .fancybox-close','font-family','FontAwesome','3','','.b-fancybox'),(890853,'furniture','.b-messages .select2-search-choice-close','font-family','trueloaded','3','','.b-messages'),(890855,'furniture','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(890856,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-family','$font-icons-1','3','','.w-upload-customer-id-upload-customer-id-form'),(890857,'furniture','.w-coupons-and-vauchers-checkout .btn-remove','font-family','trueloaded','3','','.w-coupons-and-vauchers-checkout'),(890858,'furniture','.w-filters .open','font-family','$font-icons-1','3','','.w-filters'),(890859,'furniture','.w-categories h2.name','font-family','$font-1','','','.w-categories'),(890860,'furniture','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(890861,'furniture','.b-fancybox .fancybox-nav span','font-family','trueloaded','','','.b-fancybox'),(890862,'furniture','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(890863,'furniture','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','font-family','$font-icons-1','3','','.w-checkout-contact-information'),(890864,'furniture','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(890865,'furniture','.no-found','font-family','$font-1','','',''),(890866,'furniture','.view-all .btn','font-family','$font-icons-1','4','',''),(890867,'furniture','.w-catalog-listing-look .list','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(890868,'furniture','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(890869,'furniture','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(890870,'furniture','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(890871,'furniture','.w-cart-compare .price-cell','font-family','$font-1','','','.w-cart-compare'),(890872,'furniture','.b-bottom .footerTitle','font-family','FontAwesome','5131,4','','.b-bottom'),(890874,'furniture','.b-rating .glyphicon-star','font-family','$font-icons-1','3','','.b-rating'),(890875,'furniture','.w-chat .w-chat-box a','font-family','$font-icons-1','3','','.w-chat'),(890876,'furniture','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(890878,'furniture','.w-cart-compare .product-actions .dropdown-toggle','font-family','$font-icons-1','3','','.w-cart-compare'),(890879,'furniture','.w-cart-compare .atr-col','font-family','$font-icons-1','3','','.w-cart-compare'),(890880,'furniture','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(890881,'furniture','.b-rating .glyphicon','font-family','$font-icons-1','','','.b-rating'),(890882,'furniture','.order-summary .price-row.ot_gv .title','font-family','trueloaded','3','','.order-summary'),(890883,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(890884,'furniture','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(890885,'furniture','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(890886,'furniture','.w-tabs .tab-li.tab-wishlist a','font-family','trueloaded','3','','.w-tabs'),(890887,'furniture','.w-multi-cart-actions .cart-actions .dropdown-toggle','font-family','$font-icons-1','3','','.w-multi-cart-actions'),(890888,'furniture','.w-top-categories h2.name','font-family','$font-1','','','.w-top-categories'),(890889,'furniture','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(890890,'furniture','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(890891,'furniture','.w-tabs .tab-a','font-family','$font-1','','','.w-tabs'),(890892,'furniture','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(890893,'furniture','.btn-edit','font-family','trueloaded','3','',''),(890894,'furniture','.w-tabs .tab-li.tab-cart a','font-family','trueloaded','3','','.w-tabs'),(890895,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(890896,'furniture','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(890897,'furniture','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(890898,'furniture','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(890900,'furniture','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(890901,'furniture','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(890902,'furniture','.btn-2','font-family','$font-1','','',''),(890903,'furniture','.btn-1','font-family','$font-1','','',''),(890904,'furniture','.heading-5, h5, .h-block h5','font-family','$font-1','','',''),(890905,'furniture','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(890906,'furniture','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(890907,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(890908,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(890909,'furniture','.w-filters .input-checkbox:checked + .checkbox-span:before','font-family','$font-icons-1','','','.w-filters'),(890910,'furniture','.in-stock-icon','font-family','$font-icons-1','3','',''),(890911,'furniture','.out-stock-icon','font-family','$font-icons-1','3','',''),(890912,'furniture','.transit-icon','font-family','$font-icons-1','3','',''),(890913,'furniture','.heading-3 .edit, h3 .edit','font-family','trueloaded','4','',''),(890914,'furniture','.heading-3 .edit, h3 .edit','font-family','$font-1','','',''),(890915,'furniture','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(890916,'furniture','.w-checkout-create-account .account-benefits strong','font-family','trueloaded','3','','.w-checkout-create-account'),(890917,'furniture','.savings-ico .heading-2','font-family','trueloaded','3','','.savings-ico'),(890918,'furniture','.w-cart-bonus-points .btn-remove','font-family','trueloaded','3','','.w-cart-bonus-points'),(890919,'furniture','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(890921,'furniture','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(890922,'furniture','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-family','$font-1','','','.w-multi-cart-cart-switcher'),(890923,'furniture','.js-stock-icon','font-family','$font-icons-1','3','',''),(890924,'furniture','.b-switch .candlestick-wrapper .fa-check','font-family','FontAwesome','3','','.b-switch'),(890925,'furniture','.b-switch .candlestick-wrapper .fa-times','font-family','FontAwesome','3','','.b-switch'),(890926,'furniture','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(890927,'furniture','.w-top-categories .categories h2','font-family','inherit','','','.w-top-categories'),(890928,'furniture','.btn','font-family','$font-1','','',''),(890929,'furniture','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(890930,'furniture','.heading-4, h4, .h-block h4','font-family','$font-1','','',''),(890931,'furniture','.b-upload-file .upload-file-wrap .upload-remove','font-family','trueloaded','3','','.b-upload-file'),(890932,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-family','FontAwesome','','','.b-form'),(890933,'furniture','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(890934,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(890935,'furniture','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(890936,'furniture','.w-reviews .heading-3','font-family','trueloaded','3','','.w-reviews'),(890937,'furniture','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(890938,'furniture','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(890939,'furniture','.btn-del','font-family','$font-icons-1','4','',''),(890940,'furniture','.b-rating .glyphicon-star.coloron','font-family','$font-icons-1','3','','.b-rating'),(890941,'furniture','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(890942,'furniture','.w-cart-credit-amount .btn-remove','font-family','trueloaded','3','','.w-cart-credit-amount'),(890944,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(890945,'furniture','.heading-6, h6, .h-block h6','font-family','$font-1','','',''),(890946,'furniture','.closeable-heading','font-family','$font-icons-1','3','',''),(890947,'furniture','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(890948,'furniture','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(890949,'furniture','.b-bottom .pop-up-close','font-family','FontAwesome','3','','.b-bottom'),(890950,'furniture','.b-info-popup .info-popup','font-family','trueloaded','3','','.b-info-popup'),(890951,'furniture','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-family','$font-icons-1','','','.b-products-listing'),(890952,'furniture','.b-upload-files .remove-file','font-family','$font-icons-1','3','','.b-upload-files'),(890955,'furniture','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(890956,'furniture','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(890957,'furniture','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(890958,'furniture','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(890959,'furniture','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(890960,'furniture','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(890961,'furniture','.w-text .customer-service b','font-family','$font-1','','','.w-text'),(890962,'furniture','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(890964,'furniture','.heading-3, h3, .h-block h3','font-family','$font-1','','',''),(890965,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-family','$font-1','','','.b-select-suggest'),(890966,'furniture','.b-select-suggest .select2-search input','font-family','$font-1','','','.b-select-suggest'),(890971,'furniture','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(890974,'furniture','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(890975,'furniture','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(890977,'furniture','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(890978,'furniture','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(890979,'furniture','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(890980,'furniture','.b-products-listing .products-listing .bonus-points-price','font-family','$font-icons-1','3','','.b-products-listing'),(890981,'furniture','.b-products-listing .products-listing .bonus-points-cost','font-family','$font-icons-1','3','','.b-products-listing'),(890982,'furniture','.b-products-listing .products-listing a.btn.view-button','font-family','trueloaded','3','','.b-products-listing'),(890983,'furniture','.b-products-listing .btn-preloader','font-family','$font-icons-1','3','','.b-products-listing'),(890984,'furniture','.b-products-listing .loader','font-family','$font-icons-1','4','','.b-products-listing'),(890985,'furniture','.b-products-listing .products-listing .btn-buy','font-family','trueloaded','3','','.b-products-listing'),(890987,'furniture','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(890988,'furniture','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(890989,'furniture','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(890990,'furniture','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','font-family','$font-icons-1','3','','.w-checkout-contact-information'),(890991,'furniture','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(890994,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(890995,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(890996,'furniture','.b-form .eye-password','font-family','FontAwesome','3','','.b-form'),(890997,'furniture','.heading-4 .right-text, h4 .right-text','font-family','$font-1','','',''),(890998,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-family','inherit','','',''),(890999,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-family','inherit','','','.b-h-inline'),(891000,'furniture','h1, .heading-1','font-family','$font-1','','',''),(891002,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','font-family','FontAwesome','3','','.b-form'),(891003,'furniture','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','font-family','$font-icons-1','3','','.w-checkout-contact-information'),(891004,'furniture','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(891005,'furniture','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(891006,'furniture','.w-tabs .tab-li.tab-quote a','font-family','trueloaded','3','','.w-tabs'),(891008,'furniture','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(891009,'furniture','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','font-family','$font-icons-2','3','','.order-summary'),(891010,'furniture','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(891011,'furniture','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(891012,'furniture','.w-product-cross-sell .buy-all-checker','font-family','$font-icons-1','3','','.w-product-cross-sell'),(891013,'furniture','.w-catalog-listing-look .b2b','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(891014,'furniture','.w-catalog-listing-look .grid','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(891015,'furniture','.checkbox input:checked + span:before','font-family','$font-icons-1','','',''),(891016,'furniture','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-family','trueloaded','3','','.w-cart-listing'),(891017,'furniture','.w-cart-listing .points-redeem','font-family','$font-1','','','.w-cart-listing'),(891018,'furniture','.w-cart-listing .points-redeem','font-family','$font-icons-1','3','','.w-cart-listing'),(891019,'furniture','.w-cart-listing .remove-btn','font-family','$font-icons-1','3','','.w-cart-listing'),(891020,'furniture','.w-cart-give-away .ga_qty','font-family','$font-1','','','.w-cart-give-away'),(891021,'furniture','.w-cart-discount-coupon .btn-remove','font-family','$font-icons-2','3','','.w-cart-discount-coupon'),(891024,'furniture','.w-text .customer-service','font-family','trueloaded','3','','.w-text'),(891025,'furniture','.w-tabs .accordion-heading','font-family','$font-1','','','.w-tabs'),(891026,'furniture','.b-compare .clear_all','font-family','$font-icons-1','4','','.b-compare'),(891027,'furniture','.order-summary .price-row.ot_bonus_points .title','font-family','$font-icons-2','3','','.order-summary'),(891028,'furniture','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(891029,'furniture','.w-checkout-credit-amount .btn-remove','font-family','trueloaded','3','','.w-checkout-credit-amount'),(891030,'furniture','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(891031,'furniture','.w-filters .view_more','font-family','$font-icons-1','4','','.w-filters'),(891032,'furniture','.w-filters span.close','font-family','$font-icons-1','3','','.w-filters'),(891033,'furniture','.w-filters .head-filter-widget','font-family','$font-1','','','.w-filters'),(891034,'furniture','.w-quote .cart-box-link','font-family','trueloaded','3','','.w-quote'),(891035,'furniture','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(891036,'furniture','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(891037,'furniture','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(891038,'furniture','.heading-2, h2, .h-block h2','font-family','$font-1','','',''),(891039,'furniture','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(891040,'furniture','body','font-family','$font-1','','',''),(891041,'furniture','.w-tabs .tab-li.tab-sample a','font-family','trueloaded','3','','.w-tabs'),(891042,'furniture','.w-checkout-bonus-points .btn-remove','font-family','trueloaded','3','','.w-checkout-bonus-points'),(891043,'furniture','.b-data-table table.dataTable thead td','font-family','$font-1','','','.b-data-table'),(891046,'furniture','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(891048,'furniture','.btn-3','font-family','$font-1','','',''),(891049,'furniture','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(891051,'furniture','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(891052,'furniture','.w-filters .mobileCollapse','font-family','$font-icons-1','4','','.w-filters'),(891053,'furniture','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-family','$font-icons-1','','','.w-filters'),(891054,'furniture','.b-product-images .media-popup .mp-close','font-family','$font-icons-1','3','','.b-product-images'),(891055,'furniture','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','font-family','$font-icons-1','3','','.b-menu-burger_icon'),(891056,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','font-family','$font-icons-1','3','','.b-menu-style-2'),(891057,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','font-family','$font-icons-1','3','','.b-menu-style-2'),(891058,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-family','$font-icons-1','3','','.b-menu-style-2'),(891059,'furniture','.w-account-personal-catalog .list-switcher a','font-family','$font-1','','','.w-account-personal-catalog'),(891060,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-family','trueloaded','3','','.w-catalog-compare'),(891062,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','font-family','$font-icons-1','3','','.b-slick'),(891063,'furniture','.b-products-listing .add-to-personal-catalog','font-family','$font-icons-1','3','','.b-products-listing'),(891064,'furniture','.b-products-listing .del-from-personal-catalog','font-family','$font-icons-1','3','','.b-products-listing'),(891065,'furniture','.w-subscribers .btn-submit','font-family','$font-1','','','.w-subscribers'),(891066,'furniture','.w-quote .multicart .switch-cart','font-family','$font-icons-1','3','','.w-quote'),(891067,'furniture','.w-quote .multicart .title','font-family','$font-1','','','.w-quote'),(891069,'furniture','.w-product-personal-catalog-button .btn','font-family','$font-icons-1','3','','.w-product-personal-catalog-button'),(891070,'furniture','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','font-family','trueloaded','3','','.w-product-buttons'),(891071,'furniture','.w-product-bonus-points > div > div','font-family','$font-icons-1','3','','.w-product-bonus-points'),(891072,'furniture','.w-compare .remove','font-family','$font-icons-1','3','','.w-compare'),(891073,'furniture','.w-files-catalog-widgets-files-list .file','font-family','$font-icons-1','3','','.w-files-catalog-widgets-files-list'),(891074,'furniture','.w-sample .cart-box-link','font-family','trueloaded','3','','.w-sample'),(891075,'furniture','.w-sample .multicart .switch-cart','font-family','$font-icons-1','3','','.w-sample'),(891076,'furniture','.w-sample .multicart .title','font-family','$font-1','','','.w-sample'),(891077,'furniture','.w-sample .qty','font-family','$font-icons-1','4','','.w-sample'),(891078,'furniture','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','trueloaded','3','','.w-cart-gift-certificate'),(891079,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','font-family','inherit','','','.b-products-listing'),(891080,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','font-family','$font-icons-1','3','','.b-pagination'),(891081,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','font-family','$font-icons-1','3','','.b-pagination'),(891082,'furniture','.w-account-personal-catalog .list-row-action ul','font-family','$font-icons-1','4','','.w-account-personal-catalog'),(891083,'furniture','.w-product-collection .right-area .btn','font-family','$font-icons-2','3','','.w-product-collection'),(891084,'furniture','.w-product-collection .right-area .btn-2','font-family','$font-icons-2','3','','.w-product-collection'),(891085,'furniture','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','font-family','$font-icons-2','3','','.w-product-custom-bundle'),(891086,'furniture','.w-delivery-location-location-list .deliveryListParrent','font-family','$font-1','','','.w-delivery-location-location-list'),(891087,'furniture','.w-support-system-filter .dd3-content .collapse_span','font-family','$font-icons-1','3','','.w-support-system-filter'),(891088,'furniture','.w-rma-returns-history .column .title','font-family','inherit','','','.w-rma-returns-history'),(891089,'furniture','.w-predefined-promotion .nextdiscount .heading','font-family','$font-icons-1','3','','.w-predefined-promotion'),(891090,'furniture','.w-supplier-purchase-supplier-products .active .select_item > div:before','font-family','$font-icons-1','','','.w-supplier-purchase-supplier-products'),(891091,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','font-family','$font-icons-1','','','.w-filters'),(891092,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','font-family','$font-icons-1','','','.w-filters'),(891093,'furniture','.order-summary .icon','font-family','$font-icons-1','3','','.order-summary'),(891094,'furniture','.w-cart-discount-coupon .title','font-family','$font-icons-1','4','','.w-cart-discount-coupon'),(891095,'furniture','.w-cart-checkout-btn .with-card','font-family','$font-icons-1','4','','.w-cart-checkout-btn'),(891110,'furniture','.account-address-book .leftMes div','font-family','$font-1','','','.account-address-book'),(891114,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-family','trueloaded','3','','.account-order-pay'),(891115,'furniture','.account-samples .orders-table th','font-family','$font-1','','','.account-samples'),(891116,'furniture','.account-samples .view_link','font-family','trueloaded','4','','.account-samples'),(891117,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-family','trueloaded','3','','.account-sample-info'),(891118,'furniture','.catalog-product-wrap .pn-direction','font-family','$font-1','','','.catalog-product-wrap'),(891119,'furniture','.catalog-product-wrap .pn-image','font-family','$font-icons-1','3','','.catalog-product-wrap'),(891120,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','font-family','$font-1','','','.checkout-index-wrap'),(891121,'furniture','.checkout-index-wrap .order-ico','font-family','$font-icons-2','3','','.checkout-index-wrap'),(891122,'furniture','.checkout-index-wrap .pay-ico','font-family','$font-icons-2','3','','.checkout-index-wrap'),(891123,'furniture','.checkout-index-wrap .ship-ico','font-family','$font-icons-2','3','','.checkout-index-wrap'),(891124,'furniture','.checkout-order-confirmation .comment-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(891125,'furniture','.checkout-order-confirmation .discount-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(891126,'furniture','.checkout-order-confirmation .order-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(891127,'furniture','.checkout-order-confirmation .ship-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(891128,'furniture','.checkout-success-wrap .page-success .text-1','font-family','trueloaded','3','','.checkout-success-wrap'),(891129,'furniture','.checkout-success-wrap .page-success .text-1, .checkout-success-wrap .page-success .text-2, .checkout-success-wrap .page-success .text-3','font-family','$font-1','','','.checkout-success-wrap'),(891130,'furniture','.shopping-cart-index .gift-code .heading-4','font-family','$font-icons-1','4','','.shopping-cart-index'),(891131,'furniture','.b-info .info','font-family','trueloaded','3','','.b-info'),(891132,'furniture','.b-info .info strong','font-family','$font-1','','','.b-info'),(891133,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-family','$font-1','','','.b-multi-page-checkout'),(891134,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-family','$font-icons-1','3','','.b-multi-page-checkout'),(891135,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-family','trueloaded','4','','.b-multi-page-checkout'),(891136,'furniture','.success-page .check-ico-block','font-family','trueloaded','3','','.success-page'),(891137,'furniture','.success-page .comment-ico','font-family','trueloaded','3','','.success-page'),(891138,'furniture','.success-page .discount-ico','font-family','trueloaded','3','','.success-page'),(891139,'furniture','.success-page .order-ico','font-family','trueloaded','3','','.success-page'),(891140,'furniture','.success-page .page-success .text-1','font-family','trueloaded','3','','.success-page'),(891141,'furniture','.success-page .page-success .text-1, .success-page .page-success .text-2, .success-page .page-success .text-3','font-family','$font-1','','','.success-page'),(891142,'furniture','.success-page .pay-ico','font-family','trueloaded','3','','.success-page'),(891143,'furniture','.success-page .prod-ico','font-family','trueloaded','3','','.success-page'),(891144,'furniture','.success-page .ship-ico','font-family','trueloaded','3','','.success-page'),(891145,'furniture','.menu-header .menu-style[data-style=\"1\"] .goto-button a','font-family','$font-icons-1','4','','.menu-header'),(891146,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > .parent > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','font-family','$font-icons-1','4','','.menu-header'),(891147,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 .parent > a, .menu-header .menu-style[data-style=\"1\"] .level-2 .parent > .no-link','font-family','$font-icons-1','4','','.menu-header'),(891148,'furniture','.w-catalog-paging .next','font-family','FontAwesome','3','','.w-catalog-paging'),(891149,'furniture','.w-catalog-paging .prev','font-family','FontAwesome','3','','.w-catalog-paging'),(891150,'furniture','.w-compare-box-item .checkbox:checked + span:before','font-family','$font-icons-1','','','.w-compare-box-item'),(891151,'furniture','.b-rating .glyphicon','font-family_important','important','','','.b-rating'),(891152,'furniture','.w-communication-new-topic td.date-purchased','font-size','14','','','.w-communication-new-topic'),(891153,'furniture','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-size','14','','','.w-communication-new-topic'),(891154,'furniture','.b-email .price','font-size','14','','','.b-email'),(891155,'furniture','.heading-4 .right-text, h4 .right-text','font-size','16','','',''),(891156,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(891157,'furniture','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(891158,'furniture','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(891160,'furniture','.b-form .middle-form label','font-size','16','','','.b-form'),(891161,'furniture','.b-email-editor .price','font-size','18','','','.b-email-editor'),(891162,'furniture','.p-quick-order-index .paginate_button.previous','font-size','20','3','','.p-quick-order-index'),(891163,'furniture','.b-email .qty','font-size','14','','','.b-email'),(891164,'furniture','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','font-size','13','','','.p-quick-order-index'),(891165,'furniture','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-size','14','','','.p-quick-order-index'),(891166,'furniture','.p-quick-order-index .paginate_button.next','font-size','20','3','','.p-quick-order-index'),(891167,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.next','font-size','0','','','.p-quick-order-index'),(891168,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.previous','font-size','0','','','.p-quick-order-index'),(891169,'furniture','.w-promotions .promo-item','font-size','24','','','.w-promotions'),(891170,'furniture','.w-text .customer-service','font-size','13','','','.w-text'),(891171,'furniture','.w-promotions .prom-multi-discount .promo-range','font-size','13','','','.w-promotions'),(891172,'furniture','.w-text .customer-service','font-size','21','3','','.w-text'),(891173,'furniture','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(891174,'furniture','.w-cart-compare .attributes-label','font-size','14','','','.w-cart-compare'),(891176,'furniture','.w-personal-gift-status-bar .end-label','font-size','14','','','.w-personal-gift-status-bar'),(891177,'furniture','.p-sample-checkout-success .page-success .text-1','font-size','60','','','.p-sample-checkout-success'),(891178,'furniture','.p-sample-checkout-success .page-success .text-3','font-size','27','','','.p-sample-checkout-success'),(891179,'furniture','.p-sample-checkout-success .page-success .text-2','font-size','34','','','.p-sample-checkout-success'),(891180,'furniture','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(891181,'furniture','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(891182,'furniture','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(891183,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(891184,'furniture','.w-promotions .prom-multi-discount .heading','font-size','26','','','.w-promotions'),(891185,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(891186,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(891187,'furniture','.b-email .heading-name','font-size','14','','','.b-email'),(891188,'furniture','.testimonials .reviews-list span','font-size','22','','',''),(891189,'furniture','.testimonials .rating','font-size','22','','',''),(891190,'furniture','.testimonials .reviews-list .date','font-size','14','','',''),(891191,'furniture','.testimonials .date','font-size','14','','',''),(891192,'furniture','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','font-size','14','','','.w-promotions'),(891193,'furniture','.w-promotions .prom-multi-discount .promo-group','font-size','16','','','.w-promotions'),(891194,'furniture','.w-promotions .nextdiscount .heading','font-size','26','','','.w-promotions'),(891195,'furniture','.w-promotions .nextdiscount .heading','font-size','18','3','','.w-promotions'),(891196,'furniture','.w-promotions .nextdiscount .promo-for-each','font-size','14','','','.w-promotions'),(891197,'furniture','.w-promotions .nextdiscount .item-holder .name','font-size','14','','','.w-promotions'),(891198,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.p-quick-order-index'),(891199,'furniture','.w-promotions .heading-3','font-size','48','','','.w-promotions'),(891200,'furniture','.w-promotions .promo-salemaker .discount','font-size','13','','','.w-promotions'),(891201,'furniture','.w-promotions .promo-salemaker .content a','font-size','14','','','.w-promotions'),(891202,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','font-size','16','','','.w-promotions'),(891203,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','font-size','13','','','.w-promotions'),(891204,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-name','font-size','16','','','.b-warehouses-popup'),(891205,'furniture','.w-promotions .promo-cart-discount .item a','font-size','14','','','.w-promotions'),(891206,'furniture','.b-warehouses-popup a.warehouses-popup-link','font-size','14','','','.b-warehouses-popup'),(891207,'furniture','.b-warehouses-popup .warehouses-popup .heading','font-size','18','','','.b-warehouses-popup'),(891208,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','font-size','14','','','.b-warehouses-popup'),(891209,'furniture','.b-preloader .preloader','font-size','40','3','','.b-preloader'),(891210,'furniture','.w-chat .w-chat-box a','font-size','20','3','','.w-chat'),(891211,'furniture','.w-cart-compare .dropdown li','font-size','14','','','.w-cart-compare'),(891212,'furniture','.w-cart-compare .attributes-cell','font-size','14','','','.w-cart-compare'),(891213,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(891214,'furniture','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(891215,'furniture','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','font-size','12','3','','.order-summary'),(891216,'furniture','.b-compare .compare-head','font-size','22','','','.b-compare'),(891217,'furniture','.b-bottom .closeable-heading','font-size','20','3','','.b-bottom'),(891218,'furniture','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(891219,'furniture','.b-messages .messBtnMenuDelete','font-size','22','3','','.b-messages'),(891220,'furniture','.b-messages .content-messages .heading-2','font-size','26','','','.b-messages'),(891221,'furniture','.b-messages span.starred::before','font-size','16','','','.b-messages'),(891222,'furniture','.b-messages .messBtnMenuStarred','font-size','22','3','','.b-messages'),(891223,'furniture','.b-messages .messBtnMenuUnread','font-size','22','3','','.b-messages'),(891224,'furniture','.b-messages .messMenuButton span','font-size','14','','','.b-messages'),(891225,'furniture','.b-messages .content_management_attach','font-size','14','','','.b-messages'),(891226,'furniture','.b-messages .content_management_attach span','font-size','16','','','.b-messages'),(891227,'furniture','.b-messages .content_management_attach button','font-size','14','','','.b-messages'),(891228,'furniture','.b-messages .select2-search-choice-close','font-size','11','3','','.b-messages'),(891229,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','font-size','14','','',''),(891230,'furniture','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(891231,'furniture','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(891232,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(891233,'furniture','.w-text .customer-service','font-size','21','3','','.w-text'),(891234,'furniture','.p-payer-order-confirmation .ship-ico','font-size','30','3','','.p-payer-order-confirmation'),(891235,'furniture','.p-payer-order-confirmation .pay-ico','font-size','30','3','','.p-payer-order-confirmation'),(891236,'furniture','.p-payer-order-confirmation .order-ico','font-size','36','3','','.p-payer-order-confirmation'),(891237,'furniture','.b-data-table table.dataTable thead td','font-size','16','','','.b-data-table'),(891238,'furniture','.p-payer-order-confirmation .discount-ico','font-size','30','3','','.p-payer-order-confirmation'),(891239,'furniture','.p-payer-order-pay .ship-ico','font-size','30','3','','.p-payer-order-pay'),(891240,'furniture','.p-payer-order-confirmation .comment-ico','font-size','30','3','','.p-payer-order-confirmation'),(891241,'furniture','.p-payer-order-pay .pay-ico','font-size','30','3','','.p-payer-order-pay'),(891242,'furniture','.p-payer-order-pay .order-ico','font-size','36','3','','.p-payer-order-pay'),(891243,'furniture','.p-payer-order-pay .comment-ico','font-size','30','3','','.p-payer-order-pay'),(891244,'furniture','.p-payer-order-pay .discount-ico','font-size','30','3','','.p-payer-order-pay'),(891245,'furniture','.w-checkout-terms .terms-box','font-size','13','','','.w-checkout-terms'),(891246,'furniture','.w-cart-cart-tabs .w-tabs .tab-a','font-size','12','5131','','.w-cart-cart-tabs'),(891247,'furniture','.order-summary .price-box .title','font-size','15','','','.order-summary'),(891248,'furniture','.b-email .heading-qty','font-size','14','','','.b-email'),(891249,'furniture','.b-email .model','font-size','14','','','.b-email'),(891250,'furniture','.b-email .heading-name','font-size','14','','','.b-email'),(891251,'furniture','.p-quote-checkout-success .page-success .text-2','font-size','30','5131','','.p-quote-checkout-success'),(891252,'furniture','.b-page-name .page-name','font-size','20','','','.b-page-name'),(891253,'furniture','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(891254,'furniture','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(891255,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','font-size','10','','','.b-switch'),(891256,'furniture','.p-quick-order-index .value','font-size','20','','','.p-quick-order-index'),(891257,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-size','20','','','.w-upload-customer-id-upload-customer-id-form'),(891258,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-template','font-size','18','','','.w-upload-customer-id-upload-customer-id-form'),(891259,'furniture','.b-switch .bootstrap-switch','font-size','16','','','.b-switch'),(891260,'furniture','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(891261,'furniture','.b-email .qty','font-size','14','','','.b-email'),(891262,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(891263,'furniture','.w-coupons-and-vauchers-checkout .btn-remove','font-size','12','','','.w-coupons-and-vauchers-checkout'),(891264,'furniture','.w-checkout-bonus-points .btn-remove','font-size','12','','','.w-checkout-bonus-points'),(891265,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','font-size','7','','','.b-switch'),(891267,'furniture','.b-form .required-message','font-size','14','','','.b-form'),(891268,'furniture','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(891269,'furniture','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(891270,'furniture','.w-text .customer-service','font-size','21','3','','.w-text'),(891271,'furniture','.w-text .customer-service b','font-size','18','','','.w-text'),(891272,'furniture','.b-email-editor .price','font-size','18','','','.b-email-editor'),(891273,'furniture','.b-info-popup .info-popup div','font-size','14','','','.b-info-popup'),(891274,'furniture','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-size','24','','','.w-multi-cart-cart-switcher'),(891275,'furniture','.p-quote-checkout-success .page-success .text-2','font-size','30','5131','','.p-quote-checkout-success'),(891276,'furniture','.w-personal-gift-status-bar .inform','font-size','24','4','','.w-personal-gift-status-bar'),(891277,'furniture','.w-promo-code .holder','font-size','30','5161,3','','.w-promo-code'),(891278,'furniture','.no-found','font-size','1.4','','',''),(891279,'furniture','.price','font-size','30','','',''),(891280,'furniture','.w-text .customer-service','font-size','13','','','.w-text'),(891281,'furniture','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(891282,'furniture','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(891283,'furniture','.w-filters .input-checkbox:checked + .checkbox-span:before','font-size','21','','','.w-filters'),(891284,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','font-size','14','','','.b-switch'),(891285,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','font-size','14','','','.b-switch'),(891286,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(891287,'furniture','.w-personal-gift-status-bar .end-date','font-size','22','3','','.w-personal-gift-status-bar'),(891288,'furniture','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(891289,'furniture','.b-email .heading-model','font-size','14','','','.b-email'),(891290,'furniture','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(891291,'furniture','.b-email .totals-label','font-size','18','','','.b-email'),(891292,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-size','18','','','.b-form'),(891293,'furniture','.w-reviews-content .rating','font-size','18','','','.w-reviews-content'),(891294,'furniture','.w-reviews-content .date','font-size','13','','','.w-reviews-content'),(891295,'furniture','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(891296,'furniture','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(891297,'furniture','.w-reviews .date','font-size','13','','','.w-reviews'),(891298,'furniture','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(891300,'furniture','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(891301,'furniture','h1','font-size','24','5140','',''),(891302,'furniture','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(891303,'furniture','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(891304,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(891305,'furniture','.w-personal-gift-status-bar .end-date','font-size','14','','','.w-personal-gift-status-bar'),(891306,'furniture','.w-cart-compare .price-cell','font-size','18','','','.w-cart-compare'),(891307,'furniture','.w-cart-compare .price-label','font-size','14','','','.w-cart-compare'),(891308,'furniture','.w-checkout-create-account .account-benefits','font-size','0.8','','','.w-checkout-create-account'),(891309,'furniture','.w-cart-listing .price','font-size','24','','','.w-cart-listing'),(891310,'furniture','.w-cart-compare .js-cart_totals_container b','font-size','16','','','.w-cart-compare'),(891311,'furniture','.p-quote-checkout-success .page-success .text-2','font-size','30','5131','','.p-quote-checkout-success'),(891312,'furniture','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(891313,'furniture','.view-all .btn','font-size','0.8','4','',''),(891314,'furniture','.btn-1','font-size','16','','',''),(891315,'furniture','.b-form .privacy-row','font-size','16','','','.b-form'),(891316,'furniture','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(891317,'furniture','.b-email .name','font-size','14','','','.b-email'),(891318,'furniture','.w-tabs .tab-li.tab-quote a','font-size','29','3','','.w-tabs'),(891319,'furniture','.w-text .customer-service b','font-size','18','','','.w-text'),(891320,'furniture','.w-text .customer-service','font-size','21','3','','.w-text'),(891321,'furniture','.w-text .customer-service','font-size','13','','','.w-text'),(891322,'furniture','.w-tabs .tab-a','font-size','16','5140','','.w-tabs'),(891323,'furniture','.w-tabs .tab-a','font-size','24','','','.w-tabs'),(891324,'furniture','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(891326,'furniture','.btn-edit','font-size','0.8','3','',''),(891327,'furniture','.w-promo-code .holder','font-size','30','5161,3','','.w-promo-code'),(891328,'furniture','.w-tabs .tab-li.tab-wishlist a','font-size','25','3','','.w-tabs'),(891329,'furniture','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(891330,'furniture','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(891331,'furniture','.w-personal-gift-status-bar .start-label','font-size','14','','','.w-personal-gift-status-bar'),(891332,'furniture','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(891333,'furniture','.heading-4 .edit, h4 .edit','font-size','16','','',''),(891334,'furniture','.heading-6, h6, .h-block h6','font-size','16','','',''),(891335,'furniture','.btn-2','font-size','24','','',''),(891336,'furniture','.w-cart-compare .cart-name a','font-size','17','','','.w-cart-compare'),(891337,'furniture','.w-cart-compare .delete-cart','font-size','12','','','.w-cart-compare'),(891338,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(891339,'furniture','.p-sample-checkout-success .page-success .text-2','font-size','30','5131','','.p-sample-checkout-success'),(891340,'furniture','.w-top-categories .categories h2','font-size','inherit','','','.w-top-categories'),(891341,'furniture','.out-stock','font-size','14','','',''),(891342,'furniture','.transit','font-size','14','','',''),(891343,'furniture','.in-stock','font-size','14','','',''),(891344,'furniture','.heading-3 .right-text, h3 .right-text','font-size','16','','',''),(891345,'furniture','.heading-3 .edit, h3 .edit','font-size','14','4','',''),(891346,'furniture','.heading-3 .edit, h3 .edit','font-size','16','','',''),(891347,'furniture','.heading-5, h5, .h-block h5','font-size','17','','',''),(891348,'furniture','.b-email .heading-model','font-size','14','','','.b-email'),(891349,'furniture','.b-email .heading-price','font-size','14','','','.b-email'),(891350,'furniture','.b-page-name .page-name','font-size','20','','','.b-page-name'),(891351,'furniture','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(891352,'furniture','.w-cart-credit-amount .text','font-size','14','','','.w-cart-credit-amount'),(891353,'furniture','.w-cart-bonus-points .btn-remove','font-size','12','','','.w-cart-bonus-points'),(891354,'furniture','.w-cart-discount-coupon .text','font-size','14','','','.w-cart-discount-coupon'),(891355,'furniture','.order-summary .price-box .price-row.total','font-size','22','','','.order-summary'),(891356,'furniture','.order-summary .price','font-size','18','','','.order-summary'),(891357,'furniture','.savings-ico .heading-2','font-size','32','3','','.savings-ico'),(891358,'furniture','.w-cart-bonus-points .text','font-size','14','','','.w-cart-bonus-points'),(891359,'furniture','.b-email .model','font-size','14','','','.b-email'),(891360,'furniture','.b-email .name','font-size','14','','','.b-email'),(891361,'furniture','.w-text .customer-service b','font-size','18','','','.w-text'),(891362,'furniture','.testimonials .heading-3','font-size','37','3','',''),(891363,'furniture','.js-stock','font-size','14','','',''),(891364,'furniture','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(891365,'furniture','.w-checkout-shipping-choice span','font-size','14','5161','','.w-checkout-shipping-choice'),(891366,'furniture','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(891367,'furniture','.w-product-reviews .reviews-list .date','font-size','14','','','.w-product-reviews'),(891368,'furniture','.b-email-editor .price','font-size','18','','','.b-email-editor'),(891369,'furniture','.b-email .model','font-size','14','','','.b-email'),(891370,'furniture','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(891371,'furniture','.heading-4, h4, .h-block h4','font-size','18','','',''),(891372,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(891373,'furniture','.b-email .price','font-size','14','','','.b-email'),(891375,'furniture','.b-email .name','font-size','14','','','.b-email'),(891376,'furniture','.btn','font-size','16','','',''),(891377,'furniture','.b-email .heading-model','font-size','14','','','.b-email'),(891378,'furniture','.b-email .price','font-size','14','','','.b-email'),(891379,'furniture','.b-email .heading-qty','font-size','14','','','.b-email'),(891381,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(891382,'furniture','.b-email .qty','font-size','14','','','.b-email'),(891383,'furniture','.b-email .heading-qty','font-size','14','','','.b-email'),(891384,'furniture','.b-email .heading-name','font-size','14','','','.b-email'),(891385,'furniture','.b-email .heading-price','font-size','14','','','.b-email'),(891386,'furniture','.b-email .totals-label','font-size','18','','','.b-email'),(891387,'furniture','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(891388,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(891389,'furniture','.w-text .customer-service','font-size','13','','','.w-text'),(891390,'furniture','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(891391,'furniture','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(891392,'furniture','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(891393,'furniture','.w-promo-code .holder','font-size','30','5161,3','','.w-promo-code'),(891394,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(891395,'furniture','.message.success','font-size','30','3','',''),(891396,'furniture','.w-reviews .heading-3','font-size','37','3','','.w-reviews'),(891397,'furniture','.b-sub-totals .historyTotal table td','font-size','18','','','.b-sub-totals'),(891398,'furniture','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(891399,'furniture','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(891400,'furniture','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(891401,'furniture','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(891402,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','40','5131','','.p-quote-checkout-success'),(891403,'furniture','.w-text .customer-service b','font-size','18','','','.w-text'),(891404,'furniture','.b-form .checkbox-style:checked + .checkbox-span:before','font-size','18','','','.b-form'),(891405,'furniture','.w-social-links a','font-size','30','5131','','.w-social-links'),(891406,'furniture','.b-email .name','font-size','14','','','.b-email'),(891407,'furniture','.b-email .heading-qty','font-size','14','','','.b-email'),(891408,'furniture','.p-quick-order-index .stock','font-size','12','','','.p-quick-order-index'),(891409,'furniture','.b-email .price','font-size','14','','','.b-email'),(891410,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','40','5131','','.p-quote-checkout-success'),(891411,'furniture','.w-cart-compare .js-cart_totals_container','font-size','14','','','.w-cart-compare'),(891412,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','40','5131','','.p-quote-checkout-success'),(891413,'furniture','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(891414,'furniture','.b-bottom .alert-message','font-size','18','','','.b-bottom'),(891415,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(891416,'furniture','.w-cart-compare .product .name a','font-size','14','','','.w-cart-compare'),(891417,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(891418,'furniture','.b-email .totals-label','font-size','18','','','.b-email'),(891419,'furniture','.w-checkout-credit-amount .btn-remove','font-size','12','','','.w-checkout-credit-amount'),(891421,'furniture','.b-info-popup .info-popup','font-size','20','3','','.b-info-popup'),(891422,'furniture','.b-email .name','font-size','14','','','.b-email'),(891423,'furniture','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(891424,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','40','5131','','.p-quote-checkout-success'),(891425,'furniture','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(891426,'furniture','.b-email .price','font-size','14','','','.b-email'),(891427,'furniture','.b-email .heading-model','font-size','14','','','.b-email'),(891428,'furniture','.b-email .heading-name','font-size','14','','','.b-email'),(891429,'furniture','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(891430,'furniture','.b-email .heading-price','font-size','14','','','.b-email'),(891431,'furniture','.b-email .model','font-size','14','','','.b-email'),(891432,'furniture','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(891433,'furniture','.order-summary .price-row.ot_coupon .title','font-size','18','3','','.order-summary'),(891434,'furniture','.w-cart-shipping-estimator .address-item','font-size','14','','','.w-cart-shipping-estimator'),(891435,'furniture','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','font-size','20','','','.b-products-listing'),(891436,'furniture','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-size','20','','','.b-products-listing'),(891437,'furniture','.b-products-listing .products-listing .attribute-qty-block','font-size','14','','','.b-products-listing'),(891438,'furniture','.w-cart-credit-amount .btn-remove','font-size','12','','','.w-cart-credit-amount'),(891439,'furniture','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(891440,'furniture','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(891441,'furniture','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(891442,'furniture','.w-text .customer-service b','font-size','18','','','.w-text'),(891443,'furniture','.p-quick-order-index .in-stock, .p-quick-order-index .out-stock','font-size','12','','','.p-quick-order-index'),(891444,'furniture','.b-email .heading-price','font-size','14','','','.b-email'),(891445,'furniture','.b-email .name','font-size','14','','','.b-email'),(891446,'furniture','.b-email .heading-name','font-size','14','','','.b-email'),(891447,'furniture','.b-form .middle-form .middle-rating span','font-size','26','','','.b-form'),(891448,'furniture','.w-product-customers-activity .customers-activity','font-size','16','','','.w-product-customers-activity'),(891449,'furniture','.w-product-available-in-warehouses .heading','font-size','18','','','.w-product-available-in-warehouses'),(891450,'furniture','.b-bottom .confirm-popup .confirm-text','font-size','20','','','.b-bottom'),(891451,'furniture','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(891452,'furniture','.b-email .qty','font-size','14','','','.b-email'),(891453,'furniture','.b-page-name .page-name','font-size','20','','','.b-page-name'),(891454,'furniture','.w-text .customer-service','font-size','13','','','.w-text'),(891455,'furniture','.w-text .customer-service','font-size','21','3','','.w-text'),(891456,'furniture','.w-text .customer-service b','font-size','18','','','.w-text'),(891457,'furniture','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(891458,'furniture','.p-sample-checkout-success .page-success .text-1','font-size','80','3','','.p-sample-checkout-success'),(891459,'furniture','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-size','22','','','.order-summary'),(891460,'furniture','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(891461,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(891462,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(891463,'furniture','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(891464,'furniture','.w-menu-horizontal .menu-ico','font-size','23','','','.w-menu-horizontal'),(891465,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(891466,'furniture','.w-promo-code .holder','font-size','30','5161,3','','.w-promo-code'),(891467,'furniture','.w-categories h2.name','font-size','18','','','.w-categories'),(891468,'furniture','.w-cart-checkout-btn a','font-size','17','5131','','.w-cart-checkout-btn'),(891469,'furniture','.price .old','font-size','0.6','','',''),(891470,'furniture','.w-cart-compare .product-actions .dropdown-toggle','font-size','18','3','','.w-cart-compare'),(891471,'furniture','.w-social-links a','font-size','20','','','.w-social-links'),(891472,'furniture','.b-fancybox .fancybox-close','font-size','26','','','.b-fancybox'),(891473,'furniture','.b-select-suggest .select2-search-choice-close','font-size','1','','','.b-select-suggest'),(891474,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-size','100','','','.b-select-suggest'),(891475,'furniture','.b-select-suggest .select2-search input','font-size','1','','','.b-select-suggest'),(891476,'furniture','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(891477,'furniture','.p-sample-checkout-success .page-success .text-1','font-size','40','5131','','.p-sample-checkout-success'),(891478,'furniture','.w-cart-compare .product-actions','font-size','12','','','.w-cart-compare'),(891479,'furniture','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(891480,'furniture','.w-personal-gift-status-bar .inform','font-size','14','','','.w-personal-gift-status-bar'),(891481,'furniture','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(891482,'furniture','.w-quote-products .empty','font-size','24','','','.w-quote-products'),(891483,'furniture','.b-bottom .footerTitle','font-size','24','','','.b-bottom'),(891484,'furniture','.w-account-addresses-list .addsess-suggestion-item','font-size','14','','','.w-account-addresses-list'),(891485,'furniture','.w-communication-post .communication-post-date','font-size','14','','','.w-communication-post'),(891486,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.b-data-table'),(891487,'furniture','.w-communication-post .communication-post-attach','font-size','14','','','.w-communication-post'),(891488,'furniture','.b-products-listing .products-listing .bonusPoints','font-size','13','','','.b-products-listing'),(891489,'furniture','.b-products-listing .products-listing .model','font-size','14','','','.b-products-listing'),(891490,'furniture','.b-products-listing .btn-preloader','font-size','24','3','','.b-products-listing'),(891491,'furniture','.b-products-listing .loader','font-size','30','4','','.b-products-listing'),(891492,'furniture','.b-products-listing .promos-info .promo-name','font-size','14','','','.b-products-listing'),(891493,'furniture','.b-products-listing .wedding-registry-count','font-size','14','','','.b-products-listing'),(891495,'furniture','.w-quote .cart-box-link','font-size','30','3','','.w-quote'),(891496,'furniture','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(891497,'furniture','.p-quote-checkout-success .page-success .text-2','font-size','30','5131','','.p-quote-checkout-success'),(891498,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','40','5131','','.p-quote-checkout-success'),(891499,'furniture','.b-email-editor .price','font-size','18','','','.b-email-editor'),(891500,'furniture','.b-form .cart-popup .price','font-size','18','','','.b-form'),(891501,'furniture','.b-email-editor .price','font-size','18','','','.b-email-editor'),(891502,'furniture','.b-email .heading-model','font-size','14','','','.b-email'),(891503,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','40','5131','','.p-quote-checkout-success'),(891504,'furniture','.w-text .customer-service','font-size','21','3','','.w-text'),(891505,'furniture','.w-top-categories h2.name','font-size','18','','','.w-top-categories'),(891506,'furniture','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(891507,'furniture','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(891508,'furniture','.w-product-reviews .reviews-list span','font-size','22','','','.w-product-reviews'),(891509,'furniture','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(891510,'furniture','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(891511,'furniture','.w-taxable .bootstrap-switch .bootstrap-switch-label','font-size','0','','','.w-taxable'),(891512,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-size','inherit','','',''),(891513,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-size','inherit','','','.b-h-inline'),(891514,'furniture','h1, .heading-1','font-size','36','','',''),(891515,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','font-size','31','','','.w-communication-new-topic'),(891516,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','font-size','31','','','.w-communication-new-topic'),(891517,'furniture','.b-page-name .page-name','font-size','20','','','.b-page-name'),(891518,'furniture','.b-email .heading-price','font-size','14','','','.b-email'),(891519,'furniture','.b-email .totals-label','font-size','18','','','.b-email'),(891520,'furniture','.b-email .price','font-size','14','','','.b-email'),(891521,'furniture','.b-email .heading-name','font-size','14','','','.b-email'),(891522,'furniture','.b-bottom .popup-heading','font-size','16','','','.b-bottom'),(891523,'furniture','.w-promo-code .holder','font-size','30','5161,3','','.w-promo-code'),(891524,'furniture','.p-quote-checkout-success .page-success .text-2','font-size','30','5131','','.p-quote-checkout-success'),(891525,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(891526,'furniture','.w-tabs .tab-li.tab-sample a','font-size','29','3','','.w-tabs'),(891527,'furniture','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(891528,'furniture','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(891529,'furniture','.b-email .model','font-size','14','','','.b-email'),(891530,'furniture','.w-cart-compare .atr-col','font-size','20','3','','.w-cart-compare'),(891531,'furniture','.w-quote .cart-box-link','font-size','25','5140,3','','.w-quote'),(891532,'furniture','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(891533,'furniture','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(891534,'furniture','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(891535,'furniture','.b-email .qty','font-size','14','','','.b-email'),(891536,'furniture','.b-email .model','font-size','14','','','.b-email'),(891537,'furniture','.b-email .totals-label','font-size','18','','','.b-email'),(891538,'furniture','.checkbox input:checked + span:before','font-size','18','','',''),(891539,'furniture','.p-quick-order-index .dataTables_info','font-size','14','','','.p-quick-order-index'),(891540,'furniture','.w-cart-listing .item .gift-wrap label','font-size','14','','','.w-cart-listing'),(891541,'furniture','.w-cart-listing .item .attributes','font-size','14','','','.w-cart-listing'),(891542,'furniture','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-size','12','','','.w-cart-listing'),(891543,'furniture','.w-cart-listing .points-earn','font-size','12','','','.w-cart-listing'),(891544,'furniture','.w-cart-listing .points-redeem','font-size','14','','','.w-cart-listing'),(891545,'furniture','.w-cart-listing .points-redeem','font-size','14','3','','.w-cart-listing'),(891546,'furniture','.w-cart-listing .remove-btn','font-size','28','','','.w-cart-listing'),(891547,'furniture','.w-cart-listing .remove-btn span','font-size','16','5140','','.w-cart-listing'),(891548,'furniture','.w-cart-give-away .ga_name','font-size','16','','','.w-cart-give-away'),(891549,'furniture','.w-cart-give-away .ga_qty','font-size','20','','','.w-cart-give-away'),(891550,'furniture','.w-cart-give-away .ga_qty','font-size','17','5131','','.w-cart-give-away'),(891551,'furniture','.w-cart-discount-coupon .btn-remove','font-size','12','','','.w-cart-discount-coupon'),(891555,'furniture','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(891556,'furniture','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(891557,'furniture','.b-upload-file .snapshot','font-size','18','','','.b-upload-file'),(891558,'furniture','.b-fancybox .fancybox-nav span','font-size','34','','','.b-fancybox'),(891559,'furniture','.b-email-editor .price','font-size','18','','','.b-email-editor'),(891560,'furniture','.b-email .heading-qty','font-size','14','','','.b-email'),(891561,'furniture','.w-promo-code .holder','font-size','30','5161,3','','.w-promo-code'),(891562,'furniture','.w-text .customer-service','font-size','13','','','.w-text'),(891563,'furniture','.w-tabs .accordion-heading','font-size','24','','','.w-tabs'),(891564,'furniture','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(891565,'furniture','.w-tabs .tab-li.tab-cart a','font-size','29','3','','.w-tabs'),(891566,'furniture','.b-compare .clear_all','font-size','16','4','','.b-compare'),(891567,'furniture','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(891568,'furniture','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(891569,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(891571,'furniture','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(891572,'furniture','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(891573,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(891574,'furniture','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(891575,'furniture','.w-checkout-create-account .account-benefits strong','font-size','18','3','','.w-checkout-create-account'),(891576,'furniture','.w-filters .head-filter-widget > span','font-size','18','5140','','.w-filters'),(891577,'furniture','.w-filters .head-filter-widget','font-size','21','5145','','.w-filters'),(891578,'furniture','.w-filters .filter-box-head','font-size','20','','','.w-filters'),(891579,'furniture','.w-filters .view_more','font-size','16','4','','.w-filters'),(891580,'furniture','.w-chat .w-chat-box a','font-size','30','5140,3','','.w-chat'),(891581,'furniture','.b-products-listing .products-listing .btn-buy','font-size','20','3','','.b-products-listing'),(891582,'furniture','.b-bottom .pop-up-close','font-size','25','','','.b-bottom'),(891583,'furniture','.w-filters .head-filter-widget','font-size','24','','','.w-filters'),(891584,'furniture','.order-summary .price-row.ot_bonus_points .title','font-size','12','3','','.order-summary'),(891585,'furniture','.b-form #payment_method .title','font-size','16','','','.b-form'),(891586,'furniture','.p-quote-checkout-success .page-success .text-2','font-size','30','5131','','.p-quote-checkout-success'),(891587,'furniture','.b-email .heading-model','font-size','14','','','.b-email'),(891588,'furniture','.b-email .heading-qty','font-size','14','','','.b-email'),(891589,'furniture','.b-page-name .page-name','font-size','20','','','.b-page-name'),(891590,'furniture','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(891591,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(891592,'furniture','.heading-3, h3, .h-block h3','font-size','20','','',''),(891593,'furniture','.heading-2, h2, .h-block h2','font-size','30','','',''),(891594,'furniture','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(891595,'furniture','.btn-3','font-size','24','','',''),(891596,'furniture','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(891597,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','font-size','20','','','.b-switch'),(891598,'furniture','.b-page-name .page-name','font-size','20','','','.b-page-name'),(891599,'furniture','.b-form .middle-form label.slim','font-size','14','','','.b-form'),(891600,'furniture','.b-email .heading-price','font-size','14','','','.b-email'),(891601,'furniture','.b-select-suggest .select2-container .select2-choice abbr','font-size','1','','','.b-select-suggest'),(891602,'furniture','.b-email .qty','font-size','14','','','.b-email'),(891603,'furniture','.b-email .totals-label','font-size','18','','','.b-email'),(891604,'furniture','.w-filters .mobileCollapse','font-size','20','4','','.w-filters'),(891605,'furniture','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-size','21','','','.w-filters'),(891606,'furniture','.b-product-images .media-popup .mp-close','font-size','50','','','.b-product-images'),(891607,'furniture','.b-product-images .media-popup .slick-dots li','font-size','30','','','.b-product-images'),(891608,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','font-size','50','3','','.b-product-images'),(891609,'furniture','.w-product-name h1','font-size','36','','','.w-product-name'),(891610,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(891611,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(891612,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(891613,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(891614,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(891615,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(891616,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(891617,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(891618,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(891619,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev63_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(891620,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','font-size','14','','','.b-menu-style-2'),(891621,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','font-size','14','','','.b-menu-style-2'),(891622,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','font-size','26','','','.b-menu-style-2'),(891623,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','font-size','20','3','','.b-menu-style-2'),(891624,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-size','20','3','','.b-menu-style-2'),(891625,'furniture','.b-trade-approval .middle-form label','font-size','16','','','.b-trade-approval'),(891626,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','font-size','14','','','.b-trade-approval'),(891627,'furniture','.w-account-personal-catalog .list-switcher a','font-size','20','','','.w-account-personal-catalog'),(891628,'furniture','.w-catalog-compare .checkbox input:checked + span:before','font-size','24','','','.w-catalog-compare'),(891629,'furniture','.w-catalog-compare .model','font-size','14','','','.w-catalog-compare'),(891630,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-size','26','3','','.w-catalog-compare'),(891631,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','font-size','0','','','.w-catalog-compare'),(891632,'furniture','.w-catalog-compare .item .compare','font-size','0','','','.w-catalog-compare'),(891633,'furniture','.w-catalog-compare .cross-box .different-all > div','font-size','15','','','.w-catalog-compare'),(891634,'furniture','.w-catalog-compare .name','font-size','12','','','.w-catalog-compare'),(891635,'furniture','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-size','40','','','.w-delivery-day'),(891636,'furniture','.w-delivery-day .ends','font-size','26','','','.w-delivery-day'),(891637,'furniture','.w-delivery-day .left-text-left','font-size','24','','','.w-delivery-day'),(891638,'furniture','.w-delivery-day .left-text-right','font-size','24','','','.w-delivery-day'),(891639,'furniture','.w-delivery-day .title','font-size','18','','','.w-delivery-day'),(891642,'furniture','.b-products-listing .products-listing .name a','font-size','18','','','.b-products-listing'),(891643,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','0','','','.b-slick'),(891644,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','20','3','','.b-slick'),(891647,'furniture','.b-products-listing .add-to-personal-catalog','font-size','22','3','','.b-products-listing'),(891648,'furniture','.b-products-listing .del-from-personal-catalog','font-size','20','3','','.b-products-listing'),(891649,'furniture','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','font-size','16','','','.b-products-listing'),(891650,'furniture','.w-cart-listing .headings .head','font-size','14','','','.w-cart-listing'),(891651,'furniture','.b-products-listing .products-listing a.btn.view-button','font-size','22','3','','.b-products-listing'),(891652,'furniture','.LeftCategories .w-menu-simple ul li a','font-size','18','','','.LeftCategories'),(891653,'furniture','.w-subscribers .btn-submit','font-size','16','','','.w-subscribers'),(891654,'furniture','.w-quote .buttons .btn','font-size','14','','','.w-quote'),(891655,'furniture','.w-quote .cart-box-link','font-size','18','','','.w-quote'),(891656,'furniture','.w-quote .cart-total','font-size','1.2','','','.w-quote'),(891657,'furniture','.w-quote .multicart .count','font-size','14','','','.w-quote'),(891658,'furniture','.w-quote .qty','font-size','0.6','4','','.w-quote'),(891659,'furniture','.w-quote .sub-total-row','font-size','18','','','.w-quote'),(891661,'furniture','.w-product-personal-catalog-button .btn','font-size','16','','','.w-product-personal-catalog-button'),(891662,'furniture','.w-product-personal-catalog-button .btn','font-size','20','3','','.w-product-personal-catalog-button'),(891663,'furniture','.b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(891664,'furniture','.b-quantity .qty-box .smaller','font-size','31','','','.b-quantity'),(891665,'furniture','.rating, .ratingCounts','font-size','14','','',''),(891666,'furniture','.w-product-sale-ends .ends','font-size','24','','','.w-product-sale-ends'),(891667,'furniture','.w-product-sale-ends .left-count-days','font-size','30','','','.w-product-sale-ends'),(891668,'furniture','.w-product-sale-ends .left-count-hours','font-size','30','','','.w-product-sale-ends'),(891669,'furniture','.w-product-sale-ends .left-text-left','font-size','24','','','.w-product-sale-ends'),(891670,'furniture','.w-product-sale-ends .left-text-right','font-size','24','','','.w-product-sale-ends'),(891671,'furniture','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(891672,'furniture','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(891673,'furniture','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(891674,'furniture','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(891675,'furniture','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(891676,'furniture','.w-product-quantity .qty-box .smaller, .w-product-quantity .qty-box .bigger','font-size','40','','','.w-product-quantity'),(891677,'furniture','.w-product-quantity .qty-input input[type=\'text\']','font-size','18','','','.w-product-quantity'),(891678,'furniture','.w-product-bonus-points > div','font-size','14','','','.w-product-bonus-points'),(891679,'furniture','.warrantyProduct .title','font-size','18','','','.warrantyProduct'),(891680,'furniture','.warrantyProduct .seeDetails a','font-size','14','','','.warrantyProduct'),(891681,'furniture','.w-compare .price','font-size','18','','','.w-compare'),(891682,'furniture','.w-compare .name','font-size','14','','','.w-compare'),(891683,'furniture','.w-compare .clear-compare-button','font-size','14','','','.w-compare'),(891684,'furniture','.w-files-catalog-widgets-files-catalog .name','font-size','16','','','.w-files-catalog-widgets-files-catalog'),(891685,'furniture','.w-files-catalog-widgets-files-list .name','font-size','18','','','.w-files-catalog-widgets-files-list'),(891686,'furniture','.w-sample .buttons .btn','font-size','14','','','.w-sample'),(891687,'furniture','.w-sample .cart-box-link','font-size','18','','','.w-sample'),(891688,'furniture','.w-sample .cart-box-link','font-size','30','3','','.w-sample'),(891689,'furniture','.w-sample .cart-total','font-size','1.2','','','.w-sample'),(891690,'furniture','.w-sample .multicart .count','font-size','14','','','.w-sample'),(891691,'furniture','.w-sample .qty','font-size','0.7','4','','.w-sample'),(891692,'furniture','.w-sample .sub-total-row','font-size','18','','','.w-sample'),(891693,'furniture','.w-sample .cart-box-link','font-size','25','5140,3','','.w-sample'),(891694,'furniture','.w-filters-simple .integrate-price-holder','font-size','20','','','.w-filters-simple'),(891695,'furniture','.w-filters-simple .integrate-price','font-size','30','','','.w-filters-simple'),(891696,'furniture','.w-cart-discount-coupon .title','font-size','20','','','.w-cart-discount-coupon'),(891697,'furniture','.w-cart-sub-total .title','font-size','24','','','.w-cart-sub-total'),(891698,'furniture','.w-cart-sub-total .price','font-size','30','','','.w-cart-sub-total'),(891699,'furniture','.w-cart-bonus-points .title','font-size','20','','','.w-cart-bonus-points'),(891700,'furniture','.shipping-ico .heading-3','font-size','24','','','.shipping-ico'),(891701,'furniture','.w-cart-up-sell .products-listing .price','font-size','18','','','.w-cart-up-sell'),(891702,'furniture','.w-cart-up-sell .products-listing .name a','font-size','16','','','.w-cart-up-sell'),(891703,'furniture','.w-cart-gift-certificate .heading-4','font-size','20','','','.w-cart-gift-certificate'),(891704,'furniture','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(891705,'furniture','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(891706,'furniture','.w-cart-order-reference .heading-4','font-size','20','','','.w-cart-order-reference'),(891707,'furniture','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(891708,'furniture','.w-product-bundle .bundle_price .old','font-size','0.8','','','.w-product-bundle'),(891709,'furniture','.w-product-in-bundles .bundle_price .old','font-size','0.6','','','.w-product-in-bundles'),(891710,'furniture','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(891711,'furniture','.w-product-quantity-discounts .count','font-size','18','','','.w-product-quantity-discounts'),(891713,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','font-size','inherit','','','.b-products-listing'),(891714,'furniture','.b-pagination .pagination .next a, .b-pagination .pagination .next span','font-size','0','','','.b-pagination'),(891715,'furniture','.b-pagination .pagination .prev a, .b-pagination .pagination .prev span','font-size','0','','','.b-pagination'),(891716,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','font-size','20','3','','.b-pagination'),(891717,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','font-size','20','3','','.b-pagination'),(891718,'furniture','.w-catalog-compare .price','font-size','20','','','.w-catalog-compare'),(891719,'furniture','.w-catalog-compare .out-stock','font-size','12','','','.w-catalog-compare'),(891720,'furniture','.w-product-properties-filters-widgets-chosen-filters .remove','font-size','0','','','.w-product-properties-filters-widgets-chosen-filters'),(891721,'furniture','.w-product-properties-filters-widgets-chosen-filters .remove','font-size','20','3','','.w-product-properties-filters-widgets-chosen-filters'),(891722,'furniture','.w-product-multi-inventory .radio-attributes > span','font-size','18','','','.w-product-multi-inventory'),(891723,'furniture','.w-product-sale-ends .left-text-right, .w-product-sale-ends .left-text-left','font-size','18','5145','','.w-product-sale-ends'),(891724,'furniture','.w-product-sale-ends .left-count-days, .w-product-sale-ends .left-count-hours','font-size','24','5145','','.w-product-sale-ends'),(891725,'furniture','.w-product-sale-ends .ends','font-size','21','5145','','.w-product-sale-ends'),(891726,'furniture','.heading-2, h2, .h-block h2','font-size','21','5140','',''),(891727,'furniture','.heading-3, h3, .h-block h3','font-size','19','5140','',''),(891728,'furniture','.heading-4, h4, .h-block h4','font-size','17','5140','',''),(891729,'furniture','.w-product-name h1','font-size','24','5140','','.w-product-name'),(891730,'furniture','.b-products-listing .products-listing.list-rows .stock','font-size','14','','','.b-products-listing'),(891731,'furniture','.b-products-listing .products-listing.list-b2b .stock','font-size','14','','','.b-products-listing'),(891732,'furniture','.b-products-listing .products-listing .radio-attributes > span','font-size','18','','','.b-products-listing'),(891733,'furniture','.b-products-listing .products-listing .radio-attributes .option','font-size','14','','','.b-products-listing'),(891734,'furniture','.w-product-collection .stock > span','font-size','14','','','.w-product-collection'),(891735,'furniture','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(891736,'furniture','.w-product-collection .right-area .special','font-size','36','','','.w-product-collection'),(891737,'furniture','.w-product-collection .right-area .separate-text, .w-product-collection .right-area .separate','font-size','16','','','.w-product-collection'),(891738,'furniture','.w-product-collection .together','font-size','16','','','.w-product-collection'),(891739,'furniture','.w-product-collection .right-area .btn','font-size','24','','','.w-product-collection'),(891740,'furniture','.price .special-promote','font-size','16','','',''),(891741,'furniture','.w-breadcrumb .catalog-breadcrumb','font-size','14','5131','','.w-breadcrumb'),(891742,'furniture','.w-product-attributes .radio-attributes > span','font-size','18','','','.w-product-attributes'),(891743,'furniture','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(891744,'furniture','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(891745,'furniture','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(891746,'furniture','.w-product-properties li','font-size','14','','','.w-product-properties'),(891747,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','font-size','0','','','.w-questionnaire-widgets-questionnaire'),(891748,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','font-size','30','3','','.w-questionnaire-widgets-questionnaire'),(891749,'furniture','.w-product-groups .radioBoxHead','font-size','16','','','.w-product-groups'),(891750,'furniture','.w-product-groups .val1','font-size','16','','','.w-product-groups'),(891751,'furniture','.w-product-groups .val2','font-size','16','','','.w-product-groups'),(891752,'furniture','.w-product-groups .radioBox label .containerBlock img + .name + .val2','font-size','16','','','.w-product-groups'),(891753,'furniture','.b-products-listing .mix-attributes .attribute-qty-block > span','font-size','13','','','.b-products-listing'),(891754,'furniture','.w-product-custom-bundle .heading-3','font-size','16','','','.w-product-custom-bundle'),(891755,'furniture','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(891756,'furniture','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(891757,'furniture','.w-product-custom-bundle .right-area .separate-text','font-size','16','','','.w-product-custom-bundle'),(891758,'furniture','.w-product-custom-bundle .right-area .separate','font-size','36','','','.w-product-custom-bundle'),(891759,'furniture','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','font-size','24','','','.w-product-custom-bundle'),(891760,'furniture','.w-delivery-location-top-location-list .deliveryName','font-size','18','','','.w-delivery-location-top-location-list'),(891761,'furniture','.w-delivery-location-location-list .deliveryName','font-size','18','','','.w-delivery-location-location-list'),(891762,'furniture','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(891763,'furniture','.w-delivery-location-location-list .deliveryListParrent a','font-size','24','','','.w-delivery-location-location-list'),(891764,'furniture','.w-delivery-location-location-list .deliveryListParrent a','font-size','18','5140','','.w-delivery-location-location-list'),(891765,'furniture','.w-delivery-location-location-list .deliveryList li','font-size','14','5140','','.w-delivery-location-location-list'),(891766,'furniture','.w-delivery-location-featured-list .deliveryName','font-size','18','','','.w-delivery-location-featured-list'),(891767,'furniture','.btn-2','font-size','16','5131','',''),(891768,'furniture','.w-sale-category .badge','font-size','20','','','.w-sale-category'),(891769,'furniture','.w-sale-category .ends','font-size','26','','','.w-sale-category'),(891770,'furniture','.w-sale-category .left-count-days','font-size','40','','','.w-sale-category'),(891771,'furniture','.w-sale-category .left-count-hours','font-size','40','','','.w-sale-category'),(891772,'furniture','.w-sale-category .left-text-left','font-size','24','','','.w-sale-category'),(891773,'furniture','.w-sale-category .left-text-right','font-size','24','','','.w-sale-category'),(891774,'furniture','.w-sale-category .name','font-size','20','','','.w-sale-category'),(891775,'furniture','.w-sale-category .old','font-size','45','','','.w-sale-category'),(891776,'furniture','.w-sale-category .percents','font-size','30','','','.w-sale-category'),(891777,'furniture','.w-sale-category .special-price','font-size','70','','','.w-sale-category'),(891778,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-name','font-size','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(891779,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-name','font-size','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(891780,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description + div','font-size','18','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(891781,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description + div','font-size','18','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(891782,'furniture','.w-delivery-location-list-by-page .name','font-size','18','','','.w-delivery-location-list-by-page'),(891783,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','font-size','14','','','.w-product-properties-icons'),(891784,'furniture','.w-delivery-location-cross-pages .name','font-size','18','','','.w-delivery-location-cross-pages'),(891785,'furniture','.w-cart-credit-amount .amount-title','font-size','20','','','.w-cart-credit-amount'),(891786,'furniture','.w-catalog-delivery-locations .name','font-size','18','','','.w-catalog-delivery-locations'),(891787,'furniture','.w-product-bonus-points .bonus-points-cost','font-size','16','','','.w-product-bonus-points'),(891788,'furniture','.w-product-bonus-points .bonus-points-cost','font-size','14','5161','','.w-product-bonus-points'),(891789,'furniture','.w-product-designer-designer .grnamebox .title-sortable','font-size','16','','','.w-product-designer-designer'),(891790,'furniture','.w-product-designer-designer .prodDesignerType label','font-size','14','','','.w-product-designer-designer'),(891791,'furniture','.w-press-reviews-widgets-press-reviews .date','font-size','13','','','.w-press-reviews-widgets-press-reviews'),(891792,'furniture','.w-press-reviews-widgets-press-reviews .heading-3','font-size','30','','','.w-press-reviews-widgets-press-reviews'),(891793,'furniture','.w-press-reviews-widgets-press-reviews .rating','font-size','18','','','.w-press-reviews-widgets-press-reviews'),(891794,'furniture','.w-press-reviews-widgets-press-reviews-list .product-name','font-size','20','','','.w-press-reviews-widgets-press-reviews-list'),(891795,'furniture','.b-products-listing .productGroup label a','font-size','12','','','.b-products-listing'),(891796,'furniture','.w-support-system-filter .filter_cats.level-0 > li > a','font-size','18','','','.w-support-system-filter'),(891797,'furniture','.w-communication-post .btn.refresh','font-size','30','','','.w-communication-post'),(891798,'furniture','.w-rma-returns-history .btn','font-size','13','','','.w-rma-returns-history'),(891799,'furniture','.w-rma-returns-history .column .title','font-size','14','','','.w-rma-returns-history'),(891800,'furniture','.w-rma-returns-history .fromTo label >span','font-size','12','','','.w-rma-returns-history'),(891801,'furniture','.w-rma-returns-history .icons .excel','font-size','20','3','','.w-rma-returns-history'),(891802,'furniture','.w-rma-returns-history .icons .print','font-size','20','3','','.w-rma-returns-history'),(891803,'furniture','.w-rma-returns-history .icons a','font-size','0','','','.w-rma-returns-history'),(891804,'furniture','.w-rma-returns-history .sorting_1','font-size','13','','','.w-rma-returns-history'),(891805,'furniture','.w-rma-returns-history .tableTitle','font-size','18','','','.w-rma-returns-history'),(891806,'furniture','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(891807,'furniture','.b-products-listing .products-listing .bonus-points-cost','font-size','13','','','.b-products-listing'),(891808,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-name','font-size','20','','','.w-catalog-pages-category-pages-list'),(891809,'furniture','.w-predefined-promotion .heading-3','font-size','48','','','.w-predefined-promotion'),(891810,'furniture','.w-predefined-promotion .nextdiscount .heading','font-size','18','3','','.w-predefined-promotion'),(891811,'furniture','.w-predefined-promotion .nextdiscount .heading','font-size','26','','','.w-predefined-promotion'),(891812,'furniture','.w-predefined-promotion .nextdiscount .item-holder .name','font-size','14','','','.w-predefined-promotion'),(891813,'furniture','.w-predefined-promotion .nextdiscount .promo-for-each','font-size','14','','','.w-predefined-promotion'),(891814,'furniture','.w-predefined-promotion .prom-multi-discount .heading','font-size','26','','','.w-predefined-promotion'),(891815,'furniture','.w-predefined-promotion .prom-multi-discount .promo-group','font-size','16','','','.w-predefined-promotion'),(891816,'furniture','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','font-size','14','','','.w-predefined-promotion'),(891817,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','font-size','13','','','.w-predefined-promotion'),(891818,'furniture','.w-predefined-promotion .promo-cart-discount .item a','font-size','14','','','.w-predefined-promotion'),(891819,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','font-size','13','','','.w-predefined-promotion'),(891820,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','font-size','16','','','.w-predefined-promotion'),(891821,'furniture','.w-predefined-promotion .promo-item','font-size','24','','','.w-predefined-promotion'),(891822,'furniture','.w-predefined-promotion .promo-salemaker .content a','font-size','14','','','.w-predefined-promotion'),(891823,'furniture','.w-predefined-promotion .promo-salemaker .discount','font-size','13','','','.w-predefined-promotion'),(891824,'furniture','.w-supplier-purchase-supplier-products .active .select_item > div:before','font-size','20','','','.w-supplier-purchase-supplier-products'),(891825,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','font-size','28','','','.w-filters'),(891826,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','font-size','28','','','.w-filters'),(891827,'furniture','.mainBanner .bottomBox .btn','font-size','1.56','','','.mainBanner'),(891828,'furniture','.mainBanner .title','font-size','2.2','','','.mainBanner'),(891829,'furniture','.mainBanner .title > span','font-size','1.6','','','.mainBanner'),(891830,'furniture','.mainBanner .topBox > .left','font-size','3.13','','','.mainBanner'),(891831,'furniture','.mainBanner .topBox > .right','font-size','24','','','.mainBanner'),(891832,'furniture','.mainBanner .topBox > .right','font-size','20','5145','','.mainBanner'),(891833,'furniture','.mainBanner .bottomBox .btn','font-size','2.848','5131','','.mainBanner'),(891834,'furniture','.mainBanner .title','font-size','4.177','5131','','.mainBanner'),(891835,'furniture','.mainBanner .title > span','font-size','3.038','5131','','.mainBanner'),(891836,'furniture','.mainBanner .topBox > .left','font-size','5.697','5131','','.mainBanner'),(891837,'furniture','.mainBanner .topBox > .right','font-size','14','5131','','.mainBanner'),(891838,'furniture','.mainBanner .bottomBox .btn','font-size','14','5161','','.mainBanner'),(891839,'furniture','.mainBanner .bottomBox .btn','font-size','24','5206','','.mainBanner'),(891840,'furniture','.mainBanner .title','font-size','36','5206','','.mainBanner'),(891841,'furniture','.mainBanner .title > span','font-size','27','5206','','.mainBanner'),(891842,'furniture','.mainBanner .topBox > .left','font-size','42','5206','','.mainBanner'),(891843,'furniture','.order-summary .icon','font-size','18','3','','.order-summary'),(891844,'furniture','.order-summary .w-cart-listing .price','font-size','16','','','.order-summary'),(891845,'furniture','.order-summary .btn-2','font-size','20','5145','','.order-summary'),(891846,'furniture','.order-summary .heading-2','font-size','24','5145','','.order-summary'),(891847,'furniture','.w-cart-discount-coupon .title','font-size','24','4','','.w-cart-discount-coupon'),(891848,'furniture','.w-cart-listing .promos-info .promo-name','font-size','11','','','.w-cart-listing'),(891849,'furniture','.w-cart-listing .remove-btn','font-size','16','5140,3','','.w-cart-listing'),(891850,'furniture','.w-cart-checkout-btn .with-card','font-size','21','4','','.w-cart-checkout-btn'),(891851,'furniture','.w-product-promotion-icons .promos-info .promo-name','font-size','14','','','.w-product-promotion-icons'),(891852,'furniture','.w-product-quantity-discounts .item .price','font-size','24','','','.w-product-quantity-discounts'),(891874,'furniture','.account-address-book .address_book .btn-edit, .account-address-book .address_book .btn-delete','font-size','16','4','','.account-address-book'),(891875,'furniture','.account-address-book .address_book h2','font-size','18','','','.account-address-book'),(891876,'furniture','.account-address-book .leftMes div','font-size','18','','','.account-address-book'),(891889,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-size','18','','','.account-order-pay'),(891890,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-size','22','3','','.account-order-pay'),(891891,'furniture','.account-order-pay .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-order-pay'),(891892,'furniture','.account-order-pay .history_attr','font-size','14','','','.account-order-pay'),(891893,'furniture','.account-order-pay .not_fully_paid_td','font-size','30','','','.account-order-pay'),(891894,'furniture','.account-samples .not_fully_paid_td','font-size','30','','','.account-samples'),(891895,'furniture','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','font-size','16','','','.account-samples'),(891896,'furniture','.account-samples .order_history_table h2','font-size','24','','','.account-samples'),(891897,'furniture','.account-samples .order_history_table th','font-size','16','','','.account-samples'),(891898,'furniture','.account-samples .view_link','font-size','18','4','','.account-samples'),(891899,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-size','18','','','.account-sample-info'),(891900,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-size','22','3','','.account-sample-info'),(891901,'furniture','.account-sample-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-sample-info'),(891902,'furniture','.account-sample-info .history_attr','font-size','14','','','.account-sample-info'),(891903,'furniture','.account-sample-info .not_fully_paid_td','font-size','30','','','.account-sample-info'),(891904,'furniture','.account-sample-info .popup-tracking-number-link','font-size','18','','','.account-sample-info'),(891905,'furniture','.account-sample-info .trackings-nambers-label','font-size','20','','','.account-sample-info'),(891906,'furniture','.catalog-product-wrap .pn-direction','font-size','14','','','.catalog-product-wrap'),(891907,'furniture','.catalog-product-wrap .pn-image','font-size','14','3','','.catalog-product-wrap'),(891908,'furniture','.catalog-product-wrap .pn-name','font-size','14','','','.catalog-product-wrap'),(891909,'furniture','.catalog-product-wrap .pn-direction','font-size','10','5140','','.catalog-product-wrap'),(891910,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','font-size','16','','','.checkout-index-wrap'),(891911,'furniture','.checkout-index-wrap .order-ico','font-size','36','3','','.checkout-index-wrap'),(891912,'furniture','.checkout-index-wrap .pay-ico','font-size','30','3','','.checkout-index-wrap'),(891913,'furniture','.checkout-index-wrap .ship-ico','font-size','30','3','','.checkout-index-wrap'),(891914,'furniture','.checkout-order-confirmation .comment-ico','font-size','30','3','','.checkout-order-confirmation'),(891915,'furniture','.checkout-order-confirmation .discount-ico','font-size','30','3','','.checkout-order-confirmation'),(891916,'furniture','.checkout-order-confirmation .order-ico','font-size','36','3','','.checkout-order-confirmation'),(891917,'furniture','.checkout-order-confirmation .price-box','font-size','16','','','.checkout-order-confirmation'),(891918,'furniture','.checkout-order-confirmation .price-box .price','font-size','16','','','.checkout-order-confirmation'),(891919,'furniture','.checkout-order-confirmation .price-box .price-row.total','font-size','22','','','.checkout-order-confirmation'),(891920,'furniture','.checkout-order-confirmation .ship-ico','font-size','30','3','','.checkout-order-confirmation'),(891921,'furniture','.checkout-success-wrap .page-success .text-1','font-size','80','3','','.checkout-success-wrap'),(891922,'furniture','.checkout-success-wrap .page-success .text-1','font-size','60','','','.checkout-success-wrap'),(891923,'furniture','.checkout-success-wrap .page-success .text-2','font-size','34','','','.checkout-success-wrap'),(891924,'furniture','.checkout-success-wrap .page-success .text-3','font-size','27','','','.checkout-success-wrap'),(891925,'furniture','.checkout-success-wrap .page-success .text-1','font-size','40','5131','','.checkout-success-wrap'),(891926,'furniture','.checkout-success-wrap .page-success .text-2','font-size','30','5131','','.checkout-success-wrap'),(891927,'furniture','.checkout-login-wrap .password-forgotten-link','font-size','14','','','.checkout-login-wrap'),(891928,'furniture','.shopping-cart-index .cart-page .empty','font-size','24','','','.shopping-cart-index'),(891929,'furniture','.shopping-cart-index .gift-code .heading-4','font-size','20','5131','','.shopping-cart-index'),(891930,'furniture','.b-info .info','font-size','30','3','','.b-info'),(891931,'furniture','.b-info .info strong','font-size','18','','','.b-info'),(891932,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-size','24','','','.b-multi-page-checkout'),(891933,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-size','0.7','4','','.b-multi-page-checkout'),(891934,'furniture','.success-page .check-ico-block','font-size','60','3','','.success-page'),(891935,'furniture','.success-page .comment-ico','font-size','30','3','','.success-page'),(891936,'furniture','.success-page .discount-ico','font-size','30','3','','.success-page'),(891937,'furniture','.success-page .order-ico','font-size','36','3','','.success-page'),(891938,'furniture','.success-page .order_totals .price','font-size','18','','','.success-page'),(891939,'furniture','.success-page .page-success .text-1','font-size','30','','','.success-page'),(891940,'furniture','.success-page .page-success .text-1','font-size','36','3','','.success-page'),(891941,'furniture','.success-page .page-success .text-1','font-size','40','5131','','.success-page'),(891942,'furniture','.success-page .page-success .text-2','font-size','24','','','.success-page'),(891943,'furniture','.success-page .page-success .text-2','font-size','30','5131','','.success-page'),(891944,'furniture','.success-page .page-success .text-3','font-size','20','','','.success-page'),(891945,'furniture','.success-page .pay-ico','font-size','30','3','','.success-page'),(891946,'furniture','.success-page .price-box','font-size','16','','','.success-page'),(891947,'furniture','.success-page .price-box .price','font-size','16','','','.success-page'),(891948,'furniture','.success-page .price-box .price-row.total','font-size','22','','','.success-page'),(891949,'furniture','.success-page .price-row.total .price b','font-size','22','','','.success-page'),(891950,'furniture','.success-page .prod-ico','font-size','30','3','','.success-page'),(891951,'furniture','.success-page .ship-ico','font-size','30','3','','.success-page'),(891952,'furniture','.success-page .w-cart-listing .history_attr','font-size','13','','','.success-page'),(891953,'furniture','.success-page .w-cart-listing .name a','font-size','14','','','.success-page'),(891954,'furniture','.success-page .w-cart-listing .price','font-size','16','','','.success-page'),(891955,'furniture','.success-page .w-cart-listing .qty','font-size','14','','','.success-page'),(891956,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > li > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > li > .no-link','font-size','20','','','.menu-header'),(891957,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','font-size','16','','','.menu-header'),(891958,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > li > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > li > .no-link','font-size','16','5145','','.menu-header'),(891959,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li > a, .footer-menu .menu-style[data-style=\"3\"] .level-1 > li > .no-link','font-size','24','','','.footer-menu'),(891960,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','font-size','44','5140,3','','.footer-menu'),(891961,'furniture','.lowestPricedBox .w-banner .ybg .btn','font-size','18','','','.lowestPricedBox'),(891962,'furniture','.lowestPricedBox .w-banner .ybg .btn','font-size','16','5131','','.lowestPricedBox'),(891963,'furniture','.lowestPricedBox .w-banner .ybg .btn','font-size','16','5140','','.lowestPricedBox'),(891964,'furniture','.lowestPricedBox .w-banner .ybg .btn','font-size','1.2','5145','','.lowestPricedBox'),(891965,'furniture','.lowestPricedBox .w-banner .ybg .btn','font-size','14','5161','','.lowestPricedBox'),(891966,'furniture','.lowestPricedBox .w-banner .ybg .descr','font-size','1.1','','','.lowestPricedBox'),(891967,'furniture','.lowestPricedBox .w-banner .ybg .descr','font-size','16','5131','','.lowestPricedBox'),(891968,'furniture','.lowestPricedBox .w-banner .ybg .descr','font-size','16','5140','','.lowestPricedBox'),(891969,'furniture','.lowestPricedBox .w-banner .ybg .descr','font-size','14','5161','','.lowestPricedBox'),(891970,'furniture','.lowestPricedBox .w-banner .ybg .descr','font-size','22','5206','','.lowestPricedBox'),(891971,'furniture','.lowestPricedBox .w-banner .ybg .title','font-size','1.5','','','.lowestPricedBox'),(891972,'furniture','.lowestPricedBox .w-banner .ybg .title','font-size','21','5131','','.lowestPricedBox'),(891973,'furniture','.lowestPricedBox .w-banner .ybg .title','font-size','21','5140','','.lowestPricedBox'),(891974,'furniture','.lowestPricedBox .w-banner .ybg .title','font-size','18','5161','','.lowestPricedBox'),(891975,'furniture','.lowestPricedBox .w-banner .ybg .title','font-size','28','5206','','.lowestPricedBox'),(891976,'furniture','.tripleBanner .w-html_box > div:nth-child(1)','font-size','18','','','.tripleBanner'),(891977,'furniture','.tripleBanner .w-html_box > div:nth-child(2)','font-size','20','','','.tripleBanner'),(891978,'furniture','.shopByCollectionBox .bannerButton a','font-size','18','','','.shopByCollectionBox'),(891979,'furniture','.shopByCollectionBox .bannerButton a','font-size','16','5145','','.shopByCollectionBox'),(891980,'furniture','.shopByCollectionBox .content .title','font-size','18','','','.shopByCollectionBox'),(891981,'furniture','.shopByCollectionBox .content .title','font-size','16','5145','','.shopByCollectionBox'),(891982,'furniture','.shopByCollectionBox .content .title span','font-size','36','','','.shopByCollectionBox'),(891983,'furniture','.shopByCollectionBox .content .title span','font-size','24','5145','','.shopByCollectionBox'),(891995,'furniture','.w-catalog-paging .next','font-size','20','3','','.w-catalog-paging'),(891996,'furniture','.w-catalog-paging .prev','font-size','20','3','','.w-catalog-paging'),(891997,'furniture','.w-compare-box-item .cb_title','font-size','16','','','.w-compare-box-item'),(891998,'furniture','.w-compare-box-item .checkbox:checked + span:before','font-size','18','','','.w-compare-box-item'),(892000,'furniture','.b-rating .glyphicon','font-style','normal','','','.b-rating'),(892001,'furniture','.b-switch .candlestick-wrapper .fa-times','font-style','normal','3','','.b-switch'),(892002,'furniture','.b-switch .candlestick-wrapper .fa-check','font-style','normal','3','','.b-switch'),(892003,'furniture','.b-select-suggest .select2-results li em','font-style','normal','','','.b-select-suggest'),(892004,'furniture','.heading-4 .right-text, h4 .right-text','font-weight','400','','',''),(892005,'furniture','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(892006,'furniture','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(892007,'furniture','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(892008,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','font-weight','600','','','.b-switch'),(892009,'furniture','.w-multi-cart-cart-switcher .dropdown-menu a','font-weight','bold','','','.w-multi-cart-cart-switcher'),(892010,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(892011,'furniture','.p-quick-order-index .filters label','font-weight','700','','','.p-quick-order-index'),(892012,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.p-quick-order-index'),(892013,'furniture','.w-promotions .prom-multi-discount .promo-range .value','font-weight','bold','','','.w-promotions'),(892014,'furniture','.w-promotions .promo-date','font-weight','500','','','.w-promotions'),(892015,'furniture','.w-personal-gift-status-bar .end-label','font-weight','bold','','','.w-personal-gift-status-bar'),(892016,'furniture','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(892017,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(892018,'furniture','.testimonials .reviews-list span','font-weight','400','','',''),(892019,'furniture','.testimonials .rating','font-weight','400','','',''),(892020,'furniture','.testimonials .name','font-weight','700','','',''),(892021,'furniture','.testimonials .heading-3','font-weight','400','3','',''),(892022,'furniture','.testimonials .reviews-list .name','font-weight','700','','',''),(892023,'furniture','.w-promotions .prom-multi-discount .heading','font-weight','300','','','.w-promotions'),(892024,'furniture','.w-promotions .heading-3','font-weight','bold','','','.w-promotions'),(892025,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.p-quick-order-index'),(892026,'furniture','.w-promotions .promo-salemaker .promo-manufacturers .heading','font-weight','300','','','.w-promotions'),(892027,'furniture','.w-promotions .promo-salemaker .promo-conditions','font-weight','300','','','.w-promotions'),(892028,'furniture','.w-promotions .promo-salemaker .discount .value','font-weight','700','','','.w-promotions'),(892029,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder .value','font-weight','bold','','','.w-promotions'),(892030,'furniture','.w-promotions .promo-cart-discount .slave .heading','font-weight','300','','','.w-promotions'),(892031,'furniture','.w-promotions .promo-cart-discount .promo-min-qty .value','font-weight','bold','','','.w-promotions'),(892032,'furniture','.w-promotions .promo-cart-discount .master .heading','font-weight','300','','','.w-promotions'),(892033,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','font-weight','bold','','','.b-warehouses-popup'),(892034,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-name','font-weight','bold','','','.b-warehouses-popup'),(892035,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','font-weight','bold','','','.b-warehouses-popup'),(892036,'furniture','.b-warehouses-popup .warehouses-popup .heading','font-weight','bold','','','.b-warehouses-popup'),(892037,'furniture','.b-warehouses-popup a.warehouses-popup-link','font-weight','bold','','','.b-warehouses-popup'),(892038,'furniture','.w-product-available-in-warehouses .warehouse-name','font-weight','bold','','','.w-product-available-in-warehouses'),(892039,'furniture','.w-checkout-create-account .account-benefits strong','font-weight','normal','','','.w-checkout-create-account'),(892040,'furniture','.w-cart-listing .name a','font-weight','bold','','','.w-cart-listing'),(892041,'furniture','.b-messages .messBtnMenuDelete','font-weight','normal','3','','.b-messages'),(892042,'furniture','.b-messages span.starred::before','font-weight','normal','','','.b-messages'),(892043,'furniture','.b-messages .messBtnMenuStarred','font-weight','normal','3','','.b-messages'),(892044,'furniture','.b-messages .messMenuButton span','font-weight','600','','','.b-messages'),(892045,'furniture','.b-messages .messBtnMenuUnread','font-weight','normal','3','','.b-messages'),(892046,'furniture','.b-messages .messages-menu li a','font-weight','bold','2','','.b-messages'),(892047,'furniture','.b-messages .content_management_attach','font-weight','600','','','.b-messages'),(892048,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','font-weight','600','','','.b-messages'),(892049,'furniture','.w-reviews .author','font-weight','bold','','','.w-reviews'),(892050,'furniture','.order-summary .price-box .price-row.total','font-weight','600','','','.order-summary'),(892051,'furniture','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(892052,'furniture','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(892053,'furniture','.p-payer-order-confirmation .cardinfo-label','font-weight','bold','','','.p-payer-order-confirmation'),(892054,'furniture','.p-payer-order-pay .cardinfo-label','font-weight','bold','','','.p-payer-order-pay'),(892055,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','font-weight','bold','4','','.b-switch'),(892056,'furniture','.b-rating .glyphicon','font-weight','400','','','.b-rating'),(892057,'furniture','.p-quick-order-index .value','font-weight','bold','','','.p-quick-order-index'),(892058,'furniture','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(892059,'furniture','.b-table .table .headings td','font-weight','600','','','.b-table'),(892060,'furniture','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(892061,'furniture','.b-form .shipping-method .cost','font-weight','bold','','','.b-form'),(892062,'furniture','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-weight','600','','','.p-quick-order-index'),(892063,'furniture','.btn-1','font-weight','600','','',''),(892064,'furniture','.w-checkout-totals .ot_code_ot_subtotal','font-weight','bold','','','.w-checkout-totals'),(892065,'furniture','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(892066,'furniture','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(892067,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(892068,'furniture','.b-bottom .popup-heading','font-weight','bold','','','.b-bottom'),(892069,'furniture','.b-form .middle-form label.slim','font-weight','400','','','.b-form'),(892070,'furniture','.w-checkout-shipping-choice span','font-weight','600','','','.w-checkout-shipping-choice'),(892071,'furniture','.btn-3','font-weight','600','','',''),(892072,'furniture','.w-reviews-content .author','font-weight','bold','','','.w-reviews-content'),(892073,'furniture','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(892074,'furniture','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(892075,'furniture','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(892076,'furniture','.w-cart-compare .js-cart_totals_container b','font-weight','600','','','.w-cart-compare'),(892077,'furniture','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(892078,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(892079,'furniture','.w-image-maps .default-links .item .title','font-weight','700','','','.w-image-maps'),(892080,'furniture','.heading-4 .edit, h4 .edit','font-weight','400','','',''),(892081,'furniture','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(892082,'furniture','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(892083,'furniture','.w-tabs .tab-li.tab-wishlist a','font-weight','normal','3','','.w-tabs'),(892084,'furniture','.w-multi-cart-cart-switcher .cart-label','font-weight','600','','','.w-multi-cart-cart-switcher'),(892085,'furniture','.w-multi-cart-actions .cart-actions','font-weight','600','','','.w-multi-cart-actions'),(892086,'furniture','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(892087,'furniture','.b-form .middle-form label','font-weight','600','','','.b-form'),(892088,'furniture','.w-cart-credit-amount .amount-title','font-weight','bold','','','.w-cart-credit-amount'),(892089,'furniture','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(892090,'furniture','.w-personal-gift-status-bar .end-date b','font-weight','bold','','','.w-personal-gift-status-bar'),(892091,'furniture','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(892092,'furniture','.btn-2','font-weight','600','','',''),(892093,'furniture','.heading-5, h5, .h-block h5','font-weight','600','','',''),(892094,'furniture','.w-cart-compare .cart-name a','font-weight','600','','','.w-cart-compare'),(892095,'furniture','.w-product-reviews .reviews-list span','font-weight','400','','','.w-product-reviews'),(892096,'furniture','.b-table .table .headings td','font-weight','600','','','.b-table'),(892097,'furniture','.w-delayed-despatch-checkout .heading','font-weight','bold','','','.w-delayed-despatch-checkout'),(892098,'furniture','.w-top-categories .categories h2','font-weight','inherit','','','.w-top-categories'),(892099,'furniture','.transit','font-weight','700','','',''),(892100,'furniture','.out-stock','font-weight','700','','',''),(892101,'furniture','.in-stock','font-weight','700','','',''),(892102,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','font-weight','bold','4','','.b-switch'),(892103,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','font-weight','bold','4','','.b-switch'),(892104,'furniture','.b-delete-account .delete-box .delete-message','font-weight','normal','','','.b-delete-account'),(892105,'furniture','.w-checkout-shipping-address .genders-title > div','font-weight','bold','','','.w-checkout-shipping-address'),(892106,'furniture','.w-cart-bonus-points .title','font-weight','bold','','','.w-cart-bonus-points'),(892107,'furniture','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(892108,'furniture','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(892109,'furniture','.w-checkout-billing-address .btn-cancel','font-weight','500','','','.w-checkout-billing-address'),(892110,'furniture','.js-stock','font-weight','700','','',''),(892111,'furniture','.b-form #payment_method .title','font-weight','bold','','','.b-form'),(892112,'furniture','.b-fancybox .fancybox-title-float-wrap .child','font-weight','bold','','','.b-fancybox'),(892113,'furniture','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(892114,'furniture','.w-reviews-content .product-name a','font-weight','bold','','','.w-reviews-content'),(892115,'furniture','.w-product-reviews .reviews-list .name','font-weight','700','','','.w-product-reviews'),(892116,'furniture','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(892117,'furniture','.b-table .table .headings td','font-weight','600','','','.b-table'),(892118,'furniture','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(892119,'furniture','.w-tabs .tab-li.tab-cart a','font-weight','normal','3','','.w-tabs'),(892120,'furniture','.btn','font-weight','600','','',''),(892121,'furniture','.w-personal-gift-status-bar .inform b','font-weight','bold','','','.w-personal-gift-status-bar'),(892122,'furniture','.b-table .table .headings td','font-weight','600','','','.b-table'),(892123,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(892124,'furniture','.w-reviews .heading-3','font-weight','400','3','','.w-reviews'),(892125,'furniture','.w-reviews .product-name a','font-weight','bold','','','.w-reviews'),(892126,'furniture','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(892127,'furniture','.w-checkout-billing-address .genders-title > div','font-weight','bold','','','.w-checkout-billing-address'),(892128,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','font-weight','600','','','.b-switch'),(892129,'furniture','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(892130,'furniture','.w-cart-compare .atr-col','font-weight','600','','','.w-cart-compare'),(892131,'furniture','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(892132,'furniture','.b-bottom .alert-message','font-weight','bold','','','.b-bottom'),(892133,'furniture','.w-image-maps .categories-items .item .title','font-weight','700','','','.w-image-maps'),(892134,'furniture','.w-neighbour-checkout .text','font-weight','bold','','','.w-neighbour-checkout'),(892135,'furniture','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-weight','600','','','.order-summary'),(892136,'furniture','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(892137,'furniture','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(892138,'furniture','.w-cart-compare .atr-col','font-weight','normal','3','','.w-cart-compare'),(892139,'furniture','.w-tabs .tab-li.tab-quote a','font-weight','normal','3','','.w-tabs'),(892140,'furniture','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(892141,'furniture','.w-product-available-in-warehouses .heading','font-weight','bold','','','.w-product-available-in-warehouses'),(892142,'furniture','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(892143,'furniture','.p-quick-order-index .dataTables_info','font-weight','500','','','.p-quick-order-index'),(892144,'furniture','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(892145,'furniture','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(892146,'furniture','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(892147,'furniture','.w-delayed-despatch-checkout-confirm .heading','font-weight','600','','','.w-delayed-despatch-checkout-confirm'),(892148,'furniture','.w-delayed-despatch-checkout-confirm .heading','font-weight','bold','','','.w-delayed-despatch-checkout-confirm'),(892149,'furniture','.w-checkout-bonus-points .title','font-weight','bold','','','.w-checkout-bonus-points'),(892150,'furniture','.w-coupons-and-vauchers-checkout .title','font-weight','bold','','','.w-coupons-and-vauchers-checkout'),(892151,'furniture','.w-checkout-credit-amount .amount-title','font-weight','bold','','','.w-checkout-credit-amount'),(892152,'furniture','.b-pass-strength .pass-strength span','font-weight','bold','','','.b-pass-strength'),(892153,'furniture','.b-table .table .headings td','font-weight','600','','','.b-table'),(892154,'furniture','.w-quote .strong','font-weight','400','','','.w-quote'),(892155,'furniture','.b-select-suggest .select2-results li.select2-result-with-children > .select2-result-label','font-weight','bold','','','.b-select-suggest'),(892156,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','font-weight','bold','','','.b-warehouses-popup'),(892157,'furniture','.b-table .table .headings td','font-weight','600','','','.b-table'),(892158,'furniture','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(892159,'furniture','.w-quote-products .empty','font-weight','700','','','.w-quote-products'),(892160,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.b-data-table'),(892161,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.b-data-table'),(892162,'furniture','.w-communication-post .communication-post-author-name','font-weight','bold','','','.w-communication-post'),(892163,'furniture','.b-products-listing .products-listing .name a','font-weight','bold','','','.b-products-listing'),(892164,'furniture','.b-products-listing .products-listing .bonus-points span:first-child','font-weight','bold','','','.b-products-listing'),(892165,'furniture','.b-products-listing .products-listing a.btn.view-button','font-weight','400','','','.b-products-listing'),(892166,'furniture','.b-products-listing .products-listing .btn-buy','font-weight','400','3','','.b-products-listing'),(892167,'furniture','.b-products-listing .promos-info .promo-name','font-weight','500','','','.b-products-listing'),(892168,'furniture','.b-products-listing .wedding-registry-count','font-weight','bold','','','.b-products-listing'),(892171,'furniture','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(892172,'furniture','.b-form .form-inputs label > span','font-weight','bold','','','.b-form'),(892173,'furniture','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','font-weight','normal','','','.w-taxable'),(892174,'furniture','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','font-weight','normal','','','.w-taxable'),(892175,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-weight','inherit','','',''),(892176,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-weight','inherit','','','.b-h-inline'),(892177,'furniture','h1, .heading-1','font-weight','700','','',''),(892178,'furniture','.w-tabs .tab-li.tab-sample a','font-weight','normal','3','','.w-tabs'),(892179,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(892180,'furniture','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(892181,'furniture','.b-form .shipping-method .title','font-weight','bold','','','.b-form'),(892182,'furniture','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(892183,'furniture','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(892184,'furniture','.w-cart-listing .item .gift-wrap label','font-weight','700','','','.w-cart-listing'),(892185,'furniture','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-weight','600','','','.w-cart-listing'),(892186,'furniture','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-weight','normal','3','','.w-cart-listing'),(892187,'furniture','.w-cart-listing .remove-btn span','font-weight','bold','5140','','.w-cart-listing'),(892188,'furniture','.w-cart-give-away .ga_price','font-weight','700','','','.w-cart-give-away'),(892193,'furniture','.w-image-maps .float-items .item .title','font-weight','700','','','.w-image-maps'),(892194,'furniture','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(892195,'furniture','.b-form .address-item .firstname, .b-form .address-item .lastname','font-weight','bold','','','.b-form'),(892198,'furniture','.w-checkout-contact-information .contact-info-buttons a','font-weight','500','','','.w-checkout-contact-information'),(892199,'furniture','.w-checkout-shipping-address .change-ab','font-weight','500','','','.w-checkout-shipping-address'),(892200,'furniture','.w-checkout-billing-address .edit-ab','font-weight','500','','','.w-checkout-billing-address'),(892201,'furniture','.w-checkout-billing-address .add-ab','font-weight','500','','','.w-checkout-billing-address'),(892202,'furniture','.w-filters .view_more','font-weight','400','4','','.w-filters'),(892203,'furniture','.b-bottom .footerTitle','font-weight','700','','','.b-bottom'),(892204,'furniture','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(892205,'furniture','.heading-2, h2, .h-block h2','font-weight','700','','',''),(892206,'furniture','.b-data-table table.dataTable thead td','font-weight','700','','','.b-data-table'),(892207,'furniture','.heading-6, h6, .h-block h6','font-weight','600','','',''),(892208,'furniture','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(892209,'furniture','.order-summary .price-row.ot_coupon .title','font-weight','bold','3','','.order-summary'),(892210,'furniture','.w-personal-gift-status-bar .start-label','font-weight','bold','','','.w-personal-gift-status-bar'),(892211,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','font-weight','600','','','.b-menu-style-2'),(892212,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','font-weight','600','','','.b-menu-style-2'),(892213,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-weight','600','','','.b-menu-style-2'),(892214,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-weight','300','3','','.b-menu-style-2'),(892215,'furniture','.b-personal-catalog-popup #personal_catalog_popup','font-weight','normal','','','.b-personal-catalog-popup'),(892216,'furniture','.b-trade-approval .middle-form label','font-weight','600','','','.b-trade-approval'),(892217,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-weight','normal','3','','.w-catalog-compare'),(892218,'furniture','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-weight','600','','','.w-delivery-day'),(892219,'furniture','.w-delivery-day .ends-date','font-weight','600','','','.w-delivery-day'),(892220,'furniture','.w-delivery-day .title','font-weight','bold','','','.w-delivery-day'),(892221,'furniture','.w-delivery-day .left-text-left','font-weight','600','','','.w-delivery-day'),(892222,'furniture','.w-delivery-day .left-text-right','font-weight','600','','','.w-delivery-day'),(892226,'furniture','.b-products-listing .products-listing.list-productlisting .price','font-weight','700','','','.b-products-listing'),(892227,'furniture','.w-cart-listing .item div.price','font-weight','bold','','','.w-cart-listing'),(892228,'furniture','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','font-weight','400','','','.b-products-listing'),(892229,'furniture','.w-filters .head-filter-widget','font-weight','700','','','.w-filters'),(892230,'furniture','.w-filters .filter-box-head','font-weight','700','','','.w-filters'),(892231,'furniture','.w-subscribers .btn-submit','font-weight','600','','','.w-subscribers'),(892232,'furniture','.w-quote .cart-box-link','font-weight','bold','','','.w-quote'),(892233,'furniture','.w-quote .cart-box-link','font-weight','normal','3','','.w-quote'),(892234,'furniture','.w-quote .cart-total','font-weight','600','','','.w-quote'),(892235,'furniture','.w-quote .multicart .title','font-weight','600','','','.w-quote'),(892236,'furniture','.w-quote .price','font-weight','600','','','.w-quote'),(892237,'furniture','.w-quote .sub-total-row','font-weight','600','','','.w-quote'),(892238,'furniture','.w-product-personal-catalog-button .btn','font-weight','400','','','.w-product-personal-catalog-button'),(892239,'furniture','.w-product-sale-ends .ends-date','font-weight','600','','','.w-product-sale-ends'),(892240,'furniture','.w-product-sale-ends .left-count-days','font-weight','600','','','.w-product-sale-ends'),(892241,'furniture','.w-product-sale-ends .left-count-hours','font-weight','600','','','.w-product-sale-ends'),(892242,'furniture','.w-product-sale-ends .left-text-left','font-weight','600','','','.w-product-sale-ends'),(892243,'furniture','.w-product-sale-ends .left-text-right','font-weight','600','','','.w-product-sale-ends'),(892244,'furniture','.w-tabs .tab-a','font-weight','700','','','.w-tabs'),(892245,'furniture','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','font-weight','400','3','','.w-product-buttons'),(892246,'furniture','.w-product-bonus-points > div','font-weight','bold','','','.w-product-bonus-points'),(892247,'furniture','.warrantyProduct .title','font-weight','700','','','.warrantyProduct'),(892248,'furniture','.w-files-catalog-widgets-files-catalog .name','font-weight','600','','','.w-files-catalog-widgets-files-catalog'),(892249,'furniture','.w-files-catalog-widgets-files-list .name','font-weight','600','','','.w-files-catalog-widgets-files-list'),(892250,'furniture','.w-sample .cart-box-link','font-weight','bold','','','.w-sample'),(892251,'furniture','.w-sample .cart-box-link','font-weight','normal','3','','.w-sample'),(892252,'furniture','.w-sample .cart-total','font-weight','600','','','.w-sample'),(892253,'furniture','.w-sample .multicart .title','font-weight','600','','','.w-sample'),(892254,'furniture','.w-sample .price','font-weight','600','','','.w-sample'),(892255,'furniture','.w-sample .strong','font-weight','400','','','.w-sample'),(892256,'furniture','.w-sample .sub-total-row','font-weight','600','','','.w-sample'),(892257,'furniture','.w-filters-simple .integrate-price','font-weight','bold','','','.w-filters-simple'),(892258,'furniture','.w-cart-sub-total .title','font-weight','700','','','.w-cart-sub-total'),(892259,'furniture','.w-cart-sub-total .price','font-weight','700','','','.w-cart-sub-total'),(892260,'furniture','.w-cart-gift-certificate .heading-4','font-weight','700','','','.w-cart-gift-certificate'),(892261,'furniture','.w-cart-order-reference .heading-4','font-weight','700','','','.w-cart-order-reference'),(892262,'furniture','.w-product-attributes .radio-attributes > span','font-weight','700','','','.w-product-attributes'),(892263,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','font-weight','inherit','','','.b-products-listing'),(892264,'furniture','.b-pagination .pagination .active a, .b-pagination .pagination .active span','font-weight','bold','','','.b-pagination'),(892265,'furniture','.b-pagination .pagination span','font-weight','700','2','','.b-pagination'),(892266,'furniture','.w-product-multi-inventory .radio-attributes > span','font-weight','700','','','.w-product-multi-inventory'),(892267,'furniture','.w-product-multi-inventory .radio-attributes .option-item','font-weight','700','','','.w-product-multi-inventory'),(892268,'furniture','.b-products-listing .products-listing.list-rows .stock','font-weight','700','','','.b-products-listing'),(892269,'furniture','.b-products-listing .products-listing.list-b2b .stock','font-weight','700','','','.b-products-listing'),(892270,'furniture','.b-products-listing .products-listing .radio-attributes .option','font-weight','700','','','.b-products-listing'),(892271,'furniture','.b-products-listing .products-listing .radio-attributes > span','font-weight','700','','','.b-products-listing'),(892272,'furniture','.b-products-listing .products-listing .attributes .item-title','font-weight','700','','','.b-products-listing'),(892273,'furniture','.w-product-collection .stock > span','font-weight','700','','','.w-product-collection'),(892274,'furniture','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(892275,'furniture','.w-product-collection .title','font-weight','bold','','','.w-product-collection'),(892276,'furniture','.w-product-collection .together','font-weight','700','','','.w-product-collection'),(892277,'furniture','.w-product-collection .right-area .btn','font-weight','400','3','','.w-product-collection'),(892278,'furniture','.w-product-collection .right-area .btn-2','font-weight','400','3','','.w-product-collection'),(892279,'furniture','.w-product-attributes .radio-attributes .option-item','font-weight','700','','','.w-product-attributes'),(892280,'furniture','.w-product-in-bundles .bundle_name','font-weight','700','','','.w-product-in-bundles'),(892281,'furniture','.w-product-groups .radioBoxHead','font-weight','700','','','.w-product-groups'),(892282,'furniture','.w-product-groups .val1','font-weight','500','','','.w-product-groups'),(892283,'furniture','.w-product-groups .radioBox label .containerBlock img + .name + .val2','font-weight','700','','','.w-product-groups'),(892284,'furniture','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(892285,'furniture','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(892286,'furniture','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(892287,'furniture','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','font-weight','400','3','','.w-product-custom-bundle'),(892288,'furniture','.w-delivery-location-top-location-list .deliveryName','font-weight','700','','','.w-delivery-location-top-location-list'),(892289,'furniture','.w-delivery-location-location-list .deliveryName','font-weight','700','','','.w-delivery-location-location-list'),(892290,'furniture','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(892291,'furniture','.w-delivery-location-location-list .deliveryList li','font-weight','600','','','.w-delivery-location-location-list'),(892292,'furniture','.w-delivery-location-featured-list .deliveryName','font-weight','700','','','.w-delivery-location-featured-list'),(892293,'furniture','.w-sale-category .ends-date','font-weight','600','','','.w-sale-category'),(892294,'furniture','.w-sale-category .left-count-days','font-weight','600','','','.w-sale-category'),(892295,'furniture','.w-sale-category .left-count-hours','font-weight','600','','','.w-sale-category'),(892296,'furniture','.w-sale-category .left-text-left','font-weight','600','','','.w-sale-category'),(892297,'furniture','.w-sale-category .left-text-right','font-weight','600','','','.w-sale-category'),(892298,'furniture','.w-sale-category .name','font-weight','bold','','','.w-sale-category'),(892299,'furniture','.w-sale-category .special-price','font-weight','600','','','.w-sale-category'),(892300,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description + div','font-weight','700','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(892301,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description + div','font-weight','700','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(892302,'furniture','.w-delivery-location-list-by-page .name','font-weight','700','','','.w-delivery-location-list-by-page'),(892303,'furniture','.w-delivery-location-cross-pages .name','font-weight','700','','','.w-delivery-location-cross-pages'),(892304,'furniture','.w-catalog-delivery-locations .name','font-weight','700','','','.w-catalog-delivery-locations'),(892305,'furniture','.w-product-bonus-points .bonus-points-cost','font-weight','700','','','.w-product-bonus-points'),(892306,'furniture','.w-product-designer-designer .grnamebox .title-sortable','font-weight','700','','','.w-product-designer-designer'),(892307,'furniture','.w-press-reviews-widgets-press-reviews .author','font-weight','bold','','','.w-press-reviews-widgets-press-reviews'),(892308,'furniture','.w-press-reviews-widgets-press-reviews .title a','font-weight','bold','','','.w-press-reviews-widgets-press-reviews'),(892309,'furniture','.w-press-reviews-widgets-press-reviews-list .product-name','font-weight','600','','','.w-press-reviews-widgets-press-reviews-list'),(892310,'furniture','.w-press-reviews-widgets-press-reviews-list .short-description','font-weight','700','','','.w-press-reviews-widgets-press-reviews-list'),(892311,'furniture','.w-support-system-filter .filter_cats.level-0 > li > a','font-weight','700','','','.w-support-system-filter'),(892312,'furniture','.w-rma-returns-history .column .title','font-weight','normal','','','.w-rma-returns-history'),(892313,'furniture','.b-products-listing .products-listing .bonus-points-cost','font-weight','700','','','.b-products-listing'),(892314,'furniture','.w-predefined-promotion .heading-3','font-weight','bold','','','.w-predefined-promotion'),(892315,'furniture','.w-predefined-promotion .prom-multi-discount .heading','font-weight','300','','','.w-predefined-promotion'),(892316,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range .value','font-weight','bold','','','.w-predefined-promotion'),(892317,'furniture','.w-predefined-promotion .promo-cart-discount .master .heading','font-weight','300','','','.w-predefined-promotion'),(892318,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty .value','font-weight','bold','','','.w-predefined-promotion'),(892319,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder .value','font-weight','bold','','','.w-predefined-promotion'),(892320,'furniture','.w-predefined-promotion .promo-cart-discount .slave .heading','font-weight','300','','','.w-predefined-promotion'),(892321,'furniture','.w-predefined-promotion .promo-date','font-weight','500','','','.w-predefined-promotion'),(892322,'furniture','.w-predefined-promotion .promo-salemaker .discount .value','font-weight','700','','','.w-predefined-promotion'),(892323,'furniture','.w-predefined-promotion .promo-salemaker .promo-conditions','font-weight','300','','','.w-predefined-promotion'),(892324,'furniture','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading','font-weight','300','','','.w-predefined-promotion'),(892325,'furniture','.mainBanner .title','font-weight','700','','','.mainBanner'),(892326,'furniture','.mainBanner .title > span','font-weight','700','','','.mainBanner'),(892327,'furniture','.mainBanner .topBox > .left','font-weight','700','','','.mainBanner'),(892328,'furniture','.w-cart-discount-coupon .title','font-weight','400','4','','.w-cart-discount-coupon'),(892329,'furniture','.w-cart-listing .promos-info .promo-name','font-weight','500','','','.w-cart-listing'),(892336,'furniture','.account-address-book .address_book h2','font-weight','normal','','','.account-address-book'),(892343,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-weight','normal','3','','.account-order-pay'),(892344,'furniture','.account-order-pay .not_fully_paid_td','font-weight','700','','','.account-order-pay'),(892345,'furniture','.account-samples .not_fully_paid_td','font-weight','700','','','.account-samples'),(892346,'furniture','.account-samples .order_history_table h2','font-weight','normal','','','.account-samples'),(892347,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-weight','normal','3','','.account-sample-info'),(892348,'furniture','.account-sample-info .not_fully_paid_td','font-weight','700','','','.account-sample-info'),(892349,'furniture','.account-sample-info .popup-tracking-number-link','font-weight','600','','','.account-sample-info'),(892350,'furniture','.account-sample-info .trackings-nambers-label','font-weight','600','','','.account-sample-info'),(892351,'furniture','.catalog-product-wrap .pn-direction','font-weight','600','','','.catalog-product-wrap'),(892352,'furniture','.checkout-index-wrap .cardinfo-label','font-weight','bold','','','.checkout-index-wrap'),(892353,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','font-weight','600','','','.checkout-index-wrap'),(892354,'furniture','.checkout-index-wrap .edit-address-popup .edit-ab','font-weight','500','','','.checkout-index-wrap'),(892355,'furniture','.shopping-cart-index .cart-page .empty','font-weight','700','','','.shopping-cart-index'),(892356,'furniture','.b-bottom .btn-cancel, .b-bottom .add-ab','font-weight','600','','','.b-bottom'),(892357,'furniture','.b-info .info strong','font-weight','400','','','.b-info'),(892358,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-weight','normal','3','','.b-multi-page-checkout'),(892359,'furniture','.success-page .price-box .price-row.total','font-weight','500','','','.success-page'),(892360,'furniture','.success-page .price-row.total .price b','font-weight','500','','','.success-page'),(892361,'furniture','.success-page .w-cart-listing .name a','font-weight','500','','','.success-page'),(892362,'furniture','.success-page .w-cart-listing .price','font-weight','normal','','','.success-page'),(892363,'furniture','.b-form .addresses .address-item .edit-ab','font-weight','bold','','','.b-form'),(892364,'furniture','.b-sub-totals .historyTotal table tr.ot_total td','font-weight','bold','','','.b-sub-totals'),(892365,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','font-weight','600','','','.menu-header'),(892366,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','font-weight','normal','5140,3','','.footer-menu'),(892367,'furniture','.lowestPricedBox .w-banner .ybg .descr','font-weight','700','','','.lowestPricedBox'),(892368,'furniture','.lowestPricedBox .w-banner .ybg .title','font-weight','700','','','.lowestPricedBox'),(892369,'furniture','.tripleBanner .w-html_box > div:nth-child(2)','font-weight','700','','','.tripleBanner'),(892370,'furniture','.shopByCollectionBox .content .title','font-weight','700','','','.shopByCollectionBox'),(892371,'furniture','.shopByCollectionBox .content .title span','font-weight','700','','','.shopByCollectionBox'),(892372,'furniture','.w-catalog-paging ','font-weight','700','2','','.w-catalog-paging'),(892373,'furniture','.no-found','font_size_measure','em','','',''),(892374,'furniture','.w-checkout-create-account .account-benefits','font_size_measure','em','','','.w-checkout-create-account'),(892375,'furniture','.view-all .btn','font_size_measure','em','4','',''),(892376,'furniture','.price .old','font_size_measure','em','','',''),(892377,'furniture','.btn-edit','font_size_measure','em','3','',''),(892378,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font_size_measure','%','','','.b-select-suggest'),(892379,'furniture','.b-select-suggest .select2-search input','font_size_measure','em','','','.b-select-suggest'),(892381,'furniture','.w-quote .cart-total','font_size_measure','em','','','.w-quote'),(892382,'furniture','.w-quote .qty','font_size_measure','em','4','','.w-quote'),(892384,'furniture','.w-sample .cart-total','font_size_measure','em','','','.w-sample'),(892385,'furniture','.w-sample .qty','font_size_measure','em','4','','.w-sample'),(892386,'furniture','.w-product-bundle .bundle_price .old','font_size_measure','em','','','.w-product-bundle'),(892387,'furniture','.w-product-in-bundles .bundle_price .old','font_size_measure','em','','','.w-product-in-bundles'),(892388,'furniture','.mainBanner .bottomBox .btn','font_size_measure','vw','','','.mainBanner'),(892389,'furniture','.mainBanner .title','font_size_measure','vw','','','.mainBanner'),(892390,'furniture','.mainBanner .title > span','font_size_measure','vw','','','.mainBanner'),(892391,'furniture','.mainBanner .topBox > .left','font_size_measure','vw','','','.mainBanner'),(892392,'furniture','.mainBanner .bottomBox .btn','font_size_measure','vw','5131','','.mainBanner'),(892393,'furniture','.mainBanner .title','font_size_measure','vw','5131','','.mainBanner'),(892394,'furniture','.mainBanner .title > span','font_size_measure','vw','5131','','.mainBanner'),(892395,'furniture','.mainBanner .topBox > .left','font_size_measure','vw','5131','','.mainBanner'),(892396,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font_size_measure','em','4','','.b-multi-page-checkout'),(892397,'furniture','.lowestPricedBox .w-banner .ybg .btn','font_size_measure','vw','5145','','.lowestPricedBox'),(892398,'furniture','.lowestPricedBox .w-banner .ybg .descr','font_size_measure','vw','','','.lowestPricedBox'),(892399,'furniture','.lowestPricedBox .w-banner .ybg .title','font_size_measure','vw','','','.lowestPricedBox'),(892400,'furniture','.w-promotions .prom-multi-discount .list','grid-auto-flow','dense','','','.w-promotions'),(892401,'furniture','.w-predefined-promotion .prom-multi-discount .list','grid-auto-flow','dense','','','.w-predefined-promotion'),(892402,'furniture','.w-promotions .prom-multi-discount .promo-group-4','grid-column','span 4','','','.w-promotions'),(892403,'furniture','.w-promotions .prom-multi-discount .promo-group-2','grid-column','span 2','','','.w-promotions'),(892404,'furniture','.w-promotions .prom-multi-discount .promo-group-3','grid-column','span 3','','','.w-promotions'),(892405,'furniture','.w-cart-listing .item .gift-wrap','grid-column','3 / 4','5131','','.w-cart-listing'),(892406,'furniture','.w-reviews .author','grid-column','2/4','','','.w-reviews'),(892407,'furniture','.w-reviews-content .rating','grid-column','2','','','.w-reviews-content'),(892408,'furniture','.w-reviews-content .date','grid-column','3','','','.w-reviews-content'),(892409,'furniture','.w-reviews-content .review','grid-column','2/4','','','.w-reviews-content'),(892410,'furniture','.w-reviews .date','grid-column','3','','','.w-reviews'),(892411,'furniture','.w-reviews-content .author','grid-column','2/4','','','.w-reviews-content'),(892412,'furniture','.w-reviews .product-name','grid-column','2/4','','','.w-reviews'),(892413,'furniture','.w-reviews .product-image','grid-column','1','','','.w-reviews'),(892414,'furniture','.w-reviews .rating','grid-column','2','','','.w-reviews'),(892415,'furniture','.w-reviews .review','grid-column','2/4','','','.w-reviews'),(892416,'furniture','.w-reviews-content .product-image','grid-column','1','','','.w-reviews-content'),(892417,'furniture','.w-cart-listing .promos-info','grid-column','2 / 3','','','.w-cart-listing'),(892418,'furniture','.w-cart-listing .qty','grid-column','4 / 5','','','.w-cart-listing'),(892419,'furniture','.w-cart-listing .price','grid-column','5 / 6','','','.w-cart-listing'),(892420,'furniture','.w-cart-listing .name','grid-column','3 / 4','','','.w-cart-listing'),(892421,'furniture','.w-cart-listing .image','grid-column','2 / 3','','','.w-cart-listing'),(892422,'furniture','.w-cart-listing .points','grid-column','4 / 6','','','.w-cart-listing'),(892423,'furniture','.w-cart-listing .item .gift-wrap','grid-column','4 / 6','','','.w-cart-listing'),(892424,'furniture','.w-cart-listing .actions','grid-column','3 / 6','','','.w-cart-listing'),(892425,'furniture','.w-cart-listing .no-price .qty','grid-column','4 / 6','','','.w-cart-listing'),(892426,'furniture','.w-reviews-content .product-name','grid-column','2/4','','','.w-reviews-content'),(892427,'furniture','.w-cart-listing .remove','grid-column','1 / 2','','','.w-cart-listing'),(892428,'furniture','.w-cart-listing .item > div.actions','grid-column','1 / 4','5131','','.w-cart-listing'),(892429,'furniture','.w-cart-listing .no-price .qty','grid-column','2/4','5140','','.w-cart-listing'),(892430,'furniture','.w-sample-products .w-cart-listing .item .qty','grid-column','2 / 4','5131','','.w-sample-products'),(892431,'furniture','.w-quote-products .cart-listing .qty','grid-column','4 / 6','','','.w-quote-products'),(892432,'furniture','.w-account-personal-catalog .check-box','grid-column','1 / 2','','','.w-account-personal-catalog'),(892433,'furniture','.w-account-personal-catalog .remove','grid-column','1 / 2','','','.w-account-personal-catalog'),(892434,'furniture','.w-account-personal-catalog .price','grid-column','4 / 5','','','.w-account-personal-catalog'),(892435,'furniture','.w-account-personal-catalog .list-row-action','grid-column','3 / 4','','','.w-account-personal-catalog'),(892436,'furniture','.w-account-personal-catalog .image','grid-column','2 / 3','','','.w-account-personal-catalog'),(892437,'furniture','.w-account-personal-catalog .name','grid-column','3 / 4','','','.w-account-personal-catalog'),(892438,'furniture','.w-account-personal-catalog .buy-box','grid-column','5 / 6','','','.w-account-personal-catalog'),(892439,'furniture','.w-account-personal-catalog .qty-input','grid-column','4 / 5','','','.w-account-personal-catalog'),(892440,'furniture','.w-account-personal-catalog .w-cart-listing .item .remove','grid-column','1 / 2','5140','','.w-account-personal-catalog'),(892441,'furniture','.w-account-personal-catalog .price','grid-column','2 / 3','5131','','.w-account-personal-catalog'),(892442,'furniture','.w-account-personal-catalog .remove','grid-column','1 / 2','5131','','.w-account-personal-catalog'),(892443,'furniture','.w-account-personal-catalog .list-row-action','grid-column','2 / 4','5131','','.w-account-personal-catalog'),(892444,'furniture','.w-account-personal-catalog .image','grid-column','2 / 3','5131','','.w-account-personal-catalog'),(892445,'furniture','.w-account-personal-catalog .name','grid-column','3 / 4','5131','','.w-account-personal-catalog'),(892446,'furniture','.w-account-personal-catalog .buy-box','grid-column','2 / 4','5131','','.w-account-personal-catalog'),(892447,'furniture','.w-account-personal-catalog .qty-input','grid-column','3 / 4','5131','','.w-account-personal-catalog'),(892448,'furniture','.w-press-reviews-widgets-press-reviews .author','grid-column','2/4','','','.w-press-reviews-widgets-press-reviews'),(892449,'furniture','.w-press-reviews-widgets-press-reviews .date','grid-column','3','','','.w-press-reviews-widgets-press-reviews'),(892450,'furniture','.w-press-reviews-widgets-press-reviews .image','grid-column','1','','','.w-press-reviews-widgets-press-reviews'),(892451,'furniture','.w-press-reviews-widgets-press-reviews .rating','grid-column','2','','','.w-press-reviews-widgets-press-reviews'),(892452,'furniture','.w-press-reviews-widgets-press-reviews .review','grid-column','2/4','','','.w-press-reviews-widgets-press-reviews'),(892453,'furniture','.w-press-reviews-widgets-press-reviews .title','grid-column','2/4','','','.w-press-reviews-widgets-press-reviews'),(892454,'furniture','.w-press-reviews-widgets-press-reviews .author','grid-column','1/2','5131','','.w-press-reviews-widgets-press-reviews'),(892455,'furniture','.w-press-reviews-widgets-press-reviews .date','grid-column','1/2','5131','','.w-press-reviews-widgets-press-reviews'),(892456,'furniture','.w-press-reviews-widgets-press-reviews .image','grid-column','1/2','5131','','.w-press-reviews-widgets-press-reviews'),(892457,'furniture','.w-press-reviews-widgets-press-reviews .rating','grid-column','1/2','5131','','.w-press-reviews-widgets-press-reviews'),(892458,'furniture','.w-press-reviews-widgets-press-reviews .review','grid-column','1/2','5131','','.w-press-reviews-widgets-press-reviews'),(892459,'furniture','.w-press-reviews-widgets-press-reviews .title','grid-column','1/2','5131','','.w-press-reviews-widgets-press-reviews'),(892460,'furniture','.w-predefined-promotion .prom-multi-discount .promo-group-2','grid-column','span 2','','','.w-predefined-promotion'),(892461,'furniture','.w-predefined-promotion .prom-multi-discount .promo-group-3','grid-column','span 3','','','.w-predefined-promotion'),(892462,'furniture','.w-predefined-promotion .prom-multi-discount .promo-group-4','grid-column','span 4','','','.w-predefined-promotion'),(892463,'furniture','.order-summary .w-cart-listing .item .name','grid-column','1/2','','','.order-summary'),(892464,'furniture','.order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price','grid-column','3/4','','','.order-summary'),(892465,'furniture','.order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty','grid-column','2/3','','','.order-summary'),(892466,'furniture','.order-summary .w-cart-listing.type-2 .image','grid-column','1 / 3','','','.order-summary'),(892467,'furniture','.w-cart-listing .item .image','grid-column','1 / 2','5140','','.w-cart-listing'),(892468,'furniture','.w-cart-listing .item .name','grid-column','2 / 3','5140','','.w-cart-listing'),(892469,'furniture','.w-cart-listing .item .qty','grid-column','3 / 4','5140','','.w-cart-listing'),(892470,'furniture','.w-cart-listing .no-price .item .image','grid-column','2/2','5140','','.w-cart-listing'),(892471,'furniture','.w-cart-listing .no-price .item .name','grid-column','3/3','5140','','.w-cart-listing'),(892472,'furniture','.w-cart-listing .no-price .item .qty','grid-column','4/6','5140','','.w-cart-listing'),(892473,'furniture','.w-cart-listing .no-price .item .remove','grid-column','1/1','5140','','.w-cart-listing'),(892474,'furniture','.w-cart-listing .promos-info','grid-column','1 / 1','5140','','.w-cart-listing'),(892475,'furniture','.w-cart-listing .item .image','grid-column','1 / 2','5131','','.w-cart-listing'),(892476,'furniture','.w-cart-listing .item .name','grid-column','2 / 4','5131','','.w-cart-listing'),(892477,'furniture','.w-cart-listing .item .points','grid-column','2 / 5','5131','','.w-cart-listing'),(892478,'furniture','.w-cart-listing .item .price','grid-column','3 / 5','5131','','.w-cart-listing'),(892479,'furniture','.w-cart-listing .item .promos-info','grid-column','1 / 2','5131','','.w-cart-listing'),(892480,'furniture','.w-cart-listing .item .qty','grid-column','1 / 3','5131','','.w-cart-listing'),(892481,'furniture','.w-cart-listing .no-price .item .image','grid-column','1/1','5131','','.w-cart-listing'),(892482,'furniture','.w-cart-listing .no-price .item .name','grid-column','2/5','5131','','.w-cart-listing'),(892483,'furniture','.w-cart-listing .no-price .item .qty','grid-column','4/5','5131','','.w-cart-listing'),(892484,'furniture','.w-quote-products .w-cart-listing .name','grid-column','3 / 5','','','.w-quote-products'),(892485,'furniture','.w-quote-products .cart-listing .qty','grid-column','2 / 6','5140','','.w-quote-products'),(892486,'furniture','.w-quote-products .w-cart-listing .name','grid-column','2 / 6','5140','','.w-quote-products'),(892487,'furniture','.success-page .w-cart-listing .image','grid-column','1','','','.success-page'),(892488,'furniture','.success-page .w-cart-listing .name','grid-column','2','','','.success-page'),(892489,'furniture','.success-page .w-cart-listing .price','grid-column','3','','','.success-page'),(892490,'furniture','.success-page .w-cart-listing .qty','grid-column','1','','','.success-page'),(892491,'furniture','.success-page .w-cart-listing .sub-product .image','grid-column','1','','','.success-page'),(892492,'furniture','.w-banner .banner-image','grid-column','1','','','.w-banner'),(892493,'furniture','.w-banner .banner-text','grid-column','1','','','.w-banner'),(892494,'furniture','.w-promotions .content','grid-column-end','3','','','.w-promotions'),(892495,'furniture','.w-predefined-promotion .content','grid-column-end','3','','','.w-predefined-promotion'),(892496,'furniture','.w-promotions .heading','grid-column-start','1','','','.w-promotions'),(892497,'furniture','.w-promotions .condition','grid-column-start','2','','','.w-promotions'),(892498,'furniture','.w-promotions .content','grid-column-start','1','','','.w-promotions'),(892499,'furniture','.w-predefined-promotion .condition','grid-column-start','2','','','.w-predefined-promotion'),(892500,'furniture','.w-predefined-promotion .content','grid-column-start','1','','','.w-predefined-promotion'),(892501,'furniture','.w-predefined-promotion .heading','grid-column-start','1','','','.w-predefined-promotion'),(892502,'furniture','.w-account-personal-catalog .remove','grid-column_important','important','5131','','.w-account-personal-catalog'),(892503,'furniture','.w-promotions .prom-multi-discount .products','grid-gap','4px','','','.w-promotions'),(892504,'furniture','.w-promotions .prom-multi-discount .list','grid-gap','20px','','','.w-promotions'),(892505,'furniture','.w-promotions .nextdiscount .content','grid-gap','3px','','','.w-promotions'),(892506,'furniture','.w-predefined-promotion .nextdiscount .content','grid-gap','3px','','','.w-predefined-promotion'),(892507,'furniture','.w-predefined-promotion .prom-multi-discount .list','grid-gap','20px','','','.w-predefined-promotion'),(892508,'furniture','.w-predefined-promotion .prom-multi-discount .products','grid-gap','4px','','','.w-predefined-promotion'),(892509,'furniture','.w-reviews-content .product-name','grid-row','2','','','.w-reviews-content'),(892510,'furniture','.w-reviews-content .date','grid-row','1','','','.w-reviews-content'),(892511,'furniture','.w-reviews .author','grid-row','4','','','.w-reviews'),(892512,'furniture','.w-reviews .date','grid-row','1','','','.w-reviews'),(892513,'furniture','.w-reviews-content .author','grid-row','4','','','.w-reviews-content'),(892514,'furniture','.w-reviews-content .review','grid-row','3','','','.w-reviews-content'),(892515,'furniture','.w-reviews .product-image','grid-row','1/6','','','.w-reviews'),(892516,'furniture','.w-reviews .product-name','grid-row','2','','','.w-reviews'),(892517,'furniture','.w-reviews .rating','grid-row','1','','','.w-reviews'),(892518,'furniture','.w-reviews .review','grid-row','3','','','.w-reviews'),(892519,'furniture','.w-reviews-content .rating','grid-row','1','','','.w-reviews-content'),(892520,'furniture','.w-reviews-content .product-image','grid-row','1/6','','','.w-reviews-content'),(892521,'furniture','.w-cart-listing .remove','grid-row','1 / 6','','','.w-cart-listing'),(892522,'furniture','.w-cart-listing .promos-info','grid-row','1 / 1','','','.w-cart-listing'),(892523,'furniture','.w-cart-listing .image','grid-row','1 / 3','','','.w-cart-listing'),(892524,'furniture','.w-cart-listing .name','grid-row','1 / 5','','','.w-cart-listing'),(892525,'furniture','.w-cart-listing .price','grid-row','1 / 2','','','.w-cart-listing'),(892526,'furniture','.w-cart-listing .actions','grid-row','5 / 6','','','.w-cart-listing'),(892527,'furniture','.w-cart-listing .qty','grid-row','1 / 2','','','.w-cart-listing'),(892528,'furniture','.w-cart-listing .item .remove','grid-row','2/3','5140','','.w-cart-listing'),(892529,'furniture','.w-cart-listing .item > div.actions','grid-row','6 / 7','5131','','.w-cart-listing'),(892530,'furniture','.w-cart-listing .no-price .qty','grid-row','2/3','5140','','.w-cart-listing'),(892531,'furniture','.w-sample-products .w-cart-listing .item .qty','grid-row','2 / 3','5131','','.w-sample-products'),(892532,'furniture','.w-account-personal-catalog .check-box','grid-row','1 / 2','','','.w-account-personal-catalog'),(892533,'furniture','.w-account-personal-catalog .remove','grid-row','3 / 4','','','.w-account-personal-catalog'),(892534,'furniture','.w-account-personal-catalog .price','grid-row','2 / 4','','','.w-account-personal-catalog'),(892535,'furniture','.w-account-personal-catalog .list-row-action','grid-row','3 / 4','','','.w-account-personal-catalog'),(892536,'furniture','.w-account-personal-catalog .image','grid-row','1 / 4','','','.w-account-personal-catalog'),(892537,'furniture','.w-account-personal-catalog .name','grid-row','1 / 3','','','.w-account-personal-catalog'),(892538,'furniture','.w-account-personal-catalog .buy-box','grid-row','1 / 4','','','.w-account-personal-catalog'),(892539,'furniture','.w-account-personal-catalog .qty-input','grid-row','1 / 2','','','.w-account-personal-catalog'),(892540,'furniture','.w-account-personal-catalog .w-cart-listing .item .remove','grid-row','3 / 4','5140','','.w-account-personal-catalog'),(892541,'furniture','.w-account-personal-catalog .price','grid-row','2 / 3','5131','','.w-account-personal-catalog'),(892542,'furniture','.w-account-personal-catalog .remove','grid-row','4 / 5','5131','','.w-account-personal-catalog'),(892543,'furniture','.w-account-personal-catalog .list-row-action','grid-row','4 / 5','5131','','.w-account-personal-catalog'),(892544,'furniture','.w-account-personal-catalog .image','grid-row','1 / 2','5131','','.w-account-personal-catalog'),(892545,'furniture','.w-account-personal-catalog .name','grid-row','1 / 2','5131','','.w-account-personal-catalog'),(892546,'furniture','.w-account-personal-catalog .buy-box','grid-row','3 / 4','5131','','.w-account-personal-catalog'),(892547,'furniture','.w-account-personal-catalog .qty-input','grid-row','2 / 3','5131','','.w-account-personal-catalog'),(892548,'furniture','.w-press-reviews-widgets-press-reviews .author','grid-row','4','','','.w-press-reviews-widgets-press-reviews'),(892549,'furniture','.w-press-reviews-widgets-press-reviews .date','grid-row','1','','','.w-press-reviews-widgets-press-reviews'),(892550,'furniture','.w-press-reviews-widgets-press-reviews .image','grid-row','1/6','','','.w-press-reviews-widgets-press-reviews'),(892551,'furniture','.w-press-reviews-widgets-press-reviews .rating','grid-row','1','','','.w-press-reviews-widgets-press-reviews'),(892552,'furniture','.w-press-reviews-widgets-press-reviews .review','grid-row','3','','','.w-press-reviews-widgets-press-reviews'),(892553,'furniture','.w-press-reviews-widgets-press-reviews .title','grid-row','2','','','.w-press-reviews-widgets-press-reviews'),(892554,'furniture','.w-press-reviews-widgets-press-reviews .author','grid-row','6/7','5131','','.w-press-reviews-widgets-press-reviews'),(892555,'furniture','.w-press-reviews-widgets-press-reviews .date','grid-row','2/3','5131','','.w-press-reviews-widgets-press-reviews'),(892556,'furniture','.w-press-reviews-widgets-press-reviews .image','grid-row','1/2','5131','','.w-press-reviews-widgets-press-reviews'),(892557,'furniture','.w-press-reviews-widgets-press-reviews .rating','grid-row','3/4','5131','','.w-press-reviews-widgets-press-reviews'),(892558,'furniture','.w-press-reviews-widgets-press-reviews .review','grid-row','5/6','5131','','.w-press-reviews-widgets-press-reviews'),(892559,'furniture','.w-press-reviews-widgets-press-reviews .title','grid-row','4/5','5131','','.w-press-reviews-widgets-press-reviews'),(892560,'furniture','.order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price','grid-row','1/2','','','.order-summary'),(892561,'furniture','.order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty','grid-row','1/2','','','.order-summary'),(892562,'furniture','.w-cart-listing .item .image','grid-row','1 / 1','5140','','.w-cart-listing'),(892563,'furniture','.w-cart-listing .item .name','grid-row','1 / 3','5140','','.w-cart-listing'),(892564,'furniture','.w-cart-listing .no-price .item .qty','grid-row','1/1','5140','','.w-cart-listing'),(892565,'furniture','.w-cart-listing .no-price .item .remove','grid-row','1/1','5140','','.w-cart-listing'),(892566,'furniture','.w-cart-listing .item .image','grid-row','1 / 1','5131','','.w-cart-listing'),(892567,'furniture','.w-cart-listing .item .name','grid-row','1 / 2','5131','','.w-cart-listing'),(892568,'furniture','.w-cart-listing .item .points','grid-row','2 / 3','5131','','.w-cart-listing'),(892569,'furniture','.w-cart-listing .item .price','grid-row','5 / 6','5131','','.w-cart-listing'),(892570,'furniture','.w-cart-listing .item .promos-info','grid-row','1 / 5','5131','','.w-cart-listing'),(892571,'furniture','.w-cart-listing .item .qty','grid-row','5 / 6','5131','','.w-cart-listing'),(892572,'furniture','.w-cart-listing .no-price .item .qty','grid-row','2/2','5131','','.w-cart-listing'),(892573,'furniture','.w-cart-listing .no-price .item .remove','grid-row','2/2','5131','','.w-cart-listing'),(892574,'furniture','.w-quote-products .cart-listing .qty','grid-row','2 / 6','5140','','.w-quote-products'),(892575,'furniture','.success-page .w-cart-listing .item > div','grid-row','1','','','.success-page'),(892576,'furniture','.w-banner .banner-image','grid-row','1','','','.w-banner'),(892577,'furniture','.w-banner .banner-item.text-bottom-text .banner-text','grid-row','2','','','.w-banner'),(892578,'furniture','.w-banner .banner-text','grid-row','1','','','.w-banner'),(892579,'furniture','.w-promotions .content','grid-row-start','2','','','.w-promotions'),(892580,'furniture','.w-promotions .condition','grid-row-start','1','','','.w-promotions'),(892581,'furniture','.w-promotions .heading','grid-row-start','1','','','.w-promotions'),(892582,'furniture','.w-predefined-promotion .condition','grid-row-start','1','','','.w-predefined-promotion'),(892583,'furniture','.w-predefined-promotion .content','grid-row-start','2','','','.w-predefined-promotion'),(892584,'furniture','.w-predefined-promotion .heading','grid-row-start','1','','','.w-predefined-promotion'),(892585,'furniture','.w-account-personal-catalog .remove','grid-row_important','important','5131','','.w-account-personal-catalog'),(892586,'furniture','.w-promotions .prom-multi-discount .list','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(892587,'furniture','.w-promotions .prom-multi-discount .promo-group-4 .products','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(892588,'furniture','.w-promotions .prom-multi-discount .promo-group-3 .products','grid-template-columns','1fr 1fr 1fr','','','.w-promotions'),(892589,'furniture','.w-promotions .prom-multi-discount .products','grid-template-columns','1fr','','','.w-promotions'),(892590,'furniture','.w-promotions .prom-multi-discount .promo-group-2 .products','grid-template-columns','1fr 1fr','','','.w-promotions'),(892591,'furniture','.w-promotions .nextdiscount .content','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(892592,'furniture','.w-reviews-content .item','grid-template-columns','170px 1fr 1fr','','','.w-reviews-content'),(892593,'furniture','.w-reviews .item','grid-template-columns','140px 1fr 1fr','','','.w-reviews'),(892594,'furniture','.w-cart-listing .item','grid-template-columns','100px 1fr 150px 130px','5140','','.w-cart-listing'),(892595,'furniture','.w-cart-listing .item','grid-template-columns','80px 70px 1fr','5131','','.w-cart-listing'),(892596,'furniture','.w-cart-listing .item, .w-cart-listing .headings','grid-template-columns','50px 120px 1fr 150px 200px','','','.w-cart-listing'),(892597,'furniture','.w-sample-products .w-cart-listing .item, .w-sample-products .w-cart-listing .headings','grid-template-columns','50px 120px 1fr 150px','','','.w-sample-products'),(892598,'furniture','.w-sample-products .w-cart-listing .item, .w-sample-products .w-cart-listing .headings','grid-template-columns','80px 70px 1fr','5131','','.w-sample-products'),(892599,'furniture','.w-account-personal-catalog .w-cart-listing .item','grid-template-columns','50px 120px 1fr 150px 200px','5140','','.w-account-personal-catalog'),(892600,'furniture','.w-account-personal-catalog .w-cart-listing .item','grid-template-columns','50px 120px 1fr','5131','','.w-account-personal-catalog'),(892601,'furniture','.w-press-reviews-widgets-press-reviews .item','grid-template-columns','170px 1fr 1fr','','','.w-press-reviews-widgets-press-reviews'),(892602,'furniture','.w-press-reviews-widgets-press-reviews .item','grid-template-columns','1fr','5131','','.w-press-reviews-widgets-press-reviews'),(892603,'furniture','.w-predefined-promotion .nextdiscount .content','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-predefined-promotion'),(892604,'furniture','.w-predefined-promotion .prom-multi-discount .list','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-predefined-promotion'),(892605,'furniture','.w-predefined-promotion .prom-multi-discount .products','grid-template-columns','1fr','','','.w-predefined-promotion'),(892606,'furniture','.w-predefined-promotion .prom-multi-discount .promo-group-2 .products','grid-template-columns','1fr 1fr','','','.w-predefined-promotion'),(892607,'furniture','.w-predefined-promotion .prom-multi-discount .promo-group-3 .products','grid-template-columns','1fr 1fr 1fr','','','.w-predefined-promotion'),(892608,'furniture','.w-predefined-promotion .prom-multi-discount .promo-group-4 .products','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-predefined-promotion'),(892609,'furniture','.order-summary .w-cart-listing .headings','grid-template-columns','3fr 1fr 1fr','','','.order-summary'),(892610,'furniture','.order-summary .w-cart-listing .item','grid-template-columns','3fr 1fr 1fr','','','.order-summary'),(892611,'furniture','.w-cart-listing .no-price .item','grid-template-columns','50px 100px 1fr 150px 130px','5140','','.w-cart-listing'),(892612,'furniture','.w-cart-listing .no-price .item','grid-template-columns','100px 1fr','5131','','.w-cart-listing'),(892613,'furniture','.success-page .w-cart-listing .item','grid-template-columns','80px 1fr 100px','','','.success-page'),(892614,'furniture','.w-cart-listing .item','grid-template-rows','1fr','5131','','.w-cart-listing'),(892615,'furniture','.w-cart-listing .item','grid-template-rows','53px 1fr','','','.w-cart-listing'),(892616,'furniture','.success-page .w-cart-listing .item','grid-template-rows','1fr','','','.success-page'),(892617,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','height','28','','','.b-switch'),(892618,'furniture','.w-product-promotions select','height','29','','','.w-product-promotions'),(892619,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','height','20','3','','.b-switch'),(892620,'furniture','.b-email-editor img','height','auto','','','.b-email-editor'),(892621,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.p-quick-order-index'),(892622,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.p-quick-order-index'),(892623,'furniture','.w-product-images-additional .item-div','height','80','5161','','.w-product-images-additional'),(892624,'furniture','.w-promotions .prom-multi-discount .products','height','calc(100% - 25px)','','','.w-promotions'),(892625,'furniture','.w-promotions .prom-multi-discount .image img','height','auto','','','.w-promotions'),(892626,'furniture','.w-promotions .promo-salemaker .image img','height','auto','','','.w-promotions'),(892627,'furniture','.w-promotions .promo-cart-discount .image img','height','auto','','','.w-promotions'),(892628,'furniture','.b-preloader .preloader','height','40','3','','.b-preloader'),(892629,'furniture','.b-preloader .preloader','height','100','','','.b-preloader'),(892630,'furniture','.b-messages .select2-container-multi input.select2-input','height','31','','','.b-messages'),(892631,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','height','35','','',''),(892632,'furniture','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(892633,'furniture','.w-product-promotions select','height','29','','','.w-product-promotions'),(892634,'furniture','.p-payer-order-confirmation .input-wrapper','height','35','','','.p-payer-order-confirmation'),(892635,'furniture','.p-payer-order-pay .input-wrapper','height','35','','','.p-payer-order-pay'),(892636,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','height','15','3','','.b-switch'),(892637,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','height','15','','','.b-switch'),(892638,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','height','15','','','.b-switch'),(892639,'furniture','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(892640,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','height','15','','','.b-switch'),(892641,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','height','30','4','','.b-switch'),(892642,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg','height','15','','','.b-switch'),(892643,'furniture','.b-fancybox #fancybox-loading div','height','44','','','.b-fancybox'),(892644,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','height','60','','','.b-switch'),(892645,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height','100','3','','.b-switch'),(892646,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-toggle','height','40','','','.b-switch'),(892647,'furniture','.w-checkout-shipping-choice input:checked + span:before','height','10','','','.w-checkout-shipping-choice'),(892648,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','height','150','','','.w-upload-customer-id-upload-customer-id-form'),(892649,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file','height','100','','','.w-upload-customer-id-upload-customer-id-form'),(892650,'furniture','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(892651,'furniture','.b-switch .bootstrap-switch','height','28','','','.b-switch'),(892652,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','height','10','3','','.b-switch'),(892653,'furniture','.w-personal-gift-status-bar .progress-bar','height','8','','','.w-personal-gift-status-bar'),(892654,'furniture','.w-filters .input-checkbox:checked + .checkbox-span','height','24','','','.w-filters'),(892655,'furniture','.b-info-popup .info-popup div','height','20','3','','.b-info-popup'),(892656,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','height','10','','','.b-switch'),(892657,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','height','10','','','.b-switch'),(892658,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','height','15','4','','.b-switch'),(892659,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-toggle','height','15','','','.b-switch'),(892660,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg','height','10','','','.b-switch'),(892661,'furniture','.b-form .hide-billing-address','height','100','','','.b-form'),(892662,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','height','16','3','','.b-switch'),(892663,'furniture','.b-select-suggest .select2-container .select2-choice abbr','height','12','','','.b-select-suggest'),(892664,'furniture','.w-filters .ui-slider-handle','height','18','','','.w-filters'),(892666,'furniture','.w-filters .ui-slider','height','6','','','.w-filters'),(892667,'furniture','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(892668,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','height','16','','','.b-switch'),(892669,'furniture','.b-switch .candlestick-wrapper','height','auto','','','.b-switch'),(892670,'furniture','.b-switch .candlestick-wrapper .candlestick-bg','height','28','','','.b-switch'),(892671,'furniture','.w-product-images-additional .item','height','80','5161','','.w-product-images-additional'),(892672,'furniture','.b-bottom .cart-options .cart-item input[type=\"text\"]','height','25','','','.b-bottom'),(892673,'furniture','.b-select-suggest .select2-measure-scrollbar','height','100','','','.b-select-suggest'),(892674,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','height','30','3','','.b-form'),(892675,'furniture','.b-fancybox .fancybox-close','height','40','','','.b-fancybox'),(892676,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height','1','','','.b-select-suggest'),(892677,'furniture','.w-product-images-additional .item','height','80','5161','','.w-product-images-additional'),(892678,'furniture','.w-product-images-additional .item-div','height','80','5161','','.w-product-images-additional'),(892679,'furniture','.w-product-images-additional .item-div','height','80','5161','','.w-product-images-additional'),(892680,'furniture','.b-email-editor img','height','auto','','','.b-email-editor'),(892681,'furniture','.w-product-images-additional .item-div','height','80','5161','','.w-product-images-additional'),(892682,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','height','20','','','.b-switch'),(892683,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span','height','18','','','.b-form'),(892684,'furniture','.w-product-promotions select','height','29','','','.w-product-promotions'),(892685,'furniture','.w-product-promotions select','height','29','','','.w-product-promotions'),(892686,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height','60','','','.b-switch'),(892687,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','height','56','','','.b-switch'),(892688,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height','100','4','','.b-switch'),(892689,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','','','.b-switch'),(892690,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height','60','','','.b-switch'),(892691,'furniture','.b-email-editor img','height','auto','','','.b-email-editor'),(892692,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','height','100','','','.b-switch'),(892693,'furniture','.b-switch .candlestick-wrapper.candlestick-contents','height','56','','','.b-switch'),(892694,'furniture','.w-product-promotions select','height','29','','','.w-product-promotions'),(892695,'furniture','.b-fancybox .fancybox-nav','height','100','','','.b-fancybox'),(892696,'furniture','.b-select-suggest .select2-container .select2-choice','height','35','','','.b-select-suggest'),(892697,'furniture','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(892698,'furniture','.w-personal-gift-status-bar .progress-bar-content','height','8','','','.w-personal-gift-status-bar'),(892699,'furniture','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(892700,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','height','20','3','','.b-switch'),(892701,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','4','','.b-switch'),(892702,'furniture','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(892703,'furniture','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(892704,'furniture','.b-email-editor img','height','auto','','','.b-email-editor'),(892705,'furniture','.w-product-images-additional .item-div','height','80','5161','','.w-product-images-additional'),(892706,'furniture','.b-autocomplete .ui-autocomplete','height','300','','','.b-autocomplete'),(892707,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','','','.b-switch'),(892708,'furniture','.b-form .checkbox-style:checked + .checkbox-span','height','18','','','.b-form'),(892709,'furniture','.b-info-popup .info-popup','height','2','','','.b-info-popup'),(892710,'furniture','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(892711,'furniture','.w-product-customers-activity .close','height','30','','','.w-product-customers-activity'),(892712,'furniture','.b-email-editor img','height','auto','','','.b-email-editor'),(892713,'furniture','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(892714,'furniture','.w-menu-horizontal .menu-ico','height','54','','','.w-menu-horizontal'),(892715,'furniture','.w-product-images-additional .item','height','80','5161','','.w-product-images-additional'),(892716,'furniture','.w-product-images-additional .item-div','height','80','5161','','.w-product-images-additional'),(892717,'furniture','.w-product-images-additional .item','height','80','5161','','.w-product-images-additional'),(892718,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','height','16','','','.b-switch'),(892719,'furniture','.b-select-suggest .select2-search-choice-close','height','13','','','.b-select-suggest'),(892720,'furniture','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','height','25','','','.b-datepicker'),(892721,'furniture','.b-select-suggest .select2-search input','height','auto','','','.b-select-suggest'),(892722,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height','100','','','.b-select-suggest'),(892723,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow','height','100','','','.b-select-suggest'),(892724,'furniture','.b-select-suggest .select2-drop-mask','height','auto','','','.b-select-suggest'),(892725,'furniture','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(892726,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.b-data-table'),(892727,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.b-data-table'),(892728,'furniture','.b-products-listing .btn-preloader','height','24','3','','.b-products-listing'),(892729,'furniture','.b-products-listing .hover-box-content','height','20','3','','.b-products-listing'),(892730,'furniture','.b-products-listing .loader','height','30','4','','.b-products-listing'),(892731,'furniture','.b-products-listing .loader','height','100','3','','.b-products-listing'),(892732,'furniture','.b-products-listing .products-listing .qty-input.hidden','height','100','3','','.b-products-listing'),(892733,'furniture','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','height','auto','','','.b-products-listing'),(892734,'furniture','.checkbox input + span','height','24','','',''),(892735,'furniture','.checkbox input:not(checked) + span:before','height','22','','',''),(892736,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','height','20','3','','.b-switch'),(892737,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','height','10','4','','.b-switch'),(892738,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-toggle','height','10','','','.b-switch'),(892739,'furniture','.b-email-editor img','height','auto','','','.b-email-editor'),(892740,'furniture','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height','100','','','.b-fancybox'),(892741,'furniture','.w-product-promotions select','height','29','','','.w-product-promotions'),(892742,'furniture','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(892743,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','height','36','','','.w-communication-new-topic'),(892744,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','height','36','','','.w-communication-new-topic'),(892745,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','height','30','','','.w-communication-new-topic'),(892746,'furniture','.w-communication-new-topic #communication_group_holder select','height','35','','','.w-communication-new-topic'),(892747,'furniture','.w-catalog-listing-look .grid','height','35','','','.w-catalog-listing-look'),(892748,'furniture','.w-catalog-listing-look .b2b','height','35','','','.w-catalog-listing-look'),(892749,'furniture','.w-catalog-listing-look .list','height','35','','','.w-catalog-listing-look'),(892750,'furniture','.w-cart-listing .remove-btn','height','30','','','.w-cart-listing'),(892751,'furniture','.w-cart-listing .item .remove','height','45','5140','','.w-cart-listing'),(892752,'furniture','.b-upload-file .snapshot','height','38','','','.b-upload-file'),(892753,'furniture','.w-image-maps .svg-wrap svg','height','100','','','.w-image-maps'),(892754,'furniture','.b-fancybox .fancybox-nav span','height','40','','','.b-fancybox'),(892755,'furniture','.b-upload-file .upload-file-template','height','150','','','.b-upload-file'),(892756,'furniture','.w-filters .ui-slider-range','height','6','','','.w-filters'),(892757,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','height','10','','','.b-switch'),(892758,'furniture','.b-bottom .pop-up-close','height','31','','','.b-bottom'),(892759,'furniture','.w-product-images-additional .item','height','80','5161','','.w-product-images-additional'),(892760,'furniture','.w-product-images-additional .item','height','80','5161','','.w-product-images-additional'),(892761,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg','height','30','','','.b-switch'),(892762,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','height','30','','','.b-switch'),(892763,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','height','30','','','.b-switch'),(892764,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','height','30','3','','.b-switch'),(892765,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','height','30','','','.b-switch'),(892766,'furniture','.w-filters .input-checkbox:not(checked) + .checkbox-span','height','24','','','.w-filters'),(892767,'furniture','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','height','auto','','','.b-product-images'),(892768,'furniture','.b-product-images .media-popup .mp-big-images','height','calc(100vh - 150px)','','','.b-product-images'),(892769,'furniture','.b-product-images .media-popup .mp-big-images .item','height','calc(100vh - 150px)','','','.b-product-images'),(892770,'furniture','.b-product-images .media-popup .mp-close','height','100','','','.b-product-images'),(892771,'furniture','.b-product-images .media-popup .mp-content','height','100','','','.b-product-images'),(892772,'furniture','.b-product-images .media-popup .mp-small-images','height','100','','','.b-product-images'),(892773,'furniture','.b-product-images .media-popup .mp-small-images .item','height','100','','','.b-product-images'),(892774,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','height','100','','','.b-product-images'),(892775,'furniture','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','height','30','','','.b-menu-burger_icon'),(892776,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(892777,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(892778,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(892779,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(892780,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(892781,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height','100','','','.b-menu-open_from-left'),(892782,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(892783,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','height','28','','','.b-menu-style-2'),(892784,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','height','50','','','.b-menu-style-2'),(892785,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','height','24','','','.b-menu-style-2'),(892786,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','height','16','3','','.b-menu-style-2'),(892787,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','height','28','','','.b-menu-style-2'),(892788,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','height','16','3','','.b-menu-style-2'),(892789,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','height','24','','','.b-menu-style-2'),(892790,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','height','35','','','.b-trade-approval'),(892791,'furniture','.w-account-subscription .info-popup','height','15','','','.w-account-subscription'),(892792,'furniture','.w-catalog-compare span.btn-preloader','height','24','','','.w-catalog-compare'),(892799,'furniture','.b-slick .slick-slide','height','100','','','.b-slick'),(892800,'furniture','.b-slick .slick-vertical .slick-slide','height','auto','','','.b-slick'),(892801,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','height','40','','','.b-slick'),(892802,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','height','50','5140','','.b-slick'),(892805,'furniture','.menu-header .burger-icon','height','40','5140','','.menu-header'),(892806,'furniture','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','height','18','','','.w-filters'),(892807,'furniture','.b-products-listing .products-listing.list-productlisting .item-content','height','1','4','','.b-products-listing'),(892808,'furniture','.w-quote .cart-box-link','height','48','3','','.w-quote'),(892809,'furniture','.w-quote .cart-box-link','height','40','5140,3','','.w-quote'),(892810,'furniture','.w-product-images .additional-vertical','height','400','','','.w-product-images'),(892811,'furniture','.w-product-images .img-holder','height','100','','','.w-product-images'),(892812,'furniture','.b-quantity .qty-box .bigger','height','35','','','.b-quantity'),(892813,'furniture','.b-quantity .qty-box .smaller','height','35','','','.b-quantity'),(892814,'furniture','.b-quantity .qty-box input','height','35','','','.b-quantity'),(892815,'furniture','h1, .heading-1','height','1','3','',''),(892816,'furniture','h1, .heading-1','height','1','4','',''),(892817,'furniture','.w-product-quantity .qty-box .smaller, .w-product-quantity .qty-box .bigger','height','46','','','.w-product-quantity'),(892818,'furniture','.w-product-quantity .qty-input input[type=\'text\']','height','46','','','.w-product-quantity'),(892819,'furniture','.warrantyProduct .warranty','height','32','3','','.warrantyProduct'),(892820,'furniture','.warrantyProduct .delivery','height','30','3','','.warrantyProduct'),(892821,'furniture','.w-sample .cart-box-link','height','10','4','','.w-sample'),(892822,'furniture','.w-sample .cart-box-link','height','48','3','','.w-sample'),(892823,'furniture','.w-sample .cart-box-link','height','40','5140,3','','.w-sample'),(892824,'furniture','.w-cart-listing .points-earn','height','0','4','','.w-cart-listing'),(892825,'furniture','.w-catalog-additional-images img','height','auto','','','.w-catalog-additional-images'),(892826,'furniture','.w-catalog-additional-images picture','height','150','','','.w-catalog-additional-images'),(892827,'furniture','.heading-2','height','1','3','',''),(892828,'furniture','.heading-2','height','1','4','',''),(892829,'furniture','.b-pagination .pagination .next-pages','height','30','','','.b-pagination'),(892830,'furniture','.b-pagination .pagination .page-number','height','30','','','.b-pagination'),(892831,'furniture','.b-pagination .pagination .prev-pages','height','30','','','.b-pagination'),(892832,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','height','30','','','.b-pagination'),(892833,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','height','30','','','.b-pagination'),(892834,'furniture','.b-pagination .pagination span','height','30','2','','.b-pagination'),(892835,'furniture','.p-quote-checkout-index .order-summary .heading-2','height','1','3','','.p-quote-checkout-index'),(892836,'furniture','.p-quote-checkout-index .order-summary .heading-2','height','1','4','','.p-quote-checkout-index'),(892837,'furniture','.p-sample-checkout-index .order-summary .heading-2','height','1','3','','.p-sample-checkout-index'),(892838,'furniture','.p-sample-checkout-index .order-summary .heading-2','height','1','4','','.p-sample-checkout-index'),(892840,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','height','36','','','.w-account-personal-catalog'),(892841,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','height','40','','','.w-questionnaire-widgets-questionnaire'),(892842,'furniture','.w-sale-category .badge','height','80','','','.w-sale-category'),(892843,'furniture','.w-product-designer-designer .prodDesignerType label','height','78','','','.w-product-designer-designer'),(892844,'furniture','.w-product-designer-designer .productDesignerBox input','height','100','','','.w-product-designer-designer'),(892845,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','height','35','','','.w-rma-returns-history'),(892846,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(892847,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(892848,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(892849,'furniture','.w-predefined-promotion .prom-multi-discount .image img','height','auto','','','.w-predefined-promotion'),(892850,'furniture','.w-predefined-promotion .prom-multi-discount .products','height','calc(100% - 25px)','','','.w-predefined-promotion'),(892851,'furniture','.w-predefined-promotion .promo-cart-discount .image img','height','auto','','','.w-predefined-promotion'),(892852,'furniture','.w-predefined-promotion .promo-salemaker .image img','height','auto','','','.w-predefined-promotion'),(892853,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','height','24','','','.w-filters'),(892854,'furniture','.mainBanner .title','height','6','3','','.mainBanner'),(892855,'furniture','.mainBanner .topBox > .right','height','18','3','','.mainBanner'),(892856,'furniture','.mainBanner .title','height','9','5131,3','','.mainBanner'),(892857,'furniture','.mainBanner .topBox > .right','height','15','5131,3','','.mainBanner'),(892858,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','height','100','','','.mainBanner'),(892859,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','height','100','','','.mainBanner'),(892860,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','height','100','','','.mainBanner'),(892861,'furniture','.mainBanner .title','height','100','5206,3','','.mainBanner'),(892862,'furniture','.order-summary .icon','height','30','','','.order-summary'),(892871,'furniture','.account-samples .orders-table .td-alignright','height','45','5140','','.account-samples'),(892872,'furniture','.catalog-product-wrap .pn-image','height','24','3','','.catalog-product-wrap'),(892873,'furniture','.checkout-index-wrap .input-wrapper','height','35','','','.checkout-index-wrap'),(892874,'furniture','.checkout-index-wrap .order-summary .heading-2','height','1','3','','.checkout-index-wrap'),(892875,'furniture','.checkout-index-wrap .order-summary .heading-2','height','1','4','','.checkout-index-wrap'),(892876,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-content','height','auto','','','.b-multi-page-checkout'),(892877,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','height','33','','','.b-multi-page-checkout'),(892878,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','height','35','3','','.b-multi-page-checkout'),(892879,'furniture','.success-page .w-cart-listing .qty','height','24','','','.success-page'),(892880,'furniture','.lowestPricedBox .w-banner .banner-item:nth-child(1) .ybg:before','height','15','5145','','.lowestPricedBox'),(892881,'furniture','.lowestPricedBox .w-banner .banner-item:nth-child(2) .ybg:before','height','15','5145','','.lowestPricedBox'),(892882,'furniture','.lowestPricedBox .w-banner .banner-text-holder','height','100','','','.lowestPricedBox'),(892883,'furniture','.lowestPricedBox .w-banner .ybg','height','100','','','.lowestPricedBox'),(892884,'furniture','.lowestPricedBox .w-banner .ybg','height','20','3','','.lowestPricedBox'),(892885,'furniture','.tripleBanner .w-html_box','height','100','3','','.tripleBanner'),(892886,'furniture','.tripleBanner > .block > .box','height','100','','','.tripleBanner'),(892887,'furniture','.w-banner .carousel-text','height','100','','','.w-banner'),(892888,'furniture','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height','100','','','.w-banner'),(892889,'furniture','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height','100','','','.w-banner'),(892890,'furniture','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height','100','','','.w-banner'),(892891,'furniture','.w-catalog-paging ','height','30','2','','.w-catalog-paging'),(892892,'furniture','.w-catalog-paging .next','height','30','','','.w-catalog-paging'),(892893,'furniture','.w-catalog-paging .next-pages','height','30','','','.w-catalog-paging'),(892894,'furniture','.w-catalog-paging .page-number','height','30','','','.w-catalog-paging'),(892895,'furniture','.w-catalog-paging .paging-holder','height','30','','','.w-catalog-paging'),(892896,'furniture','.w-catalog-paging .prev','height','30','','','.w-catalog-paging'),(892897,'furniture','.w-catalog-paging .prev-pages','height','30','','','.w-catalog-paging'),(892898,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height','30','','','.w-catalog-paging'),(892899,'furniture','.w-compare-box-item .checkbox','height','22','','','.w-compare-box-item'),(892900,'furniture','.w-compare-box-item .checkbox + span','height','24','','','.w-compare-box-item'),(892901,'furniture','.w-compare-box-item .checkbox:not(checked) + span:before','height','22','','','.w-compare-box-item'),(892902,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height_important','important','','','.b-select-suggest'),(892903,'furniture','.b-select-suggest .select2-search input','height_important','important','','','.b-select-suggest'),(892904,'furniture','.menu-header .burger-icon','height_important','important','5140','','.menu-header'),(892905,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-content','height_important','important','','','.b-multi-page-checkout'),(892906,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height_important','important','','','.w-catalog-paging'),(892907,'furniture','.b-preloader .preloader','height_measure','%','','','.b-preloader'),(892908,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height_measure','%','3','','.b-switch'),(892909,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file','height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(892910,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height_measure','%','4','','.b-switch'),(892911,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','height_measure','%','','','.b-switch'),(892912,'furniture','.b-fancybox .fancybox-nav','height_measure','%','','','.b-fancybox'),(892913,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height_measure','%','','','.b-select-suggest'),(892914,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow','height_measure','%','','','.b-select-suggest'),(892915,'furniture','.b-products-listing .loader','height_measure','%','3','','.b-products-listing'),(892916,'furniture','.b-products-listing .products-listing .qty-input.hidden','height_measure','%','3','','.b-products-listing'),(892917,'furniture','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height_measure','%','','','.b-fancybox'),(892918,'furniture','.b-form .hide-billing-address','height_measure','%','','','.b-form'),(892919,'furniture','.w-image-maps .svg-wrap svg','height_measure','%','','','.w-image-maps'),(892920,'furniture','.b-product-images .media-popup .mp-content','height_measure','vh','','','.b-product-images'),(892921,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height_measure','vh','','','.b-menu-open_from-left'),(892922,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(892923,'furniture','.b-slick .slick-slide','height_measure','%','','','.b-slick'),(892924,'furniture','.w-catalog-listing-look .b2b','height_measure','x','','','.w-catalog-listing-look'),(892925,'furniture','.w-product-images .img-holder','height_measure','%','','','.w-product-images'),(892926,'furniture','.w-product-designer-designer .productDesignerBox input','height_measure','%','','','.w-product-designer-designer'),(892927,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(892928,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(892929,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(892930,'furniture','.mainBanner .title','height_measure','vw','3','','.mainBanner'),(892931,'furniture','.mainBanner .title','height_measure','vw','5131,3','','.mainBanner'),(892932,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','height_measure','%','','','.mainBanner'),(892933,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','height_measure','%','','','.mainBanner'),(892934,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','height_measure','%','','','.mainBanner'),(892936,'furniture','.lowestPricedBox .w-banner .banner-text-holder','height_measure','%','','','.lowestPricedBox'),(892937,'furniture','.lowestPricedBox .w-banner .ybg','height_measure','%','','','.lowestPricedBox'),(892938,'furniture','.tripleBanner .w-html_box','height_measure','%','3','','.tripleBanner'),(892939,'furniture','.tripleBanner > .block > .box','height_measure','%','','','.tripleBanner'),(892940,'furniture','.w-banner .carousel-text','height_measure','%','','','.w-banner'),(892941,'furniture','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height_measure','%','','','.w-banner'),(892942,'furniture','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height_measure','%','','','.w-banner'),(892943,'furniture','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height_measure','%','','','.w-banner'),(892944,'furniture','.w-promotions .promo-cart-discount .content','justify-content','center','','','.w-promotions'),(892945,'furniture','.w-promotions .prom-multi-discount .products','justify-content','space-between','','','.w-promotions'),(892946,'furniture','.w-promotions .promo-salemaker .content','justify-content','center','','','.w-promotions'),(892947,'furniture','.b-products-listing .products-listing .attribute-qty-blocks','justify-content','space-between','','','.b-products-listing'),(892948,'furniture','.p-quick-order-index .quick-order-total','justify-content','space-between','','','.p-quick-order-index'),(892949,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(892950,'furniture','.w-personal-gift-status-bar .timeline','justify-content','center','','','.w-personal-gift-status-bar'),(892951,'furniture','.w-checkout-shipping-choice span','justify-content','center','','','.w-checkout-shipping-choice'),(892952,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(892953,'furniture','.order-summary .price-row','justify-content','space-between','','','.order-summary'),(892954,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(892955,'furniture','.w-communication-post .communication-post-author','justify-content','space-between','','','.w-communication-post'),(892956,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(892957,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(892958,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(892959,'furniture','.b-product-images .media-popup .mp-big-images .item','justify-content','center','','','.b-product-images'),(892960,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(892961,'furniture','.w-catalog-compare .cross-box','justify-content','flex-end','','','.w-catalog-compare'),(892962,'furniture','.w-product-images .img-holder','justify-content','center','','','.w-product-images'),(892963,'furniture','.w-files-catalog-widgets-files-catalog ','justify-content','space-between','','','.w-files-catalog-widgets-files-catalog'),(892964,'furniture','.w-files-catalog-widgets-files-catalog .image','justify-content','center','','','.w-files-catalog-widgets-files-catalog'),(892965,'furniture','.w-product-bundle .bundle-products','justify-content','space-between','','','.w-product-bundle'),(892966,'furniture','.w-product-in-bundles .bundle-products','justify-content','space-between','','','.w-product-in-bundles'),(892968,'furniture','.w-delivery-location-product-categories .categories','justify-content','center','','','.w-delivery-location-product-categories'),(892969,'furniture','.w-press-reviews-widgets-press-reviews .review-box','justify-content','center','','','.w-press-reviews-widgets-press-reviews'),(892970,'furniture','.w-press-reviews-widgets-press-reviews-list .review-box','justify-content','center','','','.w-press-reviews-widgets-press-reviews-list'),(892971,'furniture','.w-rma-returns-history .column','justify-content','space-between','','','.w-rma-returns-history'),(892972,'furniture','.w-rma-returns-history .filterMessages','justify-content','space-between','','','.w-rma-returns-history'),(892973,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul','justify-content','flex-start','','','.b-menu-position'),(892974,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(892975,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul','justify-content','center','','','.b-menu-position'),(892976,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(892977,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul','justify-content','flex-end','','','.b-menu-position'),(892978,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(892979,'furniture','.w-predefined-promotion .prom-multi-discount .products','justify-content','space-between','','','.w-predefined-promotion'),(892980,'furniture','.w-predefined-promotion .promo-cart-discount .content','justify-content','center','','','.w-predefined-promotion'),(892981,'furniture','.w-predefined-promotion .promo-salemaker .content','justify-content','center','','','.w-predefined-promotion'),(892982,'furniture','.w-supplier-purchase-supplier-products .item','justify-content','space-between','','','.w-supplier-purchase-supplier-products'),(892983,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons','justify-content','space-between','','','.checkout-index-wrap'),(892984,'furniture','.checkout-order-confirmation .price-row','justify-content','space-between','','','.checkout-order-confirmation'),(892985,'furniture','.b-form .columns','justify-content','space-between','','','.b-form'),(892986,'furniture','.w-checkout-totals .price-row','justify-content','space-between','','','.w-checkout-totals'),(892987,'furniture','.b-form .formWrapBox','justify-content','space-between','','','.b-form'),(892988,'furniture','.success-page .order_totals .price-row','justify-content','space-between','','','.success-page'),(892989,'furniture','.success-page .price-row','justify-content','space-between','','','.success-page'),(892990,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','justify-content','space-between','','','.menu-header'),(892991,'furniture','.lowestPricedBox .w-banner .ybg','justify-content','center','5131','','.lowestPricedBox'),(892992,'furniture','.lowestPricedBox .w-banner .ybg','justify-content','center','5140','','.lowestPricedBox'),(892993,'furniture','.shopByCollectionBox .w-banner .banner-holder','justify-content','center','5140','','.shopByCollectionBox'),(892995,'furniture','.w-banner .banner-item.text-bottom-center .banner-text','justify-content','center','','','.w-banner'),(892996,'furniture','.w-banner .banner-item.text-bottom-left .banner-text','justify-content','start','','','.w-banner'),(892997,'furniture','.w-banner .banner-item.text-bottom-right .banner-text','justify-content','end','','','.w-banner'),(892998,'furniture','.w-banner .banner-item.text-middle-center .banner-text','justify-content','center','','','.w-banner'),(892999,'furniture','.w-banner .banner-item.text-middle-left .banner-text','justify-content','start','','','.w-banner'),(893000,'furniture','.w-banner .banner-item.text-middle-right .banner-text','justify-content','end','','','.w-banner'),(893001,'furniture','.w-banner .banner-item.text-top-center .banner-text','justify-content','center','','','.w-banner'),(893002,'furniture','.w-banner .banner-item.text-top-left .banner-text','justify-content','start','','','.w-banner'),(893003,'furniture','.w-banner .banner-item.text-top-right .banner-text','justify-content','end','','','.w-banner'),(893004,'furniture','.w-banner .carousel .bottom-center','justify-content','center','','','.w-banner'),(893005,'furniture','.w-banner .carousel .bottom-left','justify-content','flex-start','','','.w-banner'),(893006,'furniture','.w-banner .carousel .bottom-right','justify-content','flex-end','','','.w-banner'),(893007,'furniture','.w-banner .carousel .middle-center','justify-content','center','','','.w-banner'),(893008,'furniture','.w-banner .carousel .middle-left','justify-content','flex-start','','','.w-banner'),(893009,'furniture','.w-banner .carousel .middle-right','justify-content','flex-end','','','.w-banner'),(893010,'furniture','.w-banner .carousel .top-center','justify-content','center','','','.w-banner'),(893011,'furniture','.w-banner .carousel .top-left','justify-content','flex-start','','','.w-banner'),(893012,'furniture','.w-banner .carousel .top-right','justify-content','flex-end','','','.w-banner'),(893013,'furniture','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(893014,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','left','2','3','','.b-switch'),(893015,'furniture','.w-promo-code .holder','left','12','5161,3','','.w-promo-code'),(893016,'furniture','.p-quick-order-index .all-scroll-div','left','0','','','.p-quick-order-index'),(893017,'furniture','.w-promo-code .holder','left','20','3','','.w-promo-code'),(893018,'furniture','.testimonials .heading-3','left','0','3','',''),(893019,'furniture','.testimonials .review','left','10','3','',''),(893020,'furniture','.b-preloader .preloader','left','calc(50% - 20px)','3','','.b-preloader'),(893021,'furniture','.b-preloader .preloader','left','0','','','.b-preloader'),(893022,'furniture','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(893023,'furniture','.w-checkout-terms .required-message','left','0','','','.w-checkout-terms'),(893024,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','left','15','','','.b-switch'),(893025,'furniture','.b-fancybox #fancybox-loading','left','50','','','.b-fancybox'),(893026,'furniture','.b-fancybox .fancybox-wrap','left','0','','','.b-fancybox'),(893027,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','left','100','','','.b-switch'),(893028,'furniture','.w-promo-code .holder','left','20','3','','.w-promo-code'),(893029,'furniture','.w-checkout-shipping-choice input:checked + span:before','left','50','','','.w-checkout-shipping-choice'),(893030,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(893031,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-details','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(893032,'furniture','.b-info-popup .info-popup div','left','-11','3','','.b-info-popup'),(893033,'furniture','.b-fancybox .fancybox-title-over-wrap','left','0','','','.b-fancybox'),(893034,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','left','10','','','.b-switch'),(893035,'furniture','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(893036,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','left','20','','','.b-switch'),(893037,'furniture','.w-cart-compare .dropdown .dropdown-menu','left','auto','','','.w-cart-compare'),(893038,'furniture','.b-select-suggest .select2-measure-scrollbar','left','-10000','','','.b-select-suggest'),(893039,'furniture','.b-fancybox .fancybox-tmp','left','-99999','','','.b-fancybox'),(893041,'furniture','.b-info-popup .info-popup.top-left div','left','auto','','','.b-info-popup'),(893042,'furniture','.b-info-popup .info-popup.top-left div','left','auto','3','','.b-info-popup'),(893043,'furniture','.w-promo-code .holder','left','12','5161,3','','.w-promo-code'),(893044,'furniture','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(893045,'furniture','.w-promo-code .holder','left','20','3','','.w-promo-code'),(893046,'furniture','.view-all','left','0','3','',''),(893047,'furniture','.w-text .customer-service','left','0','3','','.w-text'),(893048,'furniture','.b-fancybox .fancybox-overlay','left','0','','','.b-fancybox'),(893050,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left','25','','','.b-switch'),(893051,'furniture','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(893052,'furniture','.w-multi-cart-actions .dropdown .dropdown-menu','left','0','','','.w-multi-cart-actions'),(893053,'furniture','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','left','0','','','.b-switch'),(893054,'furniture','.w-text .customer-service','left','0','3','','.w-text'),(893055,'furniture','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(893056,'furniture','.b-select-suggest .select2-drop-mask','left','0','','','.b-select-suggest'),(893057,'furniture','.w-reviews .review','left','15','3','','.w-reviews'),(893058,'furniture','.w-text .customer-service','left','0','3','','.w-text'),(893059,'furniture','.b-fancybox .fancybox-prev','left','0','','','.b-fancybox'),(893060,'furniture','.b-fancybox .fancybox-prev span','left','10','','','.b-fancybox'),(893061,'furniture','.w-text .customer-service','left','0','3','','.w-text'),(893062,'furniture','.w-promo-code .holder','left','12','5161,3','','.w-promo-code'),(893063,'furniture','.w-promo-code .holder','left','20','3','','.w-promo-code'),(893064,'furniture','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(893065,'furniture','.w-reviews .heading-3','left','0','3','','.w-reviews'),(893066,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','left','2','3','','.b-switch'),(893067,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left','4','3','','.b-switch'),(893068,'furniture','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(893069,'furniture','.w-reviews-content .review','left','15','3','','.w-reviews-content'),(893070,'furniture','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(893071,'furniture','.w-promo-code .holder','left','12','5161,3','','.w-promo-code'),(893072,'furniture','.b-form .radio-button input[type=\"radio\"].no','left','-100','','','.b-form'),(893073,'furniture','.w-text .customer-service','left','0','3','','.w-text'),(893074,'furniture','.w-checkout-billing-address .addresses .address-item label input','left','0','','','.w-checkout-billing-address'),(893075,'furniture','.w-promo-code .holder','left','12','5161,3','','.w-promo-code'),(893076,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','left','0','','','.b-switch'),(893077,'furniture','.b-select-suggest .select2-container-multi .select2-search-choice-close','left','3','','','.b-select-suggest'),(893078,'furniture','.w-menu-horizontal > ul > li > ul','left','0','','','.w-menu-horizontal'),(893079,'furniture','.w-checkout-shipping-address .addresses .address-item label input','left','0','','','.w-checkout-shipping-address'),(893080,'furniture','.w-text .customer-service','left','0','3','','.w-text'),(893081,'furniture','.w-image-maps .svg-wrap svg','left','0','','','.w-image-maps'),(893082,'furniture','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(893083,'furniture','.b-products-listing .products-listing .promos-info','left','0','','','.b-products-listing'),(893084,'furniture','.b-products-listing .hover-box-content','left','0','','','.b-products-listing'),(893085,'furniture','.b-products-listing .hover-box-content','left','20','3','','.b-products-listing'),(893086,'furniture','.b-products-listing .loader','left','calc(50% - 15px)','4','','.b-products-listing'),(893087,'furniture','.b-products-listing .loader','left','0','3','','.b-products-listing'),(893088,'furniture','.w-catalog-b2b-add-button ','left','0','','','.w-catalog-b2b-add-button'),(893089,'furniture','.b-products-listing .products-listing .qty-input.hidden','left','0','3','','.b-products-listing'),(893090,'furniture','.b-products-listing .promo','left','0','','','.b-products-listing'),(893091,'furniture','.checkbox input','left','-20','','',''),(893093,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left','0','','','.b-select-suggest'),(893094,'furniture','.w-promo-code .holder','left','20','3','','.w-promo-code'),(893095,'furniture','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(893096,'furniture','.w-promo-code .holder','left','20','3','','.w-promo-code'),(893097,'furniture','.w-promo-code .holder','left','12','5161,3','','.w-promo-code'),(893098,'furniture','.w-cart-listing .item .remove','left','0','5140','','.w-cart-listing'),(893099,'furniture','.w-cart-listing .remove-btn','left','10','5140','','.w-cart-listing'),(893100,'furniture','.w-cart-listing .remove-btn span','left','5','5140','','.w-cart-listing'),(893102,'furniture','.b-info-popup .info-popup div','left','40','','','.b-info-popup'),(893103,'furniture','.w-product-reviews .reviews-list .review','left','10','3','','.w-product-reviews'),(893104,'furniture','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(893105,'furniture','.b-form .hide-billing-address','left','0','','','.b-form'),(893106,'furniture','.w-menu-big > ul > li > ul','left','0','','','.w-menu-big'),(893107,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','left','40','','','.b-switch'),(893108,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','left','0','','','.w-image-maps'),(893109,'furniture','.b-product-images .mp-shadow, .b-product-images .media-popup','left','0','','','.b-product-images'),(893110,'furniture','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','left','0','','','.b-menu-lev_display-down'),(893111,'furniture','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','left','0','','','.b-menu-lev_display-down'),(893112,'furniture','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','left','0','','','.b-menu-lev_display-down'),(893113,'furniture','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','left','0','','','.b-menu-lev_display-down'),(893114,'furniture','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','left','0','','','.b-menu-lev_display-down'),(893115,'furniture','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left','100','','','.b-menu-lev_display-lra'),(893116,'furniture','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left','100','','','.b-menu-lev_display-lra'),(893117,'furniture','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left','100','','','.b-menu-lev_display-lra'),(893118,'furniture','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left','100','','','.b-menu-lev_display-lra'),(893119,'furniture','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left','100','','','.b-menu-lev_display-lra'),(893120,'furniture','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','left','auto','','','.b-menu-lev_display-lra'),(893121,'furniture','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','left','auto','','','.b-menu-lev_display-lra'),(893122,'furniture','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','left','auto','','','.b-menu-lev_display-lra'),(893123,'furniture','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','left','auto','','','.b-menu-lev_display-lra'),(893124,'furniture','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','left','auto','','','.b-menu-lev_display-lra'),(893125,'furniture','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left','100','','','.b-menu-lev_display-right'),(893126,'furniture','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left','100','','','.b-menu-lev_display-right'),(893127,'furniture','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left','100','','','.b-menu-lev_display-right'),(893128,'furniture','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left','100','','','.b-menu-lev_display-right'),(893129,'furniture','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left','100','','','.b-menu-lev_display-right'),(893130,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left','100','','','.b-menu-lev_display-slide'),(893131,'furniture','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left','100','','','.b-menu-lev_display-slide'),(893132,'furniture','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left','100','','','.b-menu-lev_display-slide'),(893133,'furniture','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left','100','','','.b-menu-lev_display-slide'),(893134,'furniture','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left','100','','','.b-menu-lev_display-slide'),(893135,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left','-110','','','.b-menu-open_from-left'),(893136,'furniture','.b-menu-open_from-left .bi-opened .menu-style[data-open_from=\"left\"] .menu-content','left','0','','','.b-menu-open_from-left'),(893137,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','left','0','','','.b-menu-style-2'),(893138,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','left','0','','','.b-menu-style-2'),(893139,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','left','20','3','','.b-menu-style-2'),(893140,'furniture','.b-slick .slick-track','left','0','','','.b-slick'),(893141,'furniture','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left','50','','','.b-slick'),(893142,'furniture','.b-slick button.slick-next','left','auto','','','.b-slick'),(893143,'furniture','.b-slick button.slick-prev','left','0','','','.b-slick'),(893144,'furniture','.header','left','0','5140','',''),(893145,'furniture','.cartTitle >div','left','0','3','','.cartTitle'),(893146,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','left','0','','','.b-products-listing'),(893147,'furniture','.w-quote .multicart .switch-cart','left','15','','','.w-quote'),(893148,'furniture','h1, .heading-1','left','-14','3','',''),(893149,'furniture','.warrantyProduct .warranty','left','0','3','','.warrantyProduct'),(893150,'furniture','.warrantyProduct .delivery','left','0','3','','.warrantyProduct'),(893151,'furniture','.w-compare ','left','0','','','.w-compare'),(893152,'furniture','.w-sample .multicart .switch-cart','left','15','','','.w-sample'),(893153,'furniture','.heading-2','left','-14','3','',''),(893154,'furniture','.p-quote-checkout-index .order-summary .heading-2','left','-14','3','','.p-quote-checkout-index'),(893155,'furniture','.p-sample-checkout-index .order-summary .heading-2','left','-14','3','','.p-sample-checkout-index'),(893156,'furniture','.w-account-personal-catalog .w-cart-listing .remove-btn','left','0','5140','','.w-account-personal-catalog'),(893157,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input','left','-50','','','.w-questionnaire-widgets-questionnaire'),(893158,'furniture','.w-sale-category .badge','left','10','','','.w-sale-category'),(893159,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content:before','left','25','','','.w-product-properties-icons'),(893160,'furniture','.w-product-bonus-points > div > div','left','10','3','','.w-product-bonus-points'),(893161,'furniture','.w-product-designer-designer .productDesignerBox input','left','0','','','.w-product-designer-designer'),(893162,'furniture','.w-product-configurator .pc-item label input','left','0','','','.w-product-configurator'),(893163,'furniture','.b-products-listing .products-listing .bonus-points-cost','left','10','3','','.b-products-listing'),(893164,'furniture','.mainBanner .title','left','40','3','','.mainBanner'),(893165,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','left','0','','','.mainBanner'),(893166,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','left','50','','','.mainBanner'),(893174,'furniture','.account-address-book .buttonBox .info','left','-6','3','','.account-address-book'),(893182,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','left','1','3','','.account-order-pay'),(893183,'furniture','.account-order-pay .historyInfoColumn h2.title-delivery-address, .account-order-pay .historyInfoColumn h2.title-billing-address','left','10','3','','.account-order-pay'),(893184,'furniture','.account-order-pay .historyInfoColumn h2.title-payment','left','10','3','','.account-order-pay'),(893185,'furniture','.account-order-pay .not_fully_paid_td','left','15','','','.account-order-pay'),(893186,'furniture','.account-samples .not_fully_paid_td','left','15','','','.account-samples'),(893187,'furniture','.account-samples .orders-table .status-name','left','0','5140','','.account-samples'),(893188,'furniture','.account-samples .orders-table .td-alignright','left','0','5140','','.account-samples'),(893189,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','left','1','3','','.account-sample-info'),(893190,'furniture','.account-sample-info .historyInfoColumn h2.title-delivery-address, .account-sample-info .historyInfoColumn h2.title-billing-address','left','10','3','','.account-sample-info'),(893191,'furniture','.account-sample-info .historyInfoColumn h2.title-payment','left','10','3','','.account-sample-info'),(893192,'furniture','.account-sample-info .not_fully_paid_td','left','15','','','.account-sample-info'),(893193,'furniture','.catalog-product-wrap .prev-product','left','0','','','.catalog-product-wrap'),(893194,'furniture','.catalog-product-wrap .prev-product .pn-image','left','20','3','','.catalog-product-wrap'),(893195,'furniture','.checkout-index-wrap .order-summary .heading-2','left','-14','3','','.checkout-index-wrap'),(893196,'furniture','.b-form .addresses .address-item input[type=\"radio\"]','left','0','','','.b-form'),(893197,'furniture','.success-page .w-cart-listing .qty','left','50','','','.success-page'),(893198,'furniture','.menu-header .menu-style[data-style=\"1\"] .goto-button','left','0','','','.menu-header'),(893199,'furniture','.tripleBanner .w-html_box','left','0','3','','.tripleBanner'),(893200,'furniture','.w-banner .banner img + img','left','0','','','.w-banner'),(893201,'furniture','.w-banner .carousel-text','left','0','','','.w-banner'),(893202,'furniture','.w-banner .image-text-banner.bottom-left .text-banner','left','0','','','.w-banner'),(893203,'furniture','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','left','0','','','.w-banner'),(893204,'furniture','.w-banner .image-text-banner.top-left .text-banner','left','0','','','.w-banner'),(893205,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left_important','important','','','.b-select-suggest'),(893206,'furniture','.b-form .radio-button input[type=\"radio\"].no','left_measure','vw','','','.b-form'),(893207,'furniture','.b-fancybox #fancybox-loading','left_measure','%','','','.b-fancybox'),(893208,'furniture','.w-checkout-shipping-choice input:checked + span:before','left_measure','%','','','.w-checkout-shipping-choice'),(893209,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left_measure','%','','','.b-switch'),(893210,'furniture','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left_measure','%','','','.b-menu-lev_display-lra'),(893211,'furniture','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left_measure','%','','','.b-menu-lev_display-lra'),(893212,'furniture','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left_measure','%','','','.b-menu-lev_display-lra'),(893213,'furniture','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left_measure','%','','','.b-menu-lev_display-lra'),(893214,'furniture','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left_measure','%','','','.b-menu-lev_display-lra'),(893215,'furniture','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left_measure','%','','','.b-menu-lev_display-right'),(893216,'furniture','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left_measure','%','','','.b-menu-lev_display-right'),(893217,'furniture','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left_measure','%','','','.b-menu-lev_display-right'),(893218,'furniture','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left_measure','%','','','.b-menu-lev_display-right'),(893219,'furniture','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left_measure','%','','','.b-menu-lev_display-right'),(893220,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left_measure','vw','','','.b-menu-lev_display-slide'),(893221,'furniture','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left_measure','vw','','','.b-menu-lev_display-slide'),(893222,'furniture','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left_measure','vw','','','.b-menu-lev_display-slide'),(893223,'furniture','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left_measure','vw','','','.b-menu-lev_display-slide'),(893224,'furniture','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left_measure','vw','','','.b-menu-lev_display-slide'),(893225,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left_measure','vw','','','.b-menu-open_from-left'),(893226,'furniture','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left_measure','%','','','.b-slick'),(893227,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content:before','left_measure','%','','','.w-product-properties-icons'),(893228,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','left_measure','%','','','.mainBanner'),(893229,'furniture','.rating-0, .rating-1, .rating-2, .rating-3, .rating-4, .rating-5','letter-spacing','2px','','',''),(893230,'furniture','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','line-height','1.2','','','.w-communication-new-topic'),(893231,'furniture','.b-info-popup .info-popup div','line-height','30','3','','.b-info-popup'),(893232,'furniture','.b-form .shipping-method .sub-title','line-height','1.3','','','.b-form'),(893233,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','line-height','12','','','.b-switch'),(893234,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line-height','30','','','.b-switch'),(893235,'furniture','.w-tabs .tab-li.tab-cart a','line-height','0.75','3','','.w-tabs'),(893236,'furniture','.message.success','line-height','1','3','',''),(893237,'furniture','.heading-4 .edit, h4 .edit','line-height','20','','',''),(893238,'furniture','.w-socials .post_item > div','line-height','19','','','.w-socials'),(893239,'furniture','.p-quick-order-index .paginate_button.previous','line-height','26','3','','.p-quick-order-index'),(893240,'furniture','.p-quick-order-index .paginate_button.next','line-height','26','3','','.p-quick-order-index'),(893241,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.p-quick-order-index'),(893242,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.p-quick-order-index'),(893243,'furniture','.w-text .customer-service b','line-height','18','','','.w-text'),(893244,'furniture','.w-promotions .prom-multi-discount .promo-range','line-height','23','','','.w-promotions'),(893245,'furniture','.w-quote .cart-box-link','line-height','40','5140,3','','.w-quote'),(893246,'furniture','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(893248,'furniture','.testimonials .heading-3','line-height','1','3','',''),(893249,'furniture','.w-promotions .heading-3','line-height','1','','','.w-promotions'),(893250,'furniture','.w-promotions .promo-salemaker .discount','line-height','23','','','.w-promotions'),(893251,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','line-height','23','','','.w-promotions'),(893252,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','line-height','23','','','.w-promotions'),(893253,'furniture','.b-preloader .preloader','line-height','40','3','','.b-preloader'),(893254,'furniture','.w-cart-compare .attributes-cell','line-height','22','','','.w-cart-compare'),(893256,'furniture','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(893257,'furniture','.b-bottom .closeable-heading','line-height','34','3','','.b-bottom'),(893258,'furniture','.b-messages .messBtnMenuDelete','line-height','10','3','','.b-messages'),(893259,'furniture','.b-messages span.starred::before','line-height','10','','','.b-messages'),(893260,'furniture','.b-messages .messBtnMenuStarred','line-height','10','3','','.b-messages'),(893261,'furniture','.b-messages .messBtnMenuUnread','line-height','10','3','','.b-messages'),(893262,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line-height','14','','','.b-messages'),(893263,'furniture','.w-quote .cart-box-link','line-height','48','3','','.w-quote'),(893264,'furniture','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(893265,'furniture','.w-socials .post_item > div','line-height','19','','','.w-socials'),(893266,'furniture','.p-payer-order-confirmation .ship-ico','line-height','20','3','','.p-payer-order-confirmation'),(893267,'furniture','.p-payer-order-confirmation .order-ico','line-height','20','3','','.p-payer-order-confirmation'),(893268,'furniture','.p-payer-order-confirmation .pay-ico','line-height','20','3','','.p-payer-order-confirmation'),(893269,'furniture','.p-payer-order-confirmation .discount-ico','line-height','20','3','','.p-payer-order-confirmation'),(893270,'furniture','.p-payer-order-confirmation .comment-ico','line-height','20','3','','.p-payer-order-confirmation'),(893271,'furniture','.p-payer-order-pay .ship-ico','line-height','20','3','','.p-payer-order-pay'),(893272,'furniture','.p-payer-order-pay .pay-ico','line-height','20','3','','.p-payer-order-pay'),(893273,'furniture','.p-payer-order-pay .order-ico','line-height','20','3','','.p-payer-order-pay'),(893274,'furniture','.p-payer-order-pay .discount-ico','line-height','20','3','','.p-payer-order-pay'),(893275,'furniture','.p-payer-order-pay .comment-ico','line-height','20','3','','.p-payer-order-pay'),(893276,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','line-height','15','','','.b-switch'),(893277,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','line-height','15','','','.b-switch'),(893278,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','line-height','15','','','.b-switch'),(893279,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','line-height','56','4','','.b-switch'),(893280,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','line-height','16','','','.b-switch'),(893281,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','line-height','10','','','.b-switch'),(893282,'furniture','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','line-height','1.2','','','.p-quick-order-index'),(893283,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','line-height','15','','','.b-switch'),(893284,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','line-height','10','','','.b-switch'),(893285,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','line-height','10','','','.b-switch'),(893286,'furniture','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(893287,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','line-height','12','','','.b-switch'),(893288,'furniture','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(893290,'furniture','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(893291,'furniture','.w-tabs .tab-li.tab-sample a','line-height','0.75','3','','.w-tabs'),(893292,'furniture','.w-cart-compare .compare-table','line-height','1.3','','','.w-cart-compare'),(893293,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line-height','18','','','.b-form'),(893294,'furniture','.w-checkout-shipping-choice span','line-height','19','','','.w-checkout-shipping-choice'),(893295,'furniture','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(893296,'furniture','.w-socials .post_item > div','line-height','19','','','.w-socials'),(893297,'furniture','.b-info-popup .info-popup div','line-height','1.7','','','.b-info-popup'),(893298,'furniture','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(893299,'furniture','.w-checkout-shipping-address .addresses .address-item label','line-height','1.3','','','.w-checkout-shipping-address'),(893300,'furniture','.w-tabs .tab-li.tab-wishlist a','line-height','0.75','3','','.w-tabs'),(893301,'furniture','.w-text .customer-service b','line-height','18','','','.w-text'),(893302,'furniture','.w-socials .post_item > div','line-height','19','','','.w-socials'),(893303,'furniture','.b-info-popup .info-popup','line-height','2','','','.b-info-popup'),(893304,'furniture','.w-text .customer-service b','line-height','18','','','.w-text'),(893305,'furniture','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(893306,'furniture','.btn-2','line-height','20','','',''),(893307,'furniture','.w-cart-compare .delete-cart','line-height','1','','','.w-cart-compare'),(893309,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span','line-height','22','','','.b-form'),(893310,'furniture','.w-filters .input-checkbox:checked + .checkbox-span:before','line-height','22','','','.w-filters'),(893311,'furniture','.heading-3 .right-text, h3 .right-text','line-height','20','','',''),(893312,'furniture','.heading-3 .edit, h3 .edit','line-height','20','','',''),(893313,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','line-height','56','4','','.b-switch'),(893314,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','line-height','56','4','','.b-switch'),(893315,'furniture','.w-text .customer-service b','line-height','18','','','.w-text'),(893316,'furniture','.savings-ico .heading-2','line-height','10','3','','.savings-ico'),(893317,'furniture','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(893318,'furniture','.b-fancybox .fancybox-title-float-wrap .child','line-height','24','','','.b-fancybox'),(893319,'furniture','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(893320,'furniture','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(893321,'furniture','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(893322,'furniture','.w-socials .post_item > div','line-height','19','','','.w-socials'),(893323,'furniture','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(893324,'furniture','.btn','line-height','20','','',''),(893325,'furniture','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(893326,'furniture','.w-text .customer-service b','line-height','18','','','.w-text'),(893327,'furniture','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(893328,'furniture','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(893329,'furniture','.w-reviews .heading-3','line-height','1','3','','.w-reviews'),(893330,'furniture','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(893331,'furniture','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(893332,'furniture','.p-quick-order-index .stock','line-height','1.2','','','.p-quick-order-index'),(893333,'furniture','.b-form .checkbox-style:checked + .checkbox-span:before','line-height','18','','','.b-form'),(893334,'furniture','.w-cart-listing .links','line-height','35','','','.w-cart-listing'),(893335,'furniture','.price .old','line-height','0.6','','',''),(893336,'furniture','.w-cart-compare .price-cell','line-height','22','','','.w-cart-compare'),(893337,'furniture','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(893338,'furniture','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(893339,'furniture','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(893340,'furniture','.w-multi-cart-cart-switcher .cart-label','line-height','20','','','.w-multi-cart-cart-switcher'),(893341,'furniture','.b-bottom .pop-up-close','line-height','25','','','.b-bottom'),(893342,'furniture','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(893343,'furniture','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(893344,'furniture','.w-personal-gift-status-bar .inform','line-height','14','4','','.w-personal-gift-status-bar'),(893345,'furniture','.w-tabs .tab-li.tab-quote a','line-height','0.75','3','','.w-tabs'),(893346,'furniture','.b-fancybox .fancybox-close','line-height','40','','','.b-fancybox'),(893347,'furniture','.b-form .form-inputs div.required-message','line-height','1.3','','','.b-form'),(893348,'furniture','.w-product-customers-activity .close','line-height','32','','','.w-product-customers-activity'),(893349,'furniture','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(893350,'furniture','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(893351,'furniture','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(893352,'furniture','.w-checkout-billing-address .addresses .address-item label','line-height','1.3','','','.w-checkout-billing-address'),(893353,'furniture','.w-text .customer-service b','line-height','18','','','.w-text'),(893354,'furniture','.w-cart-compare .cart-name a','line-height','1.2','','','.w-cart-compare'),(893355,'furniture','.w-personal-gift-status-bar .end-date','line-height','14','3','','.w-personal-gift-status-bar'),(893356,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line-height','13','','','.b-select-suggest'),(893357,'furniture','.b-switch .bootstrap-switch','line-height','28','','','.b-switch'),(893358,'furniture','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(893359,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.b-data-table'),(893360,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.b-data-table'),(893361,'furniture','.b-products-listing .products-listing .name a','line-height','1.5','','','.b-products-listing'),(893362,'furniture','.b-products-listing .btn-preloader','line-height','24','3','','.b-products-listing'),(893363,'furniture','.b-products-listing .loader','line-height','30','4','','.b-products-listing'),(893364,'furniture','.b-products-listing .products-listing .btn-buy','line-height','10','3','','.b-products-listing'),(893365,'furniture','.checkbox input:not(checked) + span:before','line-height','24','','',''),(893368,'furniture','.b-select-suggest .select2-container .select2-choice','line-height','26','','','.b-select-suggest'),(893369,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','line-height','10','','','.b-switch'),(893370,'furniture','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(893371,'furniture','.w-socials .post_item > div','line-height','19','','','.w-socials'),(893372,'furniture','.order-summary .price-row.ot_coupon .title','line-height','22','3','','.order-summary'),(893373,'furniture','.heading-4 .right-text, h4 .right-text','line-height','20','','',''),(893374,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','40','','','.w-communication-new-topic'),(893375,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','35','3','','.w-communication-new-topic'),(893376,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line-height','36','','','.w-communication-new-topic'),(893377,'furniture','.btn-3','line-height','20','','',''),(893378,'furniture','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(893379,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','line-height','30','3','','.b-form'),(893380,'furniture','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(893381,'furniture','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(893382,'furniture','.b-form .cart-popup .price','line-height','35','','','.b-form'),(893383,'furniture','.w-menu-horizontal .menu-ico','line-height','54','','','.w-menu-horizontal'),(893384,'furniture','.w-catalog-listing-look .grid','line-height','35','','','.w-catalog-listing-look'),(893385,'furniture','.w-catalog-listing-look .b2b','line-height','35','','','.w-catalog-listing-look'),(893386,'furniture','.w-catalog-listing-look .list','line-height','35','','','.w-catalog-listing-look'),(893387,'furniture','.w-cart-listing .item .attributes','line-height','1.7','','','.w-cart-listing'),(893388,'furniture','.w-cart-listing .points-earn','line-height','1','','','.w-cart-listing'),(893389,'furniture','.w-cart-listing .points-redeem','line-height','1','','','.w-cart-listing'),(893390,'furniture','.w-cart-listing .remove-btn','line-height','30','','','.w-cart-listing'),(893391,'furniture','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(893392,'furniture','.b-fancybox .fancybox-nav span','line-height','40','','','.b-fancybox'),(893393,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','line-height','30','','','.b-switch'),(893394,'furniture','.w-checkout-create-account .account-benefits strong','line-height','16','3','','.w-checkout-create-account'),(893395,'furniture','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(893396,'furniture','.w-cart-compare .js-cart_totals_container','line-height','1.2','','','.w-cart-compare'),(893397,'furniture','.btn-1','line-height','24','','',''),(893398,'furniture','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(893399,'furniture','.b-products-listing .products-listing .btn-preloader','line-height','8','','','.b-products-listing'),(893400,'furniture','.price .special','line-height','0.8','','',''),(893401,'furniture','.b-data-table table.dataTable thead td','line-height','1.5','','','.b-data-table'),(893402,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','line-height','30','','','.b-switch'),(893403,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','line-height','30','','','.b-switch'),(893404,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','line-height','30','','','.b-switch'),(893405,'furniture','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(893406,'furniture','.w-filters .input-checkbox:not(checked) + .checkbox-span','line-height','22','','','.w-filters'),(893407,'furniture','.b-upload-file .snapshot','line-height','38','','','.b-upload-file'),(893408,'furniture','.b-product-images .media-popup .mp-close','line-height','100','','','.b-product-images'),(893409,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','line-height','100','','','.b-product-images'),(893410,'furniture','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line-height','30','','','.b-menu-burger_icon'),(893411,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(893412,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(893413,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(893414,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(893415,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(893416,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','line-height','24','','','.b-menu-style-2'),(893417,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','line-height','24','','','.b-menu-style-2'),(893418,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','line-height','42','','','.b-menu-style-2'),(893419,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','line-height','16','3','','.b-menu-style-2'),(893420,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','line-height','16','3','','.b-menu-style-2'),(893421,'furniture','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','line-height','1.3','','','.b-trade-approval'),(893422,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line-height','24','3','','.w-catalog-compare'),(893423,'furniture','.w-catalog-compare td','line-height','1.5','','','.w-catalog-compare'),(893424,'furniture','.w-catalog-compare span.btn-preloader','line-height','24','3','','.w-catalog-compare'),(893425,'furniture','.w-delivery-day .ends','line-height','1','','','.w-delivery-day'),(893427,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','40','','','.b-slick'),(893428,'furniture','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line-height','36','','','.b-slick'),(893429,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','48','5140','','.b-slick'),(893432,'furniture','.menu-header .burger-icon','line-height','40','5140','','.menu-header'),(893433,'furniture','.menu-header .burger-icon','line-height','40','5140,3','','.menu-header'),(893434,'furniture','.w-subscribers .btn-submit','line-height','24','','','.w-subscribers'),(893435,'furniture','.w-social-links a','line-height','1','','','.w-social-links'),(893436,'furniture','.b-quantity .qty-box .bigger','line-height','27','','','.b-quantity'),(893437,'furniture','.b-quantity .qty-box .smaller','line-height','31','','','.b-quantity'),(893438,'furniture','.w-product-sale-ends .ends','line-height','1','','','.w-product-sale-ends'),(893439,'furniture','.w-product-quantity .qty-box .smaller, .w-product-quantity .qty-box .bigger','line-height','38','','','.w-product-quantity'),(893440,'furniture','.warrantyProduct .title','line-height','1.2','','','.warrantyProduct'),(893441,'furniture','.warrantyProduct .seeDetails','line-height','1.2','','','.warrantyProduct'),(893442,'furniture','.w-sample .cart-box-link','line-height','48','3','','.w-sample'),(893443,'furniture','.w-sample .cart-box-link','line-height','40','5140,3','','.w-sample'),(893444,'furniture','.w-cart-bonus-points .title','line-height','1','','','.w-cart-bonus-points'),(893445,'furniture','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(893447,'furniture','.b-pagination .pagination .next-pages','line-height','30','','','.b-pagination'),(893448,'furniture','.b-pagination .pagination .page-number','line-height','30','','','.b-pagination'),(893449,'furniture','.b-pagination .pagination .prev-pages','line-height','30','','','.b-pagination'),(893450,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','line-height','30','','','.b-pagination'),(893451,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','line-height','26','3','','.b-pagination'),(893452,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','line-height','30','','','.b-pagination'),(893453,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','line-height','26','3','','.b-pagination'),(893454,'furniture','.b-pagination .pagination span','line-height','30','2','','.b-pagination'),(893455,'furniture','.w-product-properties-filters-widgets-chosen-filters .remove','line-height','10','3','','.w-product-properties-filters-widgets-chosen-filters'),(893456,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','line-height','36','','','.w-questionnaire-widgets-questionnaire'),(893457,'furniture','.w-product-groups .val1','line-height','1','','','.w-product-groups'),(893458,'furniture','.w-product-custom-bundle .right-area .price','line-height','1.2','','','.w-product-custom-bundle'),(893459,'furniture','.b-products-listing .products-listing.list-productlisting .attribute-qty-block > span','line-height','1.15','','','.b-products-listing'),(893460,'furniture','.w-delivery-location-location-list .deliveryListParrent a','line-height','1.5','','','.w-delivery-location-location-list'),(893461,'furniture','.w-sale-category .badge','line-height','27','','','.w-sale-category'),(893462,'furniture','.w-sale-category .ends','line-height','1','','','.w-sale-category'),(893463,'furniture','.w-sale-category .name','line-height','1.2','','','.w-sale-category'),(893464,'furniture','.w-sale-category .old','line-height','0.8','','','.w-sale-category'),(893465,'furniture','.w-sale-category .special-price','line-height','0.8','','','.w-sale-category'),(893466,'furniture','.w-product-bonus-points .bonus-points-cost','line-height','1.2','','','.w-product-bonus-points'),(893467,'furniture','.b-products-listing .productGroup label a','line-height','1','','','.b-products-listing'),(893468,'furniture','.w-rma-returns-history .column .title','line-height','16','','','.w-rma-returns-history'),(893469,'furniture','.w-rma-returns-history tbody tr td','line-height','1.3','','','.w-rma-returns-history'),(893470,'furniture','.w-rma-returns-history thead tr td','line-height','1.3','','','.w-rma-returns-history'),(893471,'furniture','.b-products-listing .products-listing .bonus-points-cost','line-height','1.2','','','.b-products-listing'),(893472,'furniture','.w-predefined-promotion .heading-3','line-height','1','','','.w-predefined-promotion'),(893473,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','line-height','23','','','.w-predefined-promotion'),(893474,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','line-height','23','','','.w-predefined-promotion'),(893475,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','line-height','23','','','.w-predefined-promotion'),(893476,'furniture','.w-predefined-promotion .promo-salemaker .discount','line-height','23','','','.w-predefined-promotion'),(893477,'furniture','.w-supplier-purchase-supplier-products .active .select_item > div','line-height','28','','','.w-supplier-purchase-supplier-products'),(893478,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','line-height','22','','','.w-filters'),(893479,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','line-height','22','','','.w-filters'),(893480,'furniture','.mainBanner .title > span','line-height','1','','','.mainBanner'),(893481,'furniture','.mainBanner .topBox > .left','line-height','1','','','.mainBanner'),(893482,'furniture','.order-summary .icon','line-height','30','','','.order-summary'),(893483,'furniture','.w-cart-discount-coupon .title','line-height','0.75','4','','.w-cart-discount-coupon'),(893484,'furniture','.w-cart-listing .price small','line-height','1','','','.w-cart-listing'),(893485,'furniture','.w-cart-listing .promos-info .promo-name','line-height','1','','','.w-cart-listing'),(893486,'furniture','.w-product-quantity-discounts .per-item','line-height','1','','','.w-product-quantity-discounts'),(893500,'furniture','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','line-height','20','','','.account-samples'),(893501,'furniture','.account-samples .order_history_table th','line-height','16','','','.account-samples'),(893502,'furniture','.account-samples .view_link','line-height','17','4','','.account-samples'),(893503,'furniture','.account-samples .orders-table .td-alignright','line-height','35','5140','','.account-samples'),(893504,'furniture','.catalog-product-wrap .pn-direction','line-height','1.2','','','.catalog-product-wrap'),(893505,'furniture','.catalog-product-wrap .pn-image','line-height','24','3','','.catalog-product-wrap'),(893506,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','line-height','20','','','.checkout-index-wrap'),(893507,'furniture','.checkout-index-wrap .order-ico','line-height','20','3','','.checkout-index-wrap'),(893508,'furniture','.checkout-index-wrap .pay-ico','line-height','20','3','','.checkout-index-wrap'),(893509,'furniture','.checkout-index-wrap .ship-ico','line-height','20','3','','.checkout-index-wrap'),(893510,'furniture','.checkout-index-wrap .closeable-heading','line-height','38','5140,3','','.checkout-index-wrap'),(893511,'furniture','.checkout-order-confirmation .comment-ico','line-height','20','3','','.checkout-order-confirmation'),(893512,'furniture','.checkout-order-confirmation .discount-ico','line-height','20','3','','.checkout-order-confirmation'),(893513,'furniture','.checkout-order-confirmation .order-ico','line-height','20','3','','.checkout-order-confirmation'),(893514,'furniture','.checkout-order-confirmation .ship-ico','line-height','20','3','','.checkout-order-confirmation'),(893515,'furniture','.b-info .info','line-height','1','3','','.b-info'),(893516,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line-height','31','','','.b-multi-page-checkout'),(893517,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line-height','35','3','','.b-multi-page-checkout'),(893518,'furniture','.success-page .comment-ico','line-height','20','3','','.success-page'),(893519,'furniture','.success-page .discount-ico','line-height','20','3','','.success-page'),(893520,'furniture','.success-page .order-ico','line-height','20','3','','.success-page'),(893521,'furniture','.success-page .page-success .text-1','line-height','20','3','','.success-page'),(893522,'furniture','.success-page .pay-ico','line-height','20','3','','.success-page'),(893523,'furniture','.success-page .prod-ico','line-height','20','3','','.success-page'),(893524,'furniture','.success-page .ship-ico','line-height','20','3','','.success-page'),(893525,'furniture','.success-page .w-cart-listing .qty','line-height','26','','','.success-page'),(893526,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > li > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > li > .no-link','line-height','1.2','','','.menu-header'),(893527,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','line-height','10','5140,3','','.footer-menu'),(893528,'furniture','.lowestPricedBox .w-banner .ybg .title','line-height','1','','','.lowestPricedBox'),(893529,'furniture','.tripleBanner .w-html_box','line-height','1.25','','','.tripleBanner'),(893530,'furniture','.shopByCollectionBox .content .title span','line-height','1','','','.shopByCollectionBox'),(893531,'furniture','.w-catalog-paging ','line-height','30','2','','.w-catalog-paging'),(893532,'furniture','.w-catalog-paging .next','line-height','30','','','.w-catalog-paging'),(893533,'furniture','.w-catalog-paging .next','line-height','26','3','','.w-catalog-paging'),(893534,'furniture','.w-catalog-paging .next-pages','line-height','30','','','.w-catalog-paging'),(893535,'furniture','.w-catalog-paging .page-number','line-height','30','','','.w-catalog-paging'),(893536,'furniture','.w-catalog-paging .prev','line-height','30','','','.w-catalog-paging'),(893537,'furniture','.w-catalog-paging .prev','line-height','26','3','','.w-catalog-paging'),(893538,'furniture','.w-catalog-paging .prev-pages','line-height','30','','','.w-catalog-paging'),(893539,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line-height','30','','','.w-catalog-paging'),(893540,'furniture','.w-compare-box-item .checkbox:not(checked) + span:before','line-height','24','','','.w-compare-box-item'),(893541,'furniture','.b-info-popup .info-popup div','line_height_measure','px','3','','.b-info-popup'),(893542,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(893543,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line_height_measure','px','','','.b-switch'),(893544,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','line_height_measure','px','3','','.b-form'),(893545,'furniture','.heading-4 .edit, h4 .edit','line_height_measure','px','','',''),(893546,'furniture','.p-quick-order-index .paginate_button.next','line_height_measure','px','3','','.p-quick-order-index'),(893547,'furniture','.p-quick-order-index .paginate_button.previous','line_height_measure','px','3','','.p-quick-order-index'),(893548,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.p-quick-order-index'),(893549,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.p-quick-order-index'),(893550,'furniture','.w-promotions .prom-multi-discount .promo-range','line_height_measure','px','','','.w-promotions'),(893551,'furniture','.w-promotions .promo-salemaker .discount','line_height_measure','px','','','.w-promotions'),(893552,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','line_height_measure','px','','','.w-promotions'),(893553,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','line_height_measure','px','','','.w-promotions'),(893554,'furniture','.b-preloader .preloader','line_height_measure','px','3','','.b-preloader'),(893555,'furniture','.w-cart-compare .attributes-cell','line_height_measure','px','','','.w-cart-compare'),(893556,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-messages'),(893557,'furniture','.b-bottom .closeable-heading','line_height_measure','px','3','','.b-bottom'),(893558,'furniture','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(893559,'furniture','.b-messages .messBtnMenuDelete','line_height_measure','px','3','','.b-messages'),(893560,'furniture','.b-messages .messBtnMenuStarred','line_height_measure','px','3','','.b-messages'),(893561,'furniture','.b-messages span.starred::before','line_height_measure','px','','','.b-messages'),(893562,'furniture','.b-messages .messBtnMenuUnread','line_height_measure','px','3','','.b-messages'),(893563,'furniture','.p-payer-order-confirmation .ship-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(893564,'furniture','.p-payer-order-confirmation .pay-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(893565,'furniture','.p-payer-order-confirmation .order-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(893566,'furniture','.p-payer-order-confirmation .discount-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(893567,'furniture','.p-payer-order-confirmation .comment-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(893568,'furniture','.p-payer-order-pay .ship-ico','line_height_measure','px','3','','.p-payer-order-pay'),(893569,'furniture','.p-payer-order-pay .pay-ico','line_height_measure','px','3','','.p-payer-order-pay'),(893570,'furniture','.p-payer-order-pay .order-ico','line_height_measure','px','3','','.p-payer-order-pay'),(893571,'furniture','.p-payer-order-pay .discount-ico','line_height_measure','px','3','','.p-payer-order-pay'),(893572,'furniture','.p-payer-order-pay .comment-ico','line_height_measure','px','3','','.p-payer-order-pay'),(893573,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(893574,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(893575,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(893576,'furniture','.b-fancybox .fancybox-close','line_height_measure','px','','','.b-fancybox'),(893577,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','line_height_measure','px','4','','.b-switch'),(893578,'furniture','.b-info-popup .info-popup','line_height_measure','px','','','.b-info-popup'),(893579,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(893580,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(893581,'furniture','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(893582,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(893583,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(893584,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(893585,'furniture','.b-switch .bootstrap-switch','line_height_measure','px','','','.b-switch'),(893586,'furniture','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(893587,'furniture','.w-checkout-shipping-choice span','line_height_measure','px','','','.w-checkout-shipping-choice'),(893588,'furniture','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(893589,'furniture','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(893590,'furniture','.b-form .checkbox-style:checked + .checkbox-span:before','line_height_measure','px','','','.b-form'),(893591,'furniture','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(893592,'furniture','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(893593,'furniture','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(893594,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span','line_height_measure','px','','','.b-form'),(893595,'furniture','.btn-2','line_height_measure','px','','',''),(893596,'furniture','.w-filters .input-checkbox:checked + .checkbox-span:before','line_height_measure','px','','','.w-filters'),(893597,'furniture','.w-personal-gift-status-bar .inform','line_height_measure','px','4','','.w-personal-gift-status-bar'),(893598,'furniture','.heading-3 .right-text, h3 .right-text','line_height_measure','px','','',''),(893599,'furniture','.heading-3 .edit, h3 .edit','line_height_measure','px','','',''),(893600,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','line_height_measure','px','4','','.b-switch'),(893601,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','line_height_measure','px','4','','.b-switch'),(893602,'furniture','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(893603,'furniture','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(893604,'furniture','.savings-ico .heading-2','line_height_measure','px','3','','.savings-ico'),(893605,'furniture','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(893606,'furniture','.b-fancybox .fancybox-title-float-wrap .child','line_height_measure','px','','','.b-fancybox'),(893607,'furniture','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(893608,'furniture','.btn','line_height_measure','px','','',''),(893609,'furniture','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(893610,'furniture','.b-select-suggest .select2-container .select2-choice','line_height_measure','px','','','.b-select-suggest'),(893611,'furniture','.w-cart-listing .links','line_height_measure','px','','','.w-cart-listing'),(893612,'furniture','.b-bottom .pop-up-close','line_height_measure','px','','','.b-bottom'),(893613,'furniture','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(893614,'furniture','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(893615,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line_height_measure','px','','','.b-form'),(893616,'furniture','.w-product-customers-activity .close','line_height_measure','px','','','.w-product-customers-activity'),(893617,'furniture','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(893618,'furniture','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(893619,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(893620,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-select-suggest'),(893621,'furniture','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(893622,'furniture','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(893623,'furniture','.w-cart-compare .price-cell','line_height_measure','px','','','.w-cart-compare'),(893624,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.b-data-table'),(893625,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.b-data-table'),(893626,'furniture','.b-products-listing .btn-preloader','line_height_measure','px','3','','.b-products-listing'),(893627,'furniture','.b-products-listing .loader','line_height_measure','px','4','','.b-products-listing'),(893628,'furniture','.b-products-listing .products-listing .btn-buy','line_height_measure','px','3','','.b-products-listing'),(893629,'furniture','.checkbox input:not(checked) + span:before','line_height_measure','px','','',''),(893631,'furniture','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(893632,'furniture','.w-quote .cart-box-link','line_height_measure','px','5140,3','','.w-quote'),(893633,'furniture','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(893634,'furniture','.order-summary .price-row.ot_coupon .title','line_height_measure','px','3','','.order-summary'),(893635,'furniture','.w-checkout-create-account .account-benefits strong','line_height_measure','px','3','','.w-checkout-create-account'),(893636,'furniture','.heading-4 .right-text, h4 .right-text','line_height_measure','px','','',''),(893637,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','','','.w-communication-new-topic'),(893638,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','3','','.w-communication-new-topic'),(893639,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line_height_measure','px','','','.w-communication-new-topic'),(893640,'furniture','.w-text .customer-service b','line_height_measure','px','','','.w-text'),(893641,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(893642,'furniture','.w-personal-gift-status-bar .end-date','line_height_measure','px','3','','.w-personal-gift-status-bar'),(893643,'furniture','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(893644,'furniture','.w-menu-horizontal .menu-ico','line_height_measure','px','','','.w-menu-horizontal'),(893645,'furniture','.w-catalog-listing-look .grid','line_height_measure','px','','','.w-catalog-listing-look'),(893646,'furniture','.w-catalog-listing-look .b2b','line_height_measure','px','','','.w-catalog-listing-look'),(893647,'furniture','.w-catalog-listing-look .list','line_height_measure','px','','','.w-catalog-listing-look'),(893648,'furniture','.w-cart-listing .remove-btn','line_height_measure','px','','','.w-cart-listing'),(893649,'furniture','.b-fancybox .fancybox-nav span','line_height_measure','px','','','.b-fancybox'),(893650,'furniture','.w-multi-cart-cart-switcher .cart-label','line_height_measure','px','','','.w-multi-cart-cart-switcher'),(893651,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(893652,'furniture','.b-form .cart-popup .price','line_height_measure','px','','','.b-form'),(893653,'furniture','.btn-1','line_height_measure','px','','',''),(893654,'furniture','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(893655,'furniture','.b-products-listing .products-listing .btn-preloader','line_height_measure','px','','','.b-products-listing'),(893656,'furniture','.btn-3','line_height_measure','px','','',''),(893657,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(893658,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(893659,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(893660,'furniture','.w-filters .input-checkbox:not(checked) + .checkbox-span','line_height_measure','px','','','.w-filters'),(893661,'furniture','.b-upload-file .snapshot','line_height_measure','px','','','.b-upload-file'),(893662,'furniture','.b-product-images .media-popup .mp-close','line_height_measure','px','','','.b-product-images'),(893663,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','line_height_measure','px','','','.b-product-images'),(893664,'furniture','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line_height_measure','px','','','.b-menu-burger_icon'),(893665,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(893666,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(893667,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(893668,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(893669,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(893670,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','line_height_measure','px','','','.b-menu-style-2'),(893671,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','line_height_measure','px','','','.b-menu-style-2'),(893672,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','line_height_measure','px','','','.b-menu-style-2'),(893673,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','line_height_measure','px','3','','.b-menu-style-2'),(893674,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','line_height_measure','px','3','','.b-menu-style-2'),(893675,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line_height_measure','px','3','','.w-catalog-compare'),(893676,'furniture','.w-catalog-compare span.btn-preloader','line_height_measure','px','3','','.w-catalog-compare'),(893680,'furniture','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line_height_measure','px','','','.b-slick'),(893681,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','','','.b-slick'),(893682,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','5140','','.b-slick'),(893685,'furniture','.menu-header .burger-icon','line_height_measure','px','5140','','.menu-header'),(893686,'furniture','.menu-header .burger-icon','line_height_measure','px','5140,3','','.menu-header'),(893687,'furniture','.w-subscribers .btn-submit','line_height_measure','px','','','.w-subscribers'),(893688,'furniture','.w-quote .cart-box-link','line_height_measure','px','3','','.w-quote'),(893689,'furniture','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(893690,'furniture','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(893691,'furniture','.w-product-quantity .qty-box .smaller, .w-product-quantity .qty-box .bigger','line_height_measure','px','','','.w-product-quantity'),(893692,'furniture','.w-sample .cart-box-link','line_height_measure','px','3','','.w-sample'),(893693,'furniture','.w-sample .cart-box-link','line_height_measure','px','5140,3','','.w-sample'),(893694,'furniture','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(893696,'furniture','.b-pagination .pagination .next-pages','line_height_measure','px','','','.b-pagination'),(893697,'furniture','.b-pagination .pagination .page-number','line_height_measure','px','','','.b-pagination'),(893698,'furniture','.b-pagination .pagination .prev-pages','line_height_measure','px','','','.b-pagination'),(893699,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','line_height_measure','px','','','.b-pagination'),(893700,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','line_height_measure','px','3','','.b-pagination'),(893701,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','line_height_measure','px','','','.b-pagination'),(893702,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','line_height_measure','px','3','','.b-pagination'),(893703,'furniture','.b-pagination .pagination span','line_height_measure','px','2','','.b-pagination'),(893704,'furniture','.w-product-properties-filters-widgets-chosen-filters .remove','line_height_measure','px','3','','.w-product-properties-filters-widgets-chosen-filters'),(893705,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','line_height_measure','px','','','.w-questionnaire-widgets-questionnaire'),(893706,'furniture','.w-sale-category .badge','line_height_measure','px','','','.w-sale-category'),(893707,'furniture','.w-rma-returns-history .column .title','line_height_measure','px','','','.w-rma-returns-history'),(893708,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','line_height_measure','px','','','.w-predefined-promotion'),(893709,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','line_height_measure','px','','','.w-predefined-promotion'),(893710,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','line_height_measure','px','','','.w-predefined-promotion'),(893711,'furniture','.w-predefined-promotion .promo-salemaker .discount','line_height_measure','px','','','.w-predefined-promotion'),(893712,'furniture','.w-supplier-purchase-supplier-products .active .select_item > div','line_height_measure','px','','','.w-supplier-purchase-supplier-products'),(893713,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','line_height_measure','px','','','.w-filters'),(893714,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','line_height_measure','px','','','.w-filters'),(893715,'furniture','.order-summary .icon','line_height_measure','px','','','.order-summary'),(893729,'furniture','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','line_height_measure','px','','','.account-samples'),(893730,'furniture','.account-samples .order_history_table th','line_height_measure','px','','','.account-samples'),(893731,'furniture','.account-samples .view_link','line_height_measure','px','4','','.account-samples'),(893732,'furniture','.account-samples .orders-table .td-alignright','line_height_measure','px','5140','','.account-samples'),(893733,'furniture','.catalog-product-wrap .pn-image','line_height_measure','px','3','','.catalog-product-wrap'),(893734,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','line_height_measure','px','','','.checkout-index-wrap'),(893735,'furniture','.checkout-index-wrap .order-ico','line_height_measure','px','3','','.checkout-index-wrap'),(893736,'furniture','.checkout-index-wrap .pay-ico','line_height_measure','px','3','','.checkout-index-wrap'),(893737,'furniture','.checkout-index-wrap .ship-ico','line_height_measure','px','3','','.checkout-index-wrap'),(893738,'furniture','.checkout-index-wrap .closeable-heading','line_height_measure','px','5140,3','','.checkout-index-wrap'),(893739,'furniture','.checkout-order-confirmation .comment-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(893740,'furniture','.checkout-order-confirmation .discount-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(893741,'furniture','.checkout-order-confirmation .order-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(893742,'furniture','.checkout-order-confirmation .ship-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(893743,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line_height_measure','px','','','.b-multi-page-checkout'),(893744,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line_height_measure','px','3','','.b-multi-page-checkout'),(893745,'furniture','.success-page .comment-ico','line_height_measure','px','3','','.success-page'),(893746,'furniture','.success-page .discount-ico','line_height_measure','px','3','','.success-page'),(893747,'furniture','.success-page .order-ico','line_height_measure','px','3','','.success-page'),(893748,'furniture','.success-page .page-success .text-1','line_height_measure','px','3','','.success-page'),(893749,'furniture','.success-page .pay-ico','line_height_measure','px','3','','.success-page'),(893750,'furniture','.success-page .prod-ico','line_height_measure','px','3','','.success-page'),(893751,'furniture','.success-page .ship-ico','line_height_measure','px','3','','.success-page'),(893752,'furniture','.success-page .w-cart-listing .qty','line_height_measure','px','','','.success-page'),(893753,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','line_height_measure','px','5140,3','','.footer-menu'),(893754,'furniture','.w-catalog-paging ','line_height_measure','px','2','','.w-catalog-paging'),(893755,'furniture','.w-catalog-paging .next','line_height_measure','px','','','.w-catalog-paging'),(893756,'furniture','.w-catalog-paging .next','line_height_measure','px','3','','.w-catalog-paging'),(893757,'furniture','.w-catalog-paging .next-pages','line_height_measure','px','','','.w-catalog-paging'),(893758,'furniture','.w-catalog-paging .page-number','line_height_measure','px','','','.w-catalog-paging'),(893759,'furniture','.w-catalog-paging .prev','line_height_measure','px','','','.w-catalog-paging'),(893760,'furniture','.w-catalog-paging .prev','line_height_measure','px','3','','.w-catalog-paging'),(893761,'furniture','.w-catalog-paging .prev-pages','line_height_measure','px','','','.w-catalog-paging'),(893762,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line_height_measure','px','','','.w-catalog-paging'),(893763,'furniture','.w-compare-box-item .checkbox:not(checked) + span:before','line_height_measure','px','','','.w-compare-box-item'),(893764,'furniture','.p-quick-order-index ul.token-input-list','list-style','none','','','.p-quick-order-index'),(893768,'furniture','.b-messages .messages-menu ul','list-style','none','','','.b-messages'),(893769,'furniture','.w-sitemap-delivery-location > ul > li > ul','list-style','none','','','.w-sitemap-delivery-location'),(893770,'furniture','.w-sitemap-delivery-location > ul','list-style','none','','','.w-sitemap-delivery-location'),(893771,'furniture','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(893772,'furniture','.w-filters .filter-ul-content','list-style','none','','','.w-filters'),(893773,'furniture','.w-menu-horizontal ul','list-style','none','','','.w-menu-horizontal'),(893774,'furniture','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(893775,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(893776,'furniture','.products-quick-index ul','list-style','none','','',''),(893777,'furniture','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(893778,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(893779,'furniture','.w-tabs .tab-navigation','list-style','none','','','.w-tabs'),(893780,'furniture','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(893781,'furniture','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(893782,'furniture','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(893783,'furniture','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(893784,'furniture','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(893785,'furniture','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(893786,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(893787,'furniture','.b-autocomplete .ui-autocomplete','list-style','none','','','.b-autocomplete'),(893789,'furniture','.b-select-suggest .select2-container-multi .select2-choices li','list-style','none','','','.b-select-suggest'),(893790,'furniture','.b-select-suggest .select2-results li','list-style','none','','','.b-select-suggest'),(893791,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(893792,'furniture','.w-menu-big ul','list-style','none','','','.w-menu-big'),(893794,'furniture','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(893795,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(893796,'furniture','.products-quick-index .token-input-list','list-style','none','','',''),(893797,'furniture','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(893798,'furniture','.products-quick-index ul.token-input-list','list-style','none','','',''),(893799,'furniture','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(893800,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(893801,'furniture','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','list-style','none','','','.b-menu-style'),(893802,'furniture','.w-catalog-additional-images ul, .w-catalog-additional-images li','list-style','none','','','.w-catalog-additional-images'),(893803,'furniture','.LeftCategories .w-menu-simple ul','list-style','none','','','.LeftCategories'),(893804,'furniture','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(893805,'furniture','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(893806,'furniture','.b-pagination ul.pagination','list-style','none','','','.b-pagination'),(893807,'furniture','.w-account-personal-catalog .list-row-action ul','list-style','none','','','.w-account-personal-catalog'),(893808,'furniture','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(893809,'furniture','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(893810,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list'),(893811,'furniture','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(893812,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list-block'),(893813,'furniture','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(893814,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li','list-style','none','','','.w-delivery-location-featured-list'),(893815,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(893816,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(893817,'furniture','.w-delivery-location-list-by-page .description ul','list-style','circle','','','.w-delivery-location-list-by-page'),(893818,'furniture','.w-delivery-location-cross-pages .description ul','list-style','circle','','','.w-delivery-location-cross-pages'),(893819,'furniture','.w-catalog-delivery-locations .description ul','list-style','circle','','','.w-catalog-delivery-locations'),(893820,'furniture','.w-support-system-filter .filter_cats','list-style','none','','','.w-support-system-filter'),(893821,'furniture','.w-product-configurator .pc-item','list-style','none','','','.w-product-configurator'),(893822,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-list'),(893823,'furniture','.w-filters .filter-box-content ul','list-style','none','','','.w-filters'),(893828,'furniture','.account-address-book .leftMes ul','list-style','disc inside','','','.account-address-book'),(893829,'furniture','.account-address-book .rightMes ul','list-style','disc inside','','','.account-address-book'),(893830,'furniture','.b-info .info ul','list-style','disc inside','','','.b-info'),(893831,'furniture','.w-delivery-location-featured-list .deliveryList ul','list-style-type','circle','','','.w-delivery-location-featured-list'),(893832,'furniture','.b-messages .msv_btn .btn','margin','0px auto 0px','','','.b-messages'),(893833,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','margin','3px auto 3px','','','.b-select-suggest'),(893834,'furniture','.b-select-suggest .select2-results','margin','4px auto 4px','','','.b-select-suggest'),(893835,'furniture','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(893836,'furniture','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(893837,'furniture','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(893838,'furniture','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin','0px auto 10px','','','.b-form'),(893839,'furniture','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(893840,'furniture','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(893841,'furniture','.w-catalog-b2b-add-button .b2b-add-box-wrap','margin','0 auto','','','.w-catalog-b2b-add-button'),(893842,'furniture','.b-form .terms-login .bootstrap-switch','margin','9px auto 0px','','','.b-form'),(893843,'furniture','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','margin','0 0 0 auto','','','.w-cart-listing'),(893844,'furniture','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','margin','0 auto','','','.b-product-images'),(893845,'furniture','.b-trade-approval .middle-form','margin','0 auto','','','.b-trade-approval'),(893847,'furniture','.b-products-listing .products-listing .slick-slide img','margin','auto','','','.b-products-listing'),(893848,'furniture','.b-products-listing .products-listing .compare input + span','margin','auto','','','.b-products-listing'),(893849,'furniture','.b-products-listing .products-listing.list-productlisting .item-content','margin','5px auto','4','','.b-products-listing'),(893850,'furniture','.w-product-quantity .qty_packs .price_1','margin','0px auto 0px','4','','.w-product-quantity'),(893851,'furniture','.p-quote-checkout-index .datepicker-inline','margin','0 auto','','','.p-quote-checkout-index'),(893852,'furniture','.p-sample-checkout-index .datepicker-inline','margin','0 auto','','','.p-sample-checkout-index'),(893853,'furniture','.b-slick .slick-slide img','margin','auto','','','.b-slick'),(893854,'furniture','.mainBanner .bottomBox','margin','auto','5206','','.mainBanner'),(893857,'furniture','.account-address-book .address_book .row-buttons a','margin','0px auto 0px','','','.account-address-book'),(893858,'furniture','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin','0px auto 15px','','','.account-address-book'),(893859,'furniture','.account-address-book .address_book_row h2 a','margin','0px auto 0px','','','.account-address-book'),(893860,'furniture','.account-address-book .buttonBox .info','margin','0px auto 0px','','','.account-address-book'),(893861,'furniture','.checkout-index-wrap .datepicker-inline','margin','0 auto','','','.checkout-index-wrap'),(893862,'furniture','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','margin','0 auto','','','.checkout-index-wrap'),(893863,'furniture','.b-form .middle-g','margin','0 auto','','','.b-form'),(893864,'furniture','.b-form .formWrapBox','margin','0 auto','','','.b-form'),(893865,'furniture','.lowestPricedBox .w-banner .ybg','margin','auto','3','','.lowestPricedBox'),(893866,'furniture','.w-communication-new-topic #communication_group_holder input, .w-communication-new-topic select','margin-bottom','0','','','.w-communication-new-topic'),(893867,'furniture','.w-checkout-billing-address .genders-title','margin-bottom','5','','','.w-checkout-billing-address'),(893868,'furniture','.b-form .col-full-margin','margin-bottom','10','','','.b-form'),(893869,'furniture','.w-tabs .tab-li.tab-cart a','margin-bottom','7','3','','.w-tabs'),(893871,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(893872,'furniture','.w-catalog-items-on-page select','margin-bottom','0','','','.w-catalog-items-on-page'),(893873,'furniture','.b-form .message.error','margin-bottom','10','','','.b-form'),(893874,'furniture','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-bottom','0','','','.b-fancybox'),(893875,'furniture','.p-quick-order-index .filters','margin-bottom','20','','','.p-quick-order-index'),(893876,'furniture','.w-promotions .promo-date','margin-bottom','10','','','.w-promotions'),(893877,'furniture','.w-promotions .promo-item','margin-bottom','30','','','.w-promotions'),(893878,'furniture','.w-socials > li','margin-bottom','10','','','.w-socials'),(893879,'furniture','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(893880,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(893884,'furniture','.w-promotions .prom-multi-discount .heading','margin-bottom','10','','','.w-promotions'),(893885,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(893886,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(893887,'furniture','.testimonials .reviews-list .name','margin-bottom','20','','',''),(893888,'furniture','.testimonials .heading-3','margin-bottom','10','','',''),(893889,'furniture','.testimonials .name','margin-bottom','20','','',''),(893890,'furniture','.b-products-listing .select-attributes','margin-bottom','10','','','.b-products-listing'),(893891,'furniture','.b-products-listing .select-attributes select','margin-bottom','0','','','.b-products-listing'),(893892,'furniture','.w-promotions .nextdiscount .promo-for-each','margin-bottom','10','','','.w-promotions'),(893893,'furniture','.w-promotions .nextdiscount .heading','margin-bottom','20','','','.w-promotions'),(893894,'furniture','.w-promotions .heading-3','margin-bottom','20','','','.w-promotions'),(893895,'furniture','.w-promotions .promo-salemaker .item','margin-bottom','2','','','.w-promotions'),(893896,'furniture','.w-promotions .promo-cart-discount .slave .item','margin-bottom','2','','','.w-promotions'),(893897,'furniture','.w-promotions .promo-cart-discount .master .item','margin-bottom','12','','','.w-promotions'),(893898,'furniture','.w-promotions .promo-cart-discount .master .heading','margin-bottom','10','','','.w-promotions'),(893899,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-bottom','20','','','.b-warehouses-popup'),(893900,'furniture','.b-warehouses-popup .warehouses-popup .heading','margin-bottom','20','','','.b-warehouses-popup'),(893901,'furniture','.w-info-content p','margin-bottom','10','','','.w-info-content'),(893903,'furniture','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(893904,'furniture','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(893905,'furniture','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(893907,'furniture','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(893908,'furniture','.w-top-categories .categories','margin-bottom','0','5131','','.w-top-categories'),(893909,'furniture','.b-messages .messages-menu ul','margin-bottom','0','','','.b-messages'),(893910,'furniture','.b-messages .messMenuButtonTop','margin-bottom','-39','','','.b-messages'),(893911,'furniture','.b-messages .dataTables_wrapper > .top','margin-bottom','8','','','.b-messages'),(893912,'furniture','.b-messages .messages-sidebar .heading-2','margin-bottom','20','','','.b-messages'),(893913,'furniture','.b-messages .messages-menu li','margin-bottom','0','','','.b-messages'),(893914,'furniture','.b-messages .messages-sidebar .btn-2','margin-bottom','20','','','.b-messages'),(893915,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-bottom','5','','','.b-messages'),(893916,'furniture','.w-sitemap-delivery-location > ul > li > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(893917,'furniture','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(893918,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(893919,'furniture','.b-form .middle-form .bootstrap-switch','margin-bottom','15','','','.b-form'),(893920,'furniture','.w-sitemap-delivery-location > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(893921,'furniture','.p-payer-order-confirmation .input-wrapper','margin-bottom','10','','','.p-payer-order-confirmation'),(893922,'furniture','.p-payer-order-confirmation .dob-hide','margin-bottom','-10','','','.p-payer-order-confirmation'),(893923,'furniture','.p-payer-order-pay .input-wrapper','margin-bottom','10','','','.p-payer-order-pay'),(893924,'furniture','.p-payer-order-pay .dob-hide','margin-bottom','-10','','','.p-payer-order-pay'),(893925,'furniture','.p-quick-order-index ul.token-input-list','margin-bottom','0','','','.p-quick-order-index'),(893926,'furniture','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(893927,'furniture','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(893928,'furniture','.w-checkout-shipping-address .genders-title','margin-bottom','5','','','.w-checkout-shipping-address'),(893929,'furniture','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(893930,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(893931,'furniture','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(893932,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(893933,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','margin-bottom','20','','','.w-upload-customer-id-upload-customer-id-form'),(893934,'furniture','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(893935,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(893936,'furniture','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(893937,'furniture','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(893938,'furniture','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(893939,'furniture','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(893940,'furniture','.w-filters .filter-box-head','margin-bottom','15','','','.w-filters'),(893941,'furniture','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(893942,'furniture','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(893943,'furniture','.w-menu-horizontal li','margin-bottom','0','','','.w-menu-horizontal'),(893944,'furniture','.w-menu-horizontal ul','margin-bottom','0','','','.w-menu-horizontal'),(893945,'furniture','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(893946,'furniture','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(893947,'furniture','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(893948,'furniture','.b-delete-account .delete-box > div','margin-bottom','10','','','.b-delete-account'),(893949,'furniture','.w-info-content p','margin-bottom','10','','','.w-info-content'),(893950,'furniture','.w-filters .input-checkbox','margin-bottom','0','','','.w-filters'),(893951,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(893952,'furniture','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(893953,'furniture','.b-form .newsletter-row','margin-bottom','10','','','.b-form'),(893954,'furniture','.w-cart-give-away .ga_attributes > div','margin-bottom','1','','','.w-cart-give-away'),(893955,'furniture','.w-cart-checkout-btn + .w-image','margin-bottom','0','','','.w-cart-checkout-btn'),(893956,'furniture','.heading-6, h6, .h-block h6','margin-bottom','5','','',''),(893957,'furniture','.pop-up-content .buttons .left-buttons','margin-bottom','15','5140','',''),(893958,'furniture','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(893959,'furniture','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(893960,'furniture','.w-communication-post .text-container','margin-bottom','20','','','.w-communication-post'),(893961,'furniture','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(893962,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(893963,'furniture','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(893964,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(893965,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(893966,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-bottom','0','','','.b-select-suggest'),(893967,'furniture','.b-form .password-forgotten-link','margin-bottom','0','','','.b-form'),(893968,'furniture','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(893969,'furniture','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(893970,'furniture','.w-socials > li','margin-bottom','10','','','.w-socials'),(893972,'furniture','.b-delete-account .delete-box span','margin-bottom','0','','','.b-delete-account'),(893973,'furniture','.w-socials > li','margin-bottom','10','','','.w-socials'),(893974,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(893975,'furniture','.w-image-maps .default-links .item .title','margin-bottom','10','','','.w-image-maps'),(893976,'furniture','.w-reviews .heading-3','margin-bottom','10','','','.w-reviews'),(893977,'furniture','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(893978,'furniture','.w-socials > li','margin-bottom','10','','','.w-socials'),(893979,'furniture','.w-checkout-shipping-address .addresses .address-item','margin-bottom','10','','','.w-checkout-shipping-address'),(893980,'furniture','.w-checkout-billing-address .same-address','margin-bottom','10','','','.w-checkout-billing-address'),(893981,'furniture','.b-form .required-message-wrap','margin-bottom','0','','','.b-form'),(893982,'furniture','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(893983,'furniture','.w-tabs .tab-li.tab-wishlist a','margin-bottom','7','3','','.w-tabs'),(893984,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(893985,'furniture','.w-tabs > .block','margin-bottom','20','','','.w-tabs'),(893986,'furniture','.w-cart-cart-tabs .w-tabs .tab-navigation','margin-bottom','25','','','.w-cart-cart-tabs'),(893987,'furniture','.w-tabs .tab-li','margin-bottom','0','','','.w-tabs'),(893988,'furniture','.w-socials > li','margin-bottom','10','','','.w-socials'),(893989,'furniture','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(893991,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(893992,'furniture','.w-tabs .tab-li.tab-sample a','margin-bottom','7','3','','.w-tabs'),(893993,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(893994,'furniture','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(893995,'furniture','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(893996,'furniture','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(893997,'furniture','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(893998,'furniture','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(893999,'furniture','.heading-5, h5, .h-block h5','margin-bottom','5','','',''),(894000,'furniture','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(894001,'furniture','.w-filters .filter-ul-content','margin-bottom','0','','','.w-filters'),(894002,'furniture','.heading-4, h4, .h-block h4','margin-bottom','5','','',''),(894003,'furniture','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(894004,'furniture','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(894005,'furniture','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','margin-bottom','10','','','.b-form'),(894006,'furniture','.order-summary .price-box','margin-bottom','10','','','.order-summary'),(894007,'furniture','.b-form .addresses .address-item input[type=\"radio\"]','margin-bottom','0','','','.b-form'),(894008,'furniture','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(894009,'furniture','.w-image-maps .categories-items .item .title','margin-bottom','10','','','.w-image-maps'),(894010,'furniture','.b-select-suggest .select2-drop-mask','margin-bottom','0','','','.b-select-suggest'),(894011,'furniture','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(894012,'furniture','.w-top-categories .categories','margin-bottom','0','5145','','.w-top-categories'),(894013,'furniture','.products-quick-index ul','margin-bottom','0','','',''),(894014,'furniture','.w-checkout-gdpr .col-left','margin-bottom','20','5140','','.w-checkout-gdpr'),(894015,'furniture','.w-top-categories .categories h2','margin-bottom','0','','','.w-top-categories'),(894016,'furniture','.w-product-reviews .reviews-list .name','margin-bottom','20','','','.w-product-reviews'),(894017,'furniture','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(894018,'furniture','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(894019,'furniture','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(894020,'furniture','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(894021,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(894022,'furniture','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(894023,'furniture','.b-form .required-message','margin-bottom','0','','','.b-form'),(894024,'furniture','.w-socials .post_item_img','margin-bottom','0','','','.w-socials'),(894025,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(894026,'furniture','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(894027,'furniture','.w-product-quantity .qty_packs .price_1','margin-bottom','0','4','','.w-product-quantity'),(894028,'furniture','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(894029,'furniture','.w-reviews .reviews-list','margin-bottom','20','','','.w-reviews'),(894030,'furniture','.b-select-suggest .select2-container','margin-bottom','0','','','.b-select-suggest'),(894031,'furniture','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(894032,'furniture','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(894033,'furniture','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(894034,'furniture','.w-checkout-create-account .heading-2','margin-bottom','0','','','.w-checkout-create-account'),(894035,'furniture','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(894036,'furniture','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(894037,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(894038,'furniture','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(894039,'furniture','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(894040,'furniture','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(894041,'furniture','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(894042,'furniture','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(894043,'furniture','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(894044,'furniture','.b-form .col-full-padding','margin-bottom','10','','','.b-form'),(894045,'furniture','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','margin-bottom','15','','','.b-form'),(894046,'furniture','.heading-3, h3, .h-block h3','margin-bottom','10','','',''),(894047,'furniture','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(894048,'furniture','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(894049,'furniture','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(894051,'furniture','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(894052,'furniture','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(894053,'furniture','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(894054,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(894055,'furniture','.b-form .form-inputs label > span','margin-bottom','1','','','.b-form'),(894056,'furniture','.b-autocomplete .ui-autocomplete','margin-bottom','0','','','.b-autocomplete'),(894057,'furniture','.b-bottom .cart-options .js-carts','margin-bottom','20','','','.b-bottom'),(894058,'furniture','.b-bottom .cart-options .option-item','margin-bottom','5','','','.b-bottom'),(894059,'furniture','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(894060,'furniture','.b-bottom .cart-options .cart-item','margin-bottom','5','','','.b-bottom'),(894062,'furniture','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(894063,'furniture','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(894064,'furniture','.b-select-suggest .select2-results .select2-result-label','margin-bottom','0','','','.b-select-suggest'),(894066,'furniture','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(894067,'furniture','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(894068,'furniture','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(894069,'furniture','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(894070,'furniture','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(894071,'furniture','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(894072,'furniture','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(894073,'furniture','.w-menu-big li','margin-bottom','0','','','.w-menu-big'),(894074,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(894075,'furniture','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(894076,'furniture','.b-fancybox .fancybox-error','margin-bottom','0','','','.b-fancybox'),(894077,'furniture','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(894078,'furniture','.w-cart-compare .product .image','margin-bottom','10','','','.w-cart-compare'),(894079,'furniture','.w-checkout-billing-address .addresses .address-item','margin-bottom','10','','','.w-checkout-billing-address'),(894080,'furniture','.b-bottom .confirm-popup .buttons .btn','margin-bottom','0','','','.b-bottom'),(894081,'furniture','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-bottom','0','','','.b-switch'),(894082,'furniture','.w-reviews-content .reviews-list','margin-bottom','20','','','.w-reviews-content'),(894083,'furniture','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(894084,'furniture','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(894085,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(894086,'furniture','.b-form #shipping-address .radio-buttons','margin-bottom','10','','','.b-form'),(894087,'furniture','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(894088,'furniture','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(894089,'furniture','.w-tabs .tab-navigation','margin-bottom','0','','','.w-tabs'),(894090,'furniture','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(894091,'furniture','.w-social-links a','margin-bottom','0','','','.w-social-links'),(894092,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-bottom','1','','','.b-select-suggest'),(894093,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-bottom','0','','','.b-select-suggest'),(894094,'furniture','.b-select-suggest .select2-container-multi .select2-choices','margin-bottom','0','','','.b-select-suggest'),(894095,'furniture','.w-info-content p','margin-bottom','10','','','.w-info-content'),(894096,'furniture','.b-select-suggest .select2-results ul.select2-result-sub','margin-bottom','0','','','.b-select-suggest'),(894097,'furniture','.b-select-suggest .select2-search input','margin-bottom','0','','','.b-select-suggest'),(894098,'furniture','.b-select-suggest .select2-search','margin-bottom','0','','','.b-select-suggest'),(894099,'furniture','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(894103,'furniture','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(894105,'furniture','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(894106,'furniture','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(894107,'furniture','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(894108,'furniture','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(894109,'furniture','.order-summary .btn-2, .order-summary .btn-3','margin-bottom','15','','','.order-summary'),(894111,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(894112,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(894113,'furniture','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(894114,'furniture','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(894115,'furniture','.b-bottom .content-item','margin-bottom','20','','','.b-bottom'),(894116,'furniture','.b-form .middle-form .checkbox-holder','margin-bottom','15','','','.b-form'),(894117,'furniture','.w-communication-new-topic .privacy-row','margin-bottom','10','','','.w-communication-new-topic'),(894118,'furniture','.w-communication-post .communication-post-message','margin-bottom','20','','','.w-communication-post'),(894119,'furniture','.w-communication-post .communication-post','margin-bottom','5','','','.w-communication-post'),(894120,'furniture','.b-products-listing .products-listing .name','margin-bottom','5','','','.b-products-listing'),(894121,'furniture','.b-products-listing .products-listing .model','margin-bottom','5','','','.b-products-listing'),(894122,'furniture','.b-products-listing .products-listing .description','margin-bottom','5','','','.b-products-listing'),(894123,'furniture','.b-products-listing .products-listing .bonusPoints','margin-bottom','7','','','.b-products-listing'),(894124,'furniture','.b-products-listing .products-listing .description ul','margin-bottom','0','','','.b-products-listing'),(894125,'furniture','.b-products-listing .products-listing .mult-qty-input','margin-bottom','3','','','.b-products-listing'),(894126,'furniture','.b-products-listing .promos-info','margin-bottom','-30','','','.b-products-listing'),(894127,'furniture','.b-products-listing .wedding-registry-count','margin-bottom','10','','','.b-products-listing'),(894128,'furniture','.w-info-content p','margin-bottom','10','','','.w-info-content'),(894129,'furniture','.w-checkout-gdpr .privacy-row','margin-bottom','0','','','.w-checkout-gdpr'),(894130,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(894131,'furniture','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(894132,'furniture','.b-fancybox .fancybox-title-float-wrap','margin-bottom','-35','','','.b-fancybox'),(894133,'furniture','.w-socials > li','margin-bottom','10','','','.w-socials'),(894134,'furniture','.w-product-reviews .reviews-list','margin-bottom','10','','','.w-product-reviews'),(894135,'furniture','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(894137,'furniture','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(894138,'furniture','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(894139,'furniture','.w-info-content p','margin-bottom','10','','','.w-info-content'),(894140,'furniture','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(894141,'furniture','.w-taxable label','margin-bottom','0','','','.w-taxable'),(894142,'furniture','.w-taxable select','margin-bottom','0','','','.w-taxable'),(894143,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-bottom','0','','',''),(894144,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-bottom','0','','','.b-h-inline'),(894145,'furniture','h1, .heading-1','margin-bottom','18','','',''),(894146,'furniture','.w-communication-new-topic #rmaProductReturnButtonFilterHolder','margin-bottom','30','','','.w-communication-new-topic'),(894147,'furniture','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(894148,'furniture','.w-checkout-shipping-address #shippingchoice-choice','margin-bottom','10','','','.w-checkout-shipping-address'),(894149,'furniture','.w-product-reviews .write-review-button','margin-bottom','20','','','.w-product-reviews'),(894150,'furniture','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(894151,'furniture','.w-tabs .tab-li.tab-quote a','margin-bottom','7','3','','.w-tabs'),(894152,'furniture','.b-form .checkbox-style','margin-bottom','0','','','.b-form'),(894153,'furniture','.products-quick-index .token-input-list','margin-bottom','0','','',''),(894154,'furniture','.products-quick-index ul.token-input-list','margin-bottom','0','','',''),(894155,'furniture','.w-cart-checkout-btn .or-text','margin-bottom','5','','','.w-cart-checkout-btn'),(894156,'furniture','.b-compare .col-two','margin-bottom','15','','','.b-compare'),(894157,'furniture','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(894158,'furniture','.w-cart-listing .item','margin-bottom','10','5140','','.w-cart-listing'),(894159,'furniture','.w-cart-give-away .ga_wrapper','margin-bottom','25','','','.w-cart-give-away'),(894161,'furniture','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(894162,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(894163,'furniture','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(894164,'furniture','.w-image-maps .float-items .item .title','margin-bottom','10','','','.w-image-maps'),(894165,'furniture','.w-info-content p','margin-bottom','10','','','.w-info-content'),(894166,'furniture','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-bottom','0','','','.b-fancybox'),(894167,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(894168,'furniture','.w-filters .ui-slider','margin-bottom','0','','','.w-filters'),(894169,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(894170,'furniture','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(894171,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(894172,'furniture','.w-catalog-sorting select','margin-bottom','0','','','.w-catalog-sorting'),(894173,'furniture','.b-form .radio-buttons','margin-bottom','10','','','.b-form'),(894174,'furniture','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(894175,'furniture','.heading-2, h2, .h-block h2','margin-bottom','10','','',''),(894176,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(894177,'furniture','.b-upload-files .upload-files','margin-bottom','20','','','.b-upload-files'),(894178,'furniture','.w-communication-new-topic .text-container','margin-bottom','20','','','.w-communication-new-topic'),(894181,'furniture','.w-menu-big ul','margin-bottom','0','','','.w-menu-big'),(894182,'furniture','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(894183,'furniture','.b-product-images .media-popup .slick-dots','margin-bottom','0','','','.b-product-images'),(894184,'furniture','.b-product-images .media-popup .slick-dots li','margin-bottom','0','','','.b-product-images'),(894185,'furniture','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-bottom','0','','','.b-menu-style'),(894186,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages','margin-bottom','10','','','.b-menu-style-2'),(894187,'furniture','.b-personal-catalog-popup #personal_catalog_popup .lists-message-box','margin-bottom','20','','','.b-personal-catalog-popup'),(894188,'furniture','.b-trade-approval .steps-bar','margin-bottom','25','','','.b-trade-approval'),(894189,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','margin-bottom','15','','','.b-trade-approval'),(894190,'furniture','.b-trade-approval .middle-form textarea','margin-bottom','15','','','.b-trade-approval'),(894191,'furniture','.w-account-personal-catalog .list-switcher','margin-bottom','20','','','.w-account-personal-catalog'),(894192,'furniture','.w-account-subscription .send-email','margin-bottom','20','','','.w-account-subscription'),(894193,'furniture','.w-account-subscription .subscription-list','margin-bottom','20','','','.w-account-subscription'),(894194,'furniture','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-bottom','0','','','.w-catalog-additional-images'),(894195,'furniture','.w-catalog-compare .cross-box .return','margin-bottom','30','','','.w-catalog-compare'),(894196,'furniture','.w-delivery-day .time-left','margin-bottom','30','','','.w-delivery-day'),(894197,'furniture','.w-delivery-day .ends','margin-bottom','20','','','.w-delivery-day'),(894198,'furniture','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-bottom','0','','','.b-cookie-notice'),(894199,'furniture','.b-products-listing .products-listing.list-productlisting .price','margin-bottom','0','','','.b-products-listing'),(894200,'furniture','.b-slick .slick-list','margin-bottom','0','','','.b-slick'),(894201,'furniture','.b-products-listing .products-listing a.btn.view-button','margin-bottom','4','3','','.b-products-listing'),(894202,'furniture','.b-products-listing .add-to-personal-catalog','margin-bottom','4','3','','.b-products-listing'),(894203,'furniture','.LeftCategories .w-menu-simple ul','margin-bottom','0','','','.LeftCategories'),(894204,'furniture','.w-breadcrumb .breadcrumb-li','margin-bottom','0','','','.w-breadcrumb'),(894205,'furniture','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(894206,'furniture','.w-quote .multicart .name','margin-bottom','0','','','.w-quote'),(894207,'furniture','.b-products-listing .rating, .b-products-listing .ratingCounts','margin-bottom','5','','','.b-products-listing'),(894208,'furniture','.w-product-name h1','margin-bottom','5','','','.w-product-name'),(894209,'furniture','.w-product-sale-ends .ends','margin-bottom','20','','','.w-product-sale-ends'),(894210,'furniture','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(894211,'furniture','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(894212,'furniture','.w-compare .clear-compare-button','margin-bottom','15','','','.w-compare'),(894213,'furniture','.w-files-catalog-widgets-files-catalog ','margin-bottom','50','','','.w-files-catalog-widgets-files-catalog'),(894214,'furniture','.w-files-catalog-widgets-files-list .files','margin-bottom','50','','','.w-files-catalog-widgets-files-list'),(894215,'furniture','.w-files-catalog-widgets-files-list .name','margin-bottom','10','','','.w-files-catalog-widgets-files-list'),(894216,'furniture','.w-sample .multicart .name','margin-bottom','0','','','.w-sample'),(894217,'furniture','.w-filters-simple select','margin-bottom','0','','','.w-filters-simple'),(894218,'furniture','.w-cart-discount-coupon .title','margin-bottom','0','','','.w-cart-discount-coupon'),(894219,'furniture','.w-cart-sub-total ','margin-bottom','20','','','.w-cart-sub-total'),(894220,'furniture','.shipping-ico .heading-3','margin-bottom','10','','','.shipping-ico'),(894221,'furniture','.order-summary .heading-2','margin-bottom','0','','','.order-summary'),(894222,'furniture','.w-cart-gift-certificate .heading-4','margin-bottom','0','','','.w-cart-gift-certificate'),(894223,'furniture','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(894224,'furniture','.w-product-bundle .bundle-total-price','margin-bottom','20','','','.w-product-bundle'),(894225,'furniture','.w-product-in-bundles .bundle-total-price','margin-bottom','20','','','.w-product-in-bundles'),(894226,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-bottom','0','','','.b-products-listing'),(894227,'furniture','.b-pagination .pagination','margin-bottom','20','','','.b-pagination'),(894228,'furniture','.b-pagination ul.pagination','margin-bottom','0','','','.b-pagination'),(894229,'furniture','.w-catalog-compare .list-compareproduct .stock','margin-bottom','0','','','.w-catalog-compare'),(894230,'furniture','.w-product-properties-filters-widgets-chosen-filters .item','margin-bottom','5','','','.w-product-properties-filters-widgets-chosen-filters'),(894231,'furniture','.w-product-multi-inventory .radio-attributes > span','margin-bottom','5','','','.w-product-multi-inventory'),(894232,'furniture','.w-product-multi-inventory .radio-attributes','margin-bottom','15','','','.w-product-multi-inventory'),(894233,'furniture','.w-account-personal-catalog .list-row-action ul','margin-bottom','-1','','','.w-account-personal-catalog'),(894234,'furniture','.w-account-personal-catalog .list-row-action li','margin-bottom','0','','','.w-account-personal-catalog'),(894235,'furniture','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','margin-bottom','10','','','.w-account-personal-catalog'),(894236,'furniture','.b-products-listing .products-listing .radio-attributes','margin-bottom','15','','','.b-products-listing'),(894237,'furniture','.b-products-listing .products-listing .radio-attributes > span','margin-bottom','5','','','.b-products-listing'),(894238,'furniture','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(894239,'furniture','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(894240,'furniture','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(894241,'furniture','.w-product-attributes .radio-attributes','margin-bottom','15','','','.w-product-attributes'),(894242,'furniture','.w-product-attributes .radio-attributes > span','margin-bottom','5','','','.w-product-attributes'),(894243,'furniture','.w-product-properties .property-ul','margin-bottom','0','','','.w-product-properties'),(894244,'furniture','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(894245,'furniture','.w-questionnaire-widgets-questionnaire .question','margin-bottom','20','','','.w-questionnaire-widgets-questionnaire'),(894246,'furniture','.w-questionnaire-widgets-questionnaire .description','margin-bottom','10','','','.w-questionnaire-widgets-questionnaire'),(894247,'furniture','.w-product-groups .radioBox label','margin-bottom','15','','','.w-product-groups'),(894248,'furniture','.w-product-groups .radioBoxHead','margin-bottom','10','','','.w-product-groups'),(894249,'furniture','.w-delivery-day .title','margin-bottom','10','','','.w-delivery-day'),(894250,'furniture','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img','margin-bottom','10','','','.w-product-groups'),(894251,'furniture','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(894252,'furniture','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(894253,'furniture','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(894254,'furniture','.b-products-listing .products-listing.list-productlisting .attribute-qty-block > span','margin-bottom','4','','','.b-products-listing'),(894255,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-bottom','0','','','.w-catalog-pages-category-pages-last-list'),(894256,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(894257,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-bottom','0','','','.w-catalog-pages-category-pages-last-list-block'),(894258,'furniture','.w-delivery-location-top-location-list .deliveryName','margin-bottom','10','','','.w-delivery-location-top-location-list'),(894259,'furniture','.w-delivery-location-location-list .deliveryName','margin-bottom','10','','','.w-delivery-location-location-list'),(894260,'furniture','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(894261,'furniture','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(894262,'furniture','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(894263,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','5131','','.w-delivery-location-top-location-list'),(894264,'furniture','.w-delivery-location-featured-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-featured-list'),(894265,'furniture','.w-delivery-location-location-list .deliveryListParrent a','margin-bottom','5','','','.w-delivery-location-location-list'),(894266,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li','margin-bottom','20','','','.w-delivery-location-featured-list'),(894267,'furniture','.w-sale-category .ends','margin-bottom','20','','','.w-sale-category'),(894268,'furniture','.w-sale-category .left','margin-bottom','30','','','.w-sale-category'),(894269,'furniture','.w-sale-category .name','margin-bottom','20','','','.w-sale-category'),(894270,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-img','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(894271,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-name','margin-bottom','10','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(894272,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(894273,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(894274,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-img','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(894275,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-name','margin-bottom','10','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(894276,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(894277,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(894278,'furniture','.w-delivery-location-list-by-page .description ul','margin-bottom','5','','','.w-delivery-location-list-by-page'),(894279,'furniture','.w-delivery-location-list-by-page .item','margin-bottom','20','','','.w-delivery-location-list-by-page'),(894280,'furniture','.w-delivery-location-list-by-page .item','margin-bottom','10','5161','','.w-delivery-location-list-by-page'),(894281,'furniture','.w-delivery-location-cross-pages .description ul','margin-bottom','5','','','.w-delivery-location-cross-pages'),(894282,'furniture','.w-delivery-location-cross-pages .item','margin-bottom','20','','','.w-delivery-location-cross-pages'),(894283,'furniture','.w-delivery-location-cross-pages .item','margin-bottom','10','5161','','.w-delivery-location-cross-pages'),(894284,'furniture','.w-cart-credit-amount ','margin-bottom','10','','','.w-cart-credit-amount'),(894285,'furniture','.w-catalog-delivery-locations .item','margin-bottom','20','','','.w-catalog-delivery-locations'),(894286,'furniture','.w-catalog-delivery-locations .description ul','margin-bottom','5','','','.w-catalog-delivery-locations'),(894287,'furniture','.w-catalog-delivery-locations .name','margin-bottom','10','','','.w-catalog-delivery-locations'),(894288,'furniture','.w-catalog-delivery-locations .item','margin-bottom','20','5131','','.w-catalog-delivery-locations'),(894289,'furniture','.w-product-designer-designer .grnamebox .title-sortable','margin-bottom','10','','','.w-product-designer-designer'),(894290,'furniture','.w-product-designer-designer .prodDesignerType label','margin-bottom','10','','','.w-product-designer-designer'),(894291,'furniture','.w-press-reviews-widgets-press-reviews-small ','margin-bottom','12','','','.w-press-reviews-widgets-press-reviews-small'),(894292,'furniture','.w-press-reviews-widgets-press-reviews ','margin-bottom','30','','','.w-press-reviews-widgets-press-reviews'),(894293,'furniture','.w-press-reviews-widgets-press-reviews .image','margin-bottom','15','','','.w-press-reviews-widgets-press-reviews'),(894294,'furniture','.w-press-reviews-widgets-press-reviews .reviews-list','margin-bottom','20','','','.w-press-reviews-widgets-press-reviews'),(894295,'furniture','.w-press-reviews-widgets-press-reviews .date','margin-bottom','10','5131','','.w-press-reviews-widgets-press-reviews'),(894296,'furniture','.w-press-reviews-widgets-press-reviews-list .image','margin-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(894297,'furniture','.w-press-reviews-widgets-press-reviews-list .item','margin-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(894298,'furniture','.w-press-reviews-widgets-press-reviews-list .product-name','margin-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(894299,'furniture','.b-products-listing .productGroup','margin-bottom','10','','','.b-products-listing'),(894300,'furniture','.w-gift-wrap-message-checkout .text','margin-bottom','20','','','.w-gift-wrap-message-checkout'),(894301,'furniture','.w-support-system-filter .filter_cats','margin-bottom','0','','','.w-support-system-filter'),(894302,'furniture','.w-support-system-listing .topic-products-listing .item','margin-bottom','30','','','.w-support-system-listing'),(894303,'furniture','.w-communication-post .buttons','margin-bottom','20','','','.w-communication-post'),(894304,'furniture','.w-rma-returns-history .content-messages .messages-table .top','margin-bottom','10','','','.w-rma-returns-history'),(894305,'furniture','.w-rma-returns-history .filterMessages','margin-bottom','0','','','.w-rma-returns-history'),(894306,'furniture','.w-rma-returns-history .column','margin-bottom','10','','screen and (max-width: 768px)','.w-rma-returns-history'),(894307,'furniture','.w-rma-returns-history .column .title','margin-bottom','5','','screen and (max-width: 768px)','.w-rma-returns-history'),(894308,'furniture','.w-rma-returns-history .column:last-child .title','margin-bottom','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(894309,'furniture','.w-product-designer-designer .productDesignerBox ul','margin-bottom','0','','','.w-product-designer-designer'),(894310,'furniture','.w-product-designer-designer .grnamebox','margin-bottom','10','','','.w-product-designer-designer'),(894311,'furniture','.w-product-configurator .pc-item','margin-bottom','0','','','.w-product-configurator'),(894312,'furniture','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(894313,'furniture','.w-product-configurator .pc_row','margin-bottom','10','','','.w-product-configurator'),(894314,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-bottom','0','','','.w-catalog-pages-category-pages-list'),(894315,'furniture','.w-predefined-promotion .heading-3','margin-bottom','20','','','.w-predefined-promotion'),(894316,'furniture','.w-predefined-promotion .nextdiscount .heading','margin-bottom','20','','','.w-predefined-promotion'),(894317,'furniture','.w-predefined-promotion .nextdiscount .promo-for-each','margin-bottom','10','','','.w-predefined-promotion'),(894318,'furniture','.w-predefined-promotion .prom-multi-discount .heading','margin-bottom','10','','','.w-predefined-promotion'),(894319,'furniture','.w-predefined-promotion .promo-cart-discount .master .heading','margin-bottom','10','','','.w-predefined-promotion'),(894320,'furniture','.w-predefined-promotion .promo-cart-discount .master .item','margin-bottom','12','','','.w-predefined-promotion'),(894321,'furniture','.w-predefined-promotion .promo-cart-discount .slave .item','margin-bottom','2','','','.w-predefined-promotion'),(894322,'furniture','.w-predefined-promotion .promo-date','margin-bottom','10','','','.w-predefined-promotion'),(894323,'furniture','.w-predefined-promotion .promo-item','margin-bottom','30','','','.w-predefined-promotion'),(894324,'furniture','.w-predefined-promotion .promo-salemaker .item','margin-bottom','2','','','.w-predefined-promotion'),(894325,'furniture','.w-supplier-purchase-supplier-products .item','margin-bottom','10','','','.w-supplier-purchase-supplier-products'),(894326,'furniture','.w-filters .filter-box-content ul li','margin-bottom','10','','','.w-filters'),(894327,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-bottom','0','','','.w-filters'),(894328,'furniture','.mainBanner .title','margin-bottom','20','','','.mainBanner'),(894329,'furniture','.mainBanner .title','margin-bottom','15','5140','','.mainBanner'),(894330,'furniture','.mainBanner .topBox > .left','margin-bottom','5','5131','','.mainBanner'),(894331,'furniture','.w-cart-discount-coupon .discount-box','margin-bottom','10','','','.w-cart-discount-coupon'),(894332,'furniture','.w-cart-listing .promos-info','margin-bottom','0','','','.w-cart-listing'),(894340,'furniture','.account-address-book .address_book .row-buttons a','margin-bottom','0','','','.account-address-book'),(894341,'furniture','.account-address-book .address_book h1','margin-bottom','18','','','.account-address-book'),(894342,'furniture','.account-address-book .address_book h2','margin-bottom','15','','','.account-address-book'),(894343,'furniture','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-bottom','15','','','.account-address-book'),(894344,'furniture','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-bottom','10','','','.account-address-book'),(894345,'furniture','.account-address-book .address_book_row h2 a','margin-bottom','0','','','.account-address-book'),(894346,'furniture','.account-address-book .buttonBox .info','margin-bottom','0','','','.account-address-book'),(894347,'furniture','.account-address-book .address_book_row .column','margin-bottom','12','5131','','.account-address-book'),(894348,'furniture','.account-address-book .address_book_row .column + .column','margin-bottom','12','5131','','.account-address-book'),(894349,'furniture','.account-address-book .topInfo > div','margin-bottom','12','5131','','.account-address-book'),(894350,'furniture','.account-address-book .topInfo > div + div','margin-bottom','12','5131','','.account-address-book'),(894359,'furniture','.account-order-pay .buttons','margin-bottom','20','','','.account-order-pay'),(894360,'furniture','.account-order-pay .history_info','margin-bottom','20','','','.account-order-pay'),(894361,'furniture','.account-order-pay .history_info > div','margin-bottom','12','5140','','.account-order-pay'),(894362,'furniture','.account-password-wrap .buttonedit','margin-bottom','0','','','.account-password-wrap'),(894363,'furniture','.account-password-wrap .buttons','margin-bottom','20','','','.account-password-wrap'),(894364,'furniture','.account-samples .buttonBox','margin-bottom','15','','','.account-samples'),(894365,'furniture','.account-samples .order_history_table h2','margin-bottom','8','','','.account-samples'),(894366,'furniture','.account-samples .orders-table .item','margin-bottom','10','5140','','.account-samples'),(894367,'furniture','.account-sample-info .buttons','margin-bottom','20','','','.account-sample-info'),(894368,'furniture','.account-sample-info .history_info','margin-bottom','20','','','.account-sample-info'),(894369,'furniture','.account-sample-info .history_info > div','margin-bottom','12','5140','','.account-sample-info'),(894370,'furniture','.catalog-product-wrap .pn-direction','margin-bottom','15','','','.catalog-product-wrap'),(894371,'furniture','.catalog-product-wrap .rating, .catalog-product-wrap .ratingCounts','margin-bottom','0','','','.catalog-product-wrap'),(894372,'furniture','.checkout-index-wrap .closeable-heading .heading-2','margin-bottom','0','','','.checkout-index-wrap'),(894373,'furniture','.checkout-index-wrap .dob-hide','margin-bottom','-10','','','.checkout-index-wrap'),(894374,'furniture','.checkout-index-wrap .edit-address-popup .addresses .address-item','margin-bottom','20','','','.checkout-index-wrap'),(894375,'furniture','.checkout-index-wrap .input-wrapper','margin-bottom','10','','','.checkout-index-wrap'),(894376,'furniture','.shopping-cart-index .closeable-heading .heading-2','margin-bottom','0','','','.shopping-cart-index'),(894377,'furniture','.b-form .columns','margin-bottom','10','','','.b-form'),(894378,'furniture','.b-info .info li','margin-bottom','0','','','.b-info'),(894379,'furniture','.b-info .info ul','margin-bottom','0','','','.b-info'),(894380,'furniture','.b-multi-page-checkout .multi-page-checkout .buttons','margin-bottom','0','','','.b-multi-page-checkout'),(894381,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-step','margin-bottom','5','','','.b-multi-page-checkout'),(894382,'furniture','.b-form .addresses','margin-bottom','20','','','.b-form'),(894383,'furniture','.success-page .order_totals','margin-bottom','30','','','.success-page'),(894384,'furniture','.success-page .page-success .text-1','margin-bottom','0','3','','.success-page'),(894385,'furniture','.success-page .w-order-products','margin-bottom','20','','','.success-page'),(894386,'furniture','.preFooter .w-banner .banner-image','margin-bottom','0','','','.preFooter'),(894387,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li','margin-bottom','5','','','.footer-menu'),(894388,'furniture','.lowestPricedBox .w-banner .banner-holder','margin-bottom','0','','','.lowestPricedBox'),(894389,'furniture','.lowestPricedBox .w-banner .banner-item','margin-bottom','0','','','.lowestPricedBox'),(894390,'furniture','.lowestPricedBox .w-banner .banner-item:nth-child(1)','margin-bottom','20','5131','','.lowestPricedBox'),(894391,'furniture','.lowestPricedBox .w-banner .ybg .descr','margin-bottom','15','','','.lowestPricedBox'),(894392,'furniture','.lowestPricedBox .w-banner .ybg .descr','margin-bottom','10','5145','','.lowestPricedBox'),(894393,'furniture','.lowestPricedBox .w-banner .ybg .descr','margin-bottom','5','5161','','.lowestPricedBox'),(894394,'furniture','.tripleBanner ','margin-bottom','0','','','.tripleBanner'),(894395,'furniture','.shopByCollectionBox .w-banner .banner-holder','margin-bottom','0','','','.shopByCollectionBox'),(894396,'furniture','.shopByCollectionBox .w-banner .banner-item','margin-bottom','0','','','.shopByCollectionBox'),(894397,'furniture','.shopByCollectionBox .w-banner .banner-item','margin-bottom','10','5140','','.shopByCollectionBox'),(894398,'furniture','.shopByCollectionBox .w-banner .banner-item','margin-bottom','10','5161','','.shopByCollectionBox'),(894399,'furniture','.payment-method-tf label','margin-bottom','10','','','.payment-method-tf'),(894400,'furniture','.accout-box ','margin-bottom','30','','','.accout-box'),(894401,'furniture','.accout-box select[data-type=\"vat_number\"]','margin-bottom','0','','','.accout-box'),(894402,'furniture','.w-account-customer-additional-field .field-type-checkbox','margin-bottom','10','','','.w-account-customer-additional-field'),(894403,'furniture','.w-account-customer-additional-field .field-type-text','margin-bottom','10','','','.w-account-customer-additional-field'),(894404,'furniture','.heading-4 .edit, h4 .edit','margin-left','10','4','',''),(894405,'furniture','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(894406,'furniture','.message.success','margin-left','-40','3','',''),(894407,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(894409,'furniture','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(894410,'furniture','.w-catalog-items-on-page select','margin-left','10','','','.w-catalog-items-on-page'),(894411,'furniture','.w-chat .w-chat-box','margin-left','5','','','.w-chat'),(894412,'furniture','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-left','0','','','.b-fancybox'),(894413,'furniture','.p-quick-order-index ul.token-input-list','margin-left','5','','','.p-quick-order-index'),(894414,'furniture','.p-quick-order-index .filters .clear','margin-left','15','','','.p-quick-order-index'),(894415,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','margin-left','5','','','.p-quick-order-index'),(894416,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.p-quick-order-index'),(894417,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(894421,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(894422,'furniture','.w-promotions .promo-salemaker .item','margin-left','2','','','.w-promotions'),(894423,'furniture','.w-promotions .promo-cart-discount .slave .item','margin-left','2','','','.w-promotions'),(894424,'furniture','.w-promotions .promo-cart-discount .master .item','margin-left','12','','','.w-promotions'),(894425,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','-17','3','','.b-warehouses-popup'),(894426,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','0','','','.b-warehouses-popup'),(894428,'furniture','.b-form .password-forgotten-link','margin-left','0','','','.b-form'),(894429,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(894430,'furniture','.b-messages .messages-menu ul','margin-left','0','','','.b-messages'),(894431,'furniture','.b-messages .msv_content','margin-left','0','','','.b-messages'),(894432,'furniture','.b-messages .msv_history','margin-left','0','','','.b-messages'),(894433,'furniture','.b-messages .messages-menu li','margin-left','0','','','.b-messages'),(894434,'furniture','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(894435,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-left','5','','','.b-messages'),(894436,'furniture','.w-sitemap-delivery-location > ul > li > ul','margin-left','0','','','.w-sitemap-delivery-location'),(894437,'furniture','.w-sitemap-delivery-location > ul','margin-left','0','','','.w-sitemap-delivery-location'),(894438,'furniture','.b-fancybox #fancybox-loading','margin-left','-22','','','.b-fancybox'),(894439,'furniture','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(894441,'furniture','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(894442,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(894443,'furniture','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(894444,'furniture','.w-coupons-and-vauchers-checkout .btn-remove','margin-left','-30','','','.w-coupons-and-vauchers-checkout'),(894445,'furniture','.w-checkout-bonus-points .btn-remove','margin-left','-30','','','.w-checkout-bonus-points'),(894446,'furniture','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(894447,'furniture','.w-menu-horizontal li','margin-left','0','','','.w-menu-horizontal'),(894448,'furniture','.w-filters .input-checkbox','margin-left','0','','','.w-filters'),(894449,'furniture','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(894450,'furniture','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(894451,'furniture','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(894452,'furniture','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','margin-left','7','3','','.order-summary'),(894453,'furniture','.buttons .right-buttons .btn','margin-left','10','','',''),(894454,'furniture','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(894455,'furniture','.w-top-categories .categories','margin-left','0','5131','','.w-top-categories'),(894456,'furniture','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(894457,'furniture','.w-cart-checkout-btn + .w-image','margin-left','0','','','.w-cart-checkout-btn'),(894458,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(894459,'furniture','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(894460,'furniture','.b-form .col-3 + .col-3','margin-left','3','','','.b-form'),(894461,'furniture','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(894462,'furniture','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(894463,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-left','0','','','.b-select-suggest'),(894464,'furniture','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(894465,'furniture','.w-socials > li','margin-left','10','','','.w-socials'),(894467,'furniture','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(894468,'furniture','.b-delete-account .delete-box span','margin-left','10','','','.b-delete-account'),(894469,'furniture','.w-socials > li','margin-left','10','','','.w-socials'),(894470,'furniture','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(894471,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(894472,'furniture','.w-catalog-listing-look .list','margin-left','5','','','.w-catalog-listing-look'),(894473,'furniture','.view-all .btn','margin-left','10','4','',''),(894474,'furniture','.w-socials > li','margin-left','10','','','.w-socials'),(894475,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(894476,'furniture','.w-tabs .tab-navigation','margin-left','0','','','.w-tabs'),(894477,'furniture','.w-tabs .tab-li','margin-left','0','','','.w-tabs'),(894478,'furniture','.w-socials > li','margin-left','10','','','.w-socials'),(894479,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(894480,'furniture','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(894481,'furniture','.w-cart-credit-amount .btn-remove','margin-left','-30','','','.w-cart-credit-amount'),(894482,'furniture','.heading-3 .right-text, h3 .right-text','margin-left','10','','',''),(894483,'furniture','.w-product-reviews .reviews-list','margin-left','0','','','.w-product-reviews'),(894484,'furniture','.b-products-listing .products-listing .bonus-points-price','margin-left','-20','3','','.b-products-listing'),(894486,'furniture','.w-filters .filter-ul-content','margin-left','0','','','.w-filters'),(894487,'furniture','.heading-3 .edit, h3 .edit','margin-left','10','4','',''),(894488,'furniture','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-shipping-address'),(894489,'furniture','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(894490,'furniture','.w-cart-bonus-points .btn-remove','margin-left','-30','','','.w-cart-bonus-points'),(894491,'furniture','.b-select-suggest .select2-drop-mask','margin-left','0','','','.b-select-suggest'),(894492,'furniture','.w-checkout-shipping-choice input:checked + span:before','margin-left','-5','','','.w-checkout-shipping-choice'),(894493,'furniture','.products-quick-index ul','margin-left','0','','',''),(894494,'furniture','.w-top-categories .categories h2','margin-left','0','','','.w-top-categories'),(894495,'furniture','.b-form .checkbox-style','margin-left','0','','','.b-form'),(894496,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(894497,'furniture','.b-form .addresses .address-item input[type=\"radio\"]','margin-left','0','','','.b-form'),(894498,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(894499,'furniture','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(894500,'furniture','.b-form .columns .col-2:nth-child(2n)','margin-left','0','5161','','.b-form'),(894501,'furniture','.w-product-quantity .qty_packs .price_1','margin-left','15','4','','.w-product-quantity'),(894502,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(894503,'furniture','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(894504,'furniture','.b-select-suggest .select2-container','margin-left','0','','','.b-select-suggest'),(894505,'furniture','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(894506,'furniture','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(894507,'furniture','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(894508,'furniture','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(894509,'furniture','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(894510,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(894511,'furniture','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(894512,'furniture','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(894514,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(894516,'furniture','.w-checkout-credit-amount .btn-remove','margin-left','-30','','','.w-checkout-credit-amount'),(894517,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(894518,'furniture','.b-autocomplete .ui-autocomplete','margin-left','0','','','.b-autocomplete'),(894519,'furniture','.w-top-categories .categories','margin-left','-10','5145','','.w-top-categories'),(894520,'furniture','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(894521,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(894523,'furniture','.b-select-suggest .select2-results .select2-result-label','margin-left','0','','','.b-select-suggest'),(894524,'furniture','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(894525,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(894526,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(894527,'furniture','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-billing-address'),(894528,'furniture','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(894530,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(894531,'furniture','.b-fancybox .fancybox-error','margin-left','0','','','.b-fancybox'),(894532,'furniture','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(894533,'furniture','.w-cart-compare .product .image','margin-left','0','','','.w-cart-compare'),(894534,'furniture','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(894535,'furniture','.b-bottom .confirm-popup .buttons .btn','margin-left','20','','','.b-bottom'),(894536,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(894537,'furniture','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-left','0','','','.b-switch'),(894538,'furniture','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(894539,'furniture','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(894540,'furniture','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(894541,'furniture','.w-cart-give-away .ga_attributes > div','margin-left','1','','','.w-cart-give-away'),(894542,'furniture','.w-cart-checkout-btn .or-text','margin-left','0','','','.w-cart-checkout-btn'),(894543,'furniture','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(894544,'furniture','.w-cart-give-away .ga_column','margin-left','2','','','.w-cart-give-away'),(894545,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(894546,'furniture','.w-social-links a','margin-left','5','','','.w-social-links'),(894547,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(894548,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-left','0','','','.b-select-suggest'),(894549,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-left','0','','','.b-select-suggest'),(894550,'furniture','.b-select-suggest .select2-container-multi .select2-choices','margin-left','0','','','.b-select-suggest'),(894551,'furniture','.b-select-suggest .select2-results ul.select2-result-sub','margin-left','0','','','.b-select-suggest'),(894552,'furniture','.b-select-suggest .select2-search input','margin-left','0','','','.b-select-suggest'),(894553,'furniture','.b-select-suggest .select2-search','margin-left','0','','','.b-select-suggest'),(894554,'furniture','.w-socials > li','margin-left','10','','','.w-socials'),(894557,'furniture','.w-menu-horizontal ul','margin-left','0','','','.w-menu-horizontal'),(894559,'furniture','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(894560,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.b-data-table'),(894561,'furniture','.w-catalog-b2b-add-button .add-b2b-products','margin-left','50','','','.w-catalog-b2b-add-button'),(894562,'furniture','.b-products-listing .products-listing .description ul','margin-left','0','','','.b-products-listing'),(894563,'furniture','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(894564,'furniture','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(894565,'furniture','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(894566,'furniture','.w-checkout-gdpr .privacy-row','margin-left','0','','','.w-checkout-gdpr'),(894567,'furniture','.w-checkout-gdpr .bootstrap-switch','margin-left','25','','','.w-checkout-gdpr'),(894568,'furniture','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(894569,'furniture','.w-socials > li','margin-left','10','','','.w-socials'),(894570,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(894571,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(894572,'furniture','.w-taxable label','margin-left','5','','','.w-taxable'),(894573,'furniture','.w-taxable select','margin-left','5','','','.w-taxable'),(894574,'furniture','.heading-4 .right-text, h4 .right-text','margin-left','10','','',''),(894575,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-left','0','','',''),(894576,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-left','0','','','.b-h-inline'),(894577,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(894578,'furniture','.products-quick-index ul.token-input-list','margin-left','0','','',''),(894579,'furniture','.b-form .required-message','margin-left','0','','','.b-form'),(894580,'furniture','.w-catalog-listing-look .b2b','margin-left','5','','','.w-catalog-listing-look'),(894581,'furniture','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(894582,'furniture','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(894583,'furniture','.w-cart-listing .points-redeem','margin-left','-25','3','','.w-cart-listing'),(894584,'furniture','.w-cart-listing .remove-btn','margin-left','0','5140','','.w-cart-listing'),(894585,'furniture','.w-cart-give-away .ga_column','margin-left','0','5131','','.w-cart-give-away'),(894586,'furniture','.w-cart-discount-coupon .btn-remove','margin-left','-30','','','.w-cart-discount-coupon'),(894587,'furniture','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(894589,'furniture','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-left','0','','','.b-fancybox'),(894590,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(894591,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(894592,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(894593,'furniture','.w-socials .post_item_img','margin-left','0','','','.w-socials'),(894594,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(894595,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(894596,'furniture','.w-filters .view_more','margin-left','5','4','','.w-filters'),(894597,'furniture','.products-quick-index .token-input-list','margin-left','0','','',''),(894598,'furniture','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(894601,'furniture','.w-menu-big ul','margin-left','0','','','.w-menu-big'),(894602,'furniture','.w-menu-big li','margin-left','0','','','.w-menu-big'),(894604,'furniture','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(894605,'furniture','.b-form .required-message-wrap','margin-left','0','','','.b-form'),(894606,'furniture','.b-product-images .media-popup .slick-dots','margin-left','0','','','.b-product-images'),(894607,'furniture','.b-product-images .media-popup .slick-dots li','margin-left','5','','','.b-product-images'),(894608,'furniture','.b-product-images .media-popup button.slick-prev:active','margin-left','-3','','','.b-product-images'),(894609,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(894610,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(894611,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(894612,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(894613,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(894614,'furniture','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-left','0','','','.b-menu-style'),(894615,'furniture','.b-trade-approval .steps-bar','margin-left','0','','','.b-trade-approval'),(894616,'furniture','.b-trade-approval .col-3 + .col-3','margin-left','3','','','.b-trade-approval'),(894617,'furniture','.w-account-personal-catalog .list-switcher','margin-left','0','','','.w-account-personal-catalog'),(894618,'furniture','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-left','0','','','.w-catalog-additional-images'),(894619,'furniture','.w-delivery-day .left-count','margin-left','2','','','.w-delivery-day'),(894620,'furniture','.w-delivery-day .left-text-right','margin-left','2','','','.w-delivery-day'),(894621,'furniture','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-left','0','','','.b-cookie-notice'),(894622,'furniture','.b-slick .slick-list','margin-left','0','','','.b-slick'),(894623,'furniture','.b-slick .slick-track','margin-left','auto','','','.b-slick'),(894624,'furniture','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-left','-20','','','.b-slick'),(894625,'furniture','.LeftCategories .w-menu-simple ul','margin-left','0','','','.LeftCategories'),(894626,'furniture','.w-breadcrumb .breadcrumb-li','margin-left','0','','','.w-breadcrumb'),(894627,'furniture','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(894628,'furniture','.w-quote .image','margin-left','-90','','','.w-quote'),(894629,'furniture','.w-quote .multicart .name','margin-left','-10','','','.w-quote'),(894630,'furniture','.b-quantity .qty-box input','margin-left','3','','','.b-quantity'),(894631,'furniture','.w-product-sale-ends .left-count','margin-left','2','','','.w-product-sale-ends'),(894632,'furniture','.w-product-sale-ends .left-text-right','margin-left','2','','','.w-product-sale-ends'),(894633,'furniture','h1, .heading-1','margin-left','-100','3','',''),(894634,'furniture','.w-product-quantity .qty-input input[type=\'text\']','margin-left','5','','','.w-product-quantity'),(894635,'furniture','.w-compare .image','margin-left','-80','','','.w-compare'),(894636,'furniture','.w-files-catalog-widgets-files-list .file','margin-left','-20','3','','.w-files-catalog-widgets-files-list'),(894637,'furniture','.w-files-catalog-widgets-files-list .files','margin-left','10','','','.w-files-catalog-widgets-files-list'),(894638,'furniture','.w-sample .image','margin-left','-90','','','.w-sample'),(894639,'furniture','.w-sample .multicart .name','margin-left','-10','','','.w-sample'),(894640,'furniture','.w-cart-sub-total ','margin-left','0','','','.w-cart-sub-total'),(894641,'furniture','.shipping-ico .heading-3','margin-left','0','','','.shipping-ico'),(894642,'furniture','.order-summary .heading-2','margin-left','0','','','.order-summary'),(894643,'furniture','.w-cart-gift-certificate .heading-4','margin-left','0','','','.w-cart-gift-certificate'),(894644,'furniture','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(894645,'furniture','.w-cart-order-reference .input-apple button','margin-left','10','','','.w-cart-order-reference'),(894646,'furniture','.w-cart-gift-certificate .btn','margin-left','10','','','.w-cart-gift-certificate'),(894647,'furniture','.heading-2','margin-left','-100','3','',''),(894648,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-left','0','','','.b-products-listing'),(894649,'furniture','.b-pagination .pagination .next-pages','margin-left','5','','','.b-pagination'),(894650,'furniture','.b-pagination .pagination .page-number','margin-left','5','','','.b-pagination'),(894651,'furniture','.b-pagination .pagination .prev-pages','margin-left','5','','','.b-pagination'),(894652,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','margin-left','5','','','.b-pagination'),(894653,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','margin-left','5','','','.b-pagination'),(894654,'furniture','.b-pagination .pagination span','margin-left','5','2','','.b-pagination'),(894655,'furniture','.b-pagination ul.pagination','margin-left','0','','','.b-pagination'),(894656,'furniture','.w-product-multi-inventory .select-box:nth-child(2n)','margin-left','4','','','.w-product-multi-inventory'),(894657,'furniture','.w-product-properties-filters-widgets-chosen-filters .item','margin-left','0','','','.w-product-properties-filters-widgets-chosen-filters'),(894658,'furniture','.w-product-properties-filters-widgets-chosen-filters .remove','margin-left','5','','','.w-product-properties-filters-widgets-chosen-filters'),(894659,'furniture','.p-quote-checkout-index .order-summary .heading-2','margin-left','-100','3','','.p-quote-checkout-index'),(894660,'furniture','.p-sample-checkout-index .order-summary .heading-2','margin-left','-100','3','','.p-sample-checkout-index'),(894661,'furniture','.w-account-personal-catalog .list-row-action ul','margin-left','-1','','','.w-account-personal-catalog'),(894662,'furniture','.w-account-personal-catalog .list-row-action li','margin-left','0','','','.w-account-personal-catalog'),(894663,'furniture','.w-account-personal-catalog .buy-box a + a','margin-left','10','5131','','.w-account-personal-catalog'),(894664,'furniture','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(894665,'furniture','.w-product-properties .property-ul','margin-left','0','','','.w-product-properties'),(894666,'furniture','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(894667,'furniture','.b-products-listing .mix-attributes .mult-qty-input .qty-box > input','margin-left','3','','','.b-products-listing'),(894668,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list'),(894669,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list-block'),(894670,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(894671,'furniture','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(894672,'furniture','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(894673,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin-left','0','5131','','.w-delivery-location-top-location-list'),(894674,'furniture','.w-delivery-location-featured-list .deliveryList ul','margin-left','0','','','.w-delivery-location-featured-list'),(894675,'furniture','.w-sale-category .left-count','margin-left','2','','','.w-sale-category'),(894676,'furniture','.w-sale-category .left-text-right','margin-left','2','','','.w-sale-category'),(894677,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(894678,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(894679,'furniture','.w-delivery-location-list-by-page .description ul','margin-left','0','','','.w-delivery-location-list-by-page'),(894680,'furniture','.w-delivery-location-list-by-page .item','margin-left','1','','','.w-delivery-location-list-by-page'),(894681,'furniture','.w-delivery-location-list-by-page .item','margin-left','0','5161','','.w-delivery-location-list-by-page'),(894682,'furniture','.w-delivery-location-cross-pages .description ul','margin-left','0','','','.w-delivery-location-cross-pages'),(894683,'furniture','.w-delivery-location-cross-pages .item','margin-left','1','','','.w-delivery-location-cross-pages'),(894684,'furniture','.w-delivery-location-cross-pages .item','margin-left','0','5161','','.w-delivery-location-cross-pages'),(894685,'furniture','.w-catalog-delivery-locations .item','margin-left','1','','','.w-catalog-delivery-locations'),(894686,'furniture','.w-catalog-delivery-locations .description ul','margin-left','0','','','.w-catalog-delivery-locations'),(894687,'furniture','.w-catalog-delivery-locations .item','margin-left','0','5131','','.w-catalog-delivery-locations'),(894688,'furniture','.w-product-designer-designer .prodDesignerType label','margin-left','10','','','.w-product-designer-designer'),(894689,'furniture','.w-press-reviews-widgets-press-reviews .date','margin-left','0','5131','','.w-press-reviews-widgets-press-reviews'),(894690,'furniture','.w-press-reviews-widgets-press-reviews-list .image','margin-left','0','','','.w-press-reviews-widgets-press-reviews-list'),(894691,'furniture','.w-press-reviews-widgets-press-reviews-list .item','margin-left','0','','','.w-press-reviews-widgets-press-reviews-list'),(894692,'furniture','.w-support-system-filter .filter_cats','margin-left','0','','','.w-support-system-filter'),(894693,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','margin-left','2','','','.w-rma-returns-history'),(894694,'furniture','.w-rma-returns-history .filterMessages','margin-left','-3','','','.w-rma-returns-history'),(894695,'furniture','.w-rma-returns-history .linkButton','margin-left','5','4','','.w-rma-returns-history'),(894696,'furniture','.w-rma-returns-history .column:last-child .title','margin-left','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(894697,'furniture','.w-product-designer-designer .productDesignerBox ul','margin-left','0','','','.w-product-designer-designer'),(894698,'furniture','.w-product-configurator .pc-item','margin-left','0','','','.w-product-configurator'),(894699,'furniture','.b-products-listing .promos-info .promo-name','margin-left','-30','','','.b-products-listing'),(894700,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-list'),(894701,'furniture','.w-multi-cart-save-cart button','margin-left','20','','','.w-multi-cart-save-cart'),(894702,'furniture','.w-predefined-promotion .promo-cart-discount .master .item','margin-left','12','','','.w-predefined-promotion'),(894703,'furniture','.w-predefined-promotion .promo-cart-discount .slave .item','margin-left','2','','','.w-predefined-promotion'),(894704,'furniture','.w-predefined-promotion .promo-salemaker .item','margin-left','2','','','.w-predefined-promotion'),(894705,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-left','0','','','.w-filters'),(894706,'furniture','.w-cart-discount-coupon .title','margin-left','10','4','','.w-cart-discount-coupon'),(894707,'furniture','.w-cart-checkout-btn .with-card','margin-left','15','4','','.w-cart-checkout-btn'),(894708,'furniture','.w-product-quantity-discounts .item:nth-child(even)','margin-left','2','','','.w-product-quantity-discounts'),(894715,'furniture','.account-address-book .address_book .row-buttons a','margin-left','0','','','.account-address-book'),(894716,'furniture','.account-address-book .address_book h1','margin-left','0','','','.account-address-book'),(894717,'furniture','.account-address-book .address_book h2','margin-left','0','','','.account-address-book'),(894718,'furniture','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-left','2','','','.account-address-book'),(894719,'furniture','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-left','0','','','.account-address-book'),(894720,'furniture','.account-address-book .address_book_row h2 a','margin-left','15','','','.account-address-book'),(894721,'furniture','.account-address-book .buttonBox .info','margin-left','0','','','.account-address-book'),(894722,'furniture','.account-address-book .address_book_row .column','margin-left','0','5131','','.account-address-book'),(894723,'furniture','.account-address-book .address_book_row .column + .column','margin-left','0','5131','','.account-address-book'),(894724,'furniture','.account-address-book .topInfo > div','margin-left','0','5131','','.account-address-book'),(894725,'furniture','.account-address-book .topInfo > div + div','margin-left','0','5131','','.account-address-book'),(894731,'furniture','.account-order-pay .buttons','margin-left','0','','','.account-order-pay'),(894732,'furniture','.account-order-pay .history_info','margin-left','0','','','.account-order-pay'),(894733,'furniture','.account-order-pay .history_info > div','margin-left','0','5140','','.account-order-pay'),(894734,'furniture','.account-password-wrap .buttonedit','margin-left','0','','','.account-password-wrap'),(894735,'furniture','.account-samples .buttonBox','margin-left','0','','','.account-samples'),(894736,'furniture','.account-samples .order_history_table h2','margin-left','0','','','.account-samples'),(894737,'furniture','.account-sample-info .buttons','margin-left','0','','','.account-sample-info'),(894738,'furniture','.account-sample-info .history_info','margin-left','0','','','.account-sample-info'),(894739,'furniture','.account-sample-info .history_info > div','margin-left','0','5140','','.account-sample-info'),(894740,'furniture','.checkout-index-wrap .order-summary .heading-2','margin-left','-100','3','','.checkout-index-wrap'),(894741,'furniture','.shopping-cart-index .closeable-heading .heading-2','margin-left','0','','','.shopping-cart-index'),(894742,'furniture','.b-info .info','margin-left','-40','3','','.b-info'),(894743,'furniture','.b-info .info li','margin-left','0','','','.b-info'),(894744,'furniture','.b-info .info ul','margin-left','0','','','.b-info'),(894745,'furniture','.b-multi-page-checkout .multi-page-checkout .buttons','margin-left','0','','','.b-multi-page-checkout'),(894746,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','margin-left','15','4','','.b-multi-page-checkout'),(894747,'furniture','.success-page .page-success .text-1','margin-left','-50','3','','.success-page'),(894748,'furniture','.preFooter .w-banner .banner-image','margin-left','2','','','.preFooter'),(894749,'furniture','.menu-header .menu-style[data-style=\"1\"] .goto-button a','margin-left','10','4','','.menu-header'),(894750,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > .parent > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','margin-left','5','4','','.menu-header'),(894751,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li','margin-left','-18','3','','.footer-menu'),(894752,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li + li','margin-left','20','5198','','.footer-menu'),(894753,'furniture','.lowestPricedBox .w-banner .banner-holder','margin-left','-15','','','.lowestPricedBox'),(894754,'furniture','.lowestPricedBox .w-banner .banner-item','margin-left','15','','','.lowestPricedBox'),(894755,'furniture','.lowestPricedBox .w-banner .banner-item','margin-left','0','5131','','.lowestPricedBox'),(894756,'furniture','.lowestPricedBox .w-banner .ybg .descr','margin-left','-5','','','.lowestPricedBox'),(894757,'furniture','.tripleBanner ','margin-left','-15','','','.tripleBanner'),(894758,'furniture','.shopByCollectionBox .w-banner .banner-holder','margin-left','-15','','','.shopByCollectionBox'),(894759,'furniture','.shopByCollectionBox .w-banner .banner-item','margin-left','15','','','.shopByCollectionBox'),(894760,'furniture','.shopByCollectionBox .w-banner .banner-item','margin-left','10','5140','','.shopByCollectionBox'),(894761,'furniture','.shopByCollectionBox .w-banner .banner-item','margin-left','10','5161','','.shopByCollectionBox'),(894762,'furniture','.accout-box select[data-type=\"vat_number\"]','margin-left','0','','','.accout-box'),(894763,'furniture','.w-catalog-paging .next','margin-left','2','','','.w-catalog-paging'),(894764,'furniture','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(894765,'furniture','.w-checkout-billing-address .btn-cancel','margin-right','20','','','.w-checkout-billing-address'),(894766,'furniture','.w-catalog-items-on-page select','margin-right','10','','','.w-catalog-items-on-page'),(894767,'furniture','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-right','0','','','.b-fancybox'),(894768,'furniture','.p-quick-order-index ul.token-input-list','margin-right','30','','','.p-quick-order-index'),(894769,'furniture','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(894770,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(894774,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(894775,'furniture','.w-promotions .prom-multi-discount > .heading','margin-right','5','3','','.w-promotions'),(894776,'furniture','.w-promotions .nextdiscount .heading','margin-right','10','3','','.w-promotions'),(894777,'furniture','.w-promotions .icon','margin-right','15','','','.w-promotions'),(894778,'furniture','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','margin-right','5','3','','.w-promotions'),(894779,'furniture','.w-promotions .promo-salemaker .item','margin-right','2','','','.w-promotions'),(894780,'furniture','.w-promotions .promo-cart-discount .slave .item','margin-right','2','','','.w-promotions'),(894781,'furniture','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','margin-right','5','3','','.w-promotions'),(894782,'furniture','.w-promotions .promo-cart-discount .master .item','margin-right','12','','','.w-promotions'),(894783,'furniture','.b-warehouses-popup .warehouses-popup-link','margin-right','5','3','','.b-warehouses-popup'),(894784,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-right','20','','','.b-warehouses-popup'),(894785,'furniture','.w-checkout-create-account .account-benefits strong','margin-right','5','3','','.w-checkout-create-account'),(894787,'furniture','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-right','0','','','.b-fancybox'),(894788,'furniture','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(894789,'furniture','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(894790,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(894791,'furniture','.b-messages .messages-menu ul','margin-right','0','','','.b-messages'),(894792,'furniture','.b-messages .messBtnMenuDelete','margin-right','8','3','','.b-messages'),(894793,'furniture','.b-messages .messBtnMenuUnread','margin-right','8','3','','.b-messages'),(894794,'furniture','.b-messages .msv_content','margin-right','0','','','.b-messages'),(894795,'furniture','.b-messages .msv_history','margin-right','0','','','.b-messages'),(894796,'furniture','.b-messages .messBtnMenuStarred','margin-right','8','3','','.b-messages'),(894797,'furniture','.b-messages .messages-menu li','margin-right','0','','','.b-messages'),(894798,'furniture','.b-messages .content_management_attach span::before','margin-right','5','','','.b-messages'),(894799,'furniture','.b-messages .content_management_attach span','margin-right','10','','','.b-messages'),(894800,'furniture','.w-tabs .tab-navigation','margin-right','0','','','.w-tabs'),(894801,'furniture','.w-sitemap-delivery-location > ul > li > ul','margin-right','0','','','.w-sitemap-delivery-location'),(894802,'furniture','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(894803,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(894804,'furniture','.w-sitemap-delivery-location > ul','margin-right','0','','','.w-sitemap-delivery-location'),(894805,'furniture','.p-payer-order-confirmation .order-ico','margin-right','10','3','','.p-payer-order-confirmation'),(894806,'furniture','.p-payer-order-confirmation .ship-ico','margin-right','10','3','','.p-payer-order-confirmation'),(894807,'furniture','.p-payer-order-confirmation .pay-ico','margin-right','10','3','','.p-payer-order-confirmation'),(894808,'furniture','.p-payer-order-confirmation .discount-ico','margin-right','10','3','','.p-payer-order-confirmation'),(894809,'furniture','.p-payer-order-confirmation .comment-ico','margin-right','10','3','','.p-payer-order-confirmation'),(894810,'furniture','.p-payer-order-pay .order-ico','margin-right','10','3','','.p-payer-order-pay'),(894811,'furniture','.p-payer-order-pay .ship-ico','margin-right','10','3','','.p-payer-order-pay'),(894812,'furniture','.p-payer-order-pay .pay-ico','margin-right','10','3','','.p-payer-order-pay'),(894813,'furniture','.p-payer-order-pay .discount-ico','margin-right','10','3','','.p-payer-order-pay'),(894814,'furniture','.p-payer-order-pay .comment-ico','margin-right','10','3','','.p-payer-order-pay'),(894815,'furniture','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(894816,'furniture','.b-delete-account .delete-box span','margin-right','10','','','.b-delete-account'),(894817,'furniture','.w-checkout-shipping-address .genders-title label','margin-right','20','','','.w-checkout-shipping-address'),(894818,'furniture','.w-checkout-shipping-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-shipping-address'),(894819,'furniture','.b-messages span.starred::before','margin-right','8','','','.b-messages'),(894820,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(894821,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(894822,'furniture','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(894823,'furniture','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(894824,'furniture','.w-menu-horizontal li','margin-right','0','','','.w-menu-horizontal'),(894825,'furniture','.w-menu-horizontal ul','margin-right','0','','','.w-menu-horizontal'),(894826,'furniture','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(894827,'furniture','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(894828,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(894829,'furniture','.buttons .left-buttons .btn','margin-right','10','','',''),(894830,'furniture','.out-stock-icon','margin-right','3','3','',''),(894832,'furniture','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(894833,'furniture','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(894834,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(894835,'furniture','.w-filters .input-checkbox:checked + .checkbox-span','margin-right','10','','','.w-filters'),(894836,'furniture','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(894837,'furniture','.w-top-categories .categories','margin-right','-10','5145','','.w-top-categories'),(894838,'furniture','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(894839,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-right','0','','','.b-select-suggest'),(894840,'furniture','.w-socials > li','margin-right','10','','','.w-socials'),(894843,'furniture','.w-socials > li','margin-right','10','','','.w-socials'),(894844,'furniture','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(894845,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(894846,'furniture','.w-checkout-shipping-address .btn-cancel','margin-right','20','','','.w-checkout-shipping-address'),(894847,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(894848,'furniture','.w-multi-cart-actions .cart-actions .dropdown-toggle','margin-right','10','3','','.w-multi-cart-actions'),(894849,'furniture','.w-tabs .tab-li','margin-right','0','','','.w-tabs'),(894850,'furniture','.w-socials > li','margin-right','10','','','.w-socials'),(894851,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(894852,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(894853,'furniture','.w-cart-listing .actions > div','margin-right','20','','','.w-cart-listing'),(894854,'furniture','.b-form .required-message-wrap','margin-right','0','','','.b-form'),(894855,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(894856,'furniture','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(894857,'furniture','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(894860,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(894861,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-right','5','','','.b-messages'),(894862,'furniture','.w-filters .filter-ul-content','margin-right','0','','','.w-filters'),(894863,'furniture','.transit-icon','margin-right','3','3','',''),(894864,'furniture','.in-stock-icon','margin-right','3','3','',''),(894865,'furniture','.savings-ico .heading-2','margin-right','10','3','','.savings-ico'),(894866,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(894867,'furniture','.b-select-suggest .select2-drop-mask','margin-right','0','','','.b-select-suggest'),(894868,'furniture','.js-stock-icon','margin-right','3','3','',''),(894869,'furniture','.b-form .addresses .address-item input[type=\"radio\"]','margin-right','5','','','.b-form'),(894870,'furniture','.products-quick-index ul','margin-right','0','','',''),(894871,'furniture','.b-fancybox .fancybox-title-float-wrap .child','margin-right','-100','','','.b-fancybox'),(894872,'furniture','.w-top-categories .categories h2','margin-right','0','','','.w-top-categories'),(894873,'furniture','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(894874,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(894875,'furniture','.b-form .col-gender label','margin-right','20','','','.b-form'),(894876,'furniture','.w-socials .post_item_img','margin-right','10','','','.w-socials'),(894877,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(894878,'furniture','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(894879,'furniture','.w-product-quantity .qty_packs .price_1','margin-right','25','4','','.w-product-quantity'),(894880,'furniture','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(894881,'furniture','.b-select-suggest .select2-container.select2-allowclear .select2-choice .select2-chosen','margin-right','42','','','.b-select-suggest'),(894882,'furniture','.b-select-suggest .select2-container .select2-choice > .select2-chosen','margin-right','26','','','.b-select-suggest'),(894883,'furniture','.b-select-suggest .select2-container','margin-right','0','','','.b-select-suggest'),(894884,'furniture','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(894885,'furniture','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(894886,'furniture','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(894887,'furniture','.w-checkout-billing-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-billing-address'),(894888,'furniture','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(894889,'furniture','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(894890,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(894891,'furniture','.b-form .radio-buttons .radio-button','margin-right','30','','','.b-form'),(894892,'furniture','.b-form .checkbox-style:checked + .checkbox-span','margin-right','5','','','.b-form'),(894893,'furniture','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(894894,'furniture','.w-menu-big ul','margin-right','0','','','.w-menu-big'),(894896,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(894897,'furniture','.w-checkout-billing-address .genders-title label','margin-right','20','','','.w-checkout-billing-address'),(894898,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(894899,'furniture','.b-autocomplete .ui-autocomplete','margin-right','0','','','.b-autocomplete'),(894900,'furniture','.w-cart-checkout-btn + .w-image','margin-right','0','','','.w-cart-checkout-btn'),(894901,'furniture','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(894902,'furniture','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(894903,'furniture','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(894904,'furniture','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(894905,'furniture','.b-select-suggest .select2-results .select2-result-label','margin-right','0','','','.b-select-suggest'),(894907,'furniture','.w-menu-big li','margin-right','0','','','.w-menu-big'),(894908,'furniture','.w-socials > li','margin-right','10','','','.w-socials'),(894909,'furniture','.b-fancybox .fancybox-error','margin-right','0','','','.b-fancybox'),(894910,'furniture','.w-cart-compare .product .image','margin-right','10','','','.w-cart-compare'),(894911,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(894912,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','margin-right','5','3','','.b-form'),(894913,'furniture','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-right','0','','','.b-switch'),(894914,'furniture','.b-bottom .confirm-popup .buttons .btn','margin-right','20','','','.b-bottom'),(894915,'furniture','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(894916,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(894917,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(894918,'furniture','.w-cart-checkout-btn .or-text','margin-right','0','','','.w-cart-checkout-btn'),(894919,'furniture','.w-cart-give-away .ga_column','margin-right','2','','','.w-cart-give-away'),(894920,'furniture','.w-cart-compare .product-actions .dropdown-toggle','margin-right','8','3','','.w-cart-compare'),(894921,'furniture','.w-social-links a','margin-right','5','','','.w-social-links'),(894922,'furniture','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(894923,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-right','0','','','.b-select-suggest'),(894924,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-right','0','','','.b-select-suggest'),(894925,'furniture','.b-select-suggest .select2-container-multi .select2-choices','margin-right','0','','','.b-select-suggest'),(894926,'furniture','.b-select-suggest .select2-results ul.select2-result-sub','margin-right','0','','','.b-select-suggest'),(894927,'furniture','.b-select-suggest .select2-search input','margin-right','0','','','.b-select-suggest'),(894928,'furniture','.b-select-suggest .select2-search','margin-right','0','','','.b-select-suggest'),(894929,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(894932,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(894933,'furniture','.b-products-listing .products-listing .bonus-points-cost','margin-right','12','','','.b-products-listing'),(894936,'furniture','.w-account-addresses-list .address-fields input[type=\"radio\"]','margin-right','10','','','.w-account-addresses-list'),(894937,'furniture','.b-products-listing .products-listing .btn-buy','margin-right','10','3','','.b-products-listing'),(894938,'furniture','.b-products-listing .products-listing .description ul','margin-right','0','','','.b-products-listing'),(894939,'furniture','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(894940,'furniture','.b-products-listing .products-listing .bonus-points-price','margin-right','10','','','.b-products-listing'),(894941,'furniture','.w-checkout-gdpr .privacy-row','margin-right','0','','','.w-checkout-gdpr'),(894942,'furniture','.b-compare .compare-box-btn','margin-right','20','','','.b-compare'),(894943,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(894944,'furniture','.w-socials > li','margin-right','10','','','.w-socials'),(894945,'furniture','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(894946,'furniture','.w-product-reviews .reviews-list','margin-right','0','','','.w-product-reviews'),(894948,'furniture','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(894949,'furniture','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(894950,'furniture','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(894951,'furniture','.w-taxable label','margin-right','5','','','.w-taxable'),(894952,'furniture','.w-taxable input[type=\"checkbox\"]','margin-right','5','','','.w-taxable'),(894953,'furniture','.w-taxable select','margin-right','0','','','.w-taxable'),(894954,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-right','0','','',''),(894955,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-right','0','','','.b-h-inline'),(894956,'furniture','.b-form .checkbox-style','margin-right','0','','','.b-form'),(894957,'furniture','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(894958,'furniture','.w-filters .open','margin-right','10','3','','.w-filters'),(894959,'furniture','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(894960,'furniture','.products-quick-index .token-input-list','margin-right','0','','',''),(894961,'furniture','.w-cart-give-away .ga_attributes > div','margin-right','1','','','.w-cart-give-away'),(894962,'furniture','.w-product-cross-sell .buy-all-checker','margin-right','5','','','.w-product-cross-sell'),(894963,'furniture','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(894964,'furniture','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','margin-right','10','3','','.w-cart-listing'),(894965,'furniture','.w-cart-give-away .ga_img','margin-right','2','','','.w-cart-give-away'),(894966,'furniture','.w-cart-give-away .ga_column','margin-right','0','5131','','.w-cart-give-away'),(894968,'furniture','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(894969,'furniture','.w-top-categories .categories','margin-right','0','5131','','.w-top-categories'),(894970,'furniture','.w-socials > li','margin-right','10','','','.w-socials'),(894971,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(894972,'furniture','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(894973,'furniture','.b-form .password-forgotten-link','margin-right','0','','','.b-form'),(894975,'furniture','.w-catalog-listing-look .listing-look-title','margin-right','10','','','.w-catalog-listing-look'),(894976,'furniture','.w-filters .input-checkbox','margin-right','0','','','.w-filters'),(894977,'furniture','.products-quick-index ul.token-input-list','margin-right','0','','',''),(894978,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(894979,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span','margin-right','5','','','.b-form'),(894980,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(894984,'furniture','.b-form .required-message','margin-right','0','','','.b-form'),(894985,'furniture','.w-filters .input-checkbox:not(checked) + .checkbox-span','margin-right','10','','','.w-filters'),(894986,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(894987,'furniture','.b-product-images .media-popup .slick-dots','margin-right','0','','','.b-product-images'),(894988,'furniture','.b-product-images .media-popup .slick-dots li','margin-right','5','','','.b-product-images'),(894989,'furniture','.b-product-images .media-popup button.slick-next:active','margin-right','-3','','','.b-product-images'),(894990,'furniture','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-right','0','','','.b-menu-style'),(894991,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','margin-right','10','','','.b-menu-style-2'),(894992,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','margin-right','10','','','.b-menu-style-2'),(894993,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','margin-right','10','3','','.b-menu-style-2'),(894994,'furniture','.b-trade-approval .steps-bar','margin-right','0','','','.b-trade-approval'),(894995,'furniture','.w-account-personal-catalog .list-switcher','margin-right','0','','','.w-account-personal-catalog'),(894996,'furniture','.w-account-subscription .info-popup','margin-right','20','','','.w-account-subscription'),(894997,'furniture','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-right','0','','','.w-catalog-additional-images'),(894998,'furniture','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-right','0','','','.b-cookie-notice'),(894999,'furniture','.b-products-listing .products-listing.list-productlisting .stock','margin-right','0','','','.b-products-listing'),(895000,'furniture','.b-slick .slick-list','margin-right','0','','','.b-slick'),(895001,'furniture','.b-slick .slick-track','margin-right','auto','','','.b-slick'),(895002,'furniture','.b-products-listing .del-from-personal-catalog','margin-right','10','3','','.b-products-listing'),(895003,'furniture','.LeftCategories .w-menu-simple ul','margin-right','0','','','.LeftCategories'),(895004,'furniture','.w-breadcrumb .breadcrumb-li','margin-right','0','','','.w-breadcrumb'),(895005,'furniture','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(895006,'furniture','.w-quote .multicart .name','margin-right','-10','','','.w-quote'),(895007,'furniture','.b-quantity .qty-box input','margin-right','3','','','.b-quantity'),(895008,'furniture','h1, .heading-1','margin-right','-100','4','',''),(895009,'furniture','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','margin-right','10','3','','.w-product-buttons'),(895010,'furniture','.w-product-quantity .qty-input input[type=\'text\']','margin-right','5','','','.w-product-quantity'),(895011,'furniture','.w-compare .compare-list-buttons','margin-right','-250','','','.w-compare'),(895012,'furniture','.w-sample .multicart .name','margin-right','-10','','','.w-sample'),(895013,'furniture','.w-filters-simple .system-1','margin-right','20','','','.w-filters-simple'),(895014,'furniture','.w-cart-listing .points-earn','margin-right','12','','','.w-cart-listing'),(895015,'furniture','.w-cart-discount-coupon input[type=\"text\"]','margin-right','10','','','.w-cart-discount-coupon'),(895016,'furniture','.w-cart-sub-total ','margin-right','0','','','.w-cart-sub-total'),(895017,'furniture','.shipping-ico .heading-3','margin-right','0','','','.shipping-ico'),(895018,'furniture','.order-summary .heading-2','margin-right','0','','','.order-summary'),(895019,'furniture','.w-cart-gift-certificate .heading-4','margin-right','0','','','.w-cart-gift-certificate'),(895020,'furniture','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(895021,'furniture','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(895022,'furniture','.w-product-inventory input[type=\"radio\"]','margin-right','5','','','.w-product-inventory'),(895024,'furniture','.heading-2','margin-right','-100','4','',''),(895025,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-right','0','','','.b-products-listing'),(895026,'furniture','.b-pagination ul.pagination','margin-right','0','','','.b-pagination'),(895027,'furniture','.w-product-properties-filters-widgets-chosen-filters .item','margin-right','5','','','.w-product-properties-filters-widgets-chosen-filters'),(895028,'furniture','.p-quote-checkout-index .order-summary .heading-2','margin-right','0','3','','.p-quote-checkout-index'),(895029,'furniture','.p-quote-checkout-index .order-summary .heading-2','margin-right','-100','4','','.p-quote-checkout-index'),(895030,'furniture','.p-sample-checkout-index .order-summary .heading-2','margin-right','0','3','','.p-sample-checkout-index'),(895031,'furniture','.p-sample-checkout-index .order-summary .heading-2','margin-right','-100','4','','.p-sample-checkout-index'),(895032,'furniture','.w-account-personal-catalog .list-row-action ul','margin-right','-1','','','.w-account-personal-catalog'),(895033,'furniture','.w-account-personal-catalog .list-row-action li','margin-right','0','','','.w-account-personal-catalog'),(895034,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','margin-right','20','','','.w-account-personal-catalog'),(895035,'furniture','.w-product-collection .right-area .btn','margin-right','10','3','','.w-product-collection'),(895036,'furniture','.w-product-collection .right-area .btn-2','margin-right','10','3','','.w-product-collection'),(895037,'furniture','.w-product-properties .property-ul','margin-right','0','','','.w-product-properties'),(895038,'furniture','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(895039,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','margin-right','30','','','.w-questionnaire-widgets-questionnaire'),(895040,'furniture','.b-products-listing .mix-attributes .mult-qty-input .qty-box > input','margin-right','3','','','.b-products-listing'),(895041,'furniture','.b-products-listing .products-listing .attribute-color','margin-right','4','','','.b-products-listing'),(895042,'furniture','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','margin-right','10','3','','.w-product-custom-bundle'),(895043,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list'),(895044,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list-block'),(895045,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(895046,'furniture','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(895047,'furniture','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(895048,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin-right','0','5131','','.w-delivery-location-top-location-list'),(895049,'furniture','.w-delivery-location-featured-list .deliveryList ul','margin-right','0','','','.w-delivery-location-featured-list'),(895050,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(895051,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(895052,'furniture','.w-delivery-location-list-by-page .description ul','margin-right','0','','','.w-delivery-location-list-by-page'),(895053,'furniture','.w-delivery-location-list-by-page .item','margin-right','1','','','.w-delivery-location-list-by-page'),(895054,'furniture','.w-delivery-location-list-by-page .item','margin-right','0','5161','','.w-delivery-location-list-by-page'),(895055,'furniture','.w-delivery-location-cross-pages .description ul','margin-right','0','','','.w-delivery-location-cross-pages'),(895056,'furniture','.w-delivery-location-cross-pages .item','margin-right','1','','','.w-delivery-location-cross-pages'),(895057,'furniture','.w-delivery-location-cross-pages .item','margin-right','0','5161','','.w-delivery-location-cross-pages'),(895058,'furniture','.w-catalog-delivery-locations .item','margin-right','1','','','.w-catalog-delivery-locations'),(895059,'furniture','.w-catalog-delivery-locations .description ul','margin-right','0','','','.w-catalog-delivery-locations'),(895060,'furniture','.w-catalog-delivery-locations .item','margin-right','0','5131','','.w-catalog-delivery-locations'),(895061,'furniture','.w-product-bonus-points .bonus-points-cost','margin-right','12','','','.w-product-bonus-points'),(895062,'furniture','.w-product-designer-designer .prodDesignerType label','margin-right','10','','','.w-product-designer-designer'),(895063,'furniture','.w-press-reviews-widgets-press-reviews .date','margin-right','0','5131','','.w-press-reviews-widgets-press-reviews'),(895064,'furniture','.w-press-reviews-widgets-press-reviews-list .image','margin-right','0','','','.w-press-reviews-widgets-press-reviews-list'),(895065,'furniture','.w-press-reviews-widgets-press-reviews-list .item','margin-right','0','','','.w-press-reviews-widgets-press-reviews-list'),(895066,'furniture','.w-press-reviews-widgets-press-reviews-list .review-box > *','margin-right','30','','','.w-press-reviews-widgets-press-reviews-list'),(895067,'furniture','.w-press-reviews-widgets-press-reviews-list .review-box > *','margin-right','0','5161','','.w-press-reviews-widgets-press-reviews-list'),(895068,'furniture','.w-gift-wrap-message-checkout .max-counter, .w-gift-wrap-message-checkout .max-words','margin-right','20','','','.w-gift-wrap-message-checkout'),(895069,'furniture','.w-gift-wrap-message-checkout .text','margin-right','20','','','.w-gift-wrap-message-checkout'),(895070,'furniture','.w-support-system-filter .filter_cats','margin-right','0','','','.w-support-system-filter'),(895071,'furniture','.w-support-system-listing .product_icon','margin-right','20','','','.w-support-system-listing'),(895072,'furniture','.w-rma-returns-history .filterMessages','margin-right','-3','','','.w-rma-returns-history'),(895073,'furniture','.w-rma-returns-history label[for=\'sCreateFrom\']','margin-right','5','','','.w-rma-returns-history'),(895074,'furniture','.w-rma-returns-history .column:last-child .title','margin-right','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(895075,'furniture','.w-show-inactive-show-inactive .out_stock_label','margin-right','10','','','.w-show-inactive-show-inactive'),(895076,'furniture','.w-product-designer-button label > input[type=\"checkbox\"]','margin-right','7','','','.w-product-designer-button'),(895077,'furniture','.w-product-designer-designer .productDesignerBox ul','margin-right','0','','','.w-product-designer-designer'),(895078,'furniture','.w-product-configurator .pc-item','margin-right','0','','','.w-product-configurator'),(895079,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-list'),(895080,'furniture','.w-predefined-promotion .icon','margin-right','15','','','.w-predefined-promotion'),(895081,'furniture','.w-predefined-promotion .nextdiscount .heading','margin-right','10','3','','.w-predefined-promotion'),(895082,'furniture','.w-predefined-promotion .prom-multi-discount > .heading','margin-right','5','3','','.w-predefined-promotion'),(895083,'furniture','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','margin-right','5','3','','.w-predefined-promotion'),(895084,'furniture','.w-predefined-promotion .promo-cart-discount .master .item','margin-right','12','','','.w-predefined-promotion'),(895085,'furniture','.w-predefined-promotion .promo-cart-discount .slave .item','margin-right','2','','','.w-predefined-promotion'),(895086,'furniture','.w-predefined-promotion .promo-salemaker .item','margin-right','2','','','.w-predefined-promotion'),(895087,'furniture','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','margin-right','5','3','','.w-predefined-promotion'),(895088,'furniture','.w-supplier-purchase-supplier-products .select_item','margin-right','20','','','.w-supplier-purchase-supplier-products'),(895089,'furniture','.w-supplier-purchase-supplier-products .name','margin-right','20','','','.w-supplier-purchase-supplier-products'),(895090,'furniture','.w-supplier-purchase-supplier-products .col-full','margin-right','20','','','.w-supplier-purchase-supplier-products'),(895091,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-right','0','','','.w-filters'),(895092,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','margin-right','10','','','.w-filters'),(895093,'furniture','.mainBanner .bottomBox .elf','margin-right','20','','','.mainBanner'),(895094,'furniture','.mainBanner .topBox > .left','margin-right','30','','','.mainBanner'),(895095,'furniture','.mainBanner .topBox > .right','margin-right','30','3','','.mainBanner'),(895096,'furniture','.mainBanner .topBox > .left','margin-right','15','5145','','.mainBanner'),(895097,'furniture','.mainBanner .topBox > .right','margin-right','10','5145,3','','.mainBanner'),(895098,'furniture','.mainBanner .topBox > .right','margin-right','5','5131,3','','.mainBanner'),(895099,'furniture','.w-promotions-widgets-promotion-icons-desc .promo-icon','margin-right','7','','','.w-promotions-widgets-promotion-icons-desc'),(895100,'furniture','.w-product-quantity-discounts .item:nth-child(odd)','margin-right','2','','','.w-product-quantity-discounts'),(895107,'furniture','.account-address-book .address_book .row-buttons a','margin-right','10','','','.account-address-book'),(895108,'furniture','.account-address-book .address_book h1','margin-right','0','','','.account-address-book'),(895109,'furniture','.account-address-book .address_book h2','margin-right','0','','','.account-address-book'),(895110,'furniture','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-right','0','','','.account-address-book'),(895111,'furniture','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-right','2','','','.account-address-book'),(895112,'furniture','.account-address-book .address_book_row h2 a','margin-right','0','','','.account-address-book'),(895113,'furniture','.account-address-book .buttonBox .info','margin-right','25','','','.account-address-book'),(895114,'furniture','.account-address-book .address_book_row .column','margin-right','0','5131','','.account-address-book'),(895115,'furniture','.account-address-book .address_book_row .column + .column','margin-right','0','5131','','.account-address-book'),(895116,'furniture','.account-address-book .topInfo > div','margin-right','0','5131','','.account-address-book'),(895117,'furniture','.account-address-book .topInfo > div + div','margin-right','0','5131','','.account-address-book'),(895123,'furniture','.account-order-pay .buttons','margin-right','0','','','.account-order-pay'),(895124,'furniture','.account-order-pay .history_info','margin-right','0','','','.account-order-pay'),(895125,'furniture','.account-order-pay .history_info > div','margin-right','0','5140','','.account-order-pay'),(895126,'furniture','.account-password-wrap .buttonedit','margin-right','0','','','.account-password-wrap'),(895127,'furniture','.account-samples .buttonBox','margin-right','0','','','.account-samples'),(895128,'furniture','.account-samples .order_history_table h2','margin-right','0','','','.account-samples'),(895129,'furniture','.account-sample-info .buttons','margin-right','0','','','.account-sample-info'),(895130,'furniture','.account-sample-info .history_info','margin-right','0','','','.account-sample-info'),(895131,'furniture','.account-sample-info .history_info > div','margin-right','0','5140','','.account-sample-info'),(895132,'furniture','.checkout-index-wrap .order-ico','margin-right','10','3','','.checkout-index-wrap'),(895133,'furniture','.checkout-index-wrap .order-summary .heading-2','margin-right','0','3','','.checkout-index-wrap'),(895134,'furniture','.checkout-index-wrap .order-summary .heading-2','margin-right','-100','4','','.checkout-index-wrap'),(895135,'furniture','.checkout-index-wrap .pay-ico','margin-right','10','3','','.checkout-index-wrap'),(895136,'furniture','.checkout-index-wrap .ship-ico','margin-right','10','3','','.checkout-index-wrap'),(895137,'furniture','.checkout-order-confirmation .comment-ico','margin-right','10','3','','.checkout-order-confirmation'),(895138,'furniture','.checkout-order-confirmation .discount-ico','margin-right','10','3','','.checkout-order-confirmation'),(895139,'furniture','.checkout-order-confirmation .order-ico','margin-right','10','3','','.checkout-order-confirmation'),(895140,'furniture','.checkout-order-confirmation .ship-ico','margin-right','10','3','','.checkout-order-confirmation'),(895141,'furniture','.shopping-cart-index .closeable-heading .heading-2','margin-right','0','','','.shopping-cart-index'),(895142,'furniture','.b-info .info li','margin-right','0','','','.b-info'),(895143,'furniture','.b-info .info ul','margin-right','0','','','.b-info'),(895144,'furniture','.b-multi-page-checkout .multi-page-checkout .buttons','margin-right','0','','','.b-multi-page-checkout'),(895145,'furniture','.success-page .comment-ico','margin-right','10','3','','.success-page'),(895146,'furniture','.success-page .discount-ico','margin-right','10','3','','.success-page'),(895147,'furniture','.success-page .order-ico','margin-right','10','3','','.success-page'),(895148,'furniture','.success-page .page-success .text-1','margin-right','10','3','','.success-page'),(895149,'furniture','.success-page .pay-ico','margin-right','10','3','','.success-page'),(895150,'furniture','.success-page .prod-ico','margin-right','10','3','','.success-page'),(895151,'furniture','.success-page .ship-ico','margin-right','10','3','','.success-page'),(895152,'furniture','.preFooter .w-banner .banner-image','margin-right','2','','','.preFooter'),(895153,'furniture','.lowestPricedBox .w-banner .banner-holder','margin-right','-15','','','.lowestPricedBox'),(895154,'furniture','.lowestPricedBox .w-banner .banner-item','margin-right','15','','','.lowestPricedBox'),(895155,'furniture','.lowestPricedBox .w-banner .banner-item','margin-right','0','5131','','.lowestPricedBox'),(895156,'furniture','.lowestPricedBox .w-banner .ybg .descr','margin-right','-5','','','.lowestPricedBox'),(895157,'furniture','.tripleBanner ','margin-right','-15','','','.tripleBanner'),(895158,'furniture','.shopByCollectionBox .w-banner .banner-holder','margin-right','-15','','','.shopByCollectionBox'),(895159,'furniture','.shopByCollectionBox .w-banner .banner-item','margin-right','15','','','.shopByCollectionBox'),(895160,'furniture','.shopByCollectionBox .w-banner .banner-item','margin-right','10','5140','','.shopByCollectionBox'),(895161,'furniture','.shopByCollectionBox .w-banner .banner-item','margin-right','10','5161','','.shopByCollectionBox'),(895162,'furniture','.accout-box select[data-type=\"vat_number\"]','margin-right','0','','','.accout-box'),(895163,'furniture','.w-catalog-paging .prev','margin-right','5','','','.w-catalog-paging'),(895164,'furniture','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-top','0','','','.b-switch'),(895165,'furniture','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(895166,'furniture','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(895167,'furniture','.w-catalog-items-on-page select','margin-top','0','','','.w-catalog-items-on-page'),(895168,'furniture','.p-quick-order-index ul.token-input-list','margin-top','0','','','.p-quick-order-index'),(895169,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(895173,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(895174,'furniture','.w-promotions .promo-salemaker .item','margin-top','2','','','.w-promotions'),(895175,'furniture','.w-promotions .promo-salemaker .content','margin-top','-18','','','.w-promotions'),(895176,'furniture','.w-promotions .promo-cart-discount .slave .item','margin-top','2','','','.w-promotions'),(895177,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-top','0','','','.b-warehouses-popup'),(895179,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(895180,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(895181,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(895182,'furniture','.b-messages .messages-menu ul','margin-top','0','','','.b-messages'),(895183,'furniture','.b-messages .msv_content','margin-top','15','','','.b-messages'),(895184,'furniture','.b-messages .msv_btn','margin-top','10','','','.b-messages'),(895185,'furniture','.b-messages .msv_history','margin-top','15','','','.b-messages'),(895186,'furniture','.b-messages .messages-menu li','margin-top','0','','','.b-messages'),(895187,'furniture','.w-sitemap-delivery-location > ul > li > ul','margin-top','0','','','.w-sitemap-delivery-location'),(895188,'furniture','.w-tabs .tab-navigation','margin-top','0','','','.w-tabs'),(895189,'furniture','.w-socials > li','margin-top','10','','','.w-socials'),(895190,'furniture','.b-form .g-recaptcha','margin-top','10','','','.b-form'),(895191,'furniture','.w-sitemap-delivery-location > ul','margin-top','0','','','.w-sitemap-delivery-location'),(895192,'furniture','.p-payer-order-confirmation .dob-hide','margin-top','20','','','.p-payer-order-confirmation'),(895193,'furniture','.p-payer-order-pay .dob-hide','margin-top','20','','','.p-payer-order-pay'),(895194,'furniture','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(895195,'furniture','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(895196,'furniture','.b-fancybox #fancybox-loading','margin-top','-22','','','.b-fancybox'),(895197,'furniture','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(895198,'furniture','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(895199,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-template .btn','margin-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(895200,'furniture','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(895201,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(895202,'furniture','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(895203,'furniture','.w-menu-horizontal ul','margin-top','0','','','.w-menu-horizontal'),(895204,'furniture','.w-menu-horizontal li','margin-top','0','','','.w-menu-horizontal'),(895205,'furniture','.b-form .password-forgotten-link','margin-top','0','','','.b-form'),(895206,'furniture','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(895207,'furniture','.b-form .privacy-row','margin-top','10','','','.b-form'),(895208,'furniture','.b-fancybox .fancybox-title-outside-wrap','margin-top','10','','','.b-fancybox'),(895209,'furniture','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(895210,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(895211,'furniture','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(895212,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(895214,'furniture','.w-socials > li','margin-top','10','','','.w-socials'),(895215,'furniture','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(895217,'furniture','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(895218,'furniture','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(895219,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(895220,'furniture','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(895221,'furniture','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-top','0','','','.b-fancybox'),(895222,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-top','0','','','.b-select-suggest'),(895223,'furniture','.w-socials > li','margin-top','10','','','.w-socials'),(895225,'furniture','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(895226,'furniture','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(895227,'furniture','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(895228,'furniture','.w-cart-give-away .ga_attributes > div','margin-top','1','','','.w-cart-give-away'),(895229,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(895230,'furniture','.w-multi-cart-cart-switcher .cart-label','margin-top','-20','','','.w-multi-cart-cart-switcher'),(895231,'furniture','.w-tabs .tab-li','margin-top','0','','','.w-tabs'),(895232,'furniture','.w-socials > li','margin-top','10','','','.w-socials'),(895233,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(895234,'furniture','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(895235,'furniture','.b-form .required-message-wrap','margin-top','0','','','.b-form'),(895236,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(895237,'furniture','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(895238,'furniture','.b-delete-account .delete-box span','margin-top','10','','','.b-delete-account'),(895239,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-top','0','','','.b-messages'),(895240,'furniture','.w-filters .filter-ul-content','margin-top','0','','','.w-filters'),(895241,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(895242,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(895243,'furniture','.p-quick-order-index .dataTables_info','margin-top','5','','','.p-quick-order-index'),(895244,'furniture','.b-select-suggest .select2-drop-mask','margin-top','0','','','.b-select-suggest'),(895245,'furniture','.products-quick-index ul','margin-top','0','','',''),(895246,'furniture','.w-top-categories .categories h2','margin-top','0','','','.w-top-categories'),(895247,'furniture','.b-autocomplete .ui-autocomplete','margin-top','0','','','.b-autocomplete'),(895248,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(895249,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(895250,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(895251,'furniture','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(895252,'furniture','.w-product-quantity .qty_packs .price_1','margin-top','0','4','','.w-product-quantity'),(895253,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(895254,'furniture','.b-select-suggest .select2-container','margin-top','0','','','.b-select-suggest'),(895255,'furniture','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(895256,'furniture','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(895257,'furniture','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(895258,'furniture','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(895259,'furniture','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(895260,'furniture','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(895261,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(895262,'furniture','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(895264,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(895265,'furniture','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-top','0','','','.b-fancybox'),(895266,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(895267,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(895268,'furniture','.w-top-categories .categories','margin-top','0','5131','','.w-top-categories'),(895269,'furniture','.w-cart-checkout-btn .or-text','margin-top','-5','','','.w-cart-checkout-btn'),(895270,'furniture','.w-promotions .promo-cart-discount .master .item','margin-top','12','','','.w-promotions'),(895271,'furniture','.w-promotions .promo-cart-discount .master .image','margin-top','-16','','','.w-promotions'),(895272,'furniture','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(895273,'furniture','.b-select-suggest .select2-results .select2-result-label','margin-top','0','','','.b-select-suggest'),(895274,'furniture','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(895275,'furniture','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(895276,'furniture','.b-form .required-message','margin-top','0','','','.b-form'),(895278,'furniture','.w-menu-big ul','margin-top','0','','','.w-menu-big'),(895279,'furniture','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(895280,'furniture','.b-fancybox .fancybox-error','margin-top','0','','','.b-fancybox'),(895281,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','margin-top','0','','','.b-switch'),(895282,'furniture','.w-cart-compare .product .image','margin-top','0','','','.w-cart-compare'),(895283,'furniture','.b-fancybox .fancybox-nav span','margin-top','-18','','','.b-fancybox'),(895284,'furniture','.w-product-customers-activity .buttons','margin-top','10','','','.w-product-customers-activity'),(895285,'furniture','.b-bottom .confirm-popup .buttons .btn','margin-top','0','','','.b-bottom'),(895286,'furniture','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(895287,'furniture','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(895288,'furniture','.w-menu-big li','margin-top','0','','','.w-menu-big'),(895289,'furniture','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(895290,'furniture','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(895291,'furniture','.w-cart-checkout-btn + .w-image','margin-top','0','','','.w-cart-checkout-btn'),(895292,'furniture','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(895293,'furniture','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(895294,'furniture','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(895295,'furniture','.w-social-links a','margin-top','0','','','.w-social-links'),(895296,'furniture','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(895297,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-top','1','','','.b-select-suggest'),(895298,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-top','0','','','.b-select-suggest'),(895299,'furniture','.b-select-suggest .select2-container-multi .select2-choices','margin-top','0','','','.b-select-suggest'),(895300,'furniture','.b-select-suggest .select2-results ul.select2-result-sub','margin-top','0','','','.b-select-suggest'),(895301,'furniture','.w-checkout-shipping-address .change-ab','margin-top','5','','','.w-checkout-shipping-address'),(895302,'furniture','.w-checkout-contact-information .contact-info-buttons','margin-top','5','','','.w-checkout-contact-information'),(895303,'furniture','.b-select-suggest .select2-drop.select2-drop-above .select2-search input','margin-top','4','','','.b-select-suggest'),(895304,'furniture','.b-select-suggest .select2-search input','margin-top','0','','','.b-select-suggest'),(895305,'furniture','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(895306,'furniture','.b-select-suggest .select2-search','margin-top','0','','','.b-select-suggest'),(895307,'furniture','.b-select-suggest .select2-drop.select2-drop-above','margin-top','1','','','.b-select-suggest'),(895308,'furniture','.b-select-suggest .select2-drop','margin-top','-1','','','.b-select-suggest'),(895309,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(895311,'furniture','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(895314,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(895315,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(895316,'furniture','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(895317,'furniture','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(895320,'furniture','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(895321,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(895322,'furniture','.b-products-listing .products-listing .description ul','margin-top','0','','','.b-products-listing'),(895323,'furniture','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(895324,'furniture','.w-checkout-gdpr .privacy-row','margin-top','0','','','.w-checkout-gdpr'),(895325,'furniture','.w-checkout-gdpr .bootstrap-switch','margin-top','0','','','.w-checkout-gdpr'),(895326,'furniture','.b-form .checkbox-style','margin-top','0','','','.b-form'),(895327,'furniture','.b-form .wedding-form .heading-2','margin-top','10','','','.b-form'),(895328,'furniture','.w-product-reviews .reviews-list','margin-top','10','','','.w-product-reviews'),(895329,'furniture','.w-taxable label','margin-top','0','','','.w-taxable'),(895330,'furniture','.w-taxable select','margin-top','0','','','.w-taxable'),(895331,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-top','0','','',''),(895332,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-top','0','','','.b-h-inline'),(895333,'furniture','.w-communication-new-topic .files-box','margin-top','50','','','.w-communication-new-topic'),(895334,'furniture','.b-form .addresses .address-item input[type=\"radio\"]','margin-top','0','','','.b-form'),(895335,'furniture','.w-top-categories .categories','margin-top','0','5145','','.w-top-categories'),(895336,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(895337,'furniture','.products-quick-index .token-input-list','margin-top','0','','',''),(895338,'furniture','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(895339,'furniture','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(895340,'furniture','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(895341,'furniture','.w-cart-listing .points-redeem','margin-top','-2','3','','.w-cart-listing'),(895343,'furniture','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(895344,'furniture','.w-socials > li','margin-top','10','','','.w-socials'),(895345,'furniture','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(895347,'furniture','.w-filters .ui-slider','margin-top','5','','','.w-filters'),(895348,'furniture','.w-checkout-billing-address .bootstrap-switch','margin-top','-2','','','.w-checkout-billing-address'),(895349,'furniture','.w-socials .post_item_img','margin-top','0','','','.w-socials'),(895350,'furniture','.w-socials > li','margin-top','10','','','.w-socials'),(895351,'furniture','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(895352,'furniture','.w-filters .input-checkbox','margin-top','0','','','.w-filters'),(895353,'furniture','.products-quick-index ul.token-input-list','margin-top','0','','',''),(895354,'furniture','.message.success','margin-top','-8','3','',''),(895357,'furniture','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(895358,'furniture','.b-product-images .media-popup .slick-dots','margin-top','0','','','.b-product-images'),(895359,'furniture','.b-product-images .media-popup .slick-dots li','margin-top','0','','','.b-product-images'),(895360,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','margin-top','-50','','','.b-product-images'),(895361,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(895362,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-top','-44','','','.b-menu-lev_vis-click_icon'),(895363,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(895364,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(895365,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(895366,'furniture','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-top','0','','','.b-menu-style'),(895367,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','margin-top','-8','3','','.b-menu-style-2'),(895368,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','margin-top','-10','3','','.b-menu-style-2'),(895369,'furniture','.b-trade-approval .steps-bar','margin-top','0','','','.b-trade-approval'),(895370,'furniture','.w-account-personal-catalog .list-switcher','margin-top','0','','','.w-account-personal-catalog'),(895371,'furniture','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-top','0','','','.w-catalog-additional-images'),(895372,'furniture','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-top','0','','','.b-cookie-notice'),(895375,'furniture','.b-slick .slick-list','margin-top','0','','','.b-slick'),(895376,'furniture','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-top','0','','','.b-slick'),(895377,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','margin-top','-20','','','.b-slick'),(895378,'furniture','.LeftCategories .w-menu-simple ul','margin-top','0','','','.LeftCategories'),(895379,'furniture','.w-breadcrumb .breadcrumb-li','margin-top','0','','','.w-breadcrumb'),(895380,'furniture','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(895381,'furniture','.w-quote .multicart .name','margin-top','0','','','.w-quote'),(895382,'furniture','.w-sample .cart-box-link','margin-top','-5','4','','.w-sample'),(895383,'furniture','.w-sample .multicart .name','margin-top','0','','','.w-sample'),(895384,'furniture','.w-cart-sub-total ','margin-top','0','','','.w-cart-sub-total'),(895385,'furniture','.shipping-ico .heading-3','margin-top','0','','','.shipping-ico'),(895386,'furniture','.order-summary .heading-2','margin-top','0','','','.order-summary'),(895387,'furniture','.w-cart-gift-certificate .heading-4','margin-top','0','','','.w-cart-gift-certificate'),(895388,'furniture','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(895389,'furniture','.w-product-bundle .bundle_price','margin-top','-5','','','.w-product-bundle'),(895390,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-top','0','','','.b-products-listing'),(895391,'furniture','.b-pagination ul.pagination','margin-top','0','','','.b-pagination'),(895392,'furniture','.w-product-properties-filters-widgets-chosen-filters .item','margin-top','0','','','.w-product-properties-filters-widgets-chosen-filters'),(895394,'furniture','.w-account-personal-catalog .list-row-action ul','margin-top','-1','','','.w-account-personal-catalog'),(895395,'furniture','.w-account-personal-catalog .list-row-action li','margin-top','0','','','.w-account-personal-catalog'),(895396,'furniture','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(895397,'furniture','.w-product-properties .property-ul','margin-top','0','','','.w-product-properties'),(895398,'furniture','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(895399,'furniture','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(895400,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list'),(895401,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list-block'),(895402,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(895403,'furniture','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(895404,'furniture','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(895405,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','5131','','.w-delivery-location-top-location-list'),(895406,'furniture','.w-delivery-location-featured-list .deliveryList ul','margin-top','0','','','.w-delivery-location-featured-list'),(895407,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(895408,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(895409,'furniture','.w-delivery-location-list-by-page .description ul','margin-top','5','','','.w-delivery-location-list-by-page'),(895410,'furniture','.w-delivery-location-list-by-page .item','margin-top','0','','','.w-delivery-location-list-by-page'),(895411,'furniture','.w-delivery-location-list-by-page .item','margin-top','10','5161','','.w-delivery-location-list-by-page'),(895412,'furniture','.w-delivery-location-cross-pages .description ul','margin-top','5','','','.w-delivery-location-cross-pages'),(895413,'furniture','.w-delivery-location-cross-pages .item','margin-top','0','','','.w-delivery-location-cross-pages'),(895414,'furniture','.w-delivery-location-cross-pages .item','margin-top','10','5161','','.w-delivery-location-cross-pages'),(895415,'furniture','.w-catalog-delivery-locations .item','margin-top','0','','','.w-catalog-delivery-locations'),(895416,'furniture','.w-catalog-delivery-locations .description ul','margin-top','5','','','.w-catalog-delivery-locations'),(895417,'furniture','.w-catalog-delivery-locations .item','margin-top','0','5131','','.w-catalog-delivery-locations'),(895418,'furniture','.w-product-designer-designer .prodDesignerType label','margin-top','10','','','.w-product-designer-designer'),(895419,'furniture','.w-press-reviews-widgets-press-reviews .date','margin-top','10','5131','','.w-press-reviews-widgets-press-reviews'),(895420,'furniture','.w-press-reviews-widgets-press-reviews-list .image','margin-top','0','','','.w-press-reviews-widgets-press-reviews-list'),(895421,'furniture','.w-press-reviews-widgets-press-reviews-list .item','margin-top','10','','','.w-press-reviews-widgets-press-reviews-list'),(895422,'furniture','.w-support-system-filter .filter_cats','margin-top','0','','','.w-support-system-filter'),(895423,'furniture','.w-rma-returns-history .content-messages .messages-table .bottom','margin-top','10','','','.w-rma-returns-history'),(895424,'furniture','.w-rma-returns-history .content-messages .messages-table .top','margin-top','10','','','.w-rma-returns-history'),(895425,'furniture','.w-rma-returns-history .filterMessages','margin-top','0','','','.w-rma-returns-history'),(895426,'furniture','.w-rma-returns-history .column:last-child .title','margin-top','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(895427,'furniture','.w-product-designer-designer .productDesignerBox ul','margin-top','0','','','.w-product-designer-designer'),(895428,'furniture','.w-product-configurator .pc-item','margin-top','0','','','.w-product-configurator'),(895429,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-list'),(895430,'furniture','.w-predefined-promotion .promo-cart-discount .master .image','margin-top','-16','','','.w-predefined-promotion'),(895431,'furniture','.w-predefined-promotion .promo-cart-discount .master .item','margin-top','12','','','.w-predefined-promotion'),(895432,'furniture','.w-predefined-promotion .promo-cart-discount .slave .item','margin-top','2','','','.w-predefined-promotion'),(895433,'furniture','.w-predefined-promotion .promo-salemaker .content','margin-top','-18','','','.w-predefined-promotion'),(895434,'furniture','.w-predefined-promotion .promo-salemaker .item','margin-top','2','','','.w-predefined-promotion'),(895436,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-top','0','','','.w-filters'),(895437,'furniture','.mainBanner .topBox > .right','margin-top','-20','4','','.mainBanner'),(895438,'furniture','.mainBanner .topBox > .right','margin-top','-16','5131,4','','.mainBanner'),(895439,'furniture','.w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp','margin-top','10','','','.w-cart-discount-coupon'),(895440,'furniture','.w-product-quantity-discounts .item + .item + .item','margin-top','10','','','.w-product-quantity-discounts'),(895447,'furniture','.account-address-book .address_book .row-buttons a','margin-top','0','','','.account-address-book'),(895448,'furniture','.account-address-book .address_book h1','margin-top','0','','','.account-address-book'),(895449,'furniture','.account-address-book .address_book h2','margin-top','0','','','.account-address-book'),(895450,'furniture','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-top','0','','','.account-address-book'),(895451,'furniture','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-top','0','','','.account-address-book'),(895452,'furniture','.account-address-book .address_book_row h2 a','margin-top','0','','','.account-address-book'),(895453,'furniture','.account-address-book .buttonBox .info','margin-top','0','','','.account-address-book'),(895454,'furniture','.account-address-book .address_book_row .column','margin-top','0','5131','','.account-address-book'),(895455,'furniture','.account-address-book .address_book_row .column + .column','margin-top','0','5131','','.account-address-book'),(895456,'furniture','.account-address-book .topInfo > div','margin-top','0','5131','','.account-address-book'),(895457,'furniture','.account-address-book .topInfo > div + div','margin-top','0','5131','','.account-address-book'),(895466,'furniture','.account-order-pay .buttons','margin-top','20','','','.account-order-pay'),(895467,'furniture','.account-order-pay .history_info','margin-top','0','','','.account-order-pay'),(895468,'furniture','.account-order-pay .history_info > div','margin-top','0','5140','','.account-order-pay'),(895469,'furniture','.account-password-wrap .buttonedit','margin-top','-40','','','.account-password-wrap'),(895470,'furniture','.account-password-wrap .buttons','margin-top','-70','','','.account-password-wrap'),(895471,'furniture','.account-samples .buttonBox','margin-top','15','','','.account-samples'),(895472,'furniture','.account-samples .order_history_table h2','margin-top','0','','','.account-samples'),(895473,'furniture','.account-sample-info .buttons','margin-top','20','','','.account-sample-info'),(895474,'furniture','.account-sample-info .history_info','margin-top','0','','','.account-sample-info'),(895475,'furniture','.account-sample-info .popup-tracking-number-link','margin-top','10','','','.account-sample-info'),(895476,'furniture','.account-sample-info .history_info > div','margin-top','0','5140','','.account-sample-info'),(895477,'furniture','.checkout-index-wrap .dob-hide','margin-top','20','','','.checkout-index-wrap'),(895478,'furniture','.shopping-cart-index .closeable-heading .heading-2','margin-top','0','','','.shopping-cart-index'),(895479,'furniture','.b-info .info','margin-top','-8','3','','.b-info'),(895480,'furniture','.b-info .info li','margin-top','0','','','.b-info'),(895481,'furniture','.b-info .info ul','margin-top','0','','','.b-info'),(895482,'furniture','.b-multi-page-checkout .multi-page-checkout .buttons','margin-top','0','','','.b-multi-page-checkout'),(895483,'furniture','.success-page .page-success .text-1','margin-top','0','3','','.success-page'),(895484,'furniture','.success-page .totals-line','margin-top','10','','','.success-page'),(895485,'furniture','.preFooter .w-banner .banner-image','margin-top','0','','','.preFooter'),(895486,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li.component-item','margin-top','20','','','.footer-menu'),(895487,'furniture','.lowestPricedBox .w-banner .banner-holder','margin-top','0','','','.lowestPricedBox'),(895488,'furniture','.lowestPricedBox .w-banner .banner-item','margin-top','0','','','.lowestPricedBox'),(895489,'furniture','.lowestPricedBox .w-banner .ybg .descr','margin-top','0','','','.lowestPricedBox'),(895490,'furniture','.tripleBanner ','margin-top','0','','','.tripleBanner'),(895491,'furniture','.tripleBanner > .block','margin-top','10','5140','','.tripleBanner'),(895492,'furniture','.shopByCollectionBox .w-banner .banner-holder','margin-top','0','','','.shopByCollectionBox'),(895493,'furniture','.shopByCollectionBox .w-banner .banner-item','margin-top','0','','','.shopByCollectionBox'),(895494,'furniture','.shopByCollectionBox .w-banner .banner-item','margin-top','10','5140','','.shopByCollectionBox'),(895495,'furniture','.shopByCollectionBox .w-banner .banner-item','margin-top','10','5161','','.shopByCollectionBox'),(895496,'furniture','.accout-box select[data-type=\"vat_number\"]','margin-top','0','','','.accout-box'),(895497,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top','0','','','.w-catalog-paging'),(895498,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top_important','important','','','.w-catalog-paging'),(895499,'furniture','.p-quick-order-index ul.token-input-list','margin_bottom_measure','pt','','','.p-quick-order-index'),(895500,'furniture','.w-cart-give-away .ga_attributes > div','margin_bottom_measure','%','','','.w-cart-give-away'),(895501,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(895502,'furniture','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(895503,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','5131','','.w-delivery-location-top-location-list'),(895504,'furniture','.p-quick-order-index ul.token-input-list','margin_left_measure','pt','','','.p-quick-order-index'),(895505,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_left_measure','pt','','','.b-warehouses-popup'),(895506,'furniture','.w-cart-give-away .ga_column','margin_left_measure','%','','','.w-cart-give-away'),(895507,'furniture','.w-taxable select','margin_left_measure','pt','','','.w-taxable'),(895508,'furniture','.b-form .col-3 + .col-3','margin_left_measure','%','','','.b-form'),(895509,'furniture','.w-cart-give-away .ga_attributes > div','margin_left_measure','%','','','.w-cart-give-away'),(895510,'furniture','.b-trade-approval .col-3 + .col-3','margin_left_measure','%','','','.b-trade-approval'),(895511,'furniture','.w-delivery-day .left-count','margin_left_measure','%','','','.w-delivery-day'),(895512,'furniture','.w-delivery-day .left-text-right','margin_left_measure','%','','','.w-delivery-day'),(895513,'furniture','.w-product-sale-ends .left-count','margin_left_measure','%','','','.w-product-sale-ends'),(895514,'furniture','.w-product-sale-ends .left-text-right','margin_left_measure','%','','','.w-product-sale-ends'),(895515,'furniture','h1, .heading-1','margin_left_measure','%','3','',''),(895516,'furniture','.heading-2','margin_left_measure','%','3','',''),(895517,'furniture','.w-product-multi-inventory .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-multi-inventory'),(895518,'furniture','.p-quote-checkout-index .order-summary .heading-2','margin_left_measure','%','3','','.p-quote-checkout-index'),(895519,'furniture','.p-sample-checkout-index .order-summary .heading-2','margin_left_measure','%','3','','.p-sample-checkout-index'),(895520,'furniture','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(895521,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(895522,'furniture','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(895523,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','5131','','.w-delivery-location-top-location-list'),(895524,'furniture','.w-sale-category .left-count','margin_left_measure','%','','','.w-sale-category'),(895525,'furniture','.w-sale-category .left-text-right','margin_left_measure','%','','','.w-sale-category'),(895526,'furniture','.w-delivery-location-list-by-page .item','margin_left_measure','%','','','.w-delivery-location-list-by-page'),(895527,'furniture','.w-delivery-location-cross-pages .item','margin_left_measure','%','','','.w-delivery-location-cross-pages'),(895528,'furniture','.w-catalog-delivery-locations .item','margin_left_measure','%','','','.w-catalog-delivery-locations'),(895529,'furniture','.w-product-quantity-discounts .item:nth-child(even)','margin_left_measure','%','','','.w-product-quantity-discounts'),(895530,'furniture','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin_left_measure','%','','','.account-address-book'),(895531,'furniture','.checkout-index-wrap .order-summary .heading-2','margin_left_measure','%','3','','.checkout-index-wrap'),(895532,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_right_measure','pt','','','.b-warehouses-popup'),(895533,'furniture','.p-quick-order-index ul.token-input-list','margin_right_measure','pt','','','.p-quick-order-index'),(895534,'furniture','.b-fancybox .fancybox-title-float-wrap .child','margin_right_measure','%','','','.b-fancybox'),(895535,'furniture','.w-cart-give-away .ga_column','margin_right_measure','%','','','.w-cart-give-away'),(895536,'furniture','.w-taxable select','margin_right_measure','pt','','','.w-taxable'),(895537,'furniture','.w-cart-give-away .ga_img','margin_right_measure','%','','','.w-cart-give-away'),(895538,'furniture','.w-cart-give-away .ga_attributes > div','margin_right_measure','%','','','.w-cart-give-away'),(895539,'furniture','h1, .heading-1','margin_right_measure','%','4','',''),(895540,'furniture','.heading-2','margin_right_measure','%','4','',''),(895541,'furniture','.p-quote-checkout-index .order-summary .heading-2','margin_right_measure','%','4','','.p-quote-checkout-index'),(895542,'furniture','.p-sample-checkout-index .order-summary .heading-2','margin_right_measure','%','4','','.p-sample-checkout-index'),(895543,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(895544,'furniture','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(895545,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','5131','','.w-delivery-location-top-location-list'),(895546,'furniture','.w-delivery-location-list-by-page .item','margin_right_measure','%','','','.w-delivery-location-list-by-page'),(895547,'furniture','.w-delivery-location-cross-pages .item','margin_right_measure','%','','','.w-delivery-location-cross-pages'),(895548,'furniture','.w-catalog-delivery-locations .item','margin_right_measure','%','','','.w-catalog-delivery-locations'),(895549,'furniture','.w-product-quantity-discounts .item:nth-child(odd)','margin_right_measure','%','','','.w-product-quantity-discounts'),(895551,'furniture','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin_right_measure','%','','','.account-address-book'),(895552,'furniture','.checkout-index-wrap .order-summary .heading-2','margin_right_measure','%','4','','.checkout-index-wrap'),(895553,'furniture','.p-quick-order-index ul.token-input-list','margin_top_measure','pt','','','.p-quick-order-index'),(895554,'furniture','.w-cart-give-away .ga_attributes > div','margin_top_measure','%','','','.w-cart-give-away'),(895555,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(895556,'furniture','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(895557,'furniture','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','5131','','.w-delivery-location-top-location-list'),(895558,'furniture','.w-promotions .prom-multi-discount .image img','max-height','80','','','.w-promotions'),(895559,'furniture','.w-promotions .promo-salemaker .image img','max-height','80','','','.w-promotions'),(895560,'furniture','.w-promotions .promo-cart-discount .image img','max-height','80','','','.w-promotions'),(895561,'furniture','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(895562,'furniture','.b-email-editor img','max-height','100','','','.b-email-editor'),(895563,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-height','100','','','.w-upload-customer-id-upload-customer-id-form'),(895564,'furniture','.w-product-images-additional .item-img','max-height','70','5161','','.w-product-images-additional'),(895565,'furniture','.w-product-images-additional .item-img','max-height','70','5161','','.w-product-images-additional'),(895566,'furniture','.b-email-editor img','max-height','100','','','.b-email-editor'),(895567,'furniture','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(895568,'furniture','.b-fancybox .fancybox-tmp','max-height','99999','','','.b-fancybox'),(895569,'furniture','.b-email-editor img','max-height','100','','','.b-email-editor'),(895570,'furniture','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(895571,'furniture','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(895572,'furniture','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(895573,'furniture','.b-fancybox .fancybox-image','max-height','100','','','.b-fancybox'),(895574,'furniture','.b-email-editor img','max-height','100','','','.b-email-editor'),(895575,'furniture','.b-email-editor img','max-height','100','','','.b-email-editor'),(895576,'furniture','.w-product-images-additional .item-img','max-height','70','5161','','.w-product-images-additional'),(895577,'furniture','.b-select-suggest .select2-results','max-height','200','','','.b-select-suggest'),(895578,'furniture','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(895579,'furniture','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-height','100','','','.b-products-listing'),(895580,'furniture','.b-email-editor img','max-height','100','','','.b-email-editor'),(895581,'furniture','.w-product-images-additional .item-img','max-height','70','5161','','.w-product-images-additional'),(895582,'furniture','.w-product-images-additional .item-img','max-height','70','5161','','.w-product-images-additional'),(895583,'furniture','.w-product-images-additional .item-img','max-height','70','5161','','.w-product-images-additional'),(895584,'furniture','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max-height','100','','','.b-product-images'),(895585,'furniture','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max-height','90','','','.b-product-images'),(895586,'furniture','.b-product-images .media-popup .mp-small-images img','max-height','90','','','.b-product-images'),(895587,'furniture','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','max-height','0','','','.b-menu-burger_icon'),(895588,'furniture','.b-menu-burger_icon .bi-opened .menu-style[data-open_from=\"top\"] .menu-content','max-height','2000','','','.b-menu-burger_icon'),(895589,'furniture','.w-product-images img','max-height','100','','','.w-product-images'),(895590,'furniture','.b-product-images .additional-horizontal .additional-images img','max-height','150','','','.b-product-images'),(895591,'furniture','.b-product-images .produst-image img','max-height','400','','','.b-product-images'),(895592,'furniture','.b-product-images .additional-horizontal .additional-images video','max-height','150','','','.b-product-images'),(895593,'furniture','.w-product-video .item img, .w-product-video .item video','max-height','150','','','.w-product-video'),(895594,'furniture','.w-catalog-additional-images img','max-height','150','','','.w-catalog-additional-images'),(895595,'furniture','.b-products-listing .products-listing .radio-attributes img','max-height','30','','','.b-products-listing'),(895596,'furniture','.b-product-images .additional-horizontal .additional-images img','max-height','100','5131','','.b-product-images'),(895597,'furniture','.b-product-images .additional-horizontal .additional-images video','max-height','100','5131','','.b-product-images'),(895598,'furniture','.w-sale-category .image img','max-height','300','','','.w-sale-category'),(895599,'furniture','.w-predefined-promotion .prom-multi-discount .image img','max-height','80','','','.w-predefined-promotion'),(895600,'furniture','.w-predefined-promotion .promo-cart-discount .image img','max-height','80','','','.w-predefined-promotion'),(895601,'furniture','.w-predefined-promotion .promo-salemaker .image img','max-height','80','','','.w-predefined-promotion'),(895604,'furniture','.b-product-images .additional-horizontal .additional-images img','max-height_important','important','','','.b-product-images'),(895605,'furniture','.b-product-images .additional-horizontal .additional-images video','max-height_important','important','','','.b-product-images'),(895606,'furniture','.b-product-images .additional-horizontal .additional-images img','max-height_important','important','5131','','.b-product-images'),(895607,'furniture','.b-product-images .additional-horizontal .additional-images video','max-height_important','important','5131','','.b-product-images'),(895608,'furniture','.w-checkout-guest-btn .btn-2','max-width','100','','','.w-checkout-guest-btn'),(895609,'furniture','.w-product-images-additional .item-img','max-width','70','5161','','.w-product-images-additional'),(895610,'furniture','.w-promotions .heading-3','max-width','calc(100% - 100px)','','','.w-promotions'),(895611,'furniture','.w-promotions .promo-salemaker .item','max-width','calc(50% - 4px)','','','.w-promotions'),(895612,'furniture','.w-promotions .promo-cart-discount .slave .item','max-width','calc(50% - 4px)','','','.w-promotions'),(895613,'furniture','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(895614,'furniture','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(895615,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-width','100','','','.w-upload-customer-id-upload-customer-id-form'),(895616,'furniture','.b-fancybox .fancybox-tmp','max-width','99999','','','.b-fancybox'),(895617,'furniture','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(895618,'furniture','.w-product-images-additional .item-img','max-width','70','5161','','.w-product-images-additional'),(895619,'furniture','.main-width, .type-1 > .block','max-width','1540','','',''),(895620,'furniture','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(895621,'furniture','textarea','max-width','100','','',''),(895622,'furniture','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(895623,'furniture','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(895624,'furniture','.w-product-images-additional .item-img','max-width','70','5161','','.w-product-images-additional'),(895625,'furniture','div.cart-popup','max-width','95','','',''),(895626,'furniture','.b-email-editor img','max-width','100','','','.b-email-editor'),(895627,'furniture','.w-product-images-additional .item-img','max-width','70','5161','','.w-product-images-additional'),(895628,'furniture','.w-promotions .promo-cart-discount .master .item','max-width','calc(50% - 24px)','','','.w-promotions'),(895630,'furniture','.b-email-editor img','max-width','100','','','.b-email-editor'),(895633,'furniture','.w-product-images-additional .item-img','max-width','70','5161','','.w-product-images-additional'),(895635,'furniture','.w-catalog-b2b-add-button .b2b-add-box-wrap','max-width','1250','','','.w-catalog-b2b-add-button'),(895636,'furniture','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-width','100','','','.b-products-listing'),(895637,'furniture','.b-products-listing .promo','max-width','30','','','.b-products-listing'),(895638,'furniture','.b-bottom .terms-info-popup','max-width','95','','','.b-bottom'),(895639,'furniture','.w-checkout-create-btn .btn-2','max-width','100','','','.w-checkout-create-btn'),(895640,'furniture','.b-email-editor img','max-width','100','','','.b-email-editor'),(895641,'furniture','.b-fancybox .fancybox-image','max-width','100','','','.b-fancybox'),(895642,'furniture','.b-bottom .popup-credit-amount .popup-box','max-width','960','','','.b-bottom'),(895643,'furniture','.b-email-editor img','max-width','100','','','.b-email-editor'),(895644,'furniture','.b-email-editor img','max-width','100','','','.b-email-editor'),(895646,'furniture','.w-product-images-additional .item-img','max-width','70','5161','','.w-product-images-additional'),(895647,'furniture','.b-email-editor img','max-width','100','','','.b-email-editor'),(895648,'furniture','.b-upload-files .attached-block','max-width','300','','','.b-upload-files'),(895650,'furniture','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max-width','100','','','.b-product-images'),(895651,'furniture','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max-width','100','','','.b-product-images'),(895652,'furniture','.b-product-images .media-popup .mp-small-images img','max-width','90','','','.b-product-images'),(895653,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max-width','100','','','.b-menu-lev_display-slide'),(895654,'furniture','.b-trade-approval .middle-form','max-width','560','','','.b-trade-approval'),(895655,'furniture','.w-login-register .middle-form','max-width','100','','','.w-login-register'),(895656,'furniture','.w-login-returning .middle-form','max-width','100','','','.w-login-returning'),(895657,'furniture','.w-catalog-additional-images img','max-width','150','','','.w-catalog-additional-images'),(895658,'furniture','.b-products-listing .products-listing .radio-attributes img','max-width','30','','','.b-products-listing'),(895659,'furniture','.w-product-multi-inventory .radio-attributes label img','max-width','23','','','.w-product-multi-inventory'),(895660,'furniture','.b-products-listing .products-listing .radio-attributes label img','max-width','23','','','.b-products-listing'),(895661,'furniture','.w-product-attributes .radio-attributes label img','max-width','23','','','.w-product-attributes'),(895662,'furniture','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img','max-width','100','','','.w-product-groups'),(895663,'furniture','.w-product-properties-icons .hover-box img','max-width','150','','','.w-product-properties-icons'),(895664,'furniture','.w-press-reviews-widgets-press-reviews-small .item','max-width','100','','','.w-press-reviews-widgets-press-reviews-small'),(895665,'furniture','.b-products-listing .products-listing .bonus-points-cost','max-width','150','','','.b-products-listing'),(895666,'furniture','.w-predefined-promotion .heading-3','max-width','calc(100% - 100px)','','','.w-predefined-promotion'),(895667,'furniture','.w-predefined-promotion .promo-cart-discount .master .item','max-width','calc(50% - 24px)','','','.w-predefined-promotion'),(895668,'furniture','.w-predefined-promotion .promo-cart-discount .slave .item','max-width','calc(50% - 4px)','','','.w-predefined-promotion'),(895669,'furniture','.w-predefined-promotion .promo-salemaker .item','max-width','calc(50% - 4px)','','','.w-predefined-promotion'),(895670,'furniture','.mainBanner .bottomBox','max-width','690','','','.mainBanner'),(895671,'furniture','.mainBanner .bottomBox .elf','max-width','75','','','.mainBanner'),(895672,'furniture','.mainBanner > .block','max-width','100','','','.mainBanner'),(895674,'furniture','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','max-width','600','','','.checkout-index-wrap'),(895675,'furniture','.b-form .middle-g','max-width','560','','','.b-form'),(895676,'furniture','.b-form .formWrapBox','max-width','500','','','.b-form'),(895677,'furniture','.mainBanner .w-banner .banner-text-holder','max-width','100','','','.mainBanner'),(895678,'furniture','.lowestPricedBox .w-banner .banner-text-holder','max-width','220','','','.lowestPricedBox'),(895679,'furniture','.lowestPricedBox .w-banner .banner-text-holder','max-width','185','5140','','.lowestPricedBox'),(895680,'furniture','.lowestPricedBox .w-banner .banner-text-holder','max-width','185','5161','','.lowestPricedBox'),(895681,'furniture','.lowestPricedBox .w-banner .ybg .mark img','max-width','100','','','.lowestPricedBox'),(895682,'furniture','.lowestPricedBox .w-banner .ybg .mark img','max-width','45','5131','','.lowestPricedBox'),(895683,'furniture','.lowestPricedBox .w-banner .ybg .mark img','max-width','45','5140','','.lowestPricedBox'),(895684,'furniture','.lowestPricedBox .w-banner .ybg .mark img','max-width','60','5145','','.lowestPricedBox'),(895685,'furniture','.w-banner .banner-item.text-bottom-text .banner-text-holder','max-width','100','','','.w-banner'),(895686,'furniture','.w-banner .banner-text-holder','max-width','500','','','.w-banner'),(895687,'furniture','.w-banner .na-banner','max-width','200','','','.w-banner'),(895688,'furniture','.mainBanner > .block','max-width_important','important','','','.mainBanner'),(895689,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(895690,'furniture','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(895691,'furniture','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(895692,'furniture','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(895693,'furniture','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(895694,'furniture','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(895695,'furniture','.b-fancybox .fancybox-image','max_height_measure','%','','','.b-fancybox'),(895696,'furniture','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_height_measure','%','','','.b-products-listing'),(895697,'furniture','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(895698,'furniture','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max_height_measure','%','','','.b-product-images'),(895699,'furniture','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max_height_measure','%','','','.b-product-images'),(895700,'furniture','.b-product-images .media-popup .mp-small-images img','max_height_measure','%','','','.b-product-images'),(895701,'furniture','.w-product-images img','max_height_measure','%','','','.w-product-images'),(895702,'furniture','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(895703,'furniture','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(895704,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(895705,'furniture','.w-checkout-guest-btn .btn-2','max_width_measure','%','','','.w-checkout-guest-btn'),(895706,'furniture','.w-checkout-create-btn .btn-2','max_width_measure','%','','','.w-checkout-create-btn'),(895707,'furniture','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(895708,'furniture','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(895709,'furniture','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(895710,'furniture','textarea','max_width_measure','%','','',''),(895711,'furniture','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(895712,'furniture','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(895713,'furniture','div.cart-popup','max_width_measure','%','','',''),(895714,'furniture','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(895715,'furniture','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(895716,'furniture','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(895717,'furniture','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_width_measure','%','','','.b-products-listing'),(895718,'furniture','.b-products-listing .promo','max_width_measure','%','','','.b-products-listing'),(895719,'furniture','.b-bottom .terms-info-popup','max_width_measure','%','','','.b-bottom'),(895720,'furniture','.b-fancybox .fancybox-image','max_width_measure','%','','','.b-fancybox'),(895721,'furniture','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(895722,'furniture','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(895723,'furniture','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max_width_measure','%','','','.b-product-images'),(895724,'furniture','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max_width_measure','%','','','.b-product-images'),(895725,'furniture','.b-product-images .media-popup .mp-small-images img','max_width_measure','%','','','.b-product-images'),(895726,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max_width_measure','vw','','','.b-menu-lev_display-slide'),(895727,'furniture','.w-login-register .middle-form','max_width_measure','%','','','.w-login-register'),(895728,'furniture','.w-login-returning .middle-form','max_width_measure','%','','','.w-login-returning'),(895729,'furniture','.mainBanner > .block','max_width_measure','%','','','.mainBanner'),(895730,'furniture','.mainBanner .w-banner .banner-text-holder','max_width_measure','%','','','.mainBanner'),(895731,'furniture','.w-banner .banner-item.text-bottom-text .banner-text-holder','max_width_measure','%','','','.w-banner'),(895732,'furniture','.mainBanner > .block','max_width_measure_important','important','','','.mainBanner'),(895733,'furniture','.b-select-suggest .select2-results .select2-result-label','min-height','1','','','.b-select-suggest'),(895734,'furniture','.b-select-suggest .select2-container-multi .select2-choices','min-height','26','','','.b-select-suggest'),(895735,'furniture','.b-select-suggest .select2-search input','min-height','26','','','.b-select-suggest'),(895736,'furniture','.b-select-suggest .select2-search','min-height','26','','','.b-select-suggest'),(895737,'furniture','.b-select-suggest .select2-drop-mask','min-height','100','','','.b-select-suggest'),(895740,'furniture','.w-cart-listing .item > div','min-height','1','','','.w-cart-listing'),(895741,'furniture','.b-slick .slick-slide','min-height','1','','','.b-slick'),(895742,'furniture','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(895743,'furniture','.w-supplier-purchase-supplier-products .qty_col','min-height','40','','','.w-supplier-purchase-supplier-products'),(895744,'furniture','.mainBanner .bottomBox','min-height','230','5161','','.mainBanner'),(895745,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1','min-height','35','','','.menu-header'),(895746,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','min-height','40','','','.menu-header'),(895747,'furniture','.w-communication-new-topic #communication_group_holder table','min-width','800','','','.w-communication-new-topic'),(895748,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.p-quick-order-index'),(895749,'furniture','.p-quick-order-index .al_incart, .p-quick-order-index .al-incart','min-width','60','','','.p-quick-order-index'),(895750,'furniture','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(895751,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.p-quick-order-index'),(895752,'furniture','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','min-width','150','','','.w-menu-horizontal'),(895753,'furniture','.w-communication-post .btn-submit','min-width','200','','','.w-communication-post'),(895754,'furniture','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','min-width','70','','','.b-form'),(895755,'furniture','.b-bottom .popup-box.popupCompare','min-width','800','','','.b-bottom'),(895756,'furniture','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(895757,'furniture','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(895758,'furniture','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(895759,'furniture','.b-bottom .confirm-popup .buttons .btn','min-width','120','','','.b-bottom'),(895760,'furniture','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(895761,'furniture','.b-select-suggest .select2-drop-mask','min-width','100','','','.b-select-suggest'),(895762,'furniture','.w-menu-horizontal > ul > li > ul > li','min-width','150','','','.w-menu-horizontal'),(895763,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.b-data-table'),(895764,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.b-data-table'),(895765,'furniture','.w-communication-new-topic .quantity','min-width','70','','','.w-communication-new-topic'),(895766,'furniture','.w-communication-new-topic #communication_group_holder table table','min-width','0','','','.w-communication-new-topic'),(895767,'furniture','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(895768,'furniture','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','min-width','200','','','.b-menu-lev_display-down'),(895769,'furniture','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','min-width','200','','','.b-menu-lev_display-down'),(895770,'furniture','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','min-width','200','','','.b-menu-lev_display-down'),(895771,'furniture','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','min-width','200','','','.b-menu-lev_display-down'),(895772,'furniture','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','min-width','200','','','.b-menu-lev_display-down'),(895773,'furniture','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','min-width','200','','','.b-menu-lev_display-left'),(895774,'furniture','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','min-width','200','','','.b-menu-lev_display-left'),(895775,'furniture','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','min-width','200','','','.b-menu-lev_display-left'),(895776,'furniture','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','min-width','200','','','.b-menu-lev_display-left'),(895777,'furniture','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','min-width','200','','','.b-menu-lev_display-left'),(895778,'furniture','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','min-width','200','','','.b-menu-lev_display-lra'),(895779,'furniture','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','min-width','200','','','.b-menu-lev_display-lra'),(895780,'furniture','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','min-width','200','','','.b-menu-lev_display-lra'),(895781,'furniture','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','min-width','200','','','.b-menu-lev_display-lra'),(895782,'furniture','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','min-width','200','','','.b-menu-lev_display-lra'),(895783,'furniture','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','min-width','200','','','.b-menu-lev_display-right'),(895784,'furniture','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','min-width','200','','','.b-menu-lev_display-right'),(895785,'furniture','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','min-width','200','','','.b-menu-lev_display-right'),(895786,'furniture','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','min-width','200','','','.b-menu-lev_display-right'),(895787,'furniture','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','min-width','200','','','.b-menu-lev_display-right'),(895790,'furniture','.w-quote .no-text','min-width','120','','','.w-quote'),(895791,'furniture','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(895792,'furniture','.w-sample .no-text','min-width','120','','','.w-sample'),(895793,'furniture','.b-pagination .pagination .next-pages','min-width','30','','','.b-pagination'),(895794,'furniture','.b-pagination .pagination .page-number','min-width','30','','','.b-pagination'),(895795,'furniture','.b-pagination .pagination .prev-pages','min-width','30','','','.b-pagination'),(895796,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','min-width','30','','','.b-pagination'),(895797,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','min-width','30','','','.b-pagination'),(895798,'furniture','.b-pagination .pagination span','min-width','30','2','','.b-pagination'),(895799,'furniture','.w-catalog-paging ','min-width','30','2','','.w-catalog-paging'),(895800,'furniture','.w-catalog-paging .next','min-width','30','','','.w-catalog-paging'),(895801,'furniture','.w-catalog-paging .next-pages','min-width','30','','','.w-catalog-paging'),(895802,'furniture','.w-catalog-paging .page-number','min-width','30','','','.w-catalog-paging'),(895803,'furniture','.w-catalog-paging .prev','min-width','30','','','.w-catalog-paging'),(895804,'furniture','.w-catalog-paging .prev-pages','min-width','30','','','.w-catalog-paging'),(895805,'furniture','.b-select-suggest .select2-results .select2-result-label','min_height_measure','em','','','.b-select-suggest'),(895806,'furniture','.b-select-suggest .select2-drop-mask','min_height_measure','%','','','.b-select-suggest'),(895807,'furniture','.b-select-suggest .select2-drop-mask','min_width_measure','%','','','.b-select-suggest'),(895808,'furniture','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','opacity','0','','','.b-switch'),(895809,'furniture','.p-quick-order-index .paginate_button.next.disabled','opacity','0.3','3','','.p-quick-order-index'),(895810,'furniture','.p-quick-order-index .paginate_button.previous.disabled','opacity','0.3','3','','.p-quick-order-index'),(895811,'furniture','.b-fancybox #fancybox-loading','opacity','0.8','','','.b-fancybox'),(895812,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','opacity','0.5','','','.b-switch'),(895813,'furniture','.b-form .hide-billing-address','opacity','0.7','','','.b-form'),(895814,'furniture','.disabled-area','opacity','0.5','','',''),(895815,'furniture','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled.readonly','opacity','0.7','','','.b-switch'),(895816,'furniture','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled','opacity','0.4','','','.b-switch'),(895817,'furniture','.b-form .checkbox-style','opacity','0','','','.b-form'),(895818,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','opacity','0.5','','','.b-switch'),(895819,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','opacity','0.5','','','.b-switch'),(895820,'furniture','.b-select-suggest .select2-drop-mask','opacity','0','','','.b-select-suggest'),(895821,'furniture','.b-products-listing .products-listing .qty-input.hidden','opacity','0.7','3','','.b-products-listing'),(895822,'furniture','.b-form .required-message','opacity','0.5','1','','.b-form'),(895823,'furniture','.w-filters .input-checkbox','opacity','0','','','.w-filters'),(895824,'furniture','.b-slick button.slick-disabled','opacity','0.3','','','.b-slick'),(895825,'furniture','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(895826,'furniture','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(895827,'furniture','.b-pagination .pagination .paging span.prev, .b-pagination .pagination .paging span.next','opacity','0.3','','','.b-pagination'),(895828,'furniture','.w-product-groups .radioBox label input','opacity','0','','','.w-product-groups'),(895829,'furniture','.w-product-designer-designer .productDesignerBox input','opacity','0','','','.w-product-designer-designer'),(895830,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','opacity','0','','','.w-filters'),(895832,'furniture','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-order-pay'),(895833,'furniture','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-sample-info'),(895834,'furniture','.w-catalog-paging .paging span.prev, .w-catalog-paging .paging span.next','opacity','0.3','','','.w-catalog-paging'),(895835,'furniture','.w-promotions .promo-cart-discount .slave .heading','order','1','','','.w-promotions'),(895836,'furniture','.w-promotions .promo-cart-discount .slave .content','order','3','','','.w-promotions'),(895837,'furniture','.w-promotions .promo-cart-discount .slave .condition','order','2','','','.w-promotions'),(895838,'furniture','.w-cart-gift-certificate .input-apple .btn','order','2','','','.w-cart-gift-certificate'),(895839,'furniture','.w-cart-gift-certificate .input-apple div','order','1','','','.w-cart-gift-certificate'),(895840,'furniture','.w-cart-order-reference .input-apple div','order','1','','','.w-cart-order-reference'),(895841,'furniture','.w-cart-order-reference .input-apple button','order','2','','','.w-cart-order-reference'),(895843,'furniture','.w-press-reviews-widgets-press-reviews-list .date-added','order','4','','','.w-press-reviews-widgets-press-reviews-list'),(895844,'furniture','.w-press-reviews-widgets-press-reviews-list .description','order','5','','','.w-press-reviews-widgets-press-reviews-list'),(895845,'furniture','.w-press-reviews-widgets-press-reviews-list .image','order','1','','','.w-press-reviews-widgets-press-reviews-list'),(895846,'furniture','.w-press-reviews-widgets-press-reviews-list .out-link','order','6','','','.w-press-reviews-widgets-press-reviews-list'),(895847,'furniture','.w-press-reviews-widgets-press-reviews-list .rating','order','2','','','.w-press-reviews-widgets-press-reviews-list'),(895848,'furniture','.w-press-reviews-widgets-press-reviews-list .short-description','order','3','','','.w-press-reviews-widgets-press-reviews-list'),(895849,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition','order','2','','','.w-predefined-promotion'),(895850,'furniture','.w-predefined-promotion .promo-cart-discount .slave .content','order','3','','','.w-predefined-promotion'),(895851,'furniture','.w-predefined-promotion .promo-cart-discount .slave .heading','order','1','','','.w-predefined-promotion'),(895854,'furniture','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','outline','none','','','.b-fancybox'),(895855,'furniture','.b-select-suggest .select2-container .select2-choice abbr','outline','0','','','.b-select-suggest'),(895856,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-focused','outline','0','','','.b-switch'),(895857,'furniture','.b-select-suggest .select2-search-choice-close','outline','none','','','.b-select-suggest'),(895858,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','outline','0','','','.b-select-suggest'),(895859,'furniture','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(895860,'furniture','.b-select-suggest .select2-container-active .select2-choice, .b-select-suggest .select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(895861,'furniture','.b-select-suggest .select2-search input','outline','0','','','.b-select-suggest'),(895862,'furniture','input:focus','outline','none','','',''),(895863,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline','0','','','.b-select-suggest'),(895864,'furniture','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','outline','none','','','.b-fancybox'),(895865,'furniture','.b-product-images .media-popup .mp-big-images .item','outline','none','','','.b-product-images'),(895866,'furniture','.b-product-images .media-popup .mp-small-images .item','outline','none','','','.b-product-images'),(895867,'furniture','.b-slick .slick-list:focus','outline','none','','','.b-slick'),(895868,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline_important','important','','','.b-select-suggest'),(895869,'furniture','.w-communication-new-topic #communication_group_holder','overflow','auto','','','.w-communication-new-topic'),(895870,'furniture','.b-form .shipping-method .sub-title','overflow','hidden','','','.b-form'),(895871,'furniture','.p-quick-order-index .top','overflow','hidden','','','.p-quick-order-index'),(895872,'furniture','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','overflow','hidden','','','.w-promotions'),(895873,'furniture','.w-cart-compare .product .name','overflow','hidden','','','.w-cart-compare'),(895874,'furniture','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(895875,'furniture','.b-switch .bootstrap-switch','overflow','hidden','','','.b-switch'),(895876,'furniture','.b-fancybox .fancybox-lock .fancybox-overlay','overflow','auto','','','.b-fancybox'),(895877,'furniture','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(895878,'furniture','.b-select-suggest .select2-measure-scrollbar','overflow','scroll','','','.b-select-suggest'),(895879,'furniture','.b-fancybox .fancybox-tmp','overflow','visible','','','.b-fancybox'),(895880,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow','hidden','','','.b-select-suggest'),(895881,'furniture','.p-quick-order-index .bottom','overflow','hidden','','','.p-quick-order-index'),(895882,'furniture','.w-cart-listing .right-area','overflow','hidden','5140','','.w-cart-listing'),(895884,'furniture','.b-fancybox .fancybox-inner','overflow','hidden','','','.b-fancybox'),(895885,'furniture','.b-fancybox .fancybox-lock','overflow','hidden','','','.b-fancybox'),(895886,'furniture','.b-fancybox .fancybox-overlay','overflow','hidden','','','.b-fancybox'),(895887,'furniture','.b-select-suggest .select2-container .select2-choice','overflow','hidden','','','.b-select-suggest'),(895888,'furniture','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(895889,'furniture','.b-bottom .cart-options .options','overflow','hidden','','','.b-bottom'),(895890,'furniture','.b-autocomplete .ui-autocomplete','overflow','auto','','','.b-autocomplete'),(895891,'furniture','.b-upload-files .attach-active-holder','overflow','hidden','','','.b-upload-files'),(895892,'furniture','.b-upload-files .added-file','overflow','hidden','','','.b-upload-files'),(895893,'furniture','.b-fancybox .fancybox-lock body','overflow','hidden','','','.b-fancybox'),(895894,'furniture','.w-checkout-shipping-choice input','overflow','hidden','','','.w-checkout-shipping-choice'),(895895,'furniture','.w-checkout-shipping-choice #shippingchoice-choice','overflow','hidden','','','.w-checkout-shipping-choice'),(895896,'furniture','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(895897,'furniture','.b-select-suggest .select2-container-multi .select2-choices','overflow','hidden','','','.b-select-suggest'),(895898,'furniture','.b-preloader .preloader','overflow','hidden','3','','.b-preloader'),(895899,'furniture','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(895900,'furniture','.w-account-addresses-list ','overflow','hidden','','','.w-account-addresses-list'),(895901,'furniture','.b-products-listing .btn-preloader','overflow','hidden','3','','.b-products-listing'),(895902,'furniture','.b-products-listing .loader','overflow','hidden','4','','.b-products-listing'),(895903,'furniture','.b-compare .compare-box-item','overflow','hidden','','','.b-compare'),(895905,'furniture','.b-form .payment-method .item-radio label span','overflow','hidden','','','.b-form'),(895906,'furniture','.w-quote .no-text','overflow','hidden','','','.w-quote'),(895907,'furniture','.b-compare .col-two','overflow','hidden','','','.b-compare'),(895908,'furniture','.w-cart-give-away .ga_ovr','overflow','hidden','','','.w-cart-give-away'),(895909,'furniture','.w-cart-give-away .ga_wrapper','overflow','hidden','','','.w-cart-give-away'),(895913,'furniture','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(895914,'furniture','.w-cart-shipping-estimator .item .row','overflow','hidden','','','.w-cart-shipping-estimator'),(895915,'furniture','.b-upload-files .attached-block','overflow','hidden','','','.b-upload-files'),(895916,'furniture','.b-upload-files .attach-block','overflow','hidden','','','.b-upload-files'),(895917,'furniture','.b-select-suggest .select2-container .select2-choice > .select2-chosen','overflow','hidden','','','.b-select-suggest'),(895918,'furniture','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','overflow','hidden','','','.b-menu-burger_icon'),(895919,'furniture','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','overflow','auto','','','.b-menu-lev_display-width'),(895920,'furniture','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','overflow','auto','','','.b-menu-lev_display-width'),(895921,'furniture','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','overflow','auto','','','.b-menu-lev_display-width'),(895922,'furniture','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','overflow','auto','','','.b-menu-lev_display-width'),(895923,'furniture','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','overflow','auto','','','.b-menu-lev_display-width'),(895924,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','overflow','auto','','','.b-menu-lev_display-width_cont'),(895925,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','overflow','auto','','','.b-menu-lev_display-width_cont'),(895926,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','overflow','auto','','','.b-menu-lev_display-width_cont'),(895927,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','overflow','auto','','','.b-menu-lev_display-width_cont'),(895928,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','overflow','auto','','','.b-menu-lev_display-width_cont'),(895929,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','overflow','auto','','','.b-menu-open_from-left'),(895930,'furniture','.b-trade-approval .steps-bar','overflow','hidden','','','.b-trade-approval'),(895931,'furniture','.w-catalog-compare .compare','overflow','hidden','','','.w-catalog-compare'),(895932,'furniture','.w-delivery-day .time-left','overflow','hidden','','','.w-delivery-day'),(895933,'furniture','.w-product-images .slick-vertical + .produst-image','overflow','hidden','','','.w-product-images'),(895934,'furniture','.b-slick .slick-list','overflow','hidden','','','.b-slick'),(895935,'furniture','.w-quote .multicart .sub-total-row','overflow','hidden','','','.w-quote'),(895936,'furniture','.w-quote .sub-total-row','overflow','hidden','','','.w-quote'),(895937,'furniture','h1, .heading-1','overflow','hidden','','',''),(895938,'furniture','.w-product-sale-ends .left','overflow','hidden','','','.w-product-sale-ends'),(895939,'furniture','.heading-2, h2, .h-block h2','overflow','hidden','','',''),(895940,'furniture','.w-compare .compare-list-holder','overflow','hidden','','','.w-compare'),(895941,'furniture','.w-compare .item-holder','overflow','hidden','','','.w-compare'),(895942,'furniture','.w-sample .multicart .sub-total-row','overflow','hidden','','','.w-sample'),(895943,'furniture','.w-sample .no-text','overflow','hidden','','','.w-sample'),(895944,'furniture','.w-sample .sub-total-row','overflow','hidden','','','.w-sample'),(895945,'furniture','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(895946,'furniture','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(895947,'furniture','.w-product-bundle .bundle_item','overflow','hidden','','','.w-product-bundle'),(895948,'furniture','.w-product-in-bundles .bundle_item','overflow','hidden','','','.w-product-in-bundles'),(895949,'furniture','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(895950,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','overflow','hidden','','','.w-account-personal-catalog'),(895951,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','overflow','visible','1','','.w-account-personal-catalog'),(895952,'furniture','.w-product-groups .radioBox','overflow','hidden','','','.w-product-groups'),(895953,'furniture','.w-sale-category .left','overflow','hidden','','','.w-sale-category'),(895954,'furniture','.w-sale-category .sale-holder','overflow','hidden','','','.w-sale-category'),(895955,'furniture','.w-gift-wrap-message-checkout ','overflow','hidden','','','.w-gift-wrap-message-checkout'),(895956,'furniture','.w-support-system-listing .support-head','overflow','hidden','','','.w-support-system-listing'),(895957,'furniture','.w-rma-returns-history .content-messages .messages-table .top','overflow','hidden','','','.w-rma-returns-history'),(895958,'furniture','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','overflow','hidden','','','.w-predefined-promotion'),(895962,'furniture','.account-address-book .buttonBox','overflow','hidden','','','.account-address-book'),(895964,'furniture','.account-order-pay .history_info','overflow','hidden','','','.account-order-pay'),(895965,'furniture','.account-sample-info .history_info','overflow','hidden','','','.account-sample-info'),(895966,'furniture','.payment-method-tf label','overflow','hidden','','','.payment-method-tf'),(895967,'furniture','.w-banner .banner .image-box','overflow','hidden','','','.w-banner'),(895968,'furniture','.w-catalog-paging .paging-holder','overflow','hidden','','','.w-catalog-paging'),(895969,'furniture','.w-catalog-paging .paging-holder.slick-slider','overflow','visible','','','.w-catalog-paging'),(895970,'furniture','.b-compare .compare_list','overflow-x','hidden','','','.b-compare'),(895971,'furniture','.b-select-suggest .select2-results','overflow-x','hidden','','','.b-select-suggest'),(895972,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-x','hidden','','','.b-menu-lev_display-slide'),(895973,'furniture','.b-compare .compare_list','overflow-y','auto','','','.b-compare'),(895974,'furniture','.b-fancybox .fancybox-lock .fancybox-overlay','overflow-y','scroll','','','.b-fancybox'),(895975,'furniture','.b-fancybox .fancybox-lock-test','overflow-y','hidden','','','.b-fancybox'),(895976,'furniture','.b-select-suggest .select2-results','overflow-y','auto','','','.b-select-suggest'),(895977,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-y','auto','','','.b-menu-lev_display-slide'),(895978,'furniture','.b-fancybox .fancybox-lock-test','overflow-y_important','important','','','.b-fancybox'),(895979,'furniture','.b-fancybox .fancybox-lock','overflow_important','important','','','.b-fancybox'),(895980,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow_important','important','','','.b-select-suggest'),(895981,'furniture','.b-fancybox .fancybox-tmp','overflow_important','important','','','.b-fancybox'),(895982,'furniture','.b-fancybox .fancybox-lock body','overflow_important','important','','','.b-fancybox'),(895983,'furniture','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-bottom','10','','','.w-communication-new-topic'),(895984,'furniture','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(895985,'furniture','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(895986,'furniture','.b-email .heading-model','padding-bottom','5','','','.b-email'),(895987,'furniture','.b-table .table td','padding-bottom','15','','','.b-table'),(895988,'furniture','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(895989,'furniture','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(895990,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(895991,'furniture','.w-product-images-additional .images','padding-bottom','20','5161','','.w-product-images-additional'),(895994,'furniture','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(895995,'furniture','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(895996,'furniture','.p-quick-order-index ul.token-input-list','padding-bottom','0','','','.p-quick-order-index'),(895997,'furniture','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-bottom','7','','','.p-quick-order-index'),(895998,'furniture','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-bottom','8','','','.p-quick-order-index'),(895999,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.p-quick-order-index'),(896000,'furniture','.w-promotions .promo-item','padding-bottom','20','','','.w-promotions'),(896001,'furniture','.w-top-categories h2.name','padding-bottom','3','','','.w-top-categories'),(896002,'furniture','.w-cart-compare .attributes-label','padding-bottom','10','','','.w-cart-compare'),(896009,'furniture','.w-personal-gift-status-bar .start-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(896010,'furniture','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(896011,'furniture','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(896012,'furniture','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(896013,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(896014,'furniture','.testimonials .review','padding-bottom','10','','',''),(896015,'furniture','.testimonials .heading-3','padding-bottom','10','','',''),(896016,'furniture','.testimonials .reviews-list .name','padding-bottom','5','','',''),(896017,'furniture','.testimonials .name','padding-bottom','5','','',''),(896018,'furniture','.w-categories .image','padding-bottom','75','','','.w-categories'),(896019,'furniture','.w-promotions .prom-multi-discount .promo-range','padding-bottom','0','','','.w-promotions'),(896020,'furniture','.w-promotions .prom-multi-discount .promo-product','padding-bottom','20','','','.w-promotions'),(896021,'furniture','.w-promotions .nextdiscount .promo-for-each','padding-bottom','2','','','.w-promotions'),(896022,'furniture','.w-promotions .nextdiscount .content > div','padding-bottom','10','','','.w-promotions'),(896023,'furniture','.w-promotions .promo-salemaker .item','padding-bottom','20','','','.w-promotions'),(896024,'furniture','.w-promotions .promo-salemaker .discount','padding-bottom','0','','','.w-promotions'),(896025,'furniture','.w-promotions .promo-cart-discount .slave .item','padding-bottom','20','','','.w-promotions'),(896026,'furniture','.w-promotions .promo-cart-discount .slave .heading','padding-bottom','1','','','.w-promotions'),(896027,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','padding-bottom','0','','','.w-promotions'),(896028,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','padding-bottom','0','','','.w-promotions'),(896029,'furniture','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-bottom','20','','','.b-warehouses-popup'),(896030,'furniture','.w-product-available-in-warehouses .warehouse-item','padding-bottom','20','','','.w-product-available-in-warehouses'),(896031,'furniture','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-bottom','6','','','.b-products-listing'),(896033,'furniture','.w-cart-compare .attributes-cell','padding-bottom','8','','','.w-cart-compare'),(896034,'furniture','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(896035,'furniture','.b-bottom .confirm-popup .confirm-text','padding-bottom','30','','','.b-bottom'),(896036,'furniture','.b-messages .msv_btn','padding-bottom','12','','','.b-messages'),(896037,'furniture','.b-messages .msv_content','padding-bottom','10','','','.b-messages'),(896038,'furniture','.b-messages .msv_history','padding-bottom','10','','','.b-messages'),(896039,'furniture','.b-messages .messMenuButton span','padding-bottom','10','','','.b-messages'),(896040,'furniture','.b-messages .messages-menu li a','padding-bottom','8','','','.b-messages'),(896041,'furniture','.b-messages .messages-menu li','padding-bottom','0','','','.b-messages'),(896042,'furniture','.b-messages .messages-menu ul','padding-bottom','0','','','.b-messages'),(896043,'furniture','.b-messages .content_management_attach button','padding-bottom','1','','','.b-messages'),(896044,'furniture','.b-messages .email-heading','padding-bottom','15','','','.b-messages'),(896045,'furniture','.b-messages .content_management_attach','padding-bottom','8','','','.b-messages'),(896046,'furniture','.b-messages .emailLineTextArea textarea','padding-bottom','30','','','.b-messages'),(896047,'furniture','.b-messages .msv_to_cc','padding-bottom','10','','','.b-messages'),(896048,'furniture','.b-messages .emailBtn','padding-bottom','10','','','.b-messages'),(896049,'furniture','.b-messages .dataTables_wrapper > .bottom','padding-bottom','4','','','.b-messages'),(896050,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-bottom','5','','','.b-messages'),(896051,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-bottom','6','','',''),(896052,'furniture','.w-sitemap-delivery-location > ul > li > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(896054,'furniture','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(896055,'furniture','.w-reviews-content .item','padding-bottom','25','','','.w-reviews-content'),(896056,'furniture','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(896057,'furniture','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(896058,'furniture','.w-sitemap-delivery-location > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(896059,'furniture','.w-checkout-terms .required-message','padding-bottom','5','','','.w-checkout-terms'),(896060,'furniture','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(896061,'furniture','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(896062,'furniture','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(896063,'furniture','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(896064,'furniture','.b-email .model','padding-bottom','5','','','.b-email'),(896065,'furniture','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(896066,'furniture','.w-checkout-shipping-address .edit-ab','padding-bottom','0','','','.w-checkout-shipping-address'),(896067,'furniture','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(896068,'furniture','.w-reviews-content .author','padding-bottom','20','','','.w-reviews-content'),(896069,'furniture','.w-promo-code .holder','padding-bottom','20','5161','','.w-promo-code'),(896070,'furniture','.w-cart-listing .item .remove','padding-bottom','5','5140','','.w-cart-listing'),(896071,'furniture','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(896072,'furniture','.b-email .image','padding-bottom','5','','','.b-email'),(896073,'furniture','.b-email .heading-price','padding-bottom','5','','','.b-email'),(896074,'furniture','.b-email .heading-image','padding-bottom','5','','','.b-email'),(896075,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(896076,'furniture','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(896077,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(896078,'furniture','.w-filters .filter-ul-content','padding-bottom','0','','','.w-filters'),(896079,'furniture','.w-filters .filter-box-head','padding-bottom','5','','','.w-filters'),(896080,'furniture','.w-filters .filter-li-content','padding-bottom','15','','','.w-filters'),(896081,'furniture','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(896082,'furniture','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(896083,'furniture','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(896084,'furniture','.w-menu-horizontal > ul > li > ul > li','padding-bottom','2','','','.w-menu-horizontal'),(896085,'furniture','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-bottom','2','','','.w-menu-horizontal'),(896086,'furniture','.w-menu-horizontal ul','padding-bottom','0','','','.w-menu-horizontal'),(896087,'furniture','.w-tabs .tab-navigation','padding-bottom','0','','','.w-tabs'),(896088,'furniture','.b-table .table td','padding-bottom','15','','','.b-table'),(896089,'furniture','.b-email .heading-name','padding-bottom','5','','','.b-email'),(896090,'furniture','.b-email .heading-model','padding-bottom','5','','','.b-email'),(896092,'furniture','.b-email .totals-value','padding-bottom','5','','','.b-email'),(896093,'furniture','.b-email .name','padding-bottom','5','','','.b-email'),(896094,'furniture','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(896095,'furniture','.b-email .qty','padding-bottom','5','','','.b-email'),(896096,'furniture','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(896097,'furniture','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(896098,'furniture','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(896099,'furniture','.b-bottom .terms-info-popup .pop-up-content','padding-bottom','20','','','.b-bottom'),(896100,'furniture','.w-cart-compare .dropdown .dropdown-menu','padding-bottom','5','','','.w-cart-compare'),(896101,'furniture','.no-found','padding-bottom','20','','',''),(896102,'furniture','textarea','padding-bottom','5','','',''),(896103,'furniture','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(896104,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(896105,'furniture','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(896106,'furniture','.p-quick-order-index .bottom','padding-bottom','10','','','.p-quick-order-index'),(896107,'furniture','.w-chat .w-chat-box','padding-bottom','2','','','.w-chat'),(896109,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-bottom','10','','','.w-image-maps'),(896110,'furniture','.b-table .table td','padding-bottom','15','','','.b-table'),(896111,'furniture','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(896112,'furniture','.message.success','padding-bottom','15','','',''),(896113,'furniture','.w-personal-gift-status-bar .inform','padding-bottom','0','4','','.w-personal-gift-status-bar'),(896114,'furniture','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(896115,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(896116,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(896117,'furniture','.b-email .image','padding-bottom','5','','','.b-email'),(896118,'furniture','.b-email .heading-price','padding-bottom','5','','','.b-email'),(896119,'furniture','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-bottom','0','','','.b-fancybox'),(896120,'furniture','.w-checkout-shipping-choice span','padding-bottom','4','','','.w-checkout-shipping-choice'),(896121,'furniture','.b-email .model','padding-bottom','5','','','.b-email'),(896122,'furniture','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(896123,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-bottom','0','','','.b-select-suggest'),(896124,'furniture','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(896125,'furniture','.w-reviews .review','padding-bottom','5','','','.w-reviews'),(896126,'furniture','.w-socials > li','padding-bottom','15','','','.w-socials'),(896128,'furniture','.b-info-popup .info-popup div','padding-bottom','10','','','.b-info-popup'),(896129,'furniture','.b-form .payment-method .item','padding-bottom','7','','','.b-form'),(896130,'furniture','.w-checkout-create-account .create-account','padding-bottom','10','','','.w-checkout-create-account'),(896131,'furniture','.b-form .password-forgotten-link','padding-bottom','0','','','.b-form'),(896132,'furniture','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(896133,'furniture','.w-catalog-sorting .before','padding-bottom','0','','','.w-catalog-sorting'),(896135,'furniture','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(896136,'furniture','.b-email .qty','padding-bottom','5','','','.b-email'),(896137,'furniture','.b-email .heading-price','padding-bottom','5','','','.b-email'),(896138,'furniture','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(896139,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(896140,'furniture','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-bottom','3','','','.w-multi-cart-actions'),(896141,'furniture','.w-top-categories .item','padding-bottom','30','','','.w-top-categories'),(896142,'furniture','.w-tabs > .block','padding-bottom','20','','','.w-tabs'),(896143,'furniture','.w-tabs .accordion-heading','padding-bottom','6','2','','.w-tabs'),(896144,'furniture','.w-tabs .accordion-heading','padding-bottom','9','5131','','.w-tabs'),(896145,'furniture','.w-cart-cart-tabs .w-tabs > .block','padding-bottom','0','','','.w-cart-cart-tabs'),(896146,'furniture','.w-tabs .tab-a','padding-bottom','12','','','.w-tabs'),(896147,'furniture','.w-tabs .tab-li','padding-bottom','0','','','.w-tabs'),(896148,'furniture','.w-socials > li','padding-bottom','15','','','.w-socials'),(896149,'furniture','.w-promo-code .holder','padding-bottom','20','5161','','.w-promo-code'),(896150,'furniture','.b-bottom .popup-buttons','padding-bottom','15','','','.b-bottom'),(896151,'furniture','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-bottom','7','','','.order-summary'),(896152,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(896153,'furniture','.b-sub-totals .historyTotal td','padding-bottom','2','','','.b-sub-totals'),(896154,'furniture','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(896155,'furniture','.b-form .required-message','padding-bottom','0','','','.b-form'),(896156,'furniture','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(896157,'furniture','.btn-1','padding-bottom','4','','',''),(896158,'furniture','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(896159,'furniture','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(896160,'furniture','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(896161,'furniture','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(896162,'furniture','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(896164,'furniture','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(896165,'furniture','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(896166,'furniture','.btn-3','padding-bottom','13','','',''),(896167,'furniture','.b-products-listing .products-listing .buyButton .btn','padding-bottom','4','','','.b-products-listing'),(896168,'furniture','.w-product-images-additional .images','padding-bottom','20','5161','','.w-product-images-additional'),(896169,'furniture','.b-form .required-message-wrap','padding-bottom','0','','','.b-form'),(896170,'furniture','.b-email .image','padding-bottom','5','','','.b-email'),(896171,'furniture','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(896172,'furniture','.w-cart-discount-coupon .btn','padding-bottom','4','','','.w-cart-discount-coupon'),(896173,'furniture','.b-email .heading-image','padding-bottom','5','','','.b-email'),(896174,'furniture','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(896175,'furniture','.b-email .heading-model','padding-bottom','5','','','.b-email'),(896176,'furniture','.order-summary .price-row','padding-bottom','7','','','.order-summary'),(896177,'furniture','.b-email .heading-model','padding-bottom','5','','','.b-email'),(896178,'furniture','.b-email .price','padding-bottom','5','','','.b-email'),(896179,'furniture','.b-email .heading-name','padding-bottom','5','','','.b-email'),(896180,'furniture','.w-socials > li','padding-bottom','15','','','.w-socials'),(896181,'furniture','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(896182,'furniture','.b-upload-file .upload-file-template','padding-bottom','25','','','.b-upload-file'),(896184,'furniture','.b-select-suggest .select2-drop-mask','padding-bottom','0','','','.b-select-suggest'),(896185,'furniture','.w-quote .cart-box-link','padding-bottom','0','','','.w-quote'),(896186,'furniture','.w-reviews .author','padding-bottom','10','','','.w-reviews'),(896187,'furniture','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(896188,'furniture','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(896189,'furniture','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(896190,'furniture','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(896191,'furniture','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(896192,'furniture','.b-email .price','padding-bottom','5','','','.b-email'),(896193,'furniture','.b-fancybox .fancybox-title-float-wrap .child','padding-bottom','2','','','.b-fancybox'),(896194,'furniture','.w-checkout-shipping-choice span','padding-bottom','4','5161','','.w-checkout-shipping-choice'),(896195,'furniture','.w-top-categories .categories h2','padding-bottom','0','','','.w-top-categories'),(896196,'furniture','.w-top-categories .image','padding-bottom','75','','','.w-top-categories'),(896197,'furniture','.w-product-reviews .reviews-list .review','padding-bottom','10','','','.w-product-reviews'),(896198,'furniture','.w-product-reviews .reviews-list .name','padding-bottom','5','','','.w-product-reviews'),(896199,'furniture','.w-reviews-content .rating','padding-bottom','10','','','.w-reviews-content'),(896200,'furniture','.b-email .totals-value','padding-bottom','5','','','.b-email'),(896201,'furniture','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(896202,'furniture','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(896203,'furniture','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(896204,'furniture','.b-table .table td','padding-bottom','15','','','.b-table'),(896205,'furniture','.b-bottom .rfq-form','padding-bottom','0','','','.b-bottom'),(896206,'furniture','.b-bottom .popup-simple','padding-bottom','20','','','.b-bottom'),(896207,'furniture','.b-bottom .popup-heading','padding-bottom','12','','','.b-bottom'),(896208,'furniture','.b-email .model','padding-bottom','5','','','.b-email'),(896209,'furniture','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(896210,'furniture','.b-email .image','padding-bottom','5','','','.b-email'),(896211,'furniture','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(896212,'furniture','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(896213,'furniture','.b-email .image','padding-bottom','5','','','.b-email'),(896214,'furniture','.b-email .name','padding-bottom','5','','','.b-email'),(896215,'furniture','.b-email .heading-price','padding-bottom','5','','','.b-email'),(896216,'furniture','.b-email .heading-model','padding-bottom','5','','','.b-email'),(896217,'furniture','.b-email .totals-title','padding-bottom','5','','','.b-email'),(896218,'furniture','.b-email .totals-value','padding-bottom','5','','','.b-email'),(896219,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(896220,'furniture','.b-email .qty','padding-bottom','5','','','.b-email'),(896221,'furniture','.b-email .model','padding-bottom','5','','','.b-email'),(896222,'furniture','.b-email .price','padding-bottom','5','','','.b-email'),(896223,'furniture','.b-email .heading-name','padding-bottom','5','','','.b-email'),(896224,'furniture','.b-email .heading-image','padding-bottom','5','','','.b-email'),(896225,'furniture','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(896226,'furniture','.w-checkout-shipping .sub-item','padding-bottom','5','','','.w-checkout-shipping'),(896227,'furniture','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(896228,'furniture','.b-email .totals-value','padding-bottom','5','','','.b-email'),(896229,'furniture','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(896230,'furniture','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(896231,'furniture','.b-table .table td','padding-bottom','15','','','.b-table'),(896232,'furniture','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(896233,'furniture','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(896234,'furniture','.w-promo-code .holder','padding-bottom','20','5161','','.w-promo-code'),(896235,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(896236,'furniture','.b-form .center-buttons','padding-bottom','20','','','.b-form'),(896237,'furniture','.b-form .shipping-method .input','padding-bottom','0','','','.b-form'),(896238,'furniture','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(896239,'furniture','.w-reviews .item','padding-bottom','15','','','.w-reviews'),(896240,'furniture','.w-reviews .product-name','padding-bottom','12','','','.w-reviews'),(896241,'furniture','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(896242,'furniture','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(896243,'furniture','.b-select-suggest .select2-container .select2-choice','padding-bottom','0','','','.b-select-suggest'),(896244,'furniture','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(896245,'furniture','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(896246,'furniture','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(896247,'furniture','.w-cart-compare .price-label','padding-bottom','10','','','.w-cart-compare'),(896248,'furniture','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(896249,'furniture','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(896251,'furniture','.b-upload-files .upload-files','padding-bottom','10','','','.b-upload-files'),(896252,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(896253,'furniture','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(896254,'furniture','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(896255,'furniture','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(896256,'furniture','.b-form .col-full-padding','padding-bottom','30','','','.b-form'),(896257,'furniture','.w-categories .item','padding-bottom','30','','','.w-categories'),(896258,'furniture','.b-form .form-buttons','padding-bottom','50','','','.b-form'),(896259,'furniture','.b-fancybox .fancybox-title-over-wrap','padding-bottom','10','','','.b-fancybox'),(896260,'furniture','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(896261,'furniture','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(896262,'furniture','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(896263,'furniture','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(896264,'furniture','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(896265,'furniture','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(896266,'furniture','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(896267,'furniture','.w-cart-compare .delete-cart','padding-bottom','10','','','.w-cart-compare'),(896268,'furniture','.w-personal-gift-status-bar .end-date','padding-bottom','0','3','','.w-personal-gift-status-bar'),(896269,'furniture','.p-quick-order-index .all-scroll-div','padding-bottom','10','','','.p-quick-order-index'),(896270,'furniture','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(896271,'furniture','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(896272,'furniture','.w-checkout-billing-address .same-address','padding-bottom','10','','','.w-checkout-billing-address'),(896273,'furniture','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(896274,'furniture','.b-email .heading-image','padding-bottom','5','','','.b-email'),(896275,'furniture','.b-email .price','padding-bottom','5','','','.b-email'),(896276,'furniture','.b-email .heading-name','padding-bottom','5','','','.b-email'),(896277,'furniture','.b-email .model','padding-bottom','5','','','.b-email'),(896278,'furniture','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-bottom','10','','','.b-bottom'),(896279,'furniture','.w-cart-compare .cart-cell','padding-bottom','20','','','.w-cart-compare'),(896280,'furniture','.w-promotions .promo-cart-discount .master .item','padding-bottom','20','','','.w-promotions'),(896281,'furniture','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(896282,'furniture','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(896283,'furniture','.b-bottom .cart-options','padding-bottom','20','','','.b-bottom'),(896284,'furniture','.b-bottom .alert-message','padding-bottom','20','','','.b-bottom'),(896285,'furniture','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(896286,'furniture','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(896287,'furniture','.b-select-suggest .select2-results .select2-result-label','padding-bottom','4','','','.b-select-suggest'),(896288,'furniture','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(896289,'furniture','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(896290,'furniture','.b-email .totals-title','padding-bottom','5','','','.b-email'),(896291,'furniture','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(896292,'furniture','.w-reviews-content .product-name','padding-bottom','20','','','.w-reviews-content'),(896293,'furniture','.b-email .name','padding-bottom','5','','','.b-email'),(896294,'furniture','.b-email .heading-price','padding-bottom','5','','','.b-email'),(896295,'furniture','.b-email .heading-image','padding-bottom','5','','','.b-email'),(896296,'furniture','.b-email .heading-name','padding-bottom','5','','','.b-email'),(896297,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(896298,'furniture','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(896299,'furniture','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-bottom','4','','','.b-compare'),(896300,'furniture','.b-bottom .pop-up-close','padding-bottom','1','','','.b-bottom'),(896301,'furniture','.b-bottom .footerTitle','padding-bottom','9','5131','','.b-bottom'),(896302,'furniture','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(896303,'furniture','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(896304,'furniture','.w-cart-up-sell .w-list-type-1','padding-bottom','0','','','.w-cart-up-sell'),(896305,'furniture','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','0','1','','.w-cart-up-sell'),(896306,'furniture','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','1','','','.w-cart-up-sell'),(896307,'furniture','.b-products-listing .products-listing .btn-buy','padding-bottom','4','','','.b-products-listing'),(896308,'furniture','.b-upload-files .added-file','padding-bottom','5','','','.b-upload-files'),(896310,'furniture','.w-menu-big ul','padding-bottom','0','','','.w-menu-big'),(896311,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(896312,'furniture','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(896313,'furniture','.w-categories h2.name','padding-bottom','3','','','.w-categories'),(896314,'furniture','.b-bottom .header-info','padding-bottom','20','','','.b-bottom'),(896315,'furniture','.b-bottom .popup-box-wrap','padding-bottom','10','','','.b-bottom'),(896316,'furniture','.w-product-images-additional .images','padding-bottom','20','5161','','.w-product-images-additional'),(896317,'furniture','.b-bottom .pop-up-info','padding-bottom','20','','','.b-bottom'),(896318,'furniture','.b-email .price','padding-bottom','5','','','.b-email'),(896319,'furniture','.b-fancybox .fancybox-error','padding-bottom','15','','','.b-fancybox'),(896320,'furniture','.w-product-customers-activity .customers-activity','padding-bottom','20','','','.w-product-customers-activity'),(896321,'furniture','.b-compare .compare-box-item','padding-bottom','10','','','.b-compare'),(896322,'furniture','.b-bottom .confirm-popup .buttons','padding-bottom','30','','','.b-bottom'),(896323,'furniture','.b-compare .compare-head','padding-bottom','0','','','.b-compare'),(896324,'furniture','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(896325,'furniture','.b-email .heading-image','padding-bottom','5','','','.b-email'),(896326,'furniture','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(896327,'furniture','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(896328,'furniture','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(896329,'furniture','.b-form .login-col-1','padding-bottom','0','','','.b-form'),(896330,'furniture','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(896331,'furniture','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(896333,'furniture','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(896334,'furniture','.w-checkout-billing-address .edit-ab','padding-bottom','0','','','.w-checkout-billing-address'),(896335,'furniture','.w-checkout-shipping-choice #shippingchoice-choice','padding-bottom','7','','','.w-checkout-shipping-choice'),(896336,'furniture','.w-promo-code .holder','padding-bottom','20','5161','','.w-promo-code'),(896337,'furniture','.w-product-images-additional .images','padding-bottom','20','5161','','.w-product-images-additional'),(896338,'furniture','.b-bottom .header-error','padding-bottom','20','','','.b-bottom'),(896339,'furniture','.w-tabs .accordion-heading','padding-bottom','8','','','.w-tabs'),(896340,'furniture','.w-socials > li','padding-bottom','15','','','.w-socials'),(896341,'furniture','.b-autocomplete .ui-autocomplete li','padding-bottom','3','','','.b-autocomplete'),(896342,'furniture','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(896343,'furniture','.w-cart-give-away .ga_column','padding-bottom','15','','','.w-cart-give-away'),(896344,'furniture','.w-cart-compare .price-cell','padding-bottom','8','','','.w-cart-compare'),(896345,'furniture','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(896346,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(896347,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(896348,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-bottom','5','','','.b-select-suggest'),(896349,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-bottom','0','','','.b-select-suggest'),(896350,'furniture','.b-select-suggest .select2-locked','padding-bottom','3','','','.b-select-suggest'),(896351,'furniture','.b-select-suggest .select2-container-multi .select2-choices','padding-bottom','0','','','.b-select-suggest'),(896352,'furniture','.b-select-suggest .select2-results','padding-bottom','0','','','.b-select-suggest'),(896353,'furniture','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','5','','','.w-menu-horizontal'),(896354,'furniture','.b-form .shipping-method .item + .item','padding-bottom','5','','','.b-form'),(896355,'furniture','.b-select-suggest .select2-search input','padding-bottom','4','','','.b-select-suggest'),(896356,'furniture','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(896357,'furniture','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','12','5140','','.w-menu-horizontal'),(896358,'furniture','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(896359,'furniture','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(896360,'furniture','.w-socials > li','padding-bottom','15','','','.w-socials'),(896363,'furniture','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(896364,'furniture','.w-cart-compare .dropdown li','padding-bottom','5','','','.w-cart-compare'),(896365,'furniture','.w-cart-compare .product-label','padding-bottom','15','','','.w-cart-compare'),(896368,'furniture','.b-compare .col-two label','padding-bottom','5','','','.b-compare'),(896369,'furniture','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(896372,'furniture','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(896373,'furniture','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(896374,'furniture','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(896375,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(896376,'furniture','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(896377,'furniture','.w-account-addresses-list .addsess-suggestion-item','padding-bottom','20','','','.w-account-addresses-list'),(896378,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.b-data-table'),(896379,'furniture','.w-communication-post .communication-post','padding-bottom','5','','','.w-communication-post'),(896380,'furniture','.w-communication-post .communication-post-author','padding-bottom','10','','','.w-communication-post'),(896381,'furniture','.b-products-listing .products-listing a.btn.view-button','padding-bottom','0','','','.b-products-listing'),(896382,'furniture','.b-products-listing .in-cart','padding-bottom','4','','','.b-products-listing'),(896383,'furniture','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-bottom','5','','','.w-catalog-b2b-add-button'),(896384,'furniture','.b-products-listing .promos-info .promo-item','padding-bottom','3','','','.b-products-listing'),(896385,'furniture','.b-products-listing .promos-info .promo-name','padding-bottom','3','','','.b-products-listing'),(896391,'furniture','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(896392,'furniture','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(896393,'furniture','.w-checkout-gdpr .privacy-row','padding-bottom','0','','','.w-checkout-gdpr'),(896394,'furniture','.w-checkout-gdpr .terms-login','padding-bottom','0','','','.w-checkout-gdpr'),(896395,'furniture','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(896396,'furniture','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(896397,'furniture','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(896398,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(896399,'furniture','.b-email .qty','padding-bottom','5','','','.b-email'),(896400,'furniture','.b-email .name','padding-bottom','5','','','.b-email'),(896401,'furniture','.b-email .heading-price','padding-bottom','5','','','.b-email'),(896402,'furniture','.w-reviews .heading-3','padding-bottom','15','','','.w-reviews'),(896404,'furniture','.w-personal-gift-status-bar .timeline','padding-bottom','16','','','.w-personal-gift-status-bar'),(896405,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(896406,'furniture','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(896407,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(896408,'furniture','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(896409,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-bottom','0','','',''),(896410,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-bottom','0','','','.b-h-inline'),(896411,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-bottom','0','','','.w-communication-new-topic'),(896412,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-bottom','5','','','.w-communication-new-topic'),(896413,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-bottom','5','','','.w-communication-new-topic'),(896414,'furniture','.w-communication-new-topic #communication_topic_form .middle-form','padding-bottom','0','','','.w-communication-new-topic'),(896415,'furniture','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(896416,'furniture','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(896417,'furniture','.b-bottom .popup-content','padding-bottom','15','','','.b-bottom'),(896418,'furniture','.b-compare .compare_pagination','padding-bottom','10','','','.b-compare'),(896419,'furniture','.w-promo-code .holder','padding-bottom','20','5161','','.w-promo-code'),(896420,'furniture','.w-top-categories .item','padding-bottom','30','5131','','.w-top-categories'),(896421,'furniture','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(896422,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(896423,'furniture','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(896426,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(896427,'furniture','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(896428,'furniture','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(896429,'furniture','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(896430,'furniture','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(896431,'furniture','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-bottom','0','','','.b-fancybox'),(896432,'furniture','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(896433,'furniture','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(896434,'furniture','.b-email .qty','padding-bottom','5','','','.b-email'),(896435,'furniture','.b-email .totals-title','padding-bottom','5','','','.b-email'),(896436,'furniture','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(896437,'furniture','.b-email .name','padding-bottom','5','','','.b-email'),(896438,'furniture','.products-quick-index .token-input-list','padding-bottom','0','','',''),(896439,'furniture','.w-cart-compare .product','padding-bottom','10','','','.w-cart-compare'),(896440,'furniture','.w-cart-compare .product-actions','padding-bottom','0','','','.w-cart-compare'),(896441,'furniture','.w-cart-shipping-estimator .address-item','padding-bottom','20','','','.w-cart-shipping-estimator'),(896442,'furniture','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(896443,'furniture','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(896444,'furniture','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(896445,'furniture','.b-form .shipping-method .item','padding-bottom','5','','','.b-form'),(896446,'furniture','.b-email .model','padding-bottom','5','','','.b-email'),(896447,'furniture','.b-email .totals-title','padding-bottom','5','','','.b-email'),(896448,'furniture','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(896449,'furniture','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(896450,'furniture','.w-product-images-additional .images','padding-bottom','20','5161','','.w-product-images-additional'),(896451,'furniture','.b-email .totals-value','padding-bottom','5','','','.b-email'),(896452,'furniture','.w-cart-listing .item .gift-wrap label','padding-bottom','10','','','.w-cart-listing'),(896453,'furniture','.w-cart-listing .item > div','padding-bottom','10','','','.w-cart-listing'),(896454,'furniture','.w-cart-listing .points-earn','padding-bottom','5','','','.w-cart-listing'),(896455,'furniture','.w-cart-listing .points-redeem','padding-bottom','10','','','.w-cart-listing'),(896461,'furniture','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(896462,'furniture','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(896463,'furniture','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(896464,'furniture','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(896465,'furniture','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(896466,'furniture','.b-email .totals-value','padding-bottom','5','','','.b-email'),(896467,'furniture','.b-email .totals-title','padding-bottom','5','','','.b-email'),(896468,'furniture','.b-email .price','padding-bottom','5','','','.b-email'),(896469,'furniture','.b-email .name','padding-bottom','5','','','.b-email'),(896470,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(896471,'furniture','.b-email .heading-name','padding-bottom','5','','','.b-email'),(896472,'furniture','.b-email .image','padding-bottom','5','','','.b-email'),(896473,'furniture','.w-product-images-additional .images','padding-bottom','20','5161','','.w-product-images-additional'),(896474,'furniture','.w-promo-code .holder','padding-bottom','20','5161','','.w-promo-code'),(896475,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(896476,'furniture','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(896477,'furniture','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(896478,'furniture','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(896479,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(896481,'furniture','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(896482,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(896483,'furniture','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(896484,'furniture','.w-filters .fsl_handle','padding-bottom','15','','','.w-filters'),(896485,'furniture','.w-filters .head-filter-widget','padding-bottom','0','5140','','.w-filters'),(896486,'furniture','.w-filters .filter-box-content','padding-bottom','20','','','.w-filters'),(896487,'furniture','.w-filters .ui-slider-range','padding-bottom','0','','','.w-filters'),(896488,'furniture','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(896490,'furniture','.w-filters .head-filter-widget','padding-bottom','10','','','.w-filters'),(896491,'furniture','.b-autocomplete .ui-autocomplete','padding-bottom','2','','','.b-autocomplete'),(896492,'furniture','.b-bottom .notify-form','padding-bottom','0','','','.b-bottom'),(896493,'furniture','.order-summary .heading-2','padding-bottom','0','','','.order-summary'),(896494,'furniture','.w-personal-gift-status-bar .end-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(896495,'furniture','.b-compare .column_wrapper','padding-bottom','10','','','.b-compare'),(896496,'furniture','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(896497,'furniture','.b-email .heading-model','padding-bottom','5','','','.b-email'),(896498,'furniture','.w-socials > li','padding-bottom','15','','','.w-socials'),(896499,'furniture','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(896500,'furniture','.w-reviews-content .review','padding-bottom','10','','','.w-reviews-content'),(896501,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom','0','','','.b-data-table'),(896502,'furniture','.b-data-table table.dataTable tbody td','padding-bottom','10','','','.b-data-table'),(896503,'furniture','.b-data-table table.dataTable thead td','padding-bottom','10','','','.b-data-table'),(896504,'furniture','.b-compare .popupCompare .pop-up-content','padding-bottom','10','','','.b-compare'),(896506,'furniture','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(896507,'furniture','.btn-2','padding-bottom','12','','',''),(896509,'furniture','.w-quote-products .empty','padding-bottom','100','','','.w-quote-products'),(896510,'furniture','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(896511,'furniture','.b-table .table td','padding-bottom','15','','','.b-table'),(896512,'furniture','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(896513,'furniture','.b-compare .col-gender','padding-bottom','10','','','.b-compare'),(896514,'furniture','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(896515,'furniture','.b-email .totals-title','padding-bottom','5','','','.b-email'),(896516,'furniture','.b-email .qty','padding-bottom','5','','','.b-email'),(896517,'furniture','.btn','padding-bottom','6','','',''),(896518,'furniture','.b-product-images .media-popup .mp-content','padding-bottom','0','','','.b-product-images'),(896519,'furniture','.b-product-images .media-popup .mp-small-images .item','padding-bottom','10','','','.b-product-images'),(896520,'furniture','.b-product-images .media-popup .slick-dots','padding-bottom','0','','','.b-product-images'),(896521,'furniture','.b-product-images .media-popup .slick-dots li','padding-bottom','0','','','.b-product-images'),(896522,'furniture','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-bottom','0','','','.b-menu-style'),(896523,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-bottom','5','','','.b-menu-style-2'),(896524,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-bottom','5','','','.b-menu-style-2'),(896525,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-bottom','0','','','.b-menu-style-2'),(896526,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-bottom','0','','','.b-menu-style-2'),(896527,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-bottom','10','','','.b-menu-style-2'),(896528,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-bottom','0','','','.b-menu-style-2'),(896529,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-bottom','5','','','.b-menu-style-2'),(896530,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-bottom','10','','','.b-menu-style-2'),(896531,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-bottom','5','','','.b-menu-style-2'),(896532,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-bottom','10','','','.b-menu-style-2'),(896533,'furniture','.b-personal-catalog-popup #personal_catalog_popup','padding-bottom','20','','','.b-personal-catalog-popup'),(896534,'furniture','.b-trade-approval .steps-bar li a','padding-bottom','7','','','.b-trade-approval'),(896535,'furniture','.b-trade-approval .middle-form','padding-bottom','20','','','.b-trade-approval'),(896536,'furniture','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-bottom','5','','','.b-trade-approval'),(896537,'furniture','.b-trade-approval .steps-bar','padding-bottom','0','','','.b-trade-approval'),(896538,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-bottom','6','','','.b-trade-approval'),(896539,'furniture','.b-trade-approval .center-buttons','padding-bottom','20','','','.b-trade-approval'),(896540,'furniture','.w-account-personal-catalog .list-switcher','padding-bottom','0','','','.w-account-personal-catalog'),(896541,'furniture','.w-account-personal-catalog .list-switcher a','padding-bottom','12','','','.w-account-personal-catalog'),(896542,'furniture','.w-account-subscription .subscription-variant','padding-bottom','10','','','.w-account-subscription'),(896543,'furniture','.w-catalog-additional-images li','padding-bottom','10','','','.w-catalog-additional-images'),(896544,'furniture','.w-catalog-additional-images ul','padding-bottom','0','','','.w-catalog-additional-images'),(896545,'furniture','.w-catalog-compare td','padding-bottom','10','','','.w-catalog-compare'),(896546,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-bottom','0','','','.w-catalog-compare'),(896547,'furniture','.w-catalog-compare .cross-box .different-all > div','padding-bottom','11','2','','.w-catalog-compare'),(896548,'furniture','.w-catalog-compare .cross-box .different-all > div','padding-bottom','10','','','.w-catalog-compare'),(896549,'furniture','.w-delivery-day .left-count','padding-bottom','0','','','.w-delivery-day'),(896550,'furniture','.w-delivery-day .left-text-left','padding-bottom','24','','','.w-delivery-day'),(896551,'furniture','.w-delivery-day .left-text-right','padding-bottom','24','','','.w-delivery-day'),(896552,'furniture','.w-top-text .top-text','padding-bottom','5','','','.w-top-text'),(896553,'furniture','.w-product-images .additional-horizontal .item','padding-bottom','10','','','.w-product-images'),(896554,'furniture','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-bottom','10','','','.b-cookie-notice'),(896558,'furniture','.b-slick .slick-list','padding-bottom','0','','','.b-slick'),(896559,'furniture','.b-slick .slick-vertical button.slick-next','padding-bottom','0','3','','.b-slick'),(896560,'furniture','.b-slick .slick-vertical button.slick-prev','padding-bottom','0','3','','.b-slick'),(896561,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','padding-bottom','0','','','.b-slick'),(896562,'furniture','.cartTitle span','padding-bottom','0','','','.cartTitle'),(896563,'furniture','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','padding-bottom','0','','','.b-products-listing'),(896564,'furniture','.w-cart-listing .headings .head','padding-bottom','10','','','.w-cart-listing'),(896565,'furniture','.b-products-listing .item-nav > div','padding-bottom','10','','','.b-products-listing'),(896566,'furniture','.LeftCategories .w-menu-simple ul','padding-bottom','0','','','.LeftCategories'),(896567,'furniture','.LeftCategories .w-menu-simple ul li a','padding-bottom','4','','','.LeftCategories'),(896568,'furniture','.w-filters .filter-widget','padding-bottom','20','','','.w-filters'),(896569,'furniture','.b-products-listing .products-listing.list-productlisting .item','padding-bottom','20','','','.b-products-listing'),(896570,'furniture','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-bottom','0','','','.b-products-listing'),(896571,'furniture','.b-products-listing .products-listing.list-productlisting .item-content','padding-bottom','0','','','.b-products-listing'),(896572,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','padding-bottom','10','','','.b-products-listing'),(896573,'furniture','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-bottom','15','','','.b-products-listing'),(896574,'furniture','.b-products-listing .products-listing.list-rows .item-nav > div','padding-bottom','0','','','.b-products-listing'),(896575,'furniture','.w-breadcrumb .breadcrumb-li','padding-bottom','0','','','.w-breadcrumb'),(896576,'furniture','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(896577,'furniture','.w-subscribers .btn-submit','padding-bottom','6','','','.w-subscribers'),(896578,'furniture','.w-quote .buttons','padding-bottom','15','','','.w-quote'),(896579,'furniture','.w-quote .buttons .btn','padding-bottom','4','','','.w-quote'),(896580,'furniture','.w-quote .cart-content','padding-bottom','5','','','.w-quote'),(896581,'furniture','.w-quote .cart-total','padding-bottom','10','','','.w-quote'),(896582,'furniture','.w-quote .multicart .cart-content','padding-bottom','0','','','.w-quote'),(896583,'furniture','.w-quote .multicart .item','padding-bottom','15','','','.w-quote'),(896584,'furniture','.w-quote .multicart .name','padding-bottom','0','','','.w-quote'),(896585,'furniture','.w-quote .no-text','padding-bottom','0','','','.w-quote'),(896586,'furniture','.w-quote a.item','padding-bottom','5','','','.w-quote'),(896587,'furniture','.w-social-links a','padding-bottom','4','','','.w-social-links'),(896588,'furniture','.w-product-images .additional-vertical .additional-images','padding-bottom','30','','','.w-product-images'),(896589,'furniture','.w-product-personal-catalog-button .btn','padding-bottom','0','','','.w-product-personal-catalog-button'),(896590,'furniture','.b-quantity .qty-box input','padding-bottom','5','','','.b-quantity'),(896591,'furniture','.w-product-model > div','padding-bottom','7','','','.w-product-model'),(896592,'furniture','.w-product-sale-ends .left-count','padding-bottom','0','','','.w-product-sale-ends'),(896593,'furniture','.w-product-sale-ends .left-text-left','padding-bottom','24','','','.w-product-sale-ends'),(896594,'furniture','.w-product-sale-ends .left-text-right','padding-bottom','24','','','.w-product-sale-ends'),(896595,'furniture','.w-product-sale-ends .left-count-days','padding-bottom','7','','','.w-product-sale-ends'),(896596,'furniture','.w-product-sale-ends .left-count-hours','padding-bottom','7','','','.w-product-sale-ends'),(896597,'furniture','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(896598,'furniture','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(896599,'furniture','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(896600,'furniture','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(896601,'furniture','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(896602,'furniture','.warrantyProduct .warranty, .warrantyProduct .delivery','padding-bottom','10','','','.warrantyProduct'),(896603,'furniture','.w-compare .compare-list-buttons','padding-bottom','10','','','.w-compare'),(896604,'furniture','.w-compare .item-holder','padding-bottom','10','','','.w-compare'),(896605,'furniture','.w-compare .compare-list-products','padding-bottom','0','','','.w-compare'),(896606,'furniture','.w-files-catalog-widgets-files-catalog .name','padding-bottom','10','','','.w-files-catalog-widgets-files-catalog'),(896607,'furniture','.w-sample .buttons','padding-bottom','15','','','.w-sample'),(896608,'furniture','.w-sample .buttons .btn','padding-bottom','4','','','.w-sample'),(896609,'furniture','.w-sample .cart-box-link','padding-bottom','0','','','.w-sample'),(896610,'furniture','.w-sample .cart-content','padding-bottom','5','','','.w-sample'),(896611,'furniture','.w-sample .cart-total','padding-bottom','10','','','.w-sample'),(896612,'furniture','.w-sample .multicart .cart-content','padding-bottom','0','','','.w-sample'),(896613,'furniture','.w-sample .multicart .item','padding-bottom','15','','','.w-sample'),(896614,'furniture','.w-sample .multicart .name','padding-bottom','0','','','.w-sample'),(896615,'furniture','.w-sample .no-text','padding-bottom','0','','','.w-sample'),(896616,'furniture','.w-sample a.item','padding-bottom','5','','','.w-sample'),(896617,'furniture','.w-cart-listing .item > div.points','padding-bottom','0','','','.w-cart-listing'),(896618,'furniture','.w-filters-simple .integrate-price-holder','padding-bottom','10','','','.w-filters-simple'),(896619,'furniture','.w-product-video .item','padding-bottom','10','','','.w-product-video'),(896620,'furniture','.w-cart-bonus-points .title','padding-bottom','5','','','.w-cart-bonus-points'),(896621,'furniture','.shipping-ico .heading-3','padding-bottom','10','','','.shipping-ico'),(896622,'furniture','.w-cart-order-reference .btn','padding-bottom','4','','','.w-cart-order-reference'),(896623,'furniture','.w-cart-gift-certificate .btn','padding-bottom','4','','','.w-cart-gift-certificate'),(896624,'furniture','.w-cart-shipping-estimator .btn','padding-bottom','4','','','.w-cart-shipping-estimator'),(896625,'furniture','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(896626,'furniture','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(896627,'furniture','.w-product-in-bundles .attributes-item','padding-bottom','10','','','.w-product-in-bundles'),(896628,'furniture','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(896629,'furniture','.w-cart-listing .item > div.actions','padding-bottom','10','5131','','.w-cart-listing'),(896631,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-bottom','0','','','.b-products-listing'),(896632,'furniture','.b-pagination ul.pagination','padding-bottom','0','','','.b-pagination'),(896633,'furniture','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','padding-bottom','10','','','.w-catalog-compare'),(896634,'furniture','.w-product-properties-filters-widgets-chosen-filters .item','padding-bottom','3','','','.w-product-properties-filters-widgets-chosen-filters'),(896635,'furniture','.p-quote-checkout-index .datepicker-inline','padding-bottom','10','','','.p-quote-checkout-index'),(896636,'furniture','.p-sample-checkout-index .datepicker-inline','padding-bottom','10','','','.p-sample-checkout-index'),(896640,'furniture','.w-product-multi-inventory .radio-attributes','padding-bottom','5','','','.w-product-multi-inventory'),(896641,'furniture','.w-product-multi-inventory .radio-attributes .option-item','padding-bottom','10','','','.w-product-multi-inventory'),(896642,'furniture','.w-product-multi-inventory .radio-attributes > label','padding-bottom','10','','','.w-product-multi-inventory'),(896643,'furniture','.w-account-personal-catalog .list-row-action ul','padding-bottom','0','','','.w-account-personal-catalog'),(896644,'furniture','.w-account-personal-catalog .list-row-action li','padding-bottom','5','','','.w-account-personal-catalog'),(896645,'furniture','.w-account-personal-catalog .buy-box','padding-bottom','0','5131','','.w-account-personal-catalog'),(896646,'furniture','.b-products-listing .products-listing .radio-attributes','padding-bottom','5','','','.b-products-listing'),(896647,'furniture','.b-products-listing .products-listing .radio-attributes .option','padding-bottom','10','','','.b-products-listing'),(896648,'furniture','.b-products-listing .products-listing .radio-attributes > label','padding-bottom','10','','','.b-products-listing'),(896649,'furniture','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(896650,'furniture','.w-product-collection .right-area .btn','padding-bottom','14','','','.w-product-collection'),(896651,'furniture','.w-product-collection .right-area','padding-bottom','20','5140','','.w-product-collection'),(896652,'furniture','.w-product-attributes .radio-attributes','padding-bottom','5','','','.w-product-attributes'),(896653,'furniture','.w-product-attributes .radio-attributes .option-item','padding-bottom','10','','','.w-product-attributes'),(896654,'furniture','.w-product-attributes .radio-attributes > label','padding-bottom','10','','','.w-product-attributes'),(896655,'furniture','.w-product-properties .property-ul','padding-bottom','0','','','.w-product-properties'),(896656,'furniture','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(896657,'furniture','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(896658,'furniture','.w-product-groups ','padding-bottom','30','','','.w-product-groups'),(896659,'furniture','.w-product-groups .radioBox','padding-bottom','20','','','.w-product-groups'),(896660,'furniture','.w-product-groups .radioBox label','padding-bottom','0','','','.w-product-groups'),(896661,'furniture','.w-product-groups .radioBox label .containerBlock','padding-bottom','20','','','.w-product-groups'),(896662,'furniture','.w-product-groups .radioBox label .containerBlock','padding-bottom','5','5161','','.w-product-groups'),(896663,'furniture','.b-products-listing .mix-attributes .attribute-qty-block','padding-bottom','5','','','.b-products-listing'),(896664,'furniture','.b-products-listing .products-listing .attribute-qty-block','padding-bottom','5','','','.b-products-listing'),(896665,'furniture','.blogsidebar','padding-bottom','0','5140','',''),(896666,'furniture','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(896667,'furniture','.w-product-custom-bundle .chosen-products','padding-bottom','10','','','.w-product-custom-bundle'),(896668,'furniture','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-bottom','12','','','.w-product-custom-bundle'),(896669,'furniture','.w-product-custom-bundle .right-area .main-button','padding-bottom','20','5140','','.w-product-custom-bundle'),(896670,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list'),(896671,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list'),(896672,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list-block'),(896673,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list-block'),(896674,'furniture','.w-delivery-location-top-location-list .deliveryName','padding-bottom','10','','','.w-delivery-location-top-location-list'),(896675,'furniture','.w-delivery-location-location-list .deliveryName','padding-bottom','10','','','.w-delivery-location-location-list'),(896676,'furniture','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(896677,'furniture','.w-delivery-location-location-description .deliveryDesc','padding-bottom','10','','','.w-delivery-location-location-description'),(896678,'furniture','.w-delivery-location-location-long-description ','padding-bottom','20','','','.w-delivery-location-location-long-description'),(896679,'furniture','.w-delivery-location-location-list .deliveryListParrent a','padding-bottom','6','','','.w-delivery-location-location-list'),(896680,'furniture','.w-delivery-location-location-list .deliveryList li a','padding-bottom','10','','','.w-delivery-location-location-list'),(896681,'furniture','.w-delivery-location-featured-list .deliveryName','padding-bottom','10','','','.w-delivery-location-featured-list'),(896682,'furniture','.btn-2','padding-bottom','6','5131','',''),(896683,'furniture','.w-sale-category .holder-1','padding-bottom','20','','','.w-sale-category'),(896684,'furniture','.w-sale-category .holder-2','padding-bottom','20','','','.w-sale-category'),(896685,'furniture','.w-sale-category .left-count','padding-bottom','0','','','.w-sale-category'),(896686,'furniture','.w-sale-category .left-text-left','padding-bottom','24','','','.w-sale-category'),(896687,'furniture','.w-sale-category .left-text-right','padding-bottom','24','','','.w-sale-category'),(896688,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(896689,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(896690,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(896691,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(896692,'furniture','.w-product-properties-icons .property-image','padding-bottom','10','','','.w-product-properties-icons'),(896693,'furniture','.w-product-properties-icons .hover-box-content','padding-bottom','10','','','.w-product-properties-icons'),(896694,'furniture','.w-delivery-location-product-categories .item.category-link','padding-bottom','15','','','.w-delivery-location-product-categories'),(896695,'furniture','.w-delivery-location-product-categories .item.category-link','padding-bottom','10','5140','','.w-delivery-location-product-categories'),(896696,'furniture','.w-delivery-location-product-categories .item.category-link','padding-bottom','10','5161','','.w-delivery-location-product-categories'),(896697,'furniture','.w-delivery-location-product-categories .name','padding-bottom','10','','','.w-delivery-location-product-categories'),(896698,'furniture','.w-catalog-delivery-locations .name','padding-bottom','10','','','.w-catalog-delivery-locations'),(896699,'furniture','.delivery-options-popup','padding-bottom','20','','',''),(896700,'furniture','.w-product-bonus-points .bonus-points-cost','padding-bottom','7','','','.w-product-bonus-points'),(896701,'furniture','.w-product-designer-designer .grnamebox .title-sortable','padding-bottom','8','','','.w-product-designer-designer'),(896702,'furniture','.w-product-designer-designer .prodDesignerType label','padding-bottom','10','','','.w-product-designer-designer'),(896703,'furniture','.w-press-reviews-widgets-press-reviews-small ','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews-small'),(896704,'furniture','.w-press-reviews-widgets-press-reviews ','padding-bottom','30','','','.w-press-reviews-widgets-press-reviews'),(896705,'furniture','.w-press-reviews-widgets-press-reviews .author','padding-bottom','20','','','.w-press-reviews-widgets-press-reviews'),(896706,'furniture','.w-press-reviews-widgets-press-reviews .item','padding-bottom','20','','','.w-press-reviews-widgets-press-reviews'),(896707,'furniture','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-bottom','30','','','.w-press-reviews-widgets-press-reviews'),(896708,'furniture','.w-press-reviews-widgets-press-reviews .rating','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews'),(896709,'furniture','.w-press-reviews-widgets-press-reviews .review','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews'),(896710,'furniture','.w-press-reviews-widgets-press-reviews ','padding-bottom','20','5131','','.w-press-reviews-widgets-press-reviews'),(896711,'furniture','.w-press-reviews-widgets-press-reviews .author','padding-bottom','0','5131','','.w-press-reviews-widgets-press-reviews'),(896712,'furniture','.w-press-reviews-widgets-press-reviews .item','padding-bottom','15','5131','','.w-press-reviews-widgets-press-reviews'),(896713,'furniture','.w-press-reviews-widgets-press-reviews .review','padding-bottom','10','5131','','.w-press-reviews-widgets-press-reviews'),(896714,'furniture','.w-press-reviews-widgets-press-reviews-list .date-added','padding-bottom','20','','','.w-press-reviews-widgets-press-reviews-list'),(896715,'furniture','.w-press-reviews-widgets-press-reviews-list .item','padding-bottom','0','','','.w-press-reviews-widgets-press-reviews-list'),(896716,'furniture','.w-press-reviews-widgets-press-reviews-list .rating','padding-bottom','5','','','.w-press-reviews-widgets-press-reviews-list'),(896717,'furniture','.w-press-reviews-widgets-press-reviews-list .short-description','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(896718,'furniture','.b-products-listing .productGroup label a','padding-bottom','5','','','.b-products-listing'),(896719,'furniture','.w-support-system-filter ','padding-bottom','25','','','.w-support-system-filter'),(896720,'furniture','.w-support-system-filter .filter_cats','padding-bottom','0','','','.w-support-system-filter'),(896721,'furniture','.w-support-system-listing .support-head','padding-bottom','13','','','.w-support-system-listing'),(896722,'furniture','.w-communication-post .btn.refresh','padding-bottom','0','','','.w-communication-post'),(896723,'furniture','.w-rma-returns-history .btn','padding-bottom','7','','','.w-rma-returns-history'),(896724,'furniture','.w-rma-returns-history .column','padding-bottom','0','','','.w-rma-returns-history'),(896725,'furniture','.w-rma-returns-history .column .title','padding-bottom','5','','','.w-rma-returns-history'),(896726,'furniture','.w-rma-returns-history .topRow','padding-bottom','10','','','.w-rma-returns-history'),(896727,'furniture','.w-rma-returns-history .column:last-child .title','padding-bottom','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(896728,'furniture','.w-product-designer-designer .productDesignerBox ul','padding-bottom','0','','','.w-product-designer-designer'),(896729,'furniture','.w-product-configurator .pc-item','padding-bottom','0','','','.w-product-configurator'),(896730,'furniture','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(896731,'furniture','.w-product-configurator .pc_item','padding-bottom','10','5140','','.w-product-configurator'),(896732,'furniture','.w-product-configurator .pc_attr','padding-bottom','5','5131','','.w-product-configurator'),(896733,'furniture','.b-products-listing .products-listing .bonus-points-cost','padding-bottom','7','','','.b-products-listing'),(896734,'furniture','.b-products-listing .promos-info .promo-name-span','padding-bottom','3','','','.b-products-listing'),(896735,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-list'),(896736,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-bottom','20','','','.w-catalog-pages-category-pages-list'),(896737,'furniture','.w-predefined-promotion .nextdiscount .content > div','padding-bottom','10','','','.w-predefined-promotion'),(896738,'furniture','.w-predefined-promotion .nextdiscount .promo-for-each','padding-bottom','2','','','.w-predefined-promotion'),(896739,'furniture','.w-predefined-promotion .prom-multi-discount .promo-product','padding-bottom','20','','','.w-predefined-promotion'),(896740,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','padding-bottom','0','','','.w-predefined-promotion'),(896741,'furniture','.w-predefined-promotion .promo-cart-discount .master .item','padding-bottom','20','','','.w-predefined-promotion'),(896742,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-bottom','0','','','.w-predefined-promotion'),(896743,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-bottom','0','','','.w-predefined-promotion'),(896744,'furniture','.w-predefined-promotion .promo-cart-discount .slave .heading','padding-bottom','1','','','.w-predefined-promotion'),(896745,'furniture','.w-predefined-promotion .promo-cart-discount .slave .item','padding-bottom','20','','','.w-predefined-promotion'),(896746,'furniture','.w-predefined-promotion .promo-item','padding-bottom','20','','','.w-predefined-promotion'),(896747,'furniture','.w-predefined-promotion .promo-salemaker .discount','padding-bottom','0','','','.w-predefined-promotion'),(896748,'furniture','.w-predefined-promotion .promo-salemaker .item','padding-bottom','20','','','.w-predefined-promotion'),(896749,'furniture','.w-supplier-purchase-supplier-products .item','padding-bottom','10','','','.w-supplier-purchase-supplier-products'),(896750,'furniture','.w-filters .filter-box-content ul','padding-bottom','20','','','.w-filters'),(896751,'furniture','.mainBanner .bottomBox','padding-bottom','55','','','.mainBanner'),(896752,'furniture','.mainBanner .bottomBox .btn','padding-bottom','1.09','','','.mainBanner'),(896753,'furniture','.mainBanner .title','padding-bottom','30','','','.mainBanner'),(896754,'furniture','.mainBanner .topBox > .right','padding-bottom','5','','','.mainBanner'),(896755,'furniture','.mainBanner .wrapper','padding-bottom','0','','','.mainBanner'),(896756,'furniture','.mainBanner .bottomBox','padding-bottom','33','5145','','.mainBanner'),(896757,'furniture','.mainBanner .bottomBox .btn','padding-bottom','8','5145','','.mainBanner'),(896758,'furniture','.mainBanner .topBox > .right','padding-bottom','5','5145','','.mainBanner'),(896759,'furniture','.mainBanner .wrapper','padding-bottom','0','5145','','.mainBanner'),(896760,'furniture','.mainBanner .bottomBox .btn','padding-bottom','6','5140','','.mainBanner'),(896761,'furniture','.mainBanner .title','padding-bottom','15','5140','','.mainBanner'),(896762,'furniture','.mainBanner .topBox > .right','padding-bottom','5','5131','','.mainBanner'),(896763,'furniture','.mainBanner .wrapper','padding-bottom','3','5131','','.mainBanner'),(896764,'furniture','.mainBanner .bottomBox','padding-bottom','25','5161','','.mainBanner'),(896765,'furniture','.mainBanner .bottomBox .btn','padding-bottom','4','5161','','.mainBanner'),(896766,'furniture','.mainBanner .wrapper','padding-bottom','8','5161','','.mainBanner'),(896767,'furniture','.mainBanner .bottomBox .btn','padding-bottom','15','5206','','.mainBanner'),(896768,'furniture','.order-summary .w-cart-listing .item > div ~ div','padding-bottom','10','','','.order-summary'),(896769,'furniture','.order-summary .heading-2','padding-bottom','0','5145','','.order-summary'),(896770,'furniture','.w-cart-discount-coupon .discount-box','padding-bottom','5','','','.w-cart-discount-coupon'),(896771,'furniture','.w-cart-listing .promos-info .promo-name','padding-bottom','3','','','.w-cart-listing'),(896772,'furniture','.w-cart-listing .item .image','padding-bottom','10','5140','','.w-cart-listing'),(896773,'furniture','.w-cart-listing .item .name','padding-bottom','10','5140','','.w-cart-listing'),(896774,'furniture','.w-cart-listing .item .points','padding-bottom','0','5131','','.w-cart-listing'),(896775,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','padding-bottom','5','','','.w-promotions-widgets-promotion-icons-desc'),(896776,'furniture','.w-product-promotion-icons .promos-info .promo-name','padding-bottom','3','','','.w-product-promotion-icons'),(896777,'furniture','.w-quote-products .no-price','padding-bottom','15','','','.w-quote-products'),(896778,'furniture','.w-product-quantity-discounts .item','padding-bottom','10','','','.w-product-quantity-discounts'),(896783,'furniture','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','padding-bottom','20','','','.b-product-images'),(896784,'furniture','.b-product-images .media-popup .mp-small-images img','padding-bottom','10','','','.b-product-images'),(896804,'furniture','.account-address-book .address_book','padding-bottom','30','','','.account-address-book'),(896805,'furniture','.account-address-book .address_book h1','padding-bottom','5','','','.account-address-book'),(896806,'furniture','.account-address-book .address_book h2','padding-bottom','10','','','.account-address-book'),(896807,'furniture','.account-address-book .address_book, .account-address-book .account_history_info','padding-bottom','10','','','.account-address-book'),(896808,'furniture','.account-address-book .buttonBox','padding-bottom','15','','','.account-address-book'),(896809,'furniture','.account-address-book .rightMes ul','padding-bottom','0','','','.account-address-book'),(896810,'furniture','.account-address-book .topButtons','padding-bottom','15','','','.account-address-book'),(896824,'furniture','.account-order-pay .contentColumn','padding-bottom','10','','','.account-order-pay'),(896825,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-bottom','5','','','.account-order-pay'),(896826,'furniture','.account-order-pay .history_info > div + div','padding-bottom','0','','','.account-order-pay'),(896827,'furniture','.account-order-pay .history_info > div','padding-bottom','0','5140','','.account-order-pay'),(896828,'furniture','.account-order-pay .history_info > div + div','padding-bottom','0','5140','','.account-order-pay'),(896829,'furniture','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-bottom','10','','','.account-samples'),(896830,'furniture','.account-samples .orders-table th','padding-bottom','2','','','.account-samples'),(896831,'furniture','.account-samples .order_history_table th','padding-bottom','10','','','.account-samples'),(896832,'furniture','.account-samples .view_link','padding-bottom','0','','','.account-samples'),(896833,'furniture','.account-samples .orders-table .item','padding-bottom','60','5140','','.account-samples'),(896834,'furniture','.account-samples .orders-table .td-alignright','padding-bottom','5','5140','','.account-samples'),(896835,'furniture','.account-samples .orders-table td','padding-bottom','5','5140','','.account-samples'),(896836,'furniture','.account-sample-info .contentColumn','padding-bottom','10','','','.account-sample-info'),(896837,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-bottom','5','','','.account-sample-info'),(896838,'furniture','.account-sample-info .history_info > div + div','padding-bottom','0','','','.account-sample-info'),(896839,'furniture','.account-sample-info .popup-tracking-number','padding-bottom','10','','','.account-sample-info'),(896840,'furniture','.account-sample-info .history_info > div','padding-bottom','0','5140','','.account-sample-info'),(896841,'furniture','.account-sample-info .history_info > div + div','padding-bottom','0','5140','','.account-sample-info'),(896842,'furniture','.catalog-product-wrap .next-product','padding-bottom','20','','','.catalog-product-wrap'),(896843,'furniture','.catalog-product-wrap .pn-direction','padding-bottom','0','','','.catalog-product-wrap'),(896844,'furniture','.catalog-product-wrap .pn-image','padding-bottom','20','','','.catalog-product-wrap'),(896845,'furniture','.catalog-product-wrap .prev-product','padding-bottom','20','','','.catalog-product-wrap'),(896846,'furniture','.catalog-product-wrap .next-product','padding-bottom','20','5140','','.catalog-product-wrap'),(896847,'furniture','.catalog-product-wrap .pn-direction','padding-bottom','0','5140','','.catalog-product-wrap'),(896848,'furniture','.catalog-product-wrap .prev-product','padding-bottom','20','5140','','.catalog-product-wrap'),(896849,'furniture','.checkout-index-wrap .datepicker-inline','padding-bottom','10','','','.checkout-index-wrap'),(896850,'furniture','.checkout-index-wrap .edit-address-popup','padding-bottom','20','','','.checkout-index-wrap'),(896851,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-bottom','6','','','.checkout-index-wrap'),(896852,'furniture','.checkout-index-wrap .hiding-box .checkout-cart-listing','padding-bottom','30','','','.checkout-index-wrap'),(896853,'furniture','.checkout-order-confirmation .price-row','padding-bottom','5','','','.checkout-order-confirmation'),(896854,'furniture','.shopping-cart-index .btn-3','padding-bottom','11','','','.shopping-cart-index'),(896855,'furniture','.shopping-cart-index .cart-page .empty','padding-bottom','100','','','.shopping-cart-index'),(896856,'furniture','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-bottom','10','','','.shopping-cart-index'),(896857,'furniture','.b-form .columns .col-2','padding-bottom','0','','','.b-form'),(896858,'furniture','.b-bottom .pop-up-content','padding-bottom','15','','','.b-bottom'),(896859,'furniture','.b-bottom .pop-up-content .buttons','padding-bottom','0','','','.b-bottom'),(896860,'furniture','.checkout-index-wrap .closeable-content','padding-bottom','20','','','.checkout-index-wrap'),(896861,'furniture','.checkout-index-wrap .closeable-heading','padding-bottom','8','','','.checkout-index-wrap'),(896862,'furniture','.b-form .middle-g','padding-bottom','0','','','.b-form'),(896863,'furniture','.b-info .info','padding-bottom','15','','','.b-info'),(896864,'furniture','.b-info .info li','padding-bottom','0','','','.b-info'),(896865,'furniture','.b-info .info ul','padding-bottom','0','','','.b-info'),(896866,'furniture','.b-multi-page-checkout .multi-page-checkout .buttons','padding-bottom','0','','','.b-multi-page-checkout'),(896867,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-bottom','20','','','.b-multi-page-checkout'),(896868,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-bottom','6','','','.b-multi-page-checkout'),(896869,'furniture','.b-form .col-left','padding-bottom','0','','','.b-form'),(896870,'furniture','.b-form .col-right','padding-bottom','0','','','.b-form'),(896871,'furniture','.success-page .check-ico-block','padding-bottom','0','','','.success-page'),(896872,'furniture','.success-page .order_totals .price-row','padding-bottom','5','','','.success-page'),(896873,'furniture','.success-page .price-row','padding-bottom','5','','','.success-page'),(896874,'furniture','.success-page .w-cart-listing .qty','padding-bottom','0','','','.success-page'),(896875,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','padding-bottom','0','','','.mainBanner'),(896876,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','padding-bottom','0','','','.mainBanner'),(896877,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','padding-bottom','0','','','.mainBanner'),(896878,'furniture','.menu-header .menu-style[data-style=\"1\"] .goto-button','padding-bottom','0','','','.menu-header'),(896879,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > li > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-bottom','12','','','.menu-header'),(896880,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','padding-bottom','5','','','.menu-header'),(896881,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-bottom','5','5140','','.footer-menu'),(896882,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2','padding-bottom','20','5140','','.footer-menu'),(896883,'furniture','.lowestPricedBox .w-banner .banner-holder','padding-bottom','30','','','.lowestPricedBox'),(896884,'furniture','.lowestPricedBox .w-banner .banner-holder','padding-bottom','0','5131','','.lowestPricedBox'),(896885,'furniture','.lowestPricedBox .w-banner .banner-text','padding-bottom','0','','','.lowestPricedBox'),(896886,'furniture','.lowestPricedBox .w-banner .banner-text-holder','padding-bottom','15','','','.lowestPricedBox'),(896887,'furniture','.lowestPricedBox .w-banner .banner-text-holder','padding-bottom','10','5140','','.lowestPricedBox'),(896888,'furniture','.lowestPricedBox .w-banner .banner-text-holder','padding-bottom','10','5161','','.lowestPricedBox'),(896889,'furniture','.lowestPricedBox .w-banner .ybg .btn','padding-bottom','4','5140','','.lowestPricedBox'),(896890,'furniture','.lowestPricedBox .w-banner .ybg .btn','padding-bottom','4','5161','','.lowestPricedBox'),(896891,'furniture','.lowestPricedBox .w-banner .ybg .mark','padding-bottom','10','','','.lowestPricedBox'),(896892,'furniture','.lowestPricedBox .w-banner .ybg .mark','padding-bottom','5','5161','','.lowestPricedBox'),(896893,'furniture','.tripleBanner ','padding-bottom','30','','','.tripleBanner'),(896894,'furniture','.tripleBanner .w-html_box','padding-bottom','16','','','.tripleBanner'),(896895,'furniture','.tripleBanner > .block','padding-bottom','0','','','.tripleBanner'),(896896,'furniture','.shopByCollectionBox .bannerButton a','padding-bottom','6','','','.shopByCollectionBox'),(896897,'furniture','.shopByCollectionBox .bannerButton a','padding-bottom','6','5145','','.shopByCollectionBox'),(896898,'furniture','.shopByCollectionBox .content','padding-bottom','10','','','.shopByCollectionBox'),(896899,'furniture','.shopByCollectionBox .w-banner .banner-text','padding-bottom','0','','','.shopByCollectionBox'),(896901,'furniture','.w-banner .banner-text','padding-bottom','20','','','.w-banner'),(896902,'furniture','.w-banner .carousel-text > span','padding-bottom','20','','','.w-banner'),(896903,'furniture','.w-catalog-paging .paging-item','padding-bottom','0','','','.w-catalog-paging'),(896904,'furniture','.b-data-table table.dataTable tbody td','padding-bottom_important','important','','','.b-data-table'),(896905,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom_important','important','','','.b-data-table'),(896906,'furniture','.b-data-table table.dataTable thead td','padding-bottom_important','important','','','.b-data-table'),(896907,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom_important','important','','','.b-data-table'),(896908,'furniture','.w-account-personal-catalog .buy-box','padding-bottom_important','important','5131','','.w-account-personal-catalog'),(896909,'furniture','.w-cart-listing .item .points','padding-bottom_important','important','5131','','.w-cart-listing'),(896910,'furniture','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-left','10','','','.w-communication-new-topic'),(896911,'furniture','.b-email .heading-name','padding-left','10','','','.b-email'),(896912,'furniture','.b-email .name','padding-left','10','','','.b-email'),(896913,'furniture','.b-email .heading-image','padding-left','10','','','.b-email'),(896914,'furniture','.b-email .heading-price','padding-left','10','','','.b-email'),(896915,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(896916,'furniture','.order-summary .btn-2, .order-summary .btn-3','padding-left','5','','','.order-summary'),(896917,'furniture','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(896918,'furniture','.w-promo-code .holder','padding-left','20','5161','','.w-promo-code'),(896921,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(896922,'furniture','.b-email .totals-value','padding-left','10','','','.b-email'),(896923,'furniture','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(896924,'furniture','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-left','10','','','.p-quick-order-index'),(896925,'furniture','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-left','10','','','.p-quick-order-index'),(896926,'furniture','.p-quick-order-index ul.token-input-list','padding-left','0','','','.p-quick-order-index'),(896927,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.p-quick-order-index'),(896928,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.p-quick-order-index'),(896929,'furniture','.w-promotions .promo-item','padding-left','40','','','.w-promotions'),(896930,'furniture','.w-top-categories h2.name','padding-left','3','','','.w-top-categories'),(896931,'furniture','.w-cart-compare .attributes-label','padding-left','10','','','.w-cart-compare'),(896937,'furniture','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(896938,'furniture','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(896939,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(896940,'furniture','.b-email .heading-price','padding-left','10','','','.b-email'),(896941,'furniture','.b-email .name','padding-left','10','','','.b-email'),(896942,'furniture','.testimonials .review','padding-left','10','','',''),(896943,'furniture','.testimonials .heading-3','padding-left','55','','',''),(896944,'furniture','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(896945,'furniture','.w-categories .image','padding-left','0','','','.w-categories'),(896946,'furniture','.w-promotions .prom-multi-discount .promo-range','padding-left','20','','','.w-promotions'),(896947,'furniture','.w-promotions .prom-multi-discount .promo-product','padding-left','20','','','.w-promotions'),(896948,'furniture','.w-promotions .nextdiscount .promo-for-each','padding-left','10','','','.w-promotions'),(896949,'furniture','.w-promotions .nextdiscount .content > div','padding-left','10','','','.w-promotions'),(896950,'furniture','.w-promotions .promo-salemaker .item','padding-left','20','','','.w-promotions'),(896951,'furniture','.w-promotions .promo-salemaker .promo-manufacturers','padding-left','12','','','.w-promotions'),(896952,'furniture','.w-promotions .promo-salemaker .discount','padding-left','20','','','.w-promotions'),(896953,'furniture','.w-promotions .promo-cart-discount .slave .item','padding-left','20','','','.w-promotions'),(896954,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','padding-left','20','','','.w-promotions'),(896955,'furniture','.w-promotions .promo-cart-discount .slave','padding-left','15','','','.w-promotions'),(896956,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','padding-left','20','','','.w-promotions'),(896957,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','padding-left','17','','','.b-warehouses-popup'),(896958,'furniture','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-left','20','','','.b-warehouses-popup'),(896959,'furniture','.w-product-available-in-warehouses .warehouse-item','padding-left','0','','','.w-product-available-in-warehouses'),(896960,'furniture','.w-checkout-create-account .account-benefits ul','padding-left','20','','','.w-checkout-create-account'),(896961,'furniture','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-left','2','','','.b-products-listing'),(896963,'furniture','.w-cart-compare .dropdown li','padding-left','10','','','.w-cart-compare'),(896964,'furniture','.w-cart-compare .attributes-cell','padding-left','20','','','.w-cart-compare'),(896966,'furniture','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(896968,'furniture','.w-login-block .new','padding-left','40','','','.w-login-block'),(896969,'furniture','.b-bottom .confirm-popup .confirm-text','padding-left','0','','','.b-bottom'),(896970,'furniture','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(896971,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(896972,'furniture','.b-messages .messages-menu ul','padding-left','0','','','.b-messages'),(896973,'furniture','.b-messages .development-content .type-6 .content','padding-left','0','','','.b-messages'),(896974,'furniture','.b-messages .msv_btn','padding-left','0','','','.b-messages'),(896975,'furniture','.b-messages .msv_content','padding-left','20','','','.b-messages'),(896976,'furniture','.b-messages .msv_history','padding-left','20','','','.b-messages'),(896977,'furniture','.b-messages .messMenuButton span','padding-left','15','','','.b-messages'),(896978,'furniture','.b-messages .messages-menu li a','padding-left','0','','','.b-messages'),(896979,'furniture','.b-messages .messages-menu li','padding-left','0','','','.b-messages'),(896980,'furniture','.b-messages .content_management_attach button','padding-left','27','','','.b-messages'),(896981,'furniture','.b-messages .email-heading','padding-left','15','','','.b-messages'),(896982,'furniture','.b-messages .content_management_attach','padding-left','8','','','.b-messages'),(896983,'furniture','.b-messages .emailLineTextArea textarea','padding-left','10','','','.b-messages'),(896984,'furniture','.b-messages .msv_to_cc','padding-left','15','','','.b-messages'),(896985,'furniture','.b-messages .emailBtn','padding-left','10','','','.b-messages'),(896986,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-left','10','','','.b-messages'),(896987,'furniture','.w-sitemap-delivery-location > ul > li > ul','padding-left','0','','','.w-sitemap-delivery-location'),(896988,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-left','10','','',''),(896989,'furniture','.w-sitemap-delivery-location > ul > li > ul ul','padding-left','20','','','.w-sitemap-delivery-location'),(896990,'furniture','.w-tabs .tab-navigation','padding-left','0','','','.w-tabs'),(896991,'furniture','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(896992,'furniture','.w-reviews-content .item','padding-left','0','','','.w-reviews-content'),(896993,'furniture','.p-quick-order-index .bottom','padding-left','0','','','.p-quick-order-index'),(896994,'furniture','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(896995,'furniture','.w-sitemap-delivery-location > ul','padding-left','0','','','.w-sitemap-delivery-location'),(896996,'furniture','.w-checkout-terms .required-message','padding-left','10','','','.w-checkout-terms'),(896997,'furniture','.w-cart-listing .item .remove','padding-left','10','5140','','.w-cart-listing'),(896998,'furniture','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(896999,'furniture','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(897000,'furniture','.w-socials > li','padding-left','15','','','.w-socials'),(897001,'furniture','.b-form .required-message-wrap','padding-left','0','','','.b-form'),(897002,'furniture','.b-email .image','padding-left','10','','','.b-email'),(897003,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-preview','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(897004,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-details','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(897005,'furniture','.b-table .table .headings td','padding-left','10','','','.b-table'),(897006,'furniture','.b-email .model','padding-left','10','','','.b-email'),(897007,'furniture','.b-email .heading-name','padding-left','10','','','.b-email'),(897008,'furniture','.b-email .heading-model','padding-left','10','','','.b-email'),(897009,'furniture','.b-products-listing .products-listing .bonus-points-cost','padding-left','30','','','.b-products-listing'),(897010,'furniture','.w-login-block .guest','padding-left','40','','','.w-login-block'),(897011,'furniture','.w-login-block .new','padding-left','40','','','.w-login-block'),(897012,'furniture','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(897013,'furniture','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-left','10','','','.w-menu-horizontal'),(897014,'furniture','.w-menu-horizontal > ul > li > ul > li','padding-left','10','','','.w-menu-horizontal'),(897015,'furniture','.w-menu-horizontal ul','padding-left','0','','','.w-menu-horizontal'),(897016,'furniture','.b-table .table td','padding-left','15','','','.b-table'),(897017,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(897018,'furniture','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(897019,'furniture','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(897020,'furniture','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(897021,'furniture','.w-product-images-additional .images','padding-left','0','5161','','.w-product-images-additional'),(897022,'furniture','.b-form .login-col-1','padding-left','0','','','.b-form'),(897023,'furniture','.b-email .heading-image','padding-left','10','','','.b-email'),(897025,'furniture','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(897026,'furniture','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-left','0','','','.order-summary'),(897027,'furniture','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(897028,'furniture','.b-email .price','padding-left','10','','','.b-email'),(897029,'furniture','.b-email .heading-model','padding-left','10','','','.b-email'),(897031,'furniture','.w-categories .item','padding-left','20','','','.w-categories'),(897032,'furniture','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(897033,'furniture','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(897034,'furniture','.b-bottom .terms-info-popup .pop-up-content','padding-left','20','','','.b-bottom'),(897035,'furniture','.w-cart-compare .dropdown .dropdown-menu','padding-left','0','','','.w-cart-compare'),(897036,'furniture','textarea','padding-left','10','','',''),(897040,'furniture','.w-socials > li','padding-left','15','','','.w-socials'),(897041,'furniture','.w-reviews-content .review','padding-left','20','','','.w-reviews-content'),(897043,'furniture','.w-filters .filter-ul-content','padding-left','0','','','.w-filters'),(897044,'furniture','.message.success','padding-left','40','','',''),(897045,'furniture','.p-quick-order-index .all-scroll-div','padding-left','0','','','.p-quick-order-index'),(897046,'furniture','.w-personal-gift-status-bar .end-label','padding-left','5','','','.w-personal-gift-status-bar'),(897047,'furniture','.w-promo-code .heading-4','padding-left','30','5161','','.w-promo-code'),(897048,'furniture','.b-email .heading-model','padding-left','10','','','.b-email'),(897049,'furniture','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(897050,'furniture','.b-email .heading-name','padding-left','10','','','.b-email'),(897051,'furniture','.b-email .name','padding-left','10','','','.b-email'),(897052,'furniture','.b-email .qty','padding-left','10','','','.b-email'),(897053,'furniture','.b-email .totals-value','padding-left','10','','','.b-email'),(897054,'furniture','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-left','0','','','.b-fancybox'),(897055,'furniture','.w-checkout-shipping-choice span','padding-left','0','','','.w-checkout-shipping-choice'),(897057,'furniture','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(897058,'furniture','.b-fancybox .fancybox-title-over-wrap','padding-left','10','','','.b-fancybox'),(897059,'furniture','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(897060,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-left','0','','','.b-select-suggest'),(897061,'furniture','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(897062,'furniture','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(897063,'furniture','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(897064,'furniture','.w-reviews .review','padding-left','0','','','.w-reviews'),(897065,'furniture','.w-socials > li','padding-left','15','','','.w-socials'),(897068,'furniture','.b-compare .popupCompare td.level-2:first-child','padding-left','12','','','.b-compare'),(897069,'furniture','.b-info-popup .info-popup div','padding-left','15','','','.b-info-popup'),(897070,'furniture','.b-form .payment-method .item','padding-left','0','','','.b-form'),(897071,'furniture','.b-form .password-forgotten-link','padding-left','0','','','.b-form'),(897072,'furniture','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(897073,'furniture','.w-cart-compare .price-label','padding-left','10','','','.w-cart-compare'),(897074,'furniture','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(897075,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-left','10','','','.w-image-maps'),(897076,'furniture','.w-promo-code .holder','padding-left','20','5161','','.w-promo-code'),(897077,'furniture','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(897079,'furniture','.w-reviews .heading-3','padding-left','55','','','.w-reviews'),(897080,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(897081,'furniture','.w-text .customer-service','padding-left','30','','','.w-text'),(897082,'furniture','.b-email .name','padding-left','10','','','.b-email'),(897083,'furniture','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(897084,'furniture','.b-email .heading-name','padding-left','10','','','.b-email'),(897085,'furniture','.b-email .heading-image','padding-left','10','','','.b-email'),(897086,'furniture','.b-email .image','padding-left','10','','','.b-email'),(897087,'furniture','.b-email .heading-qty','padding-left','10','','','.b-email'),(897088,'furniture','.b-email .totals-value','padding-left','10','','','.b-email'),(897089,'furniture','.b-email .price','padding-left','10','','','.b-email'),(897090,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(897091,'furniture','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-left','0','','','.w-multi-cart-actions'),(897092,'furniture','.w-text .customer-service','padding-left','30','','','.w-text'),(897093,'furniture','.w-top-categories .item','padding-left','20','','','.w-top-categories'),(897094,'furniture','.w-tabs > .block','padding-left','20','','','.w-tabs'),(897095,'furniture','.w-cart-cart-tabs .w-tabs > .block','padding-left','0','','','.w-cart-cart-tabs'),(897096,'furniture','.w-tabs .accordion-heading','padding-left','8','5131','','.w-tabs'),(897097,'furniture','.w-tabs .tab-a','padding-left','6','','','.w-tabs'),(897098,'furniture','.w-tabs .tab-li','padding-left','0','','','.w-tabs'),(897099,'furniture','.w-socials > li','padding-left','15','','','.w-socials'),(897101,'furniture','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(897102,'furniture','.b-bottom .popup-box-wrap','padding-left','10','','','.b-bottom'),(897103,'furniture','.b-bottom .popup-buttons','padding-left','15','','','.b-bottom'),(897105,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(897106,'furniture','.w-chat .w-chat-box','padding-left','12','','','.w-chat'),(897107,'furniture','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(897108,'furniture','.b-form .required-message','padding-left','3','','','.b-form'),(897109,'furniture','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(897110,'furniture','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(897111,'furniture','.btn-1','padding-left','25','','',''),(897112,'furniture','.b-autocomplete .ui-autocomplete li','padding-left','10','','','.b-autocomplete'),(897113,'furniture','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(897114,'furniture','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(897115,'furniture','.b-table .table td','padding-left','15','','','.b-table'),(897116,'furniture','.b-table .table .headings td','padding-left','10','','','.b-table'),(897117,'furniture','.w-socials > li','padding-left','15','','','.w-socials'),(897118,'furniture','.w-login-block .guest','padding-left','40','','','.w-login-block'),(897119,'furniture','.b-products-listing .products-listing .buyButton .btn','padding-left','10','','','.b-products-listing'),(897120,'furniture','.w-product-images-additional .images','padding-left','0','5161','','.w-product-images-additional'),(897121,'furniture','.b-products-listing .products-listing .bonus-points-price','padding-left','20','','','.b-products-listing'),(897122,'furniture','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(897123,'furniture','.b-email .heading-qty','padding-left','10','','','.b-email'),(897124,'furniture','.order-summary .price-row','padding-left','0','','','.order-summary'),(897125,'furniture','.b-email .heading-image','padding-left','10','','','.b-email'),(897126,'furniture','.w-quote .no-text','padding-left','20','','','.w-quote'),(897127,'furniture','.b-select-suggest .select2-drop-mask','padding-left','0','','','.b-select-suggest'),(897128,'furniture','.w-reviews .author','padding-left','0','','','.w-reviews'),(897130,'furniture','.testimonials .answer','padding-left','30','','',''),(897131,'furniture','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(897132,'furniture','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(897133,'furniture','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(897135,'furniture','.b-fancybox .fancybox-title-float-wrap .child','padding-left','20','','','.b-fancybox'),(897136,'furniture','.w-checkout-shipping-choice span','padding-left','10','5161','','.w-checkout-shipping-choice'),(897137,'furniture','.w-top-categories .categories h2','padding-left','0','','','.w-top-categories'),(897138,'furniture','.w-top-categories .image','padding-left','0','','','.w-top-categories'),(897139,'furniture','.w-product-reviews .reviews-list .review','padding-left','10','','','.w-product-reviews'),(897140,'furniture','.b-email .model','padding-left','10','','','.b-email'),(897141,'furniture','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(897142,'furniture','.b-email .price','padding-left','10','','','.b-email'),(897143,'furniture','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(897144,'furniture','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(897145,'furniture','.w-promo-code .heading-4','padding-left','30','5161','','.w-promo-code'),(897146,'furniture','.w-product-images-additional .images','padding-left','0','5161','','.w-product-images-additional'),(897147,'furniture','.b-bottom .popup-heading','padding-left','15','','','.b-bottom'),(897148,'furniture','.b-bottom .popup-simple','padding-left','20','','','.b-bottom'),(897149,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(897150,'furniture','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(897151,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(897152,'furniture','.b-email .image','padding-left','10','','','.b-email'),(897153,'furniture','.b-email .heading-qty','padding-left','10','','','.b-email'),(897154,'furniture','.b-email .name','padding-left','10','','','.b-email'),(897155,'furniture','.b-email .heading-price','padding-left','10','','','.b-email'),(897156,'furniture','.b-email .heading-model','padding-left','10','','','.b-email'),(897157,'furniture','.b-email .totals-value','padding-left','10','','','.b-email'),(897158,'furniture','.b-email .qty','padding-left','10','','','.b-email'),(897159,'furniture','.b-email .totals-title','padding-left','10','','','.b-email'),(897160,'furniture','.b-email .model','padding-left','10','','','.b-email'),(897161,'furniture','.b-email .heading-name','padding-left','10','','','.b-email'),(897162,'furniture','.b-email .heading-image','padding-left','10','','','.b-email'),(897163,'furniture','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(897164,'furniture','.w-checkout-create-account .create-account','padding-left','0','','','.w-checkout-create-account'),(897165,'furniture','.w-checkout-shipping .sub-item','padding-left','0','','','.w-checkout-shipping'),(897166,'furniture','.b-email .totals-value','padding-left','10','','','.b-email'),(897167,'furniture','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(897168,'furniture','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(897169,'furniture','.b-table .table td','padding-left','15','','','.b-table'),(897170,'furniture','.b-table .table .headings td','padding-left','10','','','.b-table'),(897171,'furniture','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(897172,'furniture','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(897173,'furniture','.w-promo-code .holder','padding-left','20','5161','','.w-promo-code'),(897174,'furniture','.w-promo-code .heading-4','padding-left','30','5161','','.w-promo-code'),(897175,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(897176,'furniture','.b-form .shipping-method .input','padding-left','0','','','.b-form'),(897177,'furniture','.b-form .center-buttons','padding-left','0','','','.b-form'),(897178,'furniture','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(897179,'furniture','.w-reviews .item','padding-left','0','','','.w-reviews'),(897180,'furniture','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(897181,'furniture','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(897182,'furniture','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(897183,'furniture','.b-select-suggest .select2-container .select2-choice','padding-left','8','','','.b-select-suggest'),(897187,'furniture','.b-sub-totals .historyTotal td','padding-left','5','','','.b-sub-totals'),(897188,'furniture','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(897189,'furniture','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(897190,'furniture','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(897191,'furniture','.w-personal-gift-status-bar .end-date','padding-left','5','3','','.w-personal-gift-status-bar'),(897192,'furniture','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(897194,'furniture','.b-upload-files .upload-files','padding-left','10','','','.b-upload-files'),(897195,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(897196,'furniture','.w-login-block .guest','padding-left','40','','','.w-login-block'),(897197,'furniture','.w-login-block .new','padding-left','40','','','.w-login-block'),(897198,'furniture','.w-product-images-additional .images','padding-left','0','5161','','.w-product-images-additional'),(897199,'furniture','.w-checkout-shipping-address .edit-ab','padding-left','15','','','.w-checkout-shipping-address'),(897200,'furniture','.b-bottom .header-error','padding-left','20','','','.b-bottom'),(897201,'furniture','.w-categories h2.name','padding-left','3','','','.w-categories'),(897202,'furniture','.w-cart-discount-coupon .btn','padding-left','25','','','.w-cart-discount-coupon'),(897203,'furniture','.b-form .form-buttons','padding-left','0','','','.b-form'),(897204,'furniture','.b-form .payment-method .item-radio label span','padding-left','5','','','.b-form'),(897205,'furniture','.w-checkout-billing-address .same-address','padding-left','10','','','.w-checkout-billing-address'),(897206,'furniture','.btn-3','padding-left','25','','',''),(897207,'furniture','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(897208,'furniture','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(897209,'furniture','.w-cart-compare .delete-cart','padding-left','10','','','.w-cart-compare'),(897210,'furniture','.w-cart-compare .price-cell','padding-left','20','','','.w-cart-compare'),(897211,'furniture','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','60','','','.b-select-suggest'),(897212,'furniture','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(897213,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(897214,'furniture','.b-email .totals-title','padding-left','10','','','.b-email'),(897215,'furniture','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(897216,'furniture','.b-email .heading-qty','padding-left','10','','','.b-email'),(897217,'furniture','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','padding-left','10','','','.b-bottom'),(897218,'furniture','.w-product-images-additional .images','padding-left','0','5161','','.w-product-images-additional'),(897219,'furniture','.w-promo-code .heading-4','padding-left','30','5161','','.w-promo-code'),(897220,'furniture','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-left','20','','','.b-bottom'),(897221,'furniture','.b-bottom .cart-options .cart-item input[type=\"text\"]','padding-left','0','','','.b-bottom'),(897222,'furniture','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-left','6','','','.b-compare'),(897223,'furniture','.w-cart-compare .cart-cell','padding-left','7','','','.w-cart-compare'),(897224,'furniture','.w-cart-compare .product','padding-left','15','','','.w-cart-compare'),(897225,'furniture','.w-promotions .promo-cart-discount .master .item','padding-left','20','','','.w-promotions'),(897227,'furniture','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(897228,'furniture','.b-bottom .alert-message','padding-left','20','','','.b-bottom'),(897229,'furniture','.b-bottom .cart-options','padding-left','20','','','.b-bottom'),(897230,'furniture','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','5140','','.w-menu-horizontal'),(897231,'furniture','.w-login-block .guest','padding-left','40','','','.w-login-block'),(897232,'furniture','.b-select-suggest .select2-results .select2-result-label','padding-left','7','','','.b-select-suggest'),(897233,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(897234,'furniture','.w-login-block .new','padding-left','40','','','.w-login-block'),(897235,'furniture','.w-login-block .guest','padding-left','40','','','.w-login-block'),(897236,'furniture','.w-quote .cart-box-link','padding-left','10','','','.w-quote'),(897237,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(897238,'furniture','.b-email .totals-value','padding-left','10','','','.b-email'),(897239,'furniture','.b-email .totals-title','padding-left','10','','','.b-email'),(897240,'furniture','.b-email .qty','padding-left','10','','','.b-email'),(897241,'furniture','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(897242,'furniture','.b-email .heading-price','padding-left','10','','','.b-email'),(897243,'furniture','.b-bottom .rfq-form','padding-left','20','','','.b-bottom'),(897244,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(897245,'furniture','.b-bottom .footerTitle','padding-left','0','5131','','.b-bottom'),(897246,'furniture','.b-bottom .pop-up-close','padding-left','1','','','.b-bottom'),(897247,'furniture','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(897248,'furniture','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(897249,'furniture','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(897250,'furniture','.w-cart-up-sell .w-list-type-1','padding-left','0','','','.w-cart-up-sell'),(897251,'furniture','.w-cart-shipping-estimator .address-item','padding-left','0','','','.w-cart-shipping-estimator'),(897252,'furniture','.w-cart-up-sell .w-list-type-1 .item','padding-left','20','1','','.w-cart-up-sell'),(897253,'furniture','.w-cart-up-sell .w-list-type-1 .item','padding-left','21','','','.w-cart-up-sell'),(897254,'furniture','.b-products-listing .products-listing .btn-buy','padding-left','10','','','.b-products-listing'),(897255,'furniture','.b-upload-files .added-file','padding-left','0','','','.b-upload-files'),(897256,'furniture','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(897257,'furniture','.w-menu-big ul','padding-left','0','','','.w-menu-big'),(897258,'furniture','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(897259,'furniture','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(897260,'furniture','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(897262,'furniture','.w-promo-code .holder','padding-left','20','5161','','.w-promo-code'),(897263,'furniture','.b-bottom .pop-up-info','padding-left','20','','','.b-bottom'),(897264,'furniture','.b-email .heading-price','padding-left','10','','','.b-email'),(897265,'furniture','.b-email .image','padding-left','10','','','.b-email'),(897266,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(897267,'furniture','.b-fancybox .fancybox-error','padding-left','15','','','.b-fancybox'),(897268,'furniture','.w-cart-compare .product .stock','padding-left','3','','','.w-cart-compare'),(897269,'furniture','.b-fancybox .fancybox-next span','padding-left','4','3','','.b-fancybox'),(897270,'furniture','.w-product-customers-activity .customers-activity','padding-left','20','','','.w-product-customers-activity'),(897271,'furniture','.b-table .table td','padding-left','15','','','.b-table'),(897272,'furniture','.b-compare .compare-box-item','padding-left','10','','','.b-compare'),(897273,'furniture','.b-compare .compare-head','padding-left','10','','','.b-compare'),(897274,'furniture','.b-email .model','padding-left','10','','','.b-email'),(897275,'furniture','.b-email .image','padding-left','10','','','.b-email'),(897276,'furniture','.b-email .heading-qty','padding-left','10','','','.b-email'),(897277,'furniture','.b-email .totals-title','padding-left','10','','','.b-email'),(897278,'furniture','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(897279,'furniture','.b-table .table .headings td','padding-left','10','','','.b-table'),(897281,'furniture','.w-text .customer-service','padding-left','30','','','.w-text'),(897282,'furniture','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(897283,'furniture','.w-text .customer-service','padding-left','30','','','.w-text'),(897284,'furniture','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(897285,'furniture','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(897286,'furniture','.w-login-block .new','padding-left','40','','','.w-login-block'),(897287,'furniture','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(897288,'furniture','.w-login-block .guest','padding-left','40','','','.w-login-block'),(897290,'furniture','.w-checkout-billing-address .edit-ab','padding-left','15','','','.w-checkout-billing-address'),(897291,'furniture','.w-checkout-billing-address .addresses.address-main label','padding-left','0','','','.w-checkout-billing-address'),(897292,'furniture','.w-checkout-billing-address .addresses .address-item label','padding-left','15','','','.w-checkout-billing-address'),(897293,'furniture','.w-promo-code .holder','padding-left','20','5161','','.w-promo-code'),(897294,'furniture','.w-promo-code .heading-4','padding-left','30','5161','','.w-promo-code'),(897295,'furniture','.w-product-images-additional .images','padding-left','0','5161','','.w-product-images-additional'),(897296,'furniture','.w-cart-checkout-btn a','padding-left','12','5131','','.w-cart-checkout-btn'),(897297,'furniture','.w-tabs .accordion-heading','padding-left','6','','','.w-tabs'),(897298,'furniture','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(897299,'furniture','.b-bottom .header-info','padding-left','20','','','.b-bottom'),(897300,'furniture','.w-personal-gift-status-bar .start-label','padding-left','30','','','.w-personal-gift-status-bar'),(897301,'furniture','.b-upload-file .upload-file-template','padding-left','1','','','.b-upload-file'),(897302,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(897303,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','padding-left','5','','','.b-switch'),(897304,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-left','5','','','.b-select-suggest'),(897305,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-left','18','','','.b-select-suggest'),(897307,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-left','5','','','.b-select-suggest'),(897308,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-left','0','','','.b-select-suggest'),(897309,'furniture','.b-select-suggest .select2-locked','padding-left','5','','','.b-select-suggest'),(897310,'furniture','.b-select-suggest .select2-container-multi .select2-choices','padding-left','0','','','.b-select-suggest'),(897311,'furniture','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','100','','','.b-select-suggest'),(897312,'furniture','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','120','','','.b-select-suggest'),(897313,'furniture','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','110','','','.b-select-suggest'),(897314,'furniture','.b-select-suggest .select2-results ul.select2-result-sub','padding-left','0','','','.b-select-suggest'),(897315,'furniture','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','80','','','.b-select-suggest'),(897316,'furniture','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','40','','','.b-select-suggest'),(897317,'furniture','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','','','.w-menu-horizontal'),(897318,'furniture','.b-select-suggest .select2-results','padding-left','4','','','.b-select-suggest'),(897319,'furniture','.w-checkout-shipping-address .addresses .address-item label','padding-left','15','','','.w-checkout-shipping-address'),(897320,'furniture','.b-select-suggest .select2-results ul.select2-result-sub > li .select2-result-label','padding-left','20','','','.b-select-suggest'),(897321,'furniture','.b-form .shipping-method .item + .item','padding-left','0','','','.b-form'),(897322,'furniture','.w-checkout-shipping-address .addresses.address-main label','padding-left','0','','','.w-checkout-shipping-address'),(897323,'furniture','.b-select-suggest .select2-search input','padding-left','5','','','.b-select-suggest'),(897324,'furniture','.b-select-suggest .select2-search','padding-left','4','','','.b-select-suggest'),(897325,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(897326,'furniture','.w-text .customer-service','padding-left','30','','','.w-text'),(897329,'furniture','.w-cart-compare .product-label','padding-left','10','','','.w-cart-compare'),(897330,'furniture','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(897331,'furniture','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(897332,'furniture','.b-table .table .headings td','padding-left','10','','','.b-table'),(897333,'furniture','.b-compare .col-two label','padding-left','0','','','.b-compare'),(897336,'furniture','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(897337,'furniture','.b-bottom .notify-form','padding-left','20','','','.b-bottom'),(897338,'furniture','.w-account-addresses-list .addsess-suggestion-item','padding-left','0','','','.w-account-addresses-list'),(897339,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.b-data-table'),(897340,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.b-data-table'),(897341,'furniture','.w-communication-post .communication-post-author','padding-left','0','','','.w-communication-post'),(897342,'furniture','.b-products-listing .products-listing a.btn.view-button','padding-left','0','','','.b-products-listing'),(897343,'furniture','.b-products-listing .in-cart','padding-left','10','','','.b-products-listing'),(897344,'furniture','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-left','5','','','.w-catalog-b2b-add-button'),(897345,'furniture','.b-products-listing .promos-info .promo-item','padding-left','0','','','.b-products-listing'),(897346,'furniture','.b-products-listing .promos-info .promo-name','padding-left','15','','','.b-products-listing'),(897347,'furniture','.blogsidebar','padding-left','35','','',''),(897353,'furniture','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(897354,'furniture','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(897355,'furniture','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(897356,'furniture','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(897357,'furniture','.w-checkout-gdpr .terms-login','padding-left','0','','','.w-checkout-gdpr'),(897358,'furniture','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(897359,'furniture','.w-checkout-gdpr .privacy-row','padding-left','0','','','.w-checkout-gdpr'),(897360,'furniture','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(897361,'furniture','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(897362,'furniture','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(897363,'furniture','.b-compare .column_wrapper','padding-left','10','','','.b-compare'),(897364,'furniture','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(897365,'furniture','.b-email .price','padding-left','10','','','.b-email'),(897366,'furniture','.b-email .heading-name','padding-left','10','','','.b-email'),(897367,'furniture','.b-email .heading-model','padding-left','10','','','.b-email'),(897368,'furniture','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(897369,'furniture','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(897370,'furniture','.w-text .customer-service','padding-left','30','','','.w-text'),(897371,'furniture','.w-top-categories .item','padding-left','10','5131','','.w-top-categories'),(897372,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(897373,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(897374,'furniture','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(897375,'furniture','.w-personal-gift-status-bar .timeline','padding-left','10','','','.w-personal-gift-status-bar'),(897376,'furniture','.w-personal-gift-status-bar .inform','padding-left','5','4','','.w-personal-gift-status-bar'),(897377,'furniture','.b-table .table td','padding-left','15','','','.b-table'),(897378,'furniture','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(897379,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-left','0','','',''),(897380,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-left','0','','','.b-h-inline'),(897381,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-left','5','','','.w-communication-new-topic'),(897382,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-left','10','','','.w-communication-new-topic'),(897383,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-left','5','','','.w-communication-new-topic'),(897384,'furniture','.w-communication-new-topic #communication_topic_form .middle-form','padding-left','0','','','.w-communication-new-topic'),(897385,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(897386,'furniture','.b-email .heading-price','padding-left','10','','','.b-email'),(897387,'furniture','.b-email .image','padding-left','10','','','.b-email'),(897388,'furniture','.btn-2','padding-left','25','','',''),(897389,'furniture','.b-compare .compare_pagination','padding-left','0','','','.b-compare'),(897390,'furniture','.b-bottom .popup-content','padding-left','15','','','.b-bottom'),(897391,'furniture','.w-reviews-content .author','padding-left','20','','','.w-reviews-content'),(897392,'furniture','.b-email .qty','padding-left','10','','','.b-email'),(897393,'furniture','.w-login-block .new','padding-left','40','','','.w-login-block'),(897395,'furniture','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(897396,'furniture','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(897397,'furniture','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-left','0','','','.b-fancybox'),(897398,'furniture','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(897399,'furniture','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(897400,'furniture','.b-email .heading-image','padding-left','10','','','.b-email'),(897401,'furniture','.b-email .price','padding-left','10','','','.b-email'),(897402,'furniture','.products-quick-index .token-input-list','padding-left','0','','',''),(897405,'furniture','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(897406,'furniture','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(897407,'furniture','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(897408,'furniture','.b-form .shipping-method .item','padding-left','0','','','.b-form'),(897409,'furniture','.b-email .model','padding-left','10','','','.b-email'),(897410,'furniture','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(897411,'furniture','.w-promo-code .holder','padding-left','20','5161','','.w-promo-code'),(897412,'furniture','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(897413,'furniture','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(897414,'furniture','.w-cart-listing .item .gift-wrap label','padding-left','10','','','.w-cart-listing'),(897415,'furniture','.w-cart-listing .item > div','padding-left','0','','','.w-cart-listing'),(897416,'furniture','.w-cart-listing .points-earn','padding-left','10','','','.w-cart-listing'),(897417,'furniture','.w-cart-listing .points-redeem','padding-left','25','','','.w-cart-listing'),(897418,'furniture','.w-cart-listing .item .gift-wrap .value','padding-left','5','','','.w-cart-listing'),(897419,'furniture','.w-cart-listing .item .gift-wrap','padding-left','0','5140','','.w-cart-listing'),(897420,'furniture','.w-cart-give-away .ga_img','padding-left','1','','','.w-cart-give-away'),(897428,'furniture','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(897429,'furniture','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(897430,'furniture','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(897431,'furniture','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(897432,'furniture','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(897433,'furniture','.b-email .heading-model','padding-left','10','','','.b-email'),(897434,'furniture','.b-email .model','padding-left','10','','','.b-email'),(897435,'furniture','.b-compare .col-gender','padding-left','0','','','.b-compare'),(897437,'furniture','.w-socials > li','padding-left','15','','','.w-socials'),(897438,'furniture','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(897439,'furniture','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(897440,'furniture','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(897442,'furniture','.b-compare .popupCompare td.level-3:first-child','padding-left','18','','','.b-compare'),(897444,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(897445,'furniture','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(897446,'furniture','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(897447,'furniture','.b-table .table .headings td','padding-left','10','','','.b-table'),(897448,'furniture','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(897450,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(897451,'furniture','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(897452,'furniture','.w-filters .fsl_handle','padding-left','0','','','.w-filters'),(897453,'furniture','.w-filters .head-filter-widget','padding-left','10','5140','','.w-filters'),(897454,'furniture','.w-catalog-sorting .before','padding-left','0','','','.w-catalog-sorting'),(897455,'furniture','.w-filters .ui-slider-range','padding-left','0','','','.w-filters'),(897457,'furniture','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(897458,'furniture','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(897459,'furniture','.w-filters .head-filter-widget','padding-left','0','','','.w-filters'),(897460,'furniture','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(897461,'furniture','.b-autocomplete .ui-autocomplete','padding-left','2','','','.b-autocomplete'),(897462,'furniture','.w-promo-code .heading-4','padding-left','30','5161','','.w-promo-code'),(897463,'furniture','.order-summary .heading-2','padding-left','25','','','.order-summary'),(897464,'furniture','.b-email .name','padding-left','10','','','.b-email'),(897465,'furniture','.b-email .totals-title','padding-left','10','','','.b-email'),(897466,'furniture','.b-email .heading-qty','padding-left','10','','','.b-email'),(897468,'furniture','.b-data-table table.dataTable tbody td','padding-left','20','','','.b-data-table'),(897469,'furniture','.b-data-table table.dataTable thead td','padding-left','20','','','.b-data-table'),(897470,'furniture','.b-compare .popupCompare .pop-up-content','padding-left','10','','','.b-compare'),(897473,'furniture','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(897474,'furniture','.b-table .table td','padding-left','15','','','.b-table'),(897475,'furniture','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(897476,'furniture','.b-email .qty','padding-left','10','','','.b-email'),(897477,'furniture','.b-email .totals-title','padding-left','10','','','.b-email'),(897478,'furniture','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(897479,'furniture','.b-email .qty','padding-left','10','','','.b-email'),(897480,'furniture','.b-email .price','padding-left','10','','','.b-email'),(897481,'furniture','.btn','padding-left','25','','',''),(897482,'furniture','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(897483,'furniture','.b-product-images .media-popup .mp-content','padding-left','5','','','.b-product-images'),(897484,'furniture','.b-product-images .media-popup .mp-small-images .item','padding-left','10','','','.b-product-images'),(897485,'furniture','.b-product-images .media-popup .slick-dots','padding-left','0','','','.b-product-images'),(897486,'furniture','.b-product-images .media-popup .slick-dots li','padding-left','0','','','.b-product-images'),(897487,'furniture','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-left','0','','','.b-menu-style'),(897488,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-left','0','','','.b-menu-style-2'),(897489,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-left','0','','','.b-menu-style-2'),(897490,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-left','0','','','.b-menu-style-2'),(897491,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-left','0','','','.b-menu-style-2'),(897492,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-left','20','','','.b-menu-style-2'),(897493,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-left','0','','','.b-menu-style-2'),(897494,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-left','20','','','.b-menu-style-2'),(897495,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-left','20','','','.b-menu-style-2'),(897496,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-left','20','','','.b-menu-style-2'),(897497,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-left','50','','','.b-menu-style-2'),(897498,'furniture','.b-personal-catalog-popup #personal_catalog_popup','padding-left','0','','','.b-personal-catalog-popup'),(897499,'furniture','.b-trade-approval .steps-bar li a','padding-left','0','','','.b-trade-approval'),(897500,'furniture','.b-trade-approval .middle-form','padding-left','0','','','.b-trade-approval'),(897501,'furniture','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-left','5','','','.b-trade-approval'),(897502,'furniture','.b-trade-approval .steps-bar','padding-left','12','','','.b-trade-approval'),(897503,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-left','10','','','.b-trade-approval'),(897504,'furniture','.b-trade-approval .center-buttons','padding-left','0','','','.b-trade-approval'),(897505,'furniture','.w-account-personal-catalog .list-switcher','padding-left','0','','','.w-account-personal-catalog'),(897506,'furniture','.w-account-personal-catalog .list-switcher a','padding-left','6','','','.w-account-personal-catalog'),(897507,'furniture','.w-account-subscription .subscription-variant','padding-left','10','','','.w-account-subscription'),(897508,'furniture','.w-catalog-additional-images li','padding-left','10','','','.w-catalog-additional-images'),(897509,'furniture','.w-catalog-additional-images ul','padding-left','0','','','.w-catalog-additional-images'),(897510,'furniture','.w-catalog-compare td','padding-left','20','','','.w-catalog-compare'),(897511,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-left','0','','','.w-catalog-compare'),(897512,'furniture','.w-catalog-compare .cross-box .different-all > div','padding-left','5','2','','.w-catalog-compare'),(897513,'furniture','.w-catalog-compare .cross-box .different-all > div','padding-left','5','','','.w-catalog-compare'),(897514,'furniture','.w-catalog-compare .cross-box .return','padding-left','20','','','.w-catalog-compare'),(897515,'furniture','.w-delivery-day .left-count','padding-left','5','','','.w-delivery-day'),(897516,'furniture','.w-top-text .top-text','padding-left','10','','','.w-top-text'),(897517,'furniture','.w-product-images .additional-horizontal .item','padding-left','10','','','.w-product-images'),(897518,'furniture','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-left','10','','','.b-cookie-notice'),(897522,'furniture','.b-slick .slick-list','padding-left','0','','','.b-slick'),(897523,'furniture','.b-slick .slick-vertical button.slick-next','padding-left','0','3','','.b-slick'),(897524,'furniture','.b-slick .slick-vertical button.slick-prev','padding-left','0','3','','.b-slick'),(897525,'furniture','.b-slick button.slick-next','padding-left','4','3','','.b-slick'),(897526,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','padding-left','0','','','.b-slick'),(897527,'furniture','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-left','15','','',''),(897528,'furniture','.cartTitle span','padding-left','30','','','.cartTitle'),(897529,'furniture','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','padding-left','0','','','.b-products-listing'),(897530,'furniture','.w-cart-listing .headings .head','padding-left','0','','','.w-cart-listing'),(897531,'furniture','.b-products-listing .item-nav > div','padding-left','15','','','.b-products-listing'),(897532,'furniture','.LeftCategories .w-menu-simple ul','padding-left','0','','','.LeftCategories'),(897533,'furniture','.LeftCategories .w-menu-simple ul li a','padding-left','25','','','.LeftCategories'),(897534,'furniture','.w-filters .filter-widget','padding-left','25','','','.w-filters'),(897535,'furniture','.b-products-listing .products-listing.list-productlisting .item','padding-left','15','','','.b-products-listing'),(897536,'furniture','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-left','0','','','.b-products-listing'),(897537,'furniture','.b-products-listing .products-listing.list-productlisting .item-content','padding-left','25','','','.b-products-listing'),(897538,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','padding-left','30','','','.b-products-listing'),(897539,'furniture','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-left','25','','','.b-products-listing'),(897540,'furniture','.b-products-listing .products-listing.list-rows .item-nav > div','padding-left','5','','','.b-products-listing'),(897541,'furniture','.w-breadcrumb .breadcrumb-li','padding-left','0','','','.w-breadcrumb'),(897542,'furniture','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(897543,'furniture','.w-subscribers .btn-submit','padding-left','25','','','.w-subscribers'),(897544,'furniture','.w-quote .buttons','padding-left','15','','','.w-quote'),(897545,'furniture','.w-quote .buttons .btn','padding-left','15','','','.w-quote'),(897546,'furniture','.w-quote .cart-content','padding-left','15','','','.w-quote'),(897547,'furniture','.w-quote .cart-total','padding-left','0','','','.w-quote'),(897548,'furniture','.w-quote .multicart .cart-content','padding-left','0','','','.w-quote'),(897549,'furniture','.w-quote .multicart .item','padding-left','45','','','.w-quote'),(897550,'furniture','.w-quote .multicart .name','padding-left','10','','','.w-quote'),(897551,'furniture','.w-quote .qty','padding-left','5','4','','.w-quote'),(897552,'furniture','.w-quote a.item','padding-left','90','','','.w-quote'),(897553,'furniture','.w-social-links a','padding-left','8','','','.w-social-links'),(897554,'furniture','.w-product-images .additional-vertical .additional-images','padding-left','0','','','.w-product-images'),(897555,'furniture','.w-product-personal-catalog-button .btn','padding-left','0','','','.w-product-personal-catalog-button'),(897556,'furniture','.b-quantity .qty-box input','padding-left','3','','','.b-quantity'),(897557,'furniture','.w-product-sale-ends .left-count','padding-left','5','','','.w-product-sale-ends'),(897558,'furniture','.w-product-sale-ends .left-count-days','padding-left','0','','','.w-product-sale-ends'),(897559,'furniture','.w-product-sale-ends .left-count-hours','padding-left','0','','','.w-product-sale-ends'),(897560,'furniture','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(897561,'furniture','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(897562,'furniture','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(897563,'furniture','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(897564,'furniture','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(897565,'furniture','.w-product-bonus-points > div > div','padding-left','25','','','.w-product-bonus-points'),(897566,'furniture','.warrantyProduct .warranty, .warrantyProduct .delivery','padding-left','50','','','.warrantyProduct'),(897567,'furniture','.w-compare .compare-list-buttons','padding-left','10','','','.w-compare'),(897568,'furniture','.w-compare .item-holder','padding-left','90','','','.w-compare'),(897569,'furniture','.w-compare .compare-list-products','padding-left','30','','','.w-compare'),(897570,'furniture','.w-files-catalog-widgets-files-catalog .name','padding-left','10','','','.w-files-catalog-widgets-files-catalog'),(897571,'furniture','.w-files-catalog-widgets-files-list .file','padding-left','20','','','.w-files-catalog-widgets-files-list'),(897572,'furniture','.w-sample .buttons','padding-left','15','','','.w-sample'),(897573,'furniture','.w-sample .buttons .btn','padding-left','15','','','.w-sample'),(897574,'furniture','.w-sample .cart-box-link','padding-left','10','','','.w-sample'),(897575,'furniture','.w-sample .cart-content','padding-left','15','','','.w-sample'),(897576,'furniture','.w-sample .cart-total','padding-left','0','','','.w-sample'),(897577,'furniture','.w-sample .multicart .cart-content','padding-left','0','','','.w-sample'),(897578,'furniture','.w-sample .multicart .item','padding-left','45','','','.w-sample'),(897579,'furniture','.w-sample .multicart .name','padding-left','10','','','.w-sample'),(897580,'furniture','.w-sample .no-text','padding-left','20','','','.w-sample'),(897581,'furniture','.w-sample .qty','padding-left','5','4','','.w-sample'),(897582,'furniture','.w-sample a.item','padding-left','90','','','.w-sample'),(897583,'furniture','.w-cart-listing .item > div.points','padding-left','0','','','.w-cart-listing'),(897584,'furniture','.w-filters-simple .integrate-price-holder','padding-left','0','','','.w-filters-simple'),(897585,'furniture','.w-product-video .item','padding-left','10','','','.w-product-video'),(897586,'furniture','.shipping-ico .heading-3','padding-left','0','','','.shipping-ico'),(897587,'furniture','.w-cart-order-reference .btn','padding-left','25','','','.w-cart-order-reference'),(897588,'furniture','.w-cart-gift-certificate .btn','padding-left','25','','','.w-cart-gift-certificate'),(897589,'furniture','.w-cart-shipping-estimator .btn','padding-left','25','','','.w-cart-shipping-estimator'),(897590,'furniture','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(897591,'furniture','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(897592,'furniture','.w-product-in-bundles .attributes-item','padding-left','0','','','.w-product-in-bundles'),(897593,'furniture','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(897594,'furniture','.w-cart-listing .item > div.actions','padding-left','10','5131','','.w-cart-listing'),(897596,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-left','0','','','.b-products-listing'),(897597,'furniture','.b-pagination .pagination .next-pages','padding-left','5','','','.b-pagination'),(897598,'furniture','.b-pagination .pagination .page-number','padding-left','5','','','.b-pagination'),(897599,'furniture','.b-pagination .pagination .prev-pages','padding-left','5','','','.b-pagination'),(897600,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','padding-left','5','','','.b-pagination'),(897601,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','padding-left','5','','','.b-pagination'),(897602,'furniture','.b-pagination .pagination span','padding-left','5','2','','.b-pagination'),(897603,'furniture','.b-pagination ul.pagination','padding-left','0','','','.b-pagination'),(897604,'furniture','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','padding-left','10','','','.w-catalog-compare'),(897605,'furniture','.w-product-properties-filters-widgets-chosen-filters .item','padding-left','10','','','.w-product-properties-filters-widgets-chosen-filters'),(897606,'furniture','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block, .checkout > .type-1 > .block','padding-left','15','','',''),(897607,'furniture','.w-tabs .tab-li.active + .tab-li','padding-left','15','','','.w-tabs'),(897608,'furniture','.p-quote-checkout-index .datepicker-inline','padding-left','0','','','.p-quote-checkout-index'),(897609,'furniture','.p-sample-checkout-index .datepicker-inline','padding-left','0','','','.p-sample-checkout-index'),(897613,'furniture','.w-product-multi-inventory .radio-attributes .option-item','padding-left','15','','','.w-product-multi-inventory'),(897614,'furniture','.w-account-personal-catalog .list-row-action ul','padding-left','0','','','.w-account-personal-catalog'),(897615,'furniture','.w-account-personal-catalog .list-row-action li','padding-left','10','','','.w-account-personal-catalog'),(897616,'furniture','.w-account-personal-catalog .buy-box','padding-left','0','5131','','.w-account-personal-catalog'),(897617,'furniture','.b-products-listing .products-listing .radio-attributes .option','padding-left','15','','','.b-products-listing'),(897618,'furniture','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(897619,'furniture','.w-product-collection .right-area .btn','padding-left','25','','','.w-product-collection'),(897620,'furniture','.w-product-collection .right-area','padding-left','2','','','.w-product-collection'),(897621,'furniture','.w-product-collection .right-area','padding-left','0','5140','','.w-product-collection'),(897622,'furniture','.w-product-attributes .radio-attributes .option-item','padding-left','15','','','.w-product-attributes'),(897623,'furniture','.w-product-properties .property-ul','padding-left','0','','','.w-product-properties'),(897624,'furniture','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(897625,'furniture','.w-product-properties li','padding-left','0','','','.w-product-properties'),(897626,'furniture','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(897627,'furniture','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(897628,'furniture','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(897629,'furniture','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(897630,'furniture','.w-product-groups .radioBox','padding-left','0','','','.w-product-groups'),(897631,'furniture','.w-product-groups .radioBox label','padding-left','0','','','.w-product-groups'),(897632,'furniture','.w-product-groups .radioBox label .containerBlock','padding-left','10','','','.w-product-groups'),(897633,'furniture','.w-product-groups .radioBox label .containerBlock','padding-left','10','5161','','.w-product-groups'),(897634,'furniture','.w-product-groups .radioBox label .containerBlock img + .name','padding-left','60','','','.w-product-groups'),(897635,'furniture','.w-product-groups .radioBox label .containerBlock img + .name + .val2','padding-left','60','','','.w-product-groups'),(897636,'furniture','.b-products-listing .mix-attributes .attribute-qty-block','padding-left','10','','','.b-products-listing'),(897637,'furniture','.b-products-listing .products-listing .attribute-qty-block','padding-left','5','','','.b-products-listing'),(897638,'furniture','.blogsidebar','padding-left','0','5140','',''),(897639,'furniture','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(897640,'furniture','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-left','25','','','.w-product-custom-bundle'),(897641,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list'),(897642,'furniture','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(897643,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-left','10','','','.w-catalog-pages-category-pages-last-list'),(897644,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list-block'),(897645,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-left','10','','','.w-catalog-pages-category-pages-last-list-block'),(897646,'furniture','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(897647,'furniture','.w-delivery-location-location-description .deliveryDesc','padding-left','0','','','.w-delivery-location-location-description'),(897648,'furniture','.w-delivery-location-location-list .deliveryListParrent a','padding-left','25','','','.w-delivery-location-location-list'),(897649,'furniture','.w-delivery-location-location-list .deliveryList li a','padding-left','15','','','.w-delivery-location-location-list'),(897650,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding-left','2','','','.w-delivery-location-featured-list'),(897651,'furniture','.w-delivery-location-featured-list .deliveryList > ul','padding-left','0','','','.w-delivery-location-featured-list'),(897652,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding-left','0','5161','','.w-delivery-location-featured-list'),(897653,'furniture','.btn-2','padding-left','25','5131','',''),(897654,'furniture','.w-sale-category .holder-1','padding-left','20','','','.w-sale-category'),(897655,'furniture','.w-sale-category .holder-2','padding-left','20','','','.w-sale-category'),(897656,'furniture','.w-sale-category .left-count','padding-left','5','','','.w-sale-category'),(897657,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(897658,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-left','10','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(897659,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(897660,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-left','10','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(897661,'furniture','.w-delivery-location-list-by-page .description ul','padding-left','30','','','.w-delivery-location-list-by-page'),(897662,'furniture','.w-product-properties-icons .property-image','padding-left','10','','','.w-product-properties-icons'),(897663,'furniture','.w-product-properties-icons .hover-box-content','padding-left','10','','','.w-product-properties-icons'),(897664,'furniture','.w-delivery-location-cross-pages .description ul','padding-left','30','','','.w-delivery-location-cross-pages'),(897665,'furniture','.w-delivery-location-product-categories .item.category-link','padding-left','15','','','.w-delivery-location-product-categories'),(897666,'furniture','.w-delivery-location-product-categories .item.category-link','padding-left','10','5140','','.w-delivery-location-product-categories'),(897667,'furniture','.w-delivery-location-product-categories .item.category-link','padding-left','0','5161','','.w-delivery-location-product-categories'),(897668,'furniture','.w-delivery-location-product-categories .name','padding-left','15','','','.w-delivery-location-product-categories'),(897669,'furniture','.w-catalog-delivery-locations .description ul','padding-left','30','','','.w-catalog-delivery-locations'),(897670,'furniture','.delivery-options-popup','padding-left','20','','',''),(897671,'furniture','.w-product-bonus-points .bonus-points-cost','padding-left','45','','','.w-product-bonus-points'),(897672,'furniture','.w-product-designer-designer .grnamebox .title-sortable','padding-left','15','','','.w-product-designer-designer'),(897673,'furniture','.w-product-designer-designer .prodDesignerType label','padding-left','10','','','.w-product-designer-designer'),(897674,'furniture','.w-press-reviews-widgets-press-reviews ','padding-left','30','','','.w-press-reviews-widgets-press-reviews'),(897675,'furniture','.w-press-reviews-widgets-press-reviews .author','padding-left','25','','','.w-press-reviews-widgets-press-reviews'),(897676,'furniture','.w-press-reviews-widgets-press-reviews .item','padding-left','20','','','.w-press-reviews-widgets-press-reviews'),(897677,'furniture','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-left','30','','','.w-press-reviews-widgets-press-reviews'),(897678,'furniture','.w-press-reviews-widgets-press-reviews .rating','padding-left','15','','','.w-press-reviews-widgets-press-reviews'),(897679,'furniture','.w-press-reviews-widgets-press-reviews .review','padding-left','25','','','.w-press-reviews-widgets-press-reviews'),(897680,'furniture','.w-press-reviews-widgets-press-reviews .sub-box','padding-left','20','','','.w-press-reviews-widgets-press-reviews'),(897681,'furniture','.w-press-reviews-widgets-press-reviews .sub-box ul','padding-left','20','','','.w-press-reviews-widgets-press-reviews'),(897682,'furniture','.w-press-reviews-widgets-press-reviews .title','padding-left','15','','','.w-press-reviews-widgets-press-reviews'),(897683,'furniture','.w-press-reviews-widgets-press-reviews ','padding-left','15','5131','','.w-press-reviews-widgets-press-reviews'),(897684,'furniture','.w-press-reviews-widgets-press-reviews .author','padding-left','0','5131','','.w-press-reviews-widgets-press-reviews'),(897685,'furniture','.w-press-reviews-widgets-press-reviews .item','padding-left','0','5131','','.w-press-reviews-widgets-press-reviews'),(897686,'furniture','.w-press-reviews-widgets-press-reviews .rating','padding-left','0','5131','','.w-press-reviews-widgets-press-reviews'),(897687,'furniture','.w-press-reviews-widgets-press-reviews .review','padding-left','0','5131','','.w-press-reviews-widgets-press-reviews'),(897688,'furniture','.w-press-reviews-widgets-press-reviews .title','padding-left','0','5131','','.w-press-reviews-widgets-press-reviews'),(897689,'furniture','.w-press-reviews-widgets-press-reviews-list .item','padding-left','25','','','.w-press-reviews-widgets-press-reviews-list'),(897690,'furniture','.w-press-reviews-widgets-press-reviews-list .short-description','padding-left','0','','','.w-press-reviews-widgets-press-reviews-list'),(897691,'furniture','.b-products-listing .productGroup label a','padding-left','16','','','.b-products-listing'),(897692,'furniture','.w-support-system-filter ','padding-left','0','','','.w-support-system-filter'),(897693,'furniture','.w-support-system-filter .filter_cats','padding-left','0','','','.w-support-system-filter'),(897694,'furniture','.w-support-system-listing .support-head','padding-left','13','','','.w-support-system-listing'),(897695,'furniture','.w-communication-post .btn.refresh','padding-left','0','','','.w-communication-post'),(897696,'furniture','.w-rma-returns-history .btn','padding-left','10','','','.w-rma-returns-history'),(897697,'furniture','.w-rma-returns-history .column','padding-left','3','','','.w-rma-returns-history'),(897698,'furniture','.w-rma-returns-history .column .title','padding-left','10','','','.w-rma-returns-history'),(897699,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','padding-left','5','','','.w-rma-returns-history'),(897700,'furniture','.w-rma-returns-history .icons .print','padding-left','15','','','.w-rma-returns-history'),(897701,'furniture','.w-rma-returns-history .topRow','padding-left','0','','','.w-rma-returns-history'),(897702,'furniture','.w-rma-returns-history .column:last-child .title','padding-left','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(897703,'furniture','.w-product-designer-designer .productDesignerBox ul','padding-left','0','','','.w-product-designer-designer'),(897704,'furniture','.w-product-configurator .pc-item','padding-left','0','','','.w-product-configurator'),(897705,'furniture','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(897706,'furniture','.w-product-configurator .pc_item','padding-left','0','5140','','.w-product-configurator'),(897707,'furniture','.w-product-configurator .pc_attr','padding-left','0','5131','','.w-product-configurator'),(897708,'furniture','.w-product-configurator .pc-item label','padding-left','20','','','.w-product-configurator'),(897709,'furniture','.b-products-listing .promos-info .promo-name-span','padding-left','40','','','.b-products-listing'),(897710,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-list'),(897711,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-left','10','','','.w-catalog-pages-category-pages-list'),(897712,'furniture','.w-predefined-promotion .nextdiscount .content > div','padding-left','10','','','.w-predefined-promotion'),(897713,'furniture','.w-predefined-promotion .nextdiscount .promo-for-each','padding-left','10','','','.w-predefined-promotion'),(897714,'furniture','.w-predefined-promotion .prom-multi-discount .promo-product','padding-left','20','','','.w-predefined-promotion'),(897715,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','padding-left','20','','','.w-predefined-promotion'),(897716,'furniture','.w-predefined-promotion .promo-cart-discount .master .item','padding-left','20','','','.w-predefined-promotion'),(897717,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-left','20','','','.w-predefined-promotion'),(897718,'furniture','.w-predefined-promotion .promo-cart-discount .slave','padding-left','15','','','.w-predefined-promotion'),(897719,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-left','20','','','.w-predefined-promotion'),(897720,'furniture','.w-predefined-promotion .promo-cart-discount .slave .item','padding-left','20','','','.w-predefined-promotion'),(897721,'furniture','.w-predefined-promotion .promo-item','padding-left','40','','','.w-predefined-promotion'),(897722,'furniture','.w-predefined-promotion .promo-salemaker .discount','padding-left','20','','','.w-predefined-promotion'),(897723,'furniture','.w-predefined-promotion .promo-salemaker .item','padding-left','20','','','.w-predefined-promotion'),(897724,'furniture','.w-predefined-promotion .promo-salemaker .promo-manufacturers','padding-left','12','','','.w-predefined-promotion'),(897725,'furniture','.w-supplier-purchase-supplier-products .item','padding-left','20','','','.w-supplier-purchase-supplier-products'),(897726,'furniture','.w-filters .filter-box-content ul','padding-left','0','','','.w-filters'),(897727,'furniture','.mainBanner .bottomBox','padding-left','20','','','.mainBanner'),(897728,'furniture','.mainBanner .bottomBox .btn','padding-left','1.30','','','.mainBanner'),(897729,'furniture','.mainBanner .title','padding-left','130','','','.mainBanner'),(897730,'furniture','.mainBanner .topBox','padding-left','10','','','.mainBanner'),(897731,'furniture','.mainBanner .topBox > .right','padding-left','15','','','.mainBanner'),(897732,'furniture','.mainBanner .wrapper','padding-left','6','','','.mainBanner'),(897733,'furniture','.mainBanner > .block','padding-left','0','','','.mainBanner'),(897734,'furniture','.mainBanner .bottomBox','padding-left','20','5145','','.mainBanner'),(897735,'furniture','.mainBanner .bottomBox .btn','padding-left','20','5145','','.mainBanner'),(897736,'furniture','.mainBanner .topBox','padding-left','10','5145','','.mainBanner'),(897737,'furniture','.mainBanner .topBox > .right','padding-left','15','5145','','.mainBanner'),(897738,'furniture','.mainBanner .wrapper','padding-left','2','5145','','.mainBanner'),(897739,'furniture','.mainBanner .bottomBox .btn','padding-left','20','5140','','.mainBanner'),(897740,'furniture','.mainBanner .title','padding-left','90','5140','','.mainBanner'),(897741,'furniture','.mainBanner .topBox','padding-left','40','5131','','.mainBanner'),(897742,'furniture','.mainBanner .topBox > .right','padding-left','15','5131','','.mainBanner'),(897743,'furniture','.mainBanner .wrapper','padding-left','2','5131','','.mainBanner'),(897744,'furniture','.mainBanner .bottomBox','padding-left','20','5161','','.mainBanner'),(897745,'furniture','.mainBanner .bottomBox .btn','padding-left','15','5161','','.mainBanner'),(897746,'furniture','.mainBanner .wrapper','padding-left','2','5161','','.mainBanner'),(897747,'furniture','.mainBanner .bottomBox .btn','padding-left','20','5206','','.mainBanner'),(897748,'furniture','.order-summary .w-cart-listing .item .name','padding-left','0','','','.order-summary'),(897749,'furniture','.order-summary .w-cart-listing .item > div ~ div','padding-left','10','','','.order-summary'),(897750,'furniture','.order-summary .heading-2','padding-left','10','5145','','.order-summary'),(897751,'furniture','.w-cart-discount-coupon .discount-box','padding-left','10','','','.w-cart-discount-coupon'),(897752,'furniture','.w-cart-listing .promos-info .promo-name','padding-left','15','','','.w-cart-listing'),(897753,'furniture','.w-cart-listing .item .image','padding-left','10','5140','','.w-cart-listing'),(897754,'furniture','.w-cart-listing .item .name','padding-left','10','5140','','.w-cart-listing'),(897755,'furniture','.w-cart-listing .item .points','padding-left','0','5131','','.w-cart-listing'),(897756,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','padding-left','0','','','.w-promotions-widgets-promotion-icons-desc'),(897757,'furniture','.w-product-promotion-icons .promos-info .promo-name','padding-left','15','','','.w-product-promotion-icons'),(897758,'furniture','.w-quote-products .no-price','padding-left','15','','','.w-quote-products'),(897759,'furniture','.w-product-quantity-discounts .item','padding-left','20','','','.w-product-quantity-discounts'),(897765,'furniture','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','padding-left','20','','','.b-product-images'),(897766,'furniture','.b-product-images .media-popup .mp-small-images img','padding-left','10','','','.b-product-images'),(897787,'furniture','.account-address-book .address_book','padding-left','0','','','.account-address-book'),(897788,'furniture','.account-address-book .address_book h1','padding-left','0','','','.account-address-book'),(897789,'furniture','.account-address-book .address_book h2','padding-left','10','','','.account-address-book'),(897790,'furniture','.account-address-book .address_book, .account-address-book .account_history_info','padding-left','0','','','.account-address-book'),(897791,'furniture','.account-address-book .buttonBox','padding-left','0','','','.account-address-book'),(897792,'furniture','.account-address-book .leftMes ul','padding-left','0','','','.account-address-book'),(897793,'furniture','.account-address-book .rightMes ul','padding-left','19','','','.account-address-book'),(897794,'furniture','.account-address-book .topButtons','padding-left','0','','','.account-address-book'),(897807,'furniture','.account-order-pay .contentColumn','padding-left','40','','','.account-order-pay'),(897808,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-left','40','','','.account-order-pay'),(897809,'furniture','.account-order-pay .history_info > div + div','padding-left','2','','','.account-order-pay'),(897810,'furniture','.account-order-pay .history_info > div','padding-left','0','5140','','.account-order-pay'),(897811,'furniture','.account-order-pay .history_info > div + div','padding-left','0','5140','','.account-order-pay'),(897812,'furniture','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-left','10','','','.account-samples'),(897813,'furniture','.account-samples .orders-table th','padding-left','10','','','.account-samples'),(897814,'furniture','.account-samples .order_history_table th','padding-left','10','','','.account-samples'),(897815,'furniture','.account-samples .view_link','padding-left','0','','','.account-samples'),(897816,'furniture','.account-samples .orders-table .td-alignright','padding-left','10','5140','','.account-samples'),(897817,'furniture','.account-samples .orders-table td','padding-left','10','5140','','.account-samples'),(897818,'furniture','.account-sample-info .contentColumn','padding-left','40','','','.account-sample-info'),(897819,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-left','40','','','.account-sample-info'),(897820,'furniture','.account-sample-info .history_info > div + div','padding-left','2','','','.account-sample-info'),(897821,'furniture','.account-sample-info .popup-tracking-number','padding-left','10','','','.account-sample-info'),(897822,'furniture','.account-sample-info .history_info > div','padding-left','0','5140','','.account-sample-info'),(897823,'furniture','.account-sample-info .history_info > div + div','padding-left','0','5140','','.account-sample-info'),(897824,'furniture','.catalog-product-wrap .next-product','padding-left','20','','','.catalog-product-wrap'),(897825,'furniture','.catalog-product-wrap .next-product .pn-image','padding-left','2','3','','.catalog-product-wrap'),(897826,'furniture','.catalog-product-wrap .pn-direction','padding-left','4','','','.catalog-product-wrap'),(897827,'furniture','.catalog-product-wrap .pn-image','padding-left','5','','','.catalog-product-wrap'),(897828,'furniture','.catalog-product-wrap .prev-product','padding-left','50','','','.catalog-product-wrap'),(897829,'furniture','.catalog-product-wrap .next-product','padding-left','0','5140','','.catalog-product-wrap'),(897830,'furniture','.catalog-product-wrap .pn-direction','padding-left','0','5140','','.catalog-product-wrap'),(897831,'furniture','.catalog-product-wrap .prev-product','padding-left','0','5140','','.catalog-product-wrap'),(897832,'furniture','.checkout-index-wrap .datepicker-inline','padding-left','0','','','.checkout-index-wrap'),(897833,'furniture','.checkout-index-wrap .edit-address-popup','padding-left','20','','','.checkout-index-wrap'),(897834,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-left','25','','','.checkout-index-wrap'),(897835,'furniture','.checkout-index-wrap .hiding-box .checkout-cart-listing','padding-left','30','','','.checkout-index-wrap'),(897836,'furniture','.checkout-order-confirmation .price-row','padding-left','0','','','.checkout-order-confirmation'),(897837,'furniture','.shopping-cart-index .btn-3','padding-left','25','','','.shopping-cart-index'),(897838,'furniture','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-left','20','','','.shopping-cart-index'),(897839,'furniture','.b-form .addresses.address-main .address-item','padding-left','0','','','.b-form'),(897840,'furniture','.b-form .columns .col-2','padding-left','10','','','.b-form'),(897841,'furniture','.b-bottom .pop-up-content','padding-left','15','','','.b-bottom'),(897842,'furniture','.b-bottom .pop-up-content .buttons','padding-left','0','','','.b-bottom'),(897843,'furniture','.checkout-index-wrap .closeable-heading','padding-left','20','','','.checkout-index-wrap'),(897844,'furniture','.checkout-index-wrap .closeable-content','padding-left','20','','','.checkout-index-wrap'),(897845,'furniture','.b-form .middle-g','padding-left','0','','','.b-form'),(897846,'furniture','.b-info .info','padding-left','40','','','.b-info'),(897847,'furniture','.b-info .info li','padding-left','0','','','.b-info'),(897848,'furniture','.b-info .info ul','padding-left','0','','','.b-info'),(897849,'furniture','.b-multi-page-checkout .multi-page-checkout .buttons','padding-left','0','','','.b-multi-page-checkout'),(897850,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-left','10','','','.b-multi-page-checkout'),(897851,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-left','10','','','.b-multi-page-checkout'),(897852,'furniture','.b-form .col-left','padding-left','5','','','.b-form'),(897853,'furniture','.b-form .col-right','padding-left','5','','','.b-form'),(897854,'furniture','.success-page .check-ico-block','padding-left','10','','','.success-page'),(897855,'furniture','.success-page .order-summary2 .btn-2','padding-left','50','','','.success-page'),(897856,'furniture','.success-page .order_totals .price-row','padding-left','0','','','.success-page'),(897857,'furniture','.success-page .price-row','padding-left','0','','','.success-page'),(897858,'furniture','.success-page .w-cart-listing .item.sub-product','padding-left','50','','','.success-page'),(897859,'furniture','.success-page .w-cart-listing .qty','padding-left','0','','','.success-page'),(897860,'furniture','.success-page .w-cart-listing .sub-product .image','padding-left','0','','','.success-page'),(897861,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','padding-left','0','','','.mainBanner'),(897862,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','padding-left','0','','','.mainBanner'),(897863,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','padding-left','0','','','.mainBanner'),(897864,'furniture','.menu-header .menu-style[data-style=\"1\"] .goto-button','padding-left','20','','','.menu-header'),(897865,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > li > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-left','5','','','.menu-header'),(897866,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','padding-left','20','','','.menu-header'),(897867,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li','padding-left','18','','','.footer-menu'),(897868,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li.component-item','padding-left','0','','','.footer-menu'),(897869,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li + li','padding-left','20','5198','','.footer-menu'),(897870,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-left','0','5140','','.footer-menu'),(897871,'furniture','.lowestPricedBox .w-banner .banner-holder','padding-left','0','','','.lowestPricedBox'),(897872,'furniture','.lowestPricedBox .w-banner .banner-holder','padding-left','0','5131','','.lowestPricedBox'),(897873,'furniture','.lowestPricedBox .w-banner .banner-text','padding-left','0','','','.lowestPricedBox'),(897874,'furniture','.lowestPricedBox .w-banner .banner-text-holder','padding-left','24','','','.lowestPricedBox'),(897875,'furniture','.lowestPricedBox .w-banner .banner-text-holder','padding-left','10','5140','','.lowestPricedBox'),(897876,'furniture','.lowestPricedBox .w-banner .banner-text-holder','padding-left','10','5161','','.lowestPricedBox'),(897877,'furniture','.lowestPricedBox .w-banner .ybg .btn','padding-left','25','5140','','.lowestPricedBox'),(897878,'furniture','.lowestPricedBox .w-banner .ybg .btn','padding-left','20','5161','','.lowestPricedBox'),(897879,'furniture','.lowestPricedBox .w-banner .ybg .mark','padding-left','0','','','.lowestPricedBox'),(897880,'furniture','.tripleBanner .w-html_box','padding-left','90','','','.tripleBanner'),(897881,'furniture','.tripleBanner > .block','padding-left','15','','','.tripleBanner'),(897882,'furniture','.shopByCollectionBox .bannerButton a','padding-left','25','','','.shopByCollectionBox'),(897883,'furniture','.shopByCollectionBox .bannerButton a','padding-left','25','5145','','.shopByCollectionBox'),(897884,'furniture','.shopByCollectionBox .content','padding-left','20','','','.shopByCollectionBox'),(897885,'furniture','.shopByCollectionBox .w-banner .banner-text','padding-left','0','','','.shopByCollectionBox'),(897887,'furniture','.w-banner .banner-text','padding-left','20','','','.w-banner'),(897888,'furniture','.w-banner .carousel-text > span','padding-left','20','','','.w-banner'),(897889,'furniture','.w-catalog-paging ','padding-left','5','2','','.w-catalog-paging'),(897890,'furniture','.w-catalog-paging .next','padding-left','5','','','.w-catalog-paging'),(897891,'furniture','.w-catalog-paging .next-pages','padding-left','5','','','.w-catalog-paging'),(897892,'furniture','.w-catalog-paging .page-number','padding-left','5','','','.w-catalog-paging'),(897893,'furniture','.w-catalog-paging .paging-item','padding-left','2','','','.w-catalog-paging'),(897894,'furniture','.w-catalog-paging .prev','padding-left','5','','','.w-catalog-paging'),(897895,'furniture','.w-catalog-paging .prev-pages','padding-left','5','','','.w-catalog-paging'),(897896,'furniture','.b-data-table table.dataTable tbody td','padding-left_important','important','','','.b-data-table'),(897897,'furniture','.b-data-table table.dataTable thead td','padding-left_important','important','','','.b-data-table'),(897898,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left_important','important','','','.b-data-table'),(897899,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left_important','important','','','.b-data-table'),(897900,'furniture','.w-account-personal-catalog .buy-box','padding-left_important','important','5131','','.w-account-personal-catalog'),(897901,'furniture','.mainBanner > .block','padding-left_important','important','','','.mainBanner'),(897902,'furniture','.w-cart-listing .item .points','padding-left_important','important','5131','','.w-cart-listing'),(897903,'furniture','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-right','10','','','.w-communication-new-topic'),(897904,'furniture','.b-email .image','padding-right','10','','','.b-email'),(897905,'furniture','.order-summary .btn-2, .order-summary .btn-3','padding-right','5','','','.order-summary'),(897906,'furniture','.b-table .table td','padding-right','15','','','.b-table'),(897909,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(897910,'furniture','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(897911,'furniture','.b-form .required-message-wrap','padding-right','0','','','.b-form'),(897912,'furniture','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-right','10','','','.p-quick-order-index'),(897913,'furniture','.p-quick-order-index ul.token-input-list','padding-right','0','','','.p-quick-order-index'),(897914,'furniture','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-right','10','','','.p-quick-order-index'),(897915,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.p-quick-order-index'),(897916,'furniture','.w-promotions .promo-date > div','padding-right','50','','','.w-promotions'),(897917,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.p-quick-order-index'),(897918,'furniture','.w-promotions .promo-item','padding-right','40','','','.w-promotions'),(897919,'furniture','.w-socials > li','padding-right','15','','','.w-socials'),(897920,'furniture','.w-cart-compare .attributes-label','padding-right','10','','','.w-cart-compare'),(897925,'furniture','.w-personal-gift-status-bar .start-label','padding-right','5','','','.w-personal-gift-status-bar'),(897926,'furniture','.w-personal-gift-status-bar .end-label','padding-right','30','','','.w-personal-gift-status-bar'),(897927,'furniture','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(897928,'furniture','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(897929,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(897930,'furniture','.b-email .image','padding-right','10','','','.b-email'),(897931,'furniture','.b-email .heading-qty','padding-right','10','','','.b-email'),(897932,'furniture','.b-email .totals-value','padding-right','10','','','.b-email'),(897933,'furniture','.b-email .model','padding-right','10','','','.b-email'),(897934,'furniture','.testimonials .heading-3','padding-right','0','','',''),(897935,'furniture','.testimonials .review','padding-right','10','','',''),(897936,'furniture','.testimonials .reviews-list .name','padding-right','10','','',''),(897937,'furniture','.testimonials .name','padding-right','10','','',''),(897938,'furniture','.w-categories .image','padding-right','0','','','.w-categories'),(897939,'furniture','.w-promotions .prom-multi-discount .promo-range','padding-right','20','','','.w-promotions'),(897940,'furniture','.w-promotions .prom-multi-discount .promo-product','padding-right','20','','','.w-promotions'),(897941,'furniture','.w-promotions .nextdiscount .item-holder .image','padding-right','10','','','.w-promotions'),(897942,'furniture','.w-promotions .nextdiscount .content > div','padding-right','10','','','.w-promotions'),(897943,'furniture','.w-promotions .master','padding-right','15','','','.w-promotions'),(897944,'furniture','.w-promotions .nextdiscount .promo-for-each','padding-right','20','','','.w-promotions'),(897945,'furniture','.w-promotions .heading','padding-right','10','','','.w-promotions'),(897946,'furniture','.w-promotions .promo-salemaker .promo-categories','padding-right','12','','','.w-promotions'),(897947,'furniture','.w-promotions .promo-salemaker .item','padding-right','20','','','.w-promotions'),(897948,'furniture','.w-promotions .promo-salemaker .discount','padding-right','20','','','.w-promotions'),(897949,'furniture','.w-promotions .promo-cart-discount .slave .item','padding-right','20','','','.w-promotions'),(897950,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','padding-right','20','','','.w-promotions'),(897951,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','padding-right','20','','','.w-promotions'),(897952,'furniture','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-right','20','','','.b-warehouses-popup'),(897953,'furniture','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-right','2','','','.b-products-listing'),(897955,'furniture','.w-cart-compare .attributes-cell','padding-right','20','','','.w-cart-compare'),(897956,'furniture','.b-table .table td','padding-right','15','','','.b-table'),(897957,'furniture','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(897958,'furniture','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(897960,'furniture','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(897961,'furniture','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(897962,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(897963,'furniture','.b-bottom .confirm-popup .confirm-text','padding-right','0','','','.b-bottom'),(897964,'furniture','.w-top-categories h2.name','padding-right','3','','','.w-top-categories'),(897965,'furniture','.b-messages .messages-menu ul','padding-right','0','','','.b-messages'),(897966,'furniture','.b-messages .development-content .type-6 .content','padding-right','40','','','.b-messages'),(897967,'furniture','.b-messages .msv_btn','padding-right','0','','','.b-messages'),(897968,'furniture','.b-messages .msv_content','padding-right','20','','','.b-messages'),(897969,'furniture','.b-messages .msv_history','padding-right','20','','','.b-messages'),(897970,'furniture','.b-messages .messMenuButton span','padding-right','15','','','.b-messages'),(897971,'furniture','.b-messages .messages-menu li a','padding-right','0','','','.b-messages'),(897972,'furniture','.b-messages .messages-menu li','padding-right','0','','','.b-messages'),(897973,'furniture','.b-messages .content_management_attach button','padding-right','27','','','.b-messages'),(897974,'furniture','.b-messages .email-heading','padding-right','15','','','.b-messages'),(897975,'furniture','.b-messages .content_management_attach','padding-right','8','','','.b-messages'),(897976,'furniture','.b-messages .emailLineTextArea textarea','padding-right','10','','','.b-messages'),(897977,'furniture','.b-messages .msv_to_cc','padding-right','15','','','.b-messages'),(897978,'furniture','.b-messages .emailBtn','padding-right','10','','','.b-messages'),(897979,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-right','10','','','.b-messages'),(897980,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-right','10','','',''),(897981,'furniture','.w-sitemap-delivery-location > ul > li > ul > li','padding-right','20','','','.w-sitemap-delivery-location'),(897982,'furniture','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(897983,'furniture','.w-reviews-content .item','padding-right','0','','','.w-reviews-content'),(897984,'furniture','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(897985,'furniture','.w-sitemap-delivery-location > ul > li > ul','padding-right','0','','','.w-sitemap-delivery-location'),(897986,'furniture','.w-sitemap-delivery-location > ul','padding-right','0','','','.w-sitemap-delivery-location'),(897987,'furniture','.w-checkout-terms .required-message','padding-right','10','','','.w-checkout-terms'),(897988,'furniture','.w-cart-listing .item .remove','padding-right','10','5140','','.w-cart-listing'),(897989,'furniture','.b-table .table td','padding-right','15','','','.b-table'),(897990,'furniture','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(897991,'furniture','.b-email .model','padding-right','10','','','.b-email'),(897992,'furniture','.b-upload-file .upload-file-template','padding-right','1','','','.b-upload-file'),(897993,'furniture','.b-email .heading-image','padding-right','10','','','.b-email'),(897994,'furniture','.b-email .heading-image','padding-right','10','','','.b-email'),(897995,'furniture','.b-email .heading-price','padding-right','10','','','.b-email'),(897996,'furniture','.b-email .heading-name','padding-right','10','','','.b-email'),(897997,'furniture','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(897998,'furniture','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(897999,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(898000,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(898001,'furniture','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(898002,'furniture','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(898003,'furniture','.b-email .price','padding-right','10','','','.b-email'),(898004,'furniture','.w-filters .filter-ul-content','padding-right','0','','','.w-filters'),(898005,'furniture','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(898006,'furniture','.w-login-block .returning','padding-right','40','','','.w-login-block'),(898007,'furniture','.w-menu-horizontal > ul > li > ul > li','padding-right','10','','','.w-menu-horizontal'),(898008,'furniture','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-right','10','','','.w-menu-horizontal'),(898009,'furniture','.w-menu-horizontal ul','padding-right','0','','','.w-menu-horizontal'),(898010,'furniture','.w-tabs .tab-navigation','padding-right','0','','','.w-tabs'),(898011,'furniture','.b-email .heading-model','padding-right','10','','','.b-email'),(898012,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(898013,'furniture','.b-email .heading-price','padding-right','10','','','.b-email'),(898015,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(898016,'furniture','.b-fancybox .fancybox-title-over-wrap','padding-right','10','','','.b-fancybox'),(898017,'furniture','.b-email .image','padding-right','10','','','.b-email'),(898018,'furniture','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(898019,'furniture','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(898020,'furniture','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(898021,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(898022,'furniture','.b-table .table .headings td','padding-right','10','','','.b-table'),(898023,'furniture','.b-sub-totals .historyTotal td','padding-right','5','','','.b-sub-totals'),(898024,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(898025,'furniture','.b-email .heading-price','padding-right','10','','','.b-email'),(898026,'furniture','.b-email .qty','padding-right','10','','','.b-email'),(898027,'furniture','.w-cart-compare .dropdown .dropdown-menu','padding-right','0','','','.w-cart-compare'),(898028,'furniture','textarea','padding-right','10','','',''),(898029,'furniture','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(898030,'furniture','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(898031,'furniture','.w-cart-compare .product','padding-right','15','','','.w-cart-compare'),(898032,'furniture','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(898033,'furniture','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(898035,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-right','10','','','.w-image-maps'),(898036,'furniture','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(898037,'furniture','.b-table .table .headings td','padding-right','10','','','.b-table'),(898038,'furniture','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(898039,'furniture','.b-form .payment-method .item','padding-right','0','','','.b-form'),(898040,'furniture','.message.success','padding-right','0','','',''),(898041,'furniture','.w-promo-code .holder','padding-right','20','5161','','.w-promo-code'),(898042,'furniture','.w-cart-discount-coupon .btn','padding-right','25','','','.w-cart-discount-coupon');
INSERT INTO `themes_styles` VALUES (898043,'furniture','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(898044,'furniture','.w-checkout-shipping-choice span','padding-right','0','','','.w-checkout-shipping-choice'),(898045,'furniture','.b-email .heading-qty','padding-right','10','','','.b-email'),(898046,'furniture','.p-quick-order-index .bottom','padding-right','0','','','.p-quick-order-index'),(898047,'furniture','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(898048,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-right','0','','','.b-select-suggest'),(898049,'furniture','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(898050,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(898051,'furniture','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(898052,'furniture','.w-reviews .review','padding-right','10','','','.w-reviews'),(898053,'furniture','.w-socials > li','padding-right','15','','','.w-socials'),(898055,'furniture','.b-info-popup .info-popup div','padding-right','15','','','.b-info-popup'),(898056,'furniture','.b-form .password-forgotten-link','padding-right','0','','','.b-form'),(898058,'furniture','.w-cart-compare .atr-col','padding-right','30','','','.w-cart-compare'),(898059,'furniture','.w-reviews .author','padding-right','10','','','.w-reviews'),(898060,'furniture','.b-form .login-col-1','padding-right','20','','','.b-form'),(898061,'furniture','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(898062,'furniture','.w-promo-code .holder','padding-right','20','5161','','.w-promo-code'),(898063,'furniture','.w-product-images-additional .images','padding-right','0','5161','','.w-product-images-additional'),(898064,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(898065,'furniture','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-right','0','','','.w-multi-cart-actions'),(898066,'furniture','.w-top-categories .item','padding-right','20','','','.w-top-categories'),(898067,'furniture','.w-tabs > .block','padding-right','20','','','.w-tabs'),(898068,'furniture','.w-tabs .accordion-heading','padding-right','8','5131','','.w-tabs'),(898069,'furniture','.w-cart-cart-tabs .w-tabs > .block','padding-right','0','','','.w-cart-cart-tabs'),(898070,'furniture','.w-tabs .tab-a','padding-right','6','','','.w-tabs'),(898071,'furniture','.w-tabs .tab-li','padding-right','15','','','.w-tabs'),(898072,'furniture','.w-socials > li','padding-right','15','','','.w-socials'),(898073,'furniture','.b-autocomplete .ui-autocomplete li','padding-right','10','','','.b-autocomplete'),(898074,'furniture','.b-bottom .popup-buttons','padding-right','15','','','.b-bottom'),(898075,'furniture','.b-bottom .popup-content','padding-right','15','','','.b-bottom'),(898076,'furniture','.w-product-images-additional .images','padding-right','0','5161','','.w-product-images-additional'),(898077,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(898078,'furniture','.b-form .required-message','padding-right','3','','','.b-form'),(898079,'furniture','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(898080,'furniture','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(898081,'furniture','.btn-1','padding-right','25','','',''),(898082,'furniture','.w-reviews-content .review','padding-right','20','','','.w-reviews-content'),(898083,'furniture','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(898084,'furniture','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(898085,'furniture','.b-table .table .headings td','padding-right','10','','','.b-table'),(898086,'furniture','.btn-3','padding-right','25','','',''),(898087,'furniture','.w-filters .filter-widget-horizontal .filter-box','padding-right','20','','','.w-filters'),(898088,'furniture','.w-product-images-additional .images','padding-right','0','5161','','.w-product-images-additional'),(898089,'furniture','.b-products-listing .products-listing .buyButton .btn','padding-right','10','','','.b-products-listing'),(898090,'furniture','.b-bottom .popup-heading','padding-right','15','','','.b-bottom'),(898091,'furniture','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(898092,'furniture','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(898093,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(898094,'furniture','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(898095,'furniture','.b-email .totals-title','padding-right','10','','','.b-email'),(898096,'furniture','.b-email .price','padding-right','10','','','.b-email'),(898097,'furniture','.b-email .totals-value','padding-right','10','','','.b-email'),(898098,'furniture','.b-email .heading-name','padding-right','10','','','.b-email'),(898099,'furniture','.b-email .image','padding-right','10','','','.b-email'),(898100,'furniture','.b-email .name','padding-right','10','','','.b-email'),(898101,'furniture','.order-summary .price-row','padding-right','0','','','.order-summary'),(898102,'furniture','.b-email .name','padding-right','10','','','.b-email'),(898103,'furniture','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-right','0','','','.b-fancybox'),(898104,'furniture','.w-socials > li','padding-right','15','','','.w-socials'),(898106,'furniture','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(898107,'furniture','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(898108,'furniture','.b-select-suggest .select2-drop-mask','padding-right','0','','','.b-select-suggest'),(898110,'furniture','.w-quote .cart-box-link','padding-right','10','','','.w-quote'),(898111,'furniture','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(898112,'furniture','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(898113,'furniture','.b-email .price','padding-right','10','','','.b-email'),(898114,'furniture','.b-fancybox .fancybox-title-float-wrap .child','padding-right','20','','','.b-fancybox'),(898115,'furniture','.w-checkout-shipping-choice span','padding-right','10','5161','','.w-checkout-shipping-choice'),(898116,'furniture','.w-top-categories .categories h2','padding-right','0','','','.w-top-categories'),(898117,'furniture','.w-top-categories .image','padding-right','0','','','.w-top-categories'),(898118,'furniture','.w-product-reviews .reviews-list .review','padding-right','10','','','.w-product-reviews'),(898119,'furniture','.w-reviews-content .product-image','padding-right','10','','','.w-reviews-content'),(898120,'furniture','.w-product-reviews .reviews-list .name','padding-right','10','','','.w-product-reviews'),(898121,'furniture','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(898122,'furniture','.b-email .name','padding-right','10','','','.b-email'),(898123,'furniture','.b-fancybox .fancybox-prev span','padding-right','4','3','','.b-fancybox'),(898124,'furniture','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(898125,'furniture','.b-bottom .popup-simple','padding-right','20','','','.b-bottom'),(898126,'furniture','.b-bottom .rfq-form','padding-right','20','','','.b-bottom'),(898127,'furniture','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(898128,'furniture','.b-email .heading-image','padding-right','10','','','.b-email'),(898129,'furniture','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(898130,'furniture','.b-email .model','padding-right','10','','','.b-email'),(898131,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(898132,'furniture','.b-email .name','padding-right','10','','','.b-email'),(898133,'furniture','.b-email .heading-price','padding-right','10','','','.b-email'),(898134,'furniture','.b-email .heading-qty','padding-right','10','','','.b-email'),(898135,'furniture','.b-email .image','padding-right','10','','','.b-email'),(898136,'furniture','.b-email .price','padding-right','10','','','.b-email'),(898137,'furniture','.b-email .heading-model','padding-right','10','','','.b-email'),(898138,'furniture','.b-email .totals-title','padding-right','10','','','.b-email'),(898139,'furniture','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(898140,'furniture','.b-email .totals-value','padding-right','10','','','.b-email'),(898141,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(898142,'furniture','.b-email .price','padding-right','10','','','.b-email'),(898143,'furniture','.b-email .qty','padding-right','10','','','.b-email'),(898144,'furniture','.b-email .heading-name','padding-right','10','','','.b-email'),(898145,'furniture','.b-email .heading-image','padding-right','10','','','.b-email'),(898146,'furniture','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(898147,'furniture','.w-checkout-shipping .sub-item','padding-right','0','','','.w-checkout-shipping'),(898148,'furniture','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(898149,'furniture','.b-table .table .headings td','padding-right','10','','','.b-table'),(898150,'furniture','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(898151,'furniture','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(898152,'furniture','.w-promo-code .holder','padding-right','20','5161','','.w-promo-code'),(898153,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(898154,'furniture','.b-form .center-buttons','padding-right','0','','','.b-form'),(898155,'furniture','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(898156,'furniture','.b-form .shipping-method .input','padding-right','10','','','.b-form'),(898157,'furniture','.w-reviews .item','padding-right','0','','','.w-reviews'),(898158,'furniture','.w-reviews .product-image','padding-right','20','','','.w-reviews'),(898159,'furniture','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(898160,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(898161,'furniture','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(898162,'furniture','.b-select-suggest .select2-container .select2-choice','padding-right','0','','','.b-select-suggest'),(898163,'furniture','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(898164,'furniture','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(898165,'furniture','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(898166,'furniture','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(898167,'furniture','.b-bottom .terms-info-popup .pop-up-content','padding-right','20','','','.b-bottom'),(898168,'furniture','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','5140','','.w-menu-horizontal'),(898169,'furniture','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(898170,'furniture','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(898171,'furniture','.b-upload-files .upload-files','padding-right','10','','','.b-upload-files'),(898172,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(898173,'furniture','.w-login-block .returning','padding-right','40','','','.w-login-block'),(898174,'furniture','.b-form .form-buttons','padding-right','0','','','.b-form'),(898175,'furniture','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(898176,'furniture','.w-login-block .returning','padding-right','40','','','.w-login-block'),(898177,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(898179,'furniture','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(898180,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(898181,'furniture','.w-cart-compare .delete-cart','padding-right','10','','','.w-cart-compare'),(898182,'furniture','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(898183,'furniture','.b-email .name','padding-right','10','','','.b-email'),(898184,'furniture','.b-email .totals-value','padding-right','10','','','.b-email'),(898185,'furniture','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(898186,'furniture','.b-email .qty','padding-right','10','','','.b-email'),(898187,'furniture','.b-email .heading-name','padding-right','10','','','.b-email'),(898188,'furniture','.b-email .heading-model','padding-right','10','','','.b-email'),(898189,'furniture','.w-categories .item','padding-right','20','','','.w-categories'),(898190,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(898191,'furniture','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(898192,'furniture','.b-email .heading-image','padding-right','10','','','.b-email'),(898193,'furniture','.b-email .heading-price','padding-right','10','','','.b-email'),(898194,'furniture','.b-email .image','padding-right','10','','','.b-email'),(898195,'furniture','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-right','20','','','.b-bottom'),(898196,'furniture','.w-promo-code .holder','padding-right','20','5161','','.w-promo-code'),(898197,'furniture','.b-compare .popupCompare .pop-up-content','padding-right','10','','','.b-compare'),(898198,'furniture','.w-promotions .promo-cart-discount .master .item','padding-right','20','','','.w-promotions'),(898199,'furniture','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(898200,'furniture','.b-bottom .cart-options','padding-right','20','','','.b-bottom'),(898201,'furniture','.b-bottom .alert-message','padding-right','20','','','.b-bottom'),(898202,'furniture','.b-select-suggest .select2-results .select2-result-label','padding-right','7','','','.b-select-suggest'),(898203,'furniture','.w-personal-gift-status-bar .inform','padding-right','5','4','','.w-personal-gift-status-bar'),(898204,'furniture','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(898205,'furniture','.b-email .totals-title','padding-right','10','','','.b-email'),(898208,'furniture','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(898209,'furniture','.b-email .heading-model','padding-right','10','','','.b-email'),(898210,'furniture','.b-email .heading-qty','padding-right','10','','','.b-email'),(898211,'furniture','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(898212,'furniture','.b-email .model','padding-right','10','','','.b-email'),(898213,'furniture','.b-email .heading-model','padding-right','10','','','.b-email'),(898214,'furniture','.b-bottom .footerTitle','padding-right','0','5131','','.b-bottom'),(898215,'furniture','.b-bottom .pop-up-close','padding-right','1','','','.b-bottom'),(898216,'furniture','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(898217,'furniture','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(898218,'furniture','.w-cart-shipping-estimator .address-item','padding-right','10','','','.w-cart-shipping-estimator'),(898219,'furniture','.w-cart-up-sell .w-list-type-1','padding-right','0','','','.w-cart-up-sell'),(898220,'furniture','.w-cart-up-sell .w-list-type-1 .item','padding-right','21','','','.w-cart-up-sell'),(898221,'furniture','.w-cart-up-sell .w-list-type-1 .item','padding-right','20','1','','.w-cart-up-sell'),(898222,'furniture','.b-products-listing .products-listing .btn-buy','padding-right','10','','','.b-products-listing'),(898223,'furniture','.b-upload-files .added-file','padding-right','0','','','.b-upload-files'),(898224,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(898225,'furniture','.b-bottom .popup-box-wrap','padding-right','10','','','.b-bottom'),(898226,'furniture','.b-bottom .pop-up-info','padding-right','20','','','.b-bottom'),(898227,'furniture','.b-email .qty','padding-right','10','','','.b-email'),(898228,'furniture','.b-email .name','padding-right','10','','','.b-email'),(898229,'furniture','.b-email .heading-qty','padding-right','10','','','.b-email'),(898230,'furniture','.b-fancybox .fancybox-error','padding-right','15','','','.b-fancybox'),(898231,'furniture','.b-email .totals-title','padding-right','10','','','.b-email'),(898232,'furniture','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(898233,'furniture','.w-product-customers-activity .customers-activity','padding-right','20','','','.w-product-customers-activity'),(898234,'furniture','.w-product-available-in-warehouses .warehouse-item','padding-right','20','','','.w-product-available-in-warehouses'),(898235,'furniture','.b-table .table td','padding-right','15','','','.b-table'),(898236,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(898237,'furniture','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(898238,'furniture','.b-email .heading-name','padding-right','10','','','.b-email'),(898239,'furniture','.b-email .heading-model','padding-right','10','','','.b-email'),(898240,'furniture','.b-table .table .headings td','padding-right','10','','','.b-table'),(898241,'furniture','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(898242,'furniture','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(898243,'furniture','.w-cart-compare .price-label','padding-right','10','','','.w-cart-compare'),(898244,'furniture','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(898245,'furniture','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(898246,'furniture','.w-checkout-billing-address .edit-ab','padding-right','0','','','.w-checkout-billing-address'),(898247,'furniture','.w-checkout-billing-address .addresses .address-item label','padding-right','10','','','.w-checkout-billing-address'),(898248,'furniture','.w-promo-code .holder','padding-right','20','5161','','.w-promo-code'),(898249,'furniture','.w-product-images-additional .images','padding-right','0','5161','','.w-product-images-additional'),(898250,'furniture','.w-categories h2.name','padding-right','3','','','.w-categories'),(898251,'furniture','.w-tabs .accordion-heading','padding-right','6','','','.w-tabs'),(898252,'furniture','.w-socials > li','padding-right','15','','','.w-socials'),(898253,'furniture','.w-product-images-additional .images','padding-right','0','5161','','.w-product-images-additional'),(898254,'furniture','.w-promo-code .holder','padding-right','20','5161','','.w-promo-code'),(898255,'furniture','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(898256,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','padding-right','5','','','.b-switch'),(898257,'furniture','.p-quick-order-index .all-scroll-div','padding-right','0','','','.p-quick-order-index'),(898258,'furniture','.w-cart-compare .price-cell','padding-right','20','','','.w-cart-compare'),(898259,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(898260,'furniture','.w-checkout-shipping-address .edit-ab','padding-right','0','','','.w-checkout-shipping-address'),(898261,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(898262,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-right','5','','','.b-select-suggest'),(898263,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-right','0','','','.b-select-suggest'),(898264,'furniture','.b-select-suggest .select2-locked','padding-right','5','','','.b-select-suggest'),(898265,'furniture','.b-select-suggest .select2-container-multi .select2-choices','padding-right','0','','','.b-select-suggest'),(898266,'furniture','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','','','.w-menu-horizontal'),(898267,'furniture','.b-form .shipping-method .item + .item','padding-right','0','','','.b-form'),(898268,'furniture','.w-checkout-shipping-address .addresses .address-item label','padding-right','10','','','.w-checkout-shipping-address'),(898269,'furniture','.b-select-suggest .select2-search','padding-right','4','','','.b-select-suggest'),(898270,'furniture','.b-select-suggest .select2-search input','padding-right','20','','','.b-select-suggest'),(898271,'furniture','.b-select-suggest .select2-results','padding-right','4','','','.b-select-suggest'),(898275,'furniture','.b-compare .compare-box-item','padding-right','10','','','.b-compare'),(898276,'furniture','.w-cart-compare .product-label','padding-right','10','','','.w-cart-compare'),(898277,'furniture','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(898278,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(898279,'furniture','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(898280,'furniture','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(898281,'furniture','.w-cart-compare .dropdown li','padding-right','10','','','.w-cart-compare'),(898282,'furniture','.w-personal-gift-status-bar .end-date','padding-right','5','3','','.w-personal-gift-status-bar'),(898284,'furniture','.w-login-block .returning','padding-right','40','','','.w-login-block'),(898285,'furniture','.w-menu-big ul','padding-right','0','','','.w-menu-big'),(898286,'furniture','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(898287,'furniture','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(898288,'furniture','.b-bottom .notify-form','padding-right','20','','','.b-bottom'),(898289,'furniture','.w-account-addresses-list .addsess-suggestion-item','padding-right','20','','','.w-account-addresses-list'),(898290,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.b-data-table'),(898291,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.b-data-table'),(898292,'furniture','.w-communication-post .communication-post-author','padding-right','0','','','.w-communication-post'),(898293,'furniture','.b-products-listing .products-listing a.btn.view-button','padding-right','0','','','.b-products-listing'),(898294,'furniture','.b-products-listing .in-cart','padding-right','10','','','.b-products-listing'),(898295,'furniture','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-right','5','','','.w-catalog-b2b-add-button'),(898296,'furniture','.b-products-listing .promos-info .promo-name','padding-right','15','','','.b-products-listing'),(898297,'furniture','.b-products-listing .promos-info .promo-item','padding-right','10','','','.b-products-listing'),(898298,'furniture','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(898304,'furniture','.b-compare .col-two label','padding-right','0','','','.b-compare'),(898305,'furniture','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(898306,'furniture','.w-checkout-gdpr .privacy-row','padding-right','0','','','.w-checkout-gdpr'),(898307,'furniture','.w-checkout-gdpr .terms-login','padding-right','0','','','.w-checkout-gdpr'),(898308,'furniture','.b-table .table td','padding-right','15','','','.b-table'),(898309,'furniture','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(898310,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(898311,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(898312,'furniture','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(898314,'furniture','.w-checkout-billing-address .same-address','padding-right','10','','','.w-checkout-billing-address'),(898315,'furniture','.w-reviews .heading-3','padding-right','0','','','.w-reviews'),(898316,'furniture','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(898317,'furniture','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(898318,'furniture','.w-personal-gift-status-bar .timeline','padding-right','10','','','.w-personal-gift-status-bar'),(898319,'furniture','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(898320,'furniture','.w-catalog-sorting .before','padding-right','5','','','.w-catalog-sorting'),(898321,'furniture','.w-chat .w-chat-box','padding-right','12','','','.w-chat'),(898322,'furniture','.b-compare .compare-head','padding-right','10','','','.b-compare'),(898323,'furniture','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(898324,'furniture','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(898325,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-right','0','','',''),(898326,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-right','0','','','.b-h-inline'),(898327,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-right','0','','','.w-communication-new-topic'),(898328,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-right','10','','','.w-communication-new-topic'),(898329,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-right','5','','','.w-communication-new-topic'),(898330,'furniture','.w-communication-new-topic #communication_topic_form .middle-form','padding-right','0','','','.w-communication-new-topic'),(898331,'furniture','.b-email .totals-title','padding-right','10','','','.b-email'),(898332,'furniture','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(898333,'furniture','.b-email .heading-qty','padding-right','10','','','.b-email'),(898334,'furniture','.b-email .model','padding-right','10','','','.b-email'),(898335,'furniture','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-right','6','','','.b-compare'),(898336,'furniture','.btn-2','padding-right','25','','',''),(898337,'furniture','.b-compare .compare_pagination','padding-right','0','','','.b-compare'),(898338,'furniture','.w-product-images-additional .images','padding-right','0','5161','','.w-product-images-additional'),(898339,'furniture','.b-bottom .header-info','padding-right','20','','','.b-bottom'),(898340,'furniture','.w-cart-checkout-btn a','padding-right','12','5131','','.w-cart-checkout-btn'),(898341,'furniture','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(898342,'furniture','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-right','10','','','.order-summary'),(898345,'furniture','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(898346,'furniture','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(898347,'furniture','.b-table .table td','padding-right','15','','','.b-table'),(898348,'furniture','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-right','0','','','.b-fancybox'),(898349,'furniture','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(898350,'furniture','.products-quick-index .token-input-list','padding-right','0','','',''),(898351,'furniture','.w-cart-compare .cart-cell','padding-right','7','','','.w-cart-compare'),(898352,'furniture','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(898353,'furniture','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(898354,'furniture','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(898355,'furniture','.b-form .shipping-method .item','padding-right','0','','','.b-form'),(898356,'furniture','.b-email .price','padding-right','10','','','.b-email'),(898357,'furniture','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(898358,'furniture','.b-email .heading-image','padding-right','10','','','.b-email'),(898359,'furniture','.w-cart-listing .item .attributes strong','padding-right','10','','','.w-cart-listing'),(898360,'furniture','.w-cart-listing .item .gift-wrap label','padding-right','10','','','.w-cart-listing'),(898361,'furniture','.w-cart-listing .item > div','padding-right','10','','','.w-cart-listing'),(898362,'furniture','.w-cart-listing .points-earn','padding-right','0','','','.w-cart-listing'),(898363,'furniture','.w-cart-listing .points-redeem','padding-right','0','','','.w-cart-listing'),(898364,'furniture','.w-cart-give-away .ga_img','padding-right','1','','','.w-cart-give-away'),(898365,'furniture','.b-bottom .header-error','padding-right','20','','','.b-bottom'),(898366,'furniture','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(898373,'furniture','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(898374,'furniture','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(898375,'furniture','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(898376,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(898377,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(898378,'furniture','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(898379,'furniture','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(898380,'furniture','.b-compare .col-gender','padding-right','0','','','.b-compare'),(898381,'furniture','.b-email .qty','padding-right','10','','','.b-email'),(898382,'furniture','.b-email .heading-price','padding-right','10','','','.b-email'),(898383,'furniture','.w-top-categories .item','padding-right','10','5131','','.w-top-categories'),(898384,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(898385,'furniture','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(898388,'furniture','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(898389,'furniture','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(898390,'furniture','.w-socials > li','padding-right','15','','','.w-socials'),(898391,'furniture','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(898392,'furniture','.w-login-block .returning','padding-right','40','','','.w-login-block'),(898394,'furniture','.w-filters .fsl_handle','padding-right','0','','','.w-filters'),(898395,'furniture','.w-filters .head-filter-widget','padding-right','10','5140','','.w-filters'),(898396,'furniture','.w-filters .ui-slider-range','padding-right','0','','','.w-filters'),(898397,'furniture','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(898398,'furniture','.w-filters .head-filter-widget','padding-right','0','','','.w-filters'),(898399,'furniture','.w-filters .handle_tit','padding-right','5','','','.w-filters'),(898400,'furniture','.b-autocomplete .ui-autocomplete','padding-right','2','','','.b-autocomplete'),(898401,'furniture','.order-summary .heading-2','padding-right','25','','','.order-summary'),(898402,'furniture','.b-compare .column_wrapper','padding-right','10','','','.b-compare'),(898403,'furniture','.b-email .totals-value','padding-right','10','','','.b-email'),(898404,'furniture','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(898405,'furniture','.b-email .model','padding-right','10','','','.b-email'),(898406,'furniture','.b-email .heading-name','padding-right','10','','','.b-email'),(898407,'furniture','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(898408,'furniture','.w-reviews-content .author','padding-right','20','','','.w-reviews-content'),(898409,'furniture','.w-login-block .returning','padding-right','40','','','.w-login-block'),(898410,'furniture','.b-data-table table.dataTable tbody td','padding-right','20','','','.b-data-table'),(898411,'furniture','.b-data-table table.dataTable thead td','padding-right','20','','','.b-data-table'),(898412,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(898413,'furniture','.b-table .table .headings td','padding-right','10','','','.b-table'),(898416,'furniture','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(898417,'furniture','.w-checkout-create-account .create-account','padding-right','0','','','.w-checkout-create-account'),(898418,'furniture','.b-email .totals-title','padding-right','10','','','.b-email'),(898419,'furniture','.b-email .totals-value','padding-right','10','','','.b-email'),(898420,'furniture','.b-email .qty','padding-right','10','','','.b-email'),(898421,'furniture','.btn','padding-right','25','','',''),(898422,'furniture','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(898423,'furniture','.b-product-images .media-popup .mp-content','padding-right','5','','','.b-product-images'),(898424,'furniture','.b-product-images .media-popup .mp-small-images .item','padding-right','10','','','.b-product-images'),(898425,'furniture','.b-product-images .media-popup .slick-dots','padding-right','0','','','.b-product-images'),(898426,'furniture','.b-product-images .media-popup .slick-dots li','padding-right','0','','','.b-product-images'),(898427,'furniture','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-right','0','','','.b-menu-style'),(898428,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-right','20','','','.b-menu-style-2'),(898429,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-right','20','','','.b-menu-style-2'),(898430,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-right','0','','','.b-menu-style-2'),(898431,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-right','0','','','.b-menu-style-2'),(898432,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-right','20','','','.b-menu-style-2'),(898433,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-right','0','','','.b-menu-style-2'),(898434,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-right','20','','','.b-menu-style-2'),(898435,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-right','20','','','.b-menu-style-2'),(898436,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-right','50','','','.b-menu-style-2'),(898437,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-right','30','','','.b-menu-style-2'),(898438,'furniture','.b-personal-catalog-popup #personal_catalog_popup','padding-right','0','','','.b-personal-catalog-popup'),(898439,'furniture','.b-trade-approval .steps-bar li a','padding-right','0','','','.b-trade-approval'),(898440,'furniture','.b-trade-approval .middle-form','padding-right','0','','','.b-trade-approval'),(898441,'furniture','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-right','5','','','.b-trade-approval'),(898442,'furniture','.b-trade-approval .steps-bar','padding-right','0','','','.b-trade-approval'),(898443,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-right','10','','','.b-trade-approval'),(898444,'furniture','.b-trade-approval .center-buttons','padding-right','0','','','.b-trade-approval'),(898445,'furniture','.w-account-personal-catalog .list-switcher','padding-right','0','','','.w-account-personal-catalog'),(898446,'furniture','.w-account-personal-catalog .list-switcher a','padding-right','6','','','.w-account-personal-catalog'),(898447,'furniture','.w-account-subscription .subscription-variant','padding-right','10','','','.w-account-subscription'),(898448,'furniture','.w-catalog-additional-images li','padding-right','10','','','.w-catalog-additional-images'),(898449,'furniture','.w-catalog-additional-images ul','padding-right','0','','','.w-catalog-additional-images'),(898450,'furniture','.w-catalog-compare td','padding-right','20','','','.w-catalog-compare'),(898451,'furniture','.w-catalog-compare .image','padding-right','10','','','.w-catalog-compare'),(898452,'furniture','.w-catalog-compare .cross-box .different-all > div','padding-right','5','2','','.w-catalog-compare'),(898453,'furniture','.w-catalog-compare .cross-box .different-all > div','padding-right','5','','','.w-catalog-compare'),(898454,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-right','0','','','.w-catalog-compare'),(898455,'furniture','.w-delivery-day .left-count','padding-right','5','','','.w-delivery-day'),(898456,'furniture','.w-top-text .top-text','padding-right','10','','','.w-top-text'),(898457,'furniture','.w-product-images .additional-horizontal .item','padding-right','10','','','.w-product-images'),(898458,'furniture','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-right','10','','','.b-cookie-notice'),(898462,'furniture','.b-slick .slick-list','padding-right','0','','','.b-slick'),(898463,'furniture','.b-slick .slick-vertical button.slick-next','padding-right','0','3','','.b-slick'),(898464,'furniture','.b-slick .slick-vertical button.slick-prev','padding-right','0','3','','.b-slick'),(898465,'furniture','.b-slick button.slick-prev','padding-right','4','3','','.b-slick'),(898466,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','padding-right','0','','','.b-slick'),(898467,'furniture','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-right','15','','',''),(898468,'furniture','.cartTitle span','padding-right','30','','','.cartTitle'),(898469,'furniture','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','padding-right','0','','','.b-products-listing'),(898470,'furniture','.w-cart-listing .headings .head','padding-right','0','','','.w-cart-listing'),(898471,'furniture','.w-cart-listing .item div.price','padding-right','0','','','.w-cart-listing'),(898472,'furniture','.b-products-listing .item-nav > div','padding-right','15','','','.b-products-listing'),(898473,'furniture','.LeftCategories .w-menu-simple ul','padding-right','0','','','.LeftCategories'),(898474,'furniture','.LeftCategories .w-menu-simple ul li a','padding-right','25','','','.LeftCategories'),(898475,'furniture','.w-filters .filter-widget','padding-right','25','','','.w-filters'),(898476,'furniture','.b-products-listing .products-listing.list-productlisting .item','padding-right','15','','','.b-products-listing'),(898477,'furniture','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-right','0','','','.b-products-listing'),(898478,'furniture','.b-products-listing .products-listing.list-productlisting .item-content','padding-right','25','','','.b-products-listing'),(898479,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','padding-right','30','','','.b-products-listing'),(898480,'furniture','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-right','25','','','.b-products-listing'),(898481,'furniture','.b-products-listing .products-listing.list-rows .item-nav > div','padding-right','5','','','.b-products-listing'),(898482,'furniture','.w-breadcrumb .breadcrumb-li','padding-right','0','','','.w-breadcrumb'),(898483,'furniture','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(898484,'furniture','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(898485,'furniture','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(898486,'furniture','.w-subscribers .btn-submit','padding-right','25','','','.w-subscribers'),(898487,'furniture','.w-quote .buttons','padding-right','15','','','.w-quote'),(898488,'furniture','.w-quote .buttons .btn','padding-right','15','','','.w-quote'),(898489,'furniture','.w-quote .cart-content','padding-right','15','','','.w-quote'),(898490,'furniture','.w-quote .cart-total','padding-right','0','','','.w-quote'),(898491,'furniture','.w-quote .multicart .cart-content','padding-right','0','','','.w-quote'),(898492,'furniture','.w-quote .multicart .item','padding-right','15','','','.w-quote'),(898493,'furniture','.w-quote .multicart .name','padding-right','10','','','.w-quote'),(898494,'furniture','.w-quote .no-text','padding-right','20','','','.w-quote'),(898495,'furniture','.w-quote .qty','padding-right','5','4','','.w-quote'),(898496,'furniture','.w-quote a.item','padding-right','0','','','.w-quote'),(898497,'furniture','.w-social-links a','padding-right','8','','','.w-social-links'),(898498,'furniture','.w-product-images .additional-vertical .additional-images','padding-right','0','','','.w-product-images'),(898499,'furniture','.w-product-personal-catalog-button .btn','padding-right','0','','','.w-product-personal-catalog-button'),(898500,'furniture','.b-quantity .qty-box input','padding-right','3','','','.b-quantity'),(898501,'furniture','.w-product-sale-ends .left-count','padding-right','5','','','.w-product-sale-ends'),(898502,'furniture','.w-product-sale-ends .left-count-days','padding-right','0','','','.w-product-sale-ends'),(898503,'furniture','.w-product-sale-ends .left-count-hours','padding-right','0','','','.w-product-sale-ends'),(898504,'furniture','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(898505,'furniture','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(898506,'furniture','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(898507,'furniture','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(898508,'furniture','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(898509,'furniture','.w-compare .compare-list-holder','padding-right','250','','','.w-compare'),(898510,'furniture','.w-compare .compare-list-buttons','padding-right','10','','','.w-compare'),(898511,'furniture','.w-compare .item-holder','padding-right','10','','','.w-compare'),(898512,'furniture','.w-compare .compare-list-products','padding-right','30','','','.w-compare'),(898513,'furniture','.w-files-catalog-widgets-files-catalog .name','padding-right','10','','','.w-files-catalog-widgets-files-catalog'),(898514,'furniture','.w-sample .buttons','padding-right','15','','','.w-sample'),(898515,'furniture','.w-sample .buttons .btn','padding-right','15','','','.w-sample'),(898516,'furniture','.w-sample .cart-box-link','padding-right','10','','','.w-sample'),(898517,'furniture','.w-sample .cart-content','padding-right','15','','','.w-sample'),(898518,'furniture','.w-sample .cart-total','padding-right','0','','','.w-sample'),(898519,'furniture','.w-sample .multicart .cart-content','padding-right','0','','','.w-sample'),(898520,'furniture','.w-sample .multicart .item','padding-right','15','','','.w-sample'),(898521,'furniture','.w-sample .multicart .name','padding-right','10','','','.w-sample'),(898522,'furniture','.w-sample .no-text','padding-right','20','','','.w-sample'),(898523,'furniture','.w-sample .qty','padding-right','5','4','','.w-sample'),(898524,'furniture','.w-sample a.item','padding-right','0','','','.w-sample'),(898525,'furniture','.w-cart-listing .item > div.points','padding-right','0','','','.w-cart-listing'),(898526,'furniture','.w-filters-simple .integrate-price-holder','padding-right','0','','','.w-filters-simple'),(898527,'furniture','.w-product-video .item','padding-right','10','','','.w-product-video'),(898528,'furniture','.shipping-ico .heading-3','padding-right','0','','','.shipping-ico'),(898529,'furniture','.w-cart-order-reference .btn','padding-right','25','','','.w-cart-order-reference'),(898530,'furniture','.w-cart-gift-certificate .btn','padding-right','25','','','.w-cart-gift-certificate'),(898531,'furniture','.w-cart-shipping-estimator .btn','padding-right','25','','','.w-cart-shipping-estimator'),(898532,'furniture','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(898533,'furniture','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(898534,'furniture','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(898535,'furniture','.w-product-in-bundles .attributes-item','padding-right','2','','','.w-product-in-bundles'),(898536,'furniture','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(898537,'furniture','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(898538,'furniture','.w-cart-listing .item > div.actions','padding-right','0','5131','','.w-cart-listing'),(898539,'furniture','.w-cart-listing .item div.price','padding-right','10','5140','','.w-cart-listing'),(898541,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-right','0','','','.b-products-listing'),(898542,'furniture','.b-pagination .pagination .next-pages','padding-right','5','','','.b-pagination'),(898543,'furniture','.b-pagination .pagination .page-number','padding-right','5','','','.b-pagination'),(898544,'furniture','.b-pagination .pagination .prev-pages','padding-right','5','','','.b-pagination'),(898545,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','padding-right','5','','','.b-pagination'),(898546,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','padding-right','5','','','.b-pagination'),(898547,'furniture','.b-pagination .pagination span','padding-right','5','2','','.b-pagination'),(898548,'furniture','.b-pagination ul.pagination','padding-right','0','','','.b-pagination'),(898549,'furniture','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','padding-right','10','','','.w-catalog-compare'),(898550,'furniture','.w-product-properties-filters-widgets-chosen-filters .item','padding-right','6','','','.w-product-properties-filters-widgets-chosen-filters'),(898551,'furniture','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block, .checkout > .type-1 > .block','padding-right','15','','',''),(898552,'furniture','.w-tabs .tab-li','padding-right','0','2','','.w-tabs'),(898553,'furniture','.w-tabs .tab-li:last-of-type','padding-right','0','','','.w-tabs'),(898554,'furniture','.w-cart-listing .no-price .headings .qty','padding-right','10','','','.w-cart-listing'),(898555,'furniture','.p-quote-checkout-index .datepicker-inline','padding-right','0','','','.p-quote-checkout-index'),(898556,'furniture','.p-sample-checkout-index .datepicker-inline','padding-right','0','','','.p-sample-checkout-index'),(898559,'furniture','.w-quote-products .cart-listing .qty','padding-right','10','','','.w-quote-products'),(898560,'furniture','.w-product-multi-inventory .radio-attributes .option-item','padding-right','15','','','.w-product-multi-inventory'),(898561,'furniture','.w-product-multi-inventory .radio-attributes > label','padding-right','10','','','.w-product-multi-inventory'),(898562,'furniture','.w-account-personal-catalog .list-row-action ul','padding-right','20','','','.w-account-personal-catalog'),(898563,'furniture','.w-account-personal-catalog .list-row-action li','padding-right','10','','','.w-account-personal-catalog'),(898564,'furniture','.w-account-personal-catalog .price','padding-right','10','','','.w-account-personal-catalog'),(898565,'furniture','.w-account-personal-catalog .buy-box','padding-right','0','5131','','.w-account-personal-catalog'),(898566,'furniture','.b-products-listing .products-listing .radio-attributes .option','padding-right','15','','','.b-products-listing'),(898567,'furniture','.b-products-listing .products-listing .radio-attributes > label','padding-right','10','','','.b-products-listing'),(898568,'furniture','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(898569,'furniture','.w-product-collection .right-area .btn','padding-right','25','','','.w-product-collection'),(898570,'furniture','.w-product-attributes .radio-attributes .option-item','padding-right','15','','','.w-product-attributes'),(898571,'furniture','.w-product-attributes .radio-attributes > label','padding-right','10','','','.w-product-attributes'),(898572,'furniture','.w-product-properties .property-ul','padding-right','0','','','.w-product-properties'),(898573,'furniture','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(898574,'furniture','.w-product-properties li','padding-right','5','','','.w-product-properties'),(898575,'furniture','.w-product-groups .radioBox','padding-right','0','','','.w-product-groups'),(898576,'furniture','.w-product-groups .radioBox label','padding-right','15','','','.w-product-groups'),(898577,'furniture','.w-product-groups .radioBox label .containerBlock','padding-right','10','','','.w-product-groups'),(898578,'furniture','.w-product-groups .radioBox label','padding-right','0','5161','','.w-product-groups'),(898579,'furniture','.w-product-groups .radioBox label .containerBlock','padding-right','10','5161','','.w-product-groups'),(898580,'furniture','.b-products-listing .mix-attributes .attribute-qty-block','padding-right','10','','','.b-products-listing'),(898581,'furniture','.b-products-listing .products-listing .attribute-qty-block','padding-right','5','','','.b-products-listing'),(898582,'furniture','.blogsidebar','padding-right','0','5140','',''),(898583,'furniture','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(898584,'furniture','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-right','25','','','.w-product-custom-bundle'),(898585,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list'),(898586,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-right','10','','','.w-catalog-pages-category-pages-last-list'),(898587,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list-block'),(898588,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-right','10','','','.w-catalog-pages-category-pages-last-list-block'),(898589,'furniture','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(898590,'furniture','.w-delivery-location-location-description .deliveryDesc','padding-right','0','','','.w-delivery-location-location-description'),(898591,'furniture','.w-delivery-location-location-list .deliveryListParrent a','padding-right','25','','','.w-delivery-location-location-list'),(898592,'furniture','.w-delivery-location-location-list .deliveryList li a','padding-right','15','','','.w-delivery-location-location-list'),(898593,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding-right','2','','','.w-delivery-location-featured-list'),(898594,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding-right','0','5161','','.w-delivery-location-featured-list'),(898595,'furniture','.btn-2','padding-right','25','5131','',''),(898596,'furniture','.w-sale-category .holder-1','padding-right','20','','','.w-sale-category'),(898597,'furniture','.w-sale-category .holder-2','padding-right','20','','','.w-sale-category'),(898598,'furniture','.w-sale-category .left-count','padding-right','5','','','.w-sale-category'),(898599,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(898600,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-right','10','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(898601,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(898602,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-right','10','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(898603,'furniture','.w-product-properties-icons .property-image','padding-right','10','','','.w-product-properties-icons'),(898604,'furniture','.w-product-properties-icons .hover-box-content','padding-right','10','','','.w-product-properties-icons'),(898605,'furniture','.w-delivery-location-product-categories .item.category-link','padding-right','15','','','.w-delivery-location-product-categories'),(898606,'furniture','.w-delivery-location-product-categories .item.category-link','padding-right','10','5140','','.w-delivery-location-product-categories'),(898607,'furniture','.w-delivery-location-product-categories .item.category-link','padding-right','0','5161','','.w-delivery-location-product-categories'),(898608,'furniture','.w-delivery-location-product-categories .name','padding-right','15','','','.w-delivery-location-product-categories'),(898609,'furniture','.delivery-options-popup','padding-right','20','','',''),(898610,'furniture','.w-product-bonus-points .bonus-points-cost','padding-right','15','','','.w-product-bonus-points'),(898611,'furniture','.w-product-designer-designer .grnamebox .title-sortable','padding-right','15','','','.w-product-designer-designer'),(898612,'furniture','.w-product-designer-designer .prodDesignerType label','padding-right','10','','','.w-product-designer-designer'),(898613,'furniture','.w-press-reviews-widgets-press-reviews ','padding-right','30','','','.w-press-reviews-widgets-press-reviews'),(898614,'furniture','.w-press-reviews-widgets-press-reviews .author','padding-right','25','','','.w-press-reviews-widgets-press-reviews'),(898615,'furniture','.w-press-reviews-widgets-press-reviews .image','padding-right','10','','','.w-press-reviews-widgets-press-reviews'),(898616,'furniture','.w-press-reviews-widgets-press-reviews .item','padding-right','20','','','.w-press-reviews-widgets-press-reviews'),(898617,'furniture','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-right','30','','','.w-press-reviews-widgets-press-reviews'),(898618,'furniture','.w-press-reviews-widgets-press-reviews .review','padding-right','25','','','.w-press-reviews-widgets-press-reviews'),(898619,'furniture','.w-press-reviews-widgets-press-reviews ','padding-right','15','5131','','.w-press-reviews-widgets-press-reviews'),(898620,'furniture','.w-press-reviews-widgets-press-reviews .item','padding-right','0','5131','','.w-press-reviews-widgets-press-reviews'),(898621,'furniture','.w-press-reviews-widgets-press-reviews .review','padding-right','0','5131','','.w-press-reviews-widgets-press-reviews'),(898622,'furniture','.w-press-reviews-widgets-press-reviews-list .item','padding-right','25','','','.w-press-reviews-widgets-press-reviews-list'),(898623,'furniture','.w-press-reviews-widgets-press-reviews-list .short-description','padding-right','0','','','.w-press-reviews-widgets-press-reviews-list'),(898624,'furniture','.b-products-listing .productGroup label a','padding-right','16','','','.b-products-listing'),(898625,'furniture','.w-support-system-filter ','padding-right','40','','','.w-support-system-filter'),(898626,'furniture','.w-support-system-filter .filter_cats','padding-right','0','','','.w-support-system-filter'),(898627,'furniture','.w-support-system-listing .support-head','padding-right','13','','','.w-support-system-listing'),(898628,'furniture','.w-communication-post .btn.refresh','padding-right','0','','','.w-communication-post'),(898629,'furniture','.w-rma-returns-history .btn','padding-right','10','','','.w-rma-returns-history'),(898630,'furniture','.w-rma-returns-history .column','padding-right','3','','','.w-rma-returns-history'),(898631,'furniture','.w-rma-returns-history .column .title','padding-right','10','','','.w-rma-returns-history'),(898632,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','padding-right','5','','','.w-rma-returns-history'),(898633,'furniture','.w-rma-returns-history .topRow','padding-right','0','','','.w-rma-returns-history'),(898634,'furniture','.w-rma-returns-history .column:last-child .title','padding-right','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(898635,'furniture','.w-product-designer-designer .productDesignerBox ul','padding-right','0','','','.w-product-designer-designer'),(898636,'furniture','.w-product-configurator .pc-item','padding-right','0','','','.w-product-configurator'),(898637,'furniture','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(898638,'furniture','.w-product-configurator .pc_item','padding-right','0','5140','','.w-product-configurator'),(898639,'furniture','.w-product-configurator .pc_attr','padding-right','0','5131','','.w-product-configurator'),(898640,'furniture','.b-products-listing .products-listing .bonus-points-cost','padding-right','15','','','.b-products-listing'),(898641,'furniture','.b-products-listing .promos-info .promo-name-span','padding-right','40','','','.b-products-listing'),(898642,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-list'),(898643,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-right','10','','','.w-catalog-pages-category-pages-list'),(898644,'furniture','.w-predefined-promotion .heading','padding-right','10','','','.w-predefined-promotion'),(898645,'furniture','.w-predefined-promotion .master','padding-right','15','','','.w-predefined-promotion'),(898646,'furniture','.w-predefined-promotion .nextdiscount .content > div','padding-right','10','','','.w-predefined-promotion'),(898647,'furniture','.w-predefined-promotion .nextdiscount .item-holder .image','padding-right','10','','','.w-predefined-promotion'),(898648,'furniture','.w-predefined-promotion .nextdiscount .promo-for-each','padding-right','20','','','.w-predefined-promotion'),(898649,'furniture','.w-predefined-promotion .prom-multi-discount .promo-product','padding-right','20','','','.w-predefined-promotion'),(898650,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','padding-right','20','','','.w-predefined-promotion'),(898651,'furniture','.w-predefined-promotion .promo-cart-discount .master .item','padding-right','20','','','.w-predefined-promotion'),(898652,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-right','20','','','.w-predefined-promotion'),(898653,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-right','20','','','.w-predefined-promotion'),(898654,'furniture','.w-predefined-promotion .promo-cart-discount .slave .item','padding-right','20','','','.w-predefined-promotion'),(898655,'furniture','.w-predefined-promotion .promo-date > div','padding-right','50','','','.w-predefined-promotion'),(898656,'furniture','.w-predefined-promotion .promo-item','padding-right','40','','','.w-predefined-promotion'),(898657,'furniture','.w-predefined-promotion .promo-salemaker .discount','padding-right','20','','','.w-predefined-promotion'),(898658,'furniture','.w-predefined-promotion .promo-salemaker .item','padding-right','20','','','.w-predefined-promotion'),(898659,'furniture','.w-predefined-promotion .promo-salemaker .promo-categories','padding-right','12','','','.w-predefined-promotion'),(898660,'furniture','.w-supplier-purchase-supplier-products .item','padding-right','20','','','.w-supplier-purchase-supplier-products'),(898661,'furniture','.w-filters .filter-box-content ul','padding-right','0','','','.w-filters'),(898662,'furniture','.mainBanner .bottomBox','padding-right','20','','','.mainBanner'),(898663,'furniture','.mainBanner .bottomBox .btn','padding-right','1.30','','','.mainBanner'),(898664,'furniture','.mainBanner .buttonBox','padding-right','10','','','.mainBanner'),(898665,'furniture','.mainBanner .topBox > .right','padding-right','47','','','.mainBanner'),(898666,'furniture','.mainBanner .wrapper','padding-right','6','','','.mainBanner'),(898667,'furniture','.mainBanner > .block','padding-right','0','','','.mainBanner'),(898668,'furniture','.mainBanner .bottomBox','padding-right','20','5145','','.mainBanner'),(898669,'furniture','.mainBanner .bottomBox .btn','padding-right','20','5145','','.mainBanner'),(898670,'furniture','.mainBanner .topBox','padding-right','15','5145','','.mainBanner'),(898671,'furniture','.mainBanner .topBox > .right','padding-right','20','5145','','.mainBanner'),(898672,'furniture','.mainBanner .wrapper','padding-right','2','5145','','.mainBanner'),(898673,'furniture','.mainBanner .bottomBox .btn','padding-right','20','5140','','.mainBanner'),(898674,'furniture','.mainBanner .topBox','padding-right','10','5131','','.mainBanner'),(898675,'furniture','.mainBanner .topBox > .right','padding-right','15','5131','','.mainBanner'),(898676,'furniture','.mainBanner .wrapper','padding-right','2','5131','','.mainBanner'),(898677,'furniture','.mainBanner .bottomBox','padding-right','20','5161','','.mainBanner'),(898678,'furniture','.mainBanner .bottomBox .btn','padding-right','15','5161','','.mainBanner'),(898679,'furniture','.mainBanner .wrapper','padding-right','2','5161','','.mainBanner'),(898680,'furniture','.mainBanner .bottomBox .btn','padding-right','20','5206','','.mainBanner'),(898681,'furniture','.order-summary .w-cart-listing .item > div ~ div','padding-right','0','','','.order-summary'),(898682,'furniture','.order-summary .heading-2','padding-right','10','5145','','.order-summary'),(898683,'furniture','.w-cart-discount-coupon .discount-box','padding-right','10','','','.w-cart-discount-coupon'),(898684,'furniture','.w-cart-listing .promos-info .promo-name','padding-right','15','','','.w-cart-listing'),(898685,'furniture','.w-cart-listing .item .image','padding-right','10','5140','','.w-cart-listing'),(898686,'furniture','.w-cart-listing .item .name','padding-right','10','5140','','.w-cart-listing'),(898687,'furniture','.w-cart-listing .item .points','padding-right','0','5131','','.w-cart-listing'),(898688,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','padding-right','0','','','.w-promotions-widgets-promotion-icons-desc'),(898689,'furniture','.w-product-promotion-icons .promos-info .promo-name','padding-right','15','','','.w-product-promotion-icons'),(898690,'furniture','.w-quote-products .no-price','padding-right','15','','','.w-quote-products'),(898691,'furniture','.w-product-quantity-discounts .item','padding-right','20','','','.w-product-quantity-discounts'),(898697,'furniture','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','padding-right','20','','','.b-product-images'),(898698,'furniture','.b-product-images .media-popup .mp-small-images img','padding-right','10','','','.b-product-images'),(898717,'furniture','.account-address-book .address_book','padding-right','0','','','.account-address-book'),(898718,'furniture','.account-address-book .address_book h1','padding-right','0','','','.account-address-book'),(898719,'furniture','.account-address-book .address_book h2','padding-right','10','','','.account-address-book'),(898720,'furniture','.account-address-book .address_book, .account-address-book .account_history_info','padding-right','0','','','.account-address-book'),(898721,'furniture','.account-address-book .buttonBox','padding-right','0','','','.account-address-book'),(898722,'furniture','.account-address-book .rightMes ul','padding-right','0','','','.account-address-book'),(898723,'furniture','.account-address-book .topButtons','padding-right','0','','','.account-address-book'),(898737,'furniture','.account-order-pay .contentColumn','padding-right','10','','','.account-order-pay'),(898738,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-right','0','','','.account-order-pay'),(898739,'furniture','.account-order-pay .history_attr div strong, .account-order-pay .history_attr div span','padding-right','10','','','.account-order-pay'),(898740,'furniture','.account-order-pay .history_info > div + div','padding-right','0','','','.account-order-pay'),(898741,'furniture','.account-order-pay .history_info > div','padding-right','0','5140','','.account-order-pay'),(898742,'furniture','.account-order-pay .history_info > div + div','padding-right','0','5140','','.account-order-pay'),(898743,'furniture','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-right','10','','','.account-samples'),(898744,'furniture','.account-samples .orders-table th','padding-right','10','','','.account-samples'),(898745,'furniture','.account-samples .order_history_table th','padding-right','10','','','.account-samples'),(898746,'furniture','.account-samples .view_link','padding-right','20','','','.account-samples'),(898747,'furniture','.account-samples .orders-table .td-alignright','padding-right','10','5140','','.account-samples'),(898748,'furniture','.account-samples .orders-table td','padding-right','10','5140','','.account-samples'),(898749,'furniture','.account-sample-info .contentColumn','padding-right','10','','','.account-sample-info'),(898750,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-right','0','','','.account-sample-info'),(898751,'furniture','.account-sample-info .history_attr div strong, .account-sample-info .history_attr div span','padding-right','10','','','.account-sample-info'),(898752,'furniture','.account-sample-info .history_info > div + div','padding-right','0','','','.account-sample-info'),(898753,'furniture','.account-sample-info .popup-tracking-number','padding-right','10','','','.account-sample-info'),(898754,'furniture','.account-sample-info .history_info > div','padding-right','0','5140','','.account-sample-info'),(898755,'furniture','.account-sample-info .history_info > div + div','padding-right','0','5140','','.account-sample-info'),(898756,'furniture','.catalog-product-wrap .next-product','padding-right','50','','','.catalog-product-wrap'),(898757,'furniture','.catalog-product-wrap .pn-direction','padding-right','4','','','.catalog-product-wrap'),(898758,'furniture','.catalog-product-wrap .pn-image','padding-right','5','','','.catalog-product-wrap'),(898759,'furniture','.catalog-product-wrap .prev-product','padding-right','20','','','.catalog-product-wrap'),(898760,'furniture','.catalog-product-wrap .prev-product .pn-image','padding-right','2','3','','.catalog-product-wrap'),(898761,'furniture','.catalog-product-wrap .next-product','padding-right','0','5140','','.catalog-product-wrap'),(898762,'furniture','.catalog-product-wrap .pn-direction','padding-right','0','5140','','.catalog-product-wrap'),(898763,'furniture','.catalog-product-wrap .prev-product','padding-right','0','5140','','.catalog-product-wrap'),(898764,'furniture','.checkout-index-wrap .closeable-heading','padding-right','25','','','.checkout-index-wrap'),(898765,'furniture','.checkout-index-wrap .datepicker-inline','padding-right','0','','','.checkout-index-wrap'),(898766,'furniture','.checkout-index-wrap .edit-address-popup','padding-right','20','','','.checkout-index-wrap'),(898767,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-right','25','','','.checkout-index-wrap'),(898768,'furniture','.checkout-index-wrap .hiding-box .checkout-cart-listing','padding-right','30','','','.checkout-index-wrap'),(898769,'furniture','.checkout-order-confirmation .price-row','padding-right','0','','','.checkout-order-confirmation'),(898770,'furniture','.shopping-cart-index .btn-3','padding-right','25','','','.shopping-cart-index'),(898771,'furniture','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-right','20','','','.shopping-cart-index'),(898772,'furniture','.b-form .columns .col-2','padding-right','10','','','.b-form'),(898773,'furniture','.b-bottom .pop-up-content','padding-right','15','','','.b-bottom'),(898774,'furniture','.b-bottom .pop-up-content .buttons','padding-right','0','','','.b-bottom'),(898775,'furniture','.checkout-index-wrap .closeable-content','padding-right','20','','','.checkout-index-wrap'),(898776,'furniture','.b-form .middle-g','padding-right','0','','','.b-form'),(898777,'furniture','.b-info .info','padding-right','0','','','.b-info'),(898778,'furniture','.b-info .info li','padding-right','0','','','.b-info'),(898779,'furniture','.b-info .info ul','padding-right','0','','','.b-info'),(898780,'furniture','.b-multi-page-checkout .multi-page-checkout .buttons','padding-right','0','','','.b-multi-page-checkout'),(898781,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-right','10','','','.b-multi-page-checkout'),(898782,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-right','10','','','.b-multi-page-checkout'),(898783,'furniture','.b-form .col-left','padding-right','5','','','.b-form'),(898784,'furniture','.b-form .col-right','padding-right','5','','','.b-form'),(898785,'furniture','.success-page .check-ico-block','padding-right','0','','','.success-page'),(898786,'furniture','.success-page .order-summary2 .btn-2','padding-right','50','','','.success-page'),(898787,'furniture','.success-page .order_totals .price-row','padding-right','0','','','.success-page'),(898788,'furniture','.success-page .price-row','padding-right','0','','','.success-page'),(898789,'furniture','.success-page .w-cart-listing .price','padding-right','0','','','.success-page'),(898790,'furniture','.success-page .w-cart-listing .qty','padding-right','0','','','.success-page'),(898791,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','padding-right','0','','','.mainBanner'),(898792,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','padding-right','0','','','.mainBanner'),(898793,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','padding-right','0','','','.mainBanner'),(898794,'furniture','.b-form .addresses .address-item','padding-right','20','','','.b-form'),(898795,'furniture','.menu-header .menu-style[data-style=\"1\"] .goto-button','padding-right','20','','','.menu-header'),(898796,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > li > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-right','5','','','.menu-header'),(898797,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','padding-right','20','','','.menu-header'),(898798,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-right','0','5140','','.footer-menu'),(898799,'furniture','.lowestPricedBox .w-banner .banner-holder','padding-right','0','','','.lowestPricedBox'),(898800,'furniture','.lowestPricedBox .w-banner .banner-holder','padding-right','0','5131','','.lowestPricedBox'),(898801,'furniture','.lowestPricedBox .w-banner .banner-text','padding-right','0','','','.lowestPricedBox'),(898802,'furniture','.lowestPricedBox .w-banner .banner-text-holder','padding-right','24','','','.lowestPricedBox'),(898803,'furniture','.lowestPricedBox .w-banner .banner-text-holder','padding-right','10','5140','','.lowestPricedBox'),(898804,'furniture','.lowestPricedBox .w-banner .banner-text-holder','padding-right','10','5161','','.lowestPricedBox'),(898805,'furniture','.lowestPricedBox .w-banner .ybg .btn','padding-right','25','5140','','.lowestPricedBox'),(898806,'furniture','.lowestPricedBox .w-banner .ybg .btn','padding-right','20','5161','','.lowestPricedBox'),(898807,'furniture','.lowestPricedBox .w-banner .ybg .mark','padding-right','0','','','.lowestPricedBox'),(898808,'furniture','.tripleBanner .w-html_box','padding-right','10','','','.tripleBanner'),(898809,'furniture','.tripleBanner > .block','padding-right','15','','','.tripleBanner'),(898810,'furniture','.shopByCollectionBox .bannerButton a','padding-right','25','','','.shopByCollectionBox'),(898811,'furniture','.shopByCollectionBox .bannerButton a','padding-right','25','5145','','.shopByCollectionBox'),(898812,'furniture','.shopByCollectionBox .content','padding-right','20','','','.shopByCollectionBox'),(898813,'furniture','.shopByCollectionBox .w-banner .banner-text','padding-right','0','','','.shopByCollectionBox'),(898815,'furniture','.w-banner .banner-text','padding-right','20','','','.w-banner'),(898816,'furniture','.w-banner .carousel-text > span','padding-right','20','','','.w-banner'),(898817,'furniture','.w-catalog-paging ','padding-right','5','2','','.w-catalog-paging'),(898818,'furniture','.w-catalog-paging .next','padding-right','5','','','.w-catalog-paging'),(898819,'furniture','.w-catalog-paging .next-pages','padding-right','5','','','.w-catalog-paging'),(898820,'furniture','.w-catalog-paging .page-number','padding-right','5','','','.w-catalog-paging'),(898821,'furniture','.w-catalog-paging .paging-item','padding-right','2','','','.w-catalog-paging'),(898822,'furniture','.w-catalog-paging .prev','padding-right','5','','','.w-catalog-paging'),(898823,'furniture','.w-catalog-paging .prev-pages','padding-right','5','','','.w-catalog-paging'),(898824,'furniture','.b-data-table table.dataTable tbody td','padding-right_important','important','','','.b-data-table'),(898825,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right_important','important','','','.b-data-table'),(898826,'furniture','.b-data-table table.dataTable thead td','padding-right_important','important','','','.b-data-table'),(898827,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right_important','important','','','.b-data-table'),(898828,'furniture','.w-account-personal-catalog .price','padding-right_important','important','','','.w-account-personal-catalog'),(898829,'furniture','.w-account-personal-catalog .buy-box','padding-right_important','important','5131','','.w-account-personal-catalog'),(898830,'furniture','.mainBanner > .block','padding-right_important','important','','','.mainBanner'),(898831,'furniture','.w-cart-listing .item .points','padding-right_important','important','5131','','.w-cart-listing'),(898832,'furniture','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-top','10','','','.w-communication-new-topic'),(898833,'furniture','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(898834,'furniture','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(898835,'furniture','.heading-4 .edit, h4 .edit','padding-top','2','','',''),(898836,'furniture','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(898837,'furniture','.b-form .password-forgotten-link','padding-top','15','','','.b-form'),(898838,'furniture','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(898839,'furniture','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(898842,'furniture','.w-cart-discount-coupon .btn','padding-top','6','','','.w-cart-discount-coupon'),(898843,'furniture','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(898844,'furniture','.b-email .totals-title','padding-top','5','','','.b-email'),(898845,'furniture','.p-quick-order-index ul.token-input-list','padding-top','0','','','.p-quick-order-index'),(898846,'furniture','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-top','7','','','.p-quick-order-index'),(898847,'furniture','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-top','8','','','.p-quick-order-index'),(898848,'furniture','.w-promotions .promo-item','padding-top','30','','','.w-promotions'),(898849,'furniture','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(898850,'furniture','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(898851,'furniture','.w-cart-compare .attributes-label','padding-top','10','','','.w-cart-compare'),(898858,'furniture','.w-personal-gift-status-bar .end-label','padding-top','0','','','.w-personal-gift-status-bar'),(898859,'furniture','.p-sample-checkout-success .page-success .text-1','padding-top','120','','','.p-sample-checkout-success'),(898860,'furniture','.w-personal-gift-status-bar .start-label','padding-top','0','','','.w-personal-gift-status-bar'),(898861,'furniture','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(898862,'furniture','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(898863,'furniture','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(898864,'furniture','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(898865,'furniture','.b-email .heading-image','padding-top','5','','','.b-email'),(898866,'furniture','.w-product-images-additional .images','padding-top','10','5161','','.w-product-images-additional'),(898867,'furniture','.testimonials .reviews-list .name','padding-top','5','','',''),(898868,'furniture','.testimonials .heading-3','padding-top','7','','',''),(898869,'furniture','.testimonials .review','padding-top','10','','',''),(898870,'furniture','.testimonials .name','padding-top','5','','',''),(898871,'furniture','.testimonials .reviews-list .answer .name','padding-top','10','','',''),(898872,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(898873,'furniture','.w-categories .image','padding-top','0','','','.w-categories'),(898874,'furniture','.w-promotions .prom-multi-discount .promo-range','padding-top','0','','','.w-promotions'),(898875,'furniture','.w-promotions .prom-multi-discount .promo-product','padding-top','20','','','.w-promotions'),(898876,'furniture','.w-catalog-items-on-page .before, .w-catalog-items-on-page .after','padding-top','5','','','.w-catalog-items-on-page'),(898877,'furniture','.w-promotions .nextdiscount .content > div','padding-top','10','','','.w-promotions'),(898878,'furniture','.w-promotions .nextdiscount .promo-for-each','padding-top','3','','','.w-promotions'),(898879,'furniture','.w-promotions .promo-salemaker .item','padding-top','20','','','.w-promotions'),(898880,'furniture','.w-promotions .promo-salemaker .discount','padding-top','0','','','.w-promotions'),(898881,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.p-quick-order-index'),(898882,'furniture','.w-promotions .promo-cart-discount .slave .item','padding-top','20','','','.w-promotions'),(898883,'furniture','.w-promotions .promo-cart-discount .slave .condition-holder','padding-top','0','','','.w-promotions'),(898884,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','padding-top','0','','','.w-promotions'),(898885,'furniture','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-top','20','','','.b-warehouses-popup'),(898886,'furniture','.w-product-available-in-warehouses .warehouse-item','padding-top','0','','','.w-product-available-in-warehouses'),(898887,'furniture','.w-chat .w-chat-box','padding-top','2','','','.w-chat'),(898888,'furniture','.w-cart-give-away .ga_column','padding-top','15','','','.w-cart-give-away'),(898889,'furniture','.w-cart-compare .attributes-cell','padding-top','8','','','.w-cart-compare'),(898890,'furniture','.p-quick-order-index .bottom','padding-top','10','','','.p-quick-order-index'),(898891,'furniture','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(898892,'furniture','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(898893,'furniture','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(898894,'furniture','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(898895,'furniture','.b-messages .messages-menu ul','padding-top','0','','','.b-messages'),(898896,'furniture','.b-messages .messages-menu li','padding-top','0','','','.b-messages'),(898897,'furniture','.b-messages .messMenuButton span','padding-top','10','','','.b-messages'),(898898,'furniture','.b-messages .msv_btn','padding-top','12','','','.b-messages'),(898899,'furniture','.b-messages .msv_content','padding-top','10','','','.b-messages'),(898900,'furniture','.b-messages .msv_history','padding-top','10','','','.b-messages'),(898901,'furniture','.b-messages .messages-menu li a','padding-top','10','','','.b-messages'),(898902,'furniture','.b-messages .email-heading','padding-top','15','','','.b-messages'),(898903,'furniture','.b-messages .content_management_attach button','padding-top','1','','','.b-messages'),(898904,'furniture','.b-messages .content_management_attach','padding-top','8','','','.b-messages'),(898905,'furniture','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(898906,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','padding-top','4','','','.b-messages'),(898907,'furniture','.b-messages .emailBtn','padding-top','10','','','.b-messages'),(898908,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-top','5','','','.b-messages'),(898909,'furniture','.b-messages .msv_to_cc','padding-top','10','','','.b-messages'),(898910,'furniture','.b-messages .messMenuButtonTop','padding-top','5','','','.b-messages'),(898911,'furniture','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-top','4','','',''),(898912,'furniture','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(898913,'furniture','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(898914,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(898915,'furniture','.w-sitemap-delivery-location > ul > li > ul','padding-top','0','','','.w-sitemap-delivery-location'),(898916,'furniture','.w-sitemap-delivery-location > ul','padding-top','0','','','.w-sitemap-delivery-location'),(898917,'furniture','.p-payer-order-confirmation .dob-hide label','padding-top','5','','','.p-payer-order-confirmation'),(898918,'furniture','.p-payer-order-pay .dob-hide label','padding-top','5','','','.p-payer-order-pay'),(898919,'furniture','.w-checkout-terms .required-message','padding-top','5','','','.w-checkout-terms'),(898920,'furniture','.w-cart-listing .item .remove','padding-top','5','5140','','.w-cart-listing'),(898921,'furniture','.b-table .table td','padding-top','15','','','.b-table'),(898922,'furniture','.b-table .table .headings td','padding-top','5','','','.b-table'),(898923,'furniture','.b-email .heading-image','padding-top','5','','','.b-email'),(898924,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(898925,'furniture','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(898926,'furniture','.w-reviews-content .item','padding-top','20','','','.w-reviews-content'),(898928,'furniture','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(898929,'furniture','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(898930,'furniture','.b-email .heading-name','padding-top','5','','','.b-email'),(898931,'furniture','.b-email .heading-price','padding-top','5','','','.b-email'),(898932,'furniture','.b-email .heading-model','padding-top','5','','','.b-email'),(898933,'furniture','.p-quick-order-index .all-scroll-div','padding-top','10','','','.p-quick-order-index'),(898934,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-template','padding-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(898935,'furniture','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(898936,'furniture','.b-email .name','padding-top','5','','','.b-email'),(898937,'furniture','.b-email .qty','padding-top','5','','','.b-email'),(898938,'furniture','.b-email .heading-qty','padding-top','5','','','.b-email'),(898939,'furniture','.b-email .heading-model','padding-top','5','','','.b-email'),(898940,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(898941,'furniture','.w-filters .filter-ul-content','padding-top','0','','','.w-filters'),(898942,'furniture','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(898943,'furniture','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(898944,'furniture','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-top','2','','','.w-menu-horizontal'),(898945,'furniture','.w-menu-horizontal ul','padding-top','0','','','.w-menu-horizontal'),(898946,'furniture','.w-tabs .tab-navigation','padding-top','0','','','.w-tabs'),(898947,'furniture','.w-promo-code .holder','padding-top','20','5161','','.w-promo-code'),(898948,'furniture','.w-promo-code .holder','padding-top','20','5161','','.w-promo-code'),(898949,'furniture','.w-product-images-additional .images','padding-top','10','5161','','.w-product-images-additional'),(898950,'furniture','.p-quote-checkout-success .page-success .text-1','padding-top','5','5131','','.p-quote-checkout-success'),(898951,'furniture','.b-fancybox .fancybox-title-over-wrap','padding-top','10','','','.b-fancybox'),(898952,'furniture','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(898953,'furniture','.b-fancybox .fancybox-title-inside-wrap','padding-top','10','','','.b-fancybox'),(898954,'furniture','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(898955,'furniture','.w-multi-cart-cart-switcher .carts-switcher','padding-top','20','','','.w-multi-cart-cart-switcher'),(898956,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(898957,'furniture','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(898958,'furniture','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(898959,'furniture','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(898960,'furniture','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(898961,'furniture','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-top','0','','','.b-fancybox'),(898962,'furniture','.w-cart-compare .dropdown li','padding-top','5','','','.w-cart-compare'),(898963,'furniture','.no-found','padding-top','20','','',''),(898965,'furniture','.b-upload-files .attached-block','padding-top','10','','','.b-upload-files'),(898967,'furniture','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(898968,'furniture','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(898969,'furniture','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(898970,'furniture','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(898972,'furniture','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(898973,'furniture','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(898974,'furniture','.message.success','padding-top','20','','',''),(898975,'furniture','.w-cart-compare .dropdown .dropdown-menu','padding-top','5','','','.w-cart-compare'),(898976,'furniture','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(898977,'furniture','.b-email .heading-qty','padding-top','5','','','.b-email'),(898978,'furniture','.b-email .model','padding-top','5','','','.b-email'),(898979,'furniture','.b-email .totals-title','padding-top','5','','','.b-email'),(898980,'furniture','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(898981,'furniture','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(898982,'furniture','.b-email .totals-value','padding-top','5','','','.b-email'),(898983,'furniture','.b-email .heading-name','padding-top','5','','','.b-email'),(898984,'furniture','.b-email .name','padding-top','5','','','.b-email'),(898985,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-top','0','','','.b-select-suggest'),(898986,'furniture','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(898987,'furniture','.w-reviews .review','padding-top','10','','','.w-reviews'),(898988,'furniture','.w-socials > li','padding-top','15','','','.w-socials'),(898990,'furniture','.w-cart-compare .product','padding-top','10','','','.w-cart-compare'),(898991,'furniture','.b-info-popup .info-popup div','padding-top','10','','','.b-info-popup'),(898993,'furniture','.w-quote .cart-box-link','padding-top','0','','','.w-quote'),(898994,'furniture','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-top','7','','','.order-summary'),(898995,'furniture','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(898996,'furniture','.w-reviews .author','padding-top','0','','','.w-reviews'),(898997,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(898998,'furniture','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(898999,'furniture','.b-email .heading-model','padding-top','5','','','.b-email'),(899000,'furniture','.b-email .model','padding-top','5','','','.b-email'),(899001,'furniture','textarea','padding-top','5','','',''),(899002,'furniture','.p-quote-checkout-success .page-success .text-1','padding-top','5','5131','','.p-quote-checkout-success'),(899003,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(899004,'furniture','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-top','3','','','.w-multi-cart-actions'),(899005,'furniture','.w-top-categories h2.name','padding-top','3','','','.w-top-categories'),(899006,'furniture','.w-top-categories .item','padding-top','5','','','.w-top-categories'),(899007,'furniture','.w-tabs .accordion-heading','padding-top','9','5131','','.w-tabs'),(899008,'furniture','.w-tabs > .block','padding-top','20','','','.w-tabs'),(899009,'furniture','.w-cart-cart-tabs .w-tabs > .block','padding-top','0','','','.w-cart-cart-tabs'),(899010,'furniture','.w-tabs .tab-a','padding-top','14','','','.w-tabs'),(899011,'furniture','.w-tabs .tab-a','padding-top','12','2','','.w-tabs'),(899012,'furniture','.w-tabs .tab-li','padding-top','0','','','.w-tabs'),(899013,'furniture','.w-socials > li','padding-top','15','','','.w-socials'),(899014,'furniture','.order-summary > div','padding-top','10','','','.order-summary'),(899015,'furniture','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(899016,'furniture','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(899017,'furniture','.b-bottom .popup-buttons','padding-top','15','','','.b-bottom'),(899018,'furniture','.b-autocomplete .ui-autocomplete li','padding-top','3','','','.b-autocomplete'),(899019,'furniture','.b-bottom .popup-content','padding-top','15','','','.b-bottom'),(899020,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(899021,'furniture','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(899022,'furniture','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(899023,'furniture','.btn-1','padding-top','5','','',''),(899024,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(899025,'furniture','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(899026,'furniture','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(899027,'furniture','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(899028,'furniture','.p-sample-checkout-success .page-success .text-1','padding-top','5','5131','','.p-sample-checkout-success'),(899029,'furniture','.b-messages .emailLineTextArea textarea','padding-top','30','','','.b-messages'),(899030,'furniture','.btn-3','padding-top','13','','',''),(899031,'furniture','.b-bottom .confirm-popup .confirm-text','padding-top','40','','','.b-bottom'),(899032,'furniture','.w-product-images-additional .images','padding-top','10','5161','','.w-product-images-additional'),(899033,'furniture','.b-products-listing .products-listing .buyButton .btn','padding-top','5','','','.b-products-listing'),(899034,'furniture','.heading-3 .right-text, h3 .right-text','padding-top','3','','',''),(899035,'furniture','.b-bottom .popup-heading','padding-top','10','','','.b-bottom'),(899036,'furniture','.b-form .shipping-method .item + .item','padding-top','5','','','.b-form'),(899037,'furniture','.heading-3 .edit, h3 .edit','padding-top','2','','',''),(899038,'furniture','.b-email .model','padding-top','5','','','.b-email'),(899039,'furniture','.b-upload-file .upload-file-template','padding-top','25','','','.b-upload-file'),(899040,'furniture','.p-quote-checkout-success .page-success .text-1','padding-top','5','5131','','.p-quote-checkout-success'),(899041,'furniture','.b-email .qty','padding-top','5','','','.b-email'),(899042,'furniture','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(899043,'furniture','.b-email .heading-price','padding-top','5','','','.b-email'),(899044,'furniture','.w-socials > li','padding-top','15','','','.w-socials'),(899045,'furniture','.order-summary .price-row','padding-top','7','','','.order-summary'),(899046,'furniture','.b-email .model','padding-top','5','','','.b-email'),(899047,'furniture','.b-email .image','padding-top','5','','','.b-email'),(899048,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(899049,'furniture','.b-select-suggest .select2-drop-mask','padding-top','0','','','.b-select-suggest'),(899051,'furniture','.w-reviews-content .review','padding-top','20','','','.w-reviews-content'),(899052,'furniture','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(899053,'furniture','.b-email .price','padding-top','5','','','.b-email'),(899054,'furniture','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(899055,'furniture','.b-fancybox .fancybox-title-float-wrap .child','padding-top','2','','','.b-fancybox'),(899056,'furniture','.w-checkout-shipping-choice span','padding-top','7','5161','','.w-checkout-shipping-choice'),(899057,'furniture','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(899058,'furniture','.w-top-categories .categories h2','padding-top','0','','','.w-top-categories'),(899059,'furniture','.w-top-categories .image','padding-top','0','','','.w-top-categories'),(899060,'furniture','.w-product-reviews .reviews-list .review','padding-top','10','','','.w-product-reviews'),(899061,'furniture','.w-product-reviews .reviews-list .name','padding-top','5','','','.w-product-reviews'),(899062,'furniture','.b-email .heading-qty','padding-top','5','','','.b-email'),(899063,'furniture','.b-email .name','padding-top','5','','','.b-email'),(899064,'furniture','.b-form .required-message','padding-top','0','','','.b-form'),(899065,'furniture','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(899066,'furniture','.p-quote-checkout-success .page-success .text-1','padding-top','5','5131','','.p-quote-checkout-success'),(899067,'furniture','.w-promo-code .holder','padding-top','20','5161','','.w-promo-code'),(899068,'furniture','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(899069,'furniture','.b-bottom .popup-simple','padding-top','20','','','.b-bottom'),(899070,'furniture','.b-bottom .rfq-form','padding-top','0','','','.b-bottom'),(899071,'furniture','.b-email .heading-model','padding-top','5','','','.b-email'),(899072,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(899073,'furniture','.b-email .price','padding-top','5','','','.b-email'),(899074,'furniture','.b-email .heading-name','padding-top','5','','','.b-email'),(899075,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(899076,'furniture','.b-email .model','padding-top','5','','','.b-email'),(899077,'furniture','.b-email .heading-price','padding-top','5','','','.b-email'),(899078,'furniture','.b-email .heading-qty','padding-top','5','','','.b-email'),(899079,'furniture','.b-email .heading-model','padding-top','5','','','.b-email'),(899080,'furniture','.b-email .qty','padding-top','5','','','.b-email'),(899081,'furniture','.b-email .totals-value','padding-top','5','','','.b-email'),(899082,'furniture','.b-email .totals-title','padding-top','5','','','.b-email'),(899083,'furniture','.b-email .image','padding-top','5','','','.b-email'),(899084,'furniture','.b-email .price','padding-top','5','','','.b-email'),(899085,'furniture','.b-email .qty','padding-top','5','','','.b-email'),(899086,'furniture','.b-email .name','padding-top','5','','','.b-email'),(899087,'furniture','.b-email .heading-image','padding-top','5','','','.b-email'),(899088,'furniture','.b-email .heading-name','padding-top','5','','','.b-email'),(899089,'furniture','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(899090,'furniture','.w-checkout-shipping .sub-item','padding-top','5','','','.w-checkout-shipping'),(899091,'furniture','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(899092,'furniture','.b-table .table .headings td','padding-top','5','','','.b-table'),(899093,'furniture','.b-table .table td','padding-top','15','','','.b-table'),(899094,'furniture','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(899095,'furniture','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(899096,'furniture','.w-promo-code .holder','padding-top','20','5161','','.w-promo-code'),(899097,'furniture','.w-socials > li','padding-top','15','','','.w-socials'),(899098,'furniture','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(899099,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(899100,'furniture','.b-form .center-buttons','padding-top','20','','','.b-form'),(899101,'furniture','.b-form .shipping-method .input','padding-top','0','','','.b-form'),(899102,'furniture','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(899103,'furniture','.w-reviews .heading-3','padding-top','7','','','.w-reviews'),(899104,'furniture','.w-checkout-shipping-address .edit-ab','padding-top','5','','','.w-checkout-shipping-address'),(899105,'furniture','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(899106,'furniture','.b-select-suggest .select2-container .select2-choice','padding-top','0','','','.b-select-suggest'),(899107,'furniture','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(899108,'furniture','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(899109,'furniture','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(899110,'furniture','.b-bottom .terms-info-popup .pop-up-content','padding-top','20','','','.b-bottom'),(899111,'furniture','.w-checkout-create-account .create-account-switcher','padding-top','8','','','.w-checkout-create-account'),(899112,'furniture','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','12','5140','','.w-menu-horizontal'),(899113,'furniture','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(899114,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(899115,'furniture','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(899116,'furniture','.w-product-images-additional .images','padding-top','10','5161','','.w-product-images-additional'),(899117,'furniture','.b-form .login-col-1','padding-top','40','','','.b-form'),(899118,'furniture','.b-form .form-buttons','padding-top','17','','','.b-form'),(899119,'furniture','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(899120,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(899121,'furniture','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(899123,'furniture','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(899124,'furniture','.w-cart-compare .delete-cart','padding-top','10','','','.w-cart-compare'),(899125,'furniture','.w-catalog-listing-look .listing-look-title','padding-top','4','','','.w-catalog-listing-look'),(899126,'furniture','.b-table .table td','padding-top','15','','','.b-table'),(899127,'furniture','.b-email .heading-price','padding-top','5','','','.b-email'),(899128,'furniture','.b-email .image','padding-top','5','','','.b-email'),(899129,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(899130,'furniture','.b-email .price','padding-top','5','','','.b-email'),(899131,'furniture','.w-product-images-additional .images','padding-top','10','5161','','.w-product-images-additional'),(899132,'furniture','.b-bottom .cart-options .heading-4','padding-top','10','','','.b-bottom'),(899133,'furniture','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-top','0','','','.b-bottom'),(899134,'furniture','.b-compare .popupCompare .pop-up-content','padding-top','0','','','.b-compare'),(899135,'furniture','.w-promotions .promo-cart-discount .master .item','padding-top','0','','','.w-promotions'),(899136,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(899137,'furniture','.b-bottom .alert-message','padding-top','20','','','.b-bottom'),(899138,'furniture','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(899139,'furniture','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(899140,'furniture','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(899141,'furniture','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(899142,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(899143,'furniture','.b-email .image','padding-top','5','','','.b-email'),(899144,'furniture','.b-bottom .cart-options','padding-top','20','','','.b-bottom'),(899145,'furniture','.b-email .totals-title','padding-top','5','','','.b-email'),(899146,'furniture','.b-email .price','padding-top','5','','','.b-email'),(899147,'furniture','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(899148,'furniture','.b-email .image','padding-top','5','','','.b-email'),(899149,'furniture','.b-email .heading-image','padding-top','5','','','.b-email'),(899150,'furniture','.b-email .heading-qty','padding-top','5','','','.b-email'),(899151,'furniture','.b-bottom .footerTitle','padding-top','9','5131','','.b-bottom'),(899152,'furniture','.b-bottom .pop-up-info','padding-top','20','','','.b-bottom'),(899153,'furniture','.b-bottom .pop-up-close','padding-top','1','','','.b-bottom'),(899154,'furniture','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(899155,'furniture','.w-cart-up-sell .w-list-type-1','padding-top','0','','','.w-cart-up-sell'),(899156,'furniture','.w-cart-up-sell .w-list-type-1 .item','padding-top','1','','','.w-cart-up-sell'),(899157,'furniture','.w-cart-shipping-estimator .address-item','padding-top','0','','','.w-cart-shipping-estimator'),(899158,'furniture','.w-cart-up-sell .w-list-type-1 .item','padding-top','0','1','','.w-cart-up-sell'),(899159,'furniture','.b-products-listing .products-listing .btn-buy','padding-top','5','','','.b-products-listing'),(899160,'furniture','.b-upload-files .added-file','padding-top','5','','','.b-upload-files'),(899161,'furniture','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(899162,'furniture','.w-socials > li','padding-top','15','','','.w-socials'),(899163,'furniture','.w-personal-gift-status-bar .end-date','padding-top','0','3','','.w-personal-gift-status-bar'),(899164,'furniture','.p-quote-checkout-success .page-success .text-1','padding-top','5','5131','','.p-quote-checkout-success'),(899165,'furniture','.b-bottom .popup-box-wrap','padding-top','10','','','.b-bottom'),(899166,'furniture','.b-fancybox .fancybox-error','padding-top','15','','','.b-fancybox'),(899167,'furniture','.b-form .privacy-row','padding-top','10','','','.b-form'),(899168,'furniture','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(899169,'furniture','.b-form .payment-method .item','padding-top','7','','','.b-form'),(899170,'furniture','.b-form .required-message-wrap','padding-top','0','','','.b-form'),(899171,'furniture','.w-product-customers-activity .customers-activity','padding-top','35','','','.w-product-customers-activity'),(899172,'furniture','.b-table .table .headings td','padding-top','5','','','.b-table'),(899173,'furniture','.b-email .name','padding-top','5','','','.b-email'),(899174,'furniture','.b-email .heading-price','padding-top','5','','','.b-email'),(899175,'furniture','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(899176,'furniture','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(899177,'furniture','.w-checkout-billing-address .edit-ab','padding-top','5','','','.w-checkout-billing-address'),(899178,'furniture','.w-checkout-shipping-choice span','padding-top','7','','','.w-checkout-shipping-choice'),(899179,'furniture','.w-promo-code .holder','padding-top','20','5161','','.w-promo-code'),(899180,'furniture','.w-product-images-additional .images','padding-top','10','5161','','.w-product-images-additional'),(899181,'furniture','.w-categories .item','padding-top','5','','','.w-categories'),(899182,'furniture','.w-tabs .accordion-heading','padding-top','6','','','.w-tabs'),(899183,'furniture','.w-socials > li','padding-top','15','','','.w-socials'),(899184,'furniture','.b-form .shipping-method .sub-title','padding-top','2','','','.b-form'),(899185,'furniture','.w-categories h2.name','padding-top','3','','','.w-categories'),(899186,'furniture','.b-table .table .headings td','padding-top','5','','','.b-table'),(899187,'furniture','.w-catalog-sorting .before','padding-top','5','','','.w-catalog-sorting'),(899188,'furniture','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(899190,'furniture','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(899191,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(899192,'furniture','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(899193,'furniture','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(899194,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(899195,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-top','0','','','.b-select-suggest'),(899196,'furniture','.b-select-suggest .select2-locked','padding-top','3','','','.b-select-suggest'),(899197,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-top','5','','','.b-select-suggest'),(899198,'furniture','.b-select-suggest .select2-container-multi .select2-choices','padding-top','0','','','.b-select-suggest'),(899199,'furniture','.b-select-suggest .select2-results .select2-result-label','padding-top','3','','','.b-select-suggest'),(899200,'furniture','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','5','','','.w-menu-horizontal'),(899201,'furniture','.b-select-suggest .select2-results','padding-top','0','','','.b-select-suggest'),(899202,'furniture','.b-select-suggest .select2-container .select2-choice > .select2-chosen','padding-top','4','','','.b-select-suggest'),(899203,'furniture','.b-select-suggest .select2-search input','padding-top','4','','','.b-select-suggest'),(899204,'furniture','.b-bottom .notify-form','padding-top','0','','','.b-bottom'),(899205,'furniture','.b-select-suggest .select2-drop-auto-width .select2-search','padding-top','4','','','.b-select-suggest'),(899206,'furniture','.w-neighbour-checkout .neighbour-comment-box','padding-top','10','','','.w-neighbour-checkout'),(899207,'furniture','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(899208,'furniture','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(899209,'furniture','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(899210,'furniture','.w-personal-gift-status-bar .inform','padding-top','0','4','','.w-personal-gift-status-bar'),(899212,'furniture','.w-checkout-billing-address .same-address','padding-top','10','','','.w-checkout-billing-address'),(899213,'furniture','.w-menu-horizontal > ul > li > ul > li','padding-top','2','','','.w-menu-horizontal'),(899214,'furniture','.w-menu-big ul','padding-top','0','','','.w-menu-big'),(899218,'furniture','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(899219,'furniture','.w-cart-compare .product-label','padding-top','15','','','.w-cart-compare'),(899220,'furniture','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(899221,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(899222,'furniture','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(899223,'furniture','.b-sub-totals .historyTotal td','padding-top','2','','','.b-sub-totals'),(899224,'furniture','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(899225,'furniture','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(899226,'furniture','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(899227,'furniture','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(899228,'furniture','.w-cart-compare .price-cell','padding-top','8','','','.w-cart-compare'),(899232,'furniture','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(899233,'furniture','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(899234,'furniture','.w-account-addresses-list .addsess-suggestion-item','padding-top','0','','','.w-account-addresses-list'),(899235,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top','0','','','.b-data-table'),(899236,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.b-data-table'),(899237,'furniture','.w-communication-post .communication-post-author','padding-top','10','','','.w-communication-post'),(899238,'furniture','.b-products-listing .products-listing a.btn.view-button','padding-top','0','','','.b-products-listing'),(899239,'furniture','.b-products-listing .in-cart','padding-top','5','','','.b-products-listing'),(899240,'furniture','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-top','4','','','.b-products-listing'),(899241,'furniture','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-top','5','','','.w-catalog-b2b-add-button'),(899242,'furniture','.b-products-listing .promos-info .promo-name','padding-top','3','','','.b-products-listing'),(899243,'furniture','.b-products-listing .promos-info .promo-item','padding-top','3','','','.b-products-listing'),(899249,'furniture','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(899250,'furniture','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(899251,'furniture','.p-quote-checkout-success .page-success .text-1','padding-top','5','5131','','.p-quote-checkout-success'),(899252,'furniture','.w-checkout-gdpr .privacy-row','padding-top','0','','','.w-checkout-gdpr'),(899253,'furniture','.w-checkout-gdpr .terms-login','padding-top','0','','','.w-checkout-gdpr'),(899254,'furniture','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(899255,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow b','padding-top','3','3','','.b-select-suggest'),(899256,'furniture','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(899257,'furniture','.b-table .table .headings td','padding-top','5','','','.b-table'),(899258,'furniture','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(899259,'furniture','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(899260,'furniture','.b-compare .compare-box-item','padding-top','10','','','.b-compare'),(899261,'furniture','.b-email .heading-qty','padding-top','5','','','.b-email'),(899262,'furniture','.b-bottom .header-info','padding-top','20','','','.b-bottom'),(899263,'furniture','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(899264,'furniture','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(899265,'furniture','.b-compare .compare-head','padding-top','10','','','.b-compare'),(899266,'furniture','.heading-4 .right-text, h4 .right-text','padding-top','4','','',''),(899267,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-top','0','','',''),(899268,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-top','0','','','.b-h-inline'),(899269,'furniture','h1, .heading-1','padding-top','20','','',''),(899270,'furniture','.w-communication-new-topic .topick-left-col','padding-top','24','','','.w-communication-new-topic'),(899271,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-top','0','','','.w-communication-new-topic'),(899272,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-top','5','','','.w-communication-new-topic'),(899273,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-top','5','','','.w-communication-new-topic'),(899274,'furniture','.w-communication-new-topic #communication_topic_form .middle-form','padding-top','20','','','.w-communication-new-topic'),(899275,'furniture','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(899276,'furniture','.b-email .heading-image','padding-top','5','','','.b-email'),(899277,'furniture','.b-email .price','padding-top','5','','','.b-email'),(899278,'furniture','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-top','4','','','.b-compare'),(899280,'furniture','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(899281,'furniture','.w-cart-compare .price-label','padding-top','10','','','.w-cart-compare'),(899282,'furniture','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(899284,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(899285,'furniture','.b-table .table td','padding-top','15','','','.b-table'),(899286,'furniture','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(899287,'furniture','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(899288,'furniture','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(899289,'furniture','.b-email .model','padding-top','5','','','.b-email'),(899290,'furniture','.b-email .totals-value','padding-top','5','','','.b-email'),(899291,'furniture','.b-email .heading-name','padding-top','5','','','.b-email'),(899292,'furniture','.products-quick-index .token-input-list','padding-top','0','','',''),(899293,'furniture','.w-cart-compare .cart-cell','padding-top','0','','','.w-cart-compare'),(899295,'furniture','.w-reviews .item','padding-top','15','','','.w-reviews'),(899296,'furniture','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(899297,'furniture','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(899298,'furniture','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(899299,'furniture','.b-email .name','padding-top','5','','','.b-email'),(899300,'furniture','.b-form .shipping-method .item','padding-top','0','','','.b-form'),(899301,'furniture','.b-email .heading-name','padding-top','5','','','.b-email'),(899302,'furniture','.b-email .qty','padding-top','5','','','.b-email'),(899303,'furniture','.b-email .totals-value','padding-top','5','','','.b-email'),(899304,'furniture','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(899305,'furniture','.b-email .heading-model','padding-top','5','','','.b-email'),(899306,'furniture','.b-compare .col-two label','padding-top','5','','','.b-compare'),(899307,'furniture','.w-cart-listing .item .attributes','padding-top','5','','','.w-cart-listing'),(899308,'furniture','.w-cart-listing .item .gift-wrap label','padding-top','10','','','.w-cart-listing'),(899309,'furniture','.w-cart-listing .item > div','padding-top','10','','','.w-cart-listing'),(899310,'furniture','.w-cart-listing .points-earn','padding-top','5','','','.w-cart-listing'),(899311,'furniture','.w-cart-listing .points-redeem','padding-top','0','','','.w-cart-listing'),(899312,'furniture','.b-bottom .header-error','padding-top','20','','','.b-bottom'),(899318,'furniture','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(899319,'furniture','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(899320,'furniture','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(899321,'furniture','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(899322,'furniture','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(899323,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-top','10','','','.w-image-maps'),(899324,'furniture','.b-compare .col-gender','padding-top','0','','','.b-compare'),(899325,'furniture','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(899326,'furniture','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-top','0','','','.b-fancybox'),(899327,'furniture','.b-compare .compare_pagination','padding-top','10','','','.b-compare'),(899328,'furniture','.w-top-categories .item','padding-top','5','5131','','.w-top-categories'),(899329,'furniture','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(899332,'furniture','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(899333,'furniture','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(899334,'furniture','.b-table .table td','padding-top','15','','','.b-table'),(899335,'furniture','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(899336,'furniture','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(899338,'furniture','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(899339,'furniture','.w-filters .fsl_handle','padding-top','20','','','.w-filters'),(899340,'furniture','.w-filters .head-filter-widget','padding-top','0','5140','','.w-filters'),(899341,'furniture','.w-filters .ui-slider-range','padding-top','0','','','.w-filters'),(899342,'furniture','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(899343,'furniture','.w-filters .head-filter-widget','padding-top','0','','','.w-filters'),(899344,'furniture','.b-autocomplete .ui-autocomplete','padding-top','2','','','.b-autocomplete'),(899345,'furniture','.w-promo-code .holder','padding-top','20','5161','','.w-promo-code'),(899347,'furniture','.order-summary .heading-2','padding-top','16','','','.order-summary'),(899348,'furniture','.b-compare .column_wrapper','padding-top','0','','','.b-compare'),(899349,'furniture','.b-email .image','padding-top','5','','','.b-email'),(899350,'furniture','.b-email .heading-price','padding-top','5','','','.b-email'),(899351,'furniture','.b-email .heading-image','padding-top','5','','','.b-email'),(899352,'furniture','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(899353,'furniture','.b-table .table .headings td','padding-top','5','','','.b-table'),(899354,'furniture','.w-reviews-content .author','padding-top','0','','','.w-reviews-content'),(899355,'furniture','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(899356,'furniture','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(899357,'furniture','.price .old','padding-top','0.3','','',''),(899358,'furniture','.b-data-table table.dataTable tbody td','padding-top','10','','','.b-data-table'),(899359,'furniture','.b-data-table table.dataTable thead td','padding-top','10','','','.b-data-table'),(899360,'furniture','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(899361,'furniture','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(899362,'furniture','.b-table .table td','padding-top','15','','','.b-table'),(899364,'furniture','.btn-2','padding-top','12','','',''),(899365,'furniture','.w-quote-products .empty','padding-top','100','','','.w-quote-products'),(899366,'furniture','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(899367,'furniture','.w-checkout-create-account .create-account','padding-top','10','','','.w-checkout-create-account'),(899368,'furniture','.b-email .totals-title','padding-top','5','','','.b-email'),(899369,'furniture','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(899370,'furniture','.b-upload-files .upload-files','padding-top','0','','','.b-upload-files'),(899371,'furniture','.b-email .totals-value','padding-top','5','','','.b-email'),(899372,'furniture','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(899373,'furniture','.b-email .totals-value','padding-top','5','','','.b-email'),(899374,'furniture','.b-email .totals-title','padding-top','5','','','.b-email'),(899375,'furniture','.b-email .qty','padding-top','5','','','.b-email'),(899376,'furniture','.btn','padding-top','7','','',''),(899377,'furniture','.w-personal-gift-status-bar .timeline','padding-top','16','','','.w-personal-gift-status-bar'),(899378,'furniture','.b-product-images .media-popup .mp-content','padding-top','0','','','.b-product-images'),(899379,'furniture','.b-product-images .media-popup .mp-small-images .item','padding-top','10','','','.b-product-images'),(899380,'furniture','.b-product-images .media-popup .slick-dots','padding-top','0','','','.b-product-images'),(899381,'furniture','.b-product-images .media-popup .slick-dots li','padding-top','0','','','.b-product-images'),(899382,'furniture','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-top','0','','','.b-menu-style'),(899383,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-top','5','','','.b-menu-style-2'),(899384,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-top','5','','','.b-menu-style-2'),(899385,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-top','0','','','.b-menu-style-2'),(899386,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-top','0','','','.b-menu-style-2'),(899387,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-top','10','','','.b-menu-style-2'),(899388,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-top','0','','','.b-menu-style-2'),(899389,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-top','5','','','.b-menu-style-2'),(899390,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-top','10','','','.b-menu-style-2'),(899391,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-top','5','','','.b-menu-style-2'),(899392,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-html_box','padding-top','7','','','.b-menu-style-2'),(899393,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-top','10','','','.b-menu-style-2'),(899394,'furniture','.b-personal-catalog-popup #personal_catalog_popup','padding-top','20','','','.b-personal-catalog-popup'),(899395,'furniture','.b-trade-approval .steps-bar li a','padding-top','7','','','.b-trade-approval'),(899396,'furniture','.b-trade-approval .middle-form','padding-top','20','','','.b-trade-approval'),(899397,'furniture','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-top','5','','','.b-trade-approval'),(899398,'furniture','.b-trade-approval .steps-bar','padding-top','0','','','.b-trade-approval'),(899399,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-top','4','','','.b-trade-approval'),(899400,'furniture','.b-trade-approval .center-buttons','padding-top','20','','','.b-trade-approval'),(899401,'furniture','.w-account-personal-catalog .list-switcher','padding-top','0','','','.w-account-personal-catalog'),(899402,'furniture','.w-account-personal-catalog .list-switcher a','padding-top','14','','','.w-account-personal-catalog'),(899403,'furniture','.w-account-personal-catalog .list-switcher a','padding-top','12','2','','.w-account-personal-catalog'),(899404,'furniture','.w-account-subscription .subscription-variant','padding-top','10','','','.w-account-subscription'),(899405,'furniture','.w-catalog-additional-images li','padding-top','10','','','.w-catalog-additional-images'),(899406,'furniture','.w-catalog-additional-images ul','padding-top','0','','','.w-catalog-additional-images'),(899407,'furniture','.w-catalog-compare td','padding-top','10','','','.w-catalog-compare'),(899408,'furniture','.w-catalog-compare .cross-box .different-all > div','padding-top','12','','','.w-catalog-compare'),(899409,'furniture','.w-catalog-compare .cross-box .different-all > div','padding-top','10','2','','.w-catalog-compare'),(899410,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-top','0','','','.w-catalog-compare'),(899411,'furniture','.w-delivery-day .left-count','padding-top','5','','','.w-delivery-day'),(899412,'furniture','.w-delivery-day .left-text-left','padding-top','24','','','.w-delivery-day'),(899413,'furniture','.w-delivery-day .left-text-right','padding-top','24','','','.w-delivery-day'),(899414,'furniture','.w-top-text .top-text','padding-top','5','','','.w-top-text'),(899415,'furniture','.w-product-images .slick-vertical + .produst-image','padding-top','400','','','.w-product-images'),(899416,'furniture','.w-product-images .additional-horizontal .item','padding-top','10','','','.w-product-images'),(899417,'furniture','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-top','10','','','.b-cookie-notice'),(899421,'furniture','.b-slick .slick-list','padding-top','0','','','.b-slick'),(899422,'furniture','.b-slick .slick-vertical button.slick-next','padding-top','0','3','','.b-slick'),(899423,'furniture','.b-slick .slick-vertical button.slick-prev','padding-top','0','3','','.b-slick'),(899424,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','padding-top','0','','','.b-slick'),(899425,'furniture','body','padding-top','75','5140','',''),(899426,'furniture','.cartTitle span','padding-top','0','','','.cartTitle'),(899427,'furniture','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','padding-top','0','','','.b-products-listing'),(899428,'furniture','.w-cart-listing .headings .head','padding-top','10','','','.w-cart-listing'),(899429,'furniture','.b-products-listing .item-nav > div','padding-top','10','','','.b-products-listing'),(899430,'furniture','.LeftCategories .w-menu-simple ul','padding-top','0','','','.LeftCategories'),(899431,'furniture','.LeftCategories .w-menu-simple ul li a','padding-top','4','','','.LeftCategories'),(899432,'furniture','.w-filters .filter-widget','padding-top','20','','','.w-filters'),(899433,'furniture','.b-products-listing .products-listing.list-productlisting .item','padding-top','0','','','.b-products-listing'),(899434,'furniture','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-top','0','','','.b-products-listing'),(899435,'furniture','.b-products-listing .products-listing.list-productlisting .item-content','padding-top','15','','','.b-products-listing'),(899436,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','padding-top','0','','','.b-products-listing'),(899437,'furniture','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-top','15','','','.b-products-listing'),(899438,'furniture','.b-products-listing .products-listing.list-rows .item-nav > div','padding-top','0','','','.b-products-listing'),(899439,'furniture','.b-products-listing .products-listing.list-rows .item:first-of-type .BlockBox.item-holder','padding-top','10','','','.b-products-listing'),(899440,'furniture','.w-breadcrumb .breadcrumb-li','padding-top','0','','','.w-breadcrumb'),(899441,'furniture','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(899442,'furniture','.w-subscribers .btn-submit','padding-top','5','','','.w-subscribers'),(899443,'furniture','.w-quote .buttons','padding-top','15','','','.w-quote'),(899444,'furniture','.w-quote .buttons .btn','padding-top','5','','','.w-quote'),(899445,'furniture','.w-quote .cart-content','padding-top','15','','','.w-quote'),(899446,'furniture','.w-quote .cart-total','padding-top','10','','','.w-quote'),(899447,'furniture','.w-quote .multicart .cart-content','padding-top','0','','','.w-quote'),(899448,'furniture','.w-quote .multicart .item','padding-top','15','','','.w-quote'),(899449,'furniture','.w-quote .multicart .name','padding-top','0','','','.w-quote'),(899450,'furniture','.w-quote .no-text','padding-top','0','','','.w-quote'),(899451,'furniture','.w-quote a.item','padding-top','5','','','.w-quote'),(899452,'furniture','.w-social-links a','padding-top','4','','','.w-social-links'),(899453,'furniture','.w-product-images .additional-vertical .additional-images','padding-top','30','','','.w-product-images'),(899454,'furniture','.w-product-personal-catalog-button .btn','padding-top','0','','','.w-product-personal-catalog-button'),(899455,'furniture','.b-quantity .qty-box input','padding-top','5','','','.b-quantity'),(899456,'furniture','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(899457,'furniture','.w-product-sale-ends .left-count','padding-top','5','','','.w-product-sale-ends'),(899458,'furniture','.w-product-sale-ends .left-text-left','padding-top','24','','','.w-product-sale-ends'),(899459,'furniture','.w-product-sale-ends .left-text-right','padding-top','24','','','.w-product-sale-ends'),(899460,'furniture','.w-product-sale-ends .left-count-days','padding-top','7','','','.w-product-sale-ends'),(899461,'furniture','.w-product-sale-ends .left-count-hours','padding-top','7','','','.w-product-sale-ends'),(899462,'furniture','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(899463,'furniture','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(899464,'furniture','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(899465,'furniture','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(899466,'furniture','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(899467,'furniture','.warrantyProduct .warranty, .warrantyProduct .delivery','padding-top','10','','','.warrantyProduct'),(899468,'furniture','.w-compare .compare-list-buttons','padding-top','10','','','.w-compare'),(899469,'furniture','.w-compare .item-holder','padding-top','10','','','.w-compare'),(899470,'furniture','.w-compare .compare-list-products','padding-top','0','','','.w-compare'),(899471,'furniture','.w-files-catalog-widgets-files-catalog .name','padding-top','10','','','.w-files-catalog-widgets-files-catalog'),(899472,'furniture','.w-files-catalog-widgets-files-list .item + .item','padding-top','30','','','.w-files-catalog-widgets-files-list'),(899473,'furniture','.w-sample .buttons','padding-top','15','','','.w-sample'),(899474,'furniture','.w-sample .buttons .btn','padding-top','5','','','.w-sample'),(899475,'furniture','.w-sample .cart-box-link','padding-top','0','','','.w-sample'),(899476,'furniture','.w-sample .cart-content','padding-top','15','','','.w-sample'),(899477,'furniture','.w-sample .cart-total','padding-top','10','','','.w-sample'),(899478,'furniture','.w-sample .multicart .cart-content','padding-top','0','','','.w-sample'),(899479,'furniture','.w-sample .multicart .item','padding-top','15','','','.w-sample'),(899480,'furniture','.w-sample .multicart .name','padding-top','0','','','.w-sample'),(899481,'furniture','.w-sample .no-text','padding-top','0','','','.w-sample'),(899482,'furniture','.w-sample a.item','padding-top','5','','','.w-sample'),(899483,'furniture','.w-cart-listing .item > div.points','padding-top','0','','','.w-cart-listing'),(899484,'furniture','.w-filters-simple .integrate-price-holder','padding-top','10','','','.w-filters-simple'),(899485,'furniture','.w-product-video .item','padding-top','10','','','.w-product-video'),(899486,'furniture','.shipping-ico .heading-3','padding-top','0','','','.shipping-ico'),(899487,'furniture','.w-cart-order-reference .btn','padding-top','6','','','.w-cart-order-reference'),(899488,'furniture','.w-cart-gift-certificate .btn','padding-top','6','','','.w-cart-gift-certificate'),(899489,'furniture','.w-cart-shipping-estimator .btn','padding-top','6','','','.w-cart-shipping-estimator'),(899490,'furniture','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(899491,'furniture','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(899492,'furniture','.w-product-in-bundles .attributes-item','padding-top','0','','','.w-product-in-bundles'),(899493,'furniture','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(899494,'furniture','.w-cart-listing .item > div.actions','padding-top','10','5131','','.w-cart-listing'),(899496,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-top','0','','','.b-products-listing'),(899497,'furniture','.b-pagination ul.pagination','padding-top','0','','','.b-pagination'),(899498,'furniture','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','padding-top','10','','','.w-catalog-compare'),(899499,'furniture','.w-product-properties-filters-widgets-chosen-filters .item','padding-top','3','','','.w-product-properties-filters-widgets-chosen-filters'),(899500,'furniture','.p-quote-checkout-index .datepicker-inline','padding-top','10','','','.p-quote-checkout-index'),(899501,'furniture','.p-sample-checkout-index .datepicker-inline','padding-top','10','','','.p-sample-checkout-index'),(899505,'furniture','.w-product-multi-inventory .radio-attributes .option-item','padding-top','10','','','.w-product-multi-inventory'),(899506,'furniture','.w-account-personal-catalog .list-row-action ul','padding-top','0','','','.w-account-personal-catalog'),(899507,'furniture','.w-account-personal-catalog .list-row-action li','padding-top','5','','','.w-account-personal-catalog'),(899508,'furniture','.w-account-personal-catalog .buy-box','padding-top','0','5131','','.w-account-personal-catalog'),(899509,'furniture','.b-products-listing .products-listing .radio-attributes .option','padding-top','10','','','.b-products-listing'),(899510,'furniture','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(899511,'furniture','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(899512,'furniture','.w-product-collection .choose-products','padding-top','20','','','.w-product-collection'),(899513,'furniture','.w-product-collection .right-area .btn','padding-top','12','','','.w-product-collection'),(899514,'furniture','.w-product-attributes .radio-attributes .option-item','padding-top','10','','','.w-product-attributes'),(899515,'furniture','.w-product-properties .property-ul','padding-top','0','','','.w-product-properties'),(899516,'furniture','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(899517,'furniture','.w-product-properties li','padding-top','5','','','.w-product-properties'),(899518,'furniture','.w-questionnaire-widgets-questionnaire .question + .question','padding-top','20','','','.w-questionnaire-widgets-questionnaire'),(899519,'furniture','.w-product-groups .radioBox','padding-top','0','','','.w-product-groups'),(899520,'furniture','.w-product-groups .radioBox label','padding-top','0','','','.w-product-groups'),(899521,'furniture','.w-product-groups .radioBox label .containerBlock','padding-top','20','','','.w-product-groups'),(899522,'furniture','.w-product-groups .radioBox label .containerBlock','padding-top','5','5161','','.w-product-groups'),(899523,'furniture','.b-products-listing .mix-attributes .attribute-qty-block','padding-top','5','','','.b-products-listing'),(899524,'furniture','.b-products-listing .products-listing .attribute-qty-block','padding-top','5','','','.b-products-listing'),(899525,'furniture','.blogsidebar','padding-top','0','5140','',''),(899526,'furniture','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(899527,'furniture','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(899528,'furniture','.w-product-custom-bundle .choose-products','padding-top','10','','','.w-product-custom-bundle'),(899529,'furniture','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-top','14','','','.w-product-custom-bundle'),(899530,'furniture','.w-product-custom-bundle .right-area','padding-top','0','5140','','.w-product-custom-bundle'),(899531,'furniture','.w-product-custom-bundle .right-area .price','padding-top','20','5140','','.w-product-custom-bundle'),(899532,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list'),(899533,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-top','0','','','.w-catalog-pages-category-pages-last-list'),(899534,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list-block'),(899535,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-top','0','','','.w-catalog-pages-category-pages-last-list-block'),(899536,'furniture','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(899537,'furniture','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(899538,'furniture','.w-delivery-location-location-description .deliveryDesc','padding-top','10','','','.w-delivery-location-location-description'),(899539,'furniture','.w-delivery-location-location-list .deliveryListParrent a','padding-top','6','','','.w-delivery-location-location-list'),(899540,'furniture','.w-delivery-location-location-list .deliveryList li a','padding-top','10','','','.w-delivery-location-location-list'),(899541,'furniture','.btn-2','padding-top','7','5131','',''),(899542,'furniture','.w-sale-category .holder-1','padding-top','20','','','.w-sale-category'),(899543,'furniture','.w-sale-category .holder-2','padding-top','20','','','.w-sale-category'),(899544,'furniture','.w-sale-category .left-count','padding-top','5','','','.w-sale-category'),(899545,'furniture','.w-sale-category .left-text-left','padding-top','24','','','.w-sale-category'),(899546,'furniture','.w-sale-category .left-text-right','padding-top','24','','','.w-sale-category'),(899547,'furniture','.w-sale-category .text','padding-top','10','','','.w-sale-category'),(899548,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(899549,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(899550,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(899551,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(899552,'furniture','.w-delivery-location-list-by-page .item','padding-top','20','','','.w-delivery-location-list-by-page'),(899553,'furniture','.w-product-properties-icons .property-image','padding-top','10','','','.w-product-properties-icons'),(899554,'furniture','.w-product-properties-icons .hover-box-content','padding-top','10','','','.w-product-properties-icons'),(899555,'furniture','.w-delivery-location-cross-pages .item','padding-top','20','','','.w-delivery-location-cross-pages'),(899556,'furniture','.w-delivery-location-product-categories .item.category-link','padding-top','15','','','.w-delivery-location-product-categories'),(899557,'furniture','.w-delivery-location-product-categories .item.category-link','padding-top','10','5140','','.w-delivery-location-product-categories'),(899558,'furniture','.w-delivery-location-product-categories .item.category-link','padding-top','10','5161','','.w-delivery-location-product-categories'),(899559,'furniture','.w-delivery-location-product-categories .name','padding-top','10','','','.w-delivery-location-product-categories'),(899560,'furniture','.delivery-options-popup','padding-top','20','','',''),(899561,'furniture','.w-product-bonus-points .bonus-points-cost','padding-top','8','','','.w-product-bonus-points'),(899562,'furniture','.w-product-designer-designer .grnamebox .title-sortable','padding-top','7','','','.w-product-designer-designer'),(899563,'furniture','.w-product-designer-designer .prodDesignerType label','padding-top','10','','','.w-product-designer-designer'),(899564,'furniture','.w-press-reviews-widgets-press-reviews ','padding-top','30','','','.w-press-reviews-widgets-press-reviews'),(899565,'furniture','.w-press-reviews-widgets-press-reviews .author','padding-top','0','','','.w-press-reviews-widgets-press-reviews'),(899566,'furniture','.w-press-reviews-widgets-press-reviews .item','padding-top','20','','','.w-press-reviews-widgets-press-reviews'),(899567,'furniture','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-top','30','','','.w-press-reviews-widgets-press-reviews'),(899568,'furniture','.w-press-reviews-widgets-press-reviews .review','padding-top','10','','','.w-press-reviews-widgets-press-reviews'),(899569,'furniture','.w-press-reviews-widgets-press-reviews ','padding-top','20','5131','','.w-press-reviews-widgets-press-reviews'),(899570,'furniture','.w-press-reviews-widgets-press-reviews .item','padding-top','15','5131','','.w-press-reviews-widgets-press-reviews'),(899571,'furniture','.w-press-reviews-widgets-press-reviews .review','padding-top','10','5131','','.w-press-reviews-widgets-press-reviews'),(899572,'furniture','.w-press-reviews-widgets-press-reviews-list .item','padding-top','0','','','.w-press-reviews-widgets-press-reviews-list'),(899573,'furniture','.w-press-reviews-widgets-press-reviews-list .short-description','padding-top','0','','','.w-press-reviews-widgets-press-reviews-list'),(899574,'furniture','.b-products-listing .productGroup label a','padding-top','5','','','.b-products-listing'),(899575,'furniture','.w-gift-wrap-message-checkout .text','padding-top','2','','','.w-gift-wrap-message-checkout'),(899576,'furniture','.w-support-system-filter ','padding-top','0','','','.w-support-system-filter'),(899577,'furniture','.w-support-system-filter .filter_cats','padding-top','0','','','.w-support-system-filter'),(899578,'furniture','.w-support-system-listing .support-head','padding-top','13','','','.w-support-system-listing'),(899579,'furniture','.w-communication-post .btn.refresh','padding-top','0','','','.w-communication-post'),(899580,'furniture','.w-rma-returns-history .btn','padding-top','7','','','.w-rma-returns-history'),(899581,'furniture','.w-rma-returns-history .column','padding-top','0','','','.w-rma-returns-history'),(899582,'furniture','.w-rma-returns-history .column .title','padding-top','5','','','.w-rma-returns-history'),(899583,'furniture','.w-rma-returns-history .topRow','padding-top','10','','','.w-rma-returns-history'),(899584,'furniture','.w-rma-returns-history .column:last-child .title','padding-top','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(899585,'furniture','.w-show-inactive-show-inactive .out_stock_label','padding-top','2','','','.w-show-inactive-show-inactive'),(899586,'furniture','.w-product-designer-designer .productDesignerBox ul','padding-top','0','','','.w-product-designer-designer'),(899587,'furniture','.w-product-configurator .pc-item','padding-top','0','','','.w-product-configurator'),(899588,'furniture','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(899589,'furniture','.w-product-configurator .pc_item','padding-top','10','5140','','.w-product-configurator'),(899590,'furniture','.w-product-configurator .pc_attr','padding-top','5','5131','','.w-product-configurator'),(899591,'furniture','.b-products-listing .products-listing .bonus-points-cost','padding-top','8','','','.b-products-listing'),(899592,'furniture','.b-products-listing .promos-info .promo-name-span','padding-top','3','','','.b-products-listing'),(899593,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-list'),(899594,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-top','0','','','.w-catalog-pages-category-pages-list'),(899595,'furniture','.w-predefined-promotion .nextdiscount .content > div','padding-top','10','','','.w-predefined-promotion'),(899596,'furniture','.w-predefined-promotion .nextdiscount .promo-for-each','padding-top','3','','','.w-predefined-promotion'),(899597,'furniture','.w-predefined-promotion .prom-multi-discount .promo-product','padding-top','20','','','.w-predefined-promotion'),(899598,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','padding-top','0','','','.w-predefined-promotion'),(899599,'furniture','.w-predefined-promotion .promo-cart-discount .master .item','padding-top','0','','','.w-predefined-promotion'),(899600,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-top','0','','','.w-predefined-promotion'),(899601,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-top','0','','','.w-predefined-promotion'),(899602,'furniture','.w-predefined-promotion .promo-cart-discount .slave .item','padding-top','20','','','.w-predefined-promotion'),(899603,'furniture','.w-predefined-promotion .promo-item','padding-top','30','','','.w-predefined-promotion'),(899604,'furniture','.w-predefined-promotion .promo-salemaker .discount','padding-top','0','','','.w-predefined-promotion'),(899605,'furniture','.w-predefined-promotion .promo-salemaker .item','padding-top','20','','','.w-predefined-promotion'),(899606,'furniture','.w-supplier-purchase-supplier-products .item','padding-top','10','','','.w-supplier-purchase-supplier-products'),(899607,'furniture','.w-filters .filter-box-content ul','padding-top','0','','','.w-filters'),(899608,'furniture','.mainBanner .bottomBox','padding-top','55','','','.mainBanner'),(899609,'furniture','.mainBanner .bottomBox .btn','padding-top','1.09','','','.mainBanner'),(899610,'furniture','.mainBanner .topBox','padding-top','3','','','.mainBanner'),(899611,'furniture','.mainBanner .topBox > .right','padding-top','5','','','.mainBanner'),(899612,'furniture','.mainBanner .wrapper','padding-top','0','','','.mainBanner'),(899613,'furniture','.mainBanner .bottomBox','padding-top','33','5145','','.mainBanner'),(899614,'furniture','.mainBanner .bottomBox .btn','padding-top','8','5145','','.mainBanner'),(899615,'furniture','.mainBanner .topBox > .right','padding-top','5','5145','','.mainBanner'),(899616,'furniture','.mainBanner .wrapper','padding-top','0','5145','','.mainBanner'),(899617,'furniture','.mainBanner .bottomBox .btn','padding-top','6','5140','','.mainBanner'),(899618,'furniture','.mainBanner .content','padding-top','15','5131','','.mainBanner'),(899619,'furniture','.mainBanner .topBox > .right','padding-top','5','5131','','.mainBanner'),(899620,'furniture','.mainBanner .wrapper','padding-top','3','5131','','.mainBanner'),(899621,'furniture','.mainBanner .bottomBox','padding-top','25','5161','','.mainBanner'),(899622,'furniture','.mainBanner .bottomBox .btn','padding-top','4','5161','','.mainBanner'),(899623,'furniture','.mainBanner .content','padding-top','5','5161','','.mainBanner'),(899624,'furniture','.mainBanner .wrapper','padding-top','3','5161','','.mainBanner'),(899625,'furniture','.mainBanner .bottomBox .btn','padding-top','15','5206','','.mainBanner'),(899626,'furniture','.order-summary .w-cart-listing .item > div ~ div','padding-top','0','','','.order-summary'),(899627,'furniture','.order-summary .heading-2','padding-top','10','5145','','.order-summary'),(899628,'furniture','.w-cart-discount-coupon .discount-box','padding-top','5','','','.w-cart-discount-coupon'),(899629,'furniture','.w-cart-listing .promos-info .promo-name','padding-top','3','','','.w-cart-listing'),(899630,'furniture','.w-cart-listing .item .image','padding-top','10','5140','','.w-cart-listing'),(899631,'furniture','.w-cart-listing .item .name','padding-top','10','5140','','.w-cart-listing'),(899632,'furniture','.w-cart-listing .item .points','padding-top','0','5131','','.w-cart-listing'),(899633,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','padding-top','5','','','.w-promotions-widgets-promotion-icons-desc'),(899634,'furniture','.w-product-promotion-icons .promos-info .promo-name','padding-top','3','','','.w-product-promotion-icons'),(899635,'furniture','.w-quote-products .no-price','padding-top','15','','','.w-quote-products'),(899636,'furniture','.w-product-quantity-discounts .item','padding-top','10','','','.w-product-quantity-discounts'),(899639,'furniture','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','padding-top','20','','','.b-product-images'),(899640,'furniture','.b-product-images .media-popup .mp-small-images img','padding-top','10','','','.b-product-images'),(899658,'furniture','.account-address-book .address_book','padding-top','0','','','.account-address-book'),(899659,'furniture','.account-address-book .address_book h1','padding-top','0','','','.account-address-book'),(899660,'furniture','.account-address-book .address_book h2','padding-top','15','','','.account-address-book'),(899661,'furniture','.account-address-book .address_book, .account-address-book .account_history_info','padding-top','10','','','.account-address-book'),(899662,'furniture','.account-address-book .buttonBox','padding-top','15','','','.account-address-book'),(899663,'furniture','.account-address-book .rightMes ul','padding-top','22','','','.account-address-book'),(899664,'furniture','.account-address-book .topButtons','padding-top','0','','','.account-address-book'),(899678,'furniture','.account-order-pay .contentColumn','padding-top','10','','','.account-order-pay'),(899679,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-top','5','','','.account-order-pay'),(899680,'furniture','.account-order-pay .history_attr','padding-top','5','','','.account-order-pay'),(899681,'furniture','.account-order-pay .history_info > div + div','padding-top','0','','','.account-order-pay'),(899682,'furniture','.account-order-pay .history_info > div','padding-top','0','5140','','.account-order-pay'),(899683,'furniture','.account-order-pay .history_info > div + div','padding-top','0','5140','','.account-order-pay'),(899684,'furniture','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-top','10','','','.account-samples'),(899685,'furniture','.account-samples .orders-table th','padding-top','2','','','.account-samples'),(899686,'furniture','.account-samples .order_history_table th','padding-top','10','','','.account-samples'),(899687,'furniture','.account-samples .view_link','padding-top','0','','','.account-samples'),(899688,'furniture','.account-samples .orders-table .td-alignright','padding-top','5','5140','','.account-samples'),(899689,'furniture','.account-samples .orders-table td','padding-top','5','5140','','.account-samples'),(899690,'furniture','.account-sample-info .contentColumn','padding-top','10','','','.account-sample-info'),(899691,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-top','5','','','.account-sample-info'),(899692,'furniture','.account-sample-info .history_attr','padding-top','5','','','.account-sample-info'),(899693,'furniture','.account-sample-info .history_info > div + div','padding-top','0','','','.account-sample-info'),(899694,'furniture','.account-sample-info .popup-tracking-number','padding-top','10','','','.account-sample-info'),(899695,'furniture','.account-sample-info .history_info > div','padding-top','0','5140','','.account-sample-info'),(899696,'furniture','.account-sample-info .history_info > div + div','padding-top','0','5140','','.account-sample-info'),(899697,'furniture','.catalog-product-wrap .next-product','padding-top','20','','','.catalog-product-wrap'),(899698,'furniture','.catalog-product-wrap .pn-direction','padding-top','0','','','.catalog-product-wrap'),(899699,'furniture','.catalog-product-wrap .pn-image','padding-top','20','','','.catalog-product-wrap'),(899700,'furniture','.catalog-product-wrap .pn-name','padding-top','15','','','.catalog-product-wrap'),(899701,'furniture','.catalog-product-wrap .prev-product','padding-top','20','','','.catalog-product-wrap'),(899702,'furniture','.catalog-product-wrap .next-product','padding-top','20','5140','','.catalog-product-wrap'),(899703,'furniture','.catalog-product-wrap .pn-direction','padding-top','0','5140','','.catalog-product-wrap'),(899704,'furniture','.catalog-product-wrap .prev-product','padding-top','20','5140','','.catalog-product-wrap'),(899705,'furniture','.checkout-index-wrap .datepicker-inline','padding-top','10','','','.checkout-index-wrap'),(899706,'furniture','.checkout-index-wrap .dob-hide label','padding-top','5','','','.checkout-index-wrap'),(899707,'furniture','.checkout-index-wrap .edit-address-popup','padding-top','20','','','.checkout-index-wrap'),(899708,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-top','7','','','.checkout-index-wrap'),(899709,'furniture','.checkout-index-wrap .hiding-box .checkout-cart-listing','padding-top','30','','','.checkout-index-wrap'),(899710,'furniture','.checkout-index-wrap .order-summary .heading-2','padding-top','10','','','.checkout-index-wrap'),(899711,'furniture','.checkout-order-confirmation .price-row','padding-top','5','','','.checkout-order-confirmation'),(899712,'furniture','.checkout-success-wrap .page-success .text-1','padding-top','120','','','.checkout-success-wrap'),(899713,'furniture','.checkout-success-wrap .page-success .text-1','padding-top','5','5131','','.checkout-success-wrap'),(899714,'furniture','.checkout-login-wrap .password-forgotten-link','padding-top','0','','','.checkout-login-wrap'),(899715,'furniture','.shopping-cart-index .btn-3','padding-top','11','','','.shopping-cart-index'),(899716,'furniture','.shopping-cart-index .cart-page .empty','padding-top','100','','','.shopping-cart-index'),(899717,'furniture','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-top','0','','','.shopping-cart-index'),(899718,'furniture','.b-form .columns .col-2','padding-top','0','','','.b-form'),(899719,'furniture','.b-bottom .pop-up-content','padding-top','15','','','.b-bottom'),(899720,'furniture','.b-bottom .pop-up-content .buttons','padding-top','10','','','.b-bottom'),(899721,'furniture','.checkout-index-wrap .closeable-content','padding-top','20','','','.checkout-index-wrap'),(899722,'furniture','.checkout-index-wrap .closeable-heading','padding-top','8','','','.checkout-index-wrap'),(899723,'furniture','.b-form .middle-g','padding-top','20','','','.b-form'),(899724,'furniture','.b-info .info','padding-top','20','','','.b-info'),(899725,'furniture','.b-info .info li','padding-top','0','','','.b-info'),(899726,'furniture','.b-info .info ul','padding-top','0','','','.b-info'),(899727,'furniture','.b-multi-page-checkout .multi-page-checkout','padding-top','20','','','.b-multi-page-checkout'),(899728,'furniture','.b-multi-page-checkout .multi-page-checkout .buttons','padding-top','0','','','.b-multi-page-checkout'),(899729,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-top','20','','','.b-multi-page-checkout'),(899730,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-top','8','','','.b-multi-page-checkout'),(899731,'furniture','.b-form .col-left','padding-top','0','','','.b-form'),(899732,'furniture','.b-form .col-right','padding-top','0','','','.b-form'),(899733,'furniture','.success-page .check-ico-block','padding-top','20','','','.success-page'),(899734,'furniture','.success-page .order_totals .price-row','padding-top','5','','','.success-page'),(899735,'furniture','.success-page .page-success .text-1','padding-top','5','5131','','.success-page'),(899736,'furniture','.success-page .price-row','padding-top','5','','','.success-page'),(899737,'furniture','.success-page .totals-line','padding-top','10','','','.success-page'),(899738,'furniture','.success-page .w-cart-listing .qty','padding-top','0','','','.success-page'),(899739,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','padding-top','0','','','.mainBanner'),(899740,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','padding-top','0','','','.mainBanner'),(899741,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','padding-top','0','','','.mainBanner'),(899742,'furniture','.preFooter .w-banner .banner-image picture','padding-top','0','','','.preFooter'),(899743,'furniture','.menu-header .menu-style[data-style=\"1\"] .goto-button','padding-top','0','','','.menu-header'),(899744,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > li > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-top','12','','','.menu-header'),(899745,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','padding-top','5','','','.menu-header'),(899746,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li > .no-link','padding-top','5','5140','','.footer-menu'),(899747,'furniture','.lowestPricedBox .w-banner .banner-holder','padding-top','30','','','.lowestPricedBox'),(899748,'furniture','.lowestPricedBox .w-banner .banner-holder','padding-top','15','5131','','.lowestPricedBox'),(899749,'furniture','.lowestPricedBox .w-banner .banner-text','padding-top','0','','','.lowestPricedBox'),(899750,'furniture','.lowestPricedBox .w-banner .banner-text-holder','padding-top','15','','','.lowestPricedBox'),(899751,'furniture','.lowestPricedBox .w-banner .banner-text-holder','padding-top','10','5140','','.lowestPricedBox'),(899752,'furniture','.lowestPricedBox .w-banner .banner-text-holder','padding-top','10','5161','','.lowestPricedBox'),(899753,'furniture','.lowestPricedBox .w-banner .ybg .btn','padding-top','4','5140','','.lowestPricedBox'),(899754,'furniture','.lowestPricedBox .w-banner .ybg .btn','padding-top','4','5161','','.lowestPricedBox'),(899755,'furniture','.lowestPricedBox .w-banner .ybg .mark','padding-top','15','','','.lowestPricedBox'),(899756,'furniture','.lowestPricedBox .w-banner .ybg .mark','padding-top','0','5131','','.lowestPricedBox'),(899757,'furniture','.lowestPricedBox .w-banner .ybg .mark','padding-top','0','5140','','.lowestPricedBox'),(899758,'furniture','.lowestPricedBox .w-banner .ybg .mark','padding-top','10','5145','','.lowestPricedBox'),(899759,'furniture','.tripleBanner ','padding-top','15','','','.tripleBanner'),(899760,'furniture','.tripleBanner .w-html_box','padding-top','17','','','.tripleBanner'),(899761,'furniture','.tripleBanner > .block','padding-top','0','','','.tripleBanner'),(899762,'furniture','.shopByCollectionBox .bannerButton','padding-top','10','','','.shopByCollectionBox'),(899763,'furniture','.shopByCollectionBox .bannerButton','padding-top','5','5145','','.shopByCollectionBox'),(899764,'furniture','.shopByCollectionBox .bannerButton a','padding-top','7','','','.shopByCollectionBox'),(899765,'furniture','.shopByCollectionBox .bannerButton a','padding-top','7','5145','','.shopByCollectionBox'),(899766,'furniture','.shopByCollectionBox .content','padding-top','10','','','.shopByCollectionBox'),(899767,'furniture','.shopByCollectionBox .w-banner .banner-text','padding-top','0','','','.shopByCollectionBox'),(899769,'furniture','.w-banner .banner-text','padding-top','20','','','.w-banner'),(899770,'furniture','.w-banner .carousel-text > span','padding-top','20','','','.w-banner'),(899771,'furniture','.w-catalog-paging .paging-item','padding-top','0','','','.w-catalog-paging'),(899772,'furniture','.b-data-table table.dataTable tbody td','padding-top_important','important','','','.b-data-table'),(899773,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top_important','important','','','.b-data-table'),(899774,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top_important','important','','','.b-data-table'),(899775,'furniture','.b-data-table table.dataTable thead td','padding-top_important','important','','','.b-data-table'),(899776,'furniture','.w-account-personal-catalog .buy-box','padding-top_important','important','5131','','.w-account-personal-catalog'),(899777,'furniture','.w-cart-listing .item .points','padding-top_important','important','5131','','.w-cart-listing'),(899778,'furniture','.success-page .totals-line','padding-top_important','important','','','.success-page'),(899779,'furniture','.preFooter .w-banner .banner-image picture','padding-top_important','important','','','.preFooter'),(899780,'furniture','.w-categories .image','padding_bottom_measure','%','','','.w-categories'),(899781,'furniture','.w-top-categories .image','padding_bottom_measure','%','','','.w-top-categories'),(899782,'furniture','.mainBanner .bottomBox .btn','padding_bottom_measure','vw','','','.mainBanner'),(899783,'furniture','.mainBanner .wrapper','padding_bottom_measure','%','5131','','.mainBanner'),(899784,'furniture','.mainBanner .wrapper','padding_bottom_measure','%','5161','','.mainBanner'),(899785,'furniture','.b-upload-file .upload-file-template','padding_left_measure','%','','','.b-upload-file'),(899786,'furniture','.w-cart-give-away .ga_img','padding_left_measure','%','','','.w-cart-give-away'),(899787,'furniture','.b-product-images .media-popup .mp-content','padding_left_measure','%','','','.b-product-images'),(899788,'furniture','.w-product-collection .right-area','padding_left_measure','%','','','.w-product-collection'),(899789,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding_left_measure','%','','','.w-delivery-location-featured-list'),(899790,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding_left_measure','%','5161','','.w-delivery-location-featured-list'),(899791,'furniture','.mainBanner .bottomBox .btn','padding_left_measure','vw','','','.mainBanner'),(899792,'furniture','.mainBanner .topBox','padding_left_measure','%','','','.mainBanner'),(899793,'furniture','.mainBanner .wrapper','padding_left_measure','%','','','.mainBanner'),(899794,'furniture','.mainBanner .topBox','padding_left_measure','%','5145','','.mainBanner'),(899795,'furniture','.mainBanner .wrapper','padding_left_measure','%','5145','','.mainBanner'),(899796,'furniture','.mainBanner .topBox','padding_left_measure','%','5131','','.mainBanner'),(899797,'furniture','.mainBanner .wrapper','padding_left_measure','%','5131','','.mainBanner'),(899798,'furniture','.mainBanner .wrapper','padding_left_measure','%','5161','','.mainBanner'),(899801,'furniture','.account-order-pay .history_info > div + div','padding_left_measure','%','','','.account-order-pay'),(899802,'furniture','.account-sample-info .history_info > div + div','padding_left_measure','%','','','.account-sample-info'),(899803,'furniture','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(899804,'furniture','.b-upload-file .upload-file-template','padding_right_measure','%','','','.b-upload-file'),(899805,'furniture','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(899806,'furniture','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(899807,'furniture','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(899808,'furniture','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(899809,'furniture','.w-cart-give-away .ga_img','padding_right_measure','%','','','.w-cart-give-away'),(899810,'furniture','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(899811,'furniture','.b-product-images .media-popup .mp-content','padding_right_measure','%','','','.b-product-images'),(899812,'furniture','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(899813,'furniture','.w-product-in-bundles .attributes-item','padding_right_measure','%','','','.w-product-in-bundles'),(899814,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding_right_measure','%','','','.w-delivery-location-featured-list'),(899815,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding_right_measure','%','5161','','.w-delivery-location-featured-list'),(899816,'furniture','.mainBanner .bottomBox .btn','padding_right_measure','vw','','','.mainBanner'),(899817,'furniture','.mainBanner .wrapper','padding_right_measure','%','','','.mainBanner'),(899818,'furniture','.mainBanner .wrapper','padding_right_measure','%','5145','','.mainBanner'),(899819,'furniture','.mainBanner .topBox','padding_right_measure','%','5131','','.mainBanner'),(899820,'furniture','.mainBanner .wrapper','padding_right_measure','%','5131','','.mainBanner'),(899821,'furniture','.mainBanner .wrapper','padding_right_measure','%','5161','','.mainBanner'),(899823,'furniture','.price .old','padding_top_measure','em','','',''),(899824,'furniture','.mainBanner .bottomBox .btn','padding_top_measure','vw','','','.mainBanner'),(899825,'furniture','.mainBanner .topBox','padding_top_measure','%','','','.mainBanner'),(899826,'furniture','.mainBanner .content','padding_top_measure','%','5131','','.mainBanner'),(899827,'furniture','.mainBanner .wrapper','padding_top_measure','%','5131','','.mainBanner'),(899828,'furniture','.mainBanner .content','padding_top_measure','%','5161','','.mainBanner'),(899829,'furniture','.mainBanner .wrapper','padding_top_measure','%','5161','','.mainBanner'),(899830,'furniture','.b-slick .slick-slide.dragging img','pointer-events','none','','','.b-slick'),(899831,'furniture','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(899832,'furniture','.w-checkout-shipping-address .addresses .address-item label','position','relative','','','.w-checkout-shipping-address'),(899833,'furniture','.b-form .radio-buttons .radio-button','position','relative','','','.b-form'),(899834,'furniture','.w-checkout-billing-address .addresses .address-item label','position','relative','','','.w-checkout-billing-address'),(899835,'furniture','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position','absolute','','','.b-switch'),(899836,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','position','relative','3','','.b-switch'),(899837,'furniture','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(899838,'furniture','.b-fancybox .filter-listing-preloader','position','absolute','','','.b-fancybox'),(899839,'furniture','.b-fancybox .filter-listing-loader','position','absolute','','','.b-fancybox'),(899840,'furniture','.w-promotions .prom-multi-discount > .heading','position','relative','3','','.w-promotions'),(899841,'furniture','.w-promotions .prom-multi-discount .promo-range','position','relative','','','.w-promotions'),(899842,'furniture','.w-promotions .promo-date','position','relative','','','.w-promotions'),(899847,'furniture','.p-sample-checkout-success .page-success > div','position','relative','','','.p-sample-checkout-success'),(899848,'furniture','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(899849,'furniture','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(899850,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(899851,'furniture','.testimonials .reviews-list span','position','relative','','',''),(899852,'furniture','.testimonials .heading-3','position','relative','','',''),(899853,'furniture','.testimonials .review','position','absolute','3','',''),(899854,'furniture','.testimonials .review','position','relative','','',''),(899855,'furniture','.testimonials .rating','position','relative','','',''),(899856,'furniture','.testimonials .heading-3','position','absolute','3','',''),(899857,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(899858,'furniture','.w-promotions .prom-multi-discount .products','position','relative','','','.w-promotions'),(899859,'furniture','.w-promotions .icon','position','relative','','','.w-promotions'),(899860,'furniture','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','position','relative','3','','.w-promotions'),(899861,'furniture','.w-promotions .promo-salemaker .discount','position','relative','','','.w-promotions'),(899862,'furniture','.w-promotions .promo-cart-discount .slave .content','position','relative','','','.w-promotions'),(899863,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','position','relative','','','.w-promotions'),(899864,'furniture','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','position','relative','3','','.w-promotions'),(899865,'furniture','.b-preloader .preloader','position','absolute','3','','.b-preloader'),(899866,'furniture','.b-preloader .preloader','position','absolute','','','.b-preloader'),(899867,'furniture','.w-checkout-create-account .account-benefits strong','position','relative','3','','.w-checkout-create-account'),(899868,'furniture','.w-cart-compare .cart-cell > div','position','relative','','','.w-cart-compare'),(899870,'furniture','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(899871,'furniture','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(899872,'furniture','.closeable-heading','position','absolute','3','',''),(899873,'furniture','.closeable-heading','position','relative','','',''),(899874,'furniture','.b-messages .messBtnMenuDelete','position','relative','3','','.b-messages'),(899875,'furniture','.b-messages .messMenuButton span','position','relative','','','.b-messages'),(899876,'furniture','.b-messages .messBtnMenuStarred','position','relative','3','','.b-messages'),(899877,'furniture','.b-messages span.starred::before','position','relative','','','.b-messages'),(899878,'furniture','.b-messages .messBtnMenuUnread','position','relative','3','','.b-messages'),(899879,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-messages'),(899880,'furniture','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(899881,'furniture','.b-info-popup .info-popup div','position','absolute','3','','.b-info-popup'),(899882,'furniture','.p-payer-order-confirmation .order-ico','position','relative','3','','.p-payer-order-confirmation'),(899883,'furniture','.p-payer-order-confirmation .comment-ico','position','relative','3','','.p-payer-order-confirmation'),(899884,'furniture','.p-payer-order-confirmation .discount-ico','position','relative','3','','.p-payer-order-confirmation'),(899885,'furniture','.p-payer-order-pay .order-ico','position','relative','3','','.p-payer-order-pay'),(899886,'furniture','.w-checkout-terms .terms-box','position','relative','','','.w-checkout-terms'),(899887,'furniture','.p-payer-order-pay .discount-ico','position','relative','3','','.p-payer-order-pay'),(899888,'furniture','.p-payer-order-pay .comment-ico','position','relative','3','','.p-payer-order-pay'),(899889,'furniture','.w-checkout-terms .required-message-wrap','position','static','','','.w-checkout-terms'),(899890,'furniture','.w-checkout-terms input[type=\"checkbox\"]','position','relative','','','.w-checkout-terms'),(899891,'furniture','.w-checkout-shipping-address .genders-title input','position','relative','','','.w-checkout-shipping-address'),(899892,'furniture','.b-fancybox #fancybox-loading','position','fixed','','','.b-fancybox'),(899893,'furniture','.b-form .radio-button input[type=\"radio\"]','position','relative','','','.b-form'),(899894,'furniture','.b-fancybox .fancybox-wrap','position','absolute','','','.b-fancybox'),(899895,'furniture','.b-upload-file .snapshot','position','absolute','','','.b-upload-file'),(899897,'furniture','.b-rating .glyphicon','position','relative','','','.b-rating'),(899898,'furniture','.w-checkout-shipping-choice input:checked + span:before','position','absolute','','','.w-checkout-shipping-choice'),(899899,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(899900,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(899901,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-remove','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(899902,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-details','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(899903,'furniture','.b-switch .bootstrap-switch','position','relative','','','.b-switch'),(899904,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(899905,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(899906,'furniture','.w-coupons-and-vauchers-checkout .btn-remove','position','relative','','','.w-coupons-and-vauchers-checkout'),(899907,'furniture','.b-products-listing .products-listing .radio-attributes input','position','relative','','','.b-products-listing'),(899908,'furniture','.w-checkout-bonus-points .btn-remove','position','relative','','','.w-checkout-bonus-points'),(899909,'furniture','.b-products-listing .products-listing .btn-buy','position','relative','3','','.b-products-listing'),(899910,'furniture','.b-form .col-3','position','relative','','','.b-form'),(899913,'furniture','.w-menu-horizontal li','position','relative','','','.w-menu-horizontal'),(899914,'furniture','.b-form .billing-address','position','relative','','','.b-form'),(899915,'furniture','.w-quote .cart-box-link','position','relative','','','.w-quote'),(899916,'furniture','.b-form .form-buttons','position','relative','','','.b-form'),(899917,'furniture','.b-fancybox .fancybox-title-over-wrap','position','absolute','','','.b-fancybox'),(899918,'furniture','.b-fancybox .fancybox-title-outside-wrap','position','relative','','','.b-fancybox'),(899921,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','position','absolute','','','.b-switch'),(899922,'furniture','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(899928,'furniture','.w-cart-compare .atr-col','position','relative','','','.w-cart-compare'),(899930,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','position','relative','','','.b-switch'),(899931,'furniture','.b-switch .candlestick-wrapper','position','relative','','','.b-switch'),(899932,'furniture','.b-bottom .footerTitle','position','absolute','5131,4','','.b-bottom'),(899933,'furniture','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(899934,'furniture','.b-select-suggest .select2-measure-scrollbar','position','absolute','','','.b-select-suggest'),(899935,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position','absolute','','','.b-select-suggest'),(899937,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(899938,'furniture','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(899939,'furniture','.w-reviews .review','position','relative','','','.w-reviews'),(899940,'furniture','.w-reviews .heading-3','position','relative','','','.w-reviews'),(899941,'furniture','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(899943,'furniture','.b-info-popup .info-popup div','position','absolute','','','.b-info-popup'),(899946,'furniture','.b-select-suggest .select2-search-choice-close','position','absolute','','','.b-select-suggest'),(899947,'furniture','.view-all','position','absolute','3','',''),(899948,'furniture','.view-all','position','relative','','',''),(899949,'furniture','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(899950,'furniture','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(899951,'furniture','.view-all .btn','position','relative','','',''),(899952,'furniture','.w-text .customer-service','position','relative','','','.w-text'),(899953,'furniture','.w-text .customer-service','position','absolute','3','','.w-text'),(899954,'furniture','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(899956,'furniture','.b-form .checkbox-style','position','absolute','','','.b-form'),(899958,'furniture','.edit-link','position','relative','','',''),(899959,'furniture','.message.success','position','relative','3','',''),(899960,'furniture','.w-text .customer-service','position','relative','','','.w-text'),(899961,'furniture','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(899962,'furniture','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(899963,'furniture','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(899964,'furniture','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(899965,'furniture','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(899966,'furniture','.b-upload-file .upload-remove','position','absolute','','','.b-upload-file'),(899968,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','position','absolute','','','.b-switch'),(899969,'furniture','.w-text .customer-service','position','absolute','3','','.w-text'),(899970,'furniture','.w-cart-bonus-points .btn-remove','position','relative','','','.w-cart-bonus-points'),(899971,'furniture','.savings-ico .heading-2','position','relative','3','','.savings-ico'),(899972,'furniture','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(899973,'furniture','.w-multi-cart-actions .cart-actions','position','relative','','','.w-multi-cart-actions'),(899974,'furniture','.w-reviews .review','position','absolute','3','','.w-reviews'),(899975,'furniture','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(899976,'furniture','.w-text .customer-service','position','absolute','3','','.w-text'),(899977,'furniture','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(899978,'furniture','.b-form .addresses .address-item input[type=\"radio\"]','position','relative','','','.b-form'),(899979,'furniture','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(899980,'furniture','.w-product-reviews .reviews-list .review','position','relative','','','.w-product-reviews'),(899981,'furniture','.b-fancybox .fancybox-skin','position','relative','','','.b-fancybox'),(899982,'furniture','.b-fancybox .fancybox-overlay-fixed','position','fixed','','','.b-fancybox'),(899983,'furniture','.b-fancybox .fancybox-overlay','position','absolute','','','.b-fancybox'),(899984,'furniture','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(899987,'furniture','.b-pass-strength .pass-strength span','position','absolute','','','.b-pass-strength'),(899988,'furniture','.w-text .customer-service','position','relative','','','.w-text'),(899989,'furniture','.b-fancybox .fancybox-nav','position','absolute','','','.b-fancybox'),(899990,'furniture','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(899991,'furniture','.w-promo-code .holder','position','relative','','','.w-promo-code'),(899992,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(899993,'furniture','.b-form .shipping-method .input input','position','relative','','','.b-form'),(899994,'furniture','.w-reviews .heading-3','position','absolute','3','','.w-reviews'),(899995,'furniture','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(899996,'furniture','.b-select-suggest .select2-container .select2-choice','position','relative','','','.b-select-suggest'),(899997,'furniture','.b-select-suggest .select2-container','position','relative','','','.b-select-suggest'),(899998,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','position','relative','3','','.b-switch'),(899999,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','position','relative','3','','.b-switch'),(900001,'furniture','.b-form .hide-billing-address','position','absolute','','','.b-form'),(900002,'furniture','.b-form .radio-button input[type=\"radio\"].no','position','absolute','','','.b-form'),(900003,'furniture','.b-form .payment-method .item-radio input','position','relative','','','.b-form'),(900004,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(900005,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(900006,'furniture','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(900007,'furniture','.w-reviews-content .review','position','absolute','3','','.w-reviews-content'),(900009,'furniture','.p-quick-order-index .all-scroll-div','position','fixed','','','.p-quick-order-index'),(900010,'furniture','.w-checkout-billing-address .genders-title input','position','relative','','','.w-checkout-billing-address'),(900011,'furniture','.b-form .required-message-wrap','position','relative','','','.b-form'),(900012,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','position','relative','3','','.b-form'),(900013,'furniture','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(900014,'furniture','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(900015,'furniture','.w-promotions .promo-cart-discount .slave .condition','position','relative','','','.w-promotions'),(900016,'furniture','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(900017,'furniture','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(900019,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(900021,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(900022,'furniture','.w-checkout-credit-amount .btn-remove','position','relative','','','.w-checkout-credit-amount'),(900024,'furniture','.w-promo-code .holder','position','relative','','','.w-promo-code'),(900025,'furniture','.b-info-popup .info-popup','position','relative','3','','.b-info-popup'),(900026,'furniture','.b-autocomplete .ui-autocomplete','position','absolute','','','.b-autocomplete'),(900027,'furniture','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(900028,'furniture','.b-bottom .footerTitle','position','relative','5131','','.b-bottom'),(900029,'furniture','.b-info-popup .info-popup','position','relative','','','.b-info-popup'),(900030,'furniture','.b-upload-files .attach-active-holder .attach-file','position','absolute','','','.b-upload-files'),(900032,'furniture','.w-cart-credit-amount .btn-remove','position','relative','','','.w-cart-credit-amount'),(900033,'furniture','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(900034,'furniture','.b-fancybox .fancybox-close','position','absolute','','','.b-fancybox'),(900035,'furniture','.b-form .required-message','position','absolute','','','.b-form'),(900036,'furniture','.b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner','position','relative','','','.b-fancybox'),(900037,'furniture','.w-product-customers-activity .customers-activity','position','fixed','','','.w-product-customers-activity'),(900038,'furniture','.w-product-customers-activity .close','position','absolute','','','.w-product-customers-activity'),(900040,'furniture','.w-text .customer-service','position','absolute','3','','.w-text'),(900041,'furniture','.w-cart-compare .remove-cart','position','absolute','','','.w-cart-compare'),(900042,'furniture','.w-promo-code .holder','position','relative','','','.w-promo-code'),(900043,'furniture','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(900045,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(900046,'furniture','.w-checkout-billing-address .addresses .address-item label input','position','absolute','','','.w-checkout-billing-address'),(900047,'furniture','.w-checkout-shipping-choice input:checked + span','position','relative','','','.w-checkout-shipping-choice'),(900048,'furniture','.w-checkout-shipping-choice input','position','absolute','','','.w-checkout-shipping-choice'),(900049,'furniture','.w-text .customer-service','position','absolute','3','','.w-text'),(900050,'furniture','.w-quote .cart-box','position','relative','','','.w-quote'),(900051,'furniture','.w-product-reviews .reviews-list span','position','relative','','','.w-product-reviews'),(900052,'furniture','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(900053,'furniture','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(900054,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-select-suggest'),(900055,'furniture','.b-select-suggest .select2-container-multi .select2-choices','position','relative','','','.b-select-suggest'),(900056,'furniture','.b-select-suggest .select2-results','position','relative','','','.b-select-suggest'),(900057,'furniture','.w-image-maps .svg-wrap svg','position','absolute','','','.w-image-maps'),(900058,'furniture','.w-checkout-shipping-address .addresses .address-item label input','position','absolute','','','.w-checkout-shipping-address'),(900059,'furniture','.w-neighbour-checkout .bootstrap-switch','position','relative','','','.w-neighbour-checkout'),(900060,'furniture','.b-select-suggest .select2-search','position','relative','','','.b-select-suggest'),(900061,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow','position','absolute','','','.b-select-suggest'),(900062,'furniture','.b-select-suggest .select2-drop','position','absolute','','','.b-select-suggest'),(900063,'furniture','.b-select-suggest .select2-drop-mask','position','fixed','','','.b-select-suggest'),(900064,'furniture','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(900066,'furniture','.w-text .customer-service','position','relative','','','.w-text'),(900070,'furniture','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(900072,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','position','absolute','','','.b-switch'),(900073,'furniture','.b-pass-strength .pass-strength','position','relative','','','.b-pass-strength'),(900074,'furniture','.p-sample-checkout-success .page-success','position','relative','','','.p-sample-checkout-success'),(900075,'furniture','.w-menu-big li','position','static','','','.w-menu-big'),(900076,'furniture','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(900077,'furniture','.w-promo-code .holder','position','relative','','','.w-promo-code'),(900078,'furniture','.w-account-addresses-list .address-fields input[type=\"radio\"]','position','relative','','','.w-account-addresses-list'),(900079,'furniture','.b-products-listing .products-listing .promos-info','position','absolute','','','.b-products-listing'),(900080,'furniture','.b-products-listing .products-listing .image','position','relative','','','.b-products-listing'),(900081,'furniture','.b-products-listing .hover-box-content','position','absolute','3','','.b-products-listing'),(900082,'furniture','.b-products-listing .hover-box','position','relative','','','.b-products-listing'),(900083,'furniture','.b-products-listing .hover-box-content','position','absolute','','','.b-products-listing'),(900084,'furniture','.b-products-listing .loader','position','absolute','4','','.b-products-listing'),(900085,'furniture','.b-products-listing .loader','position','absolute','3','','.b-products-listing'),(900086,'furniture','.b-products-listing .loader','position','relative','','','.b-products-listing'),(900087,'furniture','.w-catalog-b2b-add-button ','position','fixed','','','.w-catalog-b2b-add-button'),(900088,'furniture','.b-products-listing .products-listing .qty-input.hidden','position','absolute','3','','.b-products-listing'),(900089,'furniture','.b-products-listing .promo','position','absolute','','','.b-products-listing'),(900090,'furniture','.b-products-listing .promo-icon','position','relative','','','.b-products-listing'),(900091,'furniture','.b-products-listing .promos-info','position','relative','','','.b-products-listing'),(900092,'furniture','.checkbox input:not(checked) + span:before','position','absolute','','',''),(900093,'furniture','.checkbox input','position','ablolute','','',''),(900098,'furniture','.w-promo-code .holder','position','relative','','','.w-promo-code'),(900099,'furniture','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(900100,'furniture','.b-form .hide-box','position','relative','','','.b-form'),(900101,'furniture','.b-fancybox .fancybox-title','position','relative','','','.b-fancybox'),(900102,'furniture','.b-fancybox .fancybox-title-float-wrap','position','absolute','','','.b-fancybox'),(900103,'furniture','.w-personal-gift-status-bar .end-date','position','relative','3','','.w-personal-gift-status-bar'),(900104,'furniture','.w-text .customer-service','position','relative','','','.w-text'),(900105,'furniture','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(900106,'furniture','.w-taxable input[type=\"radio\"]','position','relative','','','.w-taxable'),(900107,'furniture','.b-form .eye-password-wrap','position','relative','','','.b-form'),(900108,'furniture','.b-form .eye-password','position','absolute','','','.b-form'),(900109,'furniture','.w-taxable input[type=\"checkbox\"]','position','relative','','','.w-taxable'),(900110,'furniture','.b-fancybox .fancybox-tmp','position','absolute','','','.b-fancybox'),(900111,'furniture','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(900112,'furniture','.b-datepicker .datepicker-dropdown','position','absolute','','','.b-datepicker'),(900113,'furniture','.w-text .customer-service','position','absolute','3','','.w-text'),(900114,'furniture','.w-text .customer-service','position','relative','','','.w-text'),(900115,'furniture','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(900116,'furniture','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(900117,'furniture','.b-form .columns .col-2','position','relative','','','.b-form'),(900118,'furniture','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','position','relative','3','','.order-summary'),(900119,'furniture','.w-cart-compare .atr-col','position','absolute','3','','.w-cart-compare'),(900120,'furniture','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(900121,'furniture','.w-promo-code .holder','position','relative','','','.w-promo-code'),(900122,'furniture','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(900123,'furniture','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(900124,'furniture','.w-menu-horizontal ul ul','position','absolute','','','.w-menu-horizontal'),(900125,'furniture','.w-cart-listing .item .gift-wrap label','position','relative','','','.w-cart-listing'),(900126,'furniture','.w-cart-listing .remove-btn span','position','relative','5140','','.w-cart-listing'),(900127,'furniture','.w-cart-discount-coupon .btn-remove','position','relative','','','.w-cart-discount-coupon'),(900132,'furniture','.w-image-maps .svg-wrap','position','relative','','','.w-image-maps'),(900133,'furniture','.b-fancybox .fancybox-nav span','position','absolute','','','.b-fancybox'),(900134,'furniture','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(900135,'furniture','.w-personal-gift-status-bar .inform','position','relative','4','','.w-personal-gift-status-bar'),(900137,'furniture','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(900138,'furniture','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(900140,'furniture','.w-product-reviews .reviews-list .review','position','absolute','3','','.w-product-reviews'),(900141,'furniture','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(900142,'furniture','.w-filters .input-checkbox','position','absolute','','','.w-filters'),(900143,'furniture','.w-filters .head-filter-widget','position','relative','','','.w-filters'),(900144,'furniture','.b-bottom .pop-up-close','position','absolute','','','.b-bottom'),(900145,'furniture','.w-reviews-content .review','position','relative','','','.w-reviews-content'),(900147,'furniture','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(900148,'furniture','.b-form .same-address','position','relative','','','.b-form'),(900151,'furniture','.w-menu-big ','position','relative','','','.w-menu-big'),(900152,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(900156,'furniture','.w-menu-big > ul > li > ul','position','absolute','','','.w-menu-big'),(900157,'furniture','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(900158,'furniture','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(900159,'furniture','.b-select-suggest .select2-container .select2-choice abbr','position','absolute','','','.b-select-suggest'),(900160,'furniture','.w-filters .mobileCollapse','position','absolute','','','.w-filters'),(900161,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','position','fixed','','','.w-image-maps'),(900162,'furniture','.b-product-images .media-popup .mp-close','position','absolute','','','.b-product-images'),(900163,'furniture','.b-product-images .mp-shadow, .b-product-images .media-popup','position','fixed','','','.b-product-images'),(900164,'furniture','.b-menu-burger_icon .menu-style[data-burger_icon]','position','relative','','','.b-menu-burger_icon'),(900165,'furniture','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-1 > li','position','relative','','','.b-menu-lev_display-down'),(900166,'furniture','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','position','absolute','','','.b-menu-lev_display-down'),(900167,'furniture','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-2 > li','position','relative','','','.b-menu-lev_display-down'),(900168,'furniture','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','position','absolute','','','.b-menu-lev_display-down'),(900169,'furniture','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-3 > li','position','relative','','','.b-menu-lev_display-down'),(900170,'furniture','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','position','absolute','','','.b-menu-lev_display-down'),(900171,'furniture','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-4 > li','position','relative','','','.b-menu-lev_display-down'),(900172,'furniture','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','position','absolute','','','.b-menu-lev_display-down'),(900173,'furniture','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-5 > li','position','relative','','','.b-menu-lev_display-down'),(900174,'furniture','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','position','absolute','','','.b-menu-lev_display-down'),(900175,'furniture','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-1 > li','position','relative','','','.b-menu-lev_display-left'),(900176,'furniture','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','position','absolute','','','.b-menu-lev_display-left'),(900177,'furniture','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-2 > li','position','relative','','','.b-menu-lev_display-left'),(900178,'furniture','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','position','absolute','','','.b-menu-lev_display-left'),(900179,'furniture','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-3 > li','position','relative','','','.b-menu-lev_display-left'),(900180,'furniture','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','position','absolute','','','.b-menu-lev_display-left'),(900181,'furniture','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-4 > li','position','relative','','','.b-menu-lev_display-left'),(900182,'furniture','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','position','absolute','','','.b-menu-lev_display-left'),(900183,'furniture','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-5 > li','position','relative','','','.b-menu-lev_display-left'),(900184,'furniture','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','position','absolute','','','.b-menu-lev_display-left'),(900185,'furniture','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-1 > li','position','relative','','','.b-menu-lev_display-lra'),(900186,'furniture','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','position','absolute','','','.b-menu-lev_display-lra'),(900187,'furniture','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-2 > li','position','relative','','','.b-menu-lev_display-lra'),(900188,'furniture','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','position','absolute','','','.b-menu-lev_display-lra'),(900189,'furniture','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-3 > li','position','relative','','','.b-menu-lev_display-lra'),(900190,'furniture','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','position','absolute','','','.b-menu-lev_display-lra'),(900191,'furniture','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-4 > li','position','relative','','','.b-menu-lev_display-lra'),(900192,'furniture','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','position','absolute','','','.b-menu-lev_display-lra'),(900193,'furniture','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-5 > li','position','relative','','','.b-menu-lev_display-lra'),(900194,'furniture','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','position','absolute','','','.b-menu-lev_display-lra'),(900195,'furniture','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right'),(900196,'furniture','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','position','absolute','','','.b-menu-lev_display-right'),(900197,'furniture','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right'),(900198,'furniture','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','position','absolute','','','.b-menu-lev_display-right'),(900199,'furniture','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right'),(900200,'furniture','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','position','absolute','','','.b-menu-lev_display-right'),(900201,'furniture','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right'),(900202,'furniture','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','position','absolute','','','.b-menu-lev_display-right'),(900203,'furniture','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right'),(900204,'furniture','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','position','absolute','','','.b-menu-lev_display-right'),(900205,'furniture','.b-menu-lev_display-right_top .menu-style[data-lev2_display=\"right_top\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right_top'),(900206,'furniture','.b-menu-lev_display-right_top .menu-style[data-lev3_display=\"right_top\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right_top'),(900207,'furniture','.b-menu-lev_display-right_top .menu-style[data-lev4_display=\"right_top\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right_top'),(900208,'furniture','.b-menu-lev_display-right_top .menu-style[data-lev5_display=\"right_top\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right_top'),(900209,'furniture','.b-menu-lev_display-right_top .menu-style[data-lev6_display=\"right_top\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right_top'),(900210,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .level-1','position','relative','','','.b-menu-lev_display-slide'),(900211,'furniture','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] .level-2','position','relative','','','.b-menu-lev_display-slide'),(900212,'furniture','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','position','absolute','','','.b-menu-lev_display-slide'),(900213,'furniture','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] .level-3','position','relative','','','.b-menu-lev_display-slide'),(900214,'furniture','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','position','absolute','','','.b-menu-lev_display-slide'),(900215,'furniture','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] .level-4','position','relative','','','.b-menu-lev_display-slide'),(900216,'furniture','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','position','absolute','','','.b-menu-lev_display-slide'),(900217,'furniture','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] .level-5','position','relative','','','.b-menu-lev_display-slide'),(900218,'furniture','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','position','absolute','','','.b-menu-lev_display-slide'),(900219,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','position','absolute','','','.b-menu-lev_display-slide'),(900220,'furniture','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width'),(900221,'furniture','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','position','absolute','','','.b-menu-lev_display-width'),(900222,'furniture','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width'),(900223,'furniture','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','position','absolute','','','.b-menu-lev_display-width'),(900224,'furniture','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width'),(900225,'furniture','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','position','absolute','','','.b-menu-lev_display-width'),(900226,'furniture','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width'),(900227,'furniture','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','position','absolute','','','.b-menu-lev_display-width'),(900228,'furniture','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width'),(900229,'furniture','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','position','absolute','','','.b-menu-lev_display-width'),(900230,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width_cont'),(900231,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','position','absolute','','','.b-menu-lev_display-width_cont'),(900232,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width_cont'),(900233,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','position','absolute','','','.b-menu-lev_display-width_cont'),(900234,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width_cont'),(900235,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','position','absolute','','','.b-menu-lev_display-width_cont'),(900236,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width_cont'),(900237,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','position','absolute','','','.b-menu-lev_display-width_cont'),(900238,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width_cont'),(900239,'furniture','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','position','absolute','','','.b-menu-lev_display-width_cont'),(900240,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(900241,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(900242,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(900243,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(900244,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(900245,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','position','fixed','','','.b-menu-open_from-left'),(900246,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','position','static','','','.b-menu-style-2'),(900247,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','position','relative','','','.b-menu-style-2'),(900248,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','position','absolute','3','','.b-menu-style-2'),(900249,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','position','static','','','.b-menu-style-2'),(900250,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','position','relative','','','.b-menu-style-2'),(900251,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','position','absolute','3','','.b-menu-style-2'),(900252,'furniture','.w-catalog-compare .compare .checkbox span','position','relative','','','.w-catalog-compare'),(900254,'furniture','.b-slick .slick-list','position','relative','','','.b-slick'),(900255,'furniture','.b-slick .slick-slider','position','relative','','','.b-slick'),(900256,'furniture','.b-slick .slick-track','position','relative','','','.b-slick'),(900257,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','position','absolute','','','.b-slick'),(900258,'furniture','.menu-header ','position','relative','5140','','.menu-header'),(900259,'furniture','.menu-header .w-menu','position','absolute','5140','','.menu-header'),(900260,'furniture','.header','position','fixed','5140','',''),(900261,'furniture','.b-products-listing .del-from-personal-catalog','position','relative','3','','.b-products-listing'),(900262,'furniture','.cartTitle >div','position','relative','','','.cartTitle'),(900263,'furniture','.cartTitle >div','position','absolute','3','','.cartTitle'),(900264,'furniture','.cartTitle span','position','relative','','','.cartTitle'),(900265,'furniture','.w-cart-listing .item, .w-cart-listing .headings','position','relative','','','.w-cart-listing'),(900266,'furniture','.b-products-listing .products-listing.list-productlisting .item:hover .item-wrapper','position','relative','','','.b-products-listing'),(900267,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','position','absolute','','','.b-products-listing'),(900268,'furniture','.b-products-listing .products-listing .compare .checkbox input:not(checked) + span:before','position','static','','','.b-products-listing'),(900269,'furniture','.w-quote .multicart .item','position','relative','','','.w-quote'),(900270,'furniture','.w-quote .multicart .switch-cart','position','absolute','','','.w-quote'),(900272,'furniture','.w-product-personal-catalog-button .btn','position','relative','3','','.w-product-personal-catalog-button'),(900273,'furniture','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(900274,'furniture','h1, .heading-1','position','relative','3','',''),(900275,'furniture','h1, .heading-1','position','relative','4','',''),(900276,'furniture','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(900277,'furniture','.warrantyProduct .warranty, .warrantyProduct .delivery','position','relative','','','.warrantyProduct'),(900278,'furniture','.warrantyProduct .warranty','position','absolute','3','','.warrantyProduct'),(900279,'furniture','.warrantyProduct .delivery','position','absolute','3','','.warrantyProduct'),(900280,'furniture','.w-compare ','position','fixed','','','.w-compare'),(900281,'furniture','.w-compare .item-holder','position','relative','','','.w-compare'),(900282,'furniture','.w-compare .remove','position','absolute','','','.w-compare'),(900283,'furniture','.w-files-catalog-widgets-files-list .file','position','relative','3','','.w-files-catalog-widgets-files-list'),(900284,'furniture','.w-sample .cart-box','position','relative','','','.w-sample'),(900285,'furniture','.w-sample .cart-box-link','position','relative','','','.w-sample'),(900286,'furniture','.w-sample .multicart .item','position','relative','','','.w-sample'),(900287,'furniture','.w-sample .multicart .switch-cart','position','absolute','','','.w-sample'),(900288,'furniture','.w-sample .qty','position','relative','4','','.w-sample'),(900289,'furniture','.w-quote .cart-box.hover-box .cart-content','position','absolute','','','.w-quote'),(900290,'furniture','.w-sample .cart-box .cart-content','position','absolute','','','.w-sample'),(900291,'furniture','.w-cart-listing .points-earn','position','relative','','','.w-cart-listing'),(900292,'furniture','.w-cart-listing .points-earn','position','absolute','4','','.w-cart-listing'),(900293,'furniture','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(900294,'furniture','.w-product-inventory input[type=\"radio\"]','position','relative','','','.w-product-inventory'),(900296,'furniture','.heading-2','position','relative','3','',''),(900297,'furniture','.heading-2','position','relative','4','',''),(900298,'furniture','.w-product-properties-filters-widgets-chosen-filters .remove','position','relative','3','','.w-product-properties-filters-widgets-chosen-filters'),(900299,'furniture','.p-quote-checkout-index .order-summary .heading-2','position','relative','3','','.p-quote-checkout-index'),(900300,'furniture','.p-quote-checkout-index .order-summary .heading-2','position','relative','4','','.p-quote-checkout-index'),(900301,'furniture','.p-sample-checkout-index .order-summary .heading-2','position','relative','3','','.p-sample-checkout-index'),(900302,'furniture','.p-sample-checkout-index .order-summary .heading-2','position','relative','4','','.p-sample-checkout-index'),(900303,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','position','relative','','','.w-account-personal-catalog'),(900304,'furniture','.w-account-personal-catalog .list-row-action ul','position','relative','','','.w-account-personal-catalog'),(900305,'furniture','.w-account-personal-catalog .list-row-action ul','position','absolute','4','','.w-account-personal-catalog'),(900306,'furniture','.w-account-personal-catalog .checkbox input:not(checked) + span:before','position','static','','','.w-account-personal-catalog'),(900307,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input','position','absolute','','','.w-questionnaire-widgets-questionnaire'),(900308,'furniture','.w-product-groups .radioBox label','position','relative','','','.w-product-groups'),(900309,'furniture','.w-product-groups .radioBox label input','position','absolute','','','.w-product-groups'),(900310,'furniture','.w-sale-category .badge','position','absolute','','','.w-sale-category'),(900311,'furniture','.w-sale-category .sale-holder','position','relative','','','.w-sale-category'),(900312,'furniture','.w-product-bonus-points .bonus-points-cost','position','relative','','','.w-product-bonus-points'),(900313,'furniture','.w-product-bonus-points > div > div','position','absolute','3','','.w-product-bonus-points'),(900314,'furniture','.w-product-designer-designer .prodDesignerType label','position','relative','','','.w-product-designer-designer'),(900315,'furniture','.w-product-designer-designer .productDesignerBox input','position','absolute','','','.w-product-designer-designer'),(900316,'furniture','.w-press-reviews-widgets-press-reviews .review','position','relative','','','.w-press-reviews-widgets-press-reviews'),(900317,'furniture','.w-support-system-listing .support-head','position','relative','','','.w-support-system-listing'),(900318,'furniture','.w-product-configurator .pc-item label','position','relative','','','.w-product-configurator'),(900319,'furniture','.w-product-configurator .pc-item label input','position','absolute','','','.w-product-configurator'),(900320,'furniture','.b-products-listing .products-listing .bonus-points-cost','position','absolute','3','','.b-products-listing'),(900321,'furniture','.b-products-listing .products-listing .bonus-points-cost','position','relative','','','.b-products-listing'),(900322,'furniture','.w-predefined-promotion .icon','position','relative','','','.w-predefined-promotion'),(900323,'furniture','.w-predefined-promotion .prom-multi-discount .products','position','relative','','','.w-predefined-promotion'),(900324,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','position','relative','','','.w-predefined-promotion'),(900325,'furniture','.w-predefined-promotion .prom-multi-discount > .heading','position','relative','3','','.w-predefined-promotion'),(900326,'furniture','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','position','relative','3','','.w-predefined-promotion'),(900327,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','position','relative','','','.w-predefined-promotion'),(900328,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition','position','relative','','','.w-predefined-promotion'),(900329,'furniture','.w-predefined-promotion .promo-cart-discount .slave .content','position','relative','','','.w-predefined-promotion'),(900330,'furniture','.w-predefined-promotion .promo-date','position','relative','','','.w-predefined-promotion'),(900331,'furniture','.w-predefined-promotion .promo-salemaker .discount','position','relative','','','.w-predefined-promotion'),(900332,'furniture','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','position','relative','3','','.w-predefined-promotion'),(900333,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','position','absolute','','','.w-filters'),(900334,'furniture','.mainBanner .title','position','absolute','3','','.mainBanner'),(900335,'furniture','.mainBanner .title','position','relative','','','.mainBanner'),(900336,'furniture','.mainBanner .topBox > .right','position','relative','','','.mainBanner'),(900337,'furniture','.mainBanner .topBox > .right','position','absolute','4','','.mainBanner'),(900338,'furniture','.mainBanner .banner-item','position','relative','','','.mainBanner'),(900339,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','position','absolute','','','.mainBanner'),(900340,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','position','absolute','','','.mainBanner'),(900341,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','position','absolute','','','.mainBanner'),(900342,'furniture','.order-summary .icon','position','absolute','3','','.order-summary'),(900343,'furniture','.order-summary .icon','position','relative','','','.order-summary'),(900344,'furniture','.w-cart-discount-coupon .title','position','relative','','','.w-cart-discount-coupon'),(900375,'furniture','.account-order-pay .account_history_info.account_history_info_due','position','relative','','','.account-order-pay'),(900376,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','position','relative','','','.account-order-pay'),(900377,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','position','absolute','3','','.account-order-pay'),(900378,'furniture','.account-order-pay .not_fully_paid_td','position','absolute','','','.account-order-pay'),(900379,'furniture','.account-samples .moduleRowDue td','position','relative','','','.account-samples'),(900380,'furniture','.account-samples .not_fully_paid_td','position','absolute','','','.account-samples'),(900381,'furniture','.account-samples .view_link','position','relative','','','.account-samples'),(900382,'furniture','.account-samples .view_link','position','absolute','4','','.account-samples'),(900383,'furniture','.account-samples .orders-table .item','position','relative','5140','','.account-samples'),(900384,'furniture','.account-samples .orders-table .order-total','position','absolute','5140','','.account-samples'),(900385,'furniture','.account-samples .orders-table .status-name','position','absolute','5140','','.account-samples'),(900386,'furniture','.account-samples .orders-table .td-alignright','position','absolute','5140','','.account-samples'),(900387,'furniture','.account-sample-info .account_history_info.account_history_info_due','position','relative','','','.account-sample-info'),(900388,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','position','relative','','','.account-sample-info'),(900389,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','position','absolute','3','','.account-sample-info'),(900390,'furniture','.account-sample-info .not_fully_paid_td','position','absolute','','','.account-sample-info'),(900391,'furniture','.catalog-product-wrap .pn-image','position','absolute','3','','.catalog-product-wrap'),(900392,'furniture','.catalog-product-wrap .prev-next-product','position','fixed','','','.catalog-product-wrap'),(900393,'furniture','.checkout-index-wrap .order-ico','position','relative','3','','.checkout-index-wrap'),(900394,'furniture','.checkout-index-wrap .order-summary .heading-2','position','relative','3','','.checkout-index-wrap'),(900395,'furniture','.checkout-index-wrap .order-summary .heading-2','position','relative','4','','.checkout-index-wrap'),(900396,'furniture','.checkout-order-confirmation .comment-ico','position','relative','3','','.checkout-order-confirmation'),(900397,'furniture','.checkout-order-confirmation .discount-ico','position','relative','3','','.checkout-order-confirmation'),(900398,'furniture','.checkout-order-confirmation .order-ico','position','relative','3','','.checkout-order-confirmation'),(900399,'furniture','.checkout-success-wrap .page-success','position','relative','','','.checkout-success-wrap'),(900400,'furniture','.checkout-success-wrap .page-success > div','position','relative','','','.checkout-success-wrap'),(900401,'furniture','.shopping-cart-index .gift-code .heading-4','position','absolute','4','','.shopping-cart-index'),(900402,'furniture','.shopping-cart-index .gift-code .heading-4','position','relative','5131','','.shopping-cart-index'),(900403,'furniture','.b-form .addresses .address-item','position','relative','','','.b-form'),(900404,'furniture','.b-info .info','position','relative','','','.b-info'),(900405,'furniture','.b-info .info','position','relative','3','','.b-info'),(900406,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','position','relative','4','','.b-multi-page-checkout'),(900407,'furniture','.success-page .comment-ico','position','relative','3','','.success-page'),(900408,'furniture','.success-page .discount-ico','position','relative','3','','.success-page'),(900409,'furniture','.success-page .order-ico','position','relative','3','','.success-page'),(900410,'furniture','.success-page .page-success','position','relative','','','.success-page'),(900411,'furniture','.success-page .page-success .text-1','position','relative','','','.success-page'),(900412,'furniture','.success-page .page-success > div','position','relative','','','.success-page'),(900413,'furniture','.success-page .w-cart-listing .qty','position','relative','','','.success-page'),(900414,'furniture','.preFooter .w-banner .banner-image picture img','position','static','','','.preFooter'),(900415,'furniture','.b-products-listing .products-listing.list-productlisting .item-content','position','relative','','','.b-products-listing'),(900416,'furniture','.menu-header .menu-style[data-style=\"1\"] .goto-button','position','absolute','','','.menu-header'),(900417,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','position','relative','','','.menu-header'),(900418,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','position','relative','5140','','.footer-menu'),(900419,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','position','absolute','5140,3','','.footer-menu'),(900420,'furniture','.tripleBanner .w-html_box','position','relative','','','.tripleBanner'),(900421,'furniture','.tripleBanner .w-html_box','position','absolute','3','','.tripleBanner'),(900422,'furniture','.w-banner .banner','position','relative','','','.w-banner'),(900423,'furniture','.w-banner .banner img + img','position','absolute','','','.w-banner'),(900424,'furniture','.w-banner .carousel .item','position','relative','','','.w-banner'),(900425,'furniture','.w-banner .carousel-text','position','absolute','','','.w-banner'),(900426,'furniture','.w-banner .image-text-banner','position','relative','','','.w-banner'),(900427,'furniture','.w-banner .image-text-banner .text-banner','position','absolute','','','.w-banner'),(900428,'furniture','.w-catalog-paging .paging-holder','position','relative','','','.w-catalog-paging'),(900429,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','position','static','','','.w-catalog-paging'),(900430,'furniture','.w-compare-box-item .checkbox:not(checked)','position','absolute','','','.w-compare-box-item'),(900431,'furniture','.w-compare-box-item .checkbox:not(checked) + span','position','relative','','','.w-compare-box-item'),(900432,'furniture','.w-compare-box-item .checkbox:not(checked) + span:before','position','absolute','','','.w-compare-box-item'),(900433,'furniture','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position_important','important','','','.b-switch'),(900435,'furniture','.b-autocomplete .ui-autocomplete','position_important','important','','','.b-autocomplete'),(900438,'furniture','.w-checkout-billing-address .addresses .address-item label input','position_important','important','','','.w-checkout-billing-address'),(900439,'furniture','.w-checkout-shipping-address .addresses .address-item label input','position_important','important','','','.w-checkout-shipping-address'),(900441,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position_important','important','','','.b-select-suggest'),(900444,'furniture','.w-socials .post_item > div','right','10','3','','.w-socials'),(900446,'furniture','.b-upload-file .snapshot','right','5','','','.b-upload-file'),(900447,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-remove','right','5','','','.w-upload-customer-id-upload-customer-id-form'),(900448,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','right','0','','','.b-switch'),(900449,'furniture','.w-cart-compare .dropdown .dropdown-menu','right','0','','','.w-cart-compare'),(900450,'furniture','.closeable-heading','right','20','3','',''),(900451,'furniture','.b-bottom .footerTitle','right','0','5131,4','','.b-bottom'),(900452,'furniture','.w-socials .post_item > div','right','10','3','','.w-socials'),(900453,'furniture','.b-info-popup .info-popup.top-left div','right','13','3','','.b-info-popup'),(900455,'furniture','.w-socials .post_item > div','right','10','3','','.w-socials'),(900456,'furniture','.w-socials .post_item > div','right','10','3','','.w-socials'),(900457,'furniture','.w-cart-compare .atr-col','right','0','3','','.w-cart-compare'),(900458,'furniture','.w-multi-cart-actions .dropdown .dropdown-menu','right','auto','','','.w-multi-cart-actions'),(900459,'furniture','.w-socials .post_item > div','right','10','3','','.w-socials'),(900460,'furniture','.b-pass-strength .pass-strength span','right','25','','','.b-pass-strength'),(900461,'furniture','.b-info-popup .info-popup.top-left div','right','-10','','','.b-info-popup'),(900462,'furniture','.b-fancybox .fancybox-overlay-fixed','right','0','','','.b-fancybox'),(900463,'furniture','.w-cart-compare .remove-cart','right','0','','','.w-cart-compare'),(900464,'furniture','.b-fancybox .fancybox-close','right','10','','','.b-fancybox'),(900465,'furniture','.b-fancybox .fancybox-next','right','0','','','.b-fancybox'),(900466,'furniture','.b-fancybox .fancybox-next span','right','10','','','.b-fancybox'),(900467,'furniture','.w-product-customers-activity .customers-activity','right','20','','','.w-product-customers-activity'),(900468,'furniture','.w-product-customers-activity .close','right','5','','','.w-product-customers-activity'),(900469,'furniture','.b-select-suggest .select2-search-choice-close','right','3','','','.b-select-suggest'),(900470,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow','right','0','','','.b-select-suggest'),(900472,'furniture','.b-fancybox .fancybox-title-float-wrap','right','50','','','.b-fancybox'),(900473,'furniture','.b-form .eye-password','right','5','','','.b-form'),(900475,'furniture','.b-upload-file .upload-remove','right','10','','','.b-upload-file'),(900476,'furniture','.w-socials .post_item > div','right','10','3','','.w-socials'),(900478,'furniture','.b-bottom .pop-up-close','right','6','','','.b-bottom'),(900479,'furniture','.w-menu-big > ul > li > ul','right','0','','','.w-menu-big'),(900480,'furniture','.b-select-suggest .select2-container .select2-choice abbr','right','24','','','.b-select-suggest'),(900481,'furniture','.w-filters .mobileCollapse','right','12','','','.w-filters'),(900482,'furniture','.b-product-images .media-popup .mp-close','right','20','','','.b-product-images'),(900483,'furniture','.b-product-images .mp-shadow, .b-product-images .media-popup','right','0','','','.b-product-images'),(900484,'furniture','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right','100','','','.b-menu-lev_display-left'),(900485,'furniture','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right','100','','','.b-menu-lev_display-left'),(900486,'furniture','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right','100','','','.b-menu-lev_display-left'),(900487,'furniture','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right','100','','','.b-menu-lev_display-left'),(900488,'furniture','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right','100','','','.b-menu-lev_display-left'),(900489,'furniture','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right','100','','','.b-menu-lev_display-lra'),(900490,'furniture','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right','100','','','.b-menu-lev_display-lra'),(900491,'furniture','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right','100','','','.b-menu-lev_display-lra'),(900492,'furniture','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right','100','','','.b-menu-lev_display-lra'),(900493,'furniture','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right','100','','','.b-menu-lev_display-lra'),(900494,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','right','10','3','','.b-menu-style-2'),(900495,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .parent > .no-link','right','40','3','','.b-menu-style-2'),(900496,'furniture','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','right','auto','','','.b-slick'),(900497,'furniture','.b-slick button.slick-next','right','0','','','.b-slick'),(900498,'furniture','.b-slick button.slick-prev','right','auto','','','.b-slick'),(900499,'furniture','.menu-header .w-menu','right','10','5140','','.menu-header'),(900500,'furniture','.header','right','0','5140','',''),(900501,'furniture','.cartTitle >div','right','0','3','','.cartTitle'),(900502,'furniture','h1, .heading-1','right','-14','4','',''),(900503,'furniture','.w-compare ','right','0','','','.w-compare'),(900504,'furniture','.w-compare .remove','right','20','','','.w-compare'),(900505,'furniture','.w-cart-listing .points-earn','right','-12','4','','.w-cart-listing'),(900506,'furniture','.heading-2','right','-14','4','',''),(900507,'furniture','.p-quote-checkout-index .order-summary .heading-2','right','-14','4','','.p-quote-checkout-index'),(900508,'furniture','.p-sample-checkout-index .order-summary .heading-2','right','-14','4','','.p-sample-checkout-index'),(900509,'furniture','.w-account-personal-catalog .list-row-action ul','right','7','4','','.w-account-personal-catalog'),(900510,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','right','-100','','','.w-product-properties-icons'),(900511,'furniture','.w-product-bonus-points .bonus-points-cost','right','-14','5161,4','','.w-product-bonus-points'),(900512,'furniture','.mainBanner .topBox > .right','right','-18','4','','.mainBanner'),(900513,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','right','0','','','.mainBanner'),(900514,'furniture','.order-summary .icon','right','0','3','','.order-summary'),(900519,'furniture','.account-samples .orders-table .order-total','right','0','5140','','.account-samples'),(900520,'furniture','.catalog-product-wrap .next-product','right','0','','','.catalog-product-wrap'),(900521,'furniture','.catalog-product-wrap .next-product .pn-image','right','20','3','','.catalog-product-wrap'),(900522,'furniture','.checkout-index-wrap .order-summary .heading-2','right','-14','4','','.checkout-index-wrap'),(900523,'furniture','.shopping-cart-index .gift-code .heading-4','right','0','4','','.shopping-cart-index'),(900524,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','right','10','5140,3','','.footer-menu'),(900525,'furniture','.w-banner .image-text-banner.bottom-right .text-banner','right','0','','','.w-banner'),(900526,'furniture','.w-banner .image-text-banner.middle-right .text-banner','right','0','','','.w-banner'),(900527,'furniture','.w-banner .image-text-banner.top-right .text-banner','right','0','','','.w-banner'),(900528,'furniture','.b-fancybox .fancybox-title-float-wrap','right_measure','%','','','.b-fancybox'),(900529,'furniture','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right_measure','%','','','.b-menu-lev_display-left'),(900530,'furniture','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right_measure','%','','','.b-menu-lev_display-left'),(900531,'furniture','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right_measure','%','','','.b-menu-lev_display-left'),(900532,'furniture','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right_measure','%','','','.b-menu-lev_display-left'),(900533,'furniture','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right_measure','%','','','.b-menu-lev_display-left'),(900534,'furniture','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right_measure','%','','','.b-menu-lev_display-lra'),(900535,'furniture','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right_measure','%','','','.b-menu-lev_display-lra'),(900536,'furniture','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right_measure','%','','','.b-menu-lev_display-lra'),(900537,'furniture','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right_measure','%','','','.b-menu-lev_display-lra'),(900538,'furniture','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right_measure','%','','','.b-menu-lev_display-lra'),(900539,'furniture','.b-info-popup .info-popup.top-left div','rotate','-135','3','','.b-info-popup'),(900540,'furniture','.w-checkout-shipping-choice input:checked + span:before','rotate','45','','','.w-checkout-shipping-choice'),(900541,'furniture','.b-info-popup .info-popup div','rotate','-45','3','','.b-info-popup'),(900544,'furniture','.w-sample .cart-box-link','rotate','45','4','','.w-sample'),(900545,'furniture','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','stroke-width','0','','','.w-image-maps'),(900546,'furniture','.w-image-maps rect:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(900547,'furniture','.w-image-maps circle:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(900548,'furniture','.w-image-maps polygon:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(900549,'furniture','.w-tabs .tab-navigation','table-layout','fixed','','','.w-tabs'),(900550,'furniture','.w-communication-new-topic .orders-id','text-align','center','','','.w-communication-new-topic'),(900551,'furniture','.w-communication-new-topic .model','text-align','center','','','.w-communication-new-topic'),(900552,'furniture','.w-communication-new-topic .date-purchased','text-align','right','','','.w-communication-new-topic'),(900553,'furniture','.w-communication-new-topic .quantity','text-align','center','','','.w-communication-new-topic'),(900554,'furniture','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(900555,'furniture','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(900556,'furniture','.w-product-wishlist-button .btn','text-align','center','5131','','.w-product-wishlist-button'),(900557,'furniture','.b-email .price','text-align','right','','','.b-email'),(900558,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.p-quick-order-index'),(900559,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.p-quick-order-index'),(900560,'furniture','.w-promotions .promo-date','text-align','center','','','.w-promotions'),(900561,'furniture','.w-promotions .promo-item','text-align','center','','','.w-promotions'),(900563,'furniture','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(900565,'furniture','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(900566,'furniture','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(900567,'furniture','.b-email .heading-model','text-align','center','','','.b-email'),(900568,'furniture','.w-categories .item','text-align','center','','','.w-categories'),(900569,'furniture','.w-promotions .prom-multi-discount .heading','text-align','center','','','.w-promotions'),(900570,'furniture','.b-products-listing .products-listing .btn-preloader','text-align','center','','','.b-products-listing'),(900571,'furniture','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(900572,'furniture','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(900573,'furniture','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(900574,'furniture','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(900575,'furniture','.b-messages .development-content','text-align','left','','','.b-messages'),(900576,'furniture','.b-messages .msv_to_cc, .b-messages .msv_btn','text-align','left','','','.b-messages'),(900577,'furniture','.b-messages .msv_content','text-align','left','','','.b-messages'),(900578,'furniture','.b-messages .msv_history','text-align','left','','','.b-messages'),(900579,'furniture','.b-messages .attach-view','text-align','left','','','.b-messages'),(900580,'furniture','.b-messages .messages-sidebar .heading-2','text-align','center','','','.b-messages'),(900581,'furniture','.b-messages .messages-sidebar .btn-2','text-align','center','','','.b-messages'),(900582,'furniture','.b-messages .emailBtn','text-align','right','','','.b-messages'),(900583,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','text-align','left','','','.b-messages'),(900584,'furniture','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(900585,'furniture','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align','left','','','.p-quick-order-index'),(900586,'furniture','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(900587,'furniture','.w-checkout-terms .terms-box','text-align','left','','','.w-checkout-terms'),(900588,'furniture','.w-checkout-terms .required-message','text-align','left','','','.w-checkout-terms'),(900589,'furniture','.b-email .heading-model','text-align','center','','','.b-email'),(900590,'furniture','.b-email .heading-qty','text-align','center','','','.b-email'),(900591,'furniture','.b-email .heading-price','text-align','right','','','.b-email'),(900592,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','text-align','center','','','.b-switch'),(900593,'furniture','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(900594,'furniture','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(900595,'furniture','.order-summary .price-box .title','text-align','left','','','.order-summary'),(900596,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','text-align','center','','','.w-upload-customer-id-upload-customer-id-form'),(900597,'furniture','.b-switch .bootstrap-switch','text-align','left','','','.b-switch'),(900598,'furniture','.b-page-name .page-name','text-align','center','','','.b-page-name'),(900599,'furniture','.b-email .totals-label','text-align','right','','','.b-email'),(900600,'furniture','.w-coupons-and-vauchers-checkout .btn-remove','text-align','center','','','.w-coupons-and-vauchers-checkout'),(900601,'furniture','.w-checkout-bonus-points .btn-remove','text-align','center','','','.w-checkout-bonus-points'),(900602,'furniture','.w-login-block .buttons','text-align','right','','','.w-login-block'),(900603,'furniture','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(900604,'furniture','.b-email .heading-qty','text-align','center','','','.b-email'),(900605,'furniture','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(900606,'furniture','.b-email .totals-value','text-align','right','','','.b-email'),(900607,'furniture','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(900608,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','text-align','center','','','.b-switch'),(900609,'furniture','.b-email .totals-value','text-align','right','','','.b-email'),(900610,'furniture','.b-email .qty','text-align','center','','','.b-email'),(900611,'furniture','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(900612,'furniture','.pop-up-content .buttons .btn-2','text-align','center','5140','',''),(900613,'furniture','.pop-up-content .buttons .btn','text-align','center','5140','',''),(900614,'furniture','.no-found','text-align','center','','',''),(900615,'furniture','.w-login-block .buttons','text-align','right','','','.w-login-block'),(900616,'furniture','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(900617,'furniture','.p-quick-order-index .all-scroll-div td + td','text-align','right','','','.p-quick-order-index'),(900618,'furniture','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(900619,'furniture','.b-email-editor .price','text-align','center','','','.b-email-editor'),(900620,'furniture','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(900621,'furniture','.b-email .model','text-align','center','','','.b-email'),(900622,'furniture','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(900623,'furniture','.b-form .wedding-form .heading-2','text-align','left','','','.b-form'),(900624,'furniture','.b-email .heading-price','text-align','right','','','.b-email'),(900625,'furniture','.b-email .price','text-align','right','','','.b-email'),(900626,'furniture','.w-top-categories .categories','text-align','center','','','.w-top-categories'),(900627,'furniture','.b-page-name .page-name','text-align','center','','','.b-page-name'),(900628,'furniture','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(900629,'furniture','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(900630,'furniture','.b-page-name .page-name','text-align','center','','','.b-page-name'),(900631,'furniture','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(900632,'furniture','.b-email .heading-qty','text-align','center','','','.b-email'),(900633,'furniture','.w-tabs .tab-a','text-align','center','','','.w-tabs'),(900634,'furniture','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(900635,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','text-align','center','','','.b-switch'),(900636,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-label','text-align','center','','','.b-switch'),(900637,'furniture','.b-social-login .social-login','text-align','center','','','.b-social-login'),(900638,'furniture','.b-page-name .page-name','text-align','center','','','.b-page-name'),(900639,'furniture','.b-email .price','text-align','right','','','.b-email'),(900640,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','text-align','center','','','.b-switch'),(900641,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','text-align','center','','','.b-switch'),(900642,'furniture','.b-email .totals-title','text-align','right','','','.b-email'),(900643,'furniture','.b-email .heading-model','text-align','center','','','.b-email'),(900644,'furniture','.b-email .totals-label','text-align','right','','','.b-email'),(900645,'furniture','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(900646,'furniture','.b-email .totals-value','text-align','right','','','.b-email'),(900647,'furniture','.w-cart-bonus-points .bonus_points_amount','text-align','center','','','.w-cart-bonus-points'),(900648,'furniture','.w-cart-bonus-points .btn-remove','text-align','center','','','.w-cart-bonus-points'),(900649,'furniture','.w-cart-credit-amount input','text-align','center','','','.w-cart-credit-amount'),(900650,'furniture','.b-email .heading-qty','text-align','center','','','.b-email'),(900651,'furniture','.w-reviews .date','text-align','right','','','.w-reviews'),(900652,'furniture','.w-top-categories .item','text-align','center','','','.w-top-categories'),(900653,'furniture','.w-reviews-content .product-image','text-align','center','','','.w-reviews-content'),(900654,'furniture','.b-email .model','text-align','center','','','.b-email'),(900655,'furniture','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(900656,'furniture','.b-email .heading-price','text-align','right','','','.b-email'),(900657,'furniture','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(900658,'furniture','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(900659,'furniture','.b-email .heading-price','text-align','right','','','.b-email'),(900660,'furniture','.b-email .price','text-align','right','','','.b-email'),(900661,'furniture','.b-email .totals-title','text-align','right','','','.b-email'),(900662,'furniture','.b-email .totals-value','text-align','right','','','.b-email'),(900663,'furniture','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(900664,'furniture','.b-email .heading-model','text-align','center','','','.b-email'),(900665,'furniture','.b-email .qty','text-align','center','','','.b-email'),(900666,'furniture','.b-email .model','text-align','center','','','.b-email'),(900667,'furniture','.b-email .totals-label','text-align','right','','','.b-email'),(900668,'furniture','.b-email .heading-qty','text-align','center','','','.b-email'),(900669,'furniture','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(900670,'furniture','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(900671,'furniture','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(900672,'furniture','.b-form .center-buttons','text-align','center','','','.b-form'),(900673,'furniture','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(900674,'furniture','.w-reviews .product-image','text-align','center','','','.w-reviews'),(900675,'furniture','.b-sub-totals .historyTotal table td','text-align','right','','','.b-sub-totals'),(900676,'furniture','.b-social-login .social-login','text-align','center','','','.b-social-login'),(900677,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','text-align','center','3','','.b-switch'),(900679,'furniture','.b-social-login .social-login','text-align','center','','','.b-social-login'),(900680,'furniture','.w-login-block .buttons','text-align','right','','','.w-login-block'),(900681,'furniture','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(900682,'furniture','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','text-align','center','','','.p-quick-order-index'),(900683,'furniture','.w-cart-checkout-btn a','text-align','center','5131','','.w-cart-checkout-btn'),(900684,'furniture','.w-categories .categories','text-align','center','','','.w-categories'),(900685,'furniture','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(900686,'furniture','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(900687,'furniture','.w-login-block .buttons','text-align','right','','','.w-login-block'),(900688,'furniture','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(900689,'furniture','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(900690,'furniture','.view-all','text-align','center','','',''),(900691,'furniture','.b-page-name .page-name','text-align','center','','','.b-page-name'),(900692,'furniture','.b-form .message.error','text-align','center','','','.b-form'),(900693,'furniture','.b-email .qty','text-align','center','','','.b-email'),(900694,'furniture','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','text-align','center','3','','.w-checkout-contact-information'),(900695,'furniture','.b-email .model','text-align','center','','','.b-email'),(900696,'furniture','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','text-align','center','3','','.w-checkout-contact-information'),(900697,'furniture','.w-product-wishlist-button .btn','text-align','center','5131','','.w-product-wishlist-button'),(900698,'furniture','.b-email .heading-qty','text-align','center','','','.b-email'),(900699,'furniture','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(900700,'furniture','.b-email .totals-value','text-align','right','','','.b-email'),(900701,'furniture','.w-product-wishlist-button .btn','text-align','center','5131','','.w-product-wishlist-button'),(900702,'furniture','.b-bottom .cart-options .js-carts','text-align','center','','','.b-bottom'),(900703,'furniture','.b-bottom .cart-options .heading-4','text-align','center','','','.b-bottom'),(900704,'furniture','.b-bottom .cart-options .heading-3','text-align','center','','','.b-bottom'),(900705,'furniture','.b-bottom .cart-options .buttons','text-align','center','','','.b-bottom'),(900706,'furniture','.b-bottom .alert-message','text-align','center','','','.b-bottom'),(900707,'furniture','.w-checkout-credit-amount .btn-remove','text-align','center','','','.w-checkout-credit-amount'),(900708,'furniture','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(900709,'furniture','.b-products-listing .btn-choose-options','text-align','center','','','.b-products-listing'),(900710,'furniture','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(900711,'furniture','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(900712,'furniture','.w-product-wishlist-button .btn','text-align','center','5131','','.w-product-wishlist-button'),(900713,'furniture','.b-email-editor .price','text-align','center','','','.b-email-editor'),(900714,'furniture','.b-email .qty','text-align','center','','','.b-email'),(900715,'furniture','.b-email-editor .price','text-align','center','','','.b-email-editor'),(900717,'furniture','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(900718,'furniture','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(900719,'furniture','.order-summary .price-row.ot_gv .title','text-align','center','3','','.order-summary'),(900720,'furniture','.w-cart-credit-amount .btn-remove','text-align','center','','','.w-cart-credit-amount'),(900721,'furniture','.b-email .qty','text-align','center','','','.b-email'),(900722,'furniture','.b-email-editor .price','text-align','center','','','.b-email-editor'),(900723,'furniture','.b-fancybox .fancybox-close','text-align','center','','','.b-fancybox'),(900724,'furniture','.w-product-customers-activity .customers-activity','text-align','center','','','.w-product-customers-activity'),(900725,'furniture','.w-product-customers-activity .close','text-align','center','','','.w-product-customers-activity'),(900726,'furniture','.b-bottom .confirm-popup .buttons','text-align','center','','','.b-bottom'),(900727,'furniture','.b-bottom .confirm-popup .confirm-text','text-align','center','','','.b-bottom'),(900728,'furniture','.b-email .totals-title','text-align','right','','','.b-email'),(900729,'furniture','.b-email .totals-label','text-align','right','','','.b-email'),(900730,'furniture','.b-email .price','text-align','right','','','.b-email'),(900731,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','text-align','center','3','','.b-switch'),(900732,'furniture','.w-quote-products .empty','text-align','center','','','.w-quote-products'),(900733,'furniture','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(900734,'furniture','.w-menu-horizontal .menu-ico','text-align','center','','','.w-menu-horizontal'),(900735,'furniture','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(900736,'furniture','.w-checkout-credit-amount .cot_gv_amount','text-align','center','','','.w-checkout-credit-amount'),(900737,'furniture','.w-checkout-bonus-points .bonus_points_amount','text-align','center','','','.w-checkout-bonus-points'),(900738,'furniture','.w-product-wishlist-button .btn','text-align','center','5131','','.w-product-wishlist-button'),(900739,'furniture','.b-page-name .page-name','text-align','center','','','.b-page-name'),(900740,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-align','left','','','.b-switch'),(900741,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-align','right','','','.b-switch'),(900742,'furniture','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(900743,'furniture','.b-social-login .social-login','text-align','center','','','.b-social-login'),(900744,'furniture','.b-products-listing .products-listing .buyButton .btn','text-align','center','','','.b-products-listing'),(900746,'furniture','.w-menu-big li li li','text-align','left','','','.w-menu-big'),(900747,'furniture','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(900748,'furniture','.w-menu-horizontal .box','text-align','center','','','.w-menu-horizontal'),(900749,'furniture','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(900750,'furniture','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(900751,'furniture','.b-social-login .social-login','text-align','center','','','.b-social-login'),(900752,'furniture','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(900753,'furniture','.w-login-block .buttons','text-align','right','','','.w-login-block'),(900754,'furniture','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(900755,'furniture','.w-cart-listing .links','text-align','center','','','.w-cart-listing'),(900756,'furniture','.w-product-wishlist-button .btn','text-align','center','5131','','.w-product-wishlist-button'),(900757,'furniture','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(900758,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.b-data-table'),(900759,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.b-data-table'),(900760,'furniture','.w-communication-post .communication-post-attach','text-align','right','','','.w-communication-post'),(900761,'furniture','.b-products-listing .products-listing .image','text-align','center','','','.b-products-listing'),(900762,'furniture','.b-products-listing .products-listing','text-align','center','','','.b-products-listing'),(900763,'furniture','.b-products-listing .products-listing .btn-buy','text-align','center','','','.b-products-listing'),(900764,'furniture','.w-catalog-b2b-add-button .b2b-add-box-wrap','text-align','right','','','.w-catalog-b2b-add-button'),(900765,'furniture','.b-products-listing .products-listing .properties','text-align','left','','','.b-products-listing'),(900766,'furniture','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','text-align','left','','','.b-products-listing'),(900767,'furniture','.b-products-listing .show-ofstock-products','text-align','center','','','.b-products-listing'),(900768,'furniture','.checkbox input:checked + span:before','text-align','center','','',''),(900769,'furniture','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(900770,'furniture','.p-sample-checkout-success .page-success','text-align','center','','','.p-sample-checkout-success'),(900771,'furniture','.b-products-listing .products-listing .in-cart','text-align','center','','','.b-products-listing'),(900772,'furniture','.b-email-editor .price','text-align','center','','','.b-email-editor'),(900773,'furniture','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(900774,'furniture','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','text-align','center','3','','.w-checkout-contact-information'),(900775,'furniture','.b-fancybox .fancybox-title-float-wrap','text-align','center','','','.b-fancybox'),(900776,'furniture','.b-email .model','text-align','center','','','.b-email'),(900778,'furniture','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(900779,'furniture','.order-summary .price-row.ot_coupon .title','text-align','center','3','','.order-summary'),(900780,'furniture','h1, .heading-1','text-align','center','','',''),(900781,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','text-align','center','','','.w-communication-new-topic'),(900782,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','text-align','center','','','.w-communication-new-topic'),(900783,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(5), .w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(7)','text-align','center','','','.w-communication-new-topic'),(900784,'furniture','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(900785,'furniture','.b-email .heading-model','text-align','center','','','.b-email'),(900787,'furniture','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(900788,'furniture','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(900789,'furniture','.b-email .model','text-align','center','','','.b-email'),(900790,'furniture','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(900791,'furniture','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(900792,'furniture','.b-email .totals-title','text-align','right','','','.b-email'),(900793,'furniture','.b-email .heading-price','text-align','right','','','.b-email'),(900794,'furniture','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(900796,'furniture','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(900797,'furniture','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(900798,'furniture','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(900799,'furniture','.b-email .totals-label','text-align','right','','','.b-email'),(900800,'furniture','.b-email .totals-title','text-align','right','','','.b-email'),(900801,'furniture','.b-email .price','text-align','right','','','.b-email'),(900802,'furniture','.b-email .heading-price','text-align','right','','','.b-email'),(900803,'furniture','.b-compare .compare-head','text-align','left','','','.b-compare'),(900804,'furniture','.w-menu-horizontal ul ul li','text-align','left','','','.w-menu-horizontal'),(900806,'furniture','.b-email .heading-model','text-align','center','','','.b-email'),(900807,'furniture','.w-catalog-listing-look .grid','text-align','center','','','.w-catalog-listing-look'),(900808,'furniture','.w-catalog-listing-look .b2b','text-align','center','','','.w-catalog-listing-look'),(900809,'furniture','.w-catalog-listing-look .list','text-align','center','','','.w-catalog-listing-look'),(900810,'furniture','.w-cart-listing .image','text-align','center','','','.w-cart-listing'),(900811,'furniture','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(900812,'furniture','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','text-align','left','','','.w-cart-listing'),(900813,'furniture','.w-cart-listing .points-earn','text-align','left','','','.w-cart-listing'),(900814,'furniture','.w-cart-listing .points-redeem','text-align','left','','','.w-cart-listing'),(900815,'furniture','.w-cart-listing .no-price .qty','text-align','right','','','.w-cart-listing'),(900816,'furniture','.w-cart-listing .remove-btn','text-align','center','','','.w-cart-listing'),(900817,'furniture','.w-cart-listing .price','text-align','right','','','.w-cart-listing'),(900818,'furniture','.w-cart-listing .remove','text-align','center','','','.w-cart-listing'),(900819,'furniture','.w-cart-listing .item .qty','text-align','right','5140','','.w-cart-listing'),(900820,'furniture','.w-cart-give-away .ga_img','text-align','center','','','.w-cart-give-away'),(900821,'furniture','.w-cart-discount-coupon .btn-remove','text-align','center','','','.w-cart-discount-coupon'),(900823,'furniture','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(900824,'furniture','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(900825,'furniture','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(900826,'furniture','.b-fancybox .fancybox-nav span','text-align','center','','','.b-fancybox'),(900827,'furniture','.w-tabs .accordion-heading','text-align','center','','','.w-tabs'),(900828,'furniture','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(900829,'furniture','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(900830,'furniture','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','text-align','center','','','.p-quick-order-index'),(900831,'furniture','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(900832,'furniture','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(900833,'furniture','.w-login-block .buttons','text-align','right','','','.w-login-block'),(900834,'furniture','.w-filters .handle-to','text-align','right','','','.w-filters'),(900835,'furniture','.order-summary .box','text-align','center','','','.order-summary'),(900836,'furniture','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(900837,'furniture','.b-bottom .pop-up-close','text-align','center','','','.b-bottom'),(900838,'furniture','.order-summary .price-row.ot_bonus_points .title','text-align','center','3','','.order-summary'),(900839,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','text-align','center','3','','.b-form'),(900840,'furniture','.b-social-login .social-login','text-align','center','','','.b-social-login'),(900841,'furniture','.w-reviews-content .date','text-align','right','','','.w-reviews-content'),(900842,'furniture','.b-data-table table.dataTable tbody td:last-child','text-align','right','','','.b-data-table'),(900843,'furniture','.b-data-table .dt-body-center','text-align','center','','','.b-data-table'),(900844,'furniture','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(900845,'furniture','.w-menu-big li a, .w-menu-big li .no-link','text-align','left','','','.w-menu-big'),(900846,'furniture','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(900847,'furniture','.b-upload-file .upload-file-template','text-align','center','','','.b-upload-file'),(900848,'furniture','.b-email-editor .price','text-align','center','','','.b-email-editor'),(900849,'furniture','.b-email .totals-value','text-align','right','','','.b-email'),(900850,'furniture','.b-email .totals-label','text-align','right','','','.b-email'),(900851,'furniture','.b-email .totals-title','text-align','right','','','.b-email'),(900852,'furniture','.b-email .qty','text-align','center','','','.b-email'),(900853,'furniture','.b-upload-file .snapshot','text-align','center','','','.b-upload-file'),(900854,'furniture','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(900855,'furniture','.b-product-images .media-popup .mp-close','text-align','center','','','.b-product-images'),(900856,'furniture','.b-product-images .media-popup .mp-small-images','text-align','center','','','.b-product-images'),(900857,'furniture','.b-product-images .media-popup .mp-small-images .item','text-align','center','','','.b-product-images'),(900858,'furniture','.b-product-images .media-popup .slick-dots','text-align','center','','','.b-product-images'),(900859,'furniture','.b-product-images .media-popup .slick-dots li','text-align','center','','','.b-product-images'),(900860,'furniture','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','text-align','center','','','.b-menu-burger_icon'),(900861,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(900862,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(900863,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(900864,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(900865,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(900866,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(900867,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','text-align','center','','','.b-menu-style-2'),(900868,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','text-align','center','','','.b-menu-style-2'),(900869,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','text-align','right','','','.b-menu-style-2'),(900870,'furniture','.b-personal-catalog-popup #personal_catalog_popup','text-align','left','','','.b-personal-catalog-popup'),(900871,'furniture','.b-trade-approval .steps-bar li','text-align','center','','','.b-trade-approval'),(900872,'furniture','.b-trade-approval .steps-bar li a','text-align','center','','','.b-trade-approval'),(900873,'furniture','.b-trade-approval .orders-table td:nth-child(1), .b-trade-approval .orders-table th:nth-child(1)','text-align','left','','','.b-trade-approval'),(900874,'furniture','.b-trade-approval .orders-table td:nth-child(2)','text-align','right','','','.b-trade-approval'),(900875,'furniture','.b-trade-approval .w-login-block label','text-align','left','','','.b-trade-approval'),(900876,'furniture','.b-trade-approval .steps-bar','text-align','left','','','.b-trade-approval'),(900877,'furniture','.b-trade-approval .center-buttons','text-align','center','','','.b-trade-approval'),(900878,'furniture','.b-trade-approval .comments','text-align','left','','','.b-trade-approval'),(900879,'furniture','.w-account-personal-catalog .list-switcher a','text-align','center','','','.w-account-personal-catalog'),(900880,'furniture','.w-catalog-additional-images ul, .w-catalog-additional-images li','text-align','center','','','.w-catalog-additional-images'),(900881,'furniture','.w-catalog-compare .cross-box .different-all > div','text-align','center','','','.w-catalog-compare'),(900882,'furniture','.w-delivery-day .time-left','text-align','center','','','.w-delivery-day'),(900883,'furniture','.w-top-text .top-text','text-align','center','','','.w-top-text'),(900884,'furniture','.b-cookie-notice .cookie-notice','text-align','center','','','.b-cookie-notice'),(900888,'furniture','.preFooter .test','text-align','center','','','.preFooter'),(900889,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','text-align','center','','','.b-slick'),(900890,'furniture','.menu-header .burger-icon','text-align','center','5140','','.menu-header'),(900891,'furniture','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','text-align','center','','','.b-products-listing'),(900892,'furniture','.b-products-listing .products-listing.list-productlisting .item:hover .item-wrapper','text-align','center','','','.b-products-listing'),(900893,'furniture','.b-products-listing .item-nav > div','text-align','center','','','.b-products-listing'),(900894,'furniture','.w-quote .cart-box-link','text-align','center','3','','.w-quote'),(900895,'furniture','.w-quote .price','text-align','right','','','.w-quote'),(900896,'furniture','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(900897,'furniture','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(900898,'furniture','.b-quantity .qty-box input','text-align','center','','','.b-quantity'),(900899,'furniture','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(900900,'furniture','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(900901,'furniture','.productNavigation .test','text-align','center','','','.productNavigation'),(900902,'furniture','.w-product-sale-ends .ends','text-align','center','','','.w-product-sale-ends'),(900903,'furniture','.w-product-sale-ends .left','text-align','center','','','.w-product-sale-ends'),(900904,'furniture','.heading-2, h2, .h-block h2','text-align','center','','',''),(900905,'furniture','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','text-align','center','','','.w-product-buttons'),(900906,'furniture','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(900907,'furniture','.w-product-quantity .qty-input','text-align','left','','','.w-product-quantity'),(900908,'furniture','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(900909,'furniture','.w-files-catalog-widgets-files-catalog .item','text-align','center','','','.w-files-catalog-widgets-files-catalog'),(900910,'furniture','.w-sample .cart-box-link','text-align','center','3','','.w-sample'),(900911,'furniture','.w-sample .price','text-align','right','','','.w-sample'),(900912,'furniture','.w-cart-listing .item > div.points','text-align','right','','','.w-cart-listing'),(900913,'furniture','.w-filters-simple .integrate-price-holder','text-align','right','','','.w-filters-simple'),(900914,'furniture','.w-cart-sub-total .price','text-align','right','','','.w-cart-sub-total'),(900915,'furniture','.w-product-images .additional-horizontal .item','text-align','center','','','.w-product-images'),(900916,'furniture','.w-product-video .frame-video','text-align','center','','','.w-product-video'),(900917,'furniture','.w-product-video .item','text-align','center','','','.w-product-video'),(900918,'furniture','.w-product-bundle .bundle-total-price','text-align','right','','','.w-product-bundle'),(900919,'furniture','.w-product-in-bundles .bundle-total-price','text-align','right','','','.w-product-in-bundles'),(900920,'furniture','.w-cart-listing .item div.price','text-align','right','5140','','.w-cart-listing'),(900921,'furniture','.w-sample-products .w-cart-listing .item .qty','text-align','right','5131','','.w-sample-products'),(900923,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','text-align','inherit','','','.b-products-listing'),(900924,'furniture','.b-pagination .pagination .next-pages','text-align','center','','','.b-pagination'),(900925,'furniture','.b-pagination .pagination .p-blog-index','text-align','right','','','.b-pagination'),(900926,'furniture','.b-pagination .pagination .page-number','text-align','center','','','.b-pagination'),(900927,'furniture','.b-pagination .pagination .prev-pages','text-align','center','','','.b-pagination'),(900928,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','text-align','center','','','.b-pagination'),(900929,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','text-align','center','','','.b-pagination'),(900930,'furniture','.b-pagination .pagination span','text-align','center','2','','.b-pagination'),(900931,'furniture','.p-quote-checkout-index .heading-2','text-align','left','','','.p-quote-checkout-index'),(900932,'furniture','.p-sample-checkout-index .heading-2','text-align','left','','','.p-sample-checkout-index'),(900933,'furniture','.p-quote-checkout-index .order-summary .heading-2','text-align','center','','','.p-quote-checkout-index'),(900934,'furniture','.w-sample-products .w-cart-listing .qty','text-align','center','','','.w-sample-products'),(900935,'furniture','.p-sample-checkout-index .order-summary .heading-2','text-align','center','','','.p-sample-checkout-index'),(900937,'furniture','.w-quote-products .cart-listing .qty','text-align','right','','','.w-quote-products'),(900938,'furniture','.w-product-multi-inventory .radio-attributes .option-item','text-align','center','','','.w-product-multi-inventory'),(900939,'furniture','.w-account-personal-catalog .check-box','text-align','center','','','.w-account-personal-catalog'),(900940,'furniture','.w-account-personal-catalog .remove','text-align','center','','','.w-account-personal-catalog'),(900941,'furniture','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','text-align','center','','','.w-account-personal-catalog'),(900942,'furniture','.w-account-personal-catalog .w-cart-listing .item .remove','text-align','center','5140','','.w-account-personal-catalog'),(900943,'furniture','.b-products-listing .products-listing.list-rows .qtyInput','text-align','center','','','.b-products-listing'),(900944,'furniture','.b-products-listing .products-listing .radio-attributes .option','text-align','center','','','.b-products-listing'),(900945,'furniture','.b-products-listing .products-listing.list-b2b .qtyInput','text-align','center','','','.b-products-listing'),(900946,'furniture','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(900947,'furniture','.w-product-collection .item','text-align','center','','','.w-product-collection'),(900948,'furniture','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(900949,'furniture','.w-product-collection .choose-products .heading-3','text-align','center','','','.w-product-collection'),(900950,'furniture','.w-product-attributes .radio-attributes .option-item','text-align','center','','','.w-product-attributes'),(900951,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','text-align','center','','','.w-questionnaire-widgets-questionnaire'),(900952,'furniture','.w-product-groups .val1','text-align','center','','','.w-product-groups'),(900953,'furniture','.w-product-groups .prop-group-swatch','text-align','center','','','.w-product-groups'),(900954,'furniture','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img + .val2','text-align','center','','','.w-product-groups'),(900955,'furniture','.b-products-listing .products-listing .attribute-qty-block > span','text-align','center','','','.b-products-listing'),(900956,'furniture','.w-product-custom-bundle .heading-3','text-align','center','','','.w-product-custom-bundle'),(900957,'furniture','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(900958,'furniture','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(900959,'furniture','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(900960,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','text-align','center','','','.w-catalog-pages-category-pages-last-list'),(900961,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','text-align','center','','','.w-catalog-pages-category-pages-last-list-block'),(900962,'furniture','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(900963,'furniture','.w-delivery-location-location-list .deliveryList li','text-align','center','','','.w-delivery-location-location-list'),(900964,'furniture','.w-sale-category .badge','text-align','center','','','.w-sale-category'),(900965,'furniture','.w-sale-category .btn','text-align','center','','','.w-sale-category'),(900966,'furniture','.w-sale-category .image','text-align','center','','','.w-sale-category'),(900967,'furniture','.w-sale-category .left','text-align','center','','','.w-sale-category'),(900968,'furniture','.w-success-download table','text-align','center','','','.w-success-download'),(900969,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-img','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(900970,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-name','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(900971,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(900972,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-img','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(900973,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-name','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(900974,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(900975,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description + div','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(900976,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(900977,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(900978,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description + div','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(900979,'furniture','.w-product-properties-icons .hover-box-content','text-align','center','','','.w-product-properties-icons'),(900980,'furniture','.w-delivery-location-product-categories .item.category-link','text-align','center','','','.w-delivery-location-product-categories'),(900981,'furniture','.w-product-bonus-points .bonus-points-cost','text-align','left','','','.w-product-bonus-points'),(900982,'furniture','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','text-align','right','','','.w-press-reviews-widgets-press-reviews-small'),(900983,'furniture','.w-press-reviews-widgets-press-reviews .date','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(900984,'furniture','.w-press-reviews-widgets-press-reviews .heading-3','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(900985,'furniture','.w-press-reviews-widgets-press-reviews .image','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(900986,'furniture','.w-press-reviews-widgets-press-reviews .item','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(900987,'furniture','.w-press-reviews-widgets-press-reviews .press-reviews-button','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(900988,'furniture','.w-press-reviews-widgets-press-reviews .sub-box','text-align','left','','','.w-press-reviews-widgets-press-reviews'),(900989,'furniture','.w-press-reviews-widgets-press-reviews .author','text-align','center','5131','','.w-press-reviews-widgets-press-reviews'),(900990,'furniture','.w-press-reviews-widgets-press-reviews .date','text-align','center','5131','','.w-press-reviews-widgets-press-reviews'),(900991,'furniture','.w-press-reviews-widgets-press-reviews .image','text-align','center','5131','','.w-press-reviews-widgets-press-reviews'),(900992,'furniture','.w-press-reviews-widgets-press-reviews .rating','text-align','center','5131','','.w-press-reviews-widgets-press-reviews'),(900993,'furniture','.w-press-reviews-widgets-press-reviews .review','text-align','center','5131','','.w-press-reviews-widgets-press-reviews'),(900994,'furniture','.w-press-reviews-widgets-press-reviews .title','text-align','center','5131','','.w-press-reviews-widgets-press-reviews'),(900995,'furniture','.w-press-reviews-widgets-press-reviews-list .review-box ul li','text-align','left','','','.w-press-reviews-widgets-press-reviews-list'),(900996,'furniture','.w-support-system-listing .product_icon','text-align','center','','','.w-support-system-listing'),(900997,'furniture','.w-rma-returns-history .btn','text-align','center','','','.w-rma-returns-history'),(900998,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','text-align','center','','','.w-rma-returns-history'),(900999,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(901000,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(901001,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(901002,'furniture','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(901003,'furniture','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(901004,'furniture','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(901005,'furniture','.w-product-configurator .pc_qty','text-align','left','5131','','.w-product-configurator'),(901006,'furniture','.b-products-listing .products-listing .bonus-points-cost','text-align','left','','','.b-products-listing'),(901007,'furniture','.b-products-listing .promo-icon','text-align','center','','','.b-products-listing'),(901008,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','text-align','center','','','.w-catalog-pages-category-pages-list'),(901009,'furniture','.w-predefined-promotion .prom-multi-discount .heading','text-align','center','','','.w-predefined-promotion'),(901010,'furniture','.w-predefined-promotion .promo-date','text-align','center','','','.w-predefined-promotion'),(901011,'furniture','.w-predefined-promotion .promo-item','text-align','center','','','.w-predefined-promotion'),(901012,'furniture','.w-supplier-purchase-supplier-products .active .select_item > div','text-align','center','','','.w-supplier-purchase-supplier-products'),(901013,'furniture','.mainBanner .bottomBox','text-align','center','','','.mainBanner'),(901014,'furniture','.mainBanner .buttonBox','text-align','right','','','.mainBanner'),(901015,'furniture','.mainBanner .topBox','text-align','center','','','.mainBanner'),(901016,'furniture','.mainBanner .topBox','text-align','left','5131','','.mainBanner'),(901017,'furniture','.order-summary .w-cart-listing .item .name','text-align','left','','','.order-summary'),(901018,'furniture','.order-summary .w-cart-listing.type-2 .image','text-align','left','','','.order-summary'),(901019,'furniture','.w-cart-discount-coupon .title','text-align','left','','','.w-cart-discount-coupon'),(901020,'furniture','.w-cart-listing .qty','text-align','center','','','.w-cart-listing'),(901021,'furniture','.w-cart-listing .item .price','text-align','right','5131','','.w-cart-listing'),(901022,'furniture','.w-product-quantity-discounts .item','text-align','center','','','.w-product-quantity-discounts'),(901032,'furniture','.account-address-book .address_book h2','text-align','right','','','.account-address-book'),(901040,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-align','left','','','.account-order-pay'),(901041,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-align','left','3','','.account-order-pay'),(901042,'furniture','.account-order-pay .tableForm th','text-align','left','','','.account-order-pay'),(901043,'furniture','.account-samples .orders-table td.td-alignright','text-align','right','','','.account-samples'),(901044,'furniture','.account-samples .orders-table th','text-align','left','','','.account-samples'),(901045,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-align','left','','','.account-sample-info'),(901046,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-align','left','3','','.account-sample-info'),(901047,'furniture','.account-sample-info .popup-tracking-number','text-align','center','','','.account-sample-info'),(901048,'furniture','.account-sample-info .tableForm th','text-align','left','','','.account-sample-info'),(901049,'furniture','.account-sample-info .trackings-nambers','text-align','center','','','.account-sample-info'),(901050,'furniture','.catalog-product-wrap .prev-next-product','text-align','center','','','.catalog-product-wrap'),(901051,'furniture','.checkout-index-wrap .heading-2','text-align','left','','','.checkout-index-wrap'),(901052,'furniture','.checkout-index-wrap .order-summary .heading-2','text-align','center','','','.checkout-index-wrap'),(901053,'furniture','.checkout-order-confirmation .heading-2.prod-ico','text-align','left','','','.checkout-order-confirmation'),(901054,'furniture','.checkout-order-confirmation .price-box .title','text-align','left','','','.checkout-order-confirmation'),(901055,'furniture','.checkout-success-wrap .page-success','text-align','center','','','.checkout-success-wrap'),(901056,'furniture','.shopping-cart-index .cart-page .empty','text-align','center','','','.shopping-cart-index'),(901057,'furniture','.b-multi-page-checkout .messageBox .info','text-align','left','','','.b-multi-page-checkout'),(901058,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','text-align','center','','','.b-multi-page-checkout'),(901059,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','text-align','center','3','','.b-multi-page-checkout'),(901060,'furniture','.success-page .page-success .text-1','text-align','center','','','.success-page'),(901061,'furniture','.success-page .price-box .title','text-align','left','','','.success-page'),(901062,'furniture','.success-page .w-cart-listing .qty','text-align','center','','','.success-page'),(901063,'furniture','.w-success-continue-btn','text-align','center','5140','','.w-success-continue-btn'),(901064,'furniture','.w-success-continue-btn','text-align','center','5140','','.w-success-continue-btn'),(901065,'furniture','.w-success-continue-btn','text-align','center','5140','','.w-success-continue-btn'),(901066,'furniture','.w-success-continue-btn','text-align','center','5140','','.w-success-continue-btn'),(901067,'furniture','.w-success-continue-btn','text-align','center','5140','','.w-success-continue-btn'),(901068,'furniture','.w-success-continue-btn','text-align','center','5140','','.w-success-continue-btn'),(901069,'furniture','.lowestPricedBox .w-banner .ybg','text-align','center','','','.lowestPricedBox'),(901070,'furniture','.shopByCollectionBox .content .title','text-align','left','','','.shopByCollectionBox'),(901071,'furniture','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','text-align','center','','','.w-banner'),(901072,'furniture','.w-banner .single_banner','text-align','center','','','.w-banner'),(901073,'furniture','.w-catalog-paging ','text-align','center','2','','.w-catalog-paging'),(901074,'furniture','.w-catalog-paging .next','text-align','center','','','.w-catalog-paging'),(901075,'furniture','.w-catalog-paging .next-pages','text-align','center','','','.w-catalog-paging'),(901076,'furniture','.w-catalog-paging .p-blog-index','text-align','right','','','.w-catalog-paging'),(901077,'furniture','.w-catalog-paging .page-number','text-align','center','','','.w-catalog-paging'),(901078,'furniture','.w-catalog-paging .prev','text-align','center','','','.w-catalog-paging'),(901079,'furniture','.w-catalog-paging .prev-pages','text-align','center','','','.w-catalog-paging'),(901080,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align','center','','','.w-catalog-paging'),(901081,'furniture','.w-compare-box-item .checkbox:checked + span:before','text-align','center','','','.w-compare-box-item'),(901082,'furniture','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align_important','important','','','.p-quick-order-index'),(901083,'furniture','.w-success-continue-btn','text-align_important','important','5140','','.w-success-continue-btn'),(901084,'furniture','.w-success-continue-btn','text-align_important','important','5140','','.w-success-continue-btn'),(901085,'furniture','.w-success-continue-btn','text-align_important','important','5140','','.w-success-continue-btn'),(901086,'furniture','.w-success-continue-btn','text-align_important','important','5140','','.w-success-continue-btn'),(901087,'furniture','.w-success-continue-btn','text-align_important','important','5140','','.w-success-continue-btn'),(901088,'furniture','.w-success-continue-btn','text-align_important','important','5140','','.w-success-continue-btn'),(901089,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align_important','important','','','.w-catalog-paging'),(901090,'furniture','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(901091,'furniture','.b-fancybox a.fancybox-close','text-decoration','none','1','','.b-fancybox'),(901092,'furniture','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(901093,'furniture','.w-chat .w-chat-box a','text-decoration','none','1','','.w-chat'),(901095,'furniture','.w-socials > li a','text-decoration','none','','','.w-socials'),(901096,'furniture','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(901097,'furniture','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(901098,'furniture','.price .old','text-decoration','line-through','','',''),(901099,'furniture','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(901100,'furniture','.b-select-suggest .select2-result-selectable .select2-match, .b-select-suggest .select2-result-unselectable .select2-match','text-decoration','underline','','','.b-select-suggest'),(901101,'furniture','.w-socials > li a','text-decoration','none','','','.w-socials'),(901102,'furniture','.w-tabs .tab-a','text-decoration','none','','','.w-tabs'),(901103,'furniture','.w-socials > li a','text-decoration','none','','','.w-socials'),(901104,'furniture','.btn-edit','text-decoration','none','1','',''),(901105,'furniture','.w-socials > li a','text-decoration','none','','','.w-socials'),(901106,'furniture','.heading-3 .right-text, h3 .right-text','text-decoration','none','','',''),(901107,'furniture','.w-socials > li a','text-decoration','none','','','.w-socials'),(901108,'furniture','.w-image-maps .categories-items .item a','text-decoration','none','1','','.w-image-maps'),(901109,'furniture','.w-social-links a','text-decoration','none','1','','.w-social-links'),(901110,'furniture','.w-chat .w-chat-box a','text-decoration','none','','','.w-chat'),(901111,'furniture','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(901112,'furniture','.w-socials > li a','text-decoration','none','','','.w-socials'),(901113,'furniture','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(901114,'furniture','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(901115,'furniture','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(901116,'furniture','.b-select-suggest .select2-container .select2-choice','text-decoration','none','','','.b-select-suggest'),(901117,'furniture','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(901118,'furniture','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(901119,'furniture','.w-cart-listing .remove-btn','text-decoration','none','','','.w-cart-listing'),(901122,'furniture','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(901123,'furniture','.w-image-maps .float-items .item a','text-decoration','none','1','','.w-image-maps'),(901124,'furniture','.b-fancybox .fancybox-nav','text-decoration','none','','','.b-fancybox'),(901125,'furniture','.w-tabs .accordion-heading','text-decoration','none','','','.w-tabs'),(901126,'furniture','.b-select-suggest .select2-container .select2-choice abbr','text-decoration','none','','','.b-select-suggest'),(901127,'furniture','.w-filters .mobileCollapse','text-decoration','none','1','','.w-filters'),(901128,'furniture','.w-account-personal-catalog .list-switcher a','text-decoration','none','','','.w-account-personal-catalog'),(901131,'furniture','.LeftCategories ul li a','text-decoration','none','1','','.LeftCategories'),(901132,'furniture','.w-quote .multicart a.name','text-decoration','none','1','','.w-quote'),(901133,'furniture','.w-quote .multicart a.switch-cart','text-decoration','none','1','','.w-quote'),(901134,'furniture','.w-quote a.cart-box-link','text-decoration','none','1','','.w-quote'),(901135,'furniture','.w-quote a.item','text-decoration','none','1','','.w-quote'),(901136,'furniture','.w-sample .multicart a.name','text-decoration','none','1','','.w-sample'),(901137,'furniture','.w-sample .multicart a.switch-cart','text-decoration','none','1','','.w-sample'),(901138,'furniture','.w-sample a.cart-box-link','text-decoration','none','1','','.w-sample'),(901139,'furniture','.w-sample a.item','text-decoration','none','1','','.w-sample'),(901140,'furniture','.w-product-bundle .bundle_price .old','text-decoration','line-through','','','.w-product-bundle'),(901141,'furniture','.w-product-in-bundles .bundle_price .old','text-decoration','line-through','','','.w-product-in-bundles'),(901142,'furniture','.b-pagination .pagination a','text-decoration','none','1','','.b-pagination'),(901143,'furniture','.b-pagination .pagination span','text-decoration','none','1','','.b-pagination'),(901144,'furniture','.w-delivery-location-location-list .deliveryList li a','text-decoration','none','1','','.w-delivery-location-location-list'),(901145,'furniture','.w-sale-category .old','text-decoration','line-through','','','.w-sale-category'),(901146,'furniture','.w-checkout-shipping-address .change-ab','text-decoration','underline','','','.w-checkout-shipping-address'),(901147,'furniture','.w-checkout-shipping-address .change-ab','text-decoration','none','1','','.w-checkout-shipping-address'),(901148,'furniture','.w-checkout-shipping-address .edit-ab','text-decoration','underline','','','.w-checkout-shipping-address'),(901149,'furniture','.w-checkout-shipping-address .edit-ab','text-decoration','none','1','','.w-checkout-shipping-address'),(901150,'furniture','.w-checkout-contact-information .btn-edit1','text-decoration','underline','','','.w-checkout-contact-information'),(901151,'furniture','.w-checkout-contact-information .btn-edit1','text-decoration','none','1','','.w-checkout-contact-information'),(901158,'furniture','.account-samples .orders-table a, .account-samples .order-info a','text-decoration','none','1','','.account-samples'),(901159,'furniture','.account-samples .view_link','text-decoration','underline','','','.account-samples'),(901160,'furniture','.catalog-product-wrap a.prev-next-product','text-decoration','none','1','','.catalog-product-wrap'),(901161,'furniture','.checkout-index-wrap .edit-address-popup .edit-ab','text-decoration','underline','','','.checkout-index-wrap'),(901162,'furniture','.checkout-index-wrap .edit-address-popup .edit-ab','text-decoration','none','1','','.checkout-index-wrap'),(901163,'furniture','.b-form .addresses .address-item .edit-ab','text-decoration','underline','','','.b-form'),(901164,'furniture','.w-catalog-paging a','text-decoration','none','1','','.w-catalog-paging'),(901165,'furniture','.w-catalog-paging span','text-decoration','none','1','','.w-catalog-paging'),(901166,'furniture','.b-select-suggest .select2-container .select2-choice > .select2-chosen','text-overflow','ellipsis','','','.b-select-suggest'),(901167,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(901168,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(901169,'furniture','.b-fancybox .fancybox-skin','text-shadow','none','','','.b-fancybox'),(901170,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(901171,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(901172,'furniture','.b-fancybox .fancybox-title','text-shadow','none','','','.b-fancybox'),(901173,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(901174,'furniture','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(901175,'furniture','.heading-4 .right-text, h4 .right-text','text-transform','none','','',''),(901176,'furniture','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(901177,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-transform','uppercase','','','.b-switch'),(901178,'furniture','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(901179,'furniture','.p-sample-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-sample-checkout-success'),(901180,'furniture','.p-sample-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-sample-checkout-success'),(901181,'furniture','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(901182,'furniture','.w-promotions .heading-3','text-transform','uppercase','','','.w-promotions'),(901183,'furniture','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(901184,'furniture','.b-messages .content-messages .heading-2','text-transform','none','','','.b-messages'),(901185,'furniture','.heading-4 .edit, h4 .edit','text-transform','none','','',''),(901186,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','text-transform','uppercase','4','','.b-switch'),(901187,'furniture','.w-personal-gift-status-bar .end-date','text-transform','uppercase','','','.w-personal-gift-status-bar'),(901188,'furniture','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(901189,'furniture','.w-checkout-shipping-choice span','text-transform','uppercase','','','.w-checkout-shipping-choice'),(901190,'furniture','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(901191,'furniture','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(901193,'furniture','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(901194,'furniture','.w-cart-compare .cart-name a','text-transform','uppercase','','','.w-cart-compare'),(901195,'furniture','.heading-3 .edit, h3 .edit','text-transform','none','','',''),(901196,'furniture','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(901197,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','text-transform','uppercase','4','','.b-switch'),(901198,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','text-transform','uppercase','4','','.b-switch'),(901199,'furniture','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','text-transform','uppercase','','','.w-multi-cart-cart-switcher'),(901200,'furniture','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(901201,'furniture','.w-top-categories .categories h2','text-transform','inherit','','','.w-top-categories'),(901202,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-transform','uppercase','','','.b-switch'),(901203,'furniture','.w-categories h2.name','text-transform','uppercase','','','.w-categories'),(901204,'furniture','.b-bottom .cart-options .heading-4','text-transform','none','','','.b-bottom'),(901205,'furniture','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(901206,'furniture','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(901207,'furniture','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(901208,'furniture','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(901209,'furniture','.w-personal-gift-status-bar .inform','text-transform','uppercase','','','.w-personal-gift-status-bar'),(901210,'furniture','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(901211,'furniture','.b-products-listing .products-listing a.btn.view-button','text-transform','none','','','.b-products-listing'),(901212,'furniture','.w-top-categories h2.name','text-transform','uppercase','','','.w-top-categories'),(901213,'furniture','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','text-transform','none','','','.w-taxable'),(901214,'furniture','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','text-transform','none','','','.w-taxable'),(901215,'furniture','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','text-transform','inherit','','',''),(901216,'furniture','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','text-transform','inherit','','','.b-h-inline'),(901217,'furniture','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(901218,'furniture','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','text-transform','uppercase','','','.w-cart-listing'),(901220,'furniture','.w-tabs .accordion-heading','text-transform','uppercase','','','.w-tabs'),(901221,'furniture','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(901222,'furniture','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(901223,'furniture','.w-account-personal-catalog .list-switcher a','text-transform','uppercase','','','.w-account-personal-catalog'),(901224,'furniture','.b-products-listing .products-listing .name a','text-transform','uppercase','','','.b-products-listing'),(901225,'furniture','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','text-transform','none','','','.b-products-listing'),(901226,'furniture','.w-quote .multicart .title','text-transform','uppercase','','','.w-quote'),(901227,'furniture','.w-product-personal-catalog-button .btn','text-transform','none','','','.w-product-personal-catalog-button'),(901228,'furniture','.w-files-catalog-widgets-files-catalog .name','text-transform','uppercase','','','.w-files-catalog-widgets-files-catalog'),(901229,'furniture','.w-files-catalog-widgets-files-list .name','text-transform','uppercase','','','.w-files-catalog-widgets-files-list'),(901230,'furniture','.w-sample .multicart .title','text-transform','uppercase','','','.w-sample'),(901231,'furniture','.w-cart-discount-coupon .btn','text-transform','none','','','.w-cart-discount-coupon'),(901232,'furniture','.w-cart-up-sell .products-listing .name a','text-transform','none','','','.w-cart-up-sell'),(901233,'furniture','.w-cart-order-reference .btn','text-transform','none','','','.w-cart-order-reference'),(901234,'furniture','.w-cart-gift-certificate .btn','text-transform','none','','','.w-cart-gift-certificate'),(901235,'furniture','.w-cart-shipping-estimator .btn','text-transform','none','','','.w-cart-shipping-estimator'),(901236,'furniture','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','text-transform','inherit','','','.b-products-listing'),(901237,'furniture','.w-rma-returns-history .column .title','text-transform','uppercase','','','.w-rma-returns-history'),(901238,'furniture','.w-rma-returns-history .tableTitle','text-transform','uppercase','','','.w-rma-returns-history'),(901239,'furniture','.w-predefined-promotion .heading-3','text-transform','uppercase','','','.w-predefined-promotion'),(901243,'furniture','.account-address-book .address_book h2','text-transform','uppercase','','','.account-address-book'),(901244,'furniture','.account-address-book .address_book_row h2 a','text-transform','none','','','.account-address-book'),(901245,'furniture','.account-address-book .leftMes div','text-transform','uppercase','','','.account-address-book'),(901251,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-transform','uppercase','','','.account-order-pay'),(901252,'furniture','.account-order-pay .not_fully_paid_td','text-transform','uppercase','','','.account-order-pay'),(901253,'furniture','.account-samples .not_fully_paid_td','text-transform','uppercase','','','.account-samples'),(901254,'furniture','.account-samples .order_history_table h2','text-transform','uppercase','','','.account-samples'),(901255,'furniture','.account-samples .order_history_table th','text-transform','none','','','.account-samples'),(901256,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-transform','uppercase','','','.account-sample-info'),(901257,'furniture','.account-sample-info .not_fully_paid_td','text-transform','uppercase','','','.account-sample-info'),(901258,'furniture','.catalog-product-wrap .pn-direction','text-transform','uppercase','','','.catalog-product-wrap'),(901259,'furniture','.checkout-success-wrap .page-success .text-1','text-transform','uppercase','','','.checkout-success-wrap'),(901260,'furniture','.checkout-success-wrap .page-success .text-2','text-transform','uppercase','','','.checkout-success-wrap'),(901261,'furniture','.b-info .info strong','text-transform','uppercase','','','.b-info'),(901262,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading','text-transform','uppercase','','','.b-multi-page-checkout'),(901263,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','text-transform','none','','','.b-multi-page-checkout'),(901264,'furniture','.success-page .page-success .text-1','text-transform','uppercase','','','.success-page'),(901265,'furniture','.success-page .page-success .text-2','text-transform','uppercase','','','.success-page'),(901266,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > li > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > li > .no-link','text-transform','uppercase','','','.menu-header'),(901267,'furniture','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_color','#222','','','.b-fancybox'),(901268,'furniture','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left','0','','','.b-fancybox'),(901269,'furniture','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left_measure','','','','.b-fancybox'),(901270,'furniture','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size','2','','','.b-fancybox'),(901271,'furniture','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size_measure','px','','','.b-fancybox'),(901272,'furniture','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top','1','','','.b-fancybox'),(901273,'furniture','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top_measure','px','','','.b-fancybox'),(901274,'furniture','.b-pass-strength .pass-strength span','top','6','','','.b-pass-strength'),(901275,'furniture','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(901276,'furniture','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','top','0','','','.b-switch'),(901277,'furniture','.w-promotions .prom-multi-discount > .heading','top','2','3','','.w-promotions'),(901278,'furniture','.w-promotions .promo-date','top','-10','','','.w-promotions'),(901280,'furniture','.w-promo-code .holder','top','2','5161,3','','.w-promo-code'),(901281,'furniture','.testimonials .rating','top','2','','',''),(901282,'furniture','.testimonials .heading-3','top','0','3','',''),(901283,'furniture','.testimonials .reviews-list span','top','2','','',''),(901284,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(901285,'furniture','.w-promotions .prom-multi-discount .products','top','-13','','','.w-promotions'),(901286,'furniture','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','top','2','3','','.w-promotions'),(901287,'furniture','.w-promotions .promo-cart-discount .slave .content','top','-17','','','.w-promotions'),(901288,'furniture','.w-promotions .promo-cart-discount .promo-min-qty','top','-19','','','.w-promotions'),(901289,'furniture','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','top','2','3','','.w-promotions'),(901290,'furniture','.b-preloader .preloader','top','calc(50% - 20px)','3','','.b-preloader'),(901291,'furniture','.b-preloader .preloader','top','0','','','.b-preloader'),(901292,'furniture','.b-messages .messBtnMenuDelete','top','3','3','','.b-messages'),(901293,'furniture','.b-messages span.starred::before','top','3','','','.b-messages'),(901294,'furniture','.b-messages .messBtnMenuStarred','top','3','3','','.b-messages'),(901295,'furniture','.b-messages .messBtnMenuUnread','top','3','3','','.b-messages'),(901296,'furniture','.b-messages .select2-container-multi .select2-choices .select2-search-choice','top','5','','','.b-messages'),(901297,'furniture','.w-text .customer-service','top','5','3','','.w-text'),(901298,'furniture','.p-payer-order-confirmation .order-ico','top','7','3','','.p-payer-order-confirmation'),(901299,'furniture','.p-payer-order-confirmation .discount-ico','top','3','3','','.p-payer-order-confirmation'),(901300,'furniture','.p-payer-order-confirmation .comment-ico','top','7','3','','.p-payer-order-confirmation'),(901301,'furniture','.p-payer-order-pay .order-ico','top','7','3','','.p-payer-order-pay'),(901302,'furniture','.p-payer-order-pay .discount-ico','top','3','3','','.p-payer-order-pay'),(901303,'furniture','.p-payer-order-pay .comment-ico','top','7','3','','.p-payer-order-pay'),(901304,'furniture','.w-checkout-terms .required-message','top','40','','','.w-checkout-terms'),(901305,'furniture','.w-checkout-terms input[type=\"checkbox\"]','top','2','','','.w-checkout-terms'),(901306,'furniture','.w-checkout-shipping-address .genders-title input','top','2','','','.w-checkout-shipping-address'),(901307,'furniture','.b-fancybox #fancybox-loading','top','50','','','.b-fancybox'),(901308,'furniture','.b-form .form-buttons','top','10','','','.b-form'),(901309,'furniture','.b-rating .glyphicon','top','1','','','.b-rating'),(901310,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(901311,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-remove','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(901312,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-details','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(901313,'furniture','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(901314,'furniture','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(901315,'furniture','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(901317,'furniture','.b-form .shipping-method .input input','top','2','','','.b-form'),(901319,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','top','8','','','.b-switch'),(901320,'furniture','.b-fancybox .fancybox-tmp','top','-99999','','','.b-fancybox'),(901321,'furniture','.w-filters .ui-slider-handle','top','-5','','','.w-filters'),(901322,'furniture','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','top','-1','3','','.order-summary'),(901323,'furniture','.view-all','top','50','3','',''),(901324,'furniture','.b-products-listing .products-listing .btn-buy','top','3','3','','.b-products-listing'),(901325,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','top','-2','','','.b-switch'),(901326,'furniture','.b-switch .candlestick-wrapper','top','-2','','','.b-switch'),(901327,'furniture','.closeable-heading','top','15','3','',''),(901328,'furniture','.b-bottom .footerTitle','top','8','5131,4','','.b-bottom'),(901329,'furniture','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(901330,'furniture','.b-info-popup .info-popup div','top','15','3','','.b-info-popup'),(901331,'furniture','.b-form .form-inputs div.required-message','top','-15','','','.b-form'),(901332,'furniture','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(901333,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top','0','','','.b-select-suggest'),(901334,'furniture','.b-form .hide-billing-address','top','0','','','.b-form'),(901335,'furniture','.b-select-suggest .select2-measure-scrollbar','top','-10000','','','.b-select-suggest'),(901336,'furniture','.w-socials .post_item > div','top','10','3','','.w-socials'),(901337,'furniture','.w-cart-compare .atr-col','top','0','3','','.w-cart-compare'),(901338,'furniture','.b-info-popup .info-popup.top-left div','top','auto','3','','.b-info-popup'),(901339,'furniture','.b-info-popup .info-popup div','top','-12','','','.b-info-popup'),(901341,'furniture','.w-socials .post_item > div','top','10','3','','.w-socials'),(901342,'furniture','.w-socials .post_item > div','top','10','3','','.w-socials'),(901343,'furniture','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(901344,'furniture','.w-text .customer-service','top','5','3','','.w-text'),(901345,'furniture','.w-socials .post_item > div','top','10','3','','.w-socials'),(901347,'furniture','.message.success','top','3','3','',''),(901348,'furniture','.b-form .middle-form .required-message','top','-15','','','.b-form'),(901349,'furniture','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(901350,'furniture','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(901351,'furniture','.w-socials .post_item > div','top','10','3','','.w-socials'),(901352,'furniture','.b-info-popup .info-popup.top-left div','top','auto','','','.b-info-popup'),(901353,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(901354,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','top','8','','','.b-switch'),(901355,'furniture','.b-form .radio-button input[type=\"radio\"]','top','2','','','.b-form'),(901356,'furniture','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(901357,'furniture','.w-personal-gift-status-bar .end-date','top','4','3','','.w-personal-gift-status-bar'),(901358,'furniture','.savings-ico .heading-2','top','5','3','','.savings-ico'),(901359,'furniture','.w-text .customer-service','top','5','3','','.w-text'),(901360,'furniture','.w-multi-cart-actions .cart-actions','top','-3','','','.w-multi-cart-actions'),(901361,'furniture','.b-fancybox .fancybox-overlay','top','0','','','.b-fancybox'),(901362,'furniture','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(901363,'furniture','.w-promo-code .holder','top','19','3','','.w-promo-code'),(901364,'furniture','.w-promo-code .holder','top','2','5161,3','','.w-promo-code'),(901365,'furniture','.w-reviews .review','top','-16','3','','.w-reviews'),(901366,'furniture','.w-reviews .heading-3','top','0','3','','.w-reviews'),(901367,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','top','4','3','','.b-switch'),(901368,'furniture','.w-menu-horizontal ul ul ul','top','0','','','.w-menu-horizontal'),(901371,'furniture','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(901372,'furniture','.b-form .payment-method .item-radio input','top','5','','','.b-form'),(901373,'furniture','.w-checkout-billing-address .genders-title input','top','2','','','.w-checkout-billing-address'),(901374,'furniture','.w-promo-code .holder','top','2','5161,3','','.w-promo-code'),(901375,'furniture','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(901376,'furniture','.w-menu-horizontal > ul > li > ul','top','100','','','.w-menu-horizontal'),(901377,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(901378,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(901379,'furniture','.b-info-popup .info-popup','top','4','3','','.b-info-popup'),(901380,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','top','1','3','','.b-form'),(901381,'furniture','.w-promo-code .holder','top','2','5161,3','','.w-promo-code'),(901382,'furniture','.w-personal-gift-status-bar .inform','top','3','4','','.w-personal-gift-status-bar'),(901383,'furniture','.b-upload-files .attach-active-holder .attach-file','top','-200','','','.b-upload-files'),(901384,'furniture','.w-promo-code .holder','top','2','5161,3','','.w-promo-code'),(901385,'furniture','.b-fancybox .fancybox-close','top','10','','','.b-fancybox'),(901386,'furniture','.w-product-customers-activity .close','top','5','','','.w-product-customers-activity'),(901387,'furniture','.w-reviews-content .review','top','-16','3','','.w-reviews-content'),(901388,'furniture','.w-text .customer-service','top','5','3','','.w-text'),(901389,'furniture','.w-cart-compare .remove-cart','top','0','','','.w-cart-compare'),(901390,'furniture','.w-promo-code .holder','top','19','3','','.w-promo-code'),(901391,'furniture','.w-promo-code .holder','top','19','3','','.w-promo-code'),(901392,'furniture','.w-promo-code .holder','top','2','5161,3','','.w-promo-code'),(901393,'furniture','.w-checkout-shipping-choice input','top','-200','','','.w-checkout-shipping-choice'),(901394,'furniture','.w-text .customer-service','top','5','3','','.w-text'),(901395,'furniture','.w-socials .post_item > div','top','10','3','','.w-socials'),(901396,'furniture','.w-product-reviews .reviews-list span','top','2','','','.w-product-reviews'),(901397,'furniture','.b-select-suggest .select2-search-choice-close','top','4','','','.b-select-suggest'),(901398,'furniture','.w-image-maps .svg-wrap svg','top','0','','','.w-image-maps'),(901399,'furniture','.w-neighbour-checkout .bootstrap-switch','top','-2','','','.w-neighbour-checkout'),(901400,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow','top','0','','','.b-select-suggest'),(901401,'furniture','.b-select-suggest .select2-drop-mask','top','0','','','.b-select-suggest'),(901402,'furniture','.b-select-suggest .select2-drop','top','100','','','.b-select-suggest'),(901403,'furniture','.w-text .customer-service','top','5','3','','.w-text'),(901404,'furniture','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(901406,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','top','4','3','','.b-switch'),(901407,'furniture','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(901408,'furniture','.w-checkout-create-account .account-benefits strong','top','3','3','','.w-checkout-create-account'),(901409,'furniture','.w-promo-code .holder','top','19','3','','.w-promo-code'),(901410,'furniture','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(901411,'furniture','.w-account-addresses-list .address-fields input[type=\"radio\"]','top','4','','','.w-account-addresses-list'),(901412,'furniture','.b-products-listing .products-listing .promos-info','top','0','','','.b-products-listing'),(901413,'furniture','.b-products-listing .hover-box-content','top','-10','3','','.b-products-listing'),(901414,'furniture','.b-products-listing .hover-box-content','top','40','','','.b-products-listing'),(901415,'furniture','.b-products-listing .loader','top','calc(50% - 15px)','4','','.b-products-listing'),(901416,'furniture','.b-products-listing .loader','top','0','3','','.b-products-listing'),(901417,'furniture','.b-products-listing .products-listing .qty-input.hidden','top','0','3','','.b-products-listing'),(901418,'furniture','.b-products-listing .promo','top','0','','','.b-products-listing'),(901423,'furniture','.w-promo-code .holder','top','19','3','','.w-promo-code'),(901424,'furniture','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(901425,'furniture','.w-checkout-gdpr .candlestick-wrapper','top','0','','','.w-checkout-gdpr'),(901426,'furniture','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(901427,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(901428,'furniture','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(901429,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','top','0','','','.b-switch'),(901430,'furniture','.b-form .eye-password','top','5','','','.b-form'),(901431,'furniture','.w-taxable input[type=\"radio\"]','top','2','','','.w-taxable'),(901432,'furniture','.w-taxable input[type=\"checkbox\"]','top','2','','','.w-taxable'),(901433,'furniture','.b-form .radio-button + .required-message-wrap .required-message','top','-5','','','.b-form'),(901434,'furniture','.b-products-listing .products-listing .radio-attributes input','top','2','','','.b-products-listing'),(901437,'furniture','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(901438,'furniture','.w-promo-code .holder','top','19','3','','.w-promo-code'),(901439,'furniture','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(901440,'furniture','.w-cart-listing .remove-btn span','top','0','5140','','.w-cart-listing'),(901442,'furniture','.b-upload-file .upload-remove','top','5','','','.b-upload-file'),(901443,'furniture','.b-fancybox .fancybox-nav span','top','50','','','.b-fancybox'),(901444,'furniture','.b-fancybox .fancybox-nav','top','0','','','.b-fancybox'),(901445,'furniture','.b-form .addresses .address-item input[type=\"radio\"]','top','3','','','.b-form'),(901446,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(901447,'furniture','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(901448,'furniture','.b-bottom .pop-up-close','top','7','','','.b-bottom'),(901449,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-container','top','0','','','.b-switch'),(901450,'furniture','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(901451,'furniture','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(901452,'furniture','.b-fancybox .fancybox-wrap','top','0','','','.b-fancybox'),(901453,'furniture','.w-menu-big > ul > li > ul','top','100','','','.w-menu-big'),(901454,'furniture','.b-select-suggest .select2-container .select2-choice abbr','top','8','','','.b-select-suggest'),(901455,'furniture','.w-filters .mobileCollapse','top','1','','','.w-filters'),(901456,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','top','0','','','.w-image-maps'),(901457,'furniture','.b-product-images .media-popup .mp-close','top','20','','','.b-product-images'),(901458,'furniture','.b-product-images .mp-shadow, .b-product-images .media-popup','top','0','','','.b-product-images'),(901459,'furniture','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top','100','','','.b-menu-lev_display-down'),(901460,'furniture','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top','100','','','.b-menu-lev_display-down'),(901461,'furniture','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top','100','','','.b-menu-lev_display-down'),(901462,'furniture','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top','100','','','.b-menu-lev_display-down'),(901463,'furniture','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top','100','','','.b-menu-lev_display-down'),(901464,'furniture','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','top','0','','','.b-menu-lev_display-left'),(901465,'furniture','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','top','0','','','.b-menu-lev_display-left'),(901466,'furniture','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','top','0','','','.b-menu-lev_display-left'),(901467,'furniture','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','top','0','','','.b-menu-lev_display-left'),(901468,'furniture','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','top','0','','','.b-menu-lev_display-left'),(901469,'furniture','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','top','0','','','.b-menu-lev_display-lra'),(901470,'furniture','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','top','0','','','.b-menu-lev_display-lra'),(901471,'furniture','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','top','0','','','.b-menu-lev_display-lra'),(901472,'furniture','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','top','0','','','.b-menu-lev_display-lra'),(901473,'furniture','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','top','0','','','.b-menu-lev_display-lra'),(901474,'furniture','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','top','0','','','.b-menu-lev_display-right'),(901475,'furniture','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','top','0','','','.b-menu-lev_display-right'),(901476,'furniture','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','top','0','','','.b-menu-lev_display-right'),(901477,'furniture','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','top','0','','','.b-menu-lev_display-right'),(901478,'furniture','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','top','0','','','.b-menu-lev_display-right'),(901479,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','top','0','','','.b-menu-lev_display-slide'),(901480,'furniture','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','top','0','','','.b-menu-lev_display-slide'),(901481,'furniture','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','top','0','','','.b-menu-lev_display-slide'),(901482,'furniture','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','top','0','','','.b-menu-lev_display-slide'),(901483,'furniture','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','top','0','','','.b-menu-lev_display-slide'),(901484,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','top','0','','','.b-menu-open_from-left'),(901485,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','top','0','','','.b-menu-style-2'),(901486,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','top','50','3','','.b-menu-style-2'),(901487,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','top','0','','','.b-menu-style-2'),(901488,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','top','50','3','','.b-menu-style-2'),(901491,'furniture','.b-slick .slick-track','top','0','','','.b-slick'),(901492,'furniture','.b-slick .slick-vertical button.slick-next','top','auto','','','.b-slick'),(901493,'furniture','.b-slick .slick-vertical button.slick-prev','top','0','','','.b-slick'),(901494,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','top','50','','','.b-slick'),(901495,'furniture','.menu-header .w-menu','top','-48','5140','','.menu-header'),(901496,'furniture','.header','top','0','5140','',''),(901497,'furniture','.b-products-listing .del-from-personal-catalog','top','2','3','','.b-products-listing'),(901498,'furniture','.cartTitle >div','top','50','3','','.cartTitle'),(901499,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','top','100','','','.b-products-listing'),(901500,'furniture','.w-quote .multicart .switch-cart','top','14','','','.w-quote'),(901502,'furniture','h1, .heading-1','top','-10','3','',''),(901503,'furniture','h1, .heading-1','top','-10','4','',''),(901504,'furniture','.warrantyProduct .warranty','top','calc(50% - 16px)','3','','.warrantyProduct'),(901505,'furniture','.warrantyProduct .delivery','top','calc(50% - 15px)','3','','.warrantyProduct'),(901506,'furniture','.w-files-catalog-widgets-files-list .file','top','-1','3','','.w-files-catalog-widgets-files-list'),(901507,'furniture','.w-sample .multicart .switch-cart','top','14','','','.w-sample'),(901508,'furniture','.w-sample .qty','top','-1','4','','.w-sample'),(901509,'furniture','.w-cart-listing .points-earn','top','0','4','','.w-cart-listing'),(901510,'furniture','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(901511,'furniture','.w-product-inventory input[type=\"radio\"]','top','1','','','.w-product-inventory'),(901513,'furniture','.heading-2','top','-10','3','',''),(901514,'furniture','.heading-2','top','-10','4','',''),(901515,'furniture','.w-product-properties-filters-widgets-chosen-filters .remove','top','2','3','','.w-product-properties-filters-widgets-chosen-filters'),(901516,'furniture','.p-quote-checkout-index .order-summary .heading-2','top','-10','3','','.p-quote-checkout-index'),(901517,'furniture','.p-quote-checkout-index .order-summary .heading-2','top','-10','4','','.p-quote-checkout-index'),(901518,'furniture','.p-sample-checkout-index .order-summary .heading-2','top','-10','3','','.p-sample-checkout-index'),(901519,'furniture','.p-sample-checkout-index .order-summary .heading-2','top','-10','4','','.p-sample-checkout-index'),(901520,'furniture','.w-account-personal-catalog .list-row-action ul','top','5','4','','.w-account-personal-catalog'),(901521,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input','top','-50','','','.w-questionnaire-widgets-questionnaire'),(901522,'furniture','.w-sale-category .badge','top','10','','','.w-sale-category'),(901523,'furniture','.w-product-properties-icons .hover-box-content','top','50','','','.w-product-properties-icons'),(901524,'furniture','.w-product-designer-designer .productDesignerBox input','top','0','','','.w-product-designer-designer'),(901525,'furniture','.w-product-configurator .pc-item label input','top','5','','','.w-product-configurator'),(901526,'furniture','.w-predefined-promotion .prom-multi-discount .products','top','-13','','','.w-predefined-promotion'),(901527,'furniture','.w-predefined-promotion .prom-multi-discount > .heading','top','2','3','','.w-predefined-promotion'),(901528,'furniture','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','top','2','3','','.w-predefined-promotion'),(901529,'furniture','.w-predefined-promotion .promo-cart-discount .promo-min-qty','top','-19','','','.w-predefined-promotion'),(901530,'furniture','.w-predefined-promotion .promo-cart-discount .slave .content','top','-17','','','.w-predefined-promotion'),(901531,'furniture','.w-predefined-promotion .promo-date','top','-10','','','.w-predefined-promotion'),(901532,'furniture','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','top','2','3','','.w-predefined-promotion'),(901533,'furniture','.mainBanner .topBox > .right','top','50','4','','.mainBanner'),(901534,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','top','0','','','.mainBanner'),(901535,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','top','0','','','.mainBanner'),(901536,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','top','0','','','.mainBanner'),(901537,'furniture','.order-summary .icon','top','0','3','','.order-summary'),(901551,'furniture','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','top','2','3','','.account-order-pay'),(901552,'furniture','.account-order-pay .not_fully_paid_td','top','19','','','.account-order-pay'),(901553,'furniture','.account-samples .not_fully_paid_td','top','19','','','.account-samples'),(901554,'furniture','.account-samples .view_link','top','4','4','','.account-samples'),(901555,'furniture','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','top','2','3','','.account-sample-info'),(901556,'furniture','.account-sample-info .not_fully_paid_td','top','19','','','.account-sample-info'),(901557,'furniture','.catalog-product-wrap .pn-image','top','120','3','','.catalog-product-wrap'),(901558,'furniture','.catalog-product-wrap .prev-next-product','top','calc(50% - 200px)','','','.catalog-product-wrap'),(901559,'furniture','.checkout-index-wrap .order-ico','top','7','3','','.checkout-index-wrap'),(901560,'furniture','.checkout-index-wrap .order-summary .heading-2','top','-10','3','','.checkout-index-wrap'),(901561,'furniture','.checkout-index-wrap .order-summary .heading-2','top','-10','4','','.checkout-index-wrap'),(901562,'furniture','.checkout-order-confirmation .comment-ico','top','7','3','','.checkout-order-confirmation'),(901563,'furniture','.checkout-order-confirmation .discount-ico','top','3','3','','.checkout-order-confirmation'),(901564,'furniture','.checkout-order-confirmation .order-ico','top','7','3','','.checkout-order-confirmation'),(901565,'furniture','.shopping-cart-index .gift-code .heading-4','top','0','4','','.shopping-cart-index'),(901566,'furniture','.b-info .info','top','3','3','','.b-info'),(901567,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','top','-2','4','','.b-multi-page-checkout'),(901568,'furniture','.success-page .comment-ico','top','7','3','','.success-page'),(901569,'furniture','.success-page .discount-ico','top','3','3','','.success-page'),(901570,'furniture','.success-page .order-ico','top','7','3','','.success-page'),(901571,'furniture','.success-page .page-success .text-1','top','7','3','','.success-page'),(901572,'furniture','.success-page .w-cart-listing .qty','top','10','','','.success-page'),(901573,'furniture','.menu-header .menu-style[data-style=\"1\"] .goto-button','top','8','','','.menu-header'),(901574,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li','top','16','5140,3','','.footer-menu'),(901575,'furniture','.tripleBanner .w-html_box','top','0','3','','.tripleBanner'),(901576,'furniture','.w-banner .banner img + img','top','0','','','.w-banner'),(901577,'furniture','.w-banner .carousel-text','top','0','','','.w-banner'),(901578,'furniture','.w-banner .image-text-banner.bottom-center .text-banner','top','auto','','','.w-banner'),(901579,'furniture','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','top','0','','','.w-banner'),(901580,'furniture','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','top','0','','','.w-banner'),(901581,'furniture','.w-banner .image-text-banner.top-left .text-banner','top','0','','','.w-banner'),(901582,'furniture','.w-banner .image-text-banner.top-right .text-banner','top','0','','','.w-banner'),(901583,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top','0','','','.w-catalog-paging'),(901584,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top_important','important','','','.b-select-suggest'),(901585,'furniture','.heading-2','top_important','important','3','',''),(901586,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top_important','important','','','.w-catalog-paging'),(901587,'furniture','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(901589,'furniture','.b-fancybox #fancybox-loading','top_measure','%','','','.b-fancybox'),(901590,'furniture','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(901591,'furniture','.view-all','top_measure','%','3','',''),(901592,'furniture','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(901593,'furniture','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(901594,'furniture','.w-menu-horizontal > ul > li > ul','top_measure','%','','','.w-menu-horizontal'),(901595,'furniture','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(901596,'furniture','.b-select-suggest .select2-drop','top_measure','%','','','.b-select-suggest'),(901597,'furniture','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(901598,'furniture','.b-fancybox .fancybox-nav span','top_measure','%','','','.b-fancybox'),(901599,'furniture','.w-menu-big > ul > li > ul','top_measure','%','','','.w-menu-big'),(901600,'furniture','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top_measure','%','','','.b-menu-lev_display-down'),(901601,'furniture','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top_measure','%','','','.b-menu-lev_display-down'),(901602,'furniture','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top_measure','%','','','.b-menu-lev_display-down'),(901603,'furniture','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top_measure','%','','','.b-menu-lev_display-down'),(901604,'furniture','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top_measure','%','','','.b-menu-lev_display-down'),(901605,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','top_measure','%','3','','.b-menu-style-2'),(901606,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','top_measure','%','3','','.b-menu-style-2'),(901607,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','top_measure','%','','','.b-slick'),(901608,'furniture','.cartTitle >div','top_measure','%','3','','.cartTitle'),(901609,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','top_measure','%','','','.b-products-listing'),(901612,'furniture','.w-product-properties-icons .hover-box-content','top_measure','%','','','.w-product-properties-icons'),(901613,'furniture','.mainBanner .topBox > .right','top_measure','%','4','','.mainBanner'),(901615,'furniture','.b-slick .slick-slider','touch-action','pan-y','','','.b-slick'),(901616,'furniture','.b-products-listing .hover-box-content','transform','rotate( 45deg )','3','','.b-products-listing'),(901617,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-container','transform','translate3d(0, 0, 0)','','','.b-switch'),(901618,'furniture','.b-product-images .media-popup .mp-close','transform','scale(1.5)','1','','.b-product-images'),(901619,'furniture','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','transform','scale(1.2)','1','','.b-product-images'),(901620,'furniture','.b-product-images .media-popup .slick-list:first-child .slick-track','transform','none','','','.b-product-images'),(901621,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','transform','scale(1.5)','1','','.b-product-images'),(901622,'furniture','.b-menu-lev_display-slide .menu-style .slide-parent','transform','translateX(-100vw)','','','.b-menu-lev_display-slide'),(901623,'furniture','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','transform','translate3d(0, 0, 0)','','','.b-slick'),(901624,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','transform','translate(-50%, 0)','','','.mainBanner'),(901625,'furniture','.b-product-images .media-popup .slick-list:first-child .slick-track','transform_important','important','','','.b-product-images'),(901626,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','transition','0.3s','','','.b-switch'),(901627,'furniture','.b-switch .bootstrap-switch','transition','border-color ease-in-out .15s, box-shadow ease-in-out .15s','','','.b-switch'),(901628,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-animate .bootstrap-switch-container','transition','margin-left 0.5s','','','.b-switch'),(901629,'furniture','.b-product-images .media-popup .mp-close','transition','transform 0.3s, color 0.3s','','','.b-product-images'),(901630,'furniture','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','transition','transform 0.3s','','','.b-product-images'),(901631,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','transition','transform 0.3s, color 0.3s','','','.b-product-images'),(901632,'furniture','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','transition','max-height 1s','','','.b-menu-burger_icon'),(901633,'furniture','.b-menu-lev_display-slide .menu-style ul','transition','visibility 300ms, transform 300ms','','','.b-menu-lev_display-slide'),(901634,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','transition','left 300ms','','','.b-menu-open_from-left'),(901636,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','user-select','none','','','.b-select-suggest'),(901637,'furniture','.b-select-suggest .select2-results .select2-result-label','user-select','none','','','.b-select-suggest'),(901638,'furniture','.b-select-suggest .select2-container .select2-choice','user-select','none','','','.b-select-suggest'),(901639,'furniture','.b-slick .slick-slider','user-select','none','','','.b-slick'),(901640,'furniture','.b-email .name','vertical-align','top','','','.b-email'),(901641,'furniture','.w-tabs .tab-li.tab-cart a','vertical-align','middle','3','','.w-tabs'),(901642,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.p-quick-order-index'),(901643,'furniture','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.p-quick-order-index'),(901644,'furniture','.b-email .model','vertical-align','top','','','.b-email'),(901645,'furniture','.w-categories .item','vertical-align','top','','','.w-categories'),(901646,'furniture','.w-promotions .heading-3','vertical-align','top','','','.w-promotions'),(901647,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','vertical-align','top','','','.b-warehouses-popup'),(901648,'furniture','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(901649,'furniture','.b-upload-file .upload-file-template','vertical-align','top','','','.b-upload-file'),(901650,'furniture','.b-messages .msv_to_cc div span','vertical-align','middle','','','.b-messages'),(901651,'furniture','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(901652,'furniture','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(901653,'furniture','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(901654,'furniture','.b-email .price','vertical-align','top','','','.b-email'),(901655,'furniture','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(901656,'furniture','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(901657,'furniture','.b-switch .bootstrap-switch','vertical-align','middle','','','.b-switch'),(901658,'furniture','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','vertical-align','middle','','','.w-menu-horizontal'),(901659,'furniture','.w-filters .input-checkbox:checked + .checkbox-span','vertical-align','middle','','','.w-filters'),(901660,'furniture','.b-email .name','vertical-align','top','','','.b-email'),(901661,'furniture','.b-email .qty','vertical-align','top','','','.b-email'),(901662,'furniture','.b-email .image','vertical-align','top','','','.b-email'),(901663,'furniture','.b-form .checkbox-style:checked + .checkbox-span','vertical-align','middle','','','.b-form'),(901664,'furniture','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','vertical-align','middle','','','.b-form'),(901665,'furniture','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(901666,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','vertical-align','top','','','.b-switch'),(901667,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','vertical-align','middle','','','.b-switch'),(901668,'furniture','.b-switch .candlestick-wrapper','vertical-align','middle','','','.b-switch'),(901669,'furniture','.order-summary .price-row.ot_gv .title','vertical-align','top','3','','.order-summary'),(901670,'furniture','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(901671,'furniture','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(901672,'furniture','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(901673,'furniture','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(901674,'furniture','.w-tabs .tab-li.tab-wishlist a','vertical-align','middle','3','','.w-tabs'),(901675,'furniture','.w-tabs .tab-li','vertical-align','bottom','','','.w-tabs'),(901676,'furniture','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(901677,'furniture','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(901678,'furniture','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(901679,'furniture','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(901680,'furniture','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(901681,'furniture','.b-email .image','vertical-align','top','','','.b-email'),(901682,'furniture','.w-checkout-billing-address .genders-title > div','vertical-align','top','','','.w-checkout-billing-address'),(901683,'furniture','.w-checkout-shipping-address .genders-title > div','vertical-align','top','','','.w-checkout-shipping-address'),(901684,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span','vertical-align','middle','','','.b-form'),(901685,'furniture','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(901686,'furniture','.b-email .qty','vertical-align','top','','','.b-email'),(901687,'furniture','.b-email .price','vertical-align','top','','','.b-email'),(901688,'furniture','.b-email .price','vertical-align','top','','','.b-email'),(901689,'furniture','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(901690,'furniture','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(901691,'furniture','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(901692,'furniture','.w-top-categories .item','vertical-align','top','','','.w-top-categories'),(901693,'furniture','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(901694,'furniture','.b-email .qty','vertical-align','top','','','.b-email'),(901695,'furniture','.b-email .name','vertical-align','top','','','.b-email'),(901696,'furniture','.b-email .model','vertical-align','top','','','.b-email'),(901697,'furniture','.b-email .price','vertical-align','top','','','.b-email'),(901698,'furniture','.b-email .image','vertical-align','top','','','.b-email'),(901699,'furniture','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(901700,'furniture','.w-cart-discount-coupon .btn','vertical-align','top','','','.w-cart-discount-coupon'),(901701,'furniture','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(901702,'furniture','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(901703,'furniture','.b-email .price','vertical-align','top','','','.b-email'),(901704,'furniture','.b-email .model','vertical-align','top','','','.b-email'),(901705,'furniture','.b-email .model','vertical-align','top','','','.b-email'),(901706,'furniture','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(901707,'furniture','.b-email .model','vertical-align','top','','','.b-email'),(901708,'furniture','.b-compare .compare_select_items','vertical-align','middle','','','.b-compare'),(901709,'furniture','.b-email .name','vertical-align','top','','','.b-email'),(901710,'furniture','.b-email .image','vertical-align','top','','','.b-email'),(901711,'furniture','.w-tabs .tab-li.tab-quote a','vertical-align','middle','3','','.w-tabs'),(901712,'furniture','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(901713,'furniture','.b-email .price','vertical-align','top','','','.b-email'),(901714,'furniture','.w-cart-compare .product-label','vertical-align','bottom','','','.w-cart-compare'),(901715,'furniture','.w-product-available-in-warehouses .warehouse-item','vertical-align','top','','','.w-product-available-in-warehouses'),(901716,'furniture','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(901717,'furniture','.w-cart-compare .product-actions .dropdown-toggle','vertical-align','middle','3','','.w-cart-compare'),(901718,'furniture','.w-menu-big li li','vertical-align','top','','','.w-menu-big'),(901719,'furniture','.w-cart-compare .product-cell','vertical-align','top','','','.w-cart-compare'),(901720,'furniture','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(901721,'furniture','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(901722,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.b-data-table'),(901723,'furniture','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.b-data-table'),(901724,'furniture','.b-products-listing .products-listing .item','vertical-align','top','','','.b-products-listing'),(901725,'furniture','.checkbox input + span','vertical-align','middle','','',''),(901726,'furniture','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(901727,'furniture','.b-email .name','vertical-align','top','','','.b-email'),(901728,'furniture','.b-email .image','vertical-align','top','','','.b-email'),(901729,'furniture','.b-email .qty','vertical-align','top','','','.b-email'),(901730,'furniture','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(901731,'furniture','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(901732,'furniture','.order-summary .price-row.ot_coupon .title','vertical-align','top','3','','.order-summary'),(901733,'furniture','.w-tabs .tab-li.tab-sample a','vertical-align','middle','3','','.w-tabs'),(901734,'furniture','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(901735,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','','','.w-communication-new-topic'),(901736,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','3','','.w-communication-new-topic'),(901737,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','vertical-align','top','','','.w-communication-new-topic'),(901738,'furniture','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','vertical-align','bottom','','','.w-communication-new-topic'),(901739,'furniture','.w-quote .no-text','vertical-align','top','','','.w-quote'),(901740,'furniture','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(901741,'furniture','.b-email .qty','vertical-align','top','','','.b-email'),(901742,'furniture','.b-email .name','vertical-align','top','','','.b-email'),(901743,'furniture','.b-email .image','vertical-align','top','','','.b-email'),(901744,'furniture','.w-catalog-listing-look .grid','vertical-align','top','','','.w-catalog-listing-look'),(901745,'furniture','.w-catalog-listing-look .b2b','vertical-align','top','','','.w-catalog-listing-look'),(901746,'furniture','.w-catalog-listing-look .list','vertical-align','top','','','.w-catalog-listing-look'),(901747,'furniture','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(901749,'furniture','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','vertical-align','top','','','.b-fancybox'),(901750,'furniture','.b-email .model','vertical-align','top','','','.b-email'),(901751,'furniture','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(901752,'furniture','.order-summary .price-row.ot_bonus_points .title','vertical-align','top','3','','.order-summary'),(901753,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align','top','','','.b-switch'),(901754,'furniture','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','vertical-align','top','','','.b-fancybox'),(901755,'furniture','.w-menu-big li a, .w-menu-big li .no-link','vertical-align','middle','','','.w-menu-big'),(901756,'furniture','.b-email .qty','vertical-align','top','','','.b-email'),(901757,'furniture','.w-filters .input-checkbox:not(checked) + .checkbox-span','vertical-align','middle','','','.w-filters'),(901758,'furniture','.b-product-images .media-popup .mp-small-images .item','vertical-align','top','','','.b-product-images'),(901759,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','vertical-align','middle','3','','.w-catalog-compare'),(901760,'furniture','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','vertical-align','middle','','','.b-cookie-notice'),(901761,'furniture','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(901762,'furniture','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(901763,'furniture','.b-quantity .qty-box input','vertical-align','top','','','.b-quantity'),(901764,'furniture','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(901765,'furniture','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(901766,'furniture','.w-sample .no-text','vertical-align','top','','','.w-sample'),(901767,'furniture','.w-cart-order-reference .btn','vertical-align','top','','','.w-cart-order-reference'),(901768,'furniture','.w-cart-gift-certificate .btn','vertical-align','top','','','.w-cart-gift-certificate'),(901769,'furniture','.w-cart-shipping-estimator .btn','vertical-align','top','','','.w-cart-shipping-estimator'),(901771,'furniture','.b-pagination .pagination .next-pages','vertical-align','top','','','.b-pagination'),(901772,'furniture','.b-pagination .pagination .page-number','vertical-align','top','','','.b-pagination'),(901773,'furniture','.b-pagination .pagination .prev-pages','vertical-align','top','','','.b-pagination'),(901774,'furniture','.b-pagination .pagination a.next, .b-pagination .pagination span.next','vertical-align','top','','','.b-pagination'),(901775,'furniture','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','vertical-align','top','','','.b-pagination'),(901776,'furniture','.b-pagination .pagination span','vertical-align','top','2','','.b-pagination'),(901777,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','vertical-align','top','','','.w-rma-returns-history'),(901778,'furniture','.w-product-configurator .item-content > div','vertical-align','top','','','.w-product-configurator'),(901779,'furniture','.w-predefined-promotion .heading-3','vertical-align','top','','','.w-predefined-promotion'),(901780,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','vertical-align','middle','','','.w-filters'),(901781,'furniture','.mainBanner .topBox > .left','vertical-align','middle','','','.mainBanner'),(901782,'furniture','.mainBanner .topBox > .right','vertical-align','middle','','','.mainBanner'),(901783,'furniture','.mainBanner .topBox > .right','vertical-align','middle','3','','.mainBanner'),(901784,'furniture','.mainBanner .topBox > .right','vertical-align','middle','4','','.mainBanner'),(901785,'furniture','.w-cart-discount-coupon .title','vertical-align','middle','4','','.w-cart-discount-coupon'),(901786,'furniture','.w-cart-checkout-btn .with-card','vertical-align','middle','4','','.w-cart-checkout-btn'),(901787,'furniture','.w-promotions-widgets-promotion-icons-desc .promo-icon','vertical-align','top','','','.w-promotions-widgets-promotion-icons-desc'),(901788,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','vertical-align','top','','','.w-promotions-widgets-promotion-icons-desc'),(901792,'furniture','.account-samples .view_link','vertical-align','middle','4','','.account-samples'),(901793,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','vertical-align','middle','3','','.b-multi-page-checkout'),(901794,'furniture','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','vertical-align','middle','','','.w-banner'),(901795,'furniture','.w-catalog-paging ','vertical-align','top','2','','.w-catalog-paging'),(901796,'furniture','.w-catalog-paging .next','vertical-align','top','','','.w-catalog-paging'),(901797,'furniture','.w-catalog-paging .next-pages','vertical-align','top','','','.w-catalog-paging'),(901798,'furniture','.w-catalog-paging .page-number','vertical-align','top','','','.w-catalog-paging'),(901799,'furniture','.w-catalog-paging .prev','vertical-align','top','','','.w-catalog-paging'),(901800,'furniture','.w-catalog-paging .prev-pages','vertical-align','top','','','.w-catalog-paging'),(901801,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','vertical-align','top','','','.w-catalog-paging'),(901802,'furniture','.w-compare-box-item .checkbox','vertical-align','top','','','.w-compare-box-item'),(901803,'furniture','.w-compare-box-item .checkbox + span','vertical-align','middle','','','.w-compare-box-item'),(901804,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align_important','important','','','.b-switch'),(901805,'furniture','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(901806,'furniture','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(901807,'furniture','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(901808,'furniture','.b-fancybox .fancybox-tmp','visibility','hidden','','','.b-fancybox'),(901809,'furniture','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(901810,'furniture','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(901811,'furniture','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(901812,'furniture','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(901813,'furniture','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(901814,'furniture','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(901815,'furniture','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(901816,'furniture','.b-upload-files .attach-active-holder .attach-file','visibility','hidden','','','.b-upload-files'),(901817,'furniture','.b-fancybox .fancybox-nav:hover span','visibility','visible','','','.b-fancybox'),(901818,'furniture','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(901819,'furniture','.b-fancybox .fancybox-opened .fancybox-title','visibility','visible','','','.b-fancybox'),(901820,'furniture','.checkbox input','visibility','hidden','','',''),(901821,'furniture','.b-fancybox .fancybox-title','visibility','hidden','','','.b-fancybox'),(901822,'furniture','.b-fancybox .fancybox-nav span','visibility','hidden','','','.b-fancybox'),(901823,'furniture','.b-form .radio-button input[type=\"radio\"].no','visibility','hidden','','','.b-form'),(901824,'furniture','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(901825,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','visibility','hidden','','','.b-menu-lev_display-slide'),(901826,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-1 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(901827,'furniture','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','visibility','hidden','','','.b-menu-lev_display-slide'),(901828,'furniture','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','visibility','hidden','','','.b-menu-lev_display-slide'),(901829,'furniture','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','visibility','hidden','','','.b-menu-lev_display-slide'),(901830,'furniture','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','visibility','hidden','','','.b-menu-lev_display-slide'),(901831,'furniture','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-2 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(901832,'furniture','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-4 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(901833,'furniture','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-5 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(901834,'furniture','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-3 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(901835,'furniture','.b-slick .slick-loading .slick-slide','visibility','hidden','','','.b-slick'),(901836,'furniture','.b-slick .slick-loading .slick-track','visibility','hidden','','','.b-slick'),(901837,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no input','visibility','hidden','','','.w-questionnaire-widgets-questionnaire'),(901838,'furniture','.w-compare-box-item .checkbox:not(checked)','visibility','hidden','','','.w-compare-box-item'),(901839,'furniture','.b-fancybox .fancybox-title-float-wrap .child','white-space','nowrap','','','.b-fancybox'),(901840,'furniture','.w-checkout-shipping-choice span','white-space','nowrap','5161','','.w-checkout-shipping-choice'),(901841,'furniture','.b-select-suggest .select2-container .select2-choice > .select2-chosen','white-space','nowrap','','','.b-select-suggest'),(901842,'furniture','.w-menu-horizontal > ul','white-space','nowrap','','','.w-menu-horizontal'),(901843,'furniture','.w-menu-horizontal > ul','white-space','normal','5140','','.w-menu-horizontal'),(901844,'furniture','.b-fancybox .fancybox-error','white-space','nowrap','','','.b-fancybox'),(901845,'furniture','.w-catalog-sorting .before','white-space','nowrap','','','.w-catalog-sorting'),(901846,'furniture','.b-select-suggest .select2-search','white-space','nowrap','','','.b-select-suggest'),(901847,'furniture','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','white-space','nowrap','','','.b-select-suggest'),(901848,'furniture','.b-select-suggest .select2-container .select2-choice','white-space','nowrap','','','.b-select-suggest'),(901849,'furniture','.w-cart-listing .remove-btn','white-space','nowrap','5140','','.w-cart-listing'),(901850,'furniture','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(901851,'furniture','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','white-space','nowrap','','','.w-cart-listing'),(901854,'furniture','.account-samples .view_link','white-space','nowrap','','','.account-samples'),(901855,'furniture','.w-communication-new-topic .model','width','100','','','.w-communication-new-topic'),(901856,'furniture','.w-communication-new-topic .date-purchased','width','130','','','.w-communication-new-topic'),(901857,'furniture','.w-communication-new-topic .request-type','width','150','','','.w-communication-new-topic'),(901858,'furniture','.w-communication-new-topic .return-reason','width','150','','','.w-communication-new-topic'),(901859,'furniture','.b-form .col-left','width','50','','','.b-form'),(901860,'furniture','.b-email img','width','60','','','.b-email'),(901861,'furniture','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(901862,'furniture','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(901863,'furniture','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(901864,'furniture','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(901865,'furniture','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(901866,'furniture','.w-product-images-additional .item','width','80','5161','','.w-product-images-additional'),(901868,'furniture','.b-email .totals-value','width','30','','','.b-email'),(901869,'furniture','.w-promotions .prom-multi-discount .image img','width','auto','','','.w-promotions'),(901870,'furniture','.w-promotions .promo-salemaker > div','width','50','','','.w-promotions'),(901871,'furniture','.w-promotions .promo-cart-discount > div','width','50','','','.w-promotions'),(901876,'furniture','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width','100','','','.p-sample-checkout-login'),(901877,'furniture','.b-email .image','width','100','','','.b-email'),(901878,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(901879,'furniture','.w-categories .item','width','25','','','.w-categories'),(901880,'furniture','.w-promotions .prom-multi-discount .list','width','100','','','.w-promotions'),(901881,'furniture','.w-promotions .nextdiscount .item-holder .image','width','40','','','.w-promotions'),(901882,'furniture','.w-promotions .nextdiscount .item-holder .name','width','60','','','.w-promotions'),(901883,'furniture','.w-promotions .icon','width','45','','','.w-promotions'),(901884,'furniture','.w-promotions .promo-salemaker .image img','width','auto','','','.w-promotions'),(901885,'furniture','.w-promotions .promo-salemaker .item','width','50','','','.w-promotions'),(901886,'furniture','.w-promotions .promo-cart-discount .slave .item','width','calc(50% - 4px)','','','.w-promotions'),(901887,'furniture','.w-promotions .promo-cart-discount .image img','width','auto','','','.w-promotions'),(901888,'furniture','.b-warehouses-popup .warehouses-popup','width','570','','','.b-warehouses-popup'),(901889,'furniture','.b-warehouses-popup .warehouses-popup .warehouse-item','width','230','','','.b-warehouses-popup'),(901890,'furniture','.b-preloader .preloader','width','40','3','','.b-preloader'),(901891,'furniture','.b-preloader .preloader','width','100','','','.b-preloader'),(901892,'furniture','.b-products-listing .products-listing .attribute-qty-block','width','47','','','.b-products-listing'),(901893,'furniture','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(901894,'furniture','.w-brands .brands-listing > div','width','16','','','.w-brands'),(901895,'furniture','.w-cart-continue-btn a','width','100','5131','','.w-cart-continue-btn'),(901896,'furniture','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(901897,'furniture','.order-summary .price-row.ot_gv .title','width','32','3','','.order-summary'),(901898,'furniture','.w-brands .brands-listing > div','width','16','','','.w-brands'),(901899,'furniture','.w-login-block .returning','width','50','','','.w-login-block'),(901900,'furniture','.w-product-images-additional .item','width','80','5161','','.w-product-images-additional'),(901901,'furniture','.w-product-images-additional .additional-images','width','80','5161','','.w-product-images-additional'),(901902,'furniture','.b-products-listing .select-attributes select','width','66','','','.b-products-listing'),(901903,'furniture','.b-messages .box-block.type-6 > .block:nth-child(1)','width','25','','','.b-messages'),(901904,'furniture','.b-messages .msv_to_cc div span.msv_to_cc_bold','width','100','','','.b-messages'),(901905,'furniture','.b-messages .messages-sidebar .btn-2','width','100','','','.b-messages'),(901906,'furniture','.b-messages .pre_upload','width','auto','','','.b-messages'),(901907,'furniture','.b-messages .email-line input','width','100','','','.b-messages'),(901908,'furniture','.b-messages .email-line label','width','150','','','.b-messages'),(901909,'furniture','.b-messages #DataTables_Table_0_wrapper table.dataTable thead td:last-child, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td:last-child','width','200','','','.b-messages'),(901910,'furniture','.w-sitemap-delivery-location > ul > li > ul > li','width','25','','','.w-sitemap-delivery-location'),(901912,'furniture','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(901913,'furniture','.b-bottom .terms-info-popup','width','1000','','','.b-bottom'),(901914,'furniture','.b-form .col-right','width','100','5140','','.b-form'),(901915,'furniture','.p-payer-order-confirmation .order-summary2 .btn-2','width','100','','','.p-payer-order-confirmation'),(901916,'furniture','.p-payer-order-confirmation .dob-hide > div','width','48','','','.p-payer-order-confirmation'),(901917,'furniture','.p-payer-order-pay .order-summary2 .btn-2','width','100','','','.p-payer-order-pay'),(901918,'furniture','.p-payer-order-pay .dob-hide > div','width','48','','','.p-payer-order-pay'),(901919,'furniture','.w-checkout-terms .required-message','width','100','','','.w-checkout-terms'),(901920,'furniture','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(901921,'furniture','.w-checkout-create-btn .btn-2','width','260','','','.w-checkout-create-btn'),(901922,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','width','15','','','.b-switch'),(901923,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-toggle','width','40','','','.b-switch'),(901924,'furniture','.b-fancybox #fancybox-loading div','width','44','','','.b-fancybox'),(901925,'furniture','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','width','79','','','.b-datepicker'),(901926,'furniture','.b-email .image','width','100','','','.b-email'),(901927,'furniture','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','width','25','3','','.w-checkout-contact-information'),(901928,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','width','100','','','.b-switch'),(901929,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','width','15','','','.b-switch'),(901930,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width','20','3','','.b-switch'),(901931,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','width','150','','','.w-upload-customer-id-upload-customer-id-form'),(901932,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(901933,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-details','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(901934,'furniture','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(901935,'furniture','.b-email .image','width','100','','','.b-email'),(901936,'furniture','.w-checkout-bonus-points .btn-remove','width','25','','','.w-checkout-bonus-points'),(901937,'furniture','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(901938,'furniture','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(901939,'furniture','.w-login-block .input','width','100','','','.w-login-block'),(901940,'furniture','.w-login-block .guest','width','50','','','.w-login-block'),(901941,'furniture','.w-login-block .new','width','50','','','.w-login-block'),(901942,'furniture','.w-menu-horizontal li','width','auto','','','.w-menu-horizontal'),(901943,'furniture','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(901944,'furniture','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(901945,'furniture','.w-login-block .input','width','100','','','.w-login-block'),(901946,'furniture','.b-form .checkbox-style:checked + .checkbox-span','width','15','','','.b-form'),(901947,'furniture','.w-delayed-despatch-checkout #delivery_date','width','150','','','.w-delayed-despatch-checkout'),(901948,'furniture','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(901949,'furniture','.w-product-images-additional .item-div','width','80','5161','','.w-product-images-additional'),(901950,'furniture','.w-product-wishlist-button .btn','width','100','5131','','.w-product-wishlist-button'),(901951,'furniture','.b-fancybox .fancybox-lock','width','auto','','','.b-fancybox'),(901952,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','width','15','','','.b-switch'),(901953,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','width','10','','','.b-switch'),(901954,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','width','10','','','.b-switch'),(901955,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs','width','30','','','.b-switch'),(901956,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-toggle','width','15','','','.b-switch'),(901958,'furniture','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(901959,'furniture','.w-promo-code .promo-code-form','width','100','5140','','.w-promo-code'),(901960,'furniture','.b-email .totals-value','width','30','','','.b-email'),(901961,'furniture','.b-email .totals-title','width','70','','','.b-email'),(901962,'furniture','.w-filters .ui-slider-handle','width','15','','','.w-filters'),(901963,'furniture','.pop-up-content .buttons .btn-2','width','100','5140','',''),(901964,'furniture','.pop-up-content .buttons .btn','width','100','5140','',''),(901965,'furniture','.pop-up-content .buttons .left-buttons','width','100','5140','',''),(901966,'furniture','.pop-up-content .buttons .right-buttons','width','100','5140','',''),(901968,'furniture','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(901969,'furniture','.w-login-block .returning','width','50','','','.w-login-block'),(901971,'furniture','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(901973,'furniture','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(901974,'furniture','.b-products-listing .btn-choose-options','width','100','','','.b-products-listing'),(901975,'furniture','.w-filters .input-checkbox:checked + .checkbox-span','width','24','','','.w-filters'),(901976,'furniture','.w-filters .ui-slider','width','100','','','.w-filters'),(901977,'furniture','.w-checkout-shipping-choice input:checked + span:before','width','10','','','.w-checkout-shipping-choice'),(901978,'furniture','.b-switch .candlestick-wrapper','width','60','','','.b-switch'),(901979,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','width','20','3','','.b-switch'),(901980,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(901981,'furniture','.b-email .image','width','100','','','.b-email'),(901982,'furniture','.b-email .totals-value','width','30','','','.b-email'),(901983,'furniture','.b-email .heading-image','width','100','','','.b-email'),(901984,'furniture','.b-email .products-table','width','100','','','.b-email'),(901985,'furniture','.b-form .login-col-1','width','25','','','.b-form'),(901986,'furniture','.b-select-suggest .select2-container','width','100','','','.b-select-suggest'),(901987,'furniture','.b-select-suggest .select2-measure-scrollbar','width','100','','','.b-select-suggest'),(901988,'furniture','.b-email-editor img','width','auto','','','.b-email-editor'),(901989,'furniture','.b-form .middle-form .dob-input input[type=\"text\"]','width','48','','','.b-form'),(901990,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width','1','','','.b-select-suggest'),(901991,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(901992,'furniture','.w-brands .brands-listing > div','width','16','','','.w-brands'),(901993,'furniture','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(901994,'furniture','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(901995,'furniture','.w-socials .post_item_img','width','100','','','.w-socials'),(901996,'furniture','.b-info-popup .info-popup div','width','250','','','.b-info-popup'),(901997,'furniture','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5140','','.w-promo-code'),(901998,'furniture','.w-brands .brands-listing > div','width','16','','','.w-brands'),(901999,'furniture','.w-cart-listing .right-area','width','100','5140','','.w-cart-listing'),(902000,'furniture','.w-product-images-additional .additional-images','width','80','5161','','.w-product-images-additional'),(902001,'furniture','.w-promo-code .promo-text','width','100','5140','','.w-promo-code'),(902002,'furniture','.w-product-wishlist-button .btn','width','100','5131','','.w-product-wishlist-button'),(902003,'furniture','.w-cart-continue-btn a','width','100','5131','','.w-cart-continue-btn'),(902004,'furniture','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(902005,'furniture','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(902006,'furniture','.w-cart-order-total.box','width','100','5131','','.w-cart-order-total'),(902007,'furniture','.b-info-popup .info-popup div','width','20','3','','.b-info-popup'),(902008,'furniture','.b-email .totals-value','width','30','','','.b-email'),(902009,'furniture','.b-email .heading-image','width','100','','','.b-email'),(902010,'furniture','.b-email .heading-image','width','100','','','.b-email'),(902011,'furniture','.view-all','width','100','3','',''),(902012,'furniture','.w-promo-code .promo-code-form','width','100','5140','','.w-promo-code'),(902013,'furniture','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5140','','.w-promo-code'),(902015,'furniture','.b-form .columns .col-2','width','50','','','.b-form'),(902016,'furniture','.b-bottom .popup-box.popupCompare','width','80','','','.b-bottom'),(902017,'furniture','.w-promo-code .promo-code-form','width','100','5140','','.w-promo-code'),(902018,'furniture','.w-cart-continue-btn a','width','100','5131','','.w-cart-continue-btn'),(902019,'furniture','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(902020,'furniture','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(902021,'furniture','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(902022,'furniture','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(902023,'furniture','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(902024,'furniture','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(902025,'furniture','.w-checkout-guest-btn .btn-2','width','260','','','.w-checkout-guest-btn'),(902026,'furniture','textarea','width','100','','',''),(902027,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(902028,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','width','100','','','.b-switch'),(902029,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','width','100','','','.b-switch'),(902030,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-label','width','30','','','.b-switch'),(902032,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(902033,'furniture','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(902034,'furniture','.b-email-editor img','width','auto','','','.b-email-editor'),(902035,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','width','100','','','.b-switch'),(902036,'furniture','.b-form .checkbox-style','width','0','','','.b-form'),(902037,'furniture','.b-email .image','width','100','','','.b-email'),(902038,'furniture','.b-email .totals-title','width','70','','','.b-email'),(902039,'furniture','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','width','25','3','','.w-checkout-contact-information'),(902040,'furniture','.b-form .addresses .address-item','width','48','','','.b-form'),(902041,'furniture','.w-categories .item','width','50','5131','','.w-categories'),(902042,'furniture','.order-summary .btn-2, .order-summary .btn-3','width','100','','','.order-summary'),(902043,'furniture','.w-cart-bonus-points .bonus_points_amount','width','150','','','.w-cart-bonus-points'),(902044,'furniture','.w-cart-bonus-points .btn-remove','width','25','','','.w-cart-bonus-points'),(902045,'furniture','.order-summary .price-box .price','width','auto','','','.order-summary'),(902046,'furniture','.b-email .totals-table','width','100','','','.b-email'),(902047,'furniture','.w-socials .post_item_img','width','100','','','.w-socials'),(902048,'furniture','.w-list-b2b .select-attributes','width','47','','','.w-list-b2b'),(902049,'furniture','.w-promo-code .promo-text','width','100','5140','','.w-promo-code'),(902050,'furniture','.w-checkout-shipping-choice label','width','50','','','.w-checkout-shipping-choice'),(902051,'furniture','.b-switch .candlestick-wrapper.candlestick-contents','width','306','','','.b-switch'),(902052,'furniture','.b-email .products-table','width','100','','','.b-email'),(902053,'furniture','.w-checkout-shipping-choice label','width','auto','5161','','.w-checkout-shipping-choice'),(902054,'furniture','.w-checkout-create-account .col-2','width','100','5140','','.w-checkout-create-account'),(902055,'furniture','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(902056,'furniture','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(902057,'furniture','.w-top-categories .item','width','25','','','.w-top-categories'),(902058,'furniture','.w-checkout-billing-address .addresses .address-item','width','50','','','.w-checkout-billing-address'),(902059,'furniture','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(902060,'furniture','.w-cart-give-away .ga_attributes select','width','100','','','.w-cart-give-away'),(902061,'furniture','.w-cart-checkout-btn a','width','100','5131','','.w-cart-checkout-btn'),(902062,'furniture','.b-autocomplete .ui-autocomplete','width','200','','','.b-autocomplete'),(902063,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(902064,'furniture','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(902065,'furniture','.w-socials .post_item_img','width','100','','','.w-socials'),(902067,'furniture','.b-email .totals-value','width','30','','','.b-email'),(902068,'furniture','.b-email .totals-table','width','100','','','.b-email'),(902069,'furniture','.b-email .totals-title','width','70','','','.b-email'),(902070,'furniture','.b-email .heading-image','width','100','','','.b-email'),(902071,'furniture','.b-email img','width','60','','','.b-email'),(902072,'furniture','.b-email .products-table','width','100','','','.b-email'),(902073,'furniture','.b-email .image','width','100','','','.b-email'),(902074,'furniture','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width','100','','','.p-quote-checkout-login'),(902075,'furniture','.b-form .col-right','width','50','','','.b-form'),(902076,'furniture','.b-email img','width','60','','','.b-email'),(902077,'furniture','.w-cart-continue-btn a','width','100','5131','','.w-cart-continue-btn'),(902078,'furniture','.w-product-wishlist-button .btn','width','100','5131','','.w-product-wishlist-button'),(902079,'furniture','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5140','','.w-promo-code'),(902080,'furniture','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(902081,'furniture','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(902082,'furniture','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(902083,'furniture','.w-promo-code .promo-code-form','width','100','5140','','.w-promo-code'),(902084,'furniture','.w-promo-code .promo-text','width','100','5140','','.w-promo-code'),(902085,'furniture','.b-form .columns .col-2','width','100','5161','','.b-form'),(902086,'furniture','.b-select-suggest .select2-container .select2-choice abbr','width','12','','','.b-select-suggest'),(902087,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(902088,'furniture','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(902089,'furniture','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(902090,'furniture','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(902091,'furniture','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(902092,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','width','20','','','.b-switch'),(902093,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','width','28','','','.b-switch'),(902094,'furniture','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(902095,'furniture','.w-login-block .new','width','50','','','.w-login-block'),(902096,'furniture','.w-login-block .guest','width','50','','','.w-login-block'),(902097,'furniture','.w-login-block .input','width','100','','','.w-login-block'),(902098,'furniture','.w-login-block .returning','width','50','','','.w-login-block'),(902099,'furniture','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(902100,'furniture','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(902101,'furniture','div.cart-popup','width','850','','',''),(902102,'furniture','.w-cart-give-away .ga_column','width','46','','','.w-cart-give-away'),(902103,'furniture','.w-cart-give-away .ga_attributes > div','width','48','','','.w-cart-give-away'),(902104,'furniture','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width','100','','','.b-form'),(902105,'furniture','.b-products-listing .products-listing .buyButton .btn','width','100','','','.b-products-listing'),(902106,'furniture','.w-image-maps .svg-wrap svg','width','100','','','.w-image-maps'),(902107,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(902108,'furniture','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(902109,'furniture','.w-login-block .guest','width','50','','','.w-login-block'),(902110,'furniture','.w-login-block .new','width','50','','','.w-login-block'),(902111,'furniture','.w-cart-shipping-estimator .right-area','width','48','','','.w-cart-shipping-estimator'),(902112,'furniture','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(902113,'furniture','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(902115,'furniture','.w-checkout-credit-amount .btn-remove','width','25','','','.w-checkout-credit-amount'),(902116,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(902117,'furniture','.w-checkout-credit-amount .cot_gv_amount','width','150','','','.w-checkout-credit-amount'),(902118,'furniture','.p-quick-order-index .all-scroll-div','width','100','','','.p-quick-order-index'),(902119,'furniture','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(902120,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(902121,'furniture','.b-email-editor img','width','auto','','','.b-email-editor'),(902122,'furniture','.b-form .col-left','width','100','5140','','.b-form'),(902123,'furniture','.b-email .totals-title','width','70','','','.b-email'),(902124,'furniture','.b-email .totals-table','width','100','','','.b-email'),(902125,'furniture','.w-product-images-additional .additional-images','width','80','5161','','.w-product-images-additional'),(902126,'furniture','.w-product-images-additional .item','width','80','5161','','.w-product-images-additional'),(902127,'furniture','.b-bottom .cart-options .option-item','width','50','','','.b-bottom'),(902128,'furniture','.w-promotions .promo-cart-discount .master .item','width','calc(50% - 24px)','','','.w-promotions'),(902129,'furniture','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(902130,'furniture','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(902131,'furniture','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(902132,'furniture','.b-bottom .cart-options .cart-item','width','50','','','.b-bottom'),(902133,'furniture','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(902134,'furniture','.w-cart-shipping-estimator .left-area','width','48','','','.w-cart-shipping-estimator'),(902136,'furniture','.w-login-block .returning','width','50','','','.w-login-block'),(902137,'furniture','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(902138,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(902139,'furniture','.b-email img','width','60','','','.b-email'),(902140,'furniture','.b-form .col-3','width','31.33','','','.b-form'),(902141,'furniture','.b-email .products-table','width','100','','','.b-email'),(902142,'furniture','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(902143,'furniture','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width','100','','','.b-form'),(902144,'furniture','.w-login-block .input','width','100','','','.w-login-block'),(902145,'furniture','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','width','35','','','.b-products-listing'),(902146,'furniture','.w-login-block .guest','width','50','','','.w-login-block'),(902147,'furniture','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(902148,'furniture','.w-product-wishlist-button .btn','width','100','5131','','.w-product-wishlist-button'),(902149,'furniture','.w-product-images-additional .item-div','width','80','5161','','.w-product-images-additional'),(902150,'furniture','.b-bottom .popup-box','width','530','','','.b-bottom'),(902151,'furniture','.b-email .totals-table','width','100','','','.b-email'),(902152,'furniture','.b-email img','width','60','','','.b-email'),(902153,'furniture','.b-form .login-col-2','width','50','','','.b-form'),(902154,'furniture','.b-fancybox .fancybox-close','width','40','','','.b-fancybox'),(902155,'furniture','.w-cart-compare .product .image','width','50','','','.w-cart-compare'),(902156,'furniture','.w-product-customers-activity .customers-activity','width','255','','','.w-product-customers-activity'),(902157,'furniture','.w-product-customers-activity .close','width','30','','','.w-product-customers-activity'),(902158,'furniture','.b-form .hide-billing-address','width','100','','','.b-form'),(902159,'furniture','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(902160,'furniture','.b-email-editor img','width','auto','','','.b-email-editor'),(902161,'furniture','.w-top-categories .item','width','50','5131','','.w-top-categories'),(902162,'furniture','.w-personal-gift-status-bar .progress-bar','width','230','','','.w-personal-gift-status-bar'),(902163,'furniture','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(902164,'furniture','.w-checkout-billing-address .addresses.address-main .address-item','width','100','','','.w-checkout-billing-address'),(902165,'furniture','.w-checkout-bonus-points .bonus_points_amount','width','150','','','.w-checkout-bonus-points'),(902166,'furniture','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width','150','','','.w-coupons-and-vauchers-checkout'),(902167,'furniture','.w-checkout-shipping-address .addresses.address-main .address-item','width','100','','','.w-checkout-shipping-address'),(902168,'furniture','.w-checkout-shipping-choice #shippingchoice-choice','width','430','','','.w-checkout-shipping-choice'),(902169,'furniture','.w-product-images-additional .item-div','width','80','5161','','.w-product-images-additional'),(902170,'furniture','.w-product-images-additional .item','width','80','5161','','.w-product-images-additional'),(902171,'furniture','.w-product-images-additional .additional-images','width','80','5161','','.w-product-images-additional'),(902172,'furniture','.w-cart-order-total.box','width','100','5131','','.w-cart-order-total'),(902173,'furniture','.w-product-wishlist-button .btn','width','100','5131','','.w-product-wishlist-button'),(902174,'furniture','.w-promo-code .promo-code-form','width','100','5140','','.w-promo-code'),(902175,'furniture','.w-cart-checkout-btn ','width','100','5131','','.w-cart-checkout-btn'),(902176,'furniture','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5140','','.w-promo-code'),(902177,'furniture','.w-cart-continue-btn a','width','100','5131','','.w-cart-continue-btn'),(902178,'furniture','.w-promo-code .promo-text','width','100','5140','','.w-promo-code'),(902179,'furniture','.w-cart-order-total.box','width','100','5131','','.w-cart-order-total'),(902180,'furniture','.w-product-images-additional .item-div','width','80','5161','','.w-product-images-additional'),(902181,'furniture','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(902182,'furniture','.b-select-suggest .select2-search-choice-close','width','12','','','.b-select-suggest'),(902183,'furniture','.b-select-suggest .select2-search input','width','100','','','.b-select-suggest'),(902184,'furniture','.b-select-suggest .select2-search','width','100','','','.b-select-suggest'),(902185,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow','width','18','','','.b-select-suggest'),(902186,'furniture','.b-select-suggest .select2-drop-auto-width','width','auto','','','.b-select-suggest'),(902187,'furniture','.b-select-suggest .select2-drop','width','100','','','.b-select-suggest'),(902188,'furniture','.b-select-suggest .select2-drop-mask','width','auto','','','.b-select-suggest'),(902189,'furniture','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(902190,'furniture','.w-socials .post_item_img','width','100','','','.w-socials'),(902191,'furniture','.w-tabs .tab-navigation','width','100','','','.w-tabs'),(902193,'furniture','.w-login-block .returning','width','50','','','.w-login-block'),(902195,'furniture','.w-categories .item','width','100','5161','','.w-categories'),(902196,'furniture','.b-email-editor img','width','auto','','','.b-email-editor'),(902197,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width','20','3','','.b-switch'),(902198,'furniture','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(902199,'furniture','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(902200,'furniture','.w-socials .post_item_img','width','100','','','.w-socials'),(902202,'furniture','.w-login-block .guest','width','50','','','.w-login-block'),(902203,'furniture','.w-login-block .returning','width','50','','','.w-login-block'),(902204,'furniture','.w-menu-big li','width','auto','','','.w-menu-big'),(902205,'furniture','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(902206,'furniture','.w-cart-listing .links','width','19','','','.w-cart-listing'),(902207,'furniture','.w-cart-order-total.box','width','100','5131','','.w-cart-order-total'),(902208,'furniture','.w-account-addresses-list .addsess-suggestion-item','width','50','','','.w-account-addresses-list'),(902209,'furniture','.b-products-listing .products-listing a.btn.view-button','width','100','','','.b-products-listing'),(902210,'furniture','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width','80','','','.b-products-listing'),(902211,'furniture','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width','60','','','.b-products-listing'),(902212,'furniture','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width','40','','','.b-products-listing'),(902213,'furniture','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width','20','','','.b-products-listing'),(902214,'furniture','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width','40','','','.b-products-listing'),(902215,'furniture','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width','20','','','.b-products-listing'),(902216,'furniture','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width','60','','','.b-products-listing'),(902217,'furniture','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width','60','','','.b-products-listing'),(902218,'furniture','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width','20','','','.b-products-listing'),(902219,'furniture','.b-products-listing .BlockBox.type-14 > .col','width','25','','','.b-products-listing'),(902220,'furniture','.b-products-listing .BlockBox.type-15 > .col','width','20','','','.b-products-listing'),(902221,'furniture','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width','50','','','.b-products-listing'),(902222,'furniture','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(902223,'furniture','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(902224,'furniture','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width','33.33','','','.b-products-listing'),(902225,'furniture','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width','50','','','.b-products-listing'),(902226,'furniture','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(902227,'furniture','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width','66.66','','','.b-products-listing'),(902228,'furniture','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width','66.66','','','.b-products-listing'),(902229,'furniture','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(902230,'furniture','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width','25','','','.b-products-listing'),(902231,'furniture','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width','25','','','.b-products-listing'),(902232,'furniture','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width','75','','','.b-products-listing'),(902233,'furniture','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width','75','','','.b-products-listing'),(902234,'furniture','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width','25','','','.b-products-listing'),(902235,'furniture','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width','50','','','.b-products-listing'),(902236,'furniture','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width','25','','','.b-products-listing'),(902237,'furniture','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width','20','','','.b-products-listing'),(902238,'furniture','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width','80','','','.b-products-listing'),(902239,'furniture','.b-products-listing .btn-preloader','width','24','3','','.b-products-listing'),(902240,'furniture','.b-products-listing .hover-box-content','width','20','3','','.b-products-listing'),(902241,'furniture','.b-products-listing .loader','width','30','4','','.b-products-listing'),(902242,'furniture','.b-products-listing .loader','width','100','3','','.b-products-listing'),(902243,'furniture','.b-products-listing .products-listing .attribute-qty-block > span','width','100','','','.b-products-listing'),(902244,'furniture','.b-products-listing .products-listing .attributes select','width','100','','','.b-products-listing'),(902245,'furniture','.b-products-listing .products-listing .btn-buy','width','100','','','.b-products-listing'),(902246,'furniture','.w-catalog-b2b-add-button ','width','100','','','.w-catalog-b2b-add-button'),(902247,'furniture','.b-products-listing .products-listing .item','width','25','','','.b-products-listing'),(902248,'furniture','.b-products-listing .products-listing .qty-input.hidden','width','100','3','','.b-products-listing'),(902249,'furniture','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','width','auto','','','.b-products-listing'),(902250,'furniture','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width','100','','','.b-products-listing'),(902251,'furniture','.checkbox input:not(checked) + span:before','width','22','','',''),(902252,'furniture','.checkbox input + span','width','24','','',''),(902254,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width','100','','','.b-select-suggest'),(902255,'furniture','.b-products-listing .products-listing .in-cart','width','100','','','.b-products-listing'),(902256,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-toggle','width','10','','','.b-switch'),(902257,'furniture','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','width','10','','','.b-switch'),(902258,'furniture','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','width','25','3','','.w-checkout-contact-information'),(902259,'furniture','.b-form .radio-button input[type=\"radio\"].no + span','width','30','3','','.b-form'),(902260,'furniture','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width','100','','','.b-fancybox'),(902261,'furniture','.b-email .heading-image','width','100','','','.b-email'),(902262,'furniture','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(902263,'furniture','.w-product-images-additional .additional-images','width','80','5161','','.w-product-images-additional'),(902264,'furniture','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5140','','.w-promo-code'),(902265,'furniture','.w-socials .post_item_img','width','100','','','.w-socials'),(902266,'furniture','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(902267,'furniture','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(902268,'furniture','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(902269,'furniture','.w-cart-credit-amount .btn-remove','width','25','','','.w-cart-credit-amount'),(902270,'furniture','.w-coupons-and-vauchers-checkout .btn-remove','width','25','','','.w-coupons-and-vauchers-checkout'),(902271,'furniture','.order-summary .price-row.ot_coupon .title','width','32','3','','.order-summary'),(902272,'furniture','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterSku\"]','width','60','','','.w-communication-new-topic'),(902273,'furniture','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterOrderId\"]','width','60','','','.w-communication-new-topic'),(902274,'furniture','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterName\"]','width','100','','','.w-communication-new-topic'),(902275,'furniture','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateFrom\"]','width','60','','','.w-communication-new-topic'),(902276,'furniture','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateTo\"]','width','60','','','.w-communication-new-topic'),(902277,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','width','36','','','.w-communication-new-topic'),(902278,'furniture','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','width','36','','','.w-communication-new-topic'),(902279,'furniture','.w-communication-new-topic .middle-form select','width','100','','','.w-communication-new-topic'),(902280,'furniture','.w-login-block .input','width','100','','','.w-login-block'),(902281,'furniture','.w-checkout-shipping-address .addresses .address-item','width','50','','','.w-checkout-shipping-address'),(902282,'furniture','.b-form .checkbox-style:not(checked) + .checkbox-span','width','15','','','.b-form'),(902283,'furniture','.w-checkout-shipping-choice #shippingchoice-choice','width','auto','5161','','.w-checkout-shipping-choice'),(902284,'furniture','.b-email img','width','60','','','.b-email'),(902285,'furniture','.w-cart-continue-btn a','width','100','5131','','.w-cart-continue-btn'),(902286,'furniture','.b-bottom .popup-credit-amount .popup-box','width','100','','','.b-bottom'),(902287,'furniture','.w-product-images-additional .item','width','80','5161','','.w-product-images-additional'),(902288,'furniture','.w-promo-code .promo-code-form','width','100','5140','','.w-promo-code'),(902289,'furniture','.b-email .products-table','width','100','','','.b-email'),(902290,'furniture','.b-email .totals-title','width','70','','','.b-email'),(902291,'furniture','.w-login-block .new','width','50','','','.w-login-block'),(902292,'furniture','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(902293,'furniture','.b-email-editor img','width','auto','','','.b-email-editor'),(902294,'furniture','.b-email .heading-image','width','100','','','.b-email'),(902295,'furniture','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(902296,'furniture','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(902297,'furniture','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(902298,'furniture','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(902299,'furniture','.b-compare .col-two label','width','20','','','.b-compare'),(902300,'furniture','.w-cart-order-total.box','width','100','5131','','.w-cart-order-total'),(902301,'furniture','.w-promo-code .promo-text','width','100','5140','','.w-promo-code'),(902302,'furniture','.w-menu-horizontal .menu-ico','width','54','','','.w-menu-horizontal'),(902303,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(902304,'furniture','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(902305,'furniture','.w-catalog-listing-look .grid','width','35','','','.w-catalog-listing-look'),(902306,'furniture','.w-catalog-listing-look .b2b','width','35','','','.w-catalog-listing-look'),(902307,'furniture','.w-catalog-listing-look .list','width','35','','','.w-catalog-listing-look'),(902308,'furniture','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','width','130','','','.w-cart-listing'),(902309,'furniture','.w-cart-listing .remove-btn','width','30','','','.w-cart-listing'),(902310,'furniture','.w-cart-listing .right-area','width','35','','','.w-cart-listing'),(902311,'furniture','.w-cart-listing .item .image','width','80','5140','','.w-cart-listing'),(902312,'furniture','.w-cart-listing .item .remove','width','100','5140','','.w-cart-listing'),(902313,'furniture','.w-cart-give-away .ga_img','width','30','','','.w-cart-give-away'),(902314,'furniture','.w-cart-give-away .ga_column','width','100','5131','','.w-cart-give-away'),(902315,'furniture','.w-cart-discount-coupon input[type=\"text\"]','width','100','','','.w-cart-discount-coupon'),(902316,'furniture','.w-cart-discount-coupon .btn-remove','width','25','','','.w-cart-discount-coupon'),(902318,'furniture','.w-brands .brands-listing > div','width','16','','','.w-brands'),(902319,'furniture','.b-upload-file .snapshot','width','38','','','.b-upload-file'),(902320,'furniture','.b-fancybox .fancybox-nav span','width','40','','','.b-fancybox'),(902321,'furniture','.b-fancybox .fancybox-nav','width','40','','','.b-fancybox'),(902322,'furniture','.b-email .totals-table','width','100','','','.b-email'),(902323,'furniture','.w-product-images-additional .item','width','80','5161','','.w-product-images-additional'),(902324,'furniture','.b-upload-file .upload-file-template','width','150','','','.b-upload-file'),(902325,'furniture','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(902326,'furniture','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(902327,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(902328,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(902329,'furniture','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(902330,'furniture','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(902331,'furniture','.b-switch .candlestick-wrapper.candlestick-size-sm','width','45','','','.b-switch'),(902332,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','width','40','','','.b-switch'),(902333,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(902334,'furniture','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(902336,'furniture','.w-login-block .new','width','50','','','.w-login-block'),(902337,'furniture','.w-filters .handle-to','width','50','','','.w-filters'),(902338,'furniture','.w-filters .handle-from','width','50','','','.w-filters'),(902339,'furniture','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5140','','.w-promo-code'),(902340,'furniture','.order-summary .price-row.ot_bonus_points .title','width','32','3','','.order-summary'),(902341,'furniture','.w-filters .input-checkbox','width','0','','','.w-filters'),(902342,'furniture','.b-bottom .pop-up-close','width','31','','','.b-bottom'),(902343,'furniture','.w-product-images-additional .item-div','width','80','5161','','.w-product-images-additional'),(902344,'furniture','.w-promo-code .promo-text','width','100','5140','','.w-promo-code'),(902345,'furniture','.w-product-images-additional .additional-images','width','80','5161','','.w-product-images-additional'),(902346,'furniture','.w-product-images-additional .item-div','width','80','5161','','.w-product-images-additional'),(902347,'furniture','.w-cart-order-total.box','width','100','5131','','.w-cart-order-total'),(902348,'furniture','.b-compare .col-two select','width','80','','','.b-compare'),(902349,'furniture','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(902350,'furniture','.w-product-wishlist-button .btn','width','100','5131','','.w-product-wishlist-button'),(902351,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(902352,'furniture','.w-login-block .new','width','50','','','.w-login-block'),(902353,'furniture','.w-login-block .input','width','100','','','.w-login-block'),(902354,'furniture','.w-login-block .guest','width','50','','','.w-login-block'),(902355,'furniture','.b-products-listing .products-listing .btn-preloader','width','100','','','.b-products-listing'),(902356,'furniture','.w-communication-new-topic .btn-submit','width','200','','','.w-communication-new-topic'),(902357,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(902359,'furniture','.w-cart-credit-amount input[type=\"text\"]','width','150','','','.w-cart-credit-amount'),(902361,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg','width','120','','','.b-switch'),(902362,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','width','40','','','.b-switch'),(902363,'furniture','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','width','40','','','.b-switch'),(902364,'furniture','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(902365,'furniture','.b-email .products-table','width','100','','','.b-email'),(902366,'furniture','.b-email .totals-value','width','30','','','.b-email'),(902367,'furniture','.b-email .totals-title','width','70','','','.b-email'),(902368,'furniture','.b-email .totals-table','width','100','','','.b-email'),(902369,'furniture','.w-filters .mobileCollapse','width','17','','','.w-filters'),(902370,'furniture','.w-filters .input-txt-keywords','width','100','','','.w-filters'),(902371,'furniture','.w-filters .input-txt','width','60','','','.w-filters'),(902372,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','width','250','','','.w-image-maps'),(902373,'furniture','.w-filters .input-checkbox:not(checked) + .checkbox-span','width','24','','','.w-filters'),(902374,'furniture','.w-brands .brands-listing > div','width','16','','','.w-brands'),(902375,'furniture','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','width','auto','','','.b-product-images'),(902376,'furniture','.b-product-images .media-popup .mp-close','width','100','','','.b-product-images'),(902377,'furniture','.b-product-images .media-popup .mp-small-images .item','width','150','','','.b-product-images'),(902378,'furniture','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','width','100','','','.b-product-images'),(902379,'furniture','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','width','30','','','.b-menu-burger_icon'),(902380,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width','100','','','.b-menu-lev_display-slide'),(902381,'furniture','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width','100','','','.b-menu-lev_display-slide'),(902382,'furniture','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width','100','','','.b-menu-lev_display-slide'),(902383,'furniture','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width','100','','','.b-menu-lev_display-slide'),(902384,'furniture','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width','100','','','.b-menu-lev_display-slide'),(902385,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(902386,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(902387,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(902388,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(902389,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(902390,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width','100','','','.b-menu-open_from-left'),(902391,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(902392,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','width','40','','','.b-menu-style-2'),(902393,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','width','50','','','.b-menu-style-2'),(902394,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','width','36','','','.b-menu-style-2'),(902395,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','width','40','','','.b-menu-style-2'),(902396,'furniture','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','width','36','','','.b-menu-style-2'),(902397,'furniture','.b-trade-approval .steps-bar','width','100','','','.b-trade-approval'),(902398,'furniture','.b-trade-approval .col-right','width','48','','','.b-trade-approval'),(902399,'furniture','.b-trade-approval .col-left','width','48','','','.b-trade-approval'),(902400,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width','100','','','.b-trade-approval'),(902401,'furniture','.b-trade-approval .col-3','width','31.33','','','.b-trade-approval'),(902402,'furniture','.w-account-personal-catalog .list-switcher','width','100','','','.w-account-personal-catalog'),(902403,'furniture','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','width','auto','','','.w-catalog-compare'),(902404,'furniture','.w-catalog-compare .cross-box .different-all > div','width','50','','','.w-catalog-compare'),(902405,'furniture','.w-product-images .additional-vertical .produst-image','width','calc(100% - 100px)','','','.w-product-images'),(902406,'furniture','.w-product-images .additional-vertical .additional-images','width','100','','','.w-product-images'),(902413,'furniture','.b-products-listing .products-listing.list-productlisting .BlockBox.type-2 > .col:nth-child(1)','width','100','','','.b-products-listing'),(902414,'furniture','.b-products-listing .products-listing.list-productlisting .BlockBox.type-2 > .col:nth-child(2)','width','100','','','.b-products-listing'),(902415,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','width','40','','','.b-slick'),(902416,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','width','50','5140','','.b-slick'),(902420,'furniture','.menu-header .burger-icon','width','40','5140','','.menu-header'),(902421,'furniture','.b-products-listing .item-nav > div','width','33.333','','','.b-products-listing'),(902422,'furniture','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','width','13','','','.w-filters'),(902423,'furniture','.b-products-listing .products-listing.list-productlisting .item-content','width','100','4','','.b-products-listing'),(902424,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','width','100','','','.b-products-listing'),(902425,'furniture','.w-quote .cart-box-link','width','48','3','','.w-quote'),(902426,'furniture','.w-quote .image','width','70','','','.w-quote'),(902427,'furniture','.w-quote .cart-box-link','width','40','5140,3','','.w-quote'),(902428,'furniture','.b-quantity .qty-box .bigger','width','35','','','.b-quantity'),(902429,'furniture','.b-quantity .qty-box .smaller','width','35','','','.b-quantity'),(902430,'furniture','.b-quantity .qty-box input','width','60','','','.b-quantity'),(902431,'furniture','.b-quantity .qty-input input','width','40','','','.b-quantity'),(902432,'furniture','.w-product-sale-ends .left-count','width','23','','','.w-product-sale-ends'),(902433,'furniture','.w-product-sale-ends .left-text-left','width','24','','','.w-product-sale-ends'),(902434,'furniture','.w-product-sale-ends .left-text-right','width','24','','','.w-product-sale-ends'),(902435,'furniture','h1, .heading-1','width','100','3','',''),(902436,'furniture','h1, .heading-1','width','100','4','',''),(902437,'furniture','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(902438,'furniture','.w-product-quantity .qty-box .smaller, .w-product-quantity .qty-box .bigger','width','46','','','.w-product-quantity'),(902439,'furniture','.w-product-quantity .qty-input input[type=\'text\']','width','77','','','.w-product-quantity'),(902440,'furniture','.w-product-bonus-points > div > div','width','100','','','.w-product-bonus-points'),(902441,'furniture','.warrantyProduct .warranty','width','35','3','','.warrantyProduct'),(902442,'furniture','.warrantyProduct .delivery','width','37','3','','.warrantyProduct'),(902443,'furniture','.w-compare .image','width','70','','','.w-compare'),(902444,'furniture','.w-files-catalog-widgets-files-catalog .item','width','18','','','.w-files-catalog-widgets-files-catalog'),(902445,'furniture','.w-files-catalog-widgets-files-catalog .item','width','23','5145','','.w-files-catalog-widgets-files-catalog'),(902446,'furniture','.w-files-catalog-widgets-files-catalog .item','width','31','5140','','.w-files-catalog-widgets-files-catalog'),(902447,'furniture','.w-files-catalog-widgets-files-catalog .item','width','48','5131','','.w-files-catalog-widgets-files-catalog'),(902448,'furniture','.w-sample .cart-box-link','width','10','4','','.w-sample'),(902449,'furniture','.w-sample .cart-box-link','width','48','3','','.w-sample'),(902450,'furniture','.w-sample .image','width','70','','','.w-sample'),(902451,'furniture','.w-sample .cart-box-link','width','40','5140,3','','.w-sample'),(902452,'furniture','.w-quote .cart-box.hover-box .cart-content','width','410','','','.w-quote'),(902453,'furniture','.w-sample .cart-box .cart-content','width','410','','','.w-sample'),(902454,'furniture','.w-cart-listing .points-earn','width','80','','','.w-cart-listing'),(902455,'furniture','.w-cart-listing .points-earn','width','0','4','','.w-cart-listing'),(902456,'furniture','.w-cart-sub-total .price-row','width','100','','','.w-cart-sub-total'),(902457,'furniture','.w-cart-sub-total .price-row > div','width','50','','','.w-cart-sub-total'),(902458,'furniture','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(902459,'furniture','.w-cart-gift-certificate .input-apple','width','100','','','.w-cart-gift-certificate'),(902460,'furniture','.w-cart-gift-certificate .input-apple div','width','100','','','.w-cart-gift-certificate'),(902461,'furniture','.w-cart-order-reference .input-apple','width','100','','','.w-cart-order-reference'),(902462,'furniture','.w-cart-order-reference .input-apple div','width','100','','','.w-cart-order-reference'),(902463,'furniture','.w-cart-order-reference .input-apple div input','width','100','','','.w-cart-order-reference'),(902464,'furniture','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(902465,'furniture','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(902466,'furniture','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(902467,'furniture','.w-product-bundle .bundle_item','width','30','','','.w-product-bundle'),(902468,'furniture','.w-product-bundle .bundle_item','width','48','5140','','.w-product-bundle'),(902469,'furniture','.w-product-bundle .bundle_item','width','100','5131','','.w-product-bundle'),(902470,'furniture','.w-product-in-bundles .attributes-item','width','48','','','.w-product-in-bundles'),(902471,'furniture','.w-product-in-bundles .attributes-select','width','100','','','.w-product-in-bundles'),(902472,'furniture','.w-product-in-bundles .bundle_item','width','48','5140','','.w-product-in-bundles'),(902473,'furniture','.w-product-in-bundles .bundle_item','width','100','5131','','.w-product-in-bundles'),(902474,'furniture','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(902475,'furniture','.w-product-in-bundles .bundle_item','width','30','','','.w-product-in-bundles'),(902476,'furniture','.w-product-quantity-discounts .count','width','100','','','.w-product-quantity-discounts'),(902477,'furniture','.w-catalog-additional-images img','width','auto','','','.w-catalog-additional-images'),(902478,'furniture','.w-catalog-additional-images picture','width','150','','','.w-catalog-additional-images'),(902479,'furniture','.heading-2','width','100','3','',''),(902480,'furniture','.heading-2','width','100','4','',''),(902481,'furniture','.w-product-quantity-discounts .item','width','48','','','.w-product-quantity-discounts'),(902482,'furniture','.w-product-multi-inventory .select-box:nth-child(2n)','width','48','','','.w-product-multi-inventory'),(902483,'furniture','.w-product-multi-inventory .select-box:nth-child(2n+1)','width','48','','','.w-product-multi-inventory'),(902484,'furniture','.p-quote-checkout-index .datepicker-inline','width','280','','','.p-quote-checkout-index'),(902485,'furniture','.p-sample-checkout-index .datepicker-inline','width','280','','','.p-sample-checkout-index'),(902486,'furniture','.p-quote-checkout-index .order-summary .heading-2','width','100','3','','.p-quote-checkout-index'),(902487,'furniture','.p-quote-checkout-index .order-summary .heading-2','width','100','4','','.p-quote-checkout-index'),(902488,'furniture','.p-sample-checkout-index .order-summary .heading-2','width','100','3','','.p-sample-checkout-index'),(902489,'furniture','.p-sample-checkout-index .order-summary .heading-2','width','100','4','','.p-sample-checkout-index'),(902491,'furniture','.w-product-multi-inventory .radio-attributes > label','width','33.3333','','','.w-product-multi-inventory'),(902492,'furniture','.w-product-multi-inventory .radio-attributes .option-item','width','100','','','.w-product-multi-inventory'),(902493,'furniture','.w-product-multi-inventory .radio-attributes > label','width','50','5145','','.w-product-multi-inventory'),(902494,'furniture','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','width','100','','','.w-account-personal-catalog'),(902495,'furniture','.w-account-personal-catalog .w-cart-listing .item .image','width','110','5131','','.w-account-personal-catalog'),(902496,'furniture','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width','65','5145','','.b-products-listing'),(902497,'furniture','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width','35','5145','','.b-products-listing'),(902498,'furniture','.b-products-listing .products-listing .radio-attributes .option','width','100','','','.b-products-listing'),(902499,'furniture','.b-products-listing .products-listing .radio-attributes > label','width','50','','','.b-products-listing'),(902500,'furniture','.w-product-collection .chosen-products','width','48','','','.w-product-collection'),(902501,'furniture','.w-product-collection .current-product','width','25','','','.w-product-collection'),(902502,'furniture','.w-product-collection .right-area','width','25','','','.w-product-collection'),(902503,'furniture','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(902504,'furniture','.w-product-collection .current-product, .w-product-collection .chosen-products','width','100','5140','','.w-product-collection'),(902505,'furniture','.w-product-collection .right-area','width','100','5140','','.w-product-collection'),(902506,'furniture','.w-product-attributes .radio-attributes .option-item','width','100','','','.w-product-attributes'),(902507,'furniture','.w-product-attributes .radio-attributes > label','width','33.3333','','','.w-product-attributes'),(902508,'furniture','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(902509,'furniture','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(902510,'furniture','.w-product-attributes .radio-attributes > label','width','50','5145','','.w-product-attributes'),(902511,'furniture','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(902512,'furniture','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(902513,'furniture','.w-product-properties li','width','50','','','.w-product-properties'),(902514,'furniture','.w-questionnaire-widgets-questionnaire .answer-yes-no span','width','40','','','.w-questionnaire-widgets-questionnaire'),(902515,'furniture','.w-product-groups .radioBox label','width','50','','','.w-product-groups'),(902516,'furniture','.w-product-groups .radioBox label','width','100','5161','','.w-product-groups'),(902517,'furniture','.b-products-listing .mix-attributes .mult-qty-input .qty-box > span','width','35','','','.b-products-listing'),(902518,'furniture','.b-products-listing .mix-attributes .mult-qty-input .qty-box > input','width','60','','','.b-products-listing'),(902519,'furniture','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(902520,'furniture','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(902521,'furniture','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(902522,'furniture','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(902523,'furniture','.w-product-custom-bundle .chosen-products','width','100','5140','','.w-product-custom-bundle'),(902524,'furniture','.w-product-custom-bundle .right-area','width','100','5140','','.w-product-custom-bundle'),(902525,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width','25','','','.w-catalog-pages-category-pages-last-list'),(902526,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width','33.33','5140','','.w-catalog-pages-category-pages-last-list'),(902527,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width','50','5131','','.w-catalog-pages-category-pages-last-list'),(902528,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width','25','','','.w-catalog-pages-category-pages-last-list-block'),(902529,'furniture','.w-delivery-location-top-location-list .deliveryList li','width','48','','','.w-delivery-location-top-location-list'),(902530,'furniture','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(902531,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width','33.33','5140','','.w-catalog-pages-category-pages-last-list-block'),(902532,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width','50','5131','','.w-catalog-pages-category-pages-last-list-block'),(902533,'furniture','.w-delivery-location-location-list .deliveryList li','width','31.333','5140','','.w-delivery-location-location-list'),(902534,'furniture','.w-delivery-location-location-list .deliveryList li','width','48','5131','','.w-delivery-location-location-list'),(902535,'furniture','.w-delivery-location-top-location-list .deliveryList li','width','100','5131','','.w-delivery-location-top-location-list'),(902536,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li','width','48','','','.w-delivery-location-featured-list'),(902537,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li','width','100','5161','','.w-delivery-location-featured-list'),(902538,'furniture','.w-sale-category .badge','width','80','','','.w-sale-category'),(902539,'furniture','.w-sale-category .holder-1','width','25','','','.w-sale-category'),(902540,'furniture','.w-sale-category .holder-2','width','25','','','.w-sale-category'),(902541,'furniture','.w-sale-category .image','width','50','','','.w-sale-category'),(902542,'furniture','.w-sale-category .left-count','width','23','','','.w-sale-category'),(902543,'furniture','.w-sale-category .left-text-left','width','24','','','.w-sale-category'),(902544,'furniture','.w-sale-category .left-text-right','width','24','','','.w-sale-category'),(902545,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width','25','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(902546,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width','50','5131','','.w-catalog-pages-category-pages-last-list-by-catalog'),(902547,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width','25','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(902548,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width','50','5131','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(902549,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width','33.33','5140','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(902550,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width','33.33','5140','','.w-catalog-pages-category-pages-last-list-by-catalog'),(902551,'furniture','.w-delivery-location-list-by-page .item','width','31.333','','','.w-delivery-location-list-by-page'),(902552,'furniture','.w-delivery-location-list-by-page .item','width','48','5140','','.w-delivery-location-list-by-page'),(902553,'furniture','.w-delivery-location-list-by-page .item','width','100','5161','','.w-delivery-location-list-by-page'),(902554,'furniture','.w-product-properties-icons .hover-box-content','width','100','','','.w-product-properties-icons'),(902555,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','width','200','','','.w-product-properties-icons'),(902556,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','width','100','5161','','.w-product-properties-icons'),(902557,'furniture','.w-delivery-location-cross-pages .item','width','31.333','','','.w-delivery-location-cross-pages'),(902558,'furniture','.w-delivery-location-cross-pages .item','width','48','5140','','.w-delivery-location-cross-pages'),(902559,'furniture','.w-delivery-location-cross-pages .item','width','100','5161','','.w-delivery-location-cross-pages'),(902560,'furniture','.w-delivery-location-product-categories .item.category-link','width','25','','','.w-delivery-location-product-categories'),(902561,'furniture','.w-delivery-location-product-categories .item.category-link','width','33.3333','5140','','.w-delivery-location-product-categories'),(902562,'furniture','.w-delivery-location-product-categories .item.category-link','width','100','5161','','.w-delivery-location-product-categories'),(902563,'furniture','.w-delivery-location-product-categories .item.category-link','width','50','5131','','.w-delivery-location-product-categories'),(902564,'furniture','.w-catalog-delivery-locations .item','width','48','','','.w-catalog-delivery-locations'),(902565,'furniture','.w-catalog-delivery-locations .item','width','100','5131','','.w-catalog-delivery-locations'),(902566,'furniture','.delivery-options-popup .datepicker-inline','width','220','','',''),(902567,'furniture','.w-product-bonus-points .bonus-points-cost','width','100','','','.w-product-bonus-points'),(902568,'furniture','.w-product-designer-designer .productDesignerBox input','width','100','','','.w-product-designer-designer'),(902569,'furniture','.w-product-designer-designer .prodDesignerType label','width','82','','','.w-product-designer-designer'),(902570,'furniture','.w-product-designer-designer .prodDesignerType','width','100','','','.w-product-designer-designer'),(902571,'furniture','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','width','30','','','.w-press-reviews-widgets-press-reviews-small'),(902572,'furniture','.w-press-reviews-widgets-press-reviews-small .small-press-review','width','70','','','.w-press-reviews-widgets-press-reviews-small'),(902573,'furniture','.w-press-reviews-widgets-press-reviews .sub-box','width','300','','','.w-press-reviews-widgets-press-reviews'),(902574,'furniture','.w-gift-wrap-message-checkout .text','width','calc(100$ - 100px)','','','.w-gift-wrap-message-checkout'),(902575,'furniture','.w-support-system-listing .product_icon','width','40','','','.w-support-system-listing'),(902576,'furniture','.w-rma-returns-history .content-messages .messages-table .bottom select','width','auto','','','.w-rma-returns-history'),(902577,'furniture','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','width','35','','','.w-rma-returns-history'),(902578,'furniture','.w-rma-returns-history input[type=\'text\'], .w-rma-returns-history input[type=\'password\'], .w-rma-returns-history input[type=\'number\'], .w-rma-returns-history input[type=\'email\'], .w-rma-returns-history input[type=\'search\'], .w-rma-returns-history select','width','100','','','.w-rma-returns-history'),(902579,'furniture','.w-rma-returns-history thead tr td:first-child','width','300','','','.w-rma-returns-history'),(902580,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(902581,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(902582,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(902583,'furniture','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(902584,'furniture','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(902585,'furniture','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(902586,'furniture','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(902587,'furniture','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(902588,'furniture','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(902589,'furniture','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(902590,'furniture','.w-product-configurator .item-content','width','100','5140','','.w-product-configurator'),(902591,'furniture','.w-product-configurator .pc_item','width','100','5140','','.w-product-configurator'),(902592,'furniture','.b-products-listing .products-listing .bonus-points-cost','width','100','','','.b-products-listing'),(902593,'furniture','.b-products-listing .promo-icon','width','60','','','.b-products-listing'),(902594,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width','25','','','.w-catalog-pages-category-pages-list'),(902595,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width','33.33','5140','','.w-catalog-pages-category-pages-list'),(902596,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width','50','5131','','.w-catalog-pages-category-pages-list'),(902597,'furniture','.w-predefined-promotion .icon','width','45','','','.w-predefined-promotion'),(902598,'furniture','.w-predefined-promotion .nextdiscount .item-holder .image','width','40','','','.w-predefined-promotion'),(902599,'furniture','.w-predefined-promotion .nextdiscount .item-holder .name','width','60','','','.w-predefined-promotion'),(902600,'furniture','.w-predefined-promotion .prom-multi-discount .image img','width','auto','','','.w-predefined-promotion'),(902601,'furniture','.w-predefined-promotion .prom-multi-discount .list','width','100','','','.w-predefined-promotion'),(902602,'furniture','.w-predefined-promotion .promo-cart-discount .image img','width','auto','','','.w-predefined-promotion'),(902603,'furniture','.w-predefined-promotion .promo-cart-discount .master .item','width','calc(50% - 24px)','','','.w-predefined-promotion'),(902604,'furniture','.w-predefined-promotion .promo-cart-discount .slave .item','width','calc(50% - 4px)','','','.w-predefined-promotion'),(902605,'furniture','.w-predefined-promotion .promo-cart-discount > div','width','50','','','.w-predefined-promotion'),(902606,'furniture','.w-predefined-promotion .promo-salemaker .image img','width','auto','','','.w-predefined-promotion'),(902607,'furniture','.w-predefined-promotion .promo-salemaker .item','width','50','','','.w-predefined-promotion'),(902608,'furniture','.w-predefined-promotion .promo-salemaker > div','width','50','','','.w-predefined-promotion'),(902609,'furniture','.w-filters .fsl_handle > div','width','50','','','.w-filters'),(902610,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','width','0','','','.w-filters'),(902611,'furniture','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','width','24','','','.w-filters'),(902612,'furniture','.mainBanner .bottomBox .elf','width','100','','','.mainBanner'),(902613,'furniture','.mainBanner .title','width','4.5','3','','.mainBanner'),(902614,'furniture','.mainBanner .title','width','100','','','.mainBanner'),(902615,'furniture','.mainBanner .topBox > .right','width','30','3','','.mainBanner'),(902616,'furniture','.mainBanner .title','width','7.5','5131,3','','.mainBanner'),(902617,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','width','40','','','.mainBanner'),(902618,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','width','65','5131','','.mainBanner'),(902619,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','width','80','5161','','.mainBanner'),(902620,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','width','40','','','.mainBanner'),(902621,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','width','40','','','.mainBanner'),(902622,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','width','65','5131','','.mainBanner'),(902623,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','width','65','5131','','.mainBanner'),(902624,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','width','80','5161','','.mainBanner'),(902625,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','width','80','5161','','.mainBanner'),(902626,'furniture','.mainBanner .title','width','80','5206,3','','.mainBanner'),(902627,'furniture','.w-promotions-widgets-promotion-icons-desc .promo-icon','width','20','','','.w-promotions-widgets-promotion-icons-desc'),(902628,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','width','75','','','.w-promotions-widgets-promotion-icons-desc'),(902648,'furniture','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','width','48','','','.account-address-book'),(902649,'furniture','.account-address-book .address_book_row .column','width','100','5131','','.account-address-book'),(902650,'furniture','.account-address-book .address_book_row .column + .column','width','100','5131','','.account-address-book'),(902651,'furniture','.account-address-book .topInfo > div','width','100','5131','','.account-address-book'),(902652,'furniture','.account-address-book .topInfo > div + div','width','100','5131','','.account-address-book'),(902659,'furniture','.account-order-pay .history_info > div','width','33.3','','','.account-order-pay'),(902660,'furniture','.account-order-pay .not_fully_paid_td','width','300','','','.account-order-pay'),(902661,'furniture','.account-order-pay .history_info > div','width','100','5140','','.account-order-pay'),(902662,'furniture','.account-samples .not_fully_paid_td','width','300','','','.account-samples'),(902663,'furniture','.account-samples .orders-table .hidden','width','130','5140','','.account-samples'),(902664,'furniture','.account-samples .orders-table .td-alignright','width','100','5140','','.account-samples'),(902665,'furniture','.account-sample-info .history_info > div','width','33.3','','','.account-sample-info'),(902666,'furniture','.account-sample-info .not_fully_paid_td','width','300','','','.account-sample-info'),(902667,'furniture','.account-sample-info .history_info > div','width','100','5140','','.account-sample-info'),(902668,'furniture','.catalog-product-wrap .pn-image','width','24','3','','.catalog-product-wrap'),(902669,'furniture','.catalog-product-wrap .prev-next-product','width','190','','','.catalog-product-wrap'),(902670,'furniture','.catalog-product-wrap .next-product','width','60','5140','','.catalog-product-wrap'),(902671,'furniture','.catalog-product-wrap .prev-product','width','60','5140','','.catalog-product-wrap'),(902672,'furniture','.checkout-index-wrap .datepicker-inline','width','280','','','.checkout-index-wrap'),(902673,'furniture','.checkout-index-wrap .dob-hide > div','width','48','','','.checkout-index-wrap'),(902674,'furniture','.checkout-index-wrap .edit-address-popup','width','1000','','','.checkout-index-wrap'),(902675,'furniture','.checkout-index-wrap .edit-address-popup .addresses .address-item','width','33','','','.checkout-index-wrap'),(902676,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons','width','100','','','.checkout-index-wrap'),(902677,'furniture','.checkout-index-wrap .order-summary .heading-2','width','100','3','','.checkout-index-wrap'),(902678,'furniture','.checkout-index-wrap .order-summary .heading-2','width','100','4','','.checkout-index-wrap'),(902679,'furniture','.checkout-index-wrap .order-summary2 .btn-2','width','100','','','.checkout-index-wrap'),(902680,'furniture','.checkout-order-confirmation .order-summary2 .btn-2','width','100','','','.checkout-order-confirmation'),(902681,'furniture','.checkout-login-wrap .col-left, .checkout-login-wrap .col-right','width','100','','','.checkout-login-wrap'),(902682,'furniture','.checkout-login-wrap .middle-form .btn-2','width','100','','','.checkout-login-wrap'),(902683,'furniture','.b-form .center-buttons','width','100','','','.b-form'),(902684,'furniture','.b-form .col-gender','width','100','','','.b-form'),(902685,'furniture','.b-form .password-row','width','100','','','.b-form'),(902686,'furniture','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','width','33','','','.b-multi-page-checkout'),(902687,'furniture','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','width','35','3','','.b-multi-page-checkout'),(902688,'furniture','.success-page .w-cart-listing .qty','width','24','','','.success-page'),(902689,'furniture','.mainBanner .w-banner .banner-text-holder .content','width','100','','','.mainBanner'),(902690,'furniture','.menu-header .menu-style[data-lev2_display=\"width\"] .level-2 > li','width','300','','','.menu-header'),(902691,'furniture','.menu-header .menu-style[data-lev2_display=\"width_cont\"] .level-2 > li','width','300','','','.menu-header'),(902692,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','width','100','','','.menu-header'),(902693,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li:nth-child(1) > ul > li, .footer-menu .menu-style[data-style=\"3\"] .level-1 > li:nth-child(2) > ul > li','width','50','','','.footer-menu'),(902694,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li','width','100','','','.footer-menu'),(902695,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li','width','100','5145','','.footer-menu'),(902696,'furniture','.lowestPricedBox .w-banner .banner-item','width','100','','','.lowestPricedBox'),(902697,'furniture','.lowestPricedBox .w-banner .banner-item:nth-child(1) .ybg:before','width','15','5145','','.lowestPricedBox'),(902698,'furniture','.lowestPricedBox .w-banner .banner-item:nth-child(2) .ybg:before','width','15','5145','','.lowestPricedBox'),(902699,'furniture','.lowestPricedBox .w-banner .banner-text-holder','width','100','','','.lowestPricedBox'),(902700,'furniture','.lowestPricedBox .w-banner .banner-text-holder','width','100','5140','','.lowestPricedBox'),(902701,'furniture','.lowestPricedBox .w-banner .ybg','width','20','3','','.lowestPricedBox'),(902702,'furniture','.lowestPricedBox .w-banner .ybg .btn','width','100','','','.lowestPricedBox'),(902703,'furniture','.tripleBanner .w-html_box','width','80','3','','.tripleBanner'),(902704,'furniture','.tripleBanner > .block','width','100','5140','','.tripleBanner'),(902705,'furniture','.shopByCollectionBox .w-banner .banner-item','width','33.333','','','.shopByCollectionBox'),(902706,'furniture','.shopByCollectionBox .w-banner .banner-item','width','calc(50% - 20px)','5140','','.shopByCollectionBox'),(902707,'furniture','.shopByCollectionBox .w-banner .banner-item','width','100','5161','','.shopByCollectionBox'),(902710,'furniture','.accout-box select[data-type=\"vat_number\"]','width','40','','','.accout-box'),(902711,'furniture','.w-account-customer-additional-field .field-type-checkbox label','width','40','','','.w-account-customer-additional-field'),(902712,'furniture','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width','60','','','.w-account-customer-additional-field'),(902713,'furniture','.w-account-customer-additional-field .field-type-text label','width','40','','','.w-account-customer-additional-field'),(902714,'furniture','.w-banner .banner-text-holder','width','100','','','.w-banner'),(902715,'furniture','.w-banner .carousel-text','width','100','','','.w-banner'),(902716,'furniture','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width','100','','','.w-banner'),(902717,'furniture','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width','100','','','.w-banner'),(902718,'furniture','.w-catalog-paging .paging-holder','width','150','','','.w-catalog-paging'),(902719,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width','30','','','.w-catalog-paging'),(902720,'furniture','.w-compare-box-item .checkbox','width','22','','','.w-compare-box-item'),(902721,'furniture','.w-compare-box-item .checkbox + span','width','24','','','.w-compare-box-item'),(902722,'furniture','.w-compare-box-item .checkbox:not(checked) + span:before','width','22','','','.w-compare-box-item'),(902723,'furniture','.b-warehouses-popup .warehouses-popup','width_important','important','','','.b-warehouses-popup'),(902726,'furniture','.b-messages .pre_upload','width_important','important','','','.b-messages'),(902727,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width_important','important','3','','.b-switch'),(902728,'furniture','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width_important','important','3','','.b-switch'),(902731,'furniture','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width_important','important','','','.b-select-suggest'),(902732,'furniture','.w-checkout-credit-amount .cot_gv_amount','width_important','important','','','.w-checkout-credit-amount'),(902735,'furniture','.w-checkout-bonus-points .bonus_points_amount','width_important','important','','','.w-checkout-bonus-points'),(902736,'furniture','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width_important','important','','','.w-coupons-and-vauchers-checkout'),(902741,'furniture','.w-cart-discount-coupon input[type=\"text\"]','width_important','important','','','.w-cart-discount-coupon'),(902742,'furniture','.w-cart-credit-amount input[type=\"text\"]','width_important','important','','','.w-cart-credit-amount'),(902745,'furniture','.menu-header .burger-icon','width_important','important','5140','','.menu-header'),(902746,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_important','important','','','.b-menu-open_from-left'),(902747,'furniture','.w-cart-bonus-points .bonus_points_amount','width_important','important','','','.w-cart-bonus-points'),(902748,'furniture','.w-rma-returns-history thead tr td:first-child','width_important','important','','','.w-rma-returns-history'),(902749,'furniture','.checkout-index-wrap .edit-address-popup','width_important','important','','','.checkout-index-wrap'),(902750,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li','width_important','important','5145','','.footer-menu'),(902751,'furniture','.tripleBanner > .block','width_important','important','5140','','.tripleBanner'),(902752,'furniture','.accout-box select[data-type=\"vat_number\"]','width_important','important','','','.accout-box'),(902753,'furniture','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width_important','important','','','.w-catalog-paging'),(902754,'furniture','.b-form .col-right','width_measure','%','5140','','.b-form'),(902755,'furniture','.b-form .login-col-2','width_measure','%','','','.b-form'),(902756,'furniture','.order-summary .btn-2, .order-summary .btn-3','width_measure','%','','','.order-summary'),(902757,'furniture','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(902758,'furniture','.w-promotions .promo-salemaker > div','width_measure','%','','','.w-promotions'),(902759,'furniture','.w-promotions .promo-cart-discount > div','width_measure','%','','','.w-promotions'),(902762,'furniture','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width_measure','%','','','.p-sample-checkout-login'),(902763,'furniture','.w-promotions .prom-multi-discount .list','width_measure','%','','','.w-promotions'),(902764,'furniture','.w-promotions .nextdiscount .item-holder .name','width_measure','%','','','.w-promotions'),(902765,'furniture','.w-promotions .nextdiscount .item-holder .image','width_measure','%','','','.w-promotions'),(902766,'furniture','.w-promotions .promo-salemaker .item','width_measure','%','','','.w-promotions'),(902767,'furniture','.b-preloader .preloader','width_measure','%','','','.b-preloader'),(902768,'furniture','.b-products-listing .products-listing .attribute-qty-block','width_measure','%','','','.b-products-listing'),(902769,'furniture','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(902770,'furniture','.w-cart-continue-btn a','width_measure','%','5131','','.w-cart-continue-btn'),(902771,'furniture','.w-cart-checkout-btn ','width_measure','%','5131','','.w-cart-checkout-btn'),(902772,'furniture','.b-messages .box-block.type-6 > .block:nth-child(1)','width_measure','%','','','.b-messages'),(902773,'furniture','.b-messages .messages-sidebar .btn-2','width_measure','%','','','.b-messages'),(902774,'furniture','.b-messages .email-line input','width_measure','%','','','.b-messages'),(902775,'furniture','.w-sitemap-delivery-location > ul > li > ul > li','width_measure','%','','','.w-sitemap-delivery-location'),(902776,'furniture','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(902777,'furniture','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(902778,'furniture','.p-payer-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-confirmation'),(902779,'furniture','.p-payer-order-confirmation .dob-hide > div','width_measure','%','','','.p-payer-order-confirmation'),(902780,'furniture','.p-payer-order-pay .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-pay'),(902781,'furniture','.p-payer-order-pay .dob-hide > div','width_measure','%','','','.p-payer-order-pay'),(902782,'furniture','.w-checkout-terms .required-message','width_measure','%','','','.w-checkout-terms'),(902783,'furniture','.b-form .checkbox-style:checked + .checkbox-span','width_measure','x','','','.b-form'),(902784,'furniture','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(902785,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(902786,'furniture','.w-upload-customer-id-upload-customer-id-form .dz-details','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(902787,'furniture','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(902788,'furniture','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(902789,'furniture','.w-login-block .input','width_measure','%','','','.w-login-block'),(902790,'furniture','.w-login-block .guest','width_measure','%','','','.w-login-block'),(902791,'furniture','.w-login-block .new','width_measure','%','','','.w-login-block'),(902792,'furniture','.w-login-block .returning','width_measure','%','','','.w-login-block'),(902793,'furniture','.w-product-wishlist-button .btn','width_measure','%','5131','','.w-product-wishlist-button'),(902794,'furniture','.w-cart-order-total.box','width_measure','%','5131','','.w-cart-order-total'),(902795,'furniture','.w-cart-give-away .ga_attributes select','width_measure','%','','','.w-cart-give-away'),(902796,'furniture','.w-categories .item','width_measure','%','5131','','.w-categories'),(902797,'furniture','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(902798,'furniture','.b-email .totals-title','width_measure','%','','','.b-email'),(902799,'furniture','.b-email .totals-table','width_measure','%','','','.b-email'),(902800,'furniture','.w-login-block .input','width_measure','%','','','.w-login-block'),(902801,'furniture','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(902802,'furniture','.w-cart-order-total.box','width_measure','%','5131','','.w-cart-order-total'),(902803,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(902804,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(902805,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(902806,'furniture','.pop-up-content .buttons .btn','width_measure','%','5140','',''),(902807,'furniture','.pop-up-content .buttons .right-buttons','width_measure','%','5140','',''),(902808,'furniture','.pop-up-content .buttons .btn-2','width_measure','%','5140','',''),(902809,'furniture','.pop-up-content .buttons .left-buttons','width_measure','%','5140','',''),(902810,'furniture','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(902811,'furniture','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(902812,'furniture','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(902813,'furniture','.w-login-block .input','width_measure','%','','','.w-login-block'),(902814,'furniture','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(902815,'furniture','.w-filters .ui-slider','width_measure','%','','','.w-filters'),(902816,'furniture','.w-cart-give-away .ga_column','width_measure','%','','','.w-cart-give-away'),(902817,'furniture','.w-product-wishlist-button .btn','width_measure','%','5131','','.w-product-wishlist-button'),(902818,'furniture','.w-promo-code .promo-text','width_measure','%','5140','','.w-promo-code'),(902819,'furniture','.w-tabs .tab-navigation','width_measure','%','','','.w-tabs'),(902820,'furniture','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width_measure','%','','','.p-quote-checkout-login'),(902821,'furniture','.b-products-listing .select-attributes select','width_measure','%','','','.b-products-listing'),(902822,'furniture','.w-cart-listing .right-area','width_measure','%','5140','','.w-cart-listing'),(902823,'furniture','.p-quick-order-index .all-scroll-div','width_measure','%','','','.p-quick-order-index'),(902824,'furniture','.w-cart-order-total.box','width_measure','%','5131','','.w-cart-order-total'),(902825,'furniture','.view-all','width_measure','%','3','',''),(902826,'furniture','.b-form .columns .col-2','width_measure','%','','','.b-form'),(902827,'furniture','.b-email .totals-title','width_measure','%','','','.b-email'),(902828,'furniture','.w-cart-checkout-btn a','width_measure','%','5131','','.w-cart-checkout-btn'),(902829,'furniture','.w-cart-order-total.box','width_measure','%','5131','','.w-cart-order-total'),(902830,'furniture','.w-top-categories .item','width_measure','%','','','.w-top-categories'),(902832,'furniture','.b-bottom .popup-box.popupCompare','width_measure','%','','','.b-bottom'),(902833,'furniture','.w-cart-order-total.box','width_measure','%','5131','','.w-cart-order-total'),(902834,'furniture','.w-promo-code .promo-text','width_measure','%','5140','','.w-promo-code'),(902835,'furniture','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(902836,'furniture','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(902837,'furniture','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(902838,'furniture','.b-form .login-col-1','width_measure','%','','','.b-form'),(902839,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(902840,'furniture','.b-email .products-table','width_measure','%','','','.b-email'),(902841,'furniture','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(902842,'furniture','.w-list-b2b .select-attributes','width_measure','%','','','.w-list-b2b'),(902843,'furniture','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(902844,'furniture','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(902845,'furniture','.w-checkout-shipping-choice label','width_measure','%','','','.w-checkout-shipping-choice'),(902846,'furniture','.b-products-listing .btn-choose-options','width_measure','%','','','.b-products-listing'),(902847,'furniture','.b-email .products-table','width_measure','%','','','.b-email'),(902848,'furniture','.w-checkout-create-account .col-2','width_measure','%','5140','','.w-checkout-create-account'),(902849,'furniture','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(902850,'furniture','.w-product-wishlist-button .btn','width_measure','%','5131','','.w-product-wishlist-button'),(902851,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(902852,'furniture','.b-email .products-table','width_measure','%','','','.b-email'),(902853,'furniture','.b-email .totals-title','width_measure','%','','','.b-email'),(902854,'furniture','.b-email .totals-value','width_measure','%','','','.b-email'),(902855,'furniture','.b-email .totals-table','width_measure','%','','','.b-email'),(902856,'furniture','.b-email .products-table','width_measure','%','','','.b-email'),(902857,'furniture','.w-cart-continue-btn a','width_measure','%','5131','','.w-cart-continue-btn'),(902858,'furniture','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(902859,'furniture','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(902860,'furniture','.w-promo-code .promo-code-form','width_measure','%','5140','','.w-promo-code'),(902861,'furniture','.w-promo-code .promo-text','width_measure','%','5140','','.w-promo-code'),(902862,'furniture','.b-form .columns .col-2','width_measure','%','5161','','.b-form'),(902863,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(902864,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(902865,'furniture','.w-login-block .input','width_measure','%','','','.w-login-block'),(902866,'furniture','.w-login-block .returning','width_measure','%','','','.w-login-block'),(902867,'furniture','.w-login-block .new','width_measure','%','','','.w-login-block'),(902868,'furniture','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(902869,'furniture','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(902870,'furniture','.w-login-block .guest','width_measure','%','','','.w-login-block'),(902871,'furniture','.b-form .col-left','width_measure','%','','','.b-form'),(902872,'furniture','.w-cart-give-away .ga_attributes > div','width_measure','%','','','.w-cart-give-away'),(902873,'furniture','.w-image-maps .svg-wrap svg','width_measure','%','','','.w-image-maps'),(902874,'furniture','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width_measure','%','','','.b-form'),(902875,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(902876,'furniture','.w-cart-listing .links','width_measure','%','','','.w-cart-listing'),(902877,'furniture','.w-login-block .returning','width_measure','%','','','.w-login-block'),(902878,'furniture','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(902879,'furniture','.w-login-block .guest','width_measure','%','','','.w-login-block'),(902880,'furniture','.w-login-block .new','width_measure','%','','','.w-login-block'),(902881,'furniture','.w-cart-shipping-estimator .left-area','width_measure','%','','','.w-cart-shipping-estimator'),(902882,'furniture','.b-form .col-right','width_measure','%','','','.b-form'),(902883,'furniture','.b-email .totals-title','width_measure','%','','','.b-email'),(902884,'furniture','.b-email .products-table','width_measure','%','','','.b-email'),(902885,'furniture','.b-bottom .cart-options .option-item','width_measure','%','','','.b-bottom'),(902886,'furniture','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(902887,'furniture','.b-bottom .cart-options .cart-item','width_measure','%','','','.b-bottom'),(902888,'furniture','.w-login-block .guest','width_measure','%','','','.w-login-block'),(902889,'furniture','.b-email .totals-table','width_measure','%','','','.b-email'),(902890,'furniture','.b-email .totals-value','width_measure','%','','','.b-email'),(902891,'furniture','.w-promo-code .promo-text','width_measure','%','5140','','.w-promo-code'),(902892,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(902893,'furniture','.w-login-block .returning','width_measure','%','','','.w-login-block'),(902894,'furniture','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(902895,'furniture','.w-cart-continue-btn a','width_measure','%','5131','','.w-cart-continue-btn'),(902896,'furniture','.b-email .totals-value','width_measure','%','','','.b-email'),(902897,'furniture','.b-form .col-left','width_measure','%','5140','','.b-form'),(902898,'furniture','.b-form .middle-form .dob-input input[type=\"text\"]','width_measure','%','','','.b-form'),(902899,'furniture','.w-top-categories .item','width_measure','%','5131','','.w-top-categories'),(902900,'furniture','.w-categories .item','width_measure','%','5161','','.w-categories'),(902901,'furniture','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(902902,'furniture','.w-checkout-billing-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-billing-address'),(902903,'furniture','.w-checkout-shipping-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-shipping-address'),(902904,'furniture','.w-cart-order-total.box','width_measure','%','5131','','.w-cart-order-total'),(902905,'furniture','.w-product-wishlist-button .btn','width_measure','%','5131','','.w-product-wishlist-button'),(902906,'furniture','.w-cart-continue-btn a','width_measure','%','5131','','.w-cart-continue-btn'),(902907,'furniture','.w-promo-code .promo-text','width_measure','%','5140','','.w-promo-code'),(902908,'furniture','.w-promo-code .promo-code-form','width_measure','%','5140','','.w-promo-code'),(902909,'furniture','.w-promo-code .promo-text','width_measure','%','5140','','.w-promo-code'),(902910,'furniture','.w-checkout-billing-address .addresses .address-item','width_measure','%','','','.w-checkout-billing-address'),(902911,'furniture','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(902912,'furniture','.b-products-listing .products-listing .buyButton .btn','width_measure','%','','','.b-products-listing'),(902913,'furniture','.b-select-suggest .select2-search input','width_measure','%','','','.b-select-suggest'),(902914,'furniture','.b-select-suggest .select2-search','width_measure','%','','','.b-select-suggest'),(902915,'furniture','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width_measure','%','','','.b-select-suggest'),(902916,'furniture','.b-select-suggest .select2-drop','width_measure','%','','','.b-select-suggest'),(902917,'furniture','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(902918,'furniture','.w-login-block .input','width_measure','%','','','.w-login-block'),(902919,'furniture','.w-login-block .new','width_measure','%','','','.w-login-block'),(902920,'furniture','.w-login-block .returning','width_measure','%','','','.w-login-block'),(902921,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(902923,'furniture','.w-login-block .returning','width_measure','%','','','.w-login-block'),(902924,'furniture','.w-cart-continue-btn a','width_measure','%','5131','','.w-cart-continue-btn'),(902925,'furniture','.w-product-wishlist-button .btn','width_measure','%','5131','','.w-product-wishlist-button'),(902926,'furniture','.w-account-addresses-list .addsess-suggestion-item','width_measure','%','','','.w-account-addresses-list'),(902927,'furniture','.b-products-listing .products-listing a.btn.view-button','width_measure','%','','','.b-products-listing'),(902928,'furniture','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(902929,'furniture','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(902930,'furniture','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(902931,'furniture','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(902932,'furniture','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(902933,'furniture','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(902934,'furniture','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(902935,'furniture','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(902936,'furniture','.b-products-listing .BlockBox.type-14 > .col','width_measure','%','','','.b-products-listing'),(902937,'furniture','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(902938,'furniture','.b-products-listing .BlockBox.type-15 > .col','width_measure','%','','','.b-products-listing'),(902939,'furniture','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(902940,'furniture','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(902941,'furniture','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(902942,'furniture','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(902943,'furniture','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(902944,'furniture','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(902945,'furniture','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(902946,'furniture','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(902947,'furniture','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(902948,'furniture','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(902949,'furniture','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(902950,'furniture','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(902951,'furniture','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(902952,'furniture','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(902953,'furniture','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(902954,'furniture','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(902955,'furniture','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(902956,'furniture','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(902957,'furniture','.b-products-listing .loader','width_measure','%','3','','.b-products-listing'),(902958,'furniture','.b-products-listing .products-listing .attribute-qty-block > span','width_measure','%','','','.b-products-listing'),(902959,'furniture','.b-products-listing .products-listing .attributes select','width_measure','%','','','.b-products-listing'),(902960,'furniture','.b-products-listing .products-listing .btn-buy','width_measure','%','','','.b-products-listing'),(902961,'furniture','.b-products-listing .products-listing .item','width_measure','%','','','.b-products-listing'),(902962,'furniture','.w-catalog-b2b-add-button ','width_measure','%','','','.w-catalog-b2b-add-button'),(902963,'furniture','.b-products-listing .products-listing .qty-input.hidden','width_measure','%','3','','.b-products-listing'),(902964,'furniture','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width_measure','%','','','.b-products-listing'),(902966,'furniture','.b-products-listing .products-listing .in-cart','width_measure','%','','','.b-products-listing'),(902967,'furniture','.b-select-suggest .select2-container','width_measure','%','','','.b-select-suggest'),(902968,'furniture','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(902969,'furniture','.b-email .totals-table','width_measure','%','','','.b-email'),(902970,'furniture','.b-email .totals-value','width_measure','%','','','.b-email'),(902971,'furniture','.b-email .totals-title','width_measure','%','','','.b-email'),(902972,'furniture','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width_measure','%','','','.b-fancybox'),(902973,'furniture','.w-promo-code .promo-code-form','width_measure','%','5140','','.w-promo-code'),(902974,'furniture','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(902975,'furniture','.w-communication-new-topic .middle-form select','width_measure','%','','','.w-communication-new-topic'),(902976,'furniture','.b-form .hide-billing-address','width_measure','%','','','.b-form'),(902977,'furniture','.b-email .totals-value','width_measure','%','','','.b-email'),(902978,'furniture','.b-email .products-table','width_measure','%','','','.b-email'),(902979,'furniture','.b-bottom .popup-credit-amount .popup-box','width_measure','%','','','.b-bottom'),(902980,'furniture','.w-promo-code .promo-code-form','width_measure','%','5140','','.w-promo-code'),(902981,'furniture','.w-login-block .new','width_measure','%','','','.w-login-block'),(902982,'furniture','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(902983,'furniture','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(902984,'furniture','.b-compare .col-two label','width_measure','%','','','.b-compare'),(902985,'furniture','.b-form .addresses .address-item','width_measure','%','','','.b-form'),(902986,'furniture','.w-cart-continue-btn a','width_measure','%','5131','','.w-cart-continue-btn'),(902987,'furniture','.w-cart-shipping-estimator .right-area','width_measure','%','','','.w-cart-shipping-estimator'),(902988,'furniture','.w-cart-listing .right-area','width_measure','%','','','.w-cart-listing'),(902989,'furniture','.w-cart-listing .item .remove','width_measure','%','5140','','.w-cart-listing'),(902990,'furniture','.w-cart-give-away .ga_img','width_measure','%','','','.w-cart-give-away'),(902991,'furniture','.w-cart-give-away .ga_column','width_measure','%','5131','','.w-cart-give-away'),(902992,'furniture','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(902993,'furniture','.b-fancybox .fancybox-nav','width_measure','%','','','.b-fancybox'),(902994,'furniture','.w-promo-code .promo-code-form','width_measure','%','5140','','.w-promo-code'),(902995,'furniture','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(902996,'furniture','.w-login-block .input','width_measure','%','','','.w-login-block'),(902997,'furniture','.w-login-block .new','width_measure','%','','','.w-login-block'),(902998,'furniture','.w-login-block .guest','width_measure','%','','','.w-login-block'),(902999,'furniture','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(903000,'furniture','.w-checkout-shipping-address .addresses .address-item','width_measure','%','','','.w-checkout-shipping-address'),(903001,'furniture','.w-login-block .guest','width_measure','%','','','.w-login-block'),(903002,'furniture','.w-filters .handle-from','width_measure','%','','','.w-filters'),(903003,'furniture','.w-promo-code .promo-code-form','width_measure','%','5140','','.w-promo-code'),(903004,'furniture','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(903005,'furniture','.w-filters .handle-to','width_measure','%','','','.w-filters'),(903006,'furniture','.w-categories .item','width_measure','%','','','.w-categories'),(903007,'furniture','.b-compare .col-two select','width_measure','%','','','.b-compare'),(903008,'furniture','.b-email .totals-table','width_measure','%','','','.b-email'),(903009,'furniture','.b-form .col-3','width_measure','%','','','.b-form'),(903010,'furniture','textarea','width_measure','%','','',''),(903011,'furniture','.w-product-wishlist-button .btn','width_measure','%','5131','','.w-product-wishlist-button'),(903012,'furniture','.b-products-listing .products-listing .btn-preloader','width_measure','%','','','.b-products-listing'),(903013,'furniture','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width_measure','%','','','.b-form'),(903014,'furniture','.b-email .totals-title','width_measure','%','','','.b-email'),(903015,'furniture','.b-email .totals-value','width_measure','%','','','.b-email'),(903016,'furniture','.b-email .totals-table','width_measure','%','','','.b-email'),(903017,'furniture','.w-filters .input-txt-keywords','width_measure','%','','','.w-filters'),(903018,'furniture','.w-filters .input-txt','width_measure','%','','','.w-filters'),(903019,'furniture','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width_measure','vw','','','.b-menu-lev_display-slide'),(903020,'furniture','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width_measure','vw','','','.b-menu-lev_display-slide'),(903021,'furniture','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width_measure','vw','','','.b-menu-lev_display-slide'),(903022,'furniture','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width_measure','vw','','','.b-menu-lev_display-slide'),(903023,'furniture','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width_measure','vw','','','.b-menu-lev_display-slide'),(903024,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_measure','vw','','','.b-menu-open_from-left'),(903025,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(903026,'furniture','.b-trade-approval .steps-bar','width_measure','%','','','.b-trade-approval'),(903027,'furniture','.b-trade-approval .col-right','width_measure','%','','','.b-trade-approval'),(903028,'furniture','.b-trade-approval .col-left','width_measure','%','','','.b-trade-approval'),(903029,'furniture','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width_measure','%','','','.b-trade-approval'),(903030,'furniture','.b-trade-approval .col-3','width_measure','%','','','.b-trade-approval'),(903031,'furniture','.w-account-personal-catalog .list-switcher','width_measure','%','','','.w-account-personal-catalog'),(903032,'furniture','.w-catalog-compare .cross-box .different-all > div','width_measure','%','','','.w-catalog-compare'),(903034,'furniture','.b-products-listing .products-listing.list-productlisting .BlockBox.type-2 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(903035,'furniture','.b-products-listing .products-listing.list-productlisting .BlockBox.type-2 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(903036,'furniture','.b-products-listing .item-nav > div','width_measure','%','','','.b-products-listing'),(903037,'furniture','.b-products-listing .products-listing.list-productlisting .item-content','width_measure','%','4','','.b-products-listing'),(903038,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','width_measure','%','','','.b-products-listing'),(903039,'furniture','.w-product-sale-ends .left-count','width_measure','%','','','.w-product-sale-ends'),(903040,'furniture','.w-product-sale-ends .left-text-left','width_measure','%','','','.w-product-sale-ends'),(903041,'furniture','.w-product-sale-ends .left-text-right','width_measure','%','','','.w-product-sale-ends'),(903042,'furniture','h1, .heading-1','width_measure','%','3','',''),(903043,'furniture','h1, .heading-1','width_measure','%','4','',''),(903044,'furniture','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(903045,'furniture','.w-product-bonus-points > div > div','width_measure','%','','','.w-product-bonus-points'),(903046,'furniture','.w-files-catalog-widgets-files-catalog .item','width_measure','%','','','.w-files-catalog-widgets-files-catalog'),(903047,'furniture','.w-files-catalog-widgets-files-catalog .item','width_measure','%','5145','','.w-files-catalog-widgets-files-catalog'),(903048,'furniture','.w-files-catalog-widgets-files-catalog .item','width_measure','%','5140','','.w-files-catalog-widgets-files-catalog'),(903049,'furniture','.w-files-catalog-widgets-files-catalog .item','width_measure','%','5131','','.w-files-catalog-widgets-files-catalog'),(903050,'furniture','.w-cart-discount-coupon input[type=\"text\"]','width_measure','%','','','.w-cart-discount-coupon'),(903051,'furniture','.w-cart-sub-total .price-row','width_measure','%','','','.w-cart-sub-total'),(903052,'furniture','.w-cart-sub-total .price-row > div','width_measure','%','','','.w-cart-sub-total'),(903053,'furniture','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(903054,'furniture','.w-cart-gift-certificate .input-apple','width_measure','%','','','.w-cart-gift-certificate'),(903055,'furniture','.w-cart-gift-certificate .input-apple div','width_measure','%','','','.w-cart-gift-certificate'),(903056,'furniture','.w-cart-order-reference .input-apple','width_measure','%','','','.w-cart-order-reference'),(903057,'furniture','.w-cart-order-reference .input-apple div','width_measure','%','','','.w-cart-order-reference'),(903058,'furniture','.w-cart-order-reference .input-apple div input','width_measure','%','','','.w-cart-order-reference'),(903059,'furniture','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(903060,'furniture','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(903061,'furniture','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(903062,'furniture','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(903063,'furniture','.w-product-bundle .bundle_item','width_measure','%','5140','','.w-product-bundle'),(903064,'furniture','.w-product-bundle .bundle_item','width_measure','%','5131','','.w-product-bundle'),(903065,'furniture','.w-product-in-bundles .attributes-item','width_measure','%','','','.w-product-in-bundles'),(903066,'furniture','.w-product-in-bundles .attributes-select','width_measure','%','','','.w-product-in-bundles'),(903067,'furniture','.w-product-in-bundles .bundle_item','width_measure','%','5140','','.w-product-in-bundles'),(903068,'furniture','.w-product-in-bundles .bundle_item','width_measure','%','5131','','.w-product-in-bundles'),(903069,'furniture','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(903070,'furniture','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(903071,'furniture','.heading-2','width_measure','%','3','',''),(903072,'furniture','.heading-2','width_measure','%','4','',''),(903073,'furniture','.w-product-quantity-discounts .item','width_measure','%','','','.w-product-quantity-discounts'),(903074,'furniture','.w-product-multi-inventory .select-box:nth-child(2n)','width_measure','%','','','.w-product-multi-inventory'),(903075,'furniture','.w-product-multi-inventory .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-multi-inventory'),(903076,'furniture','.p-quote-checkout-index .order-summary .heading-2','width_measure','%','3','','.p-quote-checkout-index'),(903077,'furniture','.p-quote-checkout-index .order-summary .heading-2','width_measure','%','4','','.p-quote-checkout-index'),(903078,'furniture','.p-sample-checkout-index .order-summary .heading-2','width_measure','%','3','','.p-sample-checkout-index'),(903079,'furniture','.p-sample-checkout-index .order-summary .heading-2','width_measure','%','4','','.p-sample-checkout-index'),(903081,'furniture','.w-product-multi-inventory .radio-attributes > label','width_measure','%','','','.w-product-multi-inventory'),(903082,'furniture','.w-product-multi-inventory .radio-attributes .option-item','width_measure','%','','','.w-product-multi-inventory'),(903083,'furniture','.w-product-multi-inventory .radio-attributes > label','width_measure','%','5145','','.w-product-multi-inventory'),(903084,'furniture','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','width_measure','%','','','.w-account-personal-catalog'),(903085,'furniture','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width_measure','%','5145','','.b-products-listing'),(903086,'furniture','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width_measure','%','5145','','.b-products-listing'),(903087,'furniture','.b-products-listing .products-listing .radio-attributes .option','width_measure','%','','','.b-products-listing'),(903088,'furniture','.b-products-listing .products-listing .radio-attributes > label','width_measure','%','','','.b-products-listing'),(903089,'furniture','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(903090,'furniture','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(903091,'furniture','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(903092,'furniture','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(903093,'furniture','.w-product-collection .current-product, .w-product-collection .chosen-products','width_measure','%','5140','','.w-product-collection'),(903094,'furniture','.w-product-collection .right-area','width_measure','%','5140','','.w-product-collection'),(903095,'furniture','.w-product-attributes .radio-attributes .option-item','width_measure','%','','','.w-product-attributes'),(903096,'furniture','.w-product-attributes .radio-attributes > label','width_measure','%','','','.w-product-attributes'),(903097,'furniture','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(903098,'furniture','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(903099,'furniture','.w-product-attributes .radio-attributes > label','width_measure','%','5145','','.w-product-attributes'),(903100,'furniture','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(903101,'furniture','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(903102,'furniture','.w-product-properties li','width_measure','%','','','.w-product-properties'),(903103,'furniture','.w-product-groups .radioBox label','width_measure','%','','','.w-product-groups'),(903104,'furniture','.w-product-groups .radioBox label','width_measure','%','5161','','.w-product-groups'),(903105,'furniture','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(903106,'furniture','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(903107,'furniture','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(903108,'furniture','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(903109,'furniture','.w-product-custom-bundle .chosen-products','width_measure','%','5140','','.w-product-custom-bundle'),(903110,'furniture','.w-product-custom-bundle .right-area','width_measure','%','5140','','.w-product-custom-bundle'),(903111,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width_measure','%','','','.w-catalog-pages-category-pages-last-list'),(903112,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width_measure','%','5140','','.w-catalog-pages-category-pages-last-list'),(903113,'furniture','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width_measure','%','5131','','.w-catalog-pages-category-pages-last-list'),(903114,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width_measure','%','','','.w-catalog-pages-category-pages-last-list-block'),(903115,'furniture','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(903116,'furniture','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(903117,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width_measure','%','5140','','.w-catalog-pages-category-pages-last-list-block'),(903118,'furniture','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width_measure','%','5131','','.w-catalog-pages-category-pages-last-list-block'),(903119,'furniture','.w-delivery-location-location-list .deliveryList li','width_measure','%','5140','','.w-delivery-location-location-list'),(903120,'furniture','.w-delivery-location-location-list .deliveryList li','width_measure','%','5131','','.w-delivery-location-location-list'),(903121,'furniture','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','5131','','.w-delivery-location-top-location-list'),(903122,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li','width_measure','%','','','.w-delivery-location-featured-list'),(903123,'furniture','.w-delivery-location-featured-list .deliveryList > ul > li','width_measure','%','5161','','.w-delivery-location-featured-list'),(903124,'furniture','.w-sale-category .holder-1','width_measure','%','','','.w-sale-category'),(903125,'furniture','.w-sale-category .holder-2','width_measure','%','','','.w-sale-category'),(903126,'furniture','.w-sale-category .image','width_measure','%','','','.w-sale-category'),(903127,'furniture','.w-sale-category .left-count','width_measure','%','','','.w-sale-category'),(903128,'furniture','.w-sale-category .left-text-left','width_measure','%','','','.w-sale-category'),(903129,'furniture','.w-sale-category .left-text-right','width_measure','%','','','.w-sale-category'),(903130,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width_measure','%','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(903131,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width_measure','%','5131','','.w-catalog-pages-category-pages-last-list-by-catalog'),(903132,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width_measure','%','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(903133,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width_measure','%','5131','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(903134,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width_measure','%','5140','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(903135,'furniture','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width_measure','%','5140','','.w-catalog-pages-category-pages-last-list-by-catalog'),(903136,'furniture','.w-delivery-location-list-by-page .item','width_measure','%','','','.w-delivery-location-list-by-page'),(903137,'furniture','.w-delivery-location-list-by-page .item','width_measure','%','5140','','.w-delivery-location-list-by-page'),(903138,'furniture','.w-delivery-location-list-by-page .item','width_measure','%','5161','','.w-delivery-location-list-by-page'),(903139,'furniture','.w-product-properties-icons .hover-box-content','width_measure','%','','','.w-product-properties-icons'),(903140,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','width_measure','%','5161','','.w-product-properties-icons'),(903141,'furniture','.w-delivery-location-cross-pages .item','width_measure','%','','','.w-delivery-location-cross-pages'),(903142,'furniture','.w-delivery-location-cross-pages .item','width_measure','%','5140','','.w-delivery-location-cross-pages'),(903143,'furniture','.w-delivery-location-cross-pages .item','width_measure','%','5161','','.w-delivery-location-cross-pages'),(903144,'furniture','.w-delivery-location-product-categories .item.category-link','width_measure','%','','','.w-delivery-location-product-categories'),(903145,'furniture','.w-delivery-location-product-categories .item.category-link','width_measure','%','5140','','.w-delivery-location-product-categories'),(903146,'furniture','.w-delivery-location-product-categories .item.category-link','width_measure','%','5161','','.w-delivery-location-product-categories'),(903147,'furniture','.w-delivery-location-product-categories .item.category-link','width_measure','%','5131','','.w-delivery-location-product-categories'),(903148,'furniture','.w-catalog-delivery-locations .item','width_measure','%','','','.w-catalog-delivery-locations'),(903149,'furniture','.w-catalog-delivery-locations .item','width_measure','%','5131','','.w-catalog-delivery-locations'),(903150,'furniture','.w-product-bonus-points .bonus-points-cost','width_measure','%','','','.w-product-bonus-points'),(903151,'furniture','.w-product-designer-designer .prodDesignerType','width_measure','%','','','.w-product-designer-designer'),(903152,'furniture','.w-product-designer-designer .productDesignerBox input','width_measure','%','','','.w-product-designer-designer'),(903153,'furniture','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','width_measure','%','','','.w-press-reviews-widgets-press-reviews-small'),(903154,'furniture','.w-press-reviews-widgets-press-reviews-small .small-press-review','width_measure','%','','','.w-press-reviews-widgets-press-reviews-small'),(903155,'furniture','.w-support-system-listing .product_icon','width_measure','%','','','.w-support-system-listing'),(903156,'furniture','.w-rma-returns-history input[type=\'text\'], .w-rma-returns-history input[type=\'password\'], .w-rma-returns-history input[type=\'number\'], .w-rma-returns-history input[type=\'email\'], .w-rma-returns-history input[type=\'search\'], .w-rma-returns-history select','width_measure','%','','','.w-rma-returns-history'),(903157,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(903158,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(903159,'furniture','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(903160,'furniture','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(903161,'furniture','.w-product-configurator .item-content','width_measure','%','5140','','.w-product-configurator'),(903162,'furniture','.w-product-configurator .pc_item','width_measure','%','5140','','.w-product-configurator'),(903163,'furniture','.b-products-listing .products-listing .bonus-points-cost','width_measure','%','','','.b-products-listing'),(903164,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width_measure','%','','','.w-catalog-pages-category-pages-list'),(903165,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width_measure','%','5140','','.w-catalog-pages-category-pages-list'),(903166,'furniture','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width_measure','%','5131','','.w-catalog-pages-category-pages-list'),(903167,'furniture','.w-predefined-promotion .nextdiscount .item-holder .image','width_measure','%','','','.w-predefined-promotion'),(903168,'furniture','.w-predefined-promotion .nextdiscount .item-holder .name','width_measure','%','','','.w-predefined-promotion'),(903169,'furniture','.w-predefined-promotion .prom-multi-discount .list','width_measure','%','','','.w-predefined-promotion'),(903170,'furniture','.w-predefined-promotion .promo-cart-discount > div','width_measure','%','','','.w-predefined-promotion'),(903171,'furniture','.w-predefined-promotion .promo-salemaker .item','width_measure','%','','','.w-predefined-promotion'),(903172,'furniture','.w-predefined-promotion .promo-salemaker > div','width_measure','%','','','.w-predefined-promotion'),(903173,'furniture','.w-filters .fsl_handle > div','width_measure','%','','','.w-filters'),(903174,'furniture','.mainBanner .bottomBox .elf','width_measure','%','','','.mainBanner'),(903175,'furniture','.mainBanner .title','width_measure','vw','3','','.mainBanner'),(903176,'furniture','.mainBanner .title','width_measure','%','','','.mainBanner'),(903177,'furniture','.mainBanner .title','width_measure','vw','5131,3','','.mainBanner'),(903178,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','width_measure','%','','','.mainBanner'),(903179,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','width_measure','%','5131','','.mainBanner'),(903180,'furniture','.mainBanner .w-banner .text-middle-right .banner-text, .mainBanner .w-banner .text-top-right .banner-text, .mainBanner .w-banner .text-bottom-right .banner-text','width_measure','%','5161','','.mainBanner'),(903181,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','width_measure','%','','','.mainBanner'),(903182,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','width_measure','%','','','.mainBanner'),(903183,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','width_measure','%','5131','','.mainBanner'),(903184,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','width_measure','%','5131','','.mainBanner'),(903185,'furniture','.mainBanner .w-banner .text-middle-left .banner-text, .mainBanner .w-banner .text-top-left .banner-text, .mainBanner .w-banner .text-bottom-left .banner-text','width_measure','%','5161','','.mainBanner'),(903186,'furniture','.mainBanner .w-banner .text-middle-center .banner-text, .mainBanner .w-banner .text-top-center .banner-text, .mainBanner .w-banner .text-bottom-center .banner-text','width_measure','%','5161','','.mainBanner'),(903187,'furniture','.w-promotions-widgets-promotion-icons-desc .promo-icon','width_measure','%','','','.w-promotions-widgets-promotion-icons-desc'),(903188,'furniture','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','width_measure','%','','','.w-promotions-widgets-promotion-icons-desc'),(903189,'furniture','.w-product-quantity-discounts .count','width_measure','%','','','.w-product-quantity-discounts'),(903202,'furniture','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','width_measure','%','','','.account-address-book'),(903203,'furniture','.account-address-book .address_book_row .column','width_measure','%','5131','','.account-address-book'),(903204,'furniture','.account-address-book .address_book_row .column + .column','width_measure','%','5131','','.account-address-book'),(903205,'furniture','.account-address-book .topInfo > div','width_measure','%','5131','','.account-address-book'),(903206,'furniture','.account-address-book .topInfo > div + div','width_measure','%','5131','','.account-address-book'),(903210,'furniture','.account-order-pay .history_info > div','width_measure','%','','','.account-order-pay'),(903211,'furniture','.account-order-pay .history_info > div','width_measure','%','5140','','.account-order-pay'),(903212,'furniture','.account-samples .orders-table .td-alignright','width_measure','%','5140','','.account-samples'),(903213,'furniture','.account-sample-info .history_info > div','width_measure','%','','','.account-sample-info'),(903214,'furniture','.account-sample-info .history_info > div','width_measure','%','5140','','.account-sample-info'),(903215,'furniture','.checkout-index-wrap .dob-hide > div','width_measure','%','','','.checkout-index-wrap'),(903216,'furniture','.checkout-index-wrap .edit-address-popup .addresses .address-item','width_measure','%','','','.checkout-index-wrap'),(903217,'furniture','.checkout-index-wrap .edit-address-popup .addresses .buttons','width_measure','%','','','.checkout-index-wrap'),(903218,'furniture','.checkout-index-wrap .order-summary .heading-2','width_measure','%','3','','.checkout-index-wrap'),(903219,'furniture','.checkout-index-wrap .order-summary .heading-2','width_measure','%','4','','.checkout-index-wrap'),(903220,'furniture','.checkout-index-wrap .order-summary2 .btn-2','width_measure','%','','','.checkout-index-wrap'),(903221,'furniture','.checkout-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.checkout-order-confirmation'),(903222,'furniture','.checkout-login-wrap .col-left, .checkout-login-wrap .col-right','width_measure','%','','','.checkout-login-wrap'),(903223,'furniture','.checkout-login-wrap .middle-form .btn-2','width_measure','%','','','.checkout-login-wrap'),(903224,'furniture','.b-form .center-buttons','width_measure','%','','','.b-form'),(903225,'furniture','.b-form .col-gender','width_measure','%','','','.b-form'),(903226,'furniture','.b-form .password-row','width_measure','%','','','.b-form'),(903227,'furniture','.mainBanner .w-banner .banner-text-holder .content','width_measure','%','','','.mainBanner'),(903228,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-2 a, .menu-header .menu-style[data-style=\"1\"] .level-2 .no-link','width_measure','%','','','.menu-header'),(903229,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-1 > li:nth-child(1) > ul > li, .footer-menu .menu-style[data-style=\"3\"] .level-1 > li:nth-child(2) > ul > li','width_measure','%','','','.footer-menu'),(903230,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li','width_measure','%','','','.footer-menu'),(903231,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li','width_measure','%','5145','','.footer-menu'),(903232,'furniture','.lowestPricedBox .w-banner .banner-item','width_measure','%','','','.lowestPricedBox'),(903233,'furniture','.lowestPricedBox .w-banner .banner-text-holder','width_measure','%','','','.lowestPricedBox'),(903234,'furniture','.lowestPricedBox .w-banner .banner-text-holder','width_measure','%','5140','','.lowestPricedBox'),(903235,'furniture','.lowestPricedBox .w-banner .ybg .btn','width_measure','%','','','.lowestPricedBox'),(903236,'furniture','.tripleBanner > .block','width_measure','%','5140','','.tripleBanner'),(903237,'furniture','.shopByCollectionBox .w-banner .banner-item','width_measure','%','','','.shopByCollectionBox'),(903238,'furniture','.shopByCollectionBox .w-banner .banner-item','width_measure','%','5161','','.shopByCollectionBox'),(903241,'furniture','.w-account-customer-additional-field .field-type-checkbox label','width_measure','%','','','.w-account-customer-additional-field'),(903242,'furniture','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width_measure','%','','','.w-account-customer-additional-field'),(903243,'furniture','.w-account-customer-additional-field .field-type-text label','width_measure','%','','','.w-account-customer-additional-field'),(903244,'furniture','.w-banner .banner-text-holder','width_measure','%','','','.w-banner'),(903245,'furniture','.w-banner .carousel-text','width_measure','%','','','.w-banner'),(903246,'furniture','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width_measure','%','','','.w-banner'),(903247,'furniture','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width_measure','%','','','.w-banner'),(903248,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_measure_important','important','','','.b-menu-open_from-left'),(903249,'furniture','.w-cart-discount-coupon input[type=\"text\"]','width_measure_important','important','','','.w-cart-discount-coupon'),(903250,'furniture','.footer-menu .menu-style[data-style=\"3\"] .level-2 > li','width_measure_important','important','5145','','.footer-menu'),(903251,'furniture','.tripleBanner > .block','width_measure_important','important','5140','','.tripleBanner'),(903252,'furniture','.b-form .same-address','z-index','80','','','.b-form'),(903253,'furniture','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','z-index','-1','','','.b-switch'),(903254,'furniture','.b-fancybox .filter-listing-loader','z-index','100000','','','.b-fancybox'),(903255,'furniture','.b-fancybox .filter-listing-preloader','z-index','100001','','','.b-fancybox'),(903256,'furniture','.w-promotions .prom-multi-discount .promo-range','z-index','1','','','.w-promotions'),(903257,'furniture','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(903260,'furniture','.p-sample-checkout-success .page-success > div','z-index','1','','','.p-sample-checkout-success'),(903261,'furniture','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(903262,'furniture','.b-preloader .preloader','z-index','10','','','.b-preloader'),(903263,'furniture','.b-messages .messMenuButton span','z-index','1','','','.b-messages'),(903264,'furniture','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(903265,'furniture','.b-fancybox #fancybox-loading','z-index','8060','','','.b-fancybox'),(903266,'furniture','.b-fancybox .fancybox-wrap','z-index','8020','','','.b-fancybox'),(903267,'furniture','.w-upload-customer-id-upload-customer-id-form .upload-file','z-index','10','','','.w-upload-customer-id-upload-customer-id-form'),(903268,'furniture','.w-menu-horizontal > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-horizontal'),(903269,'furniture','.w-menu-horizontal > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-horizontal'),(903270,'furniture','.w-menu-horizontal > ul > li > ul > li > ul','z-index','23','','','.w-menu-horizontal'),(903271,'furniture','.w-quote .cart-box-link','z-index','1','','','.w-quote'),(903272,'furniture','.b-switch .bootstrap-switch','z-index','0','','','.b-switch'),(903274,'furniture','.b-info-popup .info-popup div','z-index','1000','','','.b-info-popup'),(903275,'furniture','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(903276,'furniture','.edit-link','z-index','1','','',''),(903277,'furniture','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(903278,'furniture','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(903279,'furniture','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','z-index','0','','','.b-switch'),(903280,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-label','z-index','100','','','.b-switch'),(903281,'furniture','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(903282,'furniture','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(903283,'furniture','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(903284,'furniture','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(903285,'furniture','.b-fancybox .fancybox-overlay','z-index','8010','','','.b-fancybox'),(903286,'furniture','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(903287,'furniture','.w-menu-horizontal > ul','z-index','21','','','.w-menu-horizontal'),(903288,'furniture','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','z-index','1','','','.b-switch'),(903291,'furniture','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(903292,'furniture','.w-promotions .promo-cart-discount .slave .condition','z-index','1','','','.w-promotions'),(903293,'furniture','.w-menu-horizontal > ul > li > ul','z-index','22','','','.w-menu-horizontal'),(903296,'furniture','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(903297,'furniture','.b-fancybox .fancybox-close','z-index','8040','','','.b-fancybox'),(903298,'furniture','.b-fancybox .fancybox-opened','z-index','8030','','','.b-fancybox'),(903299,'furniture','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(903300,'furniture','.b-datepicker .datepicker-dropdown','z-index','1000','','','.b-datepicker'),(903301,'furniture','.w-quote .cart-box','z-index','100','','','.w-quote'),(903302,'furniture','.p-sample-checkout-success .page-success','z-index','-1','','','.p-sample-checkout-success'),(903303,'furniture','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','z-index','1','','','.b-switch'),(903304,'furniture','.b-select-suggest .select2-search','z-index','10000','','','.b-select-suggest'),(903305,'furniture','.b-select-suggest .select2-drop-mask','z-index','9998','','','.b-select-suggest'),(903306,'furniture','.b-select-suggest .select2-drop','z-index','9999','','','.b-select-suggest'),(903309,'furniture','.w-menu-big li','z-index','20','','','.w-menu-big'),(903310,'furniture','.b-bottom .pop-up-close','z-index','1','','','.b-bottom'),(903311,'furniture','.w-catalog-b2b-add-button ','z-index','1','','','.w-catalog-b2b-add-button'),(903312,'furniture','.b-products-listing .promos-info','z-index','1','','','.b-products-listing'),(903313,'furniture','.b-autocomplete .ui-autocomplete','z-index','1000','','','.b-autocomplete'),(903315,'furniture','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(903316,'furniture','.b-form .form-inputs div.required-message','z-index','1','','','.b-form'),(903317,'furniture','.b-fancybox .fancybox-title','z-index','8050','','','.b-fancybox'),(903318,'furniture','.b-fancybox .fancybox-title-float-wrap','z-index','8050','','','.b-fancybox'),(903319,'furniture','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(903320,'furniture','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(903321,'furniture','.b-form .eye-password-wrap','z-index','1','','','.b-form'),(903322,'furniture','.b-form .eye-password','z-index','1','','','.b-form'),(903323,'furniture','.b-form .hide-billing-address','z-index','70','','','.b-form'),(903324,'furniture','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(903327,'furniture','.b-fancybox .fancybox-nav span','z-index','8040','','','.b-fancybox'),(903328,'furniture','.b-fancybox .fancybox-nav','z-index','8040','','','.b-fancybox'),(903330,'furniture','.w-menu-big > ul > li > ul','z-index','100','','','.w-menu-big'),(903331,'furniture','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','z-index','1000','','','.w-image-maps'),(903332,'furniture','.b-product-images .media-popup .mp-close','z-index','1','','','.b-product-images'),(903333,'furniture','.b-product-images .mp-shadow, .b-product-images .media-popup','z-index','1000','','','.b-product-images'),(903334,'furniture','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(903335,'furniture','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(903336,'furniture','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(903337,'furniture','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(903338,'furniture','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(903339,'furniture','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(903340,'furniture','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(903341,'furniture','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(903342,'furniture','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(903343,'furniture','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(903344,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(903345,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(903346,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(903347,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(903348,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(903349,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(903350,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(903351,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(903352,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(903353,'furniture','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(903354,'furniture','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','z-index','1000','','','.b-menu-open_from-left'),(903355,'furniture','.b-slick button.slick-prev, .b-slick button.slick-next','z-index','1','','','.b-slick'),(903356,'furniture','.header','z-index','100','5140','',''),(903357,'furniture','.cartTitle span','z-index','1','','','.cartTitle'),(903358,'furniture','.b-products-listing .products-listing.list-productlisting .item-nav','z-index','9','','','.b-products-listing'),(903359,'furniture','.w-compare ','z-index','100','','','.w-compare'),(903360,'furniture','.w-sample .cart-box','z-index','100','','','.w-sample'),(903361,'furniture','.w-sample .cart-box-link','z-index','1','','','.w-sample'),(903362,'furniture','.w-account-personal-catalog .list-row-action ul','z-index','1','','','.w-account-personal-catalog'),(903363,'furniture','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','z-index','1','','','.w-account-personal-catalog'),(903364,'furniture','.w-product-properties-icons .hover-box:hover .hover-box-content','z-index','9','','','.w-product-properties-icons'),(903365,'furniture','.w-product-designer-designer .productDesignerBox input','z-index','1','','','.w-product-designer-designer'),(903366,'furniture','.w-predefined-promotion .prom-multi-discount .promo-range','z-index','1','','','.w-predefined-promotion'),(903367,'furniture','.w-predefined-promotion .promo-cart-discount .slave .condition','z-index','1','','','.w-predefined-promotion'),(903372,'furniture','.checkout-success-wrap .page-success','z-index','-1','','','.checkout-success-wrap'),(903373,'furniture','.checkout-success-wrap .page-success > div','z-index','1','','','.checkout-success-wrap'),(903374,'furniture','.success-page .page-success > div','z-index','1','','','.success-page'),(903375,'furniture','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-1 > li','z-index','2','','','.b-menu-lev_display-down'),(903377,'furniture','.w-banner .banner img + img','z-index','-1','','','.w-banner'),(903378,'furniture','.w-banner .banner-text','z-index','1','','','.w-banner'),(903380,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > li:hover > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > li:hover > .no-link','background-color','$header-menu-bg-5','','','.menu-header'),(903381,'furniture','.menu-header .menu-style[data-style=\"1\"] .level-1 > li:hover > a, .menu-header .menu-style[data-style=\"1\"] .level-1 > li:hover > .no-link','text-decoration','none','','','.menu-header'),(903382,'furniture','.warrantyProduct .warranty, .warrantyProduct .delivery','border-bottom-color','$content-border-1','','','.warrantyProduct'),(903383,'furniture','.tripleBanner .returns.w-html_box','background-image','url(themes/furniture/img/returns.webp)','3','','.tripleBanner'),(903384,'watch','.b-slick .slick-slider','-khtml-user-select','none','','','.b-slick'),(903385,'watch','.b-fancybox .fancybox-skin','-moz-border-radius','4px','','','.b-fancybox'),(903386,'watch','.b-fancybox .fancybox-title-float-wrap .child','-moz-border-radius','15px','','','.b-fancybox'),(903387,'watch','.b-fancybox .fancybox-opened .fancybox-skin','-moz-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(903388,'watch','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-moz-box-sizing','border-box','','','.b-select-suggest'),(903389,'watch','.b-rating .glyphicon','-moz-osx-font-smoothing','grayscale','','','.b-rating'),(903390,'watch','.b-products-listing .hover-box-content','-moz-transform','rotate( 45deg )','3','','.b-products-listing'),(903391,'watch','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-moz-transform','translate3d(0, 0, 0)','','','.b-slick'),(903392,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-moz-user-select','none','','','.b-select-suggest'),(903393,'watch','.b-select-suggest .select2-container .select2-choice','-moz-user-select','none','','','.b-select-suggest'),(903394,'watch','.b-select-suggest .select2-results .select2-result-label','-moz-user-select','none','','','.b-select-suggest'),(903395,'watch','.b-slick .slick-slider','-moz-user-select','none','','','.b-slick'),(903396,'watch','.b-slick .slick-slider','-ms-touch-action','pan-y','','','.b-slick'),(903397,'watch','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(903398,'watch','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(903399,'watch','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(903400,'watch','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(903401,'watch','.b-products-listing .hover-box-content','-ms-transform','rotate( 45deg )','3','','.b-products-listing'),(903402,'watch','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-ms-transform','translate3d(0, 0, 0)','','','.b-slick'),(903403,'watch','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(903404,'watch','.b-select-suggest .select2-container .select2-choice','-ms-user-select','none','','','.b-select-suggest'),(903405,'watch','.b-select-suggest .select2-results .select2-result-label','-ms-user-select','none','','','.b-select-suggest'),(903406,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-ms-user-select','none','','','.b-select-suggest'),(903407,'watch','.b-slick .slick-slider','-ms-user-select','none','','','.b-slick'),(903408,'watch','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-o-transform','translate3d(0, 0, 0)','','','.b-slick'),(903409,'watch','.b-fancybox .fancybox-title-float-wrap .child','-webkit-border-radius','15px','','','.b-fancybox'),(903410,'watch','.b-fancybox .fancybox-skin','-webkit-border-radius','4px','','','.b-fancybox'),(903411,'watch','.b-fancybox .fancybox-opened .fancybox-skin','-webkit-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(903412,'watch','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-webkit-box-sizing','border-box','','','.b-select-suggest'),(903413,'watch','.b-rating .glyphicon','-webkit-font-smoothing','antialiased','','','.b-rating'),(903414,'watch','.b-fancybox .fancybox-type-iframe .fancybox-inner','-webkit-overflow-scrolling','touch','','','.b-fancybox'),(903415,'watch','.b-fancybox .fancybox-nav','-webkit-tap-highlight-color','rgba(0,0,0,0)','','','.b-fancybox'),(903416,'watch','.b-select-suggest .select2-results','-webkit-tap-highlight-color','rgba(0, 0, 0, 0)','','','.b-select-suggest'),(903417,'watch','.b-slick .slick-slider','-webkit-tap-highlight-color','transparent','','','.b-slick'),(903418,'watch','.b-select-suggest .select2-container .select2-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(903419,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(903420,'watch','.b-select-suggest .select2-results .select2-result-label','-webkit-touch-callout','none','','','.b-select-suggest'),(903421,'watch','.b-slick .slick-slider','-webkit-touch-callout','none','','','.b-slick'),(903422,'watch','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(903423,'watch','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(903424,'watch','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(903425,'watch','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(903426,'watch','.b-products-listing .hover-box-content','-webkit-transform','rotate( 45deg )','3','','.b-products-listing'),(903427,'watch','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-webkit-transform','translate3d(0, 0, 0)','','','.b-slick'),(903428,'watch','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(903429,'watch','.b-select-suggest .select2-container .select2-choice','-webkit-user-select','none','','','.b-select-suggest'),(903430,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-user-select','none','','','.b-select-suggest'),(903431,'watch','.b-select-suggest .select2-results .select2-result-label','-webkit-user-select','none','','','.b-select-suggest'),(903432,'watch','.b-slick .slick-slider','-webkit-user-select','none','','','.b-slick'),(903433,'watch','.w-promotions .promo-cart-discount','align-items','flex-start','','','.w-promotions'),(903434,'watch','.b-messages .email-line','align-items','center','','','.b-messages'),(903435,'watch','.p-quick-order-index .quick-order-total','align-items','center','','','.p-quick-order-index'),(903436,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(903437,'watch','.b-products-listing .select-attributes','align-items','center','','','.b-products-listing'),(903438,'watch','.order-summary .price-row','align-items','baseline','','','.order-summary'),(903439,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(903440,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(903441,'watch','.w-personal-gift-status-bar .timeline','align-items','center','','','.w-personal-gift-status-bar'),(903442,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(903443,'watch','.b-products-listing .products-listing .attribute-qty-block','align-items','center','','','.b-products-listing'),(903444,'watch','.b-products-listing .promos-info .promo-item','align-items','center','','','.b-products-listing'),(903445,'watch','.w-taxable form','align-items','center','','','.w-taxable'),(903446,'watch','.w-cart-listing .item .gift-wrap label','align-items','center','','','.w-cart-listing'),(903447,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(903448,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(903449,'watch','.b-product-images .media-popup .mp-big-images .item','align-items','center','','','.b-product-images'),(903450,'watch','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(903451,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','align-items','center','','','.b-menu-style-1'),(903452,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .languages','align-items','center','','','.b-menu-style-2'),(903453,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','align-items','center','','','.b-menu-style-2'),(903454,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies','align-items','center','','','.b-menu-style-2'),(903455,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','align-items','center','','','.b-menu-style-2'),(903456,'watch','.w-account-subscription .subscription-variant','align-items','center','','','.w-account-subscription'),(903457,'watch','.w-catalog-compare .cross-box .different-all','align-items','flex-end','','','.w-catalog-compare'),(903458,'watch','.w-product-images .img-holder','align-items','center','','','.w-product-images'),(903462,'watch','.checkout-order-confirmation .price-row','align-items','baseline','','','.checkout-order-confirmation'),(903463,'watch','.hide-page','align-items','center','','',''),(903464,'watch','.success-page .order_totals .price-row','align-items','baseline','','','.success-page'),(903465,'watch','.success-page .price-row','align-items','baseline','','','.success-page'),(903466,'watch','.w-checkout-totals .price-row','align-items','center','','','.w-checkout-totals'),(903467,'watch','.w-account-customer-additional-field .field-type-text','align-items','center','','','.w-account-customer-additional-field'),(903468,'watch','.w-banner .banner-item.text-bottom-center .banner-text','align-items','end','','','.w-banner'),(903469,'watch','.w-banner .banner-item.text-bottom-left .banner-text','align-items','end','','','.w-banner'),(903470,'watch','.w-banner .banner-item.text-bottom-right .banner-text','align-items','end','','','.w-banner'),(903471,'watch','.w-banner .banner-item.text-middle-center .banner-text','align-items','center','','','.w-banner'),(903472,'watch','.w-banner .banner-item.text-middle-left .banner-text','align-items','center','','','.w-banner'),(903473,'watch','.w-banner .banner-item.text-middle-right .banner-text','align-items','center','','','.w-banner'),(903474,'watch','.w-banner .banner-item.text-top-center .banner-text','align-items','start','','','.w-banner'),(903475,'watch','.w-banner .banner-item.text-top-left .banner-text','align-items','start','','','.w-banner'),(903476,'watch','.w-banner .banner-item.text-top-right .banner-text','align-items','start','','','.w-banner'),(903477,'watch','.w-banner .carousel .bottom-center','align-items','flex-end','','','.w-banner'),(903478,'watch','.w-banner .carousel .bottom-left','align-items','flex-end','','','.w-banner'),(903479,'watch','.w-banner .carousel .bottom-right','align-items','flex-end','','','.w-banner'),(903480,'watch','.w-banner .carousel .middle-center','align-items','center','','','.w-banner'),(903481,'watch','.w-banner .carousel .middle-left','align-items','center','','','.w-banner'),(903482,'watch','.w-banner .carousel .middle-right','align-items','center','','','.w-banner'),(903483,'watch','.w-banner .carousel .top-center','align-items','flex-start','','','.w-banner'),(903484,'watch','.w-banner .carousel .top-left','align-items','flex-start','','','.w-banner'),(903485,'watch','.w-banner .carousel .top-right','align-items','flex-start','','','.w-banner'),(903486,'watch','.w-cart-listing .remove','align-self','center','','','.w-cart-listing'),(903487,'watch','.b-preloader .preloader','animation','load8 1.5s infinite linear','3','','.b-preloader'),(903488,'watch','.w-product-customers-activity .customers-activity','animation','customers-activity-show 4s ease-in-out','','','.w-product-customers-activity'),(903489,'watch','.w-product-customers-activity .customers-activity.closed','animation','customers-activity-hide 2s ease-in-out','','','.w-product-customers-activity'),(903490,'watch','.b-products-listing .btn-preloader','animation','load8 1.5s infinite linear','3','','.b-products-listing'),(903491,'watch','.b-products-listing .loader','animation','load8 1.5s infinite linear','4','','.b-products-listing'),(903492,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.p-quick-order-index'),(903493,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(903494,'watch','.b-fancybox .fancybox-title-float-wrap .child','background','transparent','','','.b-fancybox'),(903495,'watch','.w-filters .ui-slider','background','none','','','.w-filters'),(903496,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','background','none','','','.b-select-suggest'),(903497,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.p-quick-order-index'),(903498,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(903499,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(903500,'watch','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','background','none','','','.b-products-listing'),(903501,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(903502,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background','transparent','','','.b-select-suggest'),(903503,'watch','.b-select-suggest .select2-results .select2-highlighted em','background','transparent','','','.b-select-suggest'),(903504,'watch','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','background','transparent','','','.b-select-suggest'),(903505,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(903506,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.b-data-table'),(903507,'watch','.b-products-listing .products-listing h2','background','none','','','.b-products-listing'),(903508,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(903509,'watch','.w-filters .ui-slider-range','background','none','','','.w-filters'),(903510,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.b-data-table'),(903511,'watch','.w-top-categories .categories h2','background','none','','','.w-top-categories'),(903512,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','background','none','','','.b-product-images'),(903513,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','background','none','','','.b-menu-style-2'),(903514,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','background','none','','','.b-menu-style-2'),(903515,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','background','none','','','.w-catalog-compare'),(903516,'watch','.b-select-suggest .select2-container .select2-choice','background-clip','padding-box','','','.b-select-suggest'),(903517,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','background-clip','padding-box','','','.b-select-suggest'),(903518,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow','background-clip','padding-box','','','.b-select-suggest'),(903519,'watch','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(903520,'watch','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(903522,'watch','.b-fancybox .filter-listing-loader','background-color','$fancybox-bg-1','','','.b-fancybox'),(903523,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','$content-bg-2','','','.p-quick-order-index'),(903524,'watch','.w-promotions .promo-item','background-color','$content-bg-2','','','.w-promotions'),(903527,'watch','.testimonials .review','background-color','$content-bg-2','','',''),(903528,'watch','.w-chat .w-chat-box','background-color','$highlight-box-bg-1','','','.w-chat'),(903529,'watch','.w-promotions .prom-multi-discount .promo-range','background-color','$content-bg-1','','','.w-promotions'),(903530,'watch','.w-promotions .prom-multi-discount .promo-product','background-color','$content-bg-1','','','.w-promotions'),(903531,'watch','.w-promotions .nextdiscount .promo-for-each','background-color','$content-bg-2','','','.w-promotions'),(903532,'watch','.w-promotions .nextdiscount .content > div','background-color','$content-bg-1','','','.w-promotions'),(903533,'watch','.w-promotions .promo-salemaker .item','background-color','$content-bg-1','','','.w-promotions'),(903534,'watch','.w-promotions .promo-salemaker .discount','background-color','$content-bg-1','','','.w-promotions'),(903535,'watch','.w-promotions .promo-cart-discount .slave .item','background-color','$content-bg-1','','','.w-promotions'),(903536,'watch','.w-promotions .promo-cart-discount .promo-min-qty','background-color','$content-bg-1','','','.w-promotions'),(903537,'watch','.b-preloader .preloader','background-color','$shadow-bg-2','','','.b-preloader'),(903538,'watch','.w-cart-compare .attributes-cell','background-color','$content-bg-2','','','.w-cart-compare'),(903539,'watch','.w-cart-checkout-btn + .w-image','background-color','$content-bg-2','','','.w-cart-checkout-btn'),(903540,'watch','.b-messages .msv_history','background-color','$content-bg-2','','','.b-messages'),(903541,'watch','.b-messages .email-heading','background-color','$content-bg-2','','','.b-messages'),(903542,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','background-color','$content-bg-2','','','.b-messages'),(903543,'watch','.w-reviews .author','background-color','$content-bg-1','','','.w-reviews'),(903544,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','$transparent','1','','.p-quick-order-index'),(903545,'watch','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','background-color','$content-bg-2','','','.order-summary'),(903546,'watch','.b-fancybox .fancybox-close','background-color','$fancybox-bg-1','','','.b-fancybox'),(903547,'watch','.b-messages .msv_to_cc','background-color','$content-bg-2','','','.b-messages'),(903548,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','background-color','$transparent','3','','.b-switch'),(903549,'watch','.w-checkout-shipping-choice input:checked + span:before','background-color','$highlight-box-bg-1','','','.w-checkout-shipping-choice'),(903550,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','background-color','$content-bg-2','','','.w-upload-customer-id-upload-customer-id-form'),(903551,'watch','.w-upload-customer-id-upload-customer-id-form .dz-details','background-color','$content-bg-1','','','.w-upload-customer-id-upload-customer-id-form'),(903552,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','background-color','$switch-nc-bg-1','3','','.b-switch'),(903553,'watch','.w-menu-horizontal > ul > li > ul > li > ul','background-color','$content-bg-1','','','.w-menu-horizontal'),(903554,'watch','.w-quote .cart-box','background-color','$content-bg-1','','','.w-quote'),(903555,'watch','.b-fancybox .fancybox-title-float-wrap .child','background-color','$fancybox-bg-1','','','.b-fancybox'),(903556,'watch','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(903557,'watch','.b-info-popup .info-popup div','background-color','$content-bg-1','','','.b-info-popup'),(903558,'watch','.w-filters .ui-slider','background-color','$content-bg-2','','','.w-filters'),(903559,'watch','.b-switch .candlestick-wrapper .candlestick-bg','background-color','$switch-nc-bg-1','','','.b-switch'),(903560,'watch','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(903561,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-color','$content-bg-2','','','.b-select-suggest'),(903562,'watch','.w-reviews .review','background-color','$content-bg-1','','','.w-reviews'),(903564,'watch','.p-quick-order-index .all-scroll-div','background-color','$highlight-box-bg-1','','','.p-quick-order-index'),(903565,'watch','.btn-1','background-color','$btn-bg-2','','',''),(903566,'watch','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(903567,'watch','.order-summary > div','background-color','$content-bg-1','','','.order-summary'),(903568,'watch','.b-fancybox .fancybox-overlay','background-color','$fancybox-bg-1','','','.b-fancybox'),(903569,'watch','.b-bottom .popup-box.popupCompare','background-color','$content-bg-2','','','.b-bottom'),(903571,'watch','.w-checkout-billing-address .same-address','background-color','$content-bg-2','','','.w-checkout-billing-address'),(903572,'watch','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(903573,'watch','.btn-2','background-color','$btn-bg-3','','',''),(903574,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','background-color','$switch-off-bg-2','','','.b-switch'),(903575,'watch','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(903576,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','background-color','$transparent','4','','.b-switch'),(903577,'watch','.b-form .required-message','background-color','$content-bg-2','','','.b-form'),(903578,'watch','.b-switch .candlestick-wrapper .candlestick-bg.off','background-color','$switch-off-bg-2','','','.b-switch'),(903579,'watch','.b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-off','background-color','$switch-off-bg-2','3','','.b-switch'),(903580,'watch','.b-switch .candlestick-wrapper .candlestick-bg.on','background-color','$switch-on-bg-1','','','.b-switch'),(903581,'watch','.b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-on','background-color','$switch-off-bg-2','4','','.b-switch'),(903582,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','background-color','$switch-handle-bg-3','','','.b-switch'),(903583,'watch','.b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-on','background-color','$switch-on-bg-1','4','','.b-switch'),(903584,'watch','.b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-off','background-color','$switch-on-bg-1','3','','.b-switch'),(903585,'watch','.w-product-reviews .reviews-list .review','background-color','$content-bg-2','','','.w-product-reviews'),(903586,'watch','.b-fancybox .fancybox-skin','background-color','$fancybox-bg-1','','','.b-fancybox'),(903587,'watch','.b-info-popup .info-popup div','background-color','$content-bg-1','3','','.b-info-popup'),(903588,'watch','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(903589,'watch','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(903590,'watch','.btn','background-color','$btn-bg-1','','',''),(903591,'watch','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(903592,'watch','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(903593,'watch','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','background-color','$content-bg-2','','','.b-select-suggest'),(903594,'watch','.w-personal-gift-status-bar .timeline','background-color','$content-bg-2','','','.w-personal-gift-status-bar'),(903595,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','background-color','$switch-off-bg-2','','','.b-switch'),(903596,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label','background-color','$switch-handle-bg-3','3','','.b-switch'),(903597,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','background-color','$switch-nc-bg-1','4','','.b-switch'),(903598,'watch','.b-form .hide-billing-address','background-color','$content-bg-1','','','.b-form'),(903599,'watch','.w-reviews-content .author','background-color','$content-bg-2','','','.w-reviews-content'),(903600,'watch','.w-personal-gift-status-bar .progress-bar-content','background-color','$highlight-box-bg-1','','','.w-personal-gift-status-bar'),(903601,'watch','.w-cart-compare .price-cell','background-color','$content-bg-2','','','.w-cart-compare'),(903602,'watch','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(903603,'watch','.b-compare .popupCompare .pop-up-content','background-color','$content-bg-2','','','.b-compare'),(903604,'watch','.w-promotions .promo-cart-discount .master .item','background-color','$content-bg-1','','','.w-promotions'),(903605,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','background-color','$content-bg-1','','','.w-promotions'),(903606,'watch','.b-bottom .around-pop-up','background-color','$shadow-bg-1','','','.b-bottom'),(903607,'watch','.w-cart-compare .price-block + .attributes-block .attributes-cell','background-color','$content-bg-1','','','.w-cart-compare'),(903608,'watch','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(903609,'watch','.b-bottom .pop-up-content','background-color','$content-bg-1','','','.b-bottom'),(903610,'watch','.b-bottom .popup-box','background-color','$content-bg-1','','','.b-bottom'),(903611,'watch','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(903612,'watch','.w-product-customers-activity .customers-activity','background-color','$content-bg-2','','','.w-product-customers-activity'),(903613,'watch','.w-checkout-shipping-choice input:checked + span','background-color','$highlight-box-bg-1','','','.w-checkout-shipping-choice'),(903614,'watch','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(903615,'watch','.b-autocomplete .ui-autocomplete li','background-color','$content-bg-2','1','','.b-autocomplete'),(903616,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label','background-color','$switch-handle-bg-3','3','','.b-switch'),(903617,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','background-color','$switch-on-bg-1','','','.b-switch'),(903618,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-color','$content-bg-2','','','.b-select-suggest'),(903619,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus','background-color','$content-bg-2','','','.b-select-suggest'),(903620,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color','$content-bg-1','','','.b-select-suggest'),(903621,'watch','.b-select-suggest .select2-container-multi .select2-choices','background-color','$content-bg-1','','','.b-select-suggest'),(903622,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-color','$content-bg-2','','','.b-select-suggest'),(903623,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-color','$content-bg-2','','','.b-select-suggest'),(903624,'watch','.b-select-suggest .select2-results .select2-highlighted ul','background-color','$content-bg-1','','','.b-select-suggest'),(903625,'watch','.b-select-suggest .select2-more-results','background-color','$content-bg-2','','','.b-select-suggest'),(903626,'watch','.b-select-suggest .select2-more-results.select2-active','background-color','$content-bg-2','','','.b-select-suggest'),(903627,'watch','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','background-color','$content-bg-2','','','.b-select-suggest'),(903628,'watch','.b-select-suggest .select2-results .select2-highlighted','background-color','$content-bg-2','','','.b-select-suggest'),(903629,'watch','.b-select-suggest .select2-results .select2-disabled','background-color','$content-bg-2','','','.b-select-suggest'),(903630,'watch','.b-select-suggest .select2-results li em','background-color','$content-bg-2','','','.b-select-suggest'),(903631,'watch','.w-menu-horizontal > ul > li > ul','background-color','$content-bg-1','','','.w-menu-horizontal'),(903632,'watch','.b-select-suggest .select2-search input','background-color','$content-bg-1','','','.b-select-suggest'),(903633,'watch','.b-select-suggest .select2-search input.select2-active','background-color','$content-bg-1','','','.b-select-suggest'),(903634,'watch','.b-select-suggest .select2-drop-mask','background-color','$content-bg-1','','','.b-select-suggest'),(903635,'watch','.b-select-suggest .select2-drop','background-color','$content-bg-1','','','.b-select-suggest'),(903636,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','$content-bg-2','','','.b-data-table'),(903637,'watch','.b-products-listing .loader','background-color','$shadow-bg-2','3','','.b-products-listing'),(903638,'watch','.w-catalog-b2b-add-button ','background-color','$highlight-box-bg-1','','','.w-catalog-b2b-add-button'),(903639,'watch','.b-products-listing .products-listing .qty-input.hidden','background-color','$content-bg-1','3','','.b-products-listing'),(903640,'watch','.b-products-listing .promos-info .promo-name','background-color','$content-bg-2','','','.b-products-listing'),(903641,'watch','.checkbox input:checked + span','background-color','$checkbox-bg-1','','',''),(903642,'watch','.checkbox input + span','background-color','$checkbox-bg-1','','',''),(903643,'watch','.b-autocomplete .ui-autocomplete','background-color','$content-bg-1','','','.b-autocomplete'),(903645,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','background-color','$switch-handle-bg-3','3','','.b-switch'),(903646,'watch','.b-compare .compare-box-item','background-color','$content-bg-2','','','.b-compare'),(903648,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','background-color','$content-bg-2','','','.w-communication-new-topic'),(903649,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','background-color','$content-bg-2','','','.w-communication-new-topic'),(903650,'watch','.b-datepicker .datepicker-dropdown','background-color','$content-bg-1','','','.b-datepicker'),(903651,'watch','.b-bottom .popup-heading','background-color','$content-bg-2','','','.b-bottom'),(903652,'watch','.w-personal-gift-status-bar .progress-bar','background-color','$content-bg-1','','','.w-personal-gift-status-bar'),(903653,'watch','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(903654,'watch','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(903655,'watch','.w-quote .cart-box-link','background-color','$highlight-box-bg-1','','','.w-quote'),(903656,'watch','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(903657,'watch','.b-compare .vary td','background-color','$content-bg-2','','','.b-compare'),(903661,'watch','.b-fancybox .fancybox-nav span','background-color','$fancybox-bg-1','','','.b-fancybox'),(903662,'watch','.w-tabs .tab-a','background-color','$tab-nav-bg-1','2','','.w-tabs'),(903663,'watch','.w-filters .head-filter-widget','background-color','$highlight-box-bg-1','5240','','.w-filters'),(903664,'watch','.w-filters .ui-slider-range','background-color','$highlight-box-bg-1','','','.w-filters'),(903665,'watch','body','background-color','$content-bg-1','','',''),(903666,'watch','.w-reviews-content .review','background-color','$content-bg-2','','','.w-reviews-content'),(903667,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','$transparent','1','','.b-data-table'),(903668,'watch','.b-compare .popupCompare table','background-color','$content-bg-1','','','.b-compare'),(903669,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','background-color','$content-bg-1','','','.w-image-maps'),(903670,'watch','.b-product-images .mp-shadow','background-color','$image-popup-bg-1','','','.b-product-images'),(903671,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','background-color','$content-bg-2','','','.b-menu-style-1'),(903672,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li:hover > a','background-color','$content-bg-2','','','.b-menu-style-1'),(903673,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2','background-color','$content-bg-2','','','.b-menu-style-1'),(903674,'watch','.b-trade-approval .steps-bar','background-color','$content-bg-2','','','.b-trade-approval'),(903675,'watch','.b-trade-approval .steps-bar li.current a','background-color','$highlight-box-bg-1','','','.b-trade-approval'),(903676,'watch','.w-account-personal-catalog .list-switcher a','background-color','$content-bg-1','2','','.w-account-personal-catalog'),(903677,'watch','.w-catalog-compare tr','background-color','$content-bg-2','1','','.w-catalog-compare'),(903678,'watch','.w-catalog-compare .compare .checkbox input:checked + span','background-color','$content-bg-1','','','.w-catalog-compare'),(903679,'watch','.w-catalog-compare .compare-fix-bar','background-color','$content-bg-1','','','.w-catalog-compare'),(903680,'watch','.w-catalog-compare .cross-box .different-all > div','background-color','$content-bg-1','2','','.w-catalog-compare'),(903681,'watch','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','background-color','$content-bg-1','','','.w-delivery-day'),(903682,'watch','.w-delivery-day .left-count','background-color','$highlight-box-bg-1','','','.w-delivery-day'),(903683,'watch','.w-cart-discount-coupon .discount-box','background-color','$content-bg-2','','','.w-cart-discount-coupon'),(903690,'watch','.catalog-product-wrap .prev-next-product','background-color','$shadow-bg-2','','','.catalog-product-wrap'),(903691,'watch','.checkout-index-wrap .checkout-cart-listing.main-listing','background-color','$content-bg-1','','','.checkout-index-wrap'),(903692,'watch','.account-samples .orders-table th','background-color','$content-bg-2','','','.account-samples'),(903693,'watch','.account-samples .order_history_table th','background-color','$content-bg-2','','','.account-samples'),(903694,'watch','.b-slick .slick-dots li','background-color','$content-bg-2','3','','.b-slick'),(903695,'watch','.b-slick .slick-dots li.slick-active','background-color','$highlight-box-bg-1','3','','.b-slick'),(903696,'watch','.hide-page','background-color','$shadow-bg-2','','',''),(903697,'watch','.success-page .w-cart-listing .qty','background-color','$highlight-box-bg-1','','','.success-page'),(903698,'watch','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','background-color','$highlight-box-bg-1','','','.b-multi-page-checkout'),(903699,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','background-color','$highlight-box-bg-3','3','','.b-multi-page-checkout'),(903702,'watch','.btn-3','background-color','$btn-bg-4','','',''),(903703,'watch','.w-menu-style-1 .menu-ico','background-color','$highlight-box-bg-1','','','.w-menu-style-1'),(903704,'watch','.w-menu-style-1 > ul','background-color','$highlight-box-bg-1','','','.w-menu-style-1'),(903705,'watch','.w-menu-style-1 > ul > li','background-color','$highlight-box-bg-1','1','','.w-menu-style-1'),(903706,'watch','.w-menu-style-1 > ul > li > ul','background-color','$highlight-box-bg-1','','','.w-menu-style-1'),(903707,'watch','.w-menu-style-1 > ul > li > ul > li','background-color','$highlight-box-bg-1','1','','.w-menu-style-1'),(903708,'watch','.w-menu-style-1 > ul > li > ul > li > ul li','background-color','$highlight-box-bg-1','1','','.w-menu-style-1'),(903709,'watch','.w-menu-style-1 > ul > li > ul > li ul','background-color','$highlight-box-bg-1','','','.w-menu-style-1'),(903710,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','background-color','$content-bg-1','','','.b-slick'),(903711,'watch','.w-catalog-paging ','background-color','#183D78','2','','.w-catalog-paging'),(903712,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.p-quick-order-index'),(903713,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color_important','important','','','.b-select-suggest'),(903714,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.b-data-table'),(903716,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-image','none','','','.b-select-suggest'),(903723,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-image','none','','','.b-select-suggest'),(903724,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-image','none','','','.b-select-suggest'),(903725,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-image','none','','','.b-select-suggest'),(903726,'watch','.b-select-suggest .select2-results li','background-image','none','','','.b-select-suggest'),(903731,'watch','.account-samples .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.account-samples'),(903733,'watch','.b-select-suggest .select2-search input','background-position','100% -21px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(903734,'watch','.b-select-suggest .select2-container .select2-choice abbr','background-position','right -11px','1','','.b-select-suggest'),(903735,'watch','.w-top-categories .image','background-position','50% 50%','','','.w-top-categories'),(903736,'watch','.b-select-suggest .select2-container .select2-choice abbr','background-position','top right','','','.b-select-suggest'),(903737,'watch','.w-categories .image','background-position','50% 50%','','','.w-categories'),(903738,'watch','.b-select-suggest .select2-search input','background-position','100% -22px','','','.b-select-suggest'),(903739,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close','background-position','right -11px','','','.b-select-suggest'),(903740,'watch','.b-select-suggest .select2-search-choice-close','background-position','top right','','','.b-select-suggest'),(903741,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close','background-position','right -11px','1','','.b-select-suggest'),(903742,'watch','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow b','background-position','-18px 1px','','','.b-select-suggest'),(903743,'watch','.b-select-suggest .select2-search input','background-position_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(903744,'watch','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(903745,'watch','.b-select-suggest .select2-container .select2-choice abbr','background-repeat','no-repeat','','','.b-select-suggest'),(903746,'watch','.b-select-suggest .select2-search-choice-close','background-repeat','no-repeat','','','.b-select-suggest'),(903747,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(903748,'watch','.b-select-suggest .select2-more-results.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(903749,'watch','.b-select-suggest .select2-search input','background-repeat','no-repeat','','','.b-select-suggest'),(903750,'watch','.b-select-suggest .select2-search input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(903751,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','','.b-select-suggest'),(903752,'watch','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(903753,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat_important','important','','','.b-select-suggest'),(903754,'watch','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size','60px 40px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(903755,'watch','.w-top-categories .image','background-size','cover','','','.w-top-categories'),(903756,'watch','.w-categories .image','background-size','cover','','','.w-categories'),(903757,'watch','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(903758,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.p-quick-order-index'),(903759,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background_important','important','','','.b-select-suggest'),(903760,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.b-data-table'),(903761,'watch','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(903762,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','1','','.p-quick-order-index'),(903763,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.p-quick-order-index'),(903764,'watch','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(903765,'watch','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(903766,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(903767,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.p-quick-order-index'),(903768,'watch','.b-messages .select2-container-multi input.select2-input','border','none','','','.b-messages'),(903769,'watch','.b-messages .emailLineTextArea textarea','border','none','','','.b-messages'),(903770,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border','none','3','','.b-switch'),(903771,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(903772,'watch','.b-switch .candlestick-wrapper .candlestick-bg','border','none','','','.b-switch'),(903773,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(903774,'watch','.b-autocomplete .ui-autocomplete li','border','none','','','.b-autocomplete'),(903775,'watch','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(903776,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(903777,'watch','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(903778,'watch','.w-cart-cart-tabs .w-tabs > .block','border','none','','','.w-cart-cart-tabs'),(903779,'watch','.b-bottom .popup-box.popupCompare','border','none','','','.b-bottom'),(903780,'watch','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(903781,'watch','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(903782,'watch','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(903783,'watch','.w-top-categories .categories h2','border','none','','','.w-top-categories'),(903784,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border','none','4','','.b-switch'),(903785,'watch','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(903786,'watch','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(903787,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border','none','','','.b-switch'),(903788,'watch','.w-product-personal-catalog-button .btn','border','none','','','.w-product-personal-catalog-button'),(903789,'watch','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(903790,'watch','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(903791,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(903792,'watch','.b-form .checkbox-style','border','none','','','.b-form'),(903793,'watch','.b-sub-totals .historyTotal table','border','none','','','.b-sub-totals'),(903794,'watch','.w-product-personal-catalog-button .btn','border','none','','','.w-product-personal-catalog-button'),(903795,'watch','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(903796,'watch','.b-bottom .cart-options .heading-4','border','none','','','.b-bottom'),(903797,'watch','.w-product-personal-catalog-button .btn','border','none','','','.w-product-personal-catalog-button'),(903798,'watch','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(903799,'watch','.b-products-listing .products-listing .wishlistButton .checkbox input + span','border','none','','','.b-products-listing'),(903800,'watch','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','border','none','','','.b-products-listing'),(903801,'watch','.w-product-personal-catalog-button .btn','border','none','','','.w-product-personal-catalog-button'),(903802,'watch','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(903803,'watch','.b-compare .compare-head','border','none','','','.b-compare'),(903804,'watch','.w-product-personal-catalog-button .btn','border','none','','','.w-product-personal-catalog-button'),(903805,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.p-quick-order-index'),(903806,'watch','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(903807,'watch','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(903808,'watch','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(903809,'watch','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(903810,'watch','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(903811,'watch','.b-sub-totals .historyTotal td','border','none','','','.b-sub-totals'),(903812,'watch','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(903813,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.b-data-table'),(903814,'watch','.b-products-listing .products-listing a.btn.view-button','border','none','','','.b-products-listing'),(903815,'watch','.b-products-listing .products-listing h2','border','none','','','.b-products-listing'),(903816,'watch','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(903817,'watch','.w-checkout-gdpr .privacy-row','border','none','','','.w-checkout-gdpr'),(903818,'watch','.b-autocomplete .ui-autocomplete li','border','none','1','','.b-autocomplete'),(903819,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','border','none','','','.w-communication-new-topic'),(903820,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','border','none','','','.w-communication-new-topic'),(903821,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','border','none','','','.w-communication-new-topic'),(903822,'watch','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(903823,'watch','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(903824,'watch','.w-product-personal-catalog-button .btn','border','none','','','.w-product-personal-catalog-button'),(903825,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(903826,'watch','.w-filters .input-checkbox','border','none','','','.w-filters'),(903827,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','border','none','','',''),(903828,'watch','.b-data-table table.dataTable thead td','border','none','','','.b-data-table'),(903829,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.b-data-table'),(903830,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.b-data-table'),(903831,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border','none','','','.b-product-images'),(903832,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','border','none','','','.b-menu-style-2'),(903833,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','border','none','','','.b-menu-style-2'),(903834,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','border','none','','','.b-menu-style-2'),(903835,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','border','none','','','.w-catalog-compare'),(903836,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','border','none','','','.w-filters'),(903837,'watch','.order-summary .w-cart-listing .headings','border','none','','','.order-summary'),(903838,'watch','.order-summary .w-cart-listing .item','border','none','','','.order-summary'),(903841,'watch','.account-samples .orders-table tr:first-child','border','none','','','.account-samples'),(903842,'watch','.w-promotions .heading-3','border-bottom','none','','','.w-promotions'),(903843,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable.no-footer','border-bottom','none','','','.b-messages'),(903844,'watch','.w-tabs .tab-a','border-bottom','none','2','','.w-tabs'),(903845,'watch','.w-cart-shipping-estimator .addresses','border-bottom','none','','','.w-cart-shipping-estimator'),(903846,'watch','.w-account-personal-catalog .list-switcher a','border-bottom','none','2','','.w-account-personal-catalog'),(903847,'watch','.w-catalog-compare .cross-box .different-all > div','border-bottom','none','2','','.w-catalog-compare'),(903849,'watch','.b-quantity .qty-box .smaller','border-bottom-color','$content-border-1','','','.b-quantity'),(903850,'watch','.b-quantity .qty-box .bigger','border-bottom-color','$content-border-1','','','.b-quantity'),(903851,'watch','.b-quantity .qty-box .bigger','border-bottom-color','$content-border-1','','','.b-quantity'),(903852,'watch','.b-upload-file .upload-file-template','border-bottom-color','$content-border-1','','','.b-upload-file'),(903853,'watch','.w-promotions .prom-multi-discount .promo-range','border-bottom-color','$attention-border','','','.w-promotions'),(903854,'watch','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(903856,'watch','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(903857,'watch','.testimonials .review','border-bottom-color','transparent','3','',''),(903858,'watch','.w-promotions .promo-salemaker .discount','border-bottom-color','$attention-border','','','.w-promotions'),(903859,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-color','$attention-border','','','.w-promotions'),(903860,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-color','$attention-border','','','.w-promotions'),(903861,'watch','.w-cart-give-away .ga_column','border-bottom-color','$content-border-1','','','.w-cart-give-away'),(903862,'watch','.w-cart-compare .cart-cell > div','border-bottom-color','$content-border-1','','','.w-cart-compare'),(903863,'watch','.b-messages .msv_btn','border-bottom-color','$content-border-1','','','.b-messages'),(903864,'watch','.b-messages .content_management_attach button','border-bottom-color','$content-border-2','','','.b-messages'),(903865,'watch','.b-messages .content_management_attach','border-bottom-color','$content-border-1','','','.b-messages'),(903866,'watch','.b-messages .email-heading','border-bottom-color','$content-border-1','','','.b-messages'),(903867,'watch','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-color','$content-border-1','','','.b-messages'),(903868,'watch','.b-messages .msv_to_cc','border-bottom-color','$content-border-1','','','.b-messages'),(903869,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-color','$content-border-1','','','.b-messages'),(903870,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-bottom-color','$content-border-1','','',''),(903871,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-color','$content-border-1','','','.b-messages'),(903872,'watch','.b-messages .dataTables_wrapper > .bottom','border-bottom-color','$content-border-1','','','.b-messages'),(903873,'watch','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(903874,'watch','.w-product-reviews .reviews-list .review','border-bottom-color','$transparent','3','','.w-product-reviews'),(903875,'watch','.b-form .required-error','border-bottom-color','$attention-border','','','.b-form'),(903876,'watch','.p-payer-order-confirmation .input-wrapper','border-bottom-color','$content-border-1','','','.p-payer-order-confirmation'),(903877,'watch','.p-payer-order-pay .input-wrapper','border-bottom-color','$content-border-1','','','.p-payer-order-pay'),(903878,'watch','.b-upload-file .snapshot','border-bottom-color','$content-border-1','','','.b-upload-file'),(903879,'watch','.b-quantity .qty-box .smaller','border-bottom-color','$content-border-1','','','.b-quantity'),(903880,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-color','$switch-nc-border-1','','','.b-switch'),(903881,'watch','.b-quantity .qty-box .smaller','border-bottom-color','$content-border-1','','','.b-quantity'),(903882,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(903883,'watch','.w-filters .filter-box-head','border-bottom-color','$content-border-1','','','.w-filters'),(903884,'watch','.b-quantity .qty-box .bigger','border-bottom-color','$content-border-1','','','.b-quantity'),(903885,'watch','.b-upload-file .upload-file-template div','border-bottom-color','$content-border-1','','','.b-upload-file'),(903886,'watch','.w-product-quantity .qty_packs .qty-input','border-bottom-color','$content-border-1','','','.w-product-quantity'),(903887,'watch','.b-quantity .qty-box .smaller','border-bottom-color','$content-border-1','','','.b-quantity'),(903888,'watch','.w-checkout-shipping-choice span','border-bottom-color','$content-border-2','','','.w-checkout-shipping-choice'),(903889,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(903890,'watch','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(903891,'watch','.b-info-popup .info-popup div','border-bottom-color','$content-border-1','','','.b-info-popup'),(903892,'watch','.b-quantity .qty-box .smaller','border-bottom-color','$content-border-1','','','.b-quantity'),(903893,'watch','.b-quantity .qty-box .bigger','border-bottom-color','$content-border-1','','','.b-quantity'),(903894,'watch','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(903895,'watch','.w-tabs > .block','border-bottom-color','$tab-content-border-1','','','.w-tabs'),(903896,'watch','.w-tabs .accordion-heading','border-bottom-color','$tab-nav-border-1','2','','.w-tabs'),(903897,'watch','.w-tabs .tab-a','border-bottom-color','$tab-nav-border-2','','','.w-tabs'),(903898,'watch','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(903900,'watch','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(903901,'watch','.w-cart-compare .compare-table','border-bottom-color','$content-border-1','','','.w-cart-compare'),(903902,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-color','$switch-handle-bg-3','','','.b-switch'),(903903,'watch','.btn-3','border-bottom-color','$btn-border-4','','',''),(903904,'watch','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(903905,'watch','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(903906,'watch','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(903907,'watch','.b-products-listing .products-listing .compare','border-bottom-color','$content-border-1','','','.b-products-listing'),(903908,'watch','.w-product-quantity .qty_packs .qty-input','border-bottom-color','$content-border-1','','','.w-product-quantity'),(903909,'watch','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(903910,'watch','.w-reviews-content .review','border-bottom-color','$content-border-1','3','','.w-reviews-content'),(903911,'watch','.w-product-quantity .qty_packs .qty-input','border-bottom-color','$content-border-1','','','.w-product-quantity'),(903912,'watch','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(903913,'watch','.w-product-quantity .qty_packs .qty-input','border-bottom-color','$content-border-1','','','.w-product-quantity'),(903914,'watch','.b-select-suggest .select2-container.select2-drop-above .select2-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(903915,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-color','$switch-nc-border-1','4','','.b-switch'),(903917,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-color','$checkbox-border-1','3','','.b-form'),(903918,'watch','.w-cart-products .checkout-attention-message','border-bottom-color','$attention-border','','','.w-cart-products'),(903919,'watch','.w-cart-products .checkout-attention-message','border-bottom-color','$attention-border','','','.w-cart-products'),(903920,'watch','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-bottom-color','$content-border-1','','','.b-bottom'),(903921,'watch','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(903922,'watch','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-bottom-color','$content-bg-1','','','.b-bottom'),(903923,'watch','textarea','border-bottom-color','$content-border-1','','',''),(903924,'watch','.btn','border-bottom-color','$btn-border-1','','',''),(903925,'watch','.b-bottom .popup-box','border-bottom-color','$content-border-1','','','.b-bottom'),(903926,'watch','.w-product-customers-activity .customers-activity','border-bottom-color','$content-border-1','','','.w-product-customers-activity'),(903927,'watch','.b-quantity .qty-box .smaller','border-bottom-color','$content-border-1','','','.b-quantity'),(903928,'watch','.w-product-quantity .qty_packs .qty-input','border-bottom-color','$content-border-1','','','.w-product-quantity'),(903929,'watch','.w-tabs .accordion-heading','border-bottom-color','$tab-nav-border-2','','','.w-tabs'),(903930,'watch','.b-quantity .qty-box .bigger','border-bottom-color','$content-border-1','','','.b-quantity'),(903931,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-color','$content-border-1','','','.b-select-suggest'),(903932,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(903933,'watch','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-color','$content-border-1','','','.b-select-suggest'),(903934,'watch','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-color','$content-border-1','','','.b-select-suggest'),(903935,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(903936,'watch','.b-select-suggest .select2-dropdown-open .select2-choice','border-bottom-color','$transparent','','','.b-select-suggest'),(903937,'watch','.b-select-suggest .select2-drop-active','border-bottom-color','$content-border-1','','','.b-select-suggest'),(903938,'watch','.b-select-suggest .select2-drop','border-bottom-color','$content-border-1','','','.b-select-suggest'),(903939,'watch','.w-product-quantity .qty_packs .qty-input','border-bottom-color','$content-border-1','','','.w-product-quantity'),(903940,'watch','.w-cart-products .checkout-attention-message','border-bottom-color','$attention-border','','','.w-cart-products'),(903941,'watch','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(903942,'watch','.b-form input.required-error','border-bottom-color','$attention-border','','','.b-form'),(903943,'watch','.w-communication-post .communication-post','border-bottom-color','$content-border-1','','','.w-communication-post'),(903944,'watch','.checkbox input + span','border-bottom-color','$checkbox-border-1','','',''),(903945,'watch','.checkbox input:checked + span','border-bottom-color','$checkbox-border-1','','',''),(903946,'watch','.b-autocomplete .ui-autocomplete','border-bottom-color','$content-border-1','','','.b-autocomplete'),(903949,'watch','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(903950,'watch','.b-select-suggest .select2-container .select2-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(903951,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-color','$switch-nc-border-1','3','','.b-switch'),(903952,'watch','.w-reviews .review','border-bottom-color','$content-bg-1','3','','.w-reviews'),(903953,'watch','.w-catalog-listing-look .list','border-bottom-color','$content-border-1','','','.w-catalog-listing-look'),(903954,'watch','.b-quantity .qty-box .bigger','border-bottom-color','$content-border-1','','','.b-quantity'),(903955,'watch','.w-reviews-content .item','border-bottom-color','$content-border-1','','','.w-reviews-content'),(903956,'watch','.b-upload-files .upload-files','border-bottom-color','$content-border-1','','','.b-upload-files'),(903957,'watch','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(903958,'watch','.w-reviews .item','border-bottom-color','$content-border-1','','','.w-reviews'),(903959,'watch','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(903960,'watch','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(903961,'watch','.b-select-suggest .select2-search input','border-bottom-color','$content-border-1','','','.b-select-suggest'),(903962,'watch','.w-catalog-listing-look .b2b','border-bottom-color','$content-border-1','','','.w-catalog-listing-look'),(903963,'watch','.w-catalog-listing-look .grid','border-bottom-color','$content-border-1','','','.w-catalog-listing-look'),(903964,'watch','.w-cart-listing .item','border-bottom-color','#e0e0e0','','','.w-cart-listing'),(903965,'watch','.w-cart-products .checkout-attention-message','border-bottom-color','$attention-border','','','.w-cart-products'),(903966,'watch','.w-cart-listing .item .gift-wrap label','border-bottom-color','#e0e0e0','','','.w-cart-listing'),(903967,'watch','.w-cart-listing .item','border-bottom-color','#e0e0e0','5240','','.w-cart-listing'),(903969,'watch','.w-cart-products .checkout-attention-message','border-bottom-color','$attention-border','','','.w-cart-products'),(903970,'watch','.b-data-table table.dataTable.no-footer','border-bottom-color','$content-border-1','','','.b-data-table'),(903971,'watch','.w-cart-products .checkout-attention-message','border-bottom-color','$attention-border','','','.w-cart-products'),(903972,'watch','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-color','$content-border-1','','','.b-compare'),(903973,'watch','.b-compare .compare_pagination','border-bottom-color','$content-border-1','','','.b-compare'),(903974,'watch','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-bottom-color','$image-popup-border-1','','','.b-product-images'),(903975,'watch','.b-trade-approval .orders-table th','border-bottom-color','$content-border-1','','','.b-trade-approval'),(903976,'watch','.w-account-personal-catalog .list-switcher a','border-bottom-color','$content-border-1','','','.w-account-personal-catalog'),(903977,'watch','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-color','$content-bg-1','','','.w-catalog-compare'),(903978,'watch','.w-catalog-compare .cross-box .different-all > div','border-bottom-color','$content-border-1','','','.w-catalog-compare'),(903979,'watch','.w-delivery-day .left-text-left','border-bottom-color','$content-border-1','','','.w-delivery-day'),(903980,'watch','.w-delivery-day .left-text-right','border-bottom-color','$content-border-1','','','.w-delivery-day'),(903981,'watch','.order-summary .checkout-cart-listing','border-bottom-color','#e0e0e0','','','.order-summary'),(903985,'watch','.catalog-product-wrap .pn-image','border-bottom-color','$content-border-1','3','','.catalog-product-wrap'),(903986,'watch','.checkout-index-wrap .input-wrapper','border-bottom-color','#e0e0e0','','','.checkout-index-wrap'),(903987,'watch','.account-samples .orders-table .item','border-bottom-color','$content-border-1','5240','','.account-samples'),(903988,'watch','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-color','$highlight-box-border-1','','','.b-multi-page-checkout'),(903989,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-color','$content-border-1','','','.b-multi-page-checkout'),(903990,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-color','$content-border-1','','','.b-multi-page-checkout'),(903991,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-color','$content-border-1','','','.b-slick'),(903992,'watch','.w-catalog-paging ','border-bottom-color','#CCCCCC','2','','.w-catalog-paging'),(903993,'watch','.w-catalog-paging .next','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(903994,'watch','.w-catalog-paging .next-pages','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(903995,'watch','.w-catalog-paging .page-number','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(903996,'watch','.w-catalog-paging .prev','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(903997,'watch','.w-catalog-paging .prev-pages','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(903998,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(903999,'watch','.b-data-table table.dataTable.no-footer','border-bottom-color_important','important','','','.b-data-table'),(904000,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-left-radius','15','4','','.b-switch'),(904001,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.p-quick-order-index'),(904002,'watch','.w-promotions .prom-multi-discount .promo-range','border-bottom-left-radius','12','','','.w-promotions'),(904003,'watch','.w-promotions .promo-salemaker .discount','border-bottom-left-radius','12','','','.w-promotions'),(904004,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-left-radius','12','','','.w-promotions'),(904005,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-left-radius','12','','','.w-promotions'),(904006,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.p-quick-order-index'),(904007,'watch','.w-personal-gift-status-bar .progress-bar','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(904008,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-left-radius','5','','','.b-messages'),(904009,'watch','.b-fancybox .fancybox-close','border-bottom-left-radius','50','','','.b-fancybox'),(904010,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-left-radius','25','','','.b-switch'),(904011,'watch','.b-upload-file .snapshot','border-bottom-left-radius','50','','','.b-upload-file'),(904012,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-left-radius','15','3','','.b-switch'),(904013,'watch','.b-switch .candlestick-wrapper .candlestick-bg','border-bottom-left-radius','15','','','.b-switch'),(904014,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(904015,'watch','.w-checkout-shipping-choice label:last-child span','border-bottom-left-radius','0','','','.w-checkout-shipping-choice'),(904016,'watch','.w-checkout-shipping-choice label:first-child span','border-bottom-left-radius','16','','','.w-checkout-shipping-choice'),(904017,'watch','.btn-1','border-bottom-left-radius','20','','',''),(904018,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-bottom-left-radius','0','4','','.b-switch'),(904019,'watch','.btn-3','border-bottom-left-radius','24','','',''),(904020,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-bottom-left-radius','0','3','','.b-switch'),(904021,'watch','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-left-radius','15','','','.b-fancybox'),(904022,'watch','.b-fancybox .fancybox-skin','border-bottom-left-radius','4','','','.b-fancybox'),(904023,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-bottom-left-radius','50','3','','.b-switch'),(904024,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-left-radius','50','3','','.b-form'),(904025,'watch','.b-fancybox .fancybox-nav span','border-bottom-left-radius','50','','','.b-fancybox'),(904026,'watch','.w-product-customers-activity .customers-activity','border-bottom-left-radius','0','','','.w-product-customers-activity'),(904027,'watch','.w-product-customers-activity .close','border-bottom-left-radius','50','','','.w-product-customers-activity'),(904028,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(904029,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.b-data-table'),(904030,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.b-data-table'),(904031,'watch','.b-products-listing .promos-info .promo-name','border-bottom-left-radius','0','','','.b-products-listing'),(904032,'watch','.w-personal-gift-status-bar .progress-bar-content','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(904033,'watch','.btn-2','border-bottom-left-radius','24','','',''),(904034,'watch','.b-switch .bootstrap-switch','border-bottom-left-radius','14','','','.b-switch'),(904035,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-left-radius','25','','','.b-switch'),(904036,'watch','.btn','border-bottom-left-radius','20','','',''),(904037,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-bottom-left-radius','0','','','.b-product-images'),(904038,'watch','.b-trade-approval .steps-bar','border-bottom-left-radius','18','','','.b-trade-approval'),(904039,'watch','.w-delivery-day .left-count','border-bottom-left-radius','3','','','.w-delivery-day'),(904040,'watch','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-left-radius','3','','','.w-delivery-day'),(904042,'watch','.catalog-product-wrap .pn-image','border-bottom-left-radius','50','3','','.catalog-product-wrap'),(904043,'watch','.b-slick .slick-dots li','border-bottom-left-radius','50','3','','.b-slick'),(904044,'watch','.success-page .w-cart-listing .qty','border-bottom-left-radius','50','','','.success-page'),(904045,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-left-radius','50','','','.b-multi-page-checkout'),(904046,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-left-radius','50','3','','.b-multi-page-checkout'),(904047,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-left-radius','50','','','.b-slick'),(904048,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-left-radius','0','','','.w-catalog-paging'),(904049,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-bottom-right-radius','0','4','','.b-switch'),(904050,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-right-radius','15','4','','.b-switch'),(904051,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.p-quick-order-index'),(904052,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.p-quick-order-index'),(904053,'watch','.w-promotions .prom-multi-discount .promo-range','border-bottom-right-radius','12','','','.w-promotions'),(904054,'watch','.w-promotions .promo-salemaker .discount','border-bottom-right-radius','12','','','.w-promotions'),(904055,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-right-radius','12','','','.w-promotions'),(904056,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-right-radius','12','','','.w-promotions'),(904057,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-right-radius','5','','','.b-messages'),(904058,'watch','.b-fancybox .fancybox-close','border-bottom-right-radius','50','','','.b-fancybox'),(904059,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-right-radius','25','','','.b-switch'),(904060,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-bottom-right-radius','0','3','','.b-switch'),(904061,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-right-radius','15','3','','.b-switch'),(904062,'watch','.b-switch .candlestick-wrapper .candlestick-bg','border-bottom-right-radius','15','','','.b-switch'),(904063,'watch','.w-checkout-shipping-choice label:last-child span','border-bottom-right-radius','16','','','.w-checkout-shipping-choice'),(904064,'watch','.w-checkout-shipping-choice label:first-child span','border-bottom-right-radius','0','','','.w-checkout-shipping-choice'),(904065,'watch','.btn-1','border-bottom-right-radius','20','','',''),(904066,'watch','.btn-2','border-bottom-right-radius','24','','',''),(904067,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(904068,'watch','.btn-3','border-bottom-right-radius','24','','',''),(904069,'watch','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-right-radius','15','','','.b-fancybox'),(904070,'watch','.b-fancybox .fancybox-skin','border-bottom-right-radius','4','','','.b-fancybox'),(904071,'watch','.b-upload-file .snapshot','border-bottom-right-radius','50','','','.b-upload-file'),(904072,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-bottom-right-radius','50','3','','.b-switch'),(904073,'watch','.b-fancybox .fancybox-nav span','border-bottom-right-radius','50','','','.b-fancybox'),(904074,'watch','.w-product-customers-activity .close','border-bottom-right-radius','50','','','.w-product-customers-activity'),(904075,'watch','.w-product-customers-activity .customers-activity','border-bottom-right-radius','0','','','.w-product-customers-activity'),(904076,'watch','.w-personal-gift-status-bar .progress-bar','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(904077,'watch','.b-switch .bootstrap-switch','border-bottom-right-radius','14','','','.b-switch'),(904078,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.b-data-table'),(904079,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.b-data-table'),(904080,'watch','.b-products-listing .promos-info .promo-name','border-bottom-right-radius','8','','','.b-products-listing'),(904081,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(904082,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-right-radius','50','3','','.b-form'),(904083,'watch','.w-personal-gift-status-bar .progress-bar-content','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(904084,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-right-radius','25','','','.b-switch'),(904085,'watch','.btn','border-bottom-right-radius','20','','',''),(904086,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-bottom-right-radius','0','','','.b-product-images'),(904087,'watch','.b-trade-approval .steps-bar','border-bottom-right-radius','18','','','.b-trade-approval'),(904088,'watch','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-right-radius','3','','','.w-delivery-day'),(904089,'watch','.w-delivery-day .left-count','border-bottom-right-radius','3','','','.w-delivery-day'),(904091,'watch','.catalog-product-wrap .pn-image','border-bottom-right-radius','50','3','','.catalog-product-wrap'),(904092,'watch','.b-slick .slick-dots li','border-bottom-right-radius','50','3','','.b-slick'),(904093,'watch','.success-page .w-cart-listing .qty','border-bottom-right-radius','50','','','.success-page'),(904094,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-right-radius','50','','','.b-multi-page-checkout'),(904095,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-right-radius','50','3','','.b-multi-page-checkout'),(904096,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-right-radius','50','','','.b-slick'),(904097,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-right-radius','0','','','.w-catalog-paging'),(904098,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(904099,'watch','.b-upload-file .upload-file-template div','border-bottom-style','dotted','','','.b-upload-file'),(904100,'watch','.w-promotions .prom-multi-discount .promo-range','border-bottom-width','1','','','.w-promotions'),(904102,'watch','.testimonials .review','border-bottom-width','7','3','',''),(904103,'watch','.w-promotions .promo-salemaker .discount','border-bottom-width','1','','','.w-promotions'),(904104,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-width','1','','','.w-promotions'),(904105,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-width','1','','','.w-promotions'),(904106,'watch','.b-upload-file .upload-file-template div','border-bottom-width','1','','','.b-upload-file'),(904107,'watch','.w-cart-compare .cart-cell > div','border-bottom-width','1','','','.w-cart-compare'),(904108,'watch','.w-filters .filter-box-head','border-bottom-width','1','','','.w-filters'),(904109,'watch','.b-quantity .qty-box .bigger','border-bottom-width','2','','','.b-quantity'),(904110,'watch','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-bottom-width','1','','','.b-bottom'),(904111,'watch','.b-messages .msv_btn','border-bottom-width','1','','','.b-messages'),(904112,'watch','.b-messages .email-heading','border-bottom-width','1','','','.b-messages'),(904113,'watch','.b-messages .content_management_attach button','border-bottom-width','1','','','.b-messages'),(904114,'watch','.b-messages .content_management_attach','border-bottom-width','1','','','.b-messages'),(904115,'watch','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-width','2','','','.b-messages'),(904116,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-width','1','','','.b-messages'),(904117,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-width','1','','','.b-messages'),(904118,'watch','.b-messages .dataTables_wrapper > .bottom','border-bottom-width','1','','','.b-messages'),(904119,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-bottom-width','2','','',''),(904120,'watch','.w-catalog-listing-look .grid','border-bottom-width','1','','','.w-catalog-listing-look'),(904121,'watch','.p-payer-order-confirmation .input-wrapper','border-bottom-width','2','','','.p-payer-order-confirmation'),(904122,'watch','.p-payer-order-pay .input-wrapper','border-bottom-width','2','','','.p-payer-order-pay'),(904123,'watch','.b-messages .msv_to_cc','border-bottom-width','1','','','.b-messages'),(904124,'watch','.w-product-reviews .reviews-list .review','border-bottom-width','7','3','','.w-product-reviews'),(904125,'watch','.w-reviews .review','border-bottom-width','8','3','','.w-reviews'),(904126,'watch','.b-quantity .qty-box .bigger','border-bottom-width','2','','','.b-quantity'),(904127,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(904128,'watch','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(904129,'watch','.w-tabs .accordion-heading','border-bottom-width','1','','','.w-tabs'),(904130,'watch','.b-form .required-error','border-bottom-width','1','','','.b-form'),(904131,'watch','.b-quantity .qty-box .bigger','border-bottom-width','2','','','.b-quantity'),(904132,'watch','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(904133,'watch','.w-socials > li','border-bottom-width','1','','','.w-socials'),(904134,'watch','.b-bottom .popup-heading','border-bottom-width','1','','','.b-bottom'),(904135,'watch','.w-checkout-shipping-choice span','border-bottom-width','2','','','.w-checkout-shipping-choice'),(904136,'watch','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(904137,'watch','.w-socials > li','border-bottom-width','1','','','.w-socials'),(904140,'watch','.b-info-popup .info-popup div','border-bottom-width','1','','','.b-info-popup'),(904141,'watch','.b-quantity .qty-box .smaller','border-bottom-width','2','','','.b-quantity'),(904142,'watch','.b-quantity .qty-box .bigger','border-bottom-width','2','','','.b-quantity'),(904143,'watch','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(904144,'watch','.b-quantity .qty-box .bigger','border-bottom-width','2','','','.b-quantity'),(904145,'watch','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(904146,'watch','.w-tabs > .block','border-bottom-width','1','','','.w-tabs'),(904147,'watch','.w-tabs .accordion-heading','border-bottom-width','3','2','','.w-tabs'),(904148,'watch','.w-tabs .tab-a','border-bottom-width','1','','','.w-tabs'),(904149,'watch','.w-socials > li','border-bottom-width','1','','','.w-socials'),(904150,'watch','.w-cart-give-away .ga_column','border-bottom-width','1','','','.w-cart-give-away'),(904151,'watch','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(904152,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-width','4','','','.b-switch'),(904153,'watch','.b-quantity .qty-box .smaller','border-bottom-width','2','','','.b-quantity'),(904154,'watch','.w-filters .ui-slider-handle','border-bottom-width','0','','','.w-filters'),(904155,'watch','.w-filters .ui-slider','border-bottom-width','0','','','.w-filters'),(904156,'watch','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(904158,'watch','.b-products-listing .products-listing .compare','border-bottom-width','1','','','.b-products-listing'),(904159,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-width','2','3','','.b-form'),(904160,'watch','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(904161,'watch','.b-upload-file .upload-file-template','border-bottom-width','1','','','.b-upload-file'),(904162,'watch','.w-socials > li','border-bottom-width','1','','','.w-socials'),(904163,'watch','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(904164,'watch','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(904165,'watch','.w-reviews .item','border-bottom-width','1','','','.w-reviews'),(904166,'watch','.b-select-suggest .select2-container .select2-choice','border-bottom-width','2','','','.b-select-suggest'),(904167,'watch','.b-quantity .qty-box .smaller','border-bottom-width','2','','','.b-quantity'),(904168,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-width','2','4','','.b-switch'),(904170,'watch','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(904171,'watch','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-width','1','','','.b-compare'),(904172,'watch','.w-cart-compare .compare-table','border-bottom-width','1','','','.w-cart-compare'),(904173,'watch','.w-reviews-content .review','border-bottom-width','8','3','','.w-reviews-content'),(904174,'watch','textarea','border-bottom-width','2','','',''),(904175,'watch','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-bottom-width','1','','','.b-bottom'),(904176,'watch','.b-bottom .footerTitle','border-bottom-width','1','5232','','.b-bottom'),(904177,'watch','.w-socials > li','border-bottom-width','1','','','.w-socials'),(904178,'watch','.b-bottom .popup-box','border-bottom-width','1','','','.b-bottom'),(904179,'watch','.b-quantity .qty-box .smaller','border-bottom-width','2','','','.b-quantity'),(904180,'watch','.w-product-customers-activity .customers-activity','border-bottom-width','1','','','.w-product-customers-activity'),(904181,'watch','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(904182,'watch','.heading-3, h3, .h-block h3','border-bottom-width','1','','',''),(904183,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(904184,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(904185,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(904186,'watch','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(904187,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-width','1','','','.b-select-suggest'),(904188,'watch','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(904189,'watch','.b-select-suggest .select2-search input','border-bottom-width','1','','','.b-select-suggest'),(904190,'watch','.b-select-suggest .select2-drop-active','border-bottom-width','1','','','.b-select-suggest'),(904191,'watch','.b-select-suggest .select2-drop','border-bottom-width','1','','','.b-select-suggest'),(904192,'watch','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(904193,'watch','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(904194,'watch','.w-communication-post .communication-post','border-bottom-width','1','','','.w-communication-post'),(904195,'watch','.checkbox input:checked + span','border-bottom-width','1','','',''),(904196,'watch','.checkbox input + span','border-bottom-width','1','','',''),(904197,'watch','.b-autocomplete .ui-autocomplete','border-bottom-width','1','','','.b-autocomplete'),(904200,'watch','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(904201,'watch','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(904202,'watch','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(904203,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-width','2','3','','.b-switch'),(904204,'watch','.b-quantity .qty-box .smaller','border-bottom-width','2','','','.b-quantity'),(904205,'watch','.b-quantity .qty-box .bigger','border-bottom-width','2','','','.b-quantity'),(904206,'watch','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(904207,'watch','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(904208,'watch','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(904209,'watch','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(904210,'watch','.w-catalog-listing-look .b2b','border-bottom-width','1','','','.w-catalog-listing-look'),(904211,'watch','.w-catalog-listing-look .list','border-bottom-width','1','','','.w-catalog-listing-look'),(904212,'watch','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(904213,'watch','.w-cart-listing .item','border-bottom-width','1','','','.w-cart-listing'),(904214,'watch','.w-cart-listing .item .gift-wrap label','border-bottom-width','1','','','.w-cart-listing'),(904215,'watch','.w-cart-listing .item','border-bottom-width','1','5240','','.w-cart-listing'),(904218,'watch','.w-socials > li','border-bottom-width','1','','','.w-socials'),(904219,'watch','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(904221,'watch','.w-reviews-content .item','border-bottom-width','1','','','.w-reviews-content'),(904222,'watch','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(904223,'watch','.w-filters .ui-slider-range','border-bottom-width','0','','','.w-filters'),(904224,'watch','.btn','border-bottom-width','2','','',''),(904225,'watch','.b-upload-files .upload-files','border-bottom-width','1','','','.b-upload-files'),(904226,'watch','.btn-3','border-bottom-width','2','','',''),(904227,'watch','.b-quantity .qty-box .smaller','border-bottom-width','2','','','.b-quantity'),(904228,'watch','.b-compare .compare_pagination','border-bottom-width','1','','','.b-compare'),(904229,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-width','3','','','.b-switch'),(904230,'watch','.b-upload-file .snapshot','border-bottom-width','1','','','.b-upload-file'),(904231,'watch','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-bottom-width','2','','','.b-product-images'),(904232,'watch','.b-trade-approval .orders-table th','border-bottom-width','1','','','.b-trade-approval'),(904233,'watch','.w-account-personal-catalog .list-switcher a','border-bottom-width','1','','','.w-account-personal-catalog'),(904234,'watch','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-width','1','','','.w-catalog-compare'),(904235,'watch','.w-catalog-compare .cross-box .different-all > div','border-bottom-width','1','','','.w-catalog-compare'),(904236,'watch','.w-delivery-day .left-text-right','border-bottom-width','2','','','.w-delivery-day'),(904237,'watch','.w-delivery-day .left-text-left','border-bottom-width','2','','','.w-delivery-day'),(904238,'watch','.order-summary .checkout-cart-listing','border-bottom-width','1','','','.order-summary'),(904243,'watch','.catalog-product-wrap .pn-image','border-bottom-width','2','3','','.catalog-product-wrap'),(904244,'watch','.catalog-product-wrap .prev-next-product','border-bottom-width','1','','','.catalog-product-wrap'),(904245,'watch','.checkout-index-wrap .input-wrapper','border-bottom-width','2','','','.checkout-index-wrap'),(904246,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','border-bottom-width','1','','','.account-order-pay'),(904247,'watch','.account-samples .orders-table .item','border-bottom-width','1','5240','','.account-samples'),(904248,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','border-bottom-width','1','','','.account-sample-info'),(904249,'watch','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(904250,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(904251,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-width','1','','','.b-multi-page-checkout'),(904252,'watch','.b-slick .slick-vertical .slick-slide','border-bottom-width','1','','','.b-slick'),(904253,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-width','2','','','.b-slick'),(904254,'watch','.w-catalog-paging ','border-bottom-width','1','2','','.w-catalog-paging'),(904255,'watch','.w-catalog-paging .next','border-bottom-width','1','','','.w-catalog-paging'),(904256,'watch','.w-catalog-paging .next-pages','border-bottom-width','1','','','.w-catalog-paging'),(904257,'watch','.w-catalog-paging .page-number','border-bottom-width','1','','','.w-catalog-paging'),(904258,'watch','.w-catalog-paging .prev','border-bottom-width','1','','','.w-catalog-paging'),(904259,'watch','.w-catalog-paging .prev-pages','border-bottom-width','1','','','.w-catalog-paging'),(904260,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-width','1','','','.w-catalog-paging'),(904261,'watch','.b-compare .popupCompare table','border-collapse','collapse','','','.b-compare'),(904262,'watch','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','border-left','none','','','.b-select-suggest'),(904263,'watch','.w-catalog-listing-look .list','border-left-color','$content-border-1','','','.w-catalog-listing-look'),(904264,'watch','.w-promotions .prom-multi-discount .promo-range','border-left-color','$attention-border','','','.w-promotions'),(904265,'watch','.w-cart-compare .attributes-block td:nth-child(1)','border-left-color','$content-border-1','','','.w-cart-compare'),(904267,'watch','.w-promotions .promo-salemaker .discount','border-left-color','$attention-border','','','.w-promotions'),(904268,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-color','$attention-border','','','.w-promotions'),(904269,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border-left-color','$attention-border','','','.w-promotions'),(904270,'watch','.w-cart-compare .cart-cell > div','border-left-color','$content-border-1','','','.w-cart-compare'),(904271,'watch','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(904272,'watch','.b-quantity .qty-box .smaller','border-left-color','$content-border-1','','','.b-quantity'),(904273,'watch','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-left-color','$content-border-1','','','.b-bottom'),(904274,'watch','.b-messages .content_management_attach button','border-left-color','$content-border-2','','','.b-messages'),(904275,'watch','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-color','$content-border-1','','','.b-messages'),(904276,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-left-color','$content-border-1','','',''),(904277,'watch','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(904278,'watch','.w-cart-products .checkout-attention-message','border-left-color','$attention-border','','','.w-cart-products'),(904279,'watch','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(904280,'watch','.p-payer-order-confirmation .input-wrapper','border-left-color','$content-border-1','','','.p-payer-order-confirmation'),(904281,'watch','.p-payer-order-pay .input-wrapper','border-left-color','$content-border-1','','','.p-payer-order-pay'),(904282,'watch','.b-quantity .qty-box .bigger','border-left-color','$content-border-1','','','.b-quantity'),(904283,'watch','.b-quantity .qty-box .bigger','border-left-color','$content-border-1','','','.b-quantity'),(904284,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-left-color','$switch-nc-border-1','','','.b-switch'),(904285,'watch','.b-quantity .qty-box .smaller','border-left-color','$content-border-1','','','.b-quantity'),(904286,'watch','.w-cart-products .checkout-attention-message','border-left-color','$attention-border','','','.w-cart-products'),(904287,'watch','.w-cart-products .checkout-attention-message','border-left-color','$attention-border','','','.w-cart-products'),(904288,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(904289,'watch','.b-info-popup .info-popup div','border-left-color','$content-border-1','3','','.b-info-popup'),(904290,'watch','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-color','$content-border-1','','','.b-compare'),(904291,'watch','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(904292,'watch','.b-form .required-error','border-left-color','$attention-border','','','.b-form'),(904293,'watch','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(904294,'watch','.b-info-popup .info-popup div','border-left-color','$content-border-1','','','.b-info-popup'),(904295,'watch','.w-checkout-shipping-choice label:first-child span','border-left-color','$content-border-2','','','.w-checkout-shipping-choice'),(904296,'watch','.b-quantity .qty-box .bigger','border-left-color','$content-border-1','','','.b-quantity'),(904297,'watch','.b-quantity .qty-box .smaller','border-left-color','$content-border-1','','','.b-quantity'),(904298,'watch','.w-product-reviews .reviews-list .review','border-left-color','$content-border-1','3','','.w-product-reviews'),(904299,'watch','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(904300,'watch','.w-tabs > .block','border-left-color','$tab-content-border-1','','','.w-tabs'),(904301,'watch','.w-tabs .tab-a','border-left-color','$tab-nav-border-2','2','','.w-tabs'),(904302,'watch','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(904304,'watch','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(904305,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-left-color','$switch-handle-bg-3','','','.b-switch'),(904306,'watch','.b-quantity .qty-box .bigger','border-left-color','$content-border-1','','','.b-quantity'),(904307,'watch','.w-reviews .review','border-left-color','$content-bg-1','3','','.w-reviews'),(904308,'watch','.w-reviews-content .review','border-left-color','$content-border-1','3','','.w-reviews-content'),(904309,'watch','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(904310,'watch','.b-select-suggest .select2-container .select2-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(904311,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-left-color','$switch-nc-border-1','4','','.b-switch'),(904313,'watch','.w-cart-products .checkout-attention-message','border-left-color','$attention-border','','','.w-cart-products'),(904314,'watch','.w-catalog-listing-look .grid','border-left-color','$content-border-1','','','.w-catalog-listing-look'),(904315,'watch','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(904316,'watch','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-left-color','$content-bg-1','','','.b-bottom'),(904317,'watch','textarea','border-left-color','$content-border-1','','',''),(904318,'watch','.b-bottom .popup-box','border-left-color','$content-border-1','','','.b-bottom'),(904319,'watch','.b-quantity .qty-box .bigger','border-left-color','$content-border-1','','','.b-quantity'),(904320,'watch','.w-product-customers-activity .customers-activity','border-left-color','$content-border-1','','','.w-product-customers-activity'),(904321,'watch','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(904322,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border-left-color','$checkbox-border-1','3','','.b-form'),(904323,'watch','.b-quantity .qty-box .bigger','border-left-color','$content-border-1','','','.b-quantity'),(904324,'watch','.w-cart-compare .price-block td:nth-child(1)','border-left-color','$content-border-1','','','.w-cart-compare'),(904325,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(904326,'watch','.b-quantity .qty-box .smaller','border-left-color','$content-border-1','','','.b-quantity'),(904327,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-color','$content-border-1','','','.b-select-suggest'),(904328,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(904329,'watch','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-color','$content-border-1','','','.b-select-suggest'),(904330,'watch','.b-select-suggest .select2-container-multi .select2-choices','border-left-color','$content-border-1','','','.b-select-suggest'),(904331,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(904332,'watch','.b-select-suggest .select2-search input','border-left-color','$content-border-1','','','.b-select-suggest'),(904333,'watch','.b-select-suggest .select2-drop','border-left-color','$content-border-1','','','.b-select-suggest'),(904334,'watch','.b-select-suggest .select2-drop-active','border-left-color','$content-border-1','','','.b-select-suggest'),(904335,'watch','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(904336,'watch','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(904337,'watch','.b-form input.required-error','border-left-color','$attention-border','','','.b-form'),(904338,'watch','.checkbox input:checked + span','border-left-color','$checkbox-border-1','','',''),(904339,'watch','.checkbox input + span','border-left-color','$checkbox-border-1','','',''),(904340,'watch','.b-autocomplete .ui-autocomplete','border-left-color','$content-border-1','','','.b-autocomplete'),(904343,'watch','.b-quantity .qty-box .smaller','border-left-color','$content-border-1','','','.b-quantity'),(904344,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-left-color','$switch-nc-border-1','3','','.b-switch'),(904345,'watch','.b-upload-file .snapshot','border-left-color','$content-border-1','','','.b-upload-file'),(904346,'watch','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(904347,'watch','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(904348,'watch','.b-quantity .qty-box .smaller','border-left-color','$content-border-1','','','.b-quantity'),(904349,'watch','.b-upload-files .upload-files','border-left-color','$content-border-1','','','.b-upload-files'),(904350,'watch','.b-upload-file .upload-file-template','border-left-color','$content-border-1','','','.b-upload-file'),(904351,'watch','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(904352,'watch','.w-catalog-listing-look .b2b','border-left-color','$content-border-1','','','.w-catalog-listing-look'),(904353,'watch','.w-cart-products .checkout-attention-message','border-left-color','$attention-border','','','.w-cart-products'),(904354,'watch','.w-cart-listing .item .gift-wrap label','border-left-color','#e0e0e0','','','.w-cart-listing'),(904355,'watch','.w-cart-listing .item','border-left-color','#e0e0e0','5240','','.w-cart-listing'),(904357,'watch','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(904358,'watch','.w-cart-products .checkout-attention-message','border-left-color','$attention-border','','','.w-cart-products'),(904359,'watch','.btn','border-left-color','$btn-border-1','','',''),(904360,'watch','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(904361,'watch','.w-cart-compare .product-block td:nth-child(1)','border-left-color','$content-border-1','','','.w-cart-compare'),(904362,'watch','.b-data-table table.dataTable.no-footer','border-left-color','$content-border-1','','','.b-data-table'),(904363,'watch','.btn-3','border-left-color','$btn-border-4','','',''),(904364,'watch','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-left-color','$image-popup-border-1','','','.b-product-images'),(904365,'watch','.b-trade-approval .steps-bar li ~ li a','border-left-color','$content-border-1','','','.b-trade-approval'),(904366,'watch','.w-account-personal-catalog .list-switcher a','border-left-color','$content-border-1','2','','.w-account-personal-catalog'),(904367,'watch','.w-catalog-compare .compare .checkbox input:checked + span','border-left-color','$content-bg-1','','','.w-catalog-compare'),(904368,'watch','.w-catalog-compare .cross-box .different-all > div','border-left-color','$content-border-1','2','','.w-catalog-compare'),(904371,'watch','.catalog-product-wrap .pn-image','border-left-color','$content-border-1','3','','.catalog-product-wrap'),(904372,'watch','.checkout-index-wrap .input-wrapper','border-left-color','#e0e0e0','','','.checkout-index-wrap'),(904373,'watch','.account-samples .orders-table .item','border-left-color','$content-border-1','5240','','.account-samples'),(904374,'watch','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-color','$highlight-box-border-1','','','.b-multi-page-checkout'),(904375,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-color','$content-border-1','','','.b-multi-page-checkout'),(904376,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-color','$content-border-1','','','.b-multi-page-checkout'),(904377,'watch','.testimonials .review','border-left-color','$content-bg-2','3','',''),(904378,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border-left-color','$content-border-1','','','.b-slick'),(904379,'watch','.w-catalog-paging ','border-left-color','#CCCCCC','2','','.w-catalog-paging'),(904380,'watch','.w-catalog-paging .next','border-left-color','#CCCCCC','','','.w-catalog-paging'),(904381,'watch','.w-catalog-paging .next-pages','border-left-color','#CCCCCC','','','.w-catalog-paging'),(904382,'watch','.w-catalog-paging .page-number','border-left-color','#CCCCCC','','','.w-catalog-paging'),(904383,'watch','.w-catalog-paging .prev','border-left-color','#CCCCCC','','','.w-catalog-paging'),(904384,'watch','.w-catalog-paging .prev-pages','border-left-color','#CCCCCC','','','.w-catalog-paging'),(904385,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-color','#CCCCCC','','','.w-catalog-paging'),(904386,'watch','.b-data-table table.dataTable.no-footer','border-left-color_important','important','','','.b-data-table'),(904387,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(904388,'watch','.b-quantity .qty-box .smaller','border-left-width','2','','','.b-quantity'),(904389,'watch','.b-quantity .qty-box .bigger','border-left-width','2','','','.b-quantity'),(904390,'watch','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(904391,'watch','.w-promotions .prom-multi-discount .promo-range','border-left-width','1','','','.w-promotions'),(904392,'watch','.w-cart-compare .attributes-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(904396,'watch','.testimonials .review','border-left-width','10','3','',''),(904397,'watch','.w-promotions .promo-salemaker .discount','border-left-width','1','','','.w-promotions'),(904398,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-width','1','','','.w-promotions'),(904399,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border-left-width','1','','','.w-promotions'),(904400,'watch','.btn','border-left-width','2','','',''),(904401,'watch','.b-messages .content_management_attach button','border-left-width','1','','','.b-messages'),(904402,'watch','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-width','2','','','.b-messages'),(904403,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-left-width','2','','',''),(904404,'watch','.p-payer-order-confirmation .input-wrapper','border-left-width','2','','','.p-payer-order-confirmation'),(904405,'watch','.p-payer-order-pay .input-wrapper','border-left-width','2','','','.p-payer-order-pay'),(904406,'watch','.w-product-reviews .reviews-list .review','border-left-width','10','3','','.w-product-reviews'),(904407,'watch','.b-quantity .qty-box .smaller','border-left-width','2','','','.b-quantity'),(904408,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(904409,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border-left-width','2','3','','.b-form'),(904410,'watch','.b-quantity .qty-box .smaller','border-left-width','2','','','.b-quantity'),(904411,'watch','.b-info-popup .info-popup div','border-left-width','1','3','','.b-info-popup'),(904412,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-left-width','2','3','','.b-switch'),(904414,'watch','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(904415,'watch','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(904416,'watch','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-left-width','1','','','.b-bottom'),(904417,'watch','.b-quantity .qty-box .smaller','border-left-width','2','','','.b-quantity'),(904418,'watch','.w-socials > li','border-left-width','1','','','.w-socials'),(904420,'watch','.w-cart-compare .cart-cell > div','border-left-width','1','','','.w-cart-compare'),(904421,'watch','.b-info-popup .info-popup div','border-left-width','1','','','.b-info-popup'),(904422,'watch','.b-quantity .qty-box .smaller','border-left-width','2','','','.b-quantity'),(904423,'watch','.b-quantity .qty-box .bigger','border-left-width','2','','','.b-quantity'),(904424,'watch','.w-tabs > .block','border-left-width','1','','','.w-tabs'),(904425,'watch','.w-tabs .tab-a','border-left-width','1','2','','.w-tabs'),(904426,'watch','.w-socials > li','border-left-width','1','','','.w-socials'),(904427,'watch','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(904428,'watch','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(904429,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-left-width','4','','','.b-switch'),(904430,'watch','.b-quantity .qty-box .bigger','border-left-width','2','','','.b-quantity'),(904431,'watch','.w-filters .ui-slider-handle','border-left-width','0','','','.w-filters'),(904432,'watch','.w-filters .ui-slider','border-left-width','0','','','.w-filters'),(904433,'watch','.w-socials > li','border-left-width','1','','','.w-socials'),(904434,'watch','.w-reviews .review','border-left-width','12','3','','.w-reviews'),(904436,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-left-width','3','','','.b-switch'),(904437,'watch','.w-reviews-content .review','border-left-width','12','3','','.w-reviews-content'),(904438,'watch','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(904439,'watch','.w-socials > li','border-left-width','1','','','.w-socials'),(904440,'watch','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(904441,'watch','.b-select-suggest .select2-container .select2-choice','border-left-width','2','','','.b-select-suggest'),(904442,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-left-width','2','4','','.b-switch'),(904444,'watch','.b-form .required-error','border-left-width','1','','','.b-form'),(904445,'watch','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(904446,'watch','.b-quantity .qty-box .bigger','border-left-width','2','','','.b-quantity'),(904447,'watch','textarea','border-left-width','2','','',''),(904448,'watch','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(904449,'watch','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-left-width','1','','','.b-bottom'),(904450,'watch','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(904451,'watch','.w-cart-compare .product-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(904452,'watch','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(904453,'watch','.b-bottom .popup-box','border-left-width','1','','','.b-bottom'),(904454,'watch','.b-quantity .qty-box .bigger','border-left-width','2','','','.b-quantity'),(904455,'watch','.w-product-customers-activity .customers-activity','border-left-width','1','','','.w-product-customers-activity'),(904456,'watch','.b-quantity .qty-box .smaller','border-left-width','2','','','.b-quantity'),(904457,'watch','.w-cart-compare .price-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(904458,'watch','.w-socials > li','border-left-width','1','','','.w-socials'),(904459,'watch','.w-socials > li','border-left-width','1','','','.w-socials'),(904460,'watch','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(904461,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(904462,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-width','1','','','.b-select-suggest'),(904463,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(904464,'watch','.b-select-suggest .select2-container-multi .select2-choices','border-left-width','1','','','.b-select-suggest'),(904465,'watch','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-width','1','','','.b-select-suggest'),(904466,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','border-left-width','0','','','.b-select-suggest'),(904467,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-width','1','','','.b-select-suggest'),(904468,'watch','.b-select-suggest .select2-search input','border-left-width','1','','','.b-select-suggest'),(904469,'watch','.b-select-suggest .select2-drop-active','border-left-width','1','','','.b-select-suggest'),(904470,'watch','.b-select-suggest .select2-drop','border-left-width','1','','','.b-select-suggest'),(904471,'watch','.b-upload-file .upload-file-template','border-left-width','1','','','.b-upload-file'),(904472,'watch','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(904473,'watch','.checkbox input:checked + span','border-left-width','1','','',''),(904474,'watch','.checkbox input + span','border-left-width','1','','',''),(904475,'watch','.b-autocomplete .ui-autocomplete','border-left-width','1','','','.b-autocomplete'),(904478,'watch','.b-quantity .qty-box .bigger','border-left-width','2','','','.b-quantity'),(904479,'watch','.w-checkout-shipping-choice label:first-child span','border-left-width','2','','','.w-checkout-shipping-choice'),(904480,'watch','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(904481,'watch','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(904482,'watch','.w-catalog-listing-look .b2b','border-left-width','1','','','.w-catalog-listing-look'),(904483,'watch','.w-catalog-listing-look .list','border-left-width','1','','','.w-catalog-listing-look'),(904484,'watch','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(904485,'watch','.w-cart-listing .item .gift-wrap label','border-left-width','1','','','.w-cart-listing'),(904486,'watch','.w-cart-listing .item','border-left-width','1','5240','','.w-cart-listing'),(904488,'watch','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(904489,'watch','.w-catalog-listing-look .grid','border-left-width','1','','','.w-catalog-listing-look'),(904490,'watch','.w-filters .ui-slider-range','border-left-width','0','','','.w-filters'),(904491,'watch','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(904492,'watch','.b-upload-files .upload-files','border-left-width','1','','','.b-upload-files'),(904493,'watch','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-width','1','','','.b-compare'),(904494,'watch','.btn-3','border-left-width','2','','',''),(904495,'watch','.b-upload-file .snapshot','border-left-width','1','','','.b-upload-file'),(904496,'watch','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-left-width','2','','','.b-product-images'),(904497,'watch','.b-trade-approval .steps-bar li ~ li a','border-left-width','1','','','.b-trade-approval'),(904498,'watch','.w-account-personal-catalog .list-switcher a','border-left-width','1','2','','.w-account-personal-catalog'),(904499,'watch','.w-catalog-compare .compare .checkbox input:checked + span','border-left-width','1','','','.w-catalog-compare'),(904500,'watch','.w-catalog-compare .cross-box .different-all > div','border-left-width','1','2','','.w-catalog-compare'),(904503,'watch','.catalog-product-wrap .next-product','border-left-width','1','','','.catalog-product-wrap'),(904504,'watch','.catalog-product-wrap .pn-image','border-left-width','2','3','','.catalog-product-wrap'),(904505,'watch','.checkout-index-wrap .input-wrapper','border-left-width','2','','','.checkout-index-wrap'),(904506,'watch','.account-samples .orders-table .item','border-left-width','1','5240','','.account-samples'),(904507,'watch','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(904508,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(904509,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-width','1','','','.b-multi-page-checkout'),(904510,'watch','.b-slick .slick-vertical .slick-slide','border-left-width','1','','','.b-slick'),(904511,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border-left-width','2','','','.b-slick'),(904512,'watch','.w-catalog-paging ','border-left-width','1','2','','.w-catalog-paging'),(904513,'watch','.w-catalog-paging .next','border-left-width','1','','','.w-catalog-paging'),(904514,'watch','.w-catalog-paging .next-pages','border-left-width','1','','','.w-catalog-paging'),(904515,'watch','.w-catalog-paging .page-number','border-left-width','1','','','.w-catalog-paging'),(904516,'watch','.w-catalog-paging .prev','border-left-width','1','','','.w-catalog-paging'),(904517,'watch','.w-catalog-paging .prev-pages','border-left-width','1','','','.w-catalog-paging'),(904518,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-width','1','','','.w-catalog-paging'),(904519,'watch','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(904520,'watch','.b-quantity .qty-box .smaller','border-right-color','$content-border-1','','','.b-quantity'),(904521,'watch','.w-cart-products .checkout-attention-message','border-right-color','$attention-border','','','.w-cart-products'),(904522,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border-right-color','$checkbox-border-1','3','','.b-form'),(904523,'watch','.w-promotions .prom-multi-discount .promo-range','border-right-color','$attention-border','','','.w-promotions'),(904524,'watch','.w-cart-compare .attributes-block td','border-right-color','$content-border-1','','','.w-cart-compare'),(904526,'watch','.testimonials .review','border-right-color','transparent','3','',''),(904527,'watch','.w-promotions .promo-salemaker .discount','border-right-color','$attention-border','','','.w-promotions'),(904528,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-color','$attention-border','','','.w-promotions'),(904529,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border-right-color','$attention-border','','','.w-promotions'),(904530,'watch','.w-cart-compare .cart-cell > div','border-right-color','$content-border-1','','','.w-cart-compare'),(904531,'watch','.w-cart-compare .price-block td','border-right-color','$content-border-1','','','.w-cart-compare'),(904532,'watch','.b-quantity .qty-box .bigger','border-right-color','$content-border-1','','','.b-quantity'),(904533,'watch','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-right-color','$content-border-1','','','.b-bottom'),(904534,'watch','.b-messages .content_management_attach button','border-right-color','$content-border-2','','','.b-messages'),(904535,'watch','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-color','$content-border-1','','','.b-messages'),(904536,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-right-color','$content-border-1','','',''),(904537,'watch','.w-cart-products .checkout-attention-message','border-right-color','$attention-border','','','.w-cart-products'),(904538,'watch','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(904539,'watch','.p-payer-order-confirmation .input-wrapper','border-right-color','$content-border-1','','','.p-payer-order-confirmation'),(904540,'watch','.p-payer-order-pay .input-wrapper','border-right-color','$content-border-1','','','.p-payer-order-pay'),(904541,'watch','.b-upload-file .upload-file-template','border-right-color','$content-border-1','','','.b-upload-file'),(904542,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-right-color','$switch-nc-border-1','','','.b-switch'),(904543,'watch','.b-quantity .qty-box .bigger','border-right-color','$content-border-1','','','.b-quantity'),(904544,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(904545,'watch','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(904546,'watch','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-color','$content-border-1','','','.b-compare'),(904547,'watch','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(904548,'watch','.w-cart-products .checkout-attention-message','border-right-color','$attention-border','','','.w-cart-products'),(904549,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(904550,'watch','.w-checkout-shipping-choice label:last-child span','border-right-color','$content-border-2','','','.w-checkout-shipping-choice'),(904551,'watch','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(904552,'watch','.b-info-popup .info-popup div','border-right-color','$content-border-1','','','.b-info-popup'),(904553,'watch','.b-quantity .qty-box .smaller','border-right-color','$content-border-1','','','.b-quantity'),(904554,'watch','.b-quantity .qty-box .bigger','border-right-color','$content-border-1','','','.b-quantity'),(904555,'watch','.w-cart-compare .product-block td','border-right-color','$content-border-1','','','.w-cart-compare'),(904556,'watch','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(904557,'watch','.w-reviews .review','border-right-color','$transparent','3','','.w-reviews'),(904558,'watch','.w-tabs > .block','border-right-color','$tab-content-border-1','','','.w-tabs'),(904559,'watch','.w-tabs .tab-a','border-right-color','$tab-nav-border-2','2','','.w-tabs'),(904560,'watch','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(904562,'watch','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(904563,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-right-color','$switch-handle-bg-3','','','.b-switch'),(904564,'watch','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(904565,'watch','.btn-3','border-right-color','$btn-border-4','','',''),(904566,'watch','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(904567,'watch','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(904568,'watch','.w-reviews-content .review','border-right-color','$transparent','3','','.w-reviews-content'),(904569,'watch','.b-select-suggest .select2-container .select2-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(904570,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-right-color','$switch-nc-border-1','4','','.b-switch'),(904572,'watch','.w-cart-products .checkout-attention-message','border-right-color','$attention-border','','','.w-cart-products'),(904573,'watch','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(904574,'watch','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-right-color','$content-bg-1','','','.b-bottom'),(904575,'watch','textarea','border-right-color','$content-border-1','','',''),(904576,'watch','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(904577,'watch','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(904578,'watch','.b-bottom .popup-box','border-right-color','$content-border-1','','','.b-bottom'),(904579,'watch','.b-quantity .qty-box .smaller','border-right-color','$content-border-1','','','.b-quantity'),(904580,'watch','.w-product-customers-activity .customers-activity','border-right-color','$content-border-1','','','.w-product-customers-activity'),(904581,'watch','.b-quantity .qty-box .smaller','border-right-color','$content-border-1','','','.b-quantity'),(904582,'watch','.w-product-reviews .reviews-list .review','border-right-color','$transparent','3','','.w-product-reviews'),(904583,'watch','.btn','border-right-color','$btn-border-1','','',''),(904584,'watch','.w-cart-products .checkout-attention-message','border-right-color','$attention-border','','','.w-cart-products'),(904585,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-color','$content-border-1','','','.b-select-suggest'),(904586,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(904587,'watch','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-color','$content-border-1','','','.b-select-suggest'),(904588,'watch','.b-select-suggest .select2-container-multi .select2-choices','border-right-color','$content-border-1','','','.b-select-suggest'),(904589,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(904590,'watch','.b-select-suggest .select2-search input','border-right-color','$content-border-1','','','.b-select-suggest'),(904591,'watch','.b-select-suggest .select2-drop-active','border-right-color','$content-border-1','','','.b-select-suggest'),(904592,'watch','.b-select-suggest .select2-drop','border-right-color','$content-border-1','','','.b-select-suggest'),(904593,'watch','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(904594,'watch','.b-form input.required-error','border-right-color','$attention-border','','','.b-form'),(904595,'watch','.checkbox input:checked + span','border-right-color','$checkbox-border-1','','',''),(904596,'watch','.checkbox input + span','border-right-color','$checkbox-border-1','','',''),(904597,'watch','.b-autocomplete .ui-autocomplete','border-right-color','$content-border-1','','','.b-autocomplete'),(904600,'watch','.b-quantity .qty-box .bigger','border-right-color','$content-border-1','','','.b-quantity'),(904601,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-right-color','$switch-nc-border-1','3','','.b-switch'),(904602,'watch','.b-upload-file .snapshot','border-right-color','$content-border-1','','','.b-upload-file'),(904603,'watch','.w-catalog-listing-look .list','border-right-color','$content-border-1','','','.w-catalog-listing-look'),(904604,'watch','.b-quantity .qty-box .smaller','border-right-color','$content-border-1','','','.b-quantity'),(904605,'watch','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(904606,'watch','.b-upload-files .upload-files','border-right-color','$content-border-1','','','.b-upload-files'),(904607,'watch','.b-form .required-error','border-right-color','$attention-border','','','.b-form'),(904608,'watch','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(904609,'watch','.w-catalog-listing-look .b2b','border-right-color','$content-border-1','','','.w-catalog-listing-look'),(904610,'watch','.w-catalog-listing-look .grid','border-right-color','$content-border-1','','','.w-catalog-listing-look'),(904611,'watch','.w-cart-products .checkout-attention-message','border-right-color','$attention-border','','','.w-cart-products'),(904612,'watch','.w-cart-listing .item .gift-wrap label','border-right-color','#e0e0e0','','','.w-cart-listing'),(904613,'watch','.w-cart-listing .item','border-right-color','#e0e0e0','5240','','.w-cart-listing'),(904614,'watch','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(904616,'watch','.b-data-table table.dataTable.no-footer','border-right-color','$content-border-1','','','.b-data-table'),(904617,'watch','.b-quantity .qty-box .bigger','border-right-color','$content-border-1','','','.b-quantity'),(904618,'watch','.b-quantity .qty-box .smaller','border-right-color','$content-border-1','','','.b-quantity'),(904619,'watch','.b-quantity .qty-box .bigger','border-right-color','$content-border-1','','','.b-quantity'),(904620,'watch','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-right-color','$image-popup-border-1','','','.b-product-images'),(904621,'watch','.w-account-personal-catalog .list-switcher a','border-right-color','$content-border-1','2','','.w-account-personal-catalog'),(904622,'watch','.w-catalog-compare .compare .checkbox input:checked + span','border-right-color','$content-bg-1','','','.w-catalog-compare'),(904623,'watch','.w-catalog-compare .cross-box .different-all > div','border-right-color','$content-border-1','2','','.w-catalog-compare'),(904624,'watch','.w-catalog-compare td:first-child','border-right-color','$content-border-1','','','.w-catalog-compare'),(904627,'watch','.catalog-product-wrap .pn-image','border-right-color','$content-border-1','3','','.catalog-product-wrap'),(904628,'watch','.checkout-index-wrap .input-wrapper','border-right-color','#e0e0e0','','','.checkout-index-wrap'),(904629,'watch','.account-samples .orders-table .item','border-right-color','$content-border-1','5240','','.account-samples'),(904630,'watch','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-color','$highlight-box-border-1','','','.b-multi-page-checkout'),(904631,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-color','$content-border-1','','','.b-multi-page-checkout'),(904632,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-color','$content-border-1','','','.b-multi-page-checkout'),(904633,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border-right-color','$content-border-1','','','.b-slick'),(904634,'watch','.w-catalog-paging ','border-right-color','#CCCCCC','2','','.w-catalog-paging'),(904635,'watch','.w-catalog-paging .next','border-right-color','#CCCCCC','','','.w-catalog-paging'),(904636,'watch','.w-catalog-paging .next-pages','border-right-color','#CCCCCC','','','.w-catalog-paging'),(904637,'watch','.w-catalog-paging .page-number','border-right-color','#CCCCCC','','','.w-catalog-paging'),(904638,'watch','.w-catalog-paging .prev','border-right-color','#CCCCCC','','','.w-catalog-paging'),(904639,'watch','.w-catalog-paging .prev-pages','border-right-color','#CCCCCC','','','.w-catalog-paging'),(904640,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-color','#CCCCCC','','','.w-catalog-paging'),(904641,'watch','.b-data-table table.dataTable.no-footer','border-right-color_important','important','','','.b-data-table'),(904642,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(904643,'watch','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(904644,'watch','.w-promotions .prom-multi-discount .promo-range','border-right-width','1','','','.w-promotions'),(904645,'watch','.w-cart-compare .attributes-block td','border-right-width','1','','','.w-cart-compare'),(904648,'watch','.testimonials .review','border-right-width','10','3','',''),(904649,'watch','.w-promotions .promo-salemaker .discount','border-right-width','1','','','.w-promotions'),(904650,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-width','1','','','.w-promotions'),(904651,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border-right-width','1','','','.w-promotions'),(904652,'watch','.w-cart-compare .cart-cell > div','border-right-width','1','','','.w-cart-compare'),(904653,'watch','.b-quantity .qty-box .smaller','border-right-width','2','','','.b-quantity'),(904654,'watch','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-right-width','1','','','.b-bottom'),(904655,'watch','.b-messages .content_management_attach button','border-right-width','1','','','.b-messages'),(904656,'watch','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-width','2','','','.b-messages'),(904657,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-right-width','2','','',''),(904658,'watch','.w-socials > li','border-right-width','1','','','.w-socials'),(904659,'watch','.p-payer-order-confirmation .input-wrapper','border-right-width','2','','','.p-payer-order-confirmation'),(904660,'watch','.p-payer-order-pay .input-wrapper','border-right-width','2','','','.p-payer-order-pay'),(904661,'watch','.b-quantity .qty-box .smaller','border-right-width','2','','','.b-quantity'),(904662,'watch','.b-quantity .qty-box .smaller','border-right-width','2','','','.b-quantity'),(904663,'watch','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(904664,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(904665,'watch','.b-quantity .qty-box .bigger','border-right-width','2','','','.b-quantity'),(904666,'watch','.b-quantity .qty-box .smaller','border-right-width','2','','','.b-quantity'),(904667,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border-right-width','2','3','','.b-form'),(904668,'watch','.w-socials > li','border-right-width','1','','','.w-socials'),(904669,'watch','.b-quantity .qty-box .bigger','border-right-width','2','','','.b-quantity'),(904670,'watch','.b-quantity .qty-box .bigger','border-right-width','2','','','.b-quantity'),(904671,'watch','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(904672,'watch','.w-socials > li','border-right-width','1','','','.w-socials'),(904675,'watch','.b-info-popup .info-popup div','border-right-width','1','','','.b-info-popup'),(904676,'watch','.w-checkout-shipping-choice label:last-child span','border-right-width','2','','','.w-checkout-shipping-choice'),(904678,'watch','.b-quantity .qty-box .smaller','border-right-width','2','','','.b-quantity'),(904679,'watch','.b-quantity .qty-box .bigger','border-right-width','2','','','.b-quantity'),(904680,'watch','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(904681,'watch','.w-tabs > .block','border-right-width','1','','','.w-tabs'),(904682,'watch','.w-tabs .tab-a','border-right-width','1','2','','.w-tabs'),(904683,'watch','.w-socials > li','border-right-width','1','','','.w-socials'),(904684,'watch','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(904685,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-right-width','4','','','.b-switch'),(904686,'watch','.w-filters .ui-slider-handle','border-right-width','0','','','.w-filters'),(904687,'watch','.w-filters .ui-slider','border-right-width','0','','','.w-filters'),(904688,'watch','.b-quantity .qty-box .bigger','border-right-width','2','','','.b-quantity'),(904689,'watch','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(904690,'watch','.w-socials > li','border-right-width','1','','','.w-socials'),(904691,'watch','.w-reviews .review','border-right-width','12','3','','.w-reviews'),(904692,'watch','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(904693,'watch','.w-product-reviews .reviews-list .review','border-right-width','10','3','','.w-product-reviews'),(904694,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-right-width','3','','','.b-switch'),(904695,'watch','.w-reviews-content .review','border-right-width','12','3','','.w-reviews-content'),(904696,'watch','.w-socials > li','border-right-width','1','','','.w-socials'),(904697,'watch','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(904698,'watch','.b-select-suggest .select2-container .select2-choice','border-right-width','2','','','.b-select-suggest'),(904699,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-right-width','2','4','','.b-switch'),(904701,'watch','.w-cart-compare .product-block td','border-right-width','1','','','.w-cart-compare'),(904702,'watch','.b-form .required-error','border-right-width','1','','','.b-form'),(904703,'watch','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(904704,'watch','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(904705,'watch','textarea','border-right-width','2','','',''),(904706,'watch','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-right-width','1','','','.b-bottom'),(904707,'watch','.b-bottom .popup-box','border-right-width','1','','','.b-bottom'),(904708,'watch','.w-product-customers-activity .customers-activity','border-right-width','1','','','.w-product-customers-activity'),(904709,'watch','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(904710,'watch','.b-quantity .qty-box .bigger','border-right-width','2','','','.b-quantity'),(904711,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(904712,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-width','1','','','.b-select-suggest'),(904713,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(904714,'watch','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-width','1','','','.b-select-suggest'),(904715,'watch','.b-select-suggest .select2-container-multi .select2-choices','border-right-width','1','','','.b-select-suggest'),(904716,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-width','1','','','.b-select-suggest'),(904717,'watch','.b-select-suggest .select2-search input','border-right-width','1','','','.b-select-suggest'),(904718,'watch','.b-select-suggest .select2-drop','border-right-width','1','','','.b-select-suggest'),(904719,'watch','.b-select-suggest .select2-drop-active','border-right-width','1','','','.b-select-suggest'),(904720,'watch','.w-cart-compare .price-block td','border-right-width','1','','','.w-cart-compare'),(904721,'watch','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-width','1','','','.b-compare'),(904722,'watch','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(904723,'watch','.checkbox input:checked + span','border-right-width','1','','',''),(904724,'watch','.checkbox input + span','border-right-width','1','','',''),(904725,'watch','.b-autocomplete .ui-autocomplete','border-right-width','1','','','.b-autocomplete'),(904728,'watch','.b-quantity .qty-box .smaller','border-right-width','2','','','.b-quantity'),(904729,'watch','.b-upload-file .upload-file-template','border-right-width','1','','','.b-upload-file'),(904730,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-right-width','2','3','','.b-switch'),(904731,'watch','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(904732,'watch','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(904733,'watch','.w-catalog-listing-look .b2b','border-right-width','1','','','.w-catalog-listing-look'),(904734,'watch','.w-catalog-listing-look .list','border-right-width','1','','','.w-catalog-listing-look'),(904735,'watch','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(904736,'watch','.w-cart-listing .item .gift-wrap label','border-right-width','1','','','.w-cart-listing'),(904737,'watch','.w-cart-listing .item','border-right-width','1','5240','','.w-cart-listing'),(904739,'watch','.w-catalog-listing-look .grid','border-right-width','1','','','.w-catalog-listing-look'),(904740,'watch','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(904741,'watch','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(904742,'watch','.w-filters .ui-slider-range','border-right-width','0','','','.w-filters'),(904743,'watch','.btn','border-right-width','2','','',''),(904744,'watch','.b-upload-files .upload-files','border-right-width','1','','','.b-upload-files'),(904745,'watch','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(904746,'watch','.btn-3','border-right-width','2','','',''),(904747,'watch','.b-upload-file .snapshot','border-right-width','1','','','.b-upload-file'),(904748,'watch','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-right-width','2','','','.b-product-images'),(904749,'watch','.w-account-personal-catalog .list-switcher a','border-right-width','1','2','','.w-account-personal-catalog'),(904750,'watch','.w-catalog-compare .compare .checkbox input:checked + span','border-right-width','1','','','.w-catalog-compare'),(904751,'watch','.w-catalog-compare td:first-child','border-right-width','1','','','.w-catalog-compare'),(904752,'watch','.w-catalog-compare .cross-box .different-all > div','border-right-width','1','2','','.w-catalog-compare'),(904755,'watch','.catalog-product-wrap .pn-image','border-right-width','2','3','','.catalog-product-wrap'),(904756,'watch','.catalog-product-wrap .prev-product','border-right-width','1','','','.catalog-product-wrap'),(904757,'watch','.checkout-index-wrap .input-wrapper','border-right-width','2','','','.checkout-index-wrap'),(904758,'watch','.account-samples .orders-table .item','border-right-width','1','5240','','.account-samples'),(904759,'watch','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(904760,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(904761,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-width','1','','','.b-multi-page-checkout'),(904762,'watch','.b-slick .slick-vertical .slick-slide','border-right-width','1','','','.b-slick'),(904763,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border-right-width','2','','','.b-slick'),(904764,'watch','.w-catalog-paging ','border-right-width','1','2','','.w-catalog-paging'),(904765,'watch','.w-catalog-paging .next','border-right-width','1','','','.w-catalog-paging'),(904766,'watch','.w-catalog-paging .next-pages','border-right-width','1','','','.w-catalog-paging'),(904767,'watch','.w-catalog-paging .page-number','border-right-width','1','','','.w-catalog-paging'),(904768,'watch','.w-catalog-paging .prev','border-right-width','1','','','.w-catalog-paging'),(904769,'watch','.w-catalog-paging .prev-pages','border-right-width','1','','','.w-catalog-paging'),(904770,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-width','1','','','.w-catalog-paging'),(904771,'watch','.b-select-suggest .select2-drop-active','border-top','none','','','.b-select-suggest'),(904772,'watch','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','border-top','none','','','.order-summary'),(904773,'watch','.order-summary .price-row.ot_gv + .price-row, .order-summary .price-row.ot_coupon + .price-row, .order-summary .price-row.ot_bonus_points + .price-row','border-top','none','','','.order-summary'),(904776,'watch','.catalog-product-wrap .pn-image','border-top','none','5240','','.catalog-product-wrap'),(904777,'watch','.account-samples .orders-table','border-top','none','','','.account-samples'),(904778,'watch','.w-communication-new-topic td','border-top-color','$content-border-1','','','.w-communication-new-topic'),(904779,'watch','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(904780,'watch','.b-quantity .qty-box .smaller','border-top-color','$content-border-1','','','.b-quantity'),(904781,'watch','.order-summary .price-row + .price-row','border-top-color','#e0e0e0','','','.order-summary'),(904782,'watch','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(904783,'watch','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(904784,'watch','.w-promotions .prom-multi-discount .promo-range','border-top-color','$attention-border','','','.w-promotions'),(904785,'watch','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(904786,'watch','.w-cart-compare .attributes-block td','border-top-color','$content-border-1','','','.w-cart-compare'),(904788,'watch','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(904789,'watch','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(904790,'watch','.w-promotions .promo-salemaker .discount','border-top-color','$attention-border','','','.w-promotions'),(904791,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-color','$attention-border','','','.w-promotions'),(904792,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border-top-color','$attention-border','','','.w-promotions'),(904793,'watch','.w-cart-compare .cart-cell > div','border-top-color','$content-border-1','','','.w-cart-compare'),(904794,'watch','.w-cart-products .checkout-attention-message','border-top-color','$attention-border','','','.w-cart-products'),(904795,'watch','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-color','$content-border-1','','','.w-product-bundle'),(904796,'watch','.b-upload-file .upload-file-template','border-top-color','$content-border-1','','','.b-upload-file'),(904797,'watch','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-top-color','$content-border-1','','','.b-bottom'),(904798,'watch','.b-messages .messMenuButtonTop','border-top-color','$content-border-1','','','.b-messages'),(904799,'watch','.b-messages .msv_btn','border-top-color','$content-border-1','','','.b-messages'),(904800,'watch','.b-messages .email-heading','border-top-color','$content-border-1','','','.b-messages'),(904801,'watch','.b-messages .dataTable','border-top-color','$content-border-1','','','.b-messages'),(904802,'watch','.b-messages .messages-menu li + li','border-top-color','$content-border-1','','','.b-messages'),(904803,'watch','.b-messages .content_management_attach button','border-top-color','$content-border-2','','','.b-messages'),(904804,'watch','.b-messages .content_management_attach','border-top-color','$content-border-1','','','.b-messages'),(904805,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-top-color','$content-border-1','','',''),(904806,'watch','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(904807,'watch','.p-payer-order-confirmation .input-wrapper','border-top-color','$content-border-1','','','.p-payer-order-confirmation'),(904808,'watch','.p-payer-order-pay .input-wrapper','border-top-color','$content-border-1','','','.p-payer-order-pay'),(904809,'watch','.b-quantity .qty-box .bigger','border-top-color','$content-border-1','','','.b-quantity'),(904810,'watch','.b-quantity .qty-box .smaller','border-top-color','$content-border-1','','','.b-quantity'),(904811,'watch','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(904812,'watch','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(904813,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-color','$switch-nc-border-1','','','.b-switch'),(904814,'watch','.w-catalog-listing-look .grid','border-top-color','$content-border-1','','','.w-catalog-listing-look'),(904815,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(904816,'watch','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(904817,'watch','.b-quantity .qty-box .smaller','border-top-color','$content-border-1','','','.b-quantity'),(904818,'watch','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(904819,'watch','.b-info div + .info','border-top-color','$content-border-1','','','.b-info'),(904820,'watch','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-color','$content-border-1','','','.b-compare'),(904821,'watch','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-color','$content-border-1','','','.w-product-bundle'),(904822,'watch','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(904823,'watch','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-color','$content-border-1','','','.w-product-in-bundles'),(904824,'watch','.w-cart-products .checkout-attention-message','border-top-color','$attention-border','','','.w-cart-products'),(904825,'watch','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(904826,'watch','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(904827,'watch','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(904828,'watch','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(904829,'watch','.w-checkout-shipping-choice span','border-top-color','$content-border-2','','','.w-checkout-shipping-choice'),(904830,'watch','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(904831,'watch','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(904832,'watch','.b-info-popup .info-popup div','border-top-color','$content-border-1','','','.b-info-popup'),(904833,'watch','.b-quantity .qty-box .smaller','border-top-color','$content-border-1','','','.b-quantity'),(904834,'watch','.b-quantity .qty-box .bigger','border-top-color','$content-border-1','','','.b-quantity'),(904835,'watch','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(904836,'watch','.b-info div + .info','border-top-color','$content-border-1','','','.b-info'),(904837,'watch','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(904838,'watch','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(904839,'watch','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(904840,'watch','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(904841,'watch','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-color','$content-border-1','','','.w-product-bundle'),(904842,'watch','.w-tabs .tab-a','border-top-color','$tab-nav-border-1','2','','.w-tabs'),(904843,'watch','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(904845,'watch','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(904846,'watch','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-color','$content-border-1','','','.w-product-bundle'),(904847,'watch','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(904848,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-color','$switch-handle-bg-3','','','.b-switch'),(904849,'watch','.b-quantity .qty-box .bigger','border-top-color','$content-border-1','','','.b-quantity'),(904850,'watch','.b-info div + .info','border-top-color','$content-border-1','','','.b-info'),(904851,'watch','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-color','$content-border-1','','','.b-messages'),(904852,'watch','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(904853,'watch','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-color','$content-border-1','','','.w-product-in-bundles'),(904854,'watch','.w-reviews .review','border-top-color','$transparent','3','','.w-reviews'),(904855,'watch','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(904856,'watch','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-color','$content-border-1','','','.w-product-in-bundles'),(904857,'watch','.w-reviews-content .review','border-top-color','$transparent','3','','.w-reviews-content'),(904858,'watch','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(904859,'watch','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(904860,'watch','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(904861,'watch','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(904862,'watch','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(904863,'watch','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(904864,'watch','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(904865,'watch','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(904866,'watch','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(904867,'watch','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(904868,'watch','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(904869,'watch','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(904870,'watch','.w-checkout-shipping .sub-item + .sub-item','border-top-color','$content-border-1','','','.w-checkout-shipping'),(904871,'watch','.b-form .required-error','border-top-color','$attention-border','','','.b-form'),(904872,'watch','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(904873,'watch','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(904874,'watch','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(904875,'watch','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(904876,'watch','.b-select-suggest .select2-container .select2-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(904877,'watch','.b-quantity .qty-box .bigger','border-top-color','$content-border-1','','','.b-quantity'),(904878,'watch','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(904879,'watch','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(904880,'watch','textarea','border-top-color','$content-border-1','','',''),(904881,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-color','$switch-nc-border-1','4','','.b-switch'),(904882,'watch','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(904883,'watch','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(904885,'watch','.b-info div + .info','border-top-color','$content-border-1','','','.b-info'),(904886,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border-top-color','$checkbox-border-1','3','','.b-form'),(904887,'watch','.w-cart-products .checkout-attention-message','border-top-color','$attention-border','','','.w-cart-products'),(904888,'watch','.w-cart-products .checkout-attention-message','border-top-color','$attention-border','','','.w-cart-products'),(904889,'watch','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(904890,'watch','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(904891,'watch','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(904892,'watch','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(904893,'watch','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(904894,'watch','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-top-color','$content-bg-1','','','.b-bottom'),(904895,'watch','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-color','$content-border-1','','','.w-product-in-bundles'),(904896,'watch','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(904897,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(904898,'watch','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(904899,'watch','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(904900,'watch','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(904901,'watch','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(904902,'watch','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-color','$content-border-1','','','.w-product-in-bundles'),(904903,'watch','.w-cart-compare .product-block td','border-top-color','$content-border-1','','','.w-cart-compare'),(904904,'watch','.b-bottom .popup-box','border-top-color','$content-border-1','','','.b-bottom'),(904905,'watch','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(904906,'watch','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(904907,'watch','.b-info div + .info','border-top-color','$content-border-1','','','.b-info'),(904908,'watch','.w-product-customers-activity .customers-activity','border-top-color','$content-border-1','','','.w-product-customers-activity'),(904909,'watch','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(904910,'watch','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(904911,'watch','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(904912,'watch','.w-cart-compare .price-block td','border-top-color','$content-border-1','','','.w-cart-compare'),(904913,'watch','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(904914,'watch','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-color','$content-border-1','','','.w-product-in-bundles'),(904915,'watch','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-color','$content-border-1','','','.w-product-bundle'),(904916,'watch','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(904917,'watch','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(904918,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-color','$content-border-1','','','.b-select-suggest'),(904919,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(904920,'watch','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-color','$content-border-1','','','.b-select-suggest'),(904921,'watch','.b-select-suggest .select2-container-multi .select2-choices','border-top-color','$content-border-1','','','.b-select-suggest'),(904922,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(904923,'watch','.b-select-suggest .select2-search input','border-top-color','$content-border-1','','','.b-select-suggest'),(904924,'watch','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-color','$content-border-1','','','.b-select-suggest'),(904925,'watch','.b-select-suggest .select2-drop.select2-drop-above','border-top-color','$content-border-1','','','.b-select-suggest'),(904926,'watch','.b-select-suggest .select2-drop-active','border-top-color','$content-border-1','','','.b-select-suggest'),(904927,'watch','.b-select-suggest .select2-drop','border-top-color','$content-border-1','','','.b-select-suggest'),(904928,'watch','.b-select-suggest .select2-drop-auto-width','border-top-color','$content-border-1','','','.b-select-suggest'),(904929,'watch','.b-quantity .qty-box .smaller','border-top-color','$content-border-1','','','.b-quantity'),(904930,'watch','.b-quantity .qty-box .bigger','border-top-color','$content-border-1','','','.b-quantity'),(904931,'watch','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(904932,'watch','.b-form input.required-error','border-top-color','$attention-border','','','.b-form'),(904933,'watch','.w-communication-post .communication-post','border-top-color','$content-border-1','','','.w-communication-post'),(904934,'watch','.b-products-listing .products-listing .compare','border-top-color','$content-border-1','','','.b-products-listing'),(904935,'watch','.checkbox input:checked + span','border-top-color','$checkbox-border-1','','',''),(904936,'watch','.checkbox input + span','border-top-color','$checkbox-border-1','','',''),(904937,'watch','.b-autocomplete .ui-autocomplete','border-top-color','$content-border-1','','','.b-autocomplete'),(904940,'watch','.b-quantity .qty-box .smaller','border-top-color','$content-border-1','','','.b-quantity'),(904941,'watch','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(904942,'watch','.b-info-popup .info-popup div','border-top-color','$content-border-1','3','','.b-info-popup'),(904943,'watch','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(904944,'watch','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(904945,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-color','$switch-nc-border-1','3','','.b-switch'),(904946,'watch','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(904947,'watch','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(904948,'watch','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(904949,'watch','.btn-3','border-top-color','$btn-border-4','','',''),(904950,'watch','.w-product-reviews .reviews-list .review','border-top-color','$content-border-1','3','','.w-product-reviews'),(904951,'watch','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(904952,'watch','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(904953,'watch','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(904954,'watch','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(904955,'watch','.w-catalog-listing-look .b2b','border-top-color','$content-border-1','','','.w-catalog-listing-look'),(904956,'watch','.w-cart-products .checkout-attention-message','border-top-color','$attention-border','','','.w-cart-products'),(904957,'watch','.w-cart-listing .item .gift-wrap label','border-top-color','#e0e0e0','','','.w-cart-listing'),(904958,'watch','.w-cart-listing .item','border-top-color','#e0e0e0','5240','','.w-cart-listing'),(904960,'watch','.w-catalog-listing-look .list','border-top-color','$content-border-1','','','.w-catalog-listing-look'),(904961,'watch','.w-cart-products .checkout-attention-message','border-top-color','$attention-border','','','.w-cart-products'),(904962,'watch','.btn','border-top-color','$btn-border-1','','',''),(904963,'watch','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(904964,'watch','.b-quantity .qty-box .bigger','border-top-color','$content-border-1','','','.b-quantity'),(904965,'watch','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(904966,'watch','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(904967,'watch','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-color','$content-border-1','','','.w-product-bundle'),(904968,'watch','.b-upload-files .added-file','border-top-color','$content-border-1','','','.b-upload-files'),(904969,'watch','.b-data-table table.dataTable.no-footer','border-top-color','$content-border-1','','','.b-data-table'),(904970,'watch','.b-data-table table.dataTable tbody td','border-top-color','$content-border-1','','','.b-data-table'),(904971,'watch','.b-upload-files .upload-files','border-top-color','$content-border-1','','','.b-upload-files'),(904972,'watch','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(904973,'watch','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(904974,'watch','.b-info div + .info','border-top-color','$content-border-1','','','.b-info'),(904975,'watch','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(904976,'watch','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(904977,'watch','.b-upload-file .snapshot','border-top-color','$content-border-1','','','.b-upload-file'),(904978,'watch','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-top-color','$image-popup-border-1','','','.b-product-images'),(904979,'watch','.w-account-personal-catalog .list-switcher a','border-top-color','$content-border-2','2','','.w-account-personal-catalog'),(904980,'watch','.w-account-subscription .subscription-variant + .subscription-variant','border-top-color','$content-border-1','','','.w-account-subscription'),(904981,'watch','.w-catalog-compare .compare .checkbox input:checked + span','border-top-color','$content-bg-1','','','.w-catalog-compare'),(904982,'watch','.w-catalog-compare .cross-box .different-all > div','border-top-color','$content-border-2','2','','.w-catalog-compare'),(904983,'watch','.w-delivery-day .left-text-left','border-top-color','$content-border-1','','','.w-delivery-day'),(904984,'watch','.w-delivery-day .left-text-right','border-top-color','$content-border-1','','','.w-delivery-day'),(904987,'watch','.catalog-product-wrap .pn-image','border-top-color','$content-border-1','3','','.catalog-product-wrap'),(904988,'watch','.checkout-index-wrap .input-wrapper','border-top-color','#e0e0e0','','','.checkout-index-wrap'),(904989,'watch','.account-samples .orders-table .item','border-top-color','$content-border-1','5240','','.account-samples'),(904990,'watch','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-color','$highlight-box-border-1','','','.b-multi-page-checkout'),(904991,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-color','$content-border-1','','','.b-multi-page-checkout'),(904992,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-color','$content-border-1','','','.b-multi-page-checkout'),(904994,'watch','.w-account-customer-additional-field .tf-file','border-top-color','$content-border-1','','','.w-account-customer-additional-field'),(904995,'watch','.testimonials .review','border-top-color','$content-bg-2','3','',''),(904996,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-color','$content-border-1','','','.b-slick'),(904997,'watch','.w-catalog-paging ','border-top-color','#CCCCCC','2','','.w-catalog-paging'),(904998,'watch','.w-catalog-paging .next','border-top-color','#CCCCCC','','','.w-catalog-paging'),(904999,'watch','.w-catalog-paging .next-pages','border-top-color','#CCCCCC','','','.w-catalog-paging'),(905000,'watch','.w-catalog-paging .page-number','border-top-color','#CCCCCC','','','.w-catalog-paging'),(905001,'watch','.w-catalog-paging .prev','border-top-color','#CCCCCC','','','.w-catalog-paging'),(905002,'watch','.w-catalog-paging .prev-pages','border-top-color','#CCCCCC','','','.w-catalog-paging'),(905003,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-color','#CCCCCC','','','.w-catalog-paging'),(905004,'watch','.b-data-table table.dataTable.no-footer','border-top-color_important','important','','','.b-data-table'),(905005,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-top-left-radius','0','4','','.b-switch'),(905006,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.p-quick-order-index'),(905007,'watch','.w-promotions .prom-multi-discount .promo-range','border-top-left-radius','12','','','.w-promotions'),(905008,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.p-quick-order-index'),(905009,'watch','.w-promotions .promo-salemaker .discount','border-top-left-radius','12','','','.w-promotions'),(905010,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-left-radius','12','','','.w-promotions'),(905011,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border-top-left-radius','12','','','.w-promotions'),(905012,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-left-radius','5','','','.b-messages'),(905013,'watch','.b-fancybox .fancybox-close','border-top-left-radius','50','','','.b-fancybox'),(905014,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-left-radius','25','','','.b-switch'),(905015,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-top-left-radius','0','3','','.b-switch'),(905016,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-left-radius','15','3','','.b-switch'),(905017,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(905018,'watch','.b-switch .bootstrap-switch','border-top-left-radius','14','','','.b-switch'),(905019,'watch','.b-switch .candlestick-wrapper .candlestick-bg','border-top-left-radius','15','','','.b-switch'),(905020,'watch','.w-checkout-shipping-choice label:first-child span','border-top-left-radius','16','','','.w-checkout-shipping-choice'),(905021,'watch','.w-checkout-shipping-choice label:last-child span','border-top-left-radius','0','','','.w-checkout-shipping-choice'),(905022,'watch','.btn-2','border-top-left-radius','24','','',''),(905023,'watch','.btn-1','border-top-left-radius','20','','',''),(905024,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-left-radius','25','','','.b-switch'),(905025,'watch','.btn-3','border-top-left-radius','24','','',''),(905026,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border-top-left-radius','50','3','','.b-form'),(905027,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-top-left-radius','50','3','','.b-switch'),(905028,'watch','.b-fancybox .fancybox-title-float-wrap .child','border-top-left-radius','15','','','.b-fancybox'),(905029,'watch','.b-fancybox .fancybox-skin','border-top-left-radius','4','','','.b-fancybox'),(905030,'watch','.w-personal-gift-status-bar .progress-bar','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(905031,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-left-radius','15','4','','.b-switch'),(905032,'watch','.btn','border-top-left-radius','20','','',''),(905033,'watch','.w-personal-gift-status-bar .progress-bar-content','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(905034,'watch','.b-fancybox .fancybox-nav span','border-top-left-radius','50','','','.b-fancybox'),(905035,'watch','.w-product-customers-activity .close','border-top-left-radius','50','','','.w-product-customers-activity'),(905036,'watch','.w-product-customers-activity .customers-activity','border-top-left-radius','10','','','.w-product-customers-activity'),(905037,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.b-data-table'),(905038,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.b-data-table'),(905039,'watch','.b-products-listing .promos-info .promo-name','border-top-left-radius','0','','','.b-products-listing'),(905040,'watch','.b-upload-file .snapshot','border-top-left-radius','50','','','.b-upload-file'),(905041,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(905042,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-top-left-radius','0','','','.b-product-images'),(905043,'watch','.b-trade-approval .steps-bar','border-top-left-radius','18','','','.b-trade-approval'),(905044,'watch','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-left-radius','3','','','.w-delivery-day'),(905045,'watch','.w-delivery-day .left-count','border-top-left-radius','3','','','.w-delivery-day'),(905047,'watch','.catalog-product-wrap .pn-image','border-top-left-radius','50','3','','.catalog-product-wrap'),(905048,'watch','.b-slick .slick-dots li','border-top-left-radius','50','3','','.b-slick'),(905049,'watch','.success-page .w-cart-listing .qty','border-top-left-radius','50','','','.success-page'),(905050,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-left-radius','50','','','.b-multi-page-checkout'),(905051,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-left-radius','50','3','','.b-multi-page-checkout'),(905052,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-left-radius','50','','','.b-slick'),(905053,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-left-radius','0','','','.w-catalog-paging'),(905054,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-top-right-radius','0','4','','.b-switch'),(905055,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.p-quick-order-index'),(905056,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.p-quick-order-index'),(905057,'watch','.w-promotions .prom-multi-discount .promo-range','border-top-right-radius','12','','','.w-promotions'),(905058,'watch','.w-promotions .promo-salemaker .discount','border-top-right-radius','12','','','.w-promotions'),(905059,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-right-radius','12','','','.w-promotions'),(905060,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border-top-right-radius','12','','','.w-promotions'),(905061,'watch','.b-upload-file .snapshot','border-top-right-radius','50','','','.b-upload-file'),(905062,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-right-radius','5','','','.b-messages'),(905063,'watch','.w-personal-gift-status-bar .progress-bar','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(905064,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border-top-right-radius','50','3','','.b-form'),(905065,'watch','.b-fancybox .fancybox-close','border-top-right-radius','50','','','.b-fancybox'),(905066,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-right-radius','25','','','.b-switch'),(905067,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-top-right-radius','0','3','','.b-switch'),(905068,'watch','.b-switch .bootstrap-switch','border-top-right-radius','14','','','.b-switch'),(905069,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-right-radius','15','3','','.b-switch'),(905070,'watch','.b-switch .candlestick-wrapper .candlestick-bg','border-top-right-radius','15','','','.b-switch'),(905071,'watch','.w-checkout-shipping-choice label:last-child span','border-top-right-radius','16','','','.w-checkout-shipping-choice'),(905072,'watch','.w-checkout-shipping-choice label:first-child span','border-top-right-radius','0','','','.w-checkout-shipping-choice'),(905073,'watch','.btn-1','border-top-right-radius','20','','',''),(905074,'watch','.btn-2','border-top-right-radius','24','','',''),(905075,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-right-radius','25','','','.b-switch'),(905076,'watch','.btn-3','border-top-right-radius','24','','',''),(905077,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-top-right-radius','50','3','','.b-switch'),(905078,'watch','.b-fancybox .fancybox-title-float-wrap .child','border-top-right-radius','15','','','.b-fancybox'),(905079,'watch','.b-fancybox .fancybox-skin','border-top-right-radius','4','','','.b-fancybox'),(905080,'watch','.btn','border-top-right-radius','20','','',''),(905081,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-right-radius','15','4','','.b-switch'),(905082,'watch','.b-fancybox .fancybox-nav span','border-top-right-radius','50','','','.b-fancybox'),(905083,'watch','.w-product-customers-activity .close','border-top-right-radius','50','','','.w-product-customers-activity'),(905084,'watch','.w-product-customers-activity .customers-activity','border-top-right-radius','10','','','.w-product-customers-activity'),(905085,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.b-data-table'),(905086,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.b-data-table'),(905087,'watch','.b-products-listing .promos-info .promo-name','border-top-right-radius','8','','','.b-products-listing'),(905088,'watch','.w-personal-gift-status-bar .progress-bar-content','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(905089,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(905090,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(905091,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-top-right-radius','0','','','.b-product-images'),(905092,'watch','.b-trade-approval .steps-bar','border-top-right-radius','18','','','.b-trade-approval'),(905093,'watch','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-right-radius','3','','','.w-delivery-day'),(905094,'watch','.w-delivery-day .left-count','border-top-right-radius','3','','','.w-delivery-day'),(905096,'watch','.catalog-product-wrap .pn-image','border-top-right-radius','50','3','','.catalog-product-wrap'),(905097,'watch','.b-slick .slick-dots li','border-top-right-radius','50','3','','.b-slick'),(905098,'watch','.success-page .w-cart-listing .qty','border-top-right-radius','50','','','.success-page'),(905099,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-right-radius','50','','','.b-multi-page-checkout'),(905100,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-right-radius','50','3','','.b-multi-page-checkout'),(905101,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-right-radius','50','','','.b-slick'),(905102,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-right-radius','0','','','.w-catalog-paging'),(905103,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(905104,'watch','.w-communication-new-topic td','border-top-width','1','','','.w-communication-new-topic'),(905105,'watch','.b-info div + .info','border-top-width','1','','','.b-info'),(905106,'watch','.b-quantity .qty-box .bigger','border-top-width','2','','','.b-quantity'),(905107,'watch','.w-promotions .prom-multi-discount .promo-range','border-top-width','1','','','.w-promotions'),(905111,'watch','.w-cart-compare .attributes-block td','border-top-width','1','','','.w-cart-compare'),(905114,'watch','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(905115,'watch','.b-email .qty','border-top-width','1','','','.b-email'),(905116,'watch','.b-email .name','border-top-width','1','','','.b-email'),(905117,'watch','.b-email .totals-table','border-top-width','1','','','.b-email'),(905118,'watch','.testimonials .review','border-top-width','7','3','',''),(905119,'watch','.w-promotions .promo-salemaker .discount','border-top-width','1','','','.w-promotions'),(905120,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-width','1','','','.w-promotions'),(905121,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border-top-width','1','','','.w-promotions'),(905122,'watch','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(905123,'watch','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(905124,'watch','.b-messages .messMenuButtonTop','border-top-width','1','','','.b-messages'),(905125,'watch','.b-messages .msv_btn','border-top-width','1','','','.b-messages'),(905126,'watch','.b-messages .email-heading','border-top-width','1','','','.b-messages'),(905127,'watch','.b-messages .dataTable','border-top-width','1','','','.b-messages'),(905128,'watch','.b-messages .messages-menu li + li','border-top-width','1','','','.b-messages'),(905129,'watch','.b-messages .content_management_attach button','border-top-width','1','','','.b-messages'),(905130,'watch','.b-messages .content_management_attach','border-top-width','1','','','.b-messages'),(905131,'watch','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-width','2','','','.b-messages'),(905132,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-top-width','2','','',''),(905133,'watch','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(905134,'watch','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(905135,'watch','.b-quantity .qty-box .bigger','border-top-width','2','','','.b-quantity'),(905136,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border-top-width','2','3','','.b-form'),(905137,'watch','.w-socials > li','border-top-width','1','','','.w-socials'),(905138,'watch','.p-payer-order-confirmation .input-wrapper','border-top-width','2','','','.p-payer-order-confirmation'),(905139,'watch','.p-payer-order-pay .input-wrapper','border-top-width','2','','','.p-payer-order-pay'),(905140,'watch','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(905141,'watch','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(905142,'watch','.b-quantity .qty-box .smaller','border-top-width','2','','','.b-quantity'),(905143,'watch','.b-email .price','border-top-width','1','','','.b-email'),(905144,'watch','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(905145,'watch','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(905146,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(905147,'watch','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(905148,'watch','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(905149,'watch','.b-info div + .info','border-top-width','1','','','.b-info'),(905150,'watch','.b-email .model','border-top-width','1','','','.b-email'),(905151,'watch','.b-info div + .info','border-top-width','1','','','.b-info'),(905152,'watch','.b-email .model','border-top-width','1','','','.b-email'),(905153,'watch','.b-email .price','border-top-width','1','','','.b-email'),(905154,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-width','2','3','','.b-switch'),(905155,'watch','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(905156,'watch','.w-filters .ui-slider','border-top-width','0','','','.w-filters'),(905157,'watch','.w-filters .ui-slider-handle','border-top-width','0','','','.w-filters'),(905158,'watch','.b-email .name','border-top-width','1','','','.b-email'),(905159,'watch','.b-email .qty','border-top-width','1','','','.b-email'),(905160,'watch','.b-email .totals-table','border-top-width','1','','','.b-email'),(905161,'watch','.w-checkout-shipping-choice span','border-top-width','2','','','.w-checkout-shipping-choice'),(905162,'watch','.w-socials > li','border-top-width','1','','','.w-socials'),(905164,'watch','.w-cart-compare .product-block td','border-top-width','1','','','.w-cart-compare'),(905165,'watch','.b-info-popup .info-popup div','border-top-width','1','','','.b-info-popup'),(905166,'watch','.b-quantity .qty-box .smaller','border-top-width','2','','','.b-quantity'),(905167,'watch','.b-quantity .qty-box .bigger','border-top-width','2','','','.b-quantity'),(905168,'watch','.b-quantity .qty-box .bigger','border-top-width','2','','','.b-quantity'),(905169,'watch','.b-email .qty','border-top-width','1','','','.b-email'),(905170,'watch','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-bundle'),(905171,'watch','.w-tabs .tab-a','border-top-width','3','2','','.w-tabs'),(905172,'watch','.w-socials > li','border-top-width','1','','','.w-socials'),(905173,'watch','.b-bottom .popup-buttons','border-top-width','1','','','.b-bottom'),(905174,'watch','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(905175,'watch','.totals-line','border-top-width','1','','',''),(905176,'watch','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-bundle'),(905177,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-width','4','','','.b-switch'),(905178,'watch','.b-email .name','border-top-width','1','','','.b-email'),(905179,'watch','.b-email .totals-table','border-top-width','1','','','.b-email'),(905180,'watch','.b-email .name','border-top-width','1','','','.b-email'),(905181,'watch','.order-summary .price-row + .price-row','border-top-width','1','','','.order-summary'),(905182,'watch','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(905183,'watch','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-bundle'),(905184,'watch','.w-reviews .review','border-top-width','8','3','','.w-reviews'),(905185,'watch','.b-quantity .qty-box .smaller','border-top-width','2','','','.b-quantity'),(905186,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-width','3','','','.b-switch'),(905187,'watch','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(905188,'watch','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(905189,'watch','.b-email .image','border-top-width','1','','','.b-email'),(905190,'watch','.b-email .image','border-top-width','1','','','.b-email'),(905191,'watch','.b-email .model','border-top-width','1','','','.b-email'),(905192,'watch','.w-socials > li','border-top-width','1','','','.w-socials'),(905193,'watch','.btn','border-top-width','2','','',''),(905194,'watch','.b-email .image','border-top-width','1','','','.b-email'),(905195,'watch','.b-email .price','border-top-width','1','','','.b-email'),(905196,'watch','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(905197,'watch','.b-email .name','border-top-width','1','','','.b-email'),(905198,'watch','.b-email .qty','border-top-width','1','','','.b-email'),(905199,'watch','.b-email .model','border-top-width','1','','','.b-email'),(905200,'watch','.b-email .totals-table','border-top-width','1','','','.b-email'),(905201,'watch','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(905202,'watch','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(905203,'watch','.b-form .shipping-method .item + .item','border-top-width','1','','','.b-form'),(905204,'watch','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(905205,'watch','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(905206,'watch','.b-select-suggest .select2-container .select2-choice','border-top-width','2','','','.b-select-suggest'),(905207,'watch','.view-all','border-top-width','1','3','',''),(905208,'watch','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(905209,'watch','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(905210,'watch','textarea','border-top-width','2','','',''),(905211,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-width','2','4','','.b-switch'),(905212,'watch','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(905213,'watch','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(905215,'watch','.w-cart-compare .cart-cell > div','border-top-width','1','','','.w-cart-compare'),(905216,'watch','.b-info div + .info','border-top-width','1','','','.b-info'),(905217,'watch','.b-form .form-buttons','border-top-width','1','','','.b-form'),(905218,'watch','.b-form .required-error','border-top-width','1','','','.b-form'),(905219,'watch','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(905220,'watch','.b-info div + .info','border-top-width','1','','','.b-info'),(905221,'watch','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(905222,'watch','.b-email .totals-table','border-top-width','1','','','.b-email'),(905223,'watch','.b-email .model','border-top-width','1','','','.b-email'),(905224,'watch','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-top-width','1','','','.b-bottom'),(905225,'watch','.b-email .model','border-top-width','1','','','.b-email'),(905226,'watch','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(905227,'watch','.b-upload-files .upload-files','border-top-width','1','','','.b-upload-files'),(905228,'watch','.b-upload-files .added-file','border-top-width','1','','','.b-upload-files'),(905229,'watch','.b-bottom .popup-box','border-top-width','1','','','.b-bottom'),(905230,'watch','.b-email .image','border-top-width','1','','','.b-email'),(905231,'watch','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(905232,'watch','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(905233,'watch','.b-quantity .qty-box .smaller','border-top-width','2','','','.b-quantity'),(905234,'watch','.w-product-customers-activity .customers-activity','border-top-width','1','','','.w-product-customers-activity'),(905235,'watch','.b-form .privacy-row','border-top-width','1','','','.b-form'),(905236,'watch','.b-quantity .qty-box .bigger','border-top-width','2','','','.b-quantity'),(905237,'watch','.w-reviews-content .review','border-top-width','8','3','','.w-reviews-content'),(905238,'watch','.w-cart-compare .price-block td','border-top-width','1','','','.w-cart-compare'),(905239,'watch','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(905240,'watch','.w-socials > li','border-top-width','1','','','.w-socials'),(905241,'watch','.b-quantity .qty-box .smaller','border-top-width','2','','','.b-quantity'),(905242,'watch','.w-product-reviews .reviews-list .review','border-top-width','7','3','','.w-product-reviews'),(905243,'watch','.b-upload-file .upload-file-template','border-top-width','1','','','.b-upload-file'),(905244,'watch','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(905245,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(905246,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-width','1','','','.b-select-suggest'),(905247,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(905248,'watch','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-width','1','','','.b-select-suggest'),(905249,'watch','.b-select-suggest .select2-container-multi .select2-choices','border-top-width','1','','','.b-select-suggest'),(905250,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-width','1','','','.b-select-suggest'),(905251,'watch','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-bundle'),(905252,'watch','.b-select-suggest .select2-search input','border-top-width','1','','','.b-select-suggest'),(905253,'watch','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-width','1','','','.b-select-suggest'),(905254,'watch','.b-select-suggest .select2-drop.select2-drop-above','border-top-width','1','','','.b-select-suggest'),(905255,'watch','.b-select-suggest .select2-drop-active','border-top-width','1','','','.b-select-suggest'),(905256,'watch','.b-select-suggest .select2-drop-auto-width','border-top-width','1','','','.b-select-suggest'),(905257,'watch','.w-socials > li','border-top-width','1','','','.w-socials'),(905258,'watch','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-bundle'),(905259,'watch','.b-quantity .qty-box .smaller','border-top-width','2','','','.b-quantity'),(905260,'watch','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(905262,'watch','.b-form .payment-method .item + .item','border-top-width','1','','','.b-form'),(905263,'watch','.w-product-bundle .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-bundle'),(905264,'watch','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(905265,'watch','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(905266,'watch','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(905267,'watch','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-top-width','1','','','.b-bottom'),(905268,'watch','.w-communication-post .communication-post','border-top-width','1','','','.w-communication-post'),(905269,'watch','.b-products-listing .products-listing .compare','border-top-width','1','','','.b-products-listing'),(905270,'watch','.checkbox input:checked + span','border-top-width','1','','',''),(905271,'watch','.checkbox input + span','border-top-width','1','','',''),(905272,'watch','.b-autocomplete .ui-autocomplete','border-top-width','1','','','.b-autocomplete'),(905275,'watch','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(905276,'watch','.b-info-popup .info-popup div','border-top-width','1','3','','.b-info-popup'),(905277,'watch','.b-info div + .info','border-top-width','1','','','.b-info'),(905278,'watch','.b-email .price','border-top-width','1','','','.b-email'),(905279,'watch','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(905280,'watch','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(905281,'watch','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(905282,'watch','.b-email .image','border-top-width','1','','','.b-email'),(905283,'watch','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(905284,'watch','.b-email .price','border-top-width','1','','','.b-email'),(905285,'watch','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(905286,'watch','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(905287,'watch','.w-checkout-shipping .sub-item + .sub-item','border-top-width','1','','','.w-checkout-shipping'),(905288,'watch','.w-product-in-bundles .bundle_row + .bundle_row .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(905289,'watch','.w-catalog-listing-look .b2b','border-top-width','1','','','.w-catalog-listing-look'),(905290,'watch','.w-catalog-listing-look .list','border-top-width','1','','','.w-catalog-listing-look'),(905291,'watch','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(905292,'watch','.w-cart-listing .item .gift-wrap label','border-top-width','1','','','.w-cart-listing'),(905293,'watch','.w-cart-listing .item','border-top-width','1','5240','','.w-cart-listing'),(905295,'watch','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(905296,'watch','.b-email .image','border-top-width','1','','','.b-email'),(905297,'watch','.b-email .price','border-top-width','1','','','.b-email'),(905298,'watch','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(905299,'watch','.w-catalog-listing-look .grid','border-top-width','1','','','.w-catalog-listing-look'),(905300,'watch','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(905301,'watch','.w-filters .ui-slider-range','border-top-width','0','','','.w-filters'),(905302,'watch','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(905303,'watch','.b-email .qty','border-top-width','1','','','.b-email'),(905304,'watch','.b-email .name','border-top-width','1','','','.b-email'),(905305,'watch','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(905306,'watch','.b-quantity .qty-box .bigger','border-top-width','2','','','.b-quantity'),(905307,'watch','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(905308,'watch','.b-data-table table.dataTable tbody td','border-top-width','1','','','.b-data-table'),(905309,'watch','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-width','1','','','.b-compare'),(905310,'watch','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(905311,'watch','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(905312,'watch','.btn-3','border-top-width','2','','',''),(905313,'watch','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(905314,'watch','.b-email .totals-table','border-top-width','1','','','.b-email'),(905315,'watch','.b-email .qty','border-top-width','1','','','.b-email'),(905316,'watch','.b-upload-file .snapshot','border-top-width','1','','','.b-upload-file'),(905317,'watch','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-top-width','2','','','.b-product-images'),(905318,'watch','.w-account-personal-catalog .list-switcher a','border-top-width','3','2','','.w-account-personal-catalog'),(905319,'watch','.w-account-subscription .subscription-variant + .subscription-variant','border-top-width','1','','','.w-account-subscription'),(905320,'watch','.w-catalog-compare .compare .checkbox input:checked + span','border-top-width','1','','','.w-catalog-compare'),(905321,'watch','.w-catalog-compare .cross-box .different-all > div','border-top-width','3','2','','.w-catalog-compare'),(905322,'watch','.w-delivery-day .left-text-left','border-top-width','2','','','.w-delivery-day'),(905323,'watch','.w-delivery-day .left-text-right','border-top-width','2','','','.w-delivery-day'),(905329,'watch','.catalog-product-wrap .pn-image','border-top-width','2','3','','.catalog-product-wrap'),(905330,'watch','.catalog-product-wrap .pn-image','border-top-width','1','','','.catalog-product-wrap'),(905331,'watch','.catalog-product-wrap .pn-name','border-top-width','1','','','.catalog-product-wrap'),(905332,'watch','.catalog-product-wrap .prev-next-product','border-top-width','1','','','.catalog-product-wrap'),(905333,'watch','.checkout-index-wrap .input-wrapper','border-top-width','2','','','.checkout-index-wrap'),(905334,'watch','.account-samples .orders-table .item','border-top-width','1','5240','','.account-samples'),(905335,'watch','.account-samples .orders-table .td-alignright','border-top-width','1','5240','','.account-samples'),(905336,'watch','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(905337,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-content','border-top-width','1','','','.b-multi-page-checkout'),(905338,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(905339,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-width','1','','','.b-multi-page-checkout'),(905341,'watch','.w-account-customer-additional-field .tf-file','border-top-width','1','','','.w-account-customer-additional-field'),(905342,'watch','.b-slick .slick-vertical .slick-slide','border-top-width','1','','','.b-slick'),(905343,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-width','2','','','.b-slick'),(905344,'watch','.w-catalog-paging ','border-top-width','1','2','','.w-catalog-paging'),(905345,'watch','.w-catalog-paging .next','border-top-width','1','','','.w-catalog-paging'),(905346,'watch','.w-catalog-paging .next-pages','border-top-width','1','','','.w-catalog-paging'),(905347,'watch','.w-catalog-paging .page-number','border-top-width','1','','','.w-catalog-paging'),(905348,'watch','.w-catalog-paging .prev','border-top-width','1','','','.w-catalog-paging'),(905349,'watch','.w-catalog-paging .prev-pages','border-top-width','1','','','.w-catalog-paging'),(905350,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-width','1','','','.w-catalog-paging'),(905351,'watch','.b-autocomplete .ui-autocomplete li','border_important','important','','','.b-autocomplete'),(905352,'watch','.b-data-table table.dataTable thead td','border_important','important','','','.b-data-table'),(905353,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_1_measure','px','4','','.b-switch'),(905354,'watch','.w-personal-gift-status-bar .progress-bar-content','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(905355,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.p-quick-order-index'),(905356,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.p-quick-order-index'),(905357,'watch','.w-promotions .prom-multi-discount .promo-range','border_radius_1_measure','px','','','.w-promotions'),(905358,'watch','.w-promotions .promo-salemaker .discount','border_radius_1_measure','px','','','.w-promotions'),(905359,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_1_measure','px','','','.w-promotions'),(905360,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_1_measure','px','','','.w-promotions'),(905361,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_1_measure','px','','','.b-messages'),(905362,'watch','.b-fancybox .fancybox-close','border_radius_1_measure','%','','','.b-fancybox'),(905363,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_1_measure','px','','','.b-switch'),(905364,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_1_measure','px','3','','.b-switch'),(905365,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_1_measure','px','3','','.b-switch'),(905366,'watch','.b-switch .bootstrap-switch','border_radius_1_measure','px','','','.b-switch'),(905367,'watch','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_1_measure','px','','','.b-switch'),(905368,'watch','.w-checkout-shipping-choice label:last-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(905369,'watch','.w-checkout-shipping-choice label:first-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(905370,'watch','.w-personal-gift-status-bar .progress-bar','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(905371,'watch','.btn-1','border_radius_1_measure','px','','',''),(905372,'watch','.btn-2','border_radius_1_measure','px','','',''),(905373,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_1_measure','px','','','.b-switch'),(905374,'watch','.btn-3','border_radius_1_measure','px','','',''),(905375,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_1_measure','%','3','','.b-switch'),(905376,'watch','.b-fancybox .fancybox-title-float-wrap .child','border_radius_1_measure','px','','','.b-fancybox'),(905377,'watch','.b-fancybox .fancybox-skin','border_radius_1_measure','px','','','.b-fancybox'),(905378,'watch','.btn','border_radius_1_measure','px','','',''),(905379,'watch','.b-fancybox .fancybox-nav span','border_radius_1_measure','%','','','.b-fancybox'),(905380,'watch','.w-product-customers-activity .close','border_radius_1_measure','%','','','.w-product-customers-activity'),(905381,'watch','.w-product-customers-activity .customers-activity','border_radius_1_measure','px','','','.w-product-customers-activity'),(905382,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_1_measure','px','4','','.b-switch'),(905383,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.b-data-table'),(905384,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.b-data-table'),(905385,'watch','.b-products-listing .promos-info .promo-name','border_radius_1_measure','px','','','.b-products-listing'),(905386,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(905387,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_1_measure','%','3','','.b-form'),(905388,'watch','.b-upload-file .snapshot','border_radius_1_measure','%','','','.b-upload-file'),(905389,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(905390,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_1_measure','px','','','.b-product-images'),(905391,'watch','.b-trade-approval .steps-bar','border_radius_1_measure','px','','','.b-trade-approval'),(905392,'watch','.w-delivery-day .left-count','border_radius_1_measure','px','','','.w-delivery-day'),(905393,'watch','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_1_measure','px','','','.w-delivery-day'),(905395,'watch','.catalog-product-wrap .pn-image','border_radius_1_measure','%','3','','.catalog-product-wrap'),(905396,'watch','.b-slick .slick-dots li','border_radius_1_measure','%','3','','.b-slick'),(905397,'watch','.success-page .w-cart-listing .qty','border_radius_1_measure','%','','','.success-page'),(905398,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_1_measure','%','','','.b-multi-page-checkout'),(905399,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_1_measure','%','3','','.b-multi-page-checkout'),(905400,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_1_measure','%','','','.b-slick'),(905401,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_1_measure','px','','','.w-catalog-paging'),(905402,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_2_measure','px','4','','.b-switch'),(905403,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_2_measure','px','','','.b-switch'),(905404,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.p-quick-order-index'),(905405,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.p-quick-order-index'),(905406,'watch','.w-promotions .prom-multi-discount .promo-range','border_radius_2_measure','px','','','.w-promotions'),(905407,'watch','.w-promotions .promo-salemaker .discount','border_radius_2_measure','px','','','.w-promotions'),(905408,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_2_measure','px','','','.w-promotions'),(905409,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_2_measure','px','','','.w-promotions'),(905410,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_2_measure','px','4','','.b-switch'),(905411,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_2_measure','px','','','.b-messages'),(905412,'watch','.b-fancybox .fancybox-close','border_radius_2_measure','%','','','.b-fancybox'),(905413,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_2_measure','px','','','.b-switch'),(905414,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_2_measure','px','3','','.b-switch'),(905415,'watch','.b-switch .bootstrap-switch','border_radius_2_measure','px','','','.b-switch'),(905416,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_2_measure','px','3','','.b-switch'),(905417,'watch','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_2_measure','px','','','.b-switch'),(905418,'watch','.w-checkout-shipping-choice label:last-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(905419,'watch','.w-checkout-shipping-choice label:first-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(905420,'watch','.btn-2','border_radius_2_measure','px','','',''),(905421,'watch','.btn-3','border_radius_2_measure','px','','',''),(905422,'watch','.w-personal-gift-status-bar .progress-bar-content','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(905423,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_2_measure','%','3','','.b-switch'),(905424,'watch','.b-fancybox .fancybox-title-float-wrap .child','border_radius_2_measure','px','','','.b-fancybox'),(905425,'watch','.b-fancybox .fancybox-skin','border_radius_2_measure','px','','','.b-fancybox'),(905426,'watch','.b-upload-file .snapshot','border_radius_2_measure','%','','','.b-upload-file'),(905427,'watch','.btn','border_radius_2_measure','px','','',''),(905428,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_2_measure','%','3','','.b-form'),(905429,'watch','.b-fancybox .fancybox-nav span','border_radius_2_measure','%','','','.b-fancybox'),(905430,'watch','.w-product-customers-activity .close','border_radius_2_measure','%','','','.w-product-customers-activity'),(905431,'watch','.w-product-customers-activity .customers-activity','border_radius_2_measure','px','','','.w-product-customers-activity'),(905432,'watch','.w-personal-gift-status-bar .progress-bar','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(905433,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.b-data-table'),(905434,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.b-data-table'),(905435,'watch','.b-products-listing .promos-info .promo-name','border_radius_2_measure','px','','','.b-products-listing'),(905436,'watch','.btn-1','border_radius_2_measure','px','','',''),(905437,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(905438,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(905439,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_2_measure','px','','','.b-product-images'),(905440,'watch','.b-trade-approval .steps-bar','border_radius_2_measure','px','','','.b-trade-approval'),(905441,'watch','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_2_measure','px','','','.w-delivery-day'),(905442,'watch','.w-delivery-day .left-count','border_radius_2_measure','px','','','.w-delivery-day'),(905444,'watch','.catalog-product-wrap .pn-image','border_radius_2_measure','%','3','','.catalog-product-wrap'),(905445,'watch','.b-slick .slick-dots li','border_radius_2_measure','%','3','','.b-slick'),(905446,'watch','.success-page .w-cart-listing .qty','border_radius_2_measure','%','','','.success-page'),(905447,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_2_measure','%','','','.b-multi-page-checkout'),(905448,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_2_measure','%','3','','.b-multi-page-checkout'),(905449,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_2_measure','%','','','.b-slick'),(905450,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_2_measure','px','','','.w-catalog-paging'),(905451,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_3_measure','px','4','','.b-switch'),(905452,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_3_measure','px','4','','.b-switch'),(905453,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.p-quick-order-index'),(905454,'watch','.w-promotions .prom-multi-discount .promo-range','border_radius_3_measure','px','','','.w-promotions'),(905455,'watch','.w-promotions .promo-salemaker .discount','border_radius_3_measure','px','','','.w-promotions'),(905456,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_3_measure','px','','','.w-promotions'),(905457,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_3_measure','px','','','.w-promotions'),(905458,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_3_measure','px','','','.b-messages'),(905459,'watch','.b-fancybox .fancybox-close','border_radius_3_measure','%','','','.b-fancybox'),(905460,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_3_measure','px','','','.b-switch'),(905461,'watch','.w-personal-gift-status-bar .progress-bar-content','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(905462,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_3_measure','px','3','','.b-switch'),(905463,'watch','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_3_measure','px','','','.b-switch'),(905464,'watch','.w-personal-gift-status-bar .progress-bar','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(905465,'watch','.w-checkout-shipping-choice label:last-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(905466,'watch','.w-checkout-shipping-choice label:first-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(905467,'watch','.btn-1','border_radius_3_measure','px','','',''),(905468,'watch','.btn-3','border_radius_3_measure','px','','',''),(905469,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_3_measure','%','3','','.b-form'),(905470,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_3_measure','px','3','','.b-switch'),(905471,'watch','.b-fancybox .fancybox-title-float-wrap .child','border_radius_3_measure','px','','','.b-fancybox'),(905472,'watch','.b-fancybox .fancybox-skin','border_radius_3_measure','px','','','.b-fancybox'),(905473,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_3_measure','%','3','','.b-switch'),(905474,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.p-quick-order-index'),(905475,'watch','.b-fancybox .fancybox-nav span','border_radius_3_measure','%','','','.b-fancybox'),(905476,'watch','.w-product-customers-activity .close','border_radius_3_measure','%','','','.w-product-customers-activity'),(905477,'watch','.w-product-customers-activity .customers-activity','border_radius_3_measure','px','','','.w-product-customers-activity'),(905478,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(905479,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.b-data-table'),(905480,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.b-data-table'),(905481,'watch','.b-products-listing .promos-info .promo-name','border_radius_3_measure','px','','','.b-products-listing'),(905482,'watch','.b-upload-file .snapshot','border_radius_3_measure','%','','','.b-upload-file'),(905483,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(905484,'watch','.btn-2','border_radius_3_measure','px','','',''),(905485,'watch','.b-switch .bootstrap-switch','border_radius_3_measure','px','','','.b-switch'),(905486,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_3_measure','px','','','.b-switch'),(905487,'watch','.btn','border_radius_3_measure','px','','',''),(905488,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_3_measure','px','','','.b-product-images'),(905489,'watch','.b-trade-approval .steps-bar','border_radius_3_measure','px','','','.b-trade-approval'),(905490,'watch','.w-delivery-day .left-count','border_radius_3_measure','px','','','.w-delivery-day'),(905491,'watch','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_3_measure','px','','','.w-delivery-day'),(905493,'watch','.catalog-product-wrap .pn-image','border_radius_3_measure','%','3','','.catalog-product-wrap'),(905494,'watch','.b-slick .slick-dots li','border_radius_3_measure','%','3','','.b-slick'),(905495,'watch','.success-page .w-cart-listing .qty','border_radius_3_measure','%','','','.success-page'),(905496,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_3_measure','%','','','.b-multi-page-checkout'),(905497,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_3_measure','%','3','','.b-multi-page-checkout'),(905498,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_3_measure','%','','','.b-slick'),(905499,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_3_measure','px','','','.w-catalog-paging'),(905500,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_4_measure','px','4','','.b-switch'),(905501,'watch','.b-upload-file .snapshot','border_radius_4_measure','%','','','.b-upload-file'),(905502,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.p-quick-order-index'),(905503,'watch','.w-promotions .prom-multi-discount .promo-range','border_radius_4_measure','px','','','.w-promotions'),(905504,'watch','.w-promotions .promo-salemaker .discount','border_radius_4_measure','px','','','.w-promotions'),(905505,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_4_measure','px','','','.w-promotions'),(905506,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.p-quick-order-index'),(905507,'watch','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_4_measure','px','','','.w-promotions'),(905508,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_4_measure','px','','','.b-messages'),(905509,'watch','.b-fancybox .fancybox-close','border_radius_4_measure','%','','','.b-fancybox'),(905510,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_4_measure','px','','','.b-switch'),(905511,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_4_measure','px','3','','.b-switch'),(905512,'watch','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_4_measure','px','','','.b-switch'),(905513,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(905514,'watch','.w-checkout-shipping-choice label:last-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(905515,'watch','.btn-2','border_radius_4_measure','px','','',''),(905516,'watch','.w-checkout-shipping-choice label:first-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(905517,'watch','.btn-1','border_radius_4_measure','px','','',''),(905518,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_4_measure','px','4','','.b-switch'),(905519,'watch','.btn-3','border_radius_4_measure','px','','',''),(905520,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_4_measure','px','3','','.b-switch'),(905521,'watch','.b-fancybox .fancybox-title-float-wrap .child','border_radius_4_measure','px','','','.b-fancybox'),(905522,'watch','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_4_measure','%','3','','.b-form'),(905523,'watch','.w-personal-gift-status-bar .progress-bar-content','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(905524,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_4_measure','%','3','','.b-switch'),(905525,'watch','.w-personal-gift-status-bar .progress-bar','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(905526,'watch','.b-fancybox .fancybox-nav span','border_radius_4_measure','%','','','.b-fancybox'),(905527,'watch','.w-product-customers-activity .customers-activity','border_radius_4_measure','px','','','.w-product-customers-activity'),(905528,'watch','.w-product-customers-activity .close','border_radius_4_measure','%','','','.w-product-customers-activity'),(905529,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(905530,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.b-data-table'),(905531,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.b-data-table'),(905532,'watch','.b-products-listing .promos-info .promo-name','border_radius_4_measure','px','','','.b-products-listing'),(905533,'watch','.b-fancybox .fancybox-skin','border_radius_4_measure','px','','','.b-fancybox'),(905534,'watch','.b-switch .bootstrap-switch','border_radius_4_measure','px','','','.b-switch'),(905535,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_4_measure','px','','','.b-switch'),(905536,'watch','.btn','border_radius_4_measure','px','','',''),(905537,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_4_measure','px','','','.b-product-images'),(905538,'watch','.b-trade-approval .steps-bar','border_radius_4_measure','px','','','.b-trade-approval'),(905539,'watch','.w-delivery-day .left-count','border_radius_4_measure','px','','','.w-delivery-day'),(905540,'watch','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_4_measure','px','','','.w-delivery-day'),(905542,'watch','.catalog-product-wrap .pn-image','border_radius_4_measure','%','3','','.catalog-product-wrap'),(905543,'watch','.b-slick .slick-dots li','border_radius_4_measure','%','3','','.b-slick'),(905544,'watch','.success-page .w-cart-listing .qty','border_radius_4_measure','%','','','.success-page'),(905545,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_4_measure','%','','','.b-multi-page-checkout'),(905546,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_4_measure','%','3','','.b-multi-page-checkout'),(905547,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_4_measure','%','','','.b-slick'),(905548,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_4_measure','px','','','.w-catalog-paging'),(905549,'watch','.testimonials .review','bottom','-13','3','',''),(905550,'watch','.w-checkout-shipping-choice input:checked + span:before','bottom','-7','','','.w-checkout-shipping-choice'),(905551,'watch','.b-fancybox .fancybox-title-over-wrap','bottom','0','','','.b-fancybox'),(905552,'watch','.b-info-popup .info-popup.top-left div','bottom','30','','','.b-info-popup'),(905553,'watch','.b-info-popup .info-popup.top-left div','bottom','-11','3','','.b-info-popup'),(905554,'watch','.b-upload-file .snapshot','bottom','5','','','.b-upload-file'),(905555,'watch','.w-product-reviews .reviews-list .review','bottom','-13','3','','.w-product-reviews'),(905556,'watch','.b-fancybox .fancybox-overlay-fixed','bottom','0','','','.b-fancybox'),(905557,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','bottom','0','','','.b-switch'),(905558,'watch','.w-product-customers-activity .customers-activity','bottom','0','','','.w-product-customers-activity'),(905559,'watch','.w-product-customers-activity .customers-activity.closed','bottom','-1000','','','.w-product-customers-activity'),(905560,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','bottom','0','','','.b-switch'),(905561,'watch','.w-catalog-b2b-add-button ','bottom','0','','','.w-catalog-b2b-add-button'),(905562,'watch','.b-fancybox .fancybox-title-float-wrap','bottom','0','','','.b-fancybox'),(905563,'watch','.p-quick-order-index .all-scroll-div','bottom','0','','','.p-quick-order-index'),(905564,'watch','.w-cart-listing .item .remove','bottom','0','5240','','.w-cart-listing'),(905565,'watch','.b-product-images .mp-shadow, .b-product-images .media-popup','bottom','0','','','.b-product-images'),(905573,'watch','.account-samples .orders-table .order-total','bottom','45','5240','','.account-samples'),(905574,'watch','.account-samples .orders-table .status-name','bottom','7','5240','','.account-samples'),(905575,'watch','.account-samples .orders-table .td-alignright','bottom','0','5240','','.account-samples'),(905576,'watch','.b-slick .slick-vertical button.slick-next','bottom','0','','','.b-slick'),(905577,'watch','.b-slick .slick-vertical button.slick-prev','bottom','auto','','','.b-slick'),(905578,'watch','.w-banner .image-text-banner.bottom-center .text-banner','bottom','0','','','.w-banner'),(905579,'watch','.w-banner .image-text-banner.bottom-left .text-banner','bottom','0','','','.w-banner'),(905580,'watch','.w-banner .image-text-banner.bottom-right .text-banner','bottom','0','','','.w-banner'),(905581,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(905582,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(905583,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(905584,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(905585,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(905586,'watch','.b-fancybox .fancybox-opened .fancybox-skin','box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(905587,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(905588,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','box-shadow','0 0 4px rgba(75,75,75,0.5)','3','','.b-switch'),(905589,'watch','.w-catalog-compare .compare-fix-bar.fix-bar-fix','box-shadow','0 10px 10px -10px #cccccc','','','.w-catalog-compare'),(905591,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-step','box-shadow','0 2px 9px 0 rgba(0, 0, 0, 0.2)','2','','.b-multi-page-checkout'),(905593,'watch','.b-fancybox .filter-listing-loader','box-sizing','content-box','','','.b-fancybox'),(905594,'watch','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','box-sizing','border-box','','','.b-switch'),(905595,'watch','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(905596,'watch','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','box-sizing','border-box','','','.b-select-suggest'),(905597,'watch','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(905598,'watch','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(905599,'watch','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(905600,'watch','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(905601,'watch','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(905602,'watch','.b-slick .slick-slider','box-sizing','border-box','','','.b-slick'),(905603,'watch','.b-info-popup .info-popup div','box_shadow_blur','10','','','.b-info-popup'),(905604,'watch','.w-product-customers-activity .customers-activity','box_shadow_blur','20','','','.w-product-customers-activity'),(905605,'watch','.b-datepicker .datepicker-dropdown','box_shadow_blur','10','','','.b-datepicker'),(905606,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur','5','','','.w-image-maps'),(905607,'watch','.b-info-popup .info-popup div','box_shadow_blur_measure','px','','','.b-info-popup'),(905608,'watch','.b-datepicker .datepicker-dropdown','box_shadow_blur_measure','px','','','.b-datepicker'),(905609,'watch','.w-product-customers-activity .customers-activity','box_shadow_blur_measure','px','','','.w-product-customers-activity'),(905610,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur_measure','px','','','.w-image-maps'),(905611,'watch','.b-info-popup .info-popup div','box_shadow_color','#ccc','','','.b-info-popup'),(905612,'watch','.b-datepicker .datepicker-dropdown','box_shadow_color','#ccc','','','.b-datepicker'),(905613,'watch','.w-product-customers-activity .customers-activity','box_shadow_color','#eee','','','.w-product-customers-activity'),(905614,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_color','#ccc','','','.w-image-maps'),(905615,'watch','.b-info-popup .info-popup div','box_shadow_left','0','','','.b-info-popup'),(905616,'watch','.b-datepicker .datepicker-dropdown','box_shadow_left','0','','','.b-datepicker'),(905617,'watch','.w-product-customers-activity .customers-activity','box_shadow_left','0','','','.w-product-customers-activity'),(905618,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left','0','','','.w-image-maps'),(905619,'watch','.b-info-popup .info-popup div','box_shadow_left_measure','','','','.b-info-popup'),(905620,'watch','.b-datepicker .datepicker-dropdown','box_shadow_left_measure','','','','.b-datepicker'),(905621,'watch','.w-product-customers-activity .customers-activity','box_shadow_left_measure','','','','.w-product-customers-activity'),(905622,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left_measure','','','','.w-image-maps'),(905623,'watch','.b-info-popup .info-popup div','box_shadow_top','0','','','.b-info-popup'),(905624,'watch','.w-product-customers-activity .customers-activity','box_shadow_top','0','','','.w-product-customers-activity'),(905625,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top','0','','','.w-image-maps'),(905626,'watch','.b-datepicker .datepicker-dropdown','box_shadow_top','0','','','.b-datepicker'),(905627,'watch','.b-info-popup .info-popup div','box_shadow_top_measure','','','','.b-info-popup'),(905628,'watch','.w-product-customers-activity .customers-activity','box_shadow_top_measure','','','','.w-product-customers-activity'),(905629,'watch','.b-datepicker .datepicker-dropdown','box_shadow_top_measure','','','','.b-datepicker'),(905630,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top_measure','','','','.w-image-maps'),(905631,'watch','.b-form .addresses .address-item:nth-child(2n + 1)','clear','left','','','.b-form'),(905632,'watch','.w-checkout-billing-address .btn-cancel','clear','both','','','.w-checkout-billing-address'),(905633,'watch','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(905635,'watch','.b-form .col-full','clear','both','','','.b-form'),(905636,'watch','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(905639,'watch','.w-promotions .prom-multi-discount','clear','both','4','','.w-promotions'),(905640,'watch','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(905641,'watch','.w-product-available-in-warehouses .content','clear','both','4','','.w-product-available-in-warehouses'),(905642,'watch','.b-products-listing .products-listing .mix-attributes','clear','bpth','4','','.b-products-listing'),(905643,'watch','.w-cart-compare .product .name','clear','right','','','.w-cart-compare'),(905644,'watch','.b-messages .dataTables_wrapper > .top','clear','both','4','','.b-messages'),(905645,'watch','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(905646,'watch','.b-messages .dataTables_wrapper > .bottom','clear','both','4','','.b-messages'),(905647,'watch','.w-product-attributes .attributes','clear','both','4','','.w-product-attributes'),(905648,'watch','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(905649,'watch','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(905650,'watch','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(905651,'watch','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(905652,'watch','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(905653,'watch','.w-login-block .buttons','clear','none','','','.w-login-block'),(905654,'watch','.w-login-block .cols','clear','both','4','','.w-login-block'),(905655,'watch','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(905656,'watch','.w-login-block .guest','clear','right','','','.w-login-block'),(905657,'watch','.w-menu-horizontal li','clear','none','','','.w-menu-horizontal'),(905658,'watch','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(905659,'watch','.b-form .col-left','clear','left','','','.b-form'),(905660,'watch','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(905661,'watch','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(905662,'watch','.w-product-attributes .attributes','clear','both','4','','.w-product-attributes'),(905663,'watch','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(905664,'watch','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(905665,'watch','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(905666,'watch','.buttons','clear','both','','',''),(905667,'watch','.buttons','clear','both','4','',''),(905668,'watch','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(905669,'watch','.w-cart-give-away .ga_column:nth-child(2n + 1)','clear','both','','','.w-cart-give-away'),(905670,'watch','.w-top-categories .categories','clear','both','4','','.w-top-categories'),(905671,'watch','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(905672,'watch','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(905673,'watch','.w-product-configurator .pc_attr','clear','both','5232','','.w-product-configurator'),(905674,'watch','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(905675,'watch','.w-checkout-billing-address .addresses','clear','both','4','','.w-checkout-billing-address'),(905676,'watch','.w-cart-listing .right-area','clear','both','5240','','.w-cart-listing'),(905677,'watch','.w-checkout-shipping-address .addresses','clear','both','4','','.w-checkout-shipping-address'),(905678,'watch','.w-checkout-shipping-address .btn-cancel','clear','both','','','.w-checkout-shipping-address'),(905679,'watch','.b-form .addresses','clear','both','4','','.b-form'),(905680,'watch','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(905681,'watch','.w-product-attributes .attributes','clear','both','4','','.w-product-attributes'),(905682,'watch','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(905683,'watch','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(905684,'watch','.w-top-categories .item:nth-child(4n + 1)','clear','both','','','.w-top-categories'),(905685,'watch','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(905686,'watch','.b-form .newsletter-row','clear','both','4','','.b-form'),(905687,'watch','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(905688,'watch','.w-login-block .cols','clear','both','4','','.w-login-block'),(905689,'watch','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(905690,'watch','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(905691,'watch','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(905692,'watch','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(905693,'watch','.w-login-block .guest','clear','right','','','.w-login-block'),(905694,'watch','.w-login-block .guest','clear','right','','','.w-login-block'),(905695,'watch','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(905696,'watch','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(905697,'watch','.w-list-b2b .attributes','clear','both','4','','.w-list-b2b'),(905698,'watch','.w-product-configurator .pc_attr','clear','both','5232','','.w-product-configurator'),(905699,'watch','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(905700,'watch','.w-product-configurator .pc_qty','clear','both','5232','','.w-product-configurator'),(905701,'watch','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(905703,'watch','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(905704,'watch','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(905705,'watch','.w-product-configurator .pc_qty','clear','both','5232','','.w-product-configurator'),(905706,'watch','.w-product-configurator .pc_attr','clear','both','5232','','.w-product-configurator'),(905707,'watch','.w-cart-shipping-estimator .item .row: after','clear','both','','','.w-cart-shipping-estimator'),(905708,'watch','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(905709,'watch','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(905710,'watch','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(905711,'watch','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(905712,'watch','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(905713,'watch','.w-login-block .guest','clear','right','','','.w-login-block'),(905714,'watch','.w-login-block .buttons','clear','none','','','.w-login-block'),(905715,'watch','.w-login-block .cols','clear','both','4','','.w-login-block'),(905716,'watch','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(905717,'watch','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(905718,'watch','.b-form .col-right','clear','right','','','.b-form'),(905719,'watch','.w-cart-compare .product','clear','both','4','','.w-cart-compare'),(905720,'watch','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(905721,'watch','.w-login-block .buttons','clear','none','','','.w-login-block'),(905722,'watch','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(905723,'watch','.b-bottom .cart-options .option-item:nth-child(2n + 1)','clear','both','','','.b-bottom'),(905724,'watch','.b-bottom .cart-options .heading-4','clear','both','','','.b-bottom'),(905725,'watch','.b-bottom .cart-options .cart-item:nth-child(2n + 1)','clear','both','','','.b-bottom'),(905726,'watch','.b-bottom .cart-options .options','clear','both','','','.b-bottom'),(905727,'watch','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(905728,'watch','.w-login-block .guest','clear','right','','','.w-login-block'),(905729,'watch','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(905730,'watch','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(905731,'watch','.w-product-attributes .attributes','clear','both','4','','.w-product-attributes'),(905732,'watch','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(905733,'watch','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-billing-address'),(905734,'watch','.b-form .center-buttons','clear','both','','','.b-form'),(905735,'watch','.w-list-b2b .mix-attributes','clear','both','','','.w-list-b2b'),(905736,'watch','.w-cart-shipping-estimator .address-item .lastname','clear','both','4','','.w-cart-shipping-estimator'),(905737,'watch','.w-login-block .buttons','clear','none','','','.w-login-block'),(905738,'watch','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(905739,'watch','.w-product-configurator .pc_qty','clear','both','5232','','.w-product-configurator'),(905740,'watch','.w-product-attributes .attributes','clear','both','4','','.w-product-attributes'),(905741,'watch','.w-cart-compare .product .image','clear','both','','','.w-cart-compare'),(905742,'watch','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(905743,'watch','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(905744,'watch','.w-product-attributes .attributes','clear','both','4','','.w-product-attributes'),(905745,'watch','.w-login-block .cols','clear','both','4','','.w-login-block'),(905746,'watch','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(905747,'watch','.w-product-configurator .pc_qty','clear','both','5232','','.w-product-configurator'),(905748,'watch','.w-product-configurator .pc_attr','clear','both','5232','','.w-product-configurator'),(905749,'watch','.w-product-reviews .reviews-list','clear','right','','','.w-product-reviews'),(905750,'watch','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(905751,'watch','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(905752,'watch','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(905753,'watch','.w-cart-compare .buttons','clear','none','','','.w-cart-compare'),(905754,'watch','.w-menu-big li','clear','none','','','.w-menu-big'),(905755,'watch','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(905756,'watch','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(905757,'watch','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(905758,'watch','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(905759,'watch','.w-login-block .cols','clear','both','4','','.w-login-block'),(905760,'watch','.w-login-block .guest','clear','right','','','.w-login-block'),(905761,'watch','.w-login-block .buttons','clear','none','','','.w-login-block'),(905762,'watch','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(905763,'watch','.b-products-listing .BlockBox','clear','both','4','','.b-products-listing'),(905764,'watch','.b-products-listing .products-listing','clear','both','4','','.b-products-listing'),(905766,'watch','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(905767,'watch','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(905768,'watch','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(905769,'watch','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(905770,'watch','.w-categories .categories','clear','both','4','','.w-categories'),(905771,'watch','.b-form .password-forgotten-link','clear','both','','','.b-form'),(905772,'watch','.b-form .requiredM','clear','both','','','.b-form'),(905773,'watch','.w-product-configurator .pc_qty','clear','both','5232','','.w-product-configurator'),(905774,'watch','.w-login-block .cols','clear','both','4','','.w-login-block'),(905775,'watch','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(905776,'watch','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-shipping-address'),(905777,'watch','.w-categories .item:nth-child(4n + 1)','clear','both','','','.w-categories'),(905778,'watch','.w-cart-give-away .ga_name','clear','both','4','','.w-cart-give-away'),(905779,'watch','.b-form .login_btns','clear','both','','','.b-form'),(905780,'watch','.w-product-configurator .pc_attr','clear','both','5232','','.w-product-configurator'),(905781,'watch','.w-product-configurator .pc_qty','clear','both','5232','','.w-product-configurator'),(905782,'watch','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(905783,'watch','.w-login-block .buttons','clear','none','','','.w-login-block'),(905784,'watch','.w-filters .fsl_handle','clear','both','4','','.w-filters'),(905785,'watch','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(905786,'watch','.w-cart-shipping-estimator .shipping-estimator','clear','both','4','','.w-cart-shipping-estimator'),(905787,'watch','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(905788,'watch','.w-product-configurator .pc_attr','clear','both','5232','','.w-product-configurator'),(905789,'watch','.b-form .col-right + .col-left','clear','both','','','.b-form'),(905790,'watch','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(905791,'watch','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(905792,'watch','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(905793,'watch','.w-cart-shipping-estimator .item .row','clear','both','','','.w-cart-shipping-estimator'),(905794,'watch','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(905795,'watch','.b-trade-approval .col-right','clear','right','','','.b-trade-approval'),(905796,'watch','.b-trade-approval .col-left','clear','left','','','.b-trade-approval'),(905797,'watch','.b-trade-approval .center-buttons','clear','both','','','.b-trade-approval'),(905798,'watch','.b-trade-approval .columns','clear','both','4','','.b-trade-approval'),(905799,'watch','.w-catalog-compare .BlockBox','clear','both','','','.w-catalog-compare'),(905801,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-content','clear','both','4','','.b-multi-page-checkout'),(905802,'watch','.w-menu-style-1 li','clear','none','','','.w-menu-style-1'),(905803,'watch','.b-slick .slick-slide','clear','none','','','.b-slick'),(905804,'watch','.b-slick .slick-track','clear','both','4','','.b-slick'),(905805,'watch','.w-menu-horizontal li','clear_important','important','','','.w-menu-horizontal'),(905806,'watch','.w-menu-big li','clear_important','important','','','.w-menu-big'),(905807,'watch','.w-menu-style-1 li','clear_important','important','','','.w-menu-style-1'),(905808,'watch','.b-slick .slick-slide','clear_important','important','','','.b-slick'),(905809,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip','rect(0 0 0 0)','','','.b-select-suggest'),(905810,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip_important','important','','','.b-select-suggest'),(905811,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-on i','color','$switch-off-color-2','','','.b-switch'),(905812,'watch','.b-info .info a','color','$highlight-color-1','','','.b-info'),(905813,'watch','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(905814,'watch','.b-rating .glyphicon','color','$fade-color-2','','','.b-rating'),(905815,'watch','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(905817,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(905818,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','$content-color-1','','','.p-quick-order-index'),(905819,'watch','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .specials_category .promo-conditions','color','$warning-color','3','','.w-promotions'),(905820,'watch','.w-promotions .promo-salemaker .content a','color','$content-color-1','','','.w-promotions'),(905821,'watch','.w-promotions .promo-cart-discount .item a','color','$content-color-1','','','.w-promotions'),(905822,'watch','.w-promotions .prom-multi-discount .promo-range','color','$attention-color','','','.w-promotions'),(905824,'watch','.w-personal-gift-status-bar .end-label','color','$highlight-color-1','','','.w-personal-gift-status-bar'),(905825,'watch','.p-sample-checkout-success .page-success .text-3','color','$attention-color','','','.p-sample-checkout-success'),(905826,'watch','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(905827,'watch','.p-quote-checkout-success .page-success .text-1','color','$highlight-color-1','3','','.p-quote-checkout-success'),(905828,'watch','.rating-1, .rating-2, .rating-3, .rating-4, .rating-5','color','$highlight-color-1','','',''),(905829,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(905830,'watch','.testimonials .reviews-list .date','color','$fade-color-1','','',''),(905831,'watch','.testimonials .heading-3','color','$highlight-color-1','3','',''),(905832,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-2','3','','.w-contact-contacts'),(905833,'watch','.w-chat .w-chat-box a','color','$highlight-box-color-1','3','','.w-chat'),(905834,'watch','.w-promotions .prom-multi-discount .promo-range, .w-promotions .prom-multi-discount > .heading','color','$attention-color','3','','.w-promotions'),(905835,'watch','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','color','$content-color-1','','','.w-promotions'),(905836,'watch','.w-promotions .cart_discount .promo-date','color','$warning-color','3','','.w-promotions'),(905837,'watch','.w-promotions .multidiscount .promo-date, .w-promotions .multidiscount .heading-3','color','$attention-color','','','.w-promotions'),(905838,'watch','.w-promotions .cart_discount .heading-3','color','$warning-color','','','.w-promotions'),(905839,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','$highlight-color-1','','','.p-quick-order-index'),(905840,'watch','.w-promotions .specials_category .promo-salemaker .content a, .w-promotions .specials_category .promo-date','color','$warning-color','3','','.w-promotions'),(905841,'watch','.w-promotions .specials_category .heading-3','color','$warning-color','','','.w-promotions'),(905842,'watch','.w-promotions .promo-salemaker .discount','color','$warning-color','','','.w-promotions'),(905843,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','color','$attention-color','','','.w-promotions'),(905844,'watch','.w-promotions .promo-cart-discount .promo-min-qty','color','$attention-color','','','.w-promotions'),(905845,'watch','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','color','$warning-color','3','','.w-promotions'),(905846,'watch','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','color','$highlight-color-1','','','.b-warehouses-popup'),(905847,'watch','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','color','$attention-color','','','.b-warehouses-popup'),(905848,'watch','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','color','$message-color','','','.b-warehouses-popup'),(905849,'watch','.b-warehouses-popup a.warehouses-popup-link','color','$content-color-1','','','.b-warehouses-popup'),(905850,'watch','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(905851,'watch','.p-payer-order-confirmation .ship-ico','color','$highlight-color-1','3','','.p-payer-order-confirmation'),(905852,'watch','.b-quantity .qty-box .bigger','color','$highlight-color-1','','','.b-quantity'),(905853,'watch','.b-bottom .closeable-heading','color','$highlight-color-1','3','','.b-bottom'),(905854,'watch','.b-messages .messMenuButton span','color','$highlight-color-1','','','.b-messages'),(905855,'watch','.b-messages .messages-menu li a','color','$content-color-1','','','.b-messages'),(905856,'watch','.b-messages .content_management_attach','color','$highlight-color-1','','','.b-messages'),(905857,'watch','.b-messages .content_management_attach button','color','$highlight-color-1','','','.b-messages'),(905858,'watch','.b-messages .select2-search-choice-close','color','$fade-color-1','3','','.b-messages'),(905860,'watch','.w-socials .post_item > div.tw_post_item','color','$color-8','3','','.w-socials'),(905861,'watch','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(905862,'watch','.w-quote .cart-box-link','color','$highlight-box-color-1','','','.w-quote'),(905863,'watch','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(905864,'watch','.p-quote-checkout-success .page-success .text-1','color','$highlight-color-1','3','','.p-quote-checkout-success'),(905865,'watch','.b-info .info','color','$attention-color','','','.b-info'),(905867,'watch','.w-product-in-bundles .product-link','color','$content-color-1','','','.w-product-in-bundles'),(905868,'watch','.p-payer-order-confirmation .pay-ico','color','$highlight-color-1','3','','.p-payer-order-confirmation'),(905869,'watch','.p-payer-order-confirmation .order-ico','color','$highlight-color-1','3','','.p-payer-order-confirmation'),(905870,'watch','.p-payer-order-confirmation .discount-ico','color','$highlight-color-1','3','','.p-payer-order-confirmation'),(905871,'watch','.p-payer-order-confirmation .comment-ico','color','$highlight-color-1','3','','.p-payer-order-confirmation'),(905872,'watch','.p-payer-order-pay .ship-ico','color','$highlight-color-1','3','','.p-payer-order-pay'),(905873,'watch','.p-payer-order-pay .pay-ico','color','$highlight-color-1','3','','.p-payer-order-pay'),(905874,'watch','.p-payer-order-pay .order-ico','color','$highlight-color-1','3','','.p-payer-order-pay'),(905875,'watch','.p-payer-order-pay .discount-ico','color','$highlight-color-1','3','','.p-payer-order-pay'),(905876,'watch','.p-payer-order-pay .comment-ico','color','$highlight-color-1','3','','.p-payer-order-pay'),(905877,'watch','.b-form .inputRequirement','color','$attention-color','','','.b-form'),(905878,'watch','.b-fancybox .fancybox-close','color','$fancybox-color-1','','','.b-fancybox'),(905879,'watch','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(905880,'watch','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(905881,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','$highlight-color-1','1','','.p-quick-order-index'),(905882,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','color','$highlight-color-1','3','','.w-cart-gift-certificate'),(905883,'watch','.shipping-ico .heading-2','color','$highlight-color-1','3','','.shipping-ico'),(905884,'watch','.shipping-ico .heading-2','color','$message-color','3','','.shipping-ico'),(905885,'watch','.w-delivery-location-top-location-list .deliveryName a','color','$content-color-1','','','.w-delivery-location-top-location-list'),(905886,'watch','.w-menu-horizontal a','color','inherit','','','.w-menu-horizontal'),(905887,'watch','.order-summary .price-row.ot_bonus_points .title','color','$message-color','3','','.order-summary'),(905888,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-2','3','','.w-contact-contacts'),(905889,'watch','.b-quantity .qty-box .bigger','color','$highlight-color-1','','','.b-quantity'),(905890,'watch','.b-form .radio-button input[type=\"radio\"].no + span','color','$checkbox-color-1','3','','.b-form'),(905891,'watch','.b-info .info a','color','$highlight-color-1','','','.b-info'),(905892,'watch','.b-info .info-plus','color','$message-color','','','.b-info'),(905893,'watch','.w-coupons-and-vauchers-checkout #credit_modules_message','color','$message-color','','','.w-coupons-and-vauchers-checkout'),(905894,'watch','.b-fancybox .fancybox-title-outside-wrap','color','$fancybox-color-1','','','.b-fancybox'),(905895,'watch','.b-fancybox .fancybox-title-over-wrap','color','$fancybox-color-1','','','.b-fancybox'),(905896,'watch','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(905897,'watch','.b-info .info','color','$attention-color','','','.b-info'),(905898,'watch','.b-email-editor .price','color','$highlight-color-1','','','.b-email-editor'),(905899,'watch','.p-quote-checkout-success .page-success .text-1','color','$highlight-color-1','3','','.p-quote-checkout-success'),(905900,'watch','.w-social-links .twitter','color','$color-8','3','','.w-social-links'),(905901,'watch','.w-social-links .stumbleupon','color','$attention-color','3','','.w-social-links'),(905902,'watch','.w-social-links .facebook','color','$highlight-color-1','3','','.w-social-links'),(905903,'watch','.w-social-links .pinterest','color','$attention-color','3','','.w-social-links'),(905904,'watch','.btn-1','color','$btn-color-2','','',''),(905905,'watch','.price .specials','color','$price-special-1','','',''),(905906,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','color','$highlight-color-1','3','','.w-cart-gift-certificate'),(905907,'watch','.w-socials .post_item > div.tw_post_item','color','$color-8','3','','.w-socials'),(905908,'watch','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(905909,'watch','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(905910,'watch','.w-filters .input-checkbox:checked + .checkbox-span:before','color','$highlight-color-1','','','.w-filters'),(905911,'watch','.w-cart-compare .product .name a','color','$content-color-1','','','.w-cart-compare'),(905912,'watch','.w-personal-gift-status-bar .inform','color','$highlight-color-1','4','','.w-personal-gift-status-bar'),(905913,'watch','.w-product-in-bundles .product-link','color','$content-color-1','','','.w-product-in-bundles'),(905914,'watch','.b-info .info a','color','$highlight-color-1','','','.b-info'),(905915,'watch','.w-reviews .date','color','$fade-color-2','','','.w-reviews'),(905916,'watch','.w-checkout-shipping-choice span','color','$highlight-color-1','','','.w-checkout-shipping-choice'),(905917,'watch','.w-product-quantity .qty_packs .price_1','color','$fade-color-2','4','','.w-product-quantity'),(905918,'watch','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(905919,'watch','.w-socials .post_item > div.fb_post_item','color','$highlight-color-1','3','','.w-socials'),(905920,'watch','.w-socials .post_item > div.tw_post_item','color','$color-8','3','','.w-socials'),(905921,'watch','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(905923,'watch','.b-quantity .qty-box .smaller','color','$highlight-color-1','','','.b-quantity'),(905924,'watch','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(905925,'watch','.b-rating .glyphicon.coloron ~ .glyphicon-star','color','$highlight-color-1','','','.b-rating'),(905926,'watch','.b-quantity .qty-box .smaller','color','$highlight-color-1','','','.b-quantity'),(905927,'watch','.b-quantity .qty-box .bigger','color','$highlight-color-1','','','.b-quantity'),(905928,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','color','$highlight-color-1','3','','.w-cart-gift-certificate'),(905929,'watch','.w-image-maps .default-links .item .description','color','$content-color-1','','','.w-image-maps'),(905930,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-2','3','','.w-contact-contacts'),(905931,'watch','.w-personal-gift-status-bar .end-date','color','$highlight-color-1','3','','.w-personal-gift-status-bar'),(905932,'watch','.price .special','color','$price-special-1','','',''),(905933,'watch','.w-reviews-content .date','color','$fade-color-2','','','.w-reviews-content'),(905934,'watch','.b-delete-account .delete-box .delete-message','color','$attention-color','','','.b-delete-account'),(905935,'watch','.b-info .info','color','$attention-color','','','.b-info'),(905936,'watch','.b-form .radio-button input[type=\"radio\"]:checked + span:before','color','$checkbox-color-1','','','.b-form'),(905937,'watch','.w-multi-cart-actions .cart-actions .dropdown-toggle','color','$fade-color-1','3','','.w-multi-cart-actions'),(905938,'watch','.w-product-collection .save','color','$message-color','','','.w-product-collection'),(905941,'watch','.w-tabs .tab-a','color','$highlight-color-1','2','','.w-tabs'),(905942,'watch','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(905943,'watch','.w-socials .post_item > div.tw_post_item','color','$color-8','3','','.w-socials'),(905944,'watch','.w-socials .post_item > div.fb_post_item','color','$highlight-color-1','3','','.w-socials'),(905945,'watch','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(905946,'watch','.btn-edit','color','$highlight-color-1','3','',''),(905947,'watch','.bell-ico .heading-2','color','$highlight-color-1','3','','.bell-ico'),(905948,'watch','.w-tabs a.tab-a','color','$content-color-1','','','.w-tabs'),(905949,'watch','.w-tabs .tab-li:hover a.tab-a','color','$highlight-color-1','','','.w-tabs'),(905950,'watch','.w-cart-credit-amount #credit_modules_message.error','color','$attention-color','','','.w-cart-credit-amount'),(905951,'watch','.w-cart-credit-amount #credit_modules_message','color','$message-color','','','.w-cart-credit-amount'),(905952,'watch','.w-cart-listing .attention_mark','color','$attention-color','','','.w-cart-listing'),(905953,'watch','.w-delivery-location-top-location-list .deliveryName a','color','$content-color-1','','','.w-delivery-location-top-location-list'),(905954,'watch','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(905955,'watch','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(905956,'watch','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(905957,'watch','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(905958,'watch','.w-personal-gift-status-bar .start-label','color','$highlight-color-1','','','.w-personal-gift-status-bar'),(905959,'watch','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(905960,'watch','a.btn-2','color','$btn-color-3','','',''),(905961,'watch','.btn-2','color','$btn-color-3','','',''),(905962,'watch','.heading-4 .edit, h4 .edit','color','$link-color-1','','',''),(905963,'watch','.w-cart-compare .delete-cart','color','$content-color-1','3','','.w-cart-compare'),(905964,'watch','.w-cart-compare .cart-name a','color','$content-color-1','','','.w-cart-compare'),(905965,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','color','$switch-on-color-1','','','.b-switch'),(905966,'watch','.b-quantity .qty-box .smaller','color','$highlight-color-1','','','.b-quantity'),(905967,'watch','.p-sample-checkout-success .page-success .text-1','color','$highlight-color-1','3','','.p-sample-checkout-success'),(905968,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-2','3','','.w-contact-contacts'),(905969,'watch','.w-top-categories .categories h2','color','inherit','','','.w-top-categories'),(905970,'watch','.out-stock','color','$attention-color','','',''),(905971,'watch','.transit','color','$highlight-color-2','','',''),(905972,'watch','.in-stock','color','$message-color','','',''),(905973,'watch','.heading-3 .edit, h3 .edit','color','$link-color-1','','',''),(905974,'watch','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(905975,'watch','.b-quantity .qty-box .bigger','color','$highlight-color-1','','','.b-quantity'),(905976,'watch','.b-bottom .header-error','color','$attention-color','','','.b-bottom'),(905977,'watch','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(905978,'watch','.shipping-ico .heading-2','color','$message-color','3','','.shipping-ico'),(905979,'watch','.savings-ico .heading-2','color','$message-color','3','','.savings-ico'),(905980,'watch','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(905981,'watch','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(905982,'watch','.w-product-quantity .qty_packs .price_1','color','$fade-color-2','4','','.w-product-quantity'),(905984,'watch','.w-socials .post_item > div.fb_post_item','color','$highlight-color-1','3','','.w-socials'),(905985,'watch','.testimonials .date','color','$highlight-color-1','','',''),(905986,'watch','.js-stock','color','$message-color','','',''),(905987,'watch','.b-quantity .qty-box .smaller','color','$highlight-color-1','','','.b-quantity'),(905988,'watch','.b-email-editor .price','color','$highlight-color-1','','','.b-email-editor'),(905989,'watch','.b-fancybox .fancybox-title-float-wrap .child','color','$fancybox-color-1','','','.b-fancybox'),(905990,'watch','.w-product-in-bundles .product-link','color','$content-color-1','','','.w-product-in-bundles'),(905991,'watch','.w-reviews-content .product-name a','color','$highlight-color-1','','','.w-reviews-content'),(905992,'watch','.b-fancybox .fancybox-skin','color','$fancybox-color-1','','','.b-fancybox'),(905993,'watch','.w-product-quantity .qty_packs .price_1','color','$fade-color-2','4','','.w-product-quantity'),(905994,'watch','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(905995,'watch','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(905996,'watch','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(905997,'watch','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(905998,'watch','.w-socials .post_item > div.tw_post_item','color','$color-8','3','','.w-socials'),(905999,'watch','.w-socials .post_item > div.fb_post_item','color','$highlight-color-1','3','','.w-socials'),(906000,'watch','.b-info .info-plus','color','$message-color','','','.b-info'),(906001,'watch','.main-content a','color','$link-color-1','','',''),(906002,'watch','.btn','color','$btn-color-1','','',''),(906005,'watch','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(906006,'watch','.message.success','color','$message-color','','',''),(906007,'watch','.b-form .required-message','color','$attention-color','','','.b-form'),(906008,'watch','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(906009,'watch','.b-email-editor .price','color','$highlight-color-1','','','.b-email-editor'),(906010,'watch','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(906011,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(906012,'watch','.w-product-quantity .qty_packs .price_1','color','$fade-color-2','4','','.w-product-quantity'),(906013,'watch','.w-reviews .heading-3','color','$highlight-color-1','3','','.w-reviews'),(906014,'watch','.w-reviews .product-name a','color','$highlight-color-1','','','.w-reviews'),(906015,'watch','.b-quantity .qty-box .bigger','color','$highlight-color-1','','','.b-quantity'),(906016,'watch','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','color','$content-color-1','','','.b-select-suggest'),(906017,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span:before','color','$checkbox-color-1','','','.b-form'),(906018,'watch','.b-info .info a','color','$highlight-color-1','','','.b-info'),(906019,'watch','.w-social-links .linkedin','color','$highlight-color-1','3','','.w-social-links'),(906020,'watch','.b-info .info','color','$attention-color','','','.b-info'),(906021,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','color','$switch-off-color-2','','','.b-switch'),(906022,'watch','a','color','inherit','','',''),(906024,'watch','.w-product-collection .save','color','$message-color','','','.w-product-collection'),(906025,'watch','a.btn','color','$btn-color-1','','',''),(906027,'watch','.b-form .checkbox-style:checked + .checkbox-span:before','color','$checkbox-color-1','','','.b-form'),(906028,'watch','.btn-del','color','$attention-color','4','',''),(906029,'watch','.b-form .required','color','$attention-color','','','.b-form'),(906030,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(906031,'watch','.p-quote-checkout-success .page-success .text-1','color','$highlight-color-1','3','','.p-quote-checkout-success'),(906032,'watch','.w-product-collection .save','color','$message-color','','','.w-product-collection'),(906033,'watch','.b-rating .glyphicon-star.coloron','color','$highlight-color-1','3','','.b-rating'),(906034,'watch','.w-social-links .instagram','color','$attention-color','3','','.w-social-links'),(906035,'watch','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(906036,'watch','.b-pass-strength span.good-pass','color','$message-color','','','.b-pass-strength'),(906037,'watch','.b-pass-strength span.strong-pass, .b-pass-strength span.pass-match','color','$message-color','','','.b-pass-strength'),(906038,'watch','.b-email-editor .price','color','$highlight-color-1','','','.b-email-editor'),(906039,'watch','.b-info .info','color','$attention-color','','','.b-info'),(906040,'watch','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(906043,'watch','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(906044,'watch','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(906045,'watch','.w-product-collection .save','color','$message-color','','','.w-product-collection'),(906046,'watch','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(906047,'watch','.w-delivery-location-top-location-list .deliveryName a','color','$content-color-1','','','.w-delivery-location-top-location-list'),(906049,'watch','.b-info .info-plus','color','$message-color','','','.b-info'),(906050,'watch','.w-product-in-bundles .product-link','color','$content-color-1','','','.w-product-in-bundles'),(906051,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(906052,'watch','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(906053,'watch','.b-bottom .pop-up-close','color','$fade-color-1','1','','.b-bottom'),(906054,'watch','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','color','$fade-color-1','3','','.order-summary'),(906055,'watch','.order-summary .price-row.ot_gv .title','color','$message-color','3','','.order-summary'),(906056,'watch','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','color','$message-color','','','.b-products-listing'),(906057,'watch','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','color','$message-color','','','.b-products-listing'),(906058,'watch','.w-product-collection .save','color','$message-color','','','.w-product-collection'),(906059,'watch','.w-socials .post_item > div.fb_post_item','color','$highlight-color-1','3','','.w-socials'),(906061,'watch','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(906062,'watch','.b-info .info a','color','$highlight-color-1','','','.b-info'),(906063,'watch','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(906064,'watch','.w-social-links .google-plus','color','$attention-color','3','','.w-social-links'),(906065,'watch','.b-info .info-plus','color','$message-color','','','.b-info'),(906066,'watch','.b-info .info','color','$attention-color','','','.b-info'),(906067,'watch','.b-form .privacy-row a','color','$highlight-color-1','','','.b-form'),(906068,'watch','.b-quantity .qty-box .bigger','color','$highlight-color-1','','','.b-quantity'),(906071,'watch','.w-product-quantity .qty_packs .price_1','color','$fade-color-2','4','','.w-product-quantity'),(906072,'watch','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(906073,'watch','.w-product-in-bundles .product-link','color','$content-color-1','','','.w-product-in-bundles'),(906074,'watch','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(906075,'watch','.w-image-maps .categories-items .item .description','color','$content-color-1','','','.w-image-maps'),(906076,'watch','.w-delivery-location-top-location-list .deliveryName a','color','$content-color-1','','','.w-delivery-location-top-location-list'),(906077,'watch','.w-checkout-shipping-choice input:checked + span','color','$highlight-box-color-1','','','.w-checkout-shipping-choice'),(906078,'watch','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(906079,'watch','.w-tabs .accordion-heading','color','$highlight-color-1','2','','.w-tabs'),(906080,'watch','.w-categories h2.name','color','$content-color-1','','','.w-categories'),(906081,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on i, .b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-off i','color','$switch-on-color-1','','','.b-switch'),(906082,'watch','.p-quote-checkout-success .page-success .text-1','color','$highlight-color-1','3','','.p-quote-checkout-success'),(906083,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','color','$content-color-1','','','.b-select-suggest'),(906084,'watch','.b-select-suggest .select2-default','color','$fade-color-1','','','.b-select-suggest'),(906085,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','color','$content-color-1','','','.b-select-suggest'),(906086,'watch','.b-select-suggest .select2-results .select2-highlighted ul','color','$content-color-1','','','.b-select-suggest'),(906087,'watch','.b-select-suggest .select2-results .select2-highlighted','color','$content-color-1','','','.b-select-suggest'),(906088,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','color','$highlight-color-1','3','','.w-cart-gift-certificate'),(906089,'watch','.b-select-suggest .select2-drop','color','$content-color-1','','','.b-select-suggest'),(906090,'watch','.w-product-in-bundles .product-link','color','$content-color-1','','','.w-product-in-bundles'),(906091,'watch','.w-socials .post_item > div.insta_post_item','color','$attention-color','3','','.w-socials'),(906092,'watch','.w-menu-big a','color','inherit','','','.w-menu-big'),(906093,'watch','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(906094,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','$content-color-1','','','.b-data-table'),(906095,'watch','.b-products-listing .products-listing .name a','color','$content-color-1','','','.b-products-listing'),(906096,'watch','.b-products-listing .products-listing .bonus-points span:first-child','color','$highlight-color-1','','','.b-products-listing'),(906097,'watch','.b-products-listing .products-listing .bonus-points-price','color','$highlight-color-1','3','','.b-products-listing'),(906098,'watch','.b-products-listing .products-listing .bonus-points-cost','color','$highlight-color-1','3','','.b-products-listing'),(906099,'watch','.w-catalog-b2b-add-button ','color','$highlight-box-color-1','','','.w-catalog-b2b-add-button'),(906100,'watch','.b-products-listing .products-listing h2','color','inherit','','','.b-products-listing'),(906101,'watch','.b-products-listing .promos-info .promo-name','color','$attention-color','','','.b-products-listing'),(906105,'watch','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(906106,'watch','.b-quantity .qty-box .smaller','color','$highlight-color-1','','','.b-quantity'),(906107,'watch','.b-select-suggest .select2-container .select2-choice','color','$content-color-1','','','.b-select-suggest'),(906108,'watch','.b-upload-file .snapshot','color','$fade-color-1','','','.b-upload-file'),(906109,'watch','.b-email-editor .price','color','$highlight-color-1','','','.b-email-editor'),(906110,'watch','.b-info .info-plus','color','$message-color','','','.b-info'),(906111,'watch','.b-info .info a','color','$highlight-color-1','','','.b-info'),(906112,'watch','.w-top-categories h2.name','color','$content-color-1','','','.w-top-categories'),(906114,'watch','.w-coupons-and-vauchers-checkout #credit_modules_message.error','color','$attention-color','','','.w-coupons-and-vauchers-checkout'),(906115,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-2','3','','.w-contact-contacts'),(906116,'watch','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','color','$highlight-box-color-1','','','.w-taxable'),(906117,'watch','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','color','$highlight-box-color-1','','','.w-taxable'),(906118,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','color','$content-color-1','','','.w-communication-new-topic'),(906119,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','color','$content-color-1','','','.w-communication-new-topic'),(906120,'watch','.b-form .middle-form label','color','$content-color-1','','','.b-form'),(906121,'watch','.btn-3','color','$btn-color-4','','',''),(906122,'watch','.order-summary .price-row.ot_coupon .title','color','$message-color','3','','.order-summary'),(906123,'watch','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(906124,'watch','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(906125,'watch','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(906126,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(906127,'watch','.w-cart-compare .product-actions .dropdown-toggle','color','$fade-color-1','','','.w-cart-compare'),(906128,'watch','.w-promo-code .holder','color','$attention-color','3','','.w-promo-code'),(906129,'watch','.b-info .info-plus','color','$message-color','','','.b-info'),(906130,'watch','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(906131,'watch','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(906132,'watch','.w-catalog-listing-look .grid','color','$fade-color-2','','','.w-catalog-listing-look'),(906133,'watch','.w-catalog-listing-look .b2b','color','$content-color-1','2','','.w-catalog-listing-look'),(906134,'watch','.w-catalog-listing-look .b2b','color','$fade-color-2','','','.w-catalog-listing-look'),(906135,'watch','.w-catalog-listing-look .list','color','$fade-color-2','','','.w-catalog-listing-look'),(906136,'watch','.w-catalog-listing-look .grid','color','$content-color-1','2','','.w-catalog-listing-look'),(906137,'watch','.w-catalog-listing-look .list','color','$content-color-1','2','','.w-catalog-listing-look'),(906138,'watch','.checkbox input:checked + span:before','color','$checkbox-color-1','','',''),(906139,'watch','.p-quick-order-index .all-scroll-div','color','$highlight-box-color-1','','','.p-quick-order-index'),(906140,'watch','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','color','$fade-color-1','','','.w-cart-listing'),(906141,'watch','.w-cart-listing .points-earn','color','$message-color','','','.w-cart-listing'),(906142,'watch','.w-cart-listing .actions a','color','$fade-color-1','','','.w-cart-listing'),(906143,'watch','.w-cart-listing .points-redeem','color','$message-color','','','.w-cart-listing'),(906144,'watch','.w-cart-listing .remove-btn','color','$fade-color-1','','','.w-cart-listing'),(906145,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','color','$highlight-color-1','3','','.w-cart-gift-certificate'),(906146,'watch','.w-cart-discount-coupon #credit_modules_message.error','color','$attention-color','','','.w-cart-discount-coupon'),(906151,'watch','.w-cart-discount-coupon #credit_modules_message','color','$message-color','','','.w-cart-discount-coupon'),(906152,'watch','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(906153,'watch','.w-image-maps .float-items .item .description','color','$content-color-1','','','.w-image-maps'),(906154,'watch','.b-fancybox .fancybox-nav span','color','$fancybox-color-1','','','.b-fancybox'),(906155,'watch','.b-email-editor .special-price','color','$attention-color','','','.b-email-editor'),(906156,'watch','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(906157,'watch','.w-socials .post_item > div.tw_post_item','color','$color-8','3','','.w-socials'),(906158,'watch','.w-socials .post_item > div.fb_post_item','color','$highlight-color-1','3','','.w-socials'),(906159,'watch','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(906160,'watch','.w-product-promotions .promotion-full-price-discount','color','$attention-color','','','.w-product-promotions'),(906161,'watch','.w-product-quantity .qty_packs .price_1','color','$fade-color-2','4','','.w-product-quantity'),(906162,'watch','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(906163,'watch','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(906164,'watch','.w-product-collection .save','color','$message-color','','','.w-product-collection'),(906165,'watch','.p-quote-checkout-success .page-success .text-1','color','$highlight-color-1','3','','.p-quote-checkout-success'),(906166,'watch','.w-filters .head-filter-widget','color','$highlight-box-color-1','5240','','.w-filters'),(906167,'watch','.w-delivery-location-top-location-list .deliveryName a','color','$content-color-1','','','.w-delivery-location-top-location-list'),(906168,'watch','.w-filters .filter-box-head','color','$content-color-1','','','.w-filters'),(906169,'watch','.w-filters .view_more','color','$highlight-color-1','','','.w-filters'),(906170,'watch','.p-quote-checkout-success .page-success .text-3','color','$attention-color','','','.p-quote-checkout-success'),(906171,'watch','.order-summary .heading-2','color','$highlight-color-1','3','','.order-summary'),(906172,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','color','$highlight-color-1','3','','.w-cart-gift-certificate'),(906173,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-2','3','','.w-contact-contacts'),(906174,'watch','.w-delivery-location-top-location-list .deliveryName a','color','$content-color-1','','','.w-delivery-location-top-location-list'),(906175,'watch','.b-bottom .pop-up-close','color','$fade-color-1','','','.b-bottom'),(906176,'watch','.b-email-editor .price','color','$highlight-color-1','','','.b-email-editor'),(906177,'watch','.b-quantity .qty-box .smaller','color','$highlight-color-1','','','.b-quantity'),(906178,'watch','.b-pass-strength span.bad-pass','color','$warning-color','','','.b-pass-strength'),(906179,'watch','.w-product-reviews .reviews-list .date','color','$fade-color-1','','','.w-product-reviews'),(906180,'watch','.b-upload-files .remove-file','color','$attention-color','3','','.b-upload-files'),(906181,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','$highlight-color-1','1','','.b-data-table'),(906182,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','$highlight-color-1','','','.b-data-table'),(906183,'watch','a.btn-3','color','$btn-color-4','','',''),(906184,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.off .candlestick-off','color','$switch-handle-bg-3','4','','.b-switch'),(906185,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.on .candlestick-on','color','$switch-handle-bg-3','4','','.b-switch'),(906186,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.default .candlestick-nc','color','$switch-handle-bg-3','4','','.b-switch'),(906187,'watch','.b-pass-strength .short-pass, .b-pass-strength .pass-strength, .b-pass-strength .pass-no-match','color','$attention-color','','','.b-pass-strength'),(906188,'watch','.b-form .message.error','color','$attention-color','','','.b-form'),(906189,'watch','a.btn-1','color','$btn-color-2','','',''),(906190,'watch','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','color','$fade-color-2','','','.w-filters'),(906191,'watch','.b-product-images .media-popup .mp-close','color','$image-popup-color-2','','','.b-product-images'),(906192,'watch','.b-product-images .media-popup .mp-close','color','$image-popup-color-1','1','','.b-product-images'),(906193,'watch','.b-product-images .media-popup .slick-dots li','color','$image-popup-color-2','','','.b-product-images'),(906194,'watch','.b-product-images .media-popup .slick-dots li.slick-active','color','$image-popup-color-1','','','.b-product-images'),(906195,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','color','$image-popup-color-2','','','.b-product-images'),(906196,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','color','$image-popup-color-1','1','','.b-product-images'),(906197,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2','color','$content-color-1','','','.b-menu-style-1'),(906198,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','color','$highlight-color-1','','','.b-menu-style-1'),(906199,'watch','.b-personal-catalog-popup #personal_catalog_popup .show-all-lists','color','$highlight-color-1','','','.b-personal-catalog-popup'),(906200,'watch','.b-trade-approval .steps-bar li.current a','color','$highlight-box-color-1','','','.b-trade-approval'),(906201,'watch','.b-trade-approval .middle-form label','color','$content-color-1','','','.b-trade-approval'),(906202,'watch','.w-account-personal-catalog .list-switcher a','color','$highlight-color-1','2','','.w-account-personal-catalog'),(906203,'watch','.w-catalog-compare .checkbox input:checked + span:before','color','$content-color-1','','','.w-catalog-compare'),(906204,'watch','.w-catalog-compare span.btn-preloader','color','$highlight-color-1','3','','.w-catalog-compare'),(906205,'watch','.w-catalog-compare .cross-box .different-all > div','color','$highlight-color-1','2','','.w-catalog-compare'),(906206,'watch','.w-catalog-compare .cross-box .return','color','$highlight-color-1','','','.w-catalog-compare'),(906207,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','color','$highlight-color-1','3','','.w-catalog-compare'),(906208,'watch','.w-delivery-day .ends','color','$attention-color','','','.w-delivery-day'),(906209,'watch','.w-delivery-day .left-count-days-text, .w-delivery-day .left-count-hours-text, .w-delivery-day .left-count-minutes-text, .w-delivery-day .left-count-seconds-text','color','$highlight-box-color-1','','','.w-delivery-day'),(906210,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','color','$fade-color-2','','','.w-filters'),(906211,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','color','$highlight-color-1','','','.w-filters'),(906230,'watch','.catalog-product-wrap .pn-direction','color','$highlight-color-1','','','.catalog-product-wrap'),(906231,'watch','.catalog-product-wrap .pn-image','color','$fade-color-2','3','','.catalog-product-wrap'),(906232,'watch','.checkout-index-wrap .comment-ico','color','$highlight-color-1','3','','.checkout-index-wrap'),(906233,'watch','.checkout-index-wrap .discount-ico','color','$highlight-color-1','3','','.checkout-index-wrap'),(906234,'watch','.checkout-index-wrap .edit-address-popup .addresses .buttons a','color','$highlight-color-1','','','.checkout-index-wrap'),(906235,'watch','.checkout-index-wrap .edit-address-popup .edit-ab','color','$highlight-color-1','','','.checkout-index-wrap'),(906236,'watch','.checkout-index-wrap .order-ico','color','$highlight-color-1','3','','.checkout-index-wrap'),(906237,'watch','.checkout-index-wrap .pay-ico','color','$highlight-color-1','3','','.checkout-index-wrap'),(906238,'watch','.checkout-index-wrap .ship-ico','color','$highlight-color-1','3','','.checkout-index-wrap'),(906239,'watch','.checkout-success-wrap .page-success .text-1','color','$highlight-color-1','3','','.checkout-success-wrap'),(906240,'watch','.checkout-success-wrap .page-success .text-3','color','$attention-color','','','.checkout-success-wrap'),(906241,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','color','$highlight-color-1','3','','.account-order-pay'),(906242,'watch','.account-order-pay .not_fully_paid_td','color','$attention-color','','','.account-order-pay'),(906243,'watch','.account-samples .moduleRowDue td','color','$fade-color-1','','','.account-samples'),(906244,'watch','.account-samples .not_fully_paid_td','color','$attention-color','','','.account-samples'),(906245,'watch','.account-samples .view_link','color','$highlight-color-1','','','.account-samples'),(906246,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','color','$highlight-color-1','3','','.account-sample-info'),(906247,'watch','.account-sample-info .not_fully_paid_td','color','$attention-color','','','.account-sample-info'),(906248,'watch','.checkout-order-confirmation .comment-ico','color','$highlight-color-1','3','','.checkout-order-confirmation'),(906249,'watch','.checkout-order-confirmation .discount-ico','color','$highlight-color-1','3','','.checkout-order-confirmation'),(906250,'watch','.checkout-order-confirmation .order-ico','color','$highlight-color-1','3','','.checkout-order-confirmation'),(906251,'watch','.checkout-order-confirmation .pay-ico','color','$highlight-color-1','3','','.checkout-order-confirmation'),(906252,'watch','.checkout-order-confirmation .prod-ico','color','$highlight-color-1','3','','.checkout-order-confirmation'),(906253,'watch','.checkout-order-confirmation .ship-ico','color','$highlight-color-1','3','','.checkout-order-confirmation'),(906254,'watch','.b-bottom .btn-cancel, .b-bottom .add-ab','color','$highlight-color-1','','','.b-bottom'),(906255,'watch','.b-info .danger-message','color','$attention-color','','','.b-info'),(906256,'watch','.b-info .info-message','color','$message-color','','','.b-info'),(906257,'watch','.b-info .success-message','color','$message-color','','','.b-info'),(906258,'watch','.b-info .warning-message','color','$warning-color','','','.b-info'),(906259,'watch','.success-page .page-success .text-3','color','$attention-color','','','.success-page'),(906260,'watch','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading','color','$highlight-color-1','','','.b-multi-page-checkout'),(906261,'watch','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','color','$highlight-box-color-1','','','.b-multi-page-checkout'),(906262,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading','color','$fade-color-2','','','.b-multi-page-checkout'),(906263,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','$highlight-box-color-3','3','','.b-multi-page-checkout'),(906264,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','$content-color-1','','','.b-multi-page-checkout'),(906265,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','$content-color-1','','','.b-multi-page-checkout'),(906266,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','$highlight-color-1','4','','.b-multi-page-checkout'),(906267,'watch','.success-page .w-cart-listing .qty','color','$highlight-box-color-1','','','.success-page'),(906268,'watch','body','color','$content-color-1','','',''),(906270,'watch','.w-bestsellers .counter','color','$best-sellers-color-1','','','.w-bestsellers'),(906271,'watch','.w-bestsellers .heading-3','color','$best-sellers-color-1','3','','.w-bestsellers'),(906272,'watch','.w-bestsellers .item','color','$best-sellers-color-1','3','','.w-bestsellers'),(906273,'watch','.w-bestsellers .item:first-child .counter','color','$best-sellers-color-2','','','.w-bestsellers'),(906274,'watch','.order-summary > div','color','$content-color-1','','','.order-summary'),(906275,'watch','.w-account-customer-additional-field .tf-file .remove','color','$attention-color','3','','.w-account-customer-additional-field'),(906276,'watch','.price','color','$price-current-1','','',''),(906277,'watch','.price .old','color','$price-old-1','','',''),(906278,'watch','.w-menu-style-1 .menu-ico','color','$highlight-box-color-1','','','.w-menu-style-1'),(906279,'watch','.w-menu-style-1 > ul','color','$highlight-box-color-1','','','.w-menu-style-1'),(906280,'watch','.w-menu-style-1 a','color','inherit','','','.w-menu-style-1'),(906281,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','color','$content-color-1','','','.b-slick'),(906282,'watch','.w-catalog-paging ','color','#FFFFFF','2','','.w-catalog-paging'),(906283,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.p-quick-order-index'),(906284,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.p-quick-order-index'),(906285,'watch','a.btn-2','color_important','important','','',''),(906286,'watch','a.btn-3','color_important','important','','',''),(906287,'watch','a.btn-1','color_important','important','','',''),(906288,'watch','a.btn','color_important','important','','',''),(906289,'watch','.b-select-suggest .select2-default','color_important','important','','','.b-select-suggest'),(906290,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.b-data-table'),(906291,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.b-data-table'),(906292,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','column-count','4','','','.b-menu-style-1'),(906293,'watch','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','content','\\f003','3','','.w-checkout-contact-information'),(906294,'watch','.heading-4 .edit, h4 .edit','content','\\e917','4','',''),(906295,'watch','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(906296,'watch','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(906297,'watch','.message.success','content','\\e918','3','',''),(906299,'watch','.p-quick-order-index .paginate_button.next','content','\\f105','3','','.p-quick-order-index'),(906300,'watch','.p-quick-order-index .paginate_button.previous','content','\\f104','3','','.p-quick-order-index'),(906301,'watch','.w-promotions .prom-multi-discount .promo-range .promo-prod-qty','content',',','4','','.w-promotions'),(906302,'watch','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','content','\\_','3','','.w-promotions'),(906303,'watch','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(906304,'watch','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(906305,'watch','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(906308,'watch','.p-sample-checkout-success .page-success','content','\\_','0,3','','.p-sample-checkout-success'),(906309,'watch','.shipping-ico .heading-2','content','\\e95e','3','','.shipping-ico'),(906310,'watch','.p-sample-checkout-success .page-success .text-1','content','\\e916','3','','.p-sample-checkout-success'),(906311,'watch','.w-promotions .prom-multi-discount','content','\\_','4','','.w-promotions'),(906312,'watch','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(906313,'watch','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(906314,'watch','.testimonials .review','content','\\_','3','',''),(906315,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(906316,'watch','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(906317,'watch','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(906318,'watch','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(906319,'watch','.w-promotions .prom-multi-discount > .heading','content','\\_','3','','.w-promotions'),(906320,'watch','.w-promotions .nextdiscount .heading','content','\\f07a','3','','.w-promotions'),(906321,'watch','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','content','\\_','3','','.w-promotions'),(906322,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','content','\\f041','3','','.b-warehouses-popup'),(906323,'watch','.b-warehouses-popup .warehouses-popup-link','content','\\f041','3','','.b-warehouses-popup'),(906324,'watch','.b-preloader .preloader','content','\\f110','3','','.b-preloader'),(906325,'watch','.w-product-available-in-warehouses .content','content','\\_','4','','.w-product-available-in-warehouses'),(906326,'watch','.b-products-listing .products-listing .mix-attributes','content','\\_','4','','.b-products-listing'),(906327,'watch','.w-breadcrumb .breadcrumb-li + .breadcrumb-li','content','/','3','','.w-breadcrumb'),(906329,'watch','.order-summary .price-row.ot_gv .title','content','\\e99f','3','','.order-summary'),(906330,'watch','.shipping-ico .heading-2','content','\\e95e','3','','.shipping-ico'),(906331,'watch','.w-breadcrumb .breadcrumb-li + .breadcrumb-li','content','/','3','','.w-breadcrumb'),(906332,'watch','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(906333,'watch','.b-messages .messBtnMenuUnread','content','\\f097','3','','.b-messages'),(906334,'watch','.b-messages .messBtnMenuDelete','content','\\e913','3','','.b-messages'),(906335,'watch','.b-messages span.starred::before','content','\\e90e','','','.b-messages'),(906336,'watch','.b-messages .dataTables_wrapper > .top','content','\\_','4','','.b-messages'),(906337,'watch','.b-messages .messBtnMenuStarred','content','\\e90e','3','','.b-messages'),(906338,'watch','.b-messages .icon-circle-with-cross::before','content','×','','','.b-messages'),(906340,'watch','.b-messages .dataTables_wrapper > .bottom','content','\\_','4','','.b-messages'),(906342,'watch','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(906343,'watch','.b-info .info','content','\\e918','3','','.b-info'),(906344,'watch','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(906345,'watch','.w-product-personal-catalog-button .btn','content','\\f097','3','','.w-product-personal-catalog-button'),(906346,'watch','.p-payer-order-confirmation .ship-ico','content','\\e94e','3','','.p-payer-order-confirmation'),(906347,'watch','.p-payer-order-confirmation .order-ico','content','\\e922','3','','.p-payer-order-confirmation'),(906348,'watch','.p-payer-order-confirmation .pay-ico','content','\\e99e','3','','.p-payer-order-confirmation'),(906349,'watch','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(906350,'watch','.p-payer-order-confirmation .discount-ico','content','\\e95e','3','','.p-payer-order-confirmation'),(906351,'watch','.p-payer-order-confirmation .comment-ico','content','\\e99d','3','','.p-payer-order-confirmation'),(906352,'watch','.p-payer-order-pay .ship-ico','content','\\e94e','3','','.p-payer-order-pay'),(906353,'watch','.p-payer-order-pay .pay-ico','content','\\e99e','3','','.p-payer-order-pay'),(906354,'watch','.p-payer-order-pay .order-ico','content','\\e922','3','','.p-payer-order-pay'),(906355,'watch','.p-payer-order-pay .discount-ico','content','\\e95e','3','','.p-payer-order-pay'),(906356,'watch','.p-payer-order-pay .comment-ico','content','\\e99d','3','','.p-payer-order-pay'),(906357,'watch','.b-quantity .qty-box .smaller','content','-','3','','.b-quantity'),(906358,'watch','.b-quantity .qty-box .bigger','content','+','3','','.b-quantity'),(906359,'watch','.b-fancybox .fancybox-close','content','\\f00d','3','','.b-fancybox'),(906360,'watch','.b-messages .select2-search-choice-close','content','\\e913','3','','.b-messages'),(906361,'watch','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','content','\\f095','3','','.w-checkout-contact-information'),(906362,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','content','ttr(data-content','4','','.b-switch'),(906363,'watch','.b-rating .glyphicon-chevron-left','content','\\f104','3','','.b-rating'),(906364,'watch','.b-quantity .qty-box .bigger','content','+','3','','.b-quantity'),(906365,'watch','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(906366,'watch','.w-product-reviews .reviews-list .review','content','\\_','3','','.w-product-reviews'),(906367,'watch','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(906368,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(906369,'watch','.bell-ico .heading-2','content','\\e9a7','3','','.bell-ico'),(906370,'watch','.b-rating .glyphicon-chevron-right','content','\\f105','3','','.b-rating'),(906371,'watch','.w-upload-customer-id-upload-customer-id-form .upload-remove','content','\\f1f8','3','','.w-upload-customer-id-upload-customer-id-form'),(906372,'watch','.b-info .info','content','\\e918','3','','.b-info'),(906373,'watch','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(906374,'watch','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(906375,'watch','.w-coupons-and-vauchers-checkout .btn-remove','content','\\e913','3','','.w-coupons-and-vauchers-checkout'),(906376,'watch','.w-login-block .cols','content','\\_','4','','.w-login-block'),(906377,'watch','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(906379,'watch','.order-summary .price-row.ot_bonus_points .title','content','\\e9a9','3','','.order-summary'),(906380,'watch','.b-info .info','content','\\e918','3','','.b-info'),(906381,'watch','.b-bottom .closeable-heading','content','\\f068','3','','.b-bottom'),(906382,'watch','.b-bottom .closeable-heading.closed','content','\\f067','3','','.b-bottom'),(906383,'watch','.b-form .radio-button input[type=\"radio\"].no + span','content','\\f00c','3','','.b-form'),(906384,'watch','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(906385,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','content',' ','3','','.b-switch'),(906386,'watch','.w-social-links .stumbleupon','content','\\f1a4','3','','.w-social-links'),(906387,'watch','.buttons','content','\\_','4','',''),(906388,'watch','.out-stock-icon','content','\\f10c','3','',''),(906389,'watch','.in-stock-icon','content','\\f058','3','',''),(906390,'watch','.transit-icon','content','\\f133','3','',''),(906391,'watch','.w-breadcrumb .breadcrumb-li + .breadcrumb-li','content','/','3','','.w-breadcrumb'),(906392,'watch','.w-cart-compare .atr-col','content','\\f070','3','','.w-cart-compare'),(906393,'watch','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(906394,'watch','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(906395,'watch','.b-rating .glyphicon-chevron-up','content','\\f106','3','','.b-rating'),(906396,'watch','.w-tabs .tab-li.tab-sample a','content','\\e984','3','','.w-tabs'),(906397,'watch','.shipping-ico .heading-2','content','\\e94e','3','','.shipping-ico'),(906398,'watch','.b-upload-file .upload-file-wrap .upload-remove','content','\\e913','3','','.b-upload-file'),(906399,'watch','.w-chat .w-chat-box a','content','\\f075','3','','.w-chat'),(906400,'watch','.b-quantity .qty-box .smaller','content','-','3','','.b-quantity'),(906401,'watch','.b-bottom .footerTitle','content','\\f067','5232,4','','.b-bottom'),(906402,'watch','.closeable-heading','content','\\f067','3','',''),(906403,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow b','content','\\25be','3','','.b-select-suggest'),(906404,'watch','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(906405,'watch','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(906406,'watch','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(906407,'watch','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(906408,'watch','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(906410,'watch','.w-top-categories .categories','content','\\_','4','','.w-top-categories'),(906411,'watch','.w-checkout-billing-address .addresses','content','\\_','4','','.w-checkout-billing-address'),(906413,'watch','.b-quantity .qty-box .smaller','content','-','3','','.b-quantity'),(906414,'watch','.b-quantity .qty-box .bigger','content','+','3','','.b-quantity'),(906415,'watch','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(906416,'watch','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(906417,'watch','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(906419,'watch','.view-all .btn','content','\\f054','4','',''),(906420,'watch','.view-all','content','\\_','3','',''),(906421,'watch','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(906422,'watch','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(906423,'watch','.b-form .newsletter-row','content','\\_','4','','.b-form'),(906424,'watch','.b-info .info','content','\\e918','3','','.b-info'),(906425,'watch','.w-checkout-shipping-address .addresses','content','\\_','4','','.w-checkout-shipping-address'),(906426,'watch','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(906427,'watch','.w-quote .cart-box-link','content','\\e90d','3','','.w-quote'),(906428,'watch','.w-tabs .tab-li.tab-wishlist a','content','\\e992','3','','.w-tabs'),(906429,'watch','.w-product-attributes .attributes','content','\\_','4','','.w-product-attributes'),(906430,'watch','.w-multi-cart-actions .cart-actions .dropdown-toggle','content','\\f013','3','','.w-multi-cart-actions'),(906431,'watch','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(906433,'watch','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(906434,'watch','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(906435,'watch','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(906436,'watch','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(906437,'watch','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(906438,'watch','.btn-edit','content','\\e917','3','',''),(906439,'watch','.b-quantity .qty-box .smaller','content','-','3','','.b-quantity'),(906440,'watch','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(906441,'watch','.w-login-block .cols','content','\\_','4','','.w-login-block'),(906442,'watch','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(906443,'watch','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(906444,'watch','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(906445,'watch','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(906446,'watch','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(906447,'watch','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(906448,'watch','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(906449,'watch','.b-rating .glyphicon-time','content','\\f017','3','','.b-rating'),(906450,'watch','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(906451,'watch','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(906453,'watch','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(906454,'watch','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(906455,'watch','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(906456,'watch','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(906457,'watch','.w-checkout-shipping-choice input:checked + span:before','content','\\_','','','.w-checkout-shipping-choice'),(906458,'watch','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(906459,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(906460,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(906461,'watch','.w-filters .input-checkbox:checked + .checkbox-span:before','content','\\f058','','','.w-filters'),(906462,'watch','.heading-3 .edit, h3 .edit','content','\\e917','4','',''),(906463,'watch','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(906464,'watch','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(906465,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','content','ttr(data-content','4','','.b-switch'),(906466,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','content',' ','3','','.b-switch'),(906467,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','content','ttr(data-content','4','','.b-switch'),(906468,'watch','.b-quantity .qty-box .smaller','content','-','3','','.b-quantity'),(906469,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(906470,'watch','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(906471,'watch','.savings-ico .heading-2','content','\\e95e','3','','.savings-ico'),(906472,'watch','.w-cart-compare .product-actions .dropdown-toggle','content','\\f013','3','','.w-cart-compare'),(906474,'watch','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(906476,'watch','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(906477,'watch','.w-reviews .review','content','\\_','3','','.w-reviews'),(906478,'watch','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(906479,'watch','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(906480,'watch','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(906481,'watch','.js-stock-icon','content','\\f058','3','',''),(906482,'watch','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(906483,'watch','.testimonials .heading-3','content','\\e908','3','',''),(906484,'watch','.b-switch .candlestick-wrapper .fa-check','content','\\f00c','3','','.b-switch'),(906485,'watch','.b-switch .candlestick-wrapper .fa-times','content','\\f00d','3','','.b-switch'),(906486,'watch','.w-product-personal-catalog-button .btn','content','\\f097','3','','.w-product-personal-catalog-button'),(906487,'watch','.b-fancybox .fancybox-prev span','content','\\e900','3','','.b-fancybox'),(906488,'watch','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(906489,'watch','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(906490,'watch','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(906491,'watch','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(906492,'watch','.w-list-b2b .attributes','content','\\_','4','','.w-list-b2b'),(906493,'watch','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(906494,'watch','.w-personal-gift-status-bar .inform','content','\\e6a0','4','','.w-personal-gift-status-bar'),(906495,'watch','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(906496,'watch','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(906497,'watch','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(906498,'watch','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(906499,'watch','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(906500,'watch','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(906501,'watch','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(906502,'watch','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(906503,'watch','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(906504,'watch','.b-info .info','content','\\e918','3','','.b-info'),(906505,'watch','.w-reviews .heading-3','content','\\e908','3','','.w-reviews'),(906506,'watch','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(906507,'watch','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(906508,'watch','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(906509,'watch','.w-social-links .instagram','content','\\f16d','3','','.w-social-links'),(906510,'watch','.w-social-links .linkedin','content','\\f0e1','3','','.w-social-links'),(906511,'watch','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(906512,'watch','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(906513,'watch','.w-login-block .cols','content','\\_','4','','.w-login-block'),(906514,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span:before','content','\\f1db','','','.b-form'),(906515,'watch','.b-info .info','content','\\e918','3','','.b-info'),(906516,'watch','.w-cart-compare .product','content','\\_','4','','.w-cart-compare'),(906517,'watch','.btn-del','content','\\f1f8','4','',''),(906518,'watch','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(906519,'watch','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(906520,'watch','.w-product-personal-catalog-button .btn','content','\\f097','3','','.w-product-personal-catalog-button'),(906521,'watch','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(906522,'watch','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(906523,'watch','.b-rating .glyphicon-star.coloron','content','\\f005','3','','.b-rating'),(906524,'watch','.w-cart-compare .delete-cart','content','\\2573','3','','.w-cart-compare'),(906525,'watch','.w-cart-shipping-estimator .shipping-estimator','content','\\_','4','','.w-cart-shipping-estimator'),(906526,'watch','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(906527,'watch','.b-form .checkbox-style:checked + .checkbox-span:before','content','\\f058','','','.b-form'),(906528,'watch','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(906529,'watch','.b-form .addresses','content','\\_','4','','.b-form'),(906530,'watch','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(906531,'watch','.w-product-personal-catalog-button .btn','content','\\f097','3','','.w-product-personal-catalog-button'),(906532,'watch','.w-cart-credit-amount .btn-remove','content','\\e913','3','','.w-cart-credit-amount'),(906533,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(906534,'watch','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(906535,'watch','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(906536,'watch','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(906537,'watch','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(906538,'watch','.b-info-popup .info-popup','content','\\e918','3','','.b-info-popup'),(906539,'watch','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(906540,'watch','.w-tabs .tab-li.tab-cart a','content','\\e90d','3','','.w-tabs'),(906541,'watch','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(906542,'watch','.b-upload-file .snapshot','content','\\f030','3','','.b-upload-file'),(906543,'watch','.b-bottom .footerTitle','content','\\f068','5232,2,4','','.b-bottom'),(906544,'watch','.b-bottom .pop-up-close','content','\\f00d','3','','.b-bottom'),(906545,'watch','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(906546,'watch','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','content','\\f004','','','.b-products-listing'),(906547,'watch','.w-cart-shipping-estimator .address-item .lastname','content','\\_','4','','.w-cart-shipping-estimator'),(906548,'watch','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','content','\\f08a','','','.b-products-listing'),(906549,'watch','.b-upload-files .remove-file','content','\\f014','3','','.b-upload-files'),(906550,'watch','.w-product-attributes .attributes','content','\\_','4','','.w-product-attributes'),(906551,'watch','.w-reviews-content .review','content','\\_','3','','.w-reviews-content'),(906552,'watch','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(906553,'watch','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(906554,'watch','.w-social-links .facebook','content','\\f09a','3','','.w-social-links'),(906555,'watch','.b-fancybox .fancybox-next span','content','\\e901','3','','.b-fancybox'),(906556,'watch','.b-quantity .qty-box .bigger','content','+','3','','.b-quantity'),(906557,'watch','.w-product-customers-activity .close','content','\\2715','3','','.w-product-customers-activity'),(906558,'watch','.w-product-personal-catalog-button .btn','content','\\f097','3','','.w-product-personal-catalog-button'),(906559,'watch','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(906560,'watch','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(906561,'watch','.w-categories .categories','content','\\_','4','','.w-categories'),(906562,'watch','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(906563,'watch','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(906564,'watch','.w-login-block .cols','content','\\_','4','','.w-login-block'),(906565,'watch','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(906566,'watch','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(906567,'watch','.w-cart-shipping-estimator .item .row: after','content','\\_','','','.w-cart-shipping-estimator'),(906569,'watch','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(906570,'watch','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(906571,'watch','.b-quantity .qty-box .bigger','content','+','3','','.b-quantity'),(906572,'watch','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(906575,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(906576,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(906577,'watch','.w-breadcrumb .breadcrumb-li + .breadcrumb-li','content','/','3','','.w-breadcrumb'),(906578,'watch','.w-social-links .pinterest','content','\\f0d2','3','','.w-social-links'),(906579,'watch','.w-social-links .google-plus','content','\\f2b3','3','','.w-social-links'),(906580,'watch','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(906581,'watch','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(906582,'watch','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(906583,'watch','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(906584,'watch','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(906585,'watch','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(906586,'watch','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(906587,'watch','.w-product-attributes .attributes','content','\\_','4','','.w-product-attributes'),(906588,'watch','.b-rating .glyphicon-chevron-down','content','\\f107','3','','.b-rating'),(906589,'watch','.b-quantity .qty-box .bigger','content','+','3','','.b-quantity'),(906590,'watch','.w-social-links .twitter','content','\\f099','3','','.w-social-links'),(906591,'watch','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(906592,'watch','.w-checkout-create-account .account-benefits strong','content','\\e918','3','','.w-checkout-create-account'),(906593,'watch','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(906594,'watch','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(906595,'watch','.b-products-listing .products-listing .bonus-points-cost','content','\\f219','3','','.b-products-listing'),(906596,'watch','.b-products-listing .products-listing .bonus-points-price','content','\\f219','3','','.b-products-listing'),(906597,'watch','.b-products-listing .products-listing a.btn.view-button','content','\\e991','3','','.b-products-listing'),(906598,'watch','.b-products-listing .BlockBox','content','\\_','4','','.b-products-listing'),(906599,'watch','.b-products-listing .btn-preloader','content','\\f110','3','','.b-products-listing'),(906600,'watch','.b-products-listing .hover-box-content','content','\\_','3','','.b-products-listing'),(906601,'watch','.b-products-listing .loader','content','\\f110','4','','.b-products-listing'),(906602,'watch','.b-products-listing .products-listing','content','\\_','4','','.b-products-listing'),(906603,'watch','.b-products-listing .loader','content','\\_','3','','.b-products-listing'),(906604,'watch','.b-products-listing .products-listing .btn-buy','content','\\e977','3','','.b-products-listing'),(906605,'watch','.b-products-listing .products-listing .qty-input.hidden','content','\\_','3','','.b-products-listing'),(906606,'watch','.checkbox input:not(checked) + span:before','content','\\_','','',''),(906609,'watch','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(906610,'watch','.b-rating .glyphicon-star','content','\\f006','3','','.b-rating'),(906611,'watch','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(906612,'watch','.b-form .hide-box','content','\\_','3','','.b-form'),(906613,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','content','\\_','3','','.b-switch'),(906614,'watch','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','content','\\f10b','3','','.w-checkout-contact-information'),(906615,'watch','.b-info-popup .info-popup div','content','\\_','3','','.b-info-popup'),(906616,'watch','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(906617,'watch','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(906618,'watch','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(906619,'watch','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(906620,'watch','.w-product-attributes .attributes','content','\\_','4','','.w-product-attributes'),(906621,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(906622,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(906623,'watch','.order-summary .price-row.ot_coupon .title','content','%','3','','.order-summary'),(906624,'watch','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(906625,'watch','.b-form .eye-password.eye-password-showed','content','\\f070','3','','.b-form'),(906626,'watch','.b-form .eye-password','content','\\f06e','3','','.b-form'),(906627,'watch','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(906628,'watch','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(906629,'watch','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(906630,'watch','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(906631,'watch','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(906632,'watch','.w-tabs .tab-li.tab-quote a','content','\\e9aa','3','','.w-tabs'),(906633,'watch','.w-product-attributes .attributes','content','\\_','4','','.w-product-attributes'),(906634,'watch','.w-login-block .cols','content','\\_','4','','.w-login-block'),(906635,'watch','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(906636,'watch','.w-personal-gift-status-bar .end-date','content','\\e72b','3','','.w-personal-gift-status-bar'),(906637,'watch','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','content','\\e913','3','','.order-summary'),(906638,'watch','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(906639,'watch','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(906640,'watch','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(906641,'watch','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(906642,'watch','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(906643,'watch','.w-product-cross-sell .buy-all-checker','content','\\f14a','3','','.w-product-cross-sell'),(906644,'watch','.w-catalog-listing-look .b2b','content','\\f0c9','3','','.w-catalog-listing-look'),(906645,'watch','.w-catalog-listing-look .grid','content','\\f009','3','','.w-catalog-listing-look'),(906646,'watch','.checkbox input:checked + span:before','content','\\f00c','','',''),(906647,'watch','.w-cart-listing .multi-product-copy','content','\\e922','3','','.w-cart-listing'),(906648,'watch','.w-cart-listing .multi-product-delete','content','\\e913','3','','.w-cart-listing'),(906649,'watch','.w-cart-listing .multi-product-move','content','\\e975','3','','.w-cart-listing'),(906650,'watch','.w-cart-listing .points-earn','content','\\e9a9','3','','.w-cart-listing'),(906651,'watch','.w-cart-listing .points-redeem','content','\\f219','3','','.w-cart-listing'),(906652,'watch','.w-cart-listing .item .gift-wrap .value','content',')','4','','.w-cart-listing'),(906653,'watch','.w-cart-listing .item .gift-wrap .value','content','(','3','','.w-cart-listing'),(906654,'watch','.w-cart-listing .remove-btn','content','\\e913','3','','.w-cart-listing'),(906655,'watch','.w-cart-give-away .ga_name','content','\\_','4','','.w-cart-give-away'),(906656,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(906657,'watch','.w-breadcrumb .breadcrumb-li + .breadcrumb-li','content','/','3','','.w-breadcrumb'),(906661,'watch','.w-cart-discount-coupon .btn-remove','content','\\e913','3','','.w-cart-discount-coupon'),(906662,'watch','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(906663,'watch','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(906664,'watch','.b-compare .clear_all','content','\\f00d','4','','.b-compare'),(906665,'watch','.w-product-personal-catalog-button .btn','content','\\f097','3','','.w-product-personal-catalog-button'),(906666,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(906667,'watch','.w-filters .open','content','\\f056','3','','.w-filters'),(906668,'watch','.w-checkout-credit-amount .btn-remove','content','\\e913','3','','.w-checkout-credit-amount'),(906669,'watch','.w-filters .fsl_handle','content','\\_','4','','.w-filters'),(906670,'watch','.w-filters .view_more','content','\\f061','4','','.w-filters'),(906671,'watch','.w-filters span.close','content','\\f055','3','','.w-filters'),(906672,'watch','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(906673,'watch','.w-breadcrumb .breadcrumb-li + .breadcrumb-li','content','/','3','','.w-breadcrumb'),(906674,'watch','.w-catalog-listing-look .list','content','\\f00b','3','','.w-catalog-listing-look'),(906675,'watch','.order-summary .heading-2','content','\\e922','3','','.order-summary'),(906676,'watch','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(906677,'watch','.w-product-attributes .attributes','content','\\_','4','','.w-product-attributes'),(906678,'watch','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(906679,'watch','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(906680,'watch','.b-quantity .qty-box .smaller','content','-','3','','.b-quantity'),(906681,'watch','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(906682,'watch','.w-login-block .cols','content','\\_','4','','.w-login-block'),(906683,'watch','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(906684,'watch','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(906685,'watch','.b-rating .glyphicon-calendar','content','\\f073','3','','.b-rating'),(906686,'watch','.w-filters .mobileCollapse','content','\\f056','2,4','','.w-filters'),(906687,'watch','.w-filters .mobileCollapse','content','\\f055','4','','.w-filters'),(906688,'watch','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','content','\\f1db','','','.w-filters'),(906689,'watch','.b-product-images .media-popup .mp-close','content','\\f00d','3','','.b-product-images'),(906690,'watch','.b-product-images .media-popup .slick-dots li','content','\\2022','3','','.b-product-images'),(906691,'watch','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','content','\\f0c9','3','','.b-menu-burger_icon'),(906692,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(906693,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(906694,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(906695,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(906696,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(906697,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(906698,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(906699,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(906700,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(906701,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(906702,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','content','\\f107','4','','.b-menu-style-1'),(906703,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > .no-link','content','\\f105','4','','.b-menu-style-1'),(906704,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','content','\\f105 \\f105','4','','.b-menu-style-1'),(906705,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','content','\\f00d','3','','.b-menu-style-2'),(906706,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','content','\\_','3','','.b-menu-style-2'),(906707,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','content','\\f105','3','','.b-menu-style-2'),(906708,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','content','\\_','3','','.b-menu-style-2'),(906709,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','content','\\f104','3','','.b-menu-style-2'),(906710,'watch','.b-trade-approval .columns','content','\\_','4','','.b-trade-approval'),(906711,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','content','\\e90d','3','','.w-catalog-compare'),(906712,'watch','.w-catalog-compare td span + span','content','| ','3','','.w-catalog-compare'),(906713,'watch','.w-catalog-compare .checkbox input:checked + span:before','content','\\f014','','','.w-catalog-compare'),(906714,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','content','\\f1db','','','.w-filters'),(906715,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','content','\\f058','','','.w-filters'),(906716,'watch','.order-summary .icon','content','\\f067','3','','.order-summary'),(906717,'watch','.order-summary .icon.opened','content','\\f068','3','','.order-summary'),(906718,'watch','.w-cart-checkout-btn .with-card','content','\\f283','4','','.w-cart-checkout-btn'),(906719,'watch','.w-cart-discount-coupon .title','content','\\f107','4','','.w-cart-discount-coupon'),(906720,'watch','.w-cart-discount-coupon .title.opened','content','\\f106','4','','.w-cart-discount-coupon'),(906742,'watch','.catalog-product-wrap .next-product .pn-image','content','\\f054','3','','.catalog-product-wrap'),(906743,'watch','.catalog-product-wrap .prev-product .pn-image','content','\\f053','3','','.catalog-product-wrap'),(906744,'watch','.checkout-index-wrap .comment-ico','content','\\e99d','3','','.checkout-index-wrap'),(906745,'watch','.checkout-index-wrap .discount-ico','content','\\e95e','3','','.checkout-index-wrap'),(906746,'watch','.checkout-index-wrap .order-ico','content','\\e922','3','','.checkout-index-wrap'),(906747,'watch','.checkout-index-wrap .pay-ico','content','\\e99e','3','','.checkout-index-wrap'),(906748,'watch','.checkout-index-wrap .ship-ico','content','\\e94e','3','','.checkout-index-wrap'),(906749,'watch','.checkout-success-wrap .page-success','content','\\_','3','','.checkout-success-wrap'),(906750,'watch','.checkout-success-wrap .page-success .text-1','content','\\e916','3','','.checkout-success-wrap'),(906751,'watch','.shopping-cart-index .gift-code .heading-4','content','\\f068','','','.shopping-cart-index'),(906752,'watch','.shopping-cart-index .gift-code .heading-4','content','\\f067','4','','.shopping-cart-index'),(906753,'watch','.account-order-pay .historyInfoColumn h2.title-delivery-address, .account-order-pay .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-order-pay'),(906754,'watch','.account-order-pay .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-order-pay'),(906755,'watch','.account-order-pay .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-order-pay'),(906756,'watch','.account-samples .view_link','content','\\e901','4','','.account-samples'),(906757,'watch','.account-sample-info .historyInfoColumn h2.title-delivery-address, .account-sample-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-sample-info'),(906758,'watch','.account-sample-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-sample-info'),(906759,'watch','.account-sample-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-sample-info'),(906760,'watch','.checkout-order-confirmation .comment-ico','content','\\e99d','3','','.checkout-order-confirmation'),(906761,'watch','.checkout-order-confirmation .discount-ico','content','\\e95e','3','','.checkout-order-confirmation'),(906762,'watch','.checkout-order-confirmation .order-ico','content','\\e922','3','','.checkout-order-confirmation'),(906763,'watch','.checkout-order-confirmation .pay-ico','content','\\e99e','3','','.checkout-order-confirmation'),(906764,'watch','.checkout-order-confirmation .prod-ico','content','\\e99b','3','','.checkout-order-confirmation'),(906765,'watch','.checkout-order-confirmation .ship-ico','content','\\e94e','3','','.checkout-order-confirmation'),(906766,'watch','.b-slick .slick-dots li','content','\\_','3','','.b-slick'),(906768,'watch','.success-page .check-ico-block','content','\\e916','3','','.success-page'),(906769,'watch','.success-page .comment-ico','content','\\e99d','3','','.success-page'),(906770,'watch','.success-page .discount-ico','content','\\e95e','3','','.success-page'),(906771,'watch','.success-page .order-ico','content','\\e922','3','','.success-page'),(906772,'watch','.success-page .page-success','content','\\_','3','','.success-page'),(906773,'watch','.success-page .page-success .text-1','content','\\e916','3','','.success-page'),(906774,'watch','.success-page .pay-ico','content','\\e99e','3','','.success-page'),(906775,'watch','.success-page .prod-ico','content','\\e99b','3','','.success-page'),(906776,'watch','.success-page .ship-ico','content','\\e94e','3','','.success-page'),(906777,'watch','.w-product-quantity-discounts .quantity-discounts .count','content','+','4','','.w-product-quantity-discounts'),(906778,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-content','content','\\_','4','','.b-multi-page-checkout'),(906779,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','content','\\f00c','3','','.b-multi-page-checkout'),(906780,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','content','\\e917','4','','.b-multi-page-checkout'),(906784,'watch','.w-bestsellers .heading-3','content','\\e903','3','','.w-bestsellers'),(906785,'watch','.w-bestsellers .item','content','\\e90b','3','','.w-bestsellers'),(906786,'watch','.w-bestsellers .item:first-child:before','content','\\e90c','','','.w-bestsellers'),(906787,'watch','.w-account-customer-additional-field .tf-file .remove','content','\\2716','3','','.w-account-customer-additional-field'),(906788,'watch','.b-slick .slick-track, .b-slick .slick-track:after','content','\\_','3','','.b-slick'),(906789,'watch','.b-slick .slick-vertical button.slick-next','content','\\f078','3','','.b-slick'),(906790,'watch','.b-slick .slick-vertical button.slick-prev','content','\\f077','3','','.b-slick'),(906791,'watch','.b-slick button.slick-next','content','\\f054','3','','.b-slick'),(906792,'watch','.b-slick button.slick-prev','content','\\f053','3','','.b-slick'),(906793,'watch','.w-catalog-paging .next','content','\\f105','3','','.w-catalog-paging'),(906794,'watch','.w-catalog-paging .prev','content','\\f104','3','','.w-catalog-paging'),(906795,'watch','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(906796,'watch','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(906797,'watch','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(906798,'watch','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(906799,'watch','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(906800,'watch','.b-rating .glyphicon-chevron-left','content_important','important','3','','.b-rating'),(906801,'watch','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(906802,'watch','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(906803,'watch','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(906804,'watch','.b-rating .glyphicon-chevron-right','content_important','important','3','','.b-rating'),(906805,'watch','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(906806,'watch','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(906807,'watch','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(906808,'watch','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(906809,'watch','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(906810,'watch','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(906811,'watch','.b-rating .glyphicon-chevron-up','content_important','important','3','','.b-rating'),(906812,'watch','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(906813,'watch','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(906814,'watch','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(906815,'watch','.b-rating .glyphicon-chevron-down','content_important','important','3','','.b-rating'),(906816,'watch','.b-rating .glyphicon-calendar','content_important','important','3','','.b-rating'),(906817,'watch','.b-rating .glyphicon-time','content_important','important','3','','.b-rating'),(906818,'watch','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(906819,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor','default','','','.b-switch'),(906820,'watch','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(906821,'watch','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(906822,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','cursor','pointer','','','.b-switch'),(906823,'watch','.p-quick-order-index .filters .clear','cursor','pointer','','','.p-quick-order-index'),(906824,'watch','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','cursor','pointer','3','','.order-summary'),(906825,'watch','.b-messages .messMenuButton span','cursor','pointer','','','.b-messages'),(906826,'watch','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(906827,'watch','.b-fancybox #fancybox-loading','cursor','pointer','','','.b-fancybox'),(906828,'watch','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(906829,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file','cursor','pointer','','','.w-upload-customer-id-upload-customer-id-form'),(906830,'watch','.b-switch .bootstrap-switch','cursor','pointer','','','.b-switch'),(906831,'watch','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(906832,'watch','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(906833,'watch','.w-coupons-and-vauchers-checkout .btn-remove','cursor','pointer','','','.w-coupons-and-vauchers-checkout'),(906834,'watch','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(906835,'watch','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(906836,'watch','.b-autocomplete .ui-autocomplete li','cursor','pointer','','','.b-autocomplete'),(906837,'watch','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(906838,'watch','.w-filters .open, .w-filters .close','cursor','pointer','','','.w-filters'),(906839,'watch','.w-checkout-shipping-choice span','cursor','pointer','','','.w-checkout-shipping-choice'),(906840,'watch','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(906841,'watch','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(906842,'watch','.w-cart-compare .atr-col','cursor','pointer','','','.w-cart-compare'),(906843,'watch','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(906844,'watch','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(906845,'watch','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(906846,'watch','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(906847,'watch','.w-tabs .tab-a','cursor','pointer','','','.w-tabs'),(906848,'watch','.w-tabs .tab-a','cursor','default','2','','.w-tabs'),(906849,'watch','.disabled-area','cursor','not-allowed','','',''),(906850,'watch','.disabled-area *','cursor','not-allowed','','',''),(906851,'watch','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(906852,'watch','.b-form .radio-button input[type=\"radio\"].no + span','cursor','pointer','3','','.b-form'),(906853,'watch','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','cursor','pointer','','','.b-switch'),(906854,'watch','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','','','.b-select-suggest'),(906855,'watch','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','1','','.b-select-suggest'),(906856,'watch','.b-switch .candlestick-wrapper .candlestick-bg.grab:not(.candlestick-disabled ) .candlestick-toggle','cursor','grab','','','.b-switch'),(906857,'watch','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled','cursor','not-allowed','','','.b-switch'),(906858,'watch','.b-fancybox .fancybox-close','cursor','pointer','','','.b-fancybox'),(906859,'watch','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(906860,'watch','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','cursor','default','','','.b-select-suggest'),(906861,'watch','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(906862,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor','default','','','.b-switch'),(906863,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor','default','','','.b-switch'),(906864,'watch','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(906865,'watch','.w-checkout-credit-amount .btn-remove','cursor','pointer','','','.w-checkout-credit-amount'),(906866,'watch','.b-upload-file .snapshot','cursor','pointer','','','.b-upload-file'),(906867,'watch','.b-form .item-radio label','cursor','pointer','','','.b-form'),(906868,'watch','.b-bottom .footerTitle','cursor','pointer','5232','','.b-bottom'),(906869,'watch','.b-products-listing .products-listing .wishlistButton .checkbox','cursor','pointer','','','.b-products-listing'),(906870,'watch','.w-cart-credit-amount .btn-remove','cursor','pointer','','','.w-cart-credit-amount'),(906871,'watch','.w-product-customers-activity .close','cursor','pointer','','','.w-product-customers-activity'),(906872,'watch','.b-form .item-radio.active label','cursor','default','','','.b-form'),(906873,'watch','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(906874,'watch','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(906875,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor','default','','','.b-switch'),(906876,'watch','.b-fancybox .fancybox-nav','cursor','pointer','','','.b-fancybox'),(906877,'watch','.closeable-event','cursor','pointer','','',''),(906878,'watch','.b-form .addresses.address-main .address-item label','cursor','default','','','.b-form'),(906879,'watch','.w-checkout-shipping-choice input:checked + span','cursor','default','','','.w-checkout-shipping-choice'),(906880,'watch','.w-tabs .accordion-heading','cursor','default','2','','.w-tabs'),(906881,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','cursor','default','','','.b-select-suggest'),(906882,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-chosen','cursor','default','','','.b-select-suggest'),(906883,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','cursor','default','','','.b-select-suggest'),(906884,'watch','.b-select-suggest .select2-container-multi .select2-choices','cursor','text','','','.b-select-suggest'),(906885,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','cursor','default','','','.b-select-suggest'),(906886,'watch','.b-select-suggest .select2-results .select2-disabled','cursor','default','','','.b-select-suggest'),(906887,'watch','.b-select-suggest .select2-results .select2-result-label','cursor','pointer','','','.b-select-suggest'),(906888,'watch','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(906889,'watch','.b-form .eye-password','cursor','pointer','','','.b-form'),(906890,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','cursor','pointer','','','.w-communication-new-topic'),(906891,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','cursor','pointer','','','.w-communication-new-topic'),(906892,'watch','.w-filters .ui-slider-handle','cursor','pointer','','','.w-filters'),(906893,'watch','.w-cart-discount-coupon .btn-remove','cursor','pointer','','','.w-cart-discount-coupon'),(906894,'watch','.b-fancybox .fancybox-nav span','cursor','pointer','','','.b-fancybox'),(906895,'watch','.w-tabs .accordion-heading','cursor','pointer','','','.w-tabs'),(906896,'watch','.w-filters .filter-box-content ul li.view_items','cursor','pointer','','','.w-filters'),(906897,'watch','.b-bottom .pop-up-close','cursor','pointer','','','.b-bottom'),(906898,'watch','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(906899,'watch','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(906900,'watch','.b-upload-files .remove-file','cursor','pointer','','','.b-upload-files'),(906901,'watch','.w-menu-big .show-all','cursor','pointer','','','.w-menu-big'),(906902,'watch','.b-form .addresses .address-item label','cursor','pointer','','','.b-form'),(906903,'watch','.w-filters .mobileCollapse','cursor','pointer','4','','.w-filters'),(906904,'watch','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','cursor','pointer','','','.b-product-images'),(906905,'watch','.b-product-images .media-popup .mp-close','cursor','pointer','','','.b-product-images'),(906906,'watch','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','cursor','pointer','','','.b-product-images'),(906907,'watch','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','cursor','pointer','','','.b-menu-burger_icon'),(906908,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(906909,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(906910,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(906911,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(906912,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(906913,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','cursor','pointer','','','.b-menu-style-2'),(906914,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','cursor','pointer','','','.b-menu-style-2'),(906915,'watch','.w-account-personal-catalog .list-switcher a','cursor','pointer','','','.w-account-personal-catalog'),(906916,'watch','.w-account-personal-catalog .list-switcher a','cursor','default','2','','.w-account-personal-catalog'),(906917,'watch','.w-catalog-compare .compare label','cursor','pointer','','','.w-catalog-compare'),(906918,'watch','.w-catalog-compare .cross-box .different-all > div','cursor','pointer','','','.w-catalog-compare'),(906919,'watch','.w-catalog-compare .cross-box .different-all > div','cursor','default','2','','.w-catalog-compare'),(906920,'watch','.w-catalog-compare .cross-box .return','cursor','pointer','','','.w-catalog-compare'),(906921,'watch','.order-summary .icon','cursor','pointer','','','.order-summary'),(906922,'watch','.w-cart-discount-coupon .title','cursor','pointer','','','.w-cart-discount-coupon'),(906925,'watch','.shopping-cart-index .gift-code .heading-4','cursor','pointer','5232','','.shopping-cart-index'),(906926,'watch','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-order-pay'),(906927,'watch','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-order-pay'),(906928,'watch','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-sample-info'),(906929,'watch','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-sample-info'),(906930,'watch','.b-slick .slick-dots li','cursor','pointer','','','.b-slick'),(906931,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','cursor','pointer','','','.b-multi-page-checkout'),(906933,'watch','.w-account-customer-additional-field .tf-file .remove','cursor','pointer','','','.w-account-customer-additional-field'),(906934,'watch','.b-slick button.slick-disabled','cursor','default','','','.b-slick'),(906935,'watch','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(906936,'watch','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(906937,'watch','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(906938,'watch','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(906939,'watch','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(906940,'watch','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(906941,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor_important','important','','','.b-switch'),(906942,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor_important','important','','','.b-switch'),(906943,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor_important','important','','','.b-switch'),(906944,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor_important','important','','','.b-switch'),(906945,'watch','.b-switch .bootstrap-switch','direction','ltr','','','.b-switch'),(906946,'watch','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(906947,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(906948,'watch','.b-info .info','display','inline-block','3','','.b-info'),(906949,'watch','.message.success','display','inline-block','3','',''),(906950,'watch','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(906951,'watch','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(906954,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(906955,'watch','.w-filters .mobileCollapse','display','inline-block','5240','','.w-filters'),(906956,'watch','.p-quick-order-index ul.token-input-list','display','inline-block','','','.p-quick-order-index'),(906957,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.p-quick-order-index'),(906958,'watch','.w-promotions .promo-salemaker .content a.name','display','block','','','.w-promotions'),(906959,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.p-quick-order-index'),(906960,'watch','.w-promotions .prom-multi-discount .promo-range > div','display','inline-block','','','.w-promotions'),(906961,'watch','.w-promotions .promo-salemaker','display','flex','','','.w-promotions'),(906962,'watch','.w-promotions .promo-cart-discount .promo-min-qty','display','inline-block','','','.w-promotions'),(906963,'watch','.w-promotions .promo-date > div','display','inline-block','','','.w-promotions'),(906964,'watch','.w-promotions .promo-cart-discount','display','flex','','','.w-promotions'),(906975,'watch','.p-sample-checkout-success .page-success .text-1','display','block','3','','.p-sample-checkout-success'),(906976,'watch','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(906977,'watch','.w-promotions .prom-multi-discount','display','block','4','','.w-promotions'),(906978,'watch','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(906979,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(906980,'watch','.testimonials .review','display','block','3','',''),(906981,'watch','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(906982,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(906983,'watch','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(906984,'watch','.w-categories .image','display','block','','','.w-categories'),(906985,'watch','.w-promotions .prom-multi-discount .promo-range','display','inline-block','','','.w-promotions'),(906986,'watch','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','display','block','','','.w-promotions'),(906987,'watch','.w-promotions .prom-multi-discount .products','display','grid','','','.w-promotions'),(906988,'watch','.w-promotions .prom-multi-discount .list','display','grid','','','.w-promotions'),(906989,'watch','.w-promotions .nextdiscount .promo-for-each','display','inline-block','','','.w-promotions'),(906990,'watch','.w-promotions .nextdiscount .item-holder','display','flex','','','.w-promotions'),(906991,'watch','.w-promotions .nextdiscount .content','display','grid','','','.w-promotions'),(906992,'watch','.w-promotions .heading-3','display','inline-block','','','.w-promotions'),(906993,'watch','.w-promotions .icon','display','inline-block','','','.w-promotions'),(906994,'watch','.w-promotions .promo-salemaker .discount','display','inline-block','','','.w-promotions'),(906995,'watch','.w-promotions .promo-salemaker .content','display','flex','','','.w-promotions'),(906996,'watch','.w-promotions .promo-content > .personalgift','display','none','','','.w-promotions'),(906997,'watch','.w-promotions .promo-cart-discount .slave','display','flex','','','.w-promotions'),(906998,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','display','inline-block','','','.w-promotions'),(906999,'watch','.w-promotions .promo-cart-discount .item a','display','block','','','.w-promotions'),(907000,'watch','.w-promotions .promo-cart-discount .content','display','flex','','','.w-promotions'),(907001,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','display','inline-block','','','.b-warehouses-popup'),(907002,'watch','.w-product-available-in-warehouses .content','display','block','4','','.w-product-available-in-warehouses'),(907003,'watch','.b-preloader .preloader','display','inline-block','3','','.b-preloader'),(907004,'watch','.w-product-available-in-warehouses .warehouse-item','display','inline-block','','','.w-product-available-in-warehouses'),(907005,'watch','.b-products-listing .products-listing .mix-attributes','display','block','4','','.b-products-listing'),(907006,'watch','.b-products-listing .products-listing .attribute-qty-blocks','display','flex','','','.b-products-listing'),(907007,'watch','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(907008,'watch','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(907009,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(907012,'watch','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(907013,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(907014,'watch','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(907016,'watch','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(907017,'watch','.b-messages .messBtnMenuDelete','display','inline-block','3','','.b-messages'),(907018,'watch','.b-messages .messMenuButton span','display','inline-block','','','.b-messages'),(907019,'watch','.b-messages .msv_to_cc div span','display','inline-block','','','.b-messages'),(907020,'watch','.b-messages span.starred::before','display','inline-block','','','.b-messages'),(907021,'watch','.b-messages .dataTables_wrapper > .top','display','block','4','','.b-messages'),(907022,'watch','.b-messages .messBtnMenuStarred','display','inline-block','3','','.b-messages'),(907023,'watch','.b-messages .messBtnMenuUnread','display','inline-block','3','','.b-messages'),(907024,'watch','.b-messages .messages-menu li a','display','block','','','.b-messages'),(907025,'watch','.b-messages .content_management_attach button','display','inline-block','','','.b-messages'),(907026,'watch','.b-messages .email-line','display','flex','','','.b-messages'),(907027,'watch','.b-messages .dataTables_wrapper > .bottom','display','block','4','','.b-messages'),(907028,'watch','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(907029,'watch','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(907030,'watch','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(907031,'watch','.w-product-properties li','display','table-cell','','','.w-product-properties'),(907032,'watch','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(907033,'watch','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(907034,'watch','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(907035,'watch','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(907037,'watch','.order-summary .price-row.ot_gv .title','display','inline-block','3','','.order-summary'),(907038,'watch','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(907039,'watch','.w-product-collection .together','display','block','','','.w-product-collection'),(907040,'watch','.w-sitemap-delivery-location > ul > li > ul','display','flex','','','.w-sitemap-delivery-location'),(907041,'watch','.w-checkout-terms .required-message-wrap','display','inline-block','','','.w-checkout-terms'),(907042,'watch','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(907043,'watch','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(907044,'watch','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(907045,'watch','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(907046,'watch','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(907047,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','display','inline-block','','','.b-switch'),(907048,'watch','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(907049,'watch','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(907050,'watch','.w-product-reviews .reviews-list .review','display','block','3','','.w-product-reviews'),(907051,'watch','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(907052,'watch','.b-info-popup .info-popup','display','inline-block','','','.b-info-popup'),(907053,'watch','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(907054,'watch','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(907055,'watch','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(907056,'watch','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(907057,'watch','.p-quick-order-index .quick-order-total','display','flex','','','.p-quick-order-index'),(907058,'watch','.w-upload-customer-id-upload-customer-id-form .dz-details ~ div','display','none','','','.w-upload-customer-id-upload-customer-id-form'),(907059,'watch','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','display','flex','','','.w-upload-customer-id-upload-customer-id-form'),(907060,'watch','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(907061,'watch','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(907062,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(907063,'watch','.w-login-block .cols','display','block','4','','.w-login-block'),(907064,'watch','.w-login-block .label','display','block','','','.w-login-block'),(907065,'watch','.w-menu-horizontal li','display','inline-block','','','.w-menu-horizontal'),(907066,'watch','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','display','inline-block','','','.w-menu-horizontal'),(907067,'watch','.w-menu-horizontal li li a, .w-menu-horizontal li li .no-link','display','block','','','.w-menu-horizontal'),(907068,'watch','.w-tabs .tab-navigation','display','table','','','.w-tabs'),(907069,'watch','.w-product-configurator .item-content > div','display','block','5232','','.w-product-configurator'),(907070,'watch','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(907071,'watch','.b-form .payment-method .item-radio label','display','block','','','.b-form'),(907072,'watch','.w-quote .cart-box-link','display','block','','','.w-quote'),(907073,'watch','.w-personal-gift-status-bar .inform','display','inline-block','4','','.w-personal-gift-status-bar'),(907074,'watch','.w-product-configurator .item-content > div','display','block','5232','','.w-product-configurator'),(907075,'watch','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(907076,'watch','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(907077,'watch','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(907078,'watch','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(907079,'watch','.w-promo-code .promo-text-2','display','none','5240','','.w-promo-code'),(907080,'watch','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(907081,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(907082,'watch','.b-switch .bootstrap-switch','display','inline-block','','','.b-switch'),(907083,'watch','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(907084,'watch','.w-social-links .name, .w-social-links .image','display','none','','','.w-social-links'),(907086,'watch','.buttons','display','block','4','',''),(907087,'watch','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(907088,'watch','.w-login-block .label','display','block','','','.w-login-block'),(907089,'watch','.w-product-properties li','display','table-cell','','','.w-product-properties'),(907090,'watch','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(907091,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(907092,'watch','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(907094,'watch','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(907095,'watch','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(907096,'watch','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(907097,'watch','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(907098,'watch','.w-login-block .cols','display','block','4','','.w-login-block'),(907099,'watch','.w-product-collection .together','display','block','','','.w-product-collection'),(907100,'watch','.w-filters .input-checkbox:checked + .checkbox-span','display','inline-block','','','.w-filters'),(907101,'watch','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(907102,'watch','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(907103,'watch','.b-switch .candlestick-wrapper','display','inline-block','','','.b-switch'),(907104,'watch','.w-catalog-listing-look .listing-look-title','display','inline-block','','','.w-catalog-listing-look'),(907105,'watch','.b-bottom .footerTitle ~ div','display','none','5232','','.b-bottom'),(907106,'watch','.b-info .info','display','inline-block','3','','.b-info'),(907107,'watch','.w-checkout-billing-address .genders-title > div','display','inline-block','','','.w-checkout-billing-address'),(907108,'watch','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(907109,'watch','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(907110,'watch','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(907111,'watch','.b-select-suggest .select2-display-none','display','none','','','.b-select-suggest'),(907112,'watch','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(907113,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','3','','.b-select-suggest'),(907114,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','display','none','','','.b-select-suggest'),(907115,'watch','.w-checkout-shipping-choice span','display','flex','','','.w-checkout-shipping-choice'),(907116,'watch','.w-menu-big li a, .w-menu-big li .no-link','display','inline-block','','','.w-menu-big'),(907117,'watch','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(907118,'watch','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(907119,'watch','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(907120,'watch','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(907121,'watch','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(907122,'watch','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(907123,'watch','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(907124,'watch','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(907125,'watch','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(907126,'watch','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(907127,'watch','.w-cart-compare .product','display','block','4','','.w-cart-compare'),(907128,'watch','.w-top-categories .categories','display','block','4','','.w-top-categories'),(907129,'watch','.w-top-categories .categories','display','flex','','','.w-top-categories'),(907130,'watch','.b-info-popup .info-popup div','display','none','','','.b-info-popup'),(907131,'watch','.w-checkout-billing-address .addresses','display','block','4','','.w-checkout-billing-address'),(907132,'watch','.w-promo-code .promo-text-2','display','none','5240','','.w-promo-code'),(907133,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(907135,'watch','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(907136,'watch','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(907137,'watch','.w-image-maps .default-links .item .description','display','block','','','.w-image-maps'),(907138,'watch','.w-image-maps .float-items .item','display','block','1','','.w-image-maps'),(907139,'watch','.w-image-maps .default-links .item .title','display','block','','','.w-image-maps'),(907140,'watch','.b-upload-file .upload-file-template','display','inline-block','','','.b-upload-file'),(907141,'watch','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(907142,'watch','.b-info .info','display','inline-block','3','','.b-info'),(907143,'watch','.w-checkout-shipping-address .addresses','display','block','4','','.w-checkout-shipping-address'),(907144,'watch','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(907145,'watch','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(907146,'watch','.w-quote .cart-box-link','display','inline-block','3','','.w-quote'),(907147,'watch','.w-product-configurator .item-content > div','display','block','5232','','.w-product-configurator'),(907148,'watch','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(907149,'watch','.w-product-quantity .product-quantity-label','display','none','','','.w-product-quantity'),(907150,'watch','.w-multi-cart-actions .cart-actions .dropdown-toggle','display','inline-block','','','.w-multi-cart-actions'),(907151,'watch','.w-tabs .tab-li.tab-wishlist a','display','block','3','','.w-tabs'),(907152,'watch','.w-product-attributes .attributes','display','block','4','','.w-product-attributes'),(907153,'watch','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(907154,'watch','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(907155,'watch','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(907156,'watch','.w-top-categories .item','display','inline-block','','','.w-top-categories'),(907158,'watch','.w-tabs .tab-a','display','block','','','.w-tabs'),(907159,'watch','.w-tabs > .block > .box .heading-2, .w-tabs > .block > .box .heading-3, .w-tabs > .block > .box .heading-4','display','none','','','.w-tabs'),(907160,'watch','.w-tabs .tab-li','display','table-cell','','','.w-tabs'),(907161,'watch','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(907163,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(907166,'watch','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(907167,'watch','.b-form .payment-method .item-radio label span','display','block','','','.b-form'),(907168,'watch','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(907169,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','display','block','3','','.b-switch'),(907170,'watch','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(907171,'watch','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(907172,'watch','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(907173,'watch','.w-login-block .cols','display','block','4','','.w-login-block'),(907174,'watch','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(907175,'watch','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(907176,'watch','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(907177,'watch','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(907178,'watch','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(907179,'watch','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(907180,'watch','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(907181,'watch','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(907182,'watch','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(907183,'watch','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(907184,'watch','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(907185,'watch','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(907186,'watch','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(907187,'watch','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(907188,'watch','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(907189,'watch','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(907190,'watch','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(907191,'watch','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(907192,'watch','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(907193,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','display','inline-block','','','.b-switch'),(907194,'watch','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(907195,'watch','.w-login-block .label','display','block','','','.w-login-block'),(907196,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(907197,'watch','.w-filters .filter-widget-horizontal .content-filter-widget','display','table','','','.w-filters'),(907198,'watch','.w-filters .filter-widget-horizontal .filter-box','display','table-cell','','','.w-filters'),(907199,'watch','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(907200,'watch','.b-products-listing .products-listing .bonus-points','display','flex','','','.b-products-listing'),(907201,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','display','inline-block','','','.b-switch'),(907202,'watch','.w-checkout-shipping-address .genders-title label','display','inline-block','','','.w-checkout-shipping-address'),(907203,'watch','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(907204,'watch','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','display','inline-block','3','','.w-checkout-contact-information'),(907205,'watch','.order-summary .price-row','display','none','','','.order-summary'),(907206,'watch','.w-cart-listing .points-earn','display','inline-block','','','.w-cart-listing'),(907207,'watch','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(907209,'watch','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(907210,'watch','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(907211,'watch','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(907212,'watch','.w-product-attributes .attributes','display','block','4','','.w-product-attributes'),(907213,'watch','.w-multi-cart-actions .cart-actions','display','inline-block','','','.w-multi-cart-actions'),(907214,'watch','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(907215,'watch','.b-select-suggest .select2-container.select2-allowclear .select2-choice abbr','display','inline-block','','','.b-select-suggest'),(907216,'watch','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(907217,'watch','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(907219,'watch','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(907220,'watch','.w-reviews .item','display','grid','','','.w-reviews'),(907221,'watch','.w-promo-code .holder','display','block','4','','.w-promo-code'),(907222,'watch','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(907223,'watch','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(907224,'watch','.w-image-maps .default-links .item','display','block','1','','.w-image-maps'),(907225,'watch','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(907226,'watch','.w-product-configurator .item-content','display','block','5232','','.w-product-configurator'),(907227,'watch','.w-product-configurator .item-content > div','display','block','5232','','.w-product-configurator'),(907228,'watch','.w-checkout-shipping-choice input:checked + span:before','display','block','','','.w-checkout-shipping-choice'),(907229,'watch','.w-checkout-create-account .columns .col-2:nth-child(2n)','display','none','5240','','.w-checkout-create-account'),(907230,'watch','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(907231,'watch','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(907232,'watch','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(907233,'watch','.w-top-categories .image','display','block','','','.w-top-categories'),(907234,'watch','.w-cart-compare .delete-cart','display','inline-block','','','.w-cart-compare'),(907235,'watch','.b-fancybox .fancybox-overlay','display','none','','','.b-fancybox'),(907236,'watch','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(907237,'watch','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(907238,'watch','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(907239,'watch','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(907240,'watch','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(907241,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(907242,'watch','.w-product-quantity .product-quantity-label','display','none','','','.w-product-quantity'),(907243,'watch','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(907244,'watch','.w-product-properties li','display','table-cell','','','.w-product-properties'),(907245,'watch','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(907246,'watch','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(907247,'watch','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(907248,'watch','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(907249,'watch','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(907250,'watch','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(907251,'watch','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(907252,'watch','.w-product-collection .together','display','block','','','.w-product-collection'),(907253,'watch','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(907254,'watch','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(907255,'watch','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(907256,'watch','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(907257,'watch','.w-list-b2b .attributes','display','block','4','','.w-list-b2b'),(907258,'watch','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(907259,'watch','.w-product-configurator .item-content','display','block','5232','','.w-product-configurator'),(907260,'watch','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(907266,'watch','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(907268,'watch','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(907269,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(907270,'watch','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(907271,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(907272,'watch','.w-promo-code .holder','display','block','4','','.w-promo-code'),(907273,'watch','.w-catalog-sorting .sorting','display','flex','','','.w-catalog-sorting'),(907274,'watch','.w-promo-code .promo-text-2','display','none','5240','','.w-promo-code'),(907275,'watch','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(907276,'watch','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(907277,'watch','.b-info .info','display','inline-block','3','','.b-info'),(907278,'watch','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(907279,'watch','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(907280,'watch','.b-select-suggest .select2-container .select2-choice abbr','display','none','','','.b-select-suggest'),(907281,'watch','.b-select-suggest .select2-container .select2-choice > .select2-chosen','display','block','','','.b-select-suggest'),(907282,'watch','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(907283,'watch','.b-select-suggest .select2-container .select2-choice','display','block','','','.b-select-suggest'),(907284,'watch','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','display','list-item','','','.b-select-suggest'),(907285,'watch','.b-select-suggest .select2-container','display','inline-block','','','.b-select-suggest'),(907286,'watch','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(907287,'watch','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(907288,'watch','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(907289,'watch','.w-checkout-shipping .sub-item','display','block','','','.w-checkout-shipping'),(907290,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','display','inline-block','','','.b-switch'),(907291,'watch','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(907292,'watch','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(907293,'watch','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(907295,'watch','.w-login-block .label','display','block','','','.w-login-block'),(907296,'watch','.w-login-block .cols','display','block','4','','.w-login-block'),(907297,'watch','.w-product-configurator .item-content','display','block','5232','','.w-product-configurator'),(907298,'watch','.w-cart-shipping-estimator .item .row: after','display','block','','','.w-cart-shipping-estimator'),(907299,'watch','.w-categories h2.name','display','block','','','.w-categories'),(907300,'watch','.b-info .info','display','inline-block','3','','.b-info'),(907302,'watch','.w-product-collection .together','display','block','','','.w-product-collection'),(907303,'watch','.w-cart-compare .js-cart_totals_container b','display','block','','','.w-cart-compare'),(907304,'watch','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(907305,'watch','.b-form .middle-form .col-gender label','display','inline-block','','','.b-form'),(907306,'watch','.b-form .login-cols','display','flex','','','.b-form'),(907307,'watch','.b-form .payment-method .sub-item span','display','block','','','.b-form'),(907308,'watch','.b-form .checkbox-style:checked + .checkbox-span','display','inline-block','','','.b-form'),(907309,'watch','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(907310,'watch','.w-cart-shipping-estimator .shipping-estimator','display','block','4','','.w-cart-shipping-estimator'),(907311,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(907312,'watch','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(907313,'watch','.b-fancybox .fancybox-title-float-wrap .child','display','inline-block','','','.b-fancybox'),(907314,'watch','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(907315,'watch','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(907316,'watch','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(907317,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(907318,'watch','.w-product-properties li','display','table-cell','','','.w-product-properties'),(907319,'watch','.w-checkout-credit-amount .btn-remove','display','inline-block','','','.w-checkout-credit-amount'),(907320,'watch','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(907321,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(907322,'watch','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(907323,'watch','.price .old','display','block','','',''),(907324,'watch','.w-tabs .tab-li.tab-cart a','display','block','3','','.w-tabs'),(907325,'watch','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(907326,'watch','.w-checkout-billing-address .genders-title label','display','inline-block','','','.w-checkout-billing-address'),(907327,'watch','.w-personal-gift-status-bar .end-date','display','inline-block','3','','.w-personal-gift-status-bar'),(907328,'watch','.w-top-categories h2.name','display','block','','','.w-top-categories'),(907329,'watch','.w-product-configurator .item-content','display','block','5232','','.w-product-configurator'),(907330,'watch','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(907331,'watch','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(907332,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(907333,'watch','.w-product-properties li','display','table-cell','','','.w-product-properties'),(907334,'watch','.w-promo-code .holder','display','block','4','','.w-promo-code'),(907335,'watch','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(907336,'watch','.w-image-maps .categories-items .item .description','display','block','','','.w-image-maps'),(907337,'watch','.w-image-maps .categories-items .item .title','display','block','','','.w-image-maps'),(907338,'watch','.w-quote .no-text','display','none','5240','','.w-quote'),(907339,'watch','.b-info-popup .info-popup','display','inline-block','3','','.b-info-popup'),(907340,'watch','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(907341,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(907342,'watch','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(907343,'watch','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(907344,'watch','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(907345,'watch','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(907346,'watch','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(907347,'watch','.b-upload-files .attach-active-holder','display','block','','','.b-upload-files'),(907348,'watch','.b-compare .compare_select_items','display','inline-block','','','.b-compare'),(907349,'watch','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display','inline-block','','','.b-switch'),(907350,'watch','.b-form .middle-form label','display','block','','','.b-form'),(907351,'watch','.b-form .form-inputs label > span','display','inline-block','','','.b-form'),(907352,'watch','.w-checkout-shipping-address .edit-ab','display','inline-block','','','.w-checkout-shipping-address'),(907353,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(907354,'watch','.w-cart-shipping-estimator .address-item .lastname','display','block','4','','.w-cart-shipping-estimator'),(907355,'watch','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(907356,'watch','.w-product-collection .together','display','block','','','.w-product-collection'),(907357,'watch','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(907358,'watch','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(907359,'watch','.w-promo-code .promo-text-2','display','none','5240','','.w-promo-code'),(907360,'watch','.b-form .addresses','display','block','4','','.b-form'),(907361,'watch','.b-datepicker .picker-switch','display','none','','','.b-datepicker'),(907362,'watch','.w-product-attributes .attributes','display','block','4','','.w-product-attributes'),(907363,'watch','.b-info .info','display','inline-block','3','','.b-info'),(907364,'watch','.w-personal-gift-status-bar .timeline','display','flex','','','.w-personal-gift-status-bar'),(907365,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(907366,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','display','block','','','.b-switch'),(907367,'watch','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','display','inline-block','3','','.w-checkout-contact-information'),(907368,'watch','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','display','inline-block','3','','.w-checkout-contact-information'),(907369,'watch','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(907370,'watch','.w-checkout-shipping-address .genders-title > div','display','inline-block','','','.w-checkout-shipping-address'),(907371,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span','display','inline-block','','','.b-form'),(907372,'watch','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(907374,'watch','.w-categories .categories','display','block','4','','.w-categories'),(907375,'watch','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(907376,'watch','.w-promo-code .holder','display','block','4','','.w-promo-code'),(907377,'watch','.w-product-quantity .product-quantity-label','display','none','','','.w-product-quantity'),(907379,'watch','.w-product-properties li','display','table-cell','','','.w-product-properties'),(907380,'watch','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(907381,'watch','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(907382,'watch','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(907383,'watch','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(907384,'watch','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(907385,'watch','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(907386,'watch','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(907387,'watch','.w-menu-big .hide-more.hide-more-disable, .w-menu-big .hide-more.hide-more-disable ~ li:not(.show-all)','display','block','','','.w-menu-big'),(907388,'watch','.w-image-maps .categories-items .item','display','block','1','','.w-image-maps'),(907389,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(907390,'watch','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(907391,'watch','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(907392,'watch','.w-checkout-billing-address .edit-ab','display','inline-block','','','.w-checkout-billing-address'),(907393,'watch','.w-checkout-billing-address .addresses .address-item label','display','block','','','.w-checkout-billing-address'),(907394,'watch','.w-checkout-shipping-choice #shippingchoice-choice','display','flex','','','.w-checkout-shipping-choice'),(907395,'watch','.w-checkout-shipping-choice input','display','none','','','.w-checkout-shipping-choice'),(907396,'watch','.w-product-configurator .item-content > div','display','block','5232','','.w-product-configurator'),(907397,'watch','.w-product-configurator .item-content','display','block','5232','','.w-product-configurator'),(907398,'watch','.w-cart-give-away h2','display','none','','','.w-cart-give-away'),(907399,'watch','.w-promo-code .promo-text-2','display','none','5240','','.w-promo-code'),(907401,'watch','.b-pass-strength .pass-strength','display','block','','','.b-pass-strength'),(907402,'watch','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(907403,'watch','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(907404,'watch','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display','inline-block','','','.b-switch'),(907405,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(907406,'watch','.w-quote .strong','display','block','','','.w-quote'),(907407,'watch','.w-cart-up-sell h3','display','none','','','.w-cart-up-sell'),(907408,'watch','.w-cart-compare .product-actions .dropdown-toggle','display','none','4','','.w-cart-compare'),(907409,'watch','.b-select-suggest .select2-results li','display','list-item','','','.b-select-suggest'),(907410,'watch','.b-select-suggest .select2-search-choice-close','display','block','','','.b-select-suggest'),(907411,'watch','.b-select-suggest .select2-container.select2-container-disabled .select2-choice abbr','display','none','','','.b-select-suggest'),(907412,'watch','.b-select-suggest .select2-more-results','display','list-item','','','.b-select-suggest'),(907413,'watch','.b-select-suggest .select2-results .select2-selected','display','none','','','.b-select-suggest'),(907414,'watch','.b-select-suggest .select2-results .select2-disabled','display','list-item','','','.b-select-suggest'),(907415,'watch','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','display','list-item','','','.b-select-suggest'),(907416,'watch','.w-menu-big .hide-more, .w-menu-big .hide-more ~ li:not(.show-all)','display','none','','','.w-menu-big'),(907417,'watch','.w-checkout-shipping-address .change-ab','display','inline-block','','','.w-checkout-shipping-address'),(907418,'watch','.w-checkout-shipping-address .addresses .address-item label','display','block','','','.w-checkout-shipping-address'),(907419,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','','','.b-select-suggest'),(907420,'watch','.b-select-suggest .select2-search','display','inline-block','','','.b-select-suggest'),(907421,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow','display','inline-block','','','.b-select-suggest'),(907422,'watch','.w-neighbour-checkout .text','display','inline-block','','','.w-neighbour-checkout'),(907424,'watch','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(907425,'watch','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(907426,'watch','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(907427,'watch','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(907428,'watch','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(907429,'watch','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(907430,'watch','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(907431,'watch','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(907432,'watch','.w-menu-big > ul > li:hover > ul','display','block','','','.w-menu-big'),(907433,'watch','.w-menu-big li li a, .w-menu-big li li .no-link','display','block','','','.w-menu-big'),(907434,'watch','.w-menu-big li li li','display','block','','','.w-menu-big'),(907435,'watch','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(907436,'watch','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(907437,'watch','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(907438,'watch','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(907439,'watch','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(907440,'watch','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(907441,'watch','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(907442,'watch','.w-product-collection .together','display','block','','','.w-product-collection'),(907443,'watch','.w-menu-horizontal ul li:hover > ul','display','block','','','.w-menu-horizontal'),(907444,'watch','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(907445,'watch','.w-menu-big li','display','inline-block','','','.w-menu-big'),(907446,'watch','.w-cart-listing .points-redeem','display','inline-block','','','.w-cart-listing'),(907447,'watch','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(907448,'watch','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(907449,'watch','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(907450,'watch','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(907451,'watch','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(907452,'watch','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(907453,'watch','.w-product-quantity .product-quantity-label','display','none','','','.w-product-quantity'),(907454,'watch','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(907455,'watch','.w-promo-code .holder','display','block','4','','.w-promo-code'),(907456,'watch','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(907457,'watch','.w-login-block .label','display','block','','','.w-login-block'),(907458,'watch','.w-categories .item','display','inline-block','','','.w-categories'),(907459,'watch','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(907460,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.b-data-table'),(907461,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.b-data-table'),(907463,'watch','.w-communication-post .communication-post-author','display','flex','','','.w-communication-post'),(907464,'watch','.b-products-listing .products-listing .compare label','display','inline','','','.b-products-listing'),(907465,'watch','.b-products-listing .products-listing .compare','display','block','','','.b-products-listing'),(907466,'watch','.b-products-listing .BlockBox','display','block','4','','.b-products-listing'),(907467,'watch','.b-products-listing .btn-preloader','display','inline-block','3','','.b-products-listing'),(907468,'watch','.b-products-listing .hide','display','none','','','.b-products-listing'),(907469,'watch','.b-products-listing .hover-box-content','display','none','','','.b-products-listing'),(907470,'watch','.b-products-listing .hover-box:hover .hover-box-content','display','block','','','.b-products-listing'),(907471,'watch','.b-products-listing .loader','display','inline-block','4','','.b-products-listing'),(907472,'watch','.b-products-listing .products-listing .attribute-qty-block','display','flex','','','.b-products-listing'),(907473,'watch','.b-products-listing .products-listing','display','block','4','','.b-products-listing'),(907474,'watch','.b-products-listing .products-listing .btn-buy','display','inline-block','3','','.b-products-listing'),(907475,'watch','.w-catalog-b2b-add-button ','display','none','','','.w-catalog-b2b-add-button'),(907476,'watch','.b-products-listing .products-listing .item','display','inline-block','','','.b-products-listing'),(907477,'watch','.b-products-listing .products-listing.align-left .item','display','block','','','.b-products-listing'),(907478,'watch','.b-products-listing .products-listing.align-right .item','display','block','','','.b-products-listing'),(907479,'watch','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','display','block','','','.b-products-listing'),(907480,'watch','.b-products-listing .promos-info .promo-item','display','flex','','','.b-products-listing'),(907481,'watch','.b-products-listing .show-ofstock-products .headerStock','display','inline-block','','','.b-products-listing'),(907482,'watch','.checkbox input','display','none','','',''),(907483,'watch','.checkbox input + span','display','inline-block','','',''),(907490,'watch','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(907491,'watch','.b-rating .glyphicon','display','inline-block','','','.b-rating'),(907492,'watch','.b-form .newsletter-row','display','block','4','','.b-form'),(907493,'watch','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','display','block','','','.b-fancybox'),(907494,'watch','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(907495,'watch','.w-product-configurator .item-content > div','display','block','5232','','.w-product-configurator'),(907496,'watch','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(907497,'watch','.w-product-quantity .product-quantity-label','display','none','','','.w-product-quantity'),(907498,'watch','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(907499,'watch','.w-cart-credit-amount .btn-remove','display','inline-block','','','.w-cart-credit-amount'),(907500,'watch','.w-login-block .label','display','block','','','.w-login-block'),(907501,'watch','.w-coupons-and-vauchers-checkout .btn-remove','display','inline-block','','','.w-coupons-and-vauchers-checkout'),(907502,'watch','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(907503,'watch','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(907504,'watch','.order-summary .price-row.ot_coupon .title','display','inline-block','3','','.order-summary'),(907505,'watch','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(907506,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(907507,'watch','.b-form .eye-password-wrap','display','block','','','.b-form'),(907508,'watch','.w-taxable form','display','flex','','','.w-taxable'),(907509,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','display','inline-block','','',''),(907510,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','','','.w-communication-new-topic'),(907511,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','3','','.w-communication-new-topic'),(907512,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','display','inline-block','','','.w-communication-new-topic'),(907513,'watch','.w-communication-new-topic .middle-form .col-2 label > span','display','block','','','.w-communication-new-topic'),(907514,'watch','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(907515,'watch','.w-tabs .tab-li.tab-quote a','display','block','3','','.w-tabs'),(907516,'watch','.w-login-block .cols','display','block','4','','.w-login-block'),(907517,'watch','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(907518,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(907519,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(907520,'watch','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','display','inline-block','','','.b-form'),(907521,'watch','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(907522,'watch','.w-promo-code .holder','display','block','4','','.w-promo-code'),(907523,'watch','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(907524,'watch','.w-product-configurator .item-content','display','block','5232','','.w-product-configurator'),(907525,'watch','.w-menu-horizontal ul ul','display','none','','','.w-menu-horizontal'),(907526,'watch','.w-menu-horizontal ul ul li','display','block','','','.w-menu-horizontal'),(907527,'watch','.w-catalog-listing-look .grid','display','inline-block','','','.w-catalog-listing-look'),(907528,'watch','.w-catalog-listing-look .b2b','display','inline-block','','','.w-catalog-listing-look'),(907529,'watch','.w-catalog-listing-look .list','display','inline-block','','','.w-catalog-listing-look'),(907530,'watch','.w-catalog-items-on-page .items-on-page','display','flex','','','.w-catalog-items-on-page'),(907531,'watch','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(907532,'watch','.w-cart-listing .item .attributes > div','display','table-row','','','.w-cart-listing'),(907533,'watch','.w-cart-listing .item .attributes span','display','table-cell','','','.w-cart-listing'),(907534,'watch','.w-cart-listing .item .attributes','display','table','','','.w-cart-listing'),(907535,'watch','.w-cart-listing .item .attributes strong','display','table-cell','','','.w-cart-listing'),(907536,'watch','.w-cart-listing .item .gift-wrap label','display','flex','','','.w-cart-listing'),(907537,'watch','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','display','block','','','.w-cart-listing'),(907538,'watch','.w-cart-listing .headings','display','none','5240','','.w-cart-listing'),(907539,'watch','.w-cart-listing .item .price *','display','inline-block','5240','','.w-cart-listing'),(907540,'watch','.w-cart-give-away .ga_name','display','block','4','','.w-cart-give-away'),(907541,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(907542,'watch','.w-cart-discount-coupon .btn-remove','display','inline-block','','','.w-cart-discount-coupon'),(907543,'watch','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(907544,'watch','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(907557,'watch','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(907558,'watch','.w-image-maps .float-items .item .title','display','block','','','.w-image-maps'),(907559,'watch','.w-image-maps .float-items .item .description','display','block','','','.w-image-maps'),(907560,'watch','.w-image-maps .products-items .item-holder','display','block','1','','.w-image-maps'),(907561,'watch','.w-image-maps .svg-wrap','display','inline-block','','','.w-image-maps'),(907562,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','display','none','','','.w-image-maps'),(907563,'watch','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','display','inline-block','','','.b-compare'),(907564,'watch','.w-tabs .accordion-heading','display','block','','','.w-tabs'),(907565,'watch','.w-product-quantity .product-quantity-label','display','none','','','.w-product-quantity'),(907566,'watch','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(907567,'watch','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(907568,'watch','.w-cart-shipping-estimator .item .row','display','block','','','.w-cart-shipping-estimator'),(907569,'watch','.w-login-block .cols','display','block','4','','.w-login-block'),(907570,'watch','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(907571,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(907572,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(907573,'watch','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(907574,'watch','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(907575,'watch','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(907576,'watch','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(907578,'watch','.order-summary .price-row.ot_bonus_points .title','display','inline-block','3','','.order-summary'),(907579,'watch','.w-cart-shipping-estimator .shipping-estimator .heading-2','display','none','','','.w-cart-shipping-estimator'),(907580,'watch','.w-cart-listing .item','display','grid','','','.w-cart-listing'),(907581,'watch','.w-cart-listing .headings','display','none','','','.w-cart-listing'),(907582,'watch','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(907583,'watch','.w-product-attributes .attributes','display','block','4','','.w-product-attributes'),(907584,'watch','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(907585,'watch','.w-reviews-content .item','display','grid','','','.w-reviews-content'),(907586,'watch','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(907587,'watch','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(907588,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(907589,'watch','.b-info-popup .info-popup:hover div','display','block','','','.b-info-popup'),(907590,'watch','.w-filters .content-filter-widget','display','none','5240','','.w-filters'),(907591,'watch','.w-filters .fsl_handle','display','block','4','','.w-filters'),(907592,'watch','.w-filters .filter-box-content ul li.view_items','display','block','','','.w-filters'),(907593,'watch','.b-products-listing .select-attributes','display','flex','','','.b-products-listing'),(907595,'watch','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(907596,'watch','.w-promo-code .promo-text-2','display','none','5240','','.w-promo-code'),(907597,'watch','.w-taxable select','display','inline-block','','','.w-taxable'),(907598,'watch','.b-switch .bootstrap-switch .bootstrap-switch-container','display','inline-block','','','.b-switch'),(907599,'watch','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(907600,'watch','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(907601,'watch','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(907602,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(907603,'watch','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(907604,'watch','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(907605,'watch','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(907606,'watch','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(907607,'watch','.w-product-attributes .attributes','display','block','4','','.w-product-attributes'),(907608,'watch','.w-tabs .tab-li.tab-sample a','display','block','3','','.w-tabs'),(907609,'watch','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(907610,'watch','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(907611,'watch','.w-product-attributes .attributes','display','block','4','','.w-product-attributes'),(907612,'watch','.w-menu-big > ul > li > ul','display','none','','','.w-menu-big'),(907613,'watch','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(907614,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','display','inline','','','.b-h-inline'),(907615,'watch','.w-quote .no-text','display','inline-block','','','.w-quote'),(907616,'watch','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(907617,'watch','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(907618,'watch','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(907619,'watch','.w-filters .mobileCollapse','display','none','','','.w-filters'),(907620,'watch','.w-filters .input-checkbox:not(checked) + .checkbox-span','display','inline-block','','','.w-filters'),(907621,'watch','.b-product-images .media-popup .mp-big-images .item','display','flex','','','.b-product-images'),(907622,'watch','.b-product-images .media-popup .mp-big-images .item + .item:not(.slick-slide)','display','none','','','.b-product-images'),(907623,'watch','.b-product-images .media-popup .mp-small-images .item','display','inline-block','','','.b-product-images'),(907624,'watch','.b-product-images .media-popup .mp-small-images img','display','inline-block','','','.b-product-images'),(907625,'watch','.b-product-images .media-popup .slick-dots button','display','none','','','.b-product-images'),(907626,'watch','.b-product-images .media-popup .slick-dots li','display','inline-block','','','.b-product-images'),(907627,'watch','.b-menu-burger_icon .menu-style[data-burger_icon] .menu-content','display','none','','','.b-menu-burger_icon'),(907628,'watch','.b-menu-burger_icon .bi-opened .menu-style[data-burger_icon] .menu-content','display','block','','','.b-menu-burger_icon'),(907629,'watch','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','display','block','','','.b-menu-burger_icon'),(907630,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','display','block','','','.b-menu-lev_display-slide'),(907631,'watch','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','display','block','','','.b-menu-lev_display-slide'),(907632,'watch','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','display','block','','','.b-menu-lev_display-slide'),(907633,'watch','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','display','block','','','.b-menu-lev_display-slide'),(907634,'watch','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','display','block','','','.b-menu-lev_display-slide'),(907635,'watch','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(907636,'watch','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(907637,'watch','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(907638,'watch','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(907639,'watch','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(907640,'watch','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(907641,'watch','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(907642,'watch','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(907643,'watch','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(907644,'watch','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(907645,'watch','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(907646,'watch','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(907647,'watch','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-2','display','none','','','.b-menu-lev_vis'),(907648,'watch','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(907649,'watch','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-3','display','none','','','.b-menu-lev_vis'),(907650,'watch','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(907651,'watch','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-4','display','none','','','.b-menu-lev_vis'),(907652,'watch','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(907653,'watch','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-5','display','none','','','.b-menu-lev_vis'),(907654,'watch','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(907655,'watch','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-6','display','none','','','.b-menu-lev_vis'),(907656,'watch','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(907657,'watch','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(907658,'watch','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-2','display','none','','','.b-menu-lev_vis'),(907659,'watch','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(907660,'watch','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-3','display','none','','','.b-menu-lev_vis'),(907661,'watch','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(907662,'watch','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-4','display','none','','','.b-menu-lev_vis'),(907663,'watch','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(907664,'watch','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-5','display','none','','','.b-menu-lev_vis'),(907665,'watch','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(907666,'watch','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-6','display','none','','','.b-menu-lev_vis'),(907667,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(907668,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1','display','none','','','.b-menu-lev_vis-click_icon'),(907669,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(907670,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-3','display','none','','','.b-menu-lev_vis-click_icon'),(907671,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(907672,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-4','display','none','','','.b-menu-lev_vis-click_icon'),(907673,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(907674,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-5','display','none','','','.b-menu-lev_vis-click_icon'),(907675,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(907676,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-6','display','none','','','.b-menu-lev_vis-click_icon'),(907677,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display','block','','','.b-menu-open_from-left'),(907678,'watch','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul','display','flex','','','.b-menu-position'),(907679,'watch','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(907680,'watch','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display','none','','','.b-menu-style'),(907681,'watch','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display','none','','','.b-menu-style'),(907682,'watch','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display','none','','','.b-menu-style'),(907683,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','display','flex','','','.b-menu-style-1'),(907684,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .component-item','display','none','','','.b-menu-style-1'),(907685,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','display','inline-block','','','.b-menu-style-1'),(907686,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','display','block','','','.b-menu-style-1'),(907687,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','display','block','','','.b-menu-style-2'),(907688,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','display','block','','','.b-menu-style-2'),(907689,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','display','flex','','','.b-menu-style-2'),(907690,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .languages','display','flex','','','.b-menu-style-2'),(907691,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','display','block','','','.b-menu-style-2'),(907692,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies','display','flex','','','.b-menu-style-2'),(907693,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','display','flex','','','.b-menu-style-2'),(907694,'watch','.b-trade-approval .steps-bar','display','table','','','.b-trade-approval'),(907695,'watch','.b-trade-approval .steps-bar li','display','table-cell','','','.b-trade-approval'),(907696,'watch','.b-trade-approval .steps-bar li a','display','block','','','.b-trade-approval'),(907697,'watch','.b-trade-approval .middle-form label','display','block','','','.b-trade-approval'),(907698,'watch','.b-trade-approval .columns','display','block','4','','.b-trade-approval'),(907699,'watch','.w-account-personal-catalog .list-switcher','display','flex','','','.w-account-personal-catalog'),(907700,'watch','.w-account-subscription .send-email','display','block','','','.w-account-subscription'),(907701,'watch','.w-account-subscription .subscription-variant','display','flex','','','.w-account-subscription'),(907702,'watch','.w-catalog-additional-images li','display','inline-block','','','.w-catalog-additional-images'),(907703,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','display','inline-block','3','','.w-catalog-compare'),(907704,'watch','.w-catalog-compare td span','display','inline','','','.w-catalog-compare'),(907705,'watch','.w-catalog-compare .product-listing','display','flex','','','.w-catalog-compare'),(907706,'watch','.w-catalog-compare .promos-info','display','none','','','.w-catalog-compare'),(907707,'watch','.w-catalog-compare .item .compare a','display','none','','','.w-catalog-compare'),(907708,'watch','.w-catalog-compare .cross-box .different-all','display','flex','','','.w-catalog-compare'),(907709,'watch','.w-catalog-compare .cross-box','display','flex','','','.w-catalog-compare'),(907710,'watch','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','display','block','','','.w-delivery-day'),(907711,'watch','.w-delivery-day .time-left','display','flex','','','.w-delivery-day'),(907712,'watch','.w-delivery-day .left-count','display','block','','','.w-delivery-day'),(907713,'watch','.w-delivery-day .left-text-left','display','block','','','.w-delivery-day'),(907714,'watch','.w-delivery-day .left-text-right','display','block','','','.w-delivery-day'),(907715,'watch','.w-product-images .img-holder','display','flex','','','.w-product-images'),(907716,'watch','.w-product-images .additional-vertical','display','flex','','','.w-product-images'),(907717,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','display','inline-block','','','.w-filters'),(907718,'watch','.order-summary .checkout-cart-listing.main-listing','display','none','','','.order-summary'),(907719,'watch','.order-summary .icon','display','block','','','.order-summary'),(907720,'watch','.order-summary .price-box .price-row.total','display','flex','','','.order-summary'),(907721,'watch','.order-summary .price-row','display','flex','2','','.order-summary'),(907722,'watch','.order-summary .top-totals .price-box .price-row.total','display','none','','','.order-summary'),(907723,'watch','.order-summary .top-totals .price-row','display','flex','2','','.order-summary'),(907724,'watch','.order-summary .w-cart-listing .item .points','display','none','','','.order-summary'),(907725,'watch','.order-summary .w-cart-listing .item > div.image','display','none','','','.order-summary'),(907726,'watch','.w-cart-checkout-btn .with-card','display','inline-block','4','','.w-cart-checkout-btn'),(907727,'watch','.w-cart-discount-coupon .inp','display','none','','','.w-cart-discount-coupon'),(907728,'watch','.w-cart-discount-coupon .title','display','inline-block','4','','.w-cart-discount-coupon'),(907729,'watch','.w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp','display','flex','','','.w-cart-discount-coupon'),(907730,'watch','.w-cart-listing .headings','display','none','5232','','.w-cart-listing'),(907731,'watch','.w-cart-listing .item .remove-btn span','display','none','5232','','.w-cart-listing'),(907732,'watch','.w-checkout-continue-btn .button-hide','display','none','','','.w-checkout-continue-btn'),(907733,'watch','.w-checkout-continue-btn .or-text','display','none','','','.w-checkout-continue-btn'),(907734,'watch','.p-quote-checkout-index .order-summary .icon','display','none','','','.p-quote-checkout-index'),(907773,'watch','.catalog-product-wrap .pn-image','display','inline-block','3','','.catalog-product-wrap'),(907774,'watch','.catalog-product-wrap .pn-price','display','none','','','.catalog-product-wrap'),(907775,'watch','.catalog-product-wrap .prev-next-product > span','display','block','','','.catalog-product-wrap'),(907776,'watch','.catalog-product-wrap .pn-image img','display','none','5240','','.catalog-product-wrap'),(907777,'watch','.catalog-product-wrap .pn-name','display','none','5240','','.catalog-product-wrap'),(907778,'watch','.checkout-index-wrap .edit-address-popup .address-item > label','display','block','','','.checkout-index-wrap'),(907779,'watch','.checkout-index-wrap .edit-address-popup .addresses','display','flex','','','.checkout-index-wrap'),(907780,'watch','.checkout-index-wrap .edit-address-popup .addresses .buttons','display','flex','','','.checkout-index-wrap'),(907781,'watch','.checkout-index-wrap .edit-address-popup .addresses .buttons','display','none','4','','.checkout-index-wrap'),(907782,'watch','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','display','block','','','.checkout-index-wrap'),(907783,'watch','.checkout-index-wrap .hiding-box .checkout-cart-listing.summary-listing','display','none','','','.checkout-index-wrap'),(907784,'watch','.checkout-success-wrap .page-success .text-1','display','block','3','','.checkout-success-wrap'),(907785,'watch','.shopping-cart-index .cart-popup .gift-wrap','display','none','','','.shopping-cart-index'),(907786,'watch','.shopping-cart-index .order-summary .bottom-totals .icon','display','none','','','.shopping-cart-index'),(907787,'watch','.shopping-cart-index .order-summary .bottom-totals .price-box .price-row.total','display','flex','','','.shopping-cart-index'),(907788,'watch','.shopping-cart-index .order-summary .bottom-totals .price-row','display','none','2','','.shopping-cart-index'),(907789,'watch','.shopping-cart-index .gift-code .heading-4 ~ *','display','none','5232','','.shopping-cart-index'),(907790,'watch','.account-order-pay .history_attr','display','table','','','.account-order-pay'),(907791,'watch','.account-order-pay .history_attr div','display','table-row','','','.account-order-pay'),(907792,'watch','.account-order-pay .history_attr div strong, .account-order-pay .history_attr div span','display','table-cell','','','.account-order-pay'),(907793,'watch','.account-samples .orders-table .hidden','display','none','','','.account-samples'),(907794,'watch','.account-samples .short-date','display','none','','','.account-samples'),(907795,'watch','.account-samples .view_link','display','inline-block','4','','.account-samples'),(907796,'watch','.account-samples .orders-table .headings','display','none','5240','','.account-samples'),(907797,'watch','.account-samples .orders-table .hidden','display','inline-block','5240','','.account-samples'),(907798,'watch','.account-samples .orders-table .item','display','block','5240','','.account-samples'),(907799,'watch','.account-samples .orders-table .item td','display','block','5240','','.account-samples'),(907800,'watch','.account-samples .orders-table td.name','display','none','5240','','.account-samples'),(907801,'watch','.account-samples .orders-table, .account-samples .orders-table tbody','display','block','5240','','.account-samples'),(907802,'watch','.account-sample-info .history_attr','display','table','','','.account-sample-info'),(907803,'watch','.account-sample-info .history_attr div','display','table-row','','','.account-sample-info'),(907804,'watch','.account-sample-info .history_attr div strong, .account-sample-info .history_attr div span','display','table-cell','','','.account-sample-info'),(907805,'watch','.account-sample-info .popup-tracking-number a','display','block','','','.account-sample-info'),(907806,'watch','.account-sample-info .popup-tracking-number-link','display','block','','','.account-sample-info'),(907807,'watch','.checkout-order-confirmation .price-row','display','flex','','','.checkout-order-confirmation'),(907808,'watch','.checkout-index-wrap .checkoutDoubleBox','display','flex','5312','','.checkout-index-wrap'),(907809,'watch','.b-form .middle-form form','display','flex','','','.b-form'),(907810,'watch','.b-form .columns','display','flex','','','.b-form'),(907811,'watch','.b-slick .slick-dots','display','flex','','','.b-slick'),(907812,'watch','.b-slick .slick-dots li','display','block','3','','.b-slick'),(907813,'watch','.b-slick .slick-dots button','display','none','','','.b-slick'),(907814,'watch','.hide-page','display','flex','','',''),(907815,'watch','.success-page .check-ico-block','display','block','3','','.success-page'),(907816,'watch','.success-page .order_totals .price-row','display','flex','','','.success-page'),(907817,'watch','.success-page .page-success .text-1','display','inline-block','3','','.success-page'),(907818,'watch','.success-page .price-row','display','flex','','','.success-page'),(907819,'watch','.w-product-quantity-discounts .quantity-discounts .count','display','inline-block','','','.w-product-quantity-discounts'),(907820,'watch','.w-checkout-totals .price-row','display','flex','','','.w-checkout-totals'),(907821,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-content','display','block','4','','.b-multi-page-checkout'),(907822,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','display','inline-block','','','.b-multi-page-checkout'),(907823,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .edit','display','none','','','.b-multi-page-checkout'),(907824,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading > .block','display','inline-block','','','.b-multi-page-checkout'),(907825,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','display','inline-block','3','','.b-multi-page-checkout'),(907826,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .count','display','none','','','.b-multi-page-checkout'),(907827,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','block','','','.b-multi-page-checkout'),(907828,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','inline-block','4','','.b-multi-page-checkout'),(907829,'watch','.b-form .formWrapBox','display','flex','','','.b-form'),(907831,'watch','.w-checkout-totals div.price-row','display','none','','','.w-checkout-totals'),(907832,'watch','.w-checkout-totals div.price-row','display','flex','2','','.w-checkout-totals'),(907833,'watch','.b-form .ui-helper-hidden-accessible','display','none','','','.b-form'),(907840,'watch','.w-bestsellers .counter','display','inline-block','','','.w-bestsellers'),(907842,'watch','.payment-method-tf label','display','block','','','.payment-method-tf'),(907843,'watch','.w-account-customer-additional-field .field-type-checkbox label','display','inline-block','','','.w-account-customer-additional-field'),(907844,'watch','.w-account-customer-additional-field .field-type-text','display','flex','','','.w-account-customer-additional-field'),(907845,'watch','.w-account-customer-additional-field .tf-file','display','flex','','','.w-account-customer-additional-field'),(907846,'watch','.w-menu-style-1 li','display','inline-block','','','.w-menu-style-1'),(907847,'watch','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','display','inline-block','','','.w-menu-style-1'),(907848,'watch','.w-menu-style-1 li li a, .w-menu-style-1 li li .no-link','display','block','','','.w-menu-style-1'),(907849,'watch','.w-menu-style-1 ul li:hover > ul','display','block','','','.w-menu-style-1'),(907850,'watch','.w-menu-style-1 ul ul','display','none','','','.w-menu-style-1'),(907851,'watch','.w-menu-style-1 ul ul li','display','block','','','.w-menu-style-1'),(907852,'watch','.b-slick .slick-arrow.slick-hidden','display','none','','','.b-slick'),(907853,'watch','.b-slick .slick-initialized .slick-slide','display','block','','','.b-slick'),(907854,'watch','.b-slick .slick-list','display','block','','','.b-slick'),(907855,'watch','.b-slick .slick-slide','display','none','','','.b-slick'),(907856,'watch','.b-slick .slick-slide img','display','block','','','.b-slick'),(907857,'watch','.b-slick .slick-slide.slick-loading img','display','none','','','.b-slick'),(907858,'watch','.b-slick .slick-slider','display','block','','','.b-slick'),(907859,'watch','.b-slick .slick-track','display','block','','','.b-slick'),(907860,'watch','.b-slick .slick-track, .b-slick .slick-track:after','display','table','3','','.b-slick'),(907861,'watch','.b-slick .slick-vertical .slick-slide','display','block','','','.b-slick'),(907862,'watch','.w-banner .banner-item','display','grid','','','.w-banner'),(907863,'watch','.w-banner .banner-text','display','flex','','','.w-banner'),(907864,'watch','.w-banner .carousel-text','display','flex','','','.w-banner'),(907865,'watch','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','display','table','','','.w-banner'),(907866,'watch','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','display','table-cell','','','.w-banner'),(907867,'watch','.w-banner .sliderItems a + a, .w-banner .sliderItems a + img, .w-banner .sliderItems img + a, .w-banner .sliderItems img + img','display','none','','','.w-banner'),(907868,'watch','.w-catalog-paging ','display','inline-block','2','','.w-catalog-paging'),(907869,'watch','.w-catalog-paging .next','display','inline-block','','','.w-catalog-paging'),(907870,'watch','.w-catalog-paging .next-pages','display','inline-block','','','.w-catalog-paging'),(907871,'watch','.w-catalog-paging .page-number','display','inline-block','','','.w-catalog-paging'),(907872,'watch','.w-catalog-paging .paging','display','inline-block','','','.w-catalog-paging'),(907873,'watch','.w-catalog-paging .paging-holder','display','inline-block','','','.w-catalog-paging'),(907874,'watch','.w-catalog-paging .paging-item','display','inline-block','','','.w-catalog-paging'),(907875,'watch','.w-catalog-paging .prev','display','inline-block','','','.w-catalog-paging'),(907876,'watch','.w-catalog-paging .prev-pages','display','inline-block','','','.w-catalog-paging'),(907880,'watch','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display_important','important','','','.b-switch'),(907881,'watch','.w-menu-horizontal ul ul li','display_important','important','','','.w-menu-horizontal'),(907882,'watch','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display_important','important','','','.b-switch'),(907885,'watch','.w-filters .filter-box-content ul li.view_items','display_important','important','','','.w-filters'),(907886,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display_important','important','','','.b-menu-open_from-left');
INSERT INTO `themes_styles` VALUES (907887,'watch','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display_important','important','','','.b-menu-style'),(907888,'watch','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display_important','important','','','.b-menu-style'),(907889,'watch','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display_important','important','','','.b-menu-style'),(907890,'watch','.order-summary .icon','display_important','important','','','.order-summary'),(907891,'watch','.w-cart-listing .item .remove-btn span','display_important','important','5232','','.w-cart-listing'),(907892,'watch','.p-quote-checkout-index .order-summary .icon','display_important','important','','','.p-quote-checkout-index'),(907893,'watch','.catalog-product-wrap .pn-price','display_important','important','','','.catalog-product-wrap'),(907894,'watch','.catalog-product-wrap .pn-name','display_important','important','5240','','.catalog-product-wrap'),(907895,'watch','.shopping-cart-index .order-summary .bottom-totals .icon','display_important','important','','','.shopping-cart-index'),(907896,'watch','.w-menu-style-1 ul ul li','display_important','important','','','.w-menu-style-1'),(907897,'watch','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','fill','rgba(255, 255, 255, 0)','','','.w-image-maps'),(907898,'watch','.w-image-maps polygon:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(907899,'watch','.w-image-maps rect:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(907900,'watch','.w-image-maps circle:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(907901,'watch','.w-image-maps rect.no-items, .w-image-maps circle.no-items, .w-image-maps polygon.no-items','fill','rgba(150, 150, 150, 0.7)','','','.w-image-maps'),(907902,'watch','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','filter','alpha(opacity=0)','','','.b-switch'),(907903,'watch','.b-select-suggest .select2-container .select2-choice','filter','progid','','','.b-select-suggest'),(907904,'watch','.b-select-suggest .select2-container.select2-drop-above .select2-choice','filter','progid','','','.b-select-suggest'),(907905,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','filter','alpha(opacity=50)','','','.b-switch'),(907906,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','filter','alpha(opacity=50)','','','.b-switch'),(907907,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','filter','progid','','','.b-select-suggest'),(907908,'watch','.b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choice, .b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choices','filter','progid','','','.b-select-suggest'),(907909,'watch','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','filter','none','','','.b-select-suggest'),(907910,'watch','.b-select-suggest .select2-dropdown-open .select2-choice','filter','progid','','','.b-select-suggest'),(907911,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow','filter','progid','','','.b-select-suggest'),(907912,'watch','.b-select-suggest .select2-drop-mask','filter','alpha(opacity=0)','','','.b-select-suggest'),(907913,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','filter','alpha(opacity=50)','','','.b-switch'),(907914,'watch','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-basis','0','','','.b-menu-position'),(907915,'watch','.w-promotions .promo-cart-discount .slave','flex-direction','column','','','.w-promotions'),(907916,'watch','.w-catalog-compare .cross-box','flex-direction','column','','','.w-catalog-compare'),(907917,'watch','.checkout-index-wrap .checkoutDoubleBox','flex-direction','column','5312','','.checkout-index-wrap'),(907918,'watch','.b-messages .email-line > div','flex-grow','1','','','.b-messages'),(907919,'watch','.w-promotions .prom-multi-discount .promo-product, .w-promotions .prom-multi-discount .promo-category-item','flex-grow','1','','','.w-promotions'),(907920,'watch','.b-products-listing .products-listing .attribute-qty-block > span','flex-grow','1','','','.b-products-listing'),(907921,'watch','.w-cart-listing .item .gift-wrap .value','flex-grow','1','','','.w-cart-listing'),(907922,'watch','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-grow','1','','','.b-menu-position'),(907923,'watch','.w-account-personal-catalog .list-switcher a','flex-grow','1','','','.w-account-personal-catalog'),(907924,'watch','.w-account-subscription .title','flex-grow','1','','','.w-account-subscription'),(907925,'watch','.w-catalog-compare .product-listing > div','flex-grow','1','','','.w-catalog-compare'),(907926,'watch','.w-delivery-day .time-left > span','flex-grow','1','','','.w-delivery-day'),(907927,'watch','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-grow','1','','','.w-account-customer-additional-field'),(907928,'watch','.w-account-customer-additional-field .field-type-text label','flex-grow','1','','','.w-account-customer-additional-field'),(907929,'watch','.w-account-customer-additional-field .tf-file .title','flex-grow','1','','','.w-account-customer-additional-field'),(907930,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','flex-shrink','0','','','.w-upload-customer-id-upload-customer-id-form'),(907931,'watch','.b-products-listing .select-attributes .item-title','flex-shrink','0','','','.b-products-listing'),(907932,'watch','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-shrink','1','','','.b-menu-position'),(907933,'watch','.w-catalog-compare .cross-box','flex-shrink','0','','','.w-catalog-compare'),(907934,'watch','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-shrink','0','','','.w-account-customer-additional-field'),(907935,'watch','.w-account-customer-additional-field .field-type-text label','flex-shrink','0','','','.w-account-customer-additional-field'),(907936,'watch','.w-promotions .promo-cart-discount .content','flex-wrap','wrap','','','.w-promotions'),(907937,'watch','.w-promotions .promo-salemaker .content','flex-wrap','wrap','','','.w-promotions'),(907938,'watch','.b-products-listing .products-listing .attribute-qty-blocks','flex-wrap','wrap','','','.b-products-listing'),(907939,'watch','.w-top-categories .categories','flex-wrap','wrap','','','.w-top-categories'),(907940,'watch','.checkout-index-wrap .edit-address-popup .addresses','flex-wrap','wrap','','','.checkout-index-wrap'),(907941,'watch','.b-form .middle-form form','flex-wrap','wrap','','','.b-form'),(907942,'watch','.b-form .columns','flex-wrap','wrap','','','.b-form'),(907943,'watch','.b-form .formWrapBox','flex-wrap','wrap','','','.b-form'),(907945,'watch','.heading-4 .right-text, h4 .right-text','float','right','','',''),(907946,'watch','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(907947,'watch','.w-checkout-billing-address .btn-cancel','float','left','','','.w-checkout-billing-address'),(907948,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(907949,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(907951,'watch','.w-socials .post_item_img','float','left','','','.w-socials'),(907954,'watch','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(907955,'watch','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(907956,'watch','.w-product-configurator .item-content > div','float','left','5232','','.w-product-configurator'),(907957,'watch','.w-brands .brands-listing > div','float','left','','','.w-brands'),(907958,'watch','.w-cart-shipping-estimator .left-area','float','left','','','.w-cart-shipping-estimator'),(907959,'watch','.w-cart-gift-certificate .gift-code button','float','right','','','.w-cart-gift-certificate'),(907960,'watch','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(907961,'watch','.w-product-in-bundles .bundle_item','float','left','','','.w-product-in-bundles'),(907962,'watch','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(907963,'watch','.b-messages .msv_btn .btn','float','right','','','.b-messages'),(907964,'watch','.b-messages .messages-menu li span','float','right','','','.b-messages'),(907965,'watch','.w-checkout-shipping-address .btn-cancel','float','left','','','.w-checkout-shipping-address'),(907966,'watch','.w-product-in-bundles .bundle_item','float','left','','','.w-product-in-bundles'),(907967,'watch','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(907968,'watch','.b-quantity .qty-input label','float','left','','','.b-quantity'),(907969,'watch','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(907970,'watch','.w-product-collection .right-area','float','left','','','.w-product-collection'),(907971,'watch','.w-login-block .guest','float','right','','','.w-login-block'),(907972,'watch','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(907973,'watch','.w-product-bundle .bundle_item','float','left','','','.w-product-bundle'),(907974,'watch','.p-payer-order-confirmation .dob-hide > div','float','right','','','.p-payer-order-confirmation'),(907975,'watch','.p-payer-order-confirmation .dob-hide label','float','left','','','.p-payer-order-confirmation'),(907976,'watch','.p-payer-order-pay .dob-hide label','float','left','','','.p-payer-order-pay'),(907977,'watch','.p-payer-order-pay .dob-hide > div','float','right','','','.p-payer-order-pay'),(907978,'watch','.b-compare .col-two label, .b-compare .col-two select','float','left','','','.b-compare'),(907979,'watch','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(907980,'watch','.b-quantity .qty-input label','float','left','','','.b-quantity'),(907981,'watch','.b-info .info','float','left','3','','.b-info'),(907982,'watch','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(907983,'watch','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(907984,'watch','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(907985,'watch','.w-login-block .guest','float','right','','','.w-login-block'),(907986,'watch','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(907987,'watch','.w-login-block .returning','float','left','','','.w-login-block'),(907988,'watch','.w-login-block .new','float','right','','','.w-login-block'),(907989,'watch','.w-menu-horizontal li','float','none','','','.w-menu-horizontal'),(907990,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(907991,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(907992,'watch','.b-info .info','float','left','3','','.b-info'),(907993,'watch','.b-bottom .closeable-heading','float','right','3','','.b-bottom'),(907994,'watch','.b-form .col-3','float','left','','','.b-form'),(907995,'watch','.w-checkout-contact-information .btn-save','float','right','','','.w-checkout-contact-information'),(907996,'watch','.b-form .terms-login .bootstrap-switch','float','right','','','.b-form'),(907997,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(907998,'watch','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(907999,'watch','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(908000,'watch','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(908001,'watch','.buttons .right-buttons','float','right','','',''),(908002,'watch','.buttons .left-buttons','float','left','','',''),(908003,'watch','.w-login-block .returning','float','left','','','.w-login-block'),(908004,'watch','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(908005,'watch','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(908006,'watch','.w-product-collection .current-product','float','left','','','.w-product-collection'),(908007,'watch','.w-brands .brands-listing > div','float','left','','','.w-brands'),(908008,'watch','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(908009,'watch','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(908010,'watch','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(908011,'watch','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(908012,'watch','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(908013,'watch','.message.success','float','left','3','',''),(908014,'watch','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(908015,'watch','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(908016,'watch','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(908017,'watch','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(908018,'watch','.w-product-in-bundles .bundle_item','float','left','','','.w-product-in-bundles'),(908019,'watch','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(908020,'watch','.w-socials > li','float','left','','','.w-socials'),(908021,'watch','.w-socials .post_item_img','float','left','','','.w-socials'),(908022,'watch','.w-checkout-billing-address .add-ab','float','left','','','.w-checkout-billing-address'),(908023,'watch','.b-quantity .qty-input label','float','left','','','.b-quantity'),(908024,'watch','.w-cart-listing .right-area','float','none','5240','','.w-cart-listing'),(908025,'watch','.w-checkout-shipping-address .add-ab','float','left','','','.w-checkout-shipping-address'),(908026,'watch','.w-socials > li','float','left','','','.w-socials'),(908027,'watch','.w-product-in-bundles .bundle_item','float','left','','','.w-product-in-bundles'),(908028,'watch','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(908029,'watch','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(908030,'watch','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(908031,'watch','.w-product-bundle .bundle_item','float','left','','','.w-product-bundle'),(908032,'watch','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(908033,'watch','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(908034,'watch','.w-product-collection .current-product','float','left','','','.w-product-collection'),(908035,'watch','.w-product-collection .right-area','float','left','','','.w-product-collection'),(908036,'watch','.w-socials .post_item_img','float','left','','','.w-socials'),(908037,'watch','.w-socials > li','float','left','','','.w-socials'),(908038,'watch','.b-info .info','float','left','3','','.b-info'),(908039,'watch','.w-product-configurator .item-content > div','float','left','5232','','.w-product-configurator'),(908040,'watch','.b-form .addresses .address-item input[type=\"radio\"]','float','left','','','.b-form'),(908041,'watch','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(908042,'watch','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(908043,'watch','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(908044,'watch','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(908045,'watch','.w-socials > li','float','left','','','.w-socials'),(908046,'watch','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(908047,'watch','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(908048,'watch','.heading-4 .edit, h4 .edit','float','right','','',''),(908049,'watch','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(908050,'watch','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(908051,'watch','.b-quantity .qty-input label','float','left','','','.b-quantity'),(908052,'watch','.w-login-block .returning','float','left','','','.w-login-block'),(908053,'watch','.b-info-popup .password-info .info-popup','float','right','','','.b-info-popup'),(908054,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(908055,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(908056,'watch','.heading-3 .right-text, h3 .right-text','float','right','','',''),(908057,'watch','.heading-3 .edit, h3 .edit','float','right','','',''),(908058,'watch','.b-quantity .qty-input label','float','left','','','.b-quantity'),(908059,'watch','.b-info .info','float','left','3','','.b-info'),(908060,'watch','.w-socials .post_item_img','float','left','','','.w-socials'),(908061,'watch','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(908062,'watch','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(908063,'watch','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(908064,'watch','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(908065,'watch','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(908066,'watch','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(908067,'watch','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(908068,'watch','.w-checkout-billing-address .addresses .address-item','float','left','','','.w-checkout-billing-address'),(908069,'watch','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(908070,'watch','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(908071,'watch','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(908072,'watch','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(908073,'watch','.w-list-b2b .select-attributes','float','left','','','.w-list-b2b'),(908074,'watch','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(908075,'watch','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(908076,'watch','.w-socials .post_item_img','float','left','','','.w-socials'),(908077,'watch','.edit-link','float','right','','',''),(908080,'watch','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(908081,'watch','.w-socials > li','float','left','','','.w-socials'),(908082,'watch','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(908083,'watch','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(908084,'watch','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(908085,'watch','.b-info .info','float','left','3','','.b-info'),(908086,'watch','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(908087,'watch','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(908088,'watch','.w-promo-code .btn','float','right','','','.w-promo-code'),(908089,'watch','.b-form .shipping-method .cost','float','right','','','.b-form'),(908090,'watch','.b-form .shipping-method .input','float','left','','','.b-form'),(908091,'watch','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(908092,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(908093,'watch','.b-sub-totals .historyTotal table','float','right','','','.b-sub-totals'),(908094,'watch','.b-info .info','float','left','3','','.b-info'),(908095,'watch','.w-login-block .returning','float','left','','','.w-login-block'),(908096,'watch','.w-login-block .guest','float','right','','','.w-login-block'),(908097,'watch','.w-login-block .new','float','right','','','.w-login-block'),(908098,'watch','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(908099,'watch','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(908100,'watch','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(908101,'watch','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(908102,'watch','.b-form .col-right','float','right','','','.b-form'),(908103,'watch','.w-product-collection .right-area','float','left','','','.w-product-collection'),(908104,'watch','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(908105,'watch','.w-product-collection .current-product','float','left','','','.w-product-collection'),(908106,'watch','.b-form .payment-method .item-radio input','float','left','','','.b-form'),(908107,'watch','.w-cart-listing .actions > div','float','left','','','.w-cart-listing'),(908108,'watch','.w-login-block .guest','float','right','','','.w-login-block'),(908109,'watch','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(908110,'watch','.w-login-block .new','float','right','','','.w-login-block'),(908111,'watch','.w-brands .brands-listing > div','float','left','','','.w-brands'),(908112,'watch','.w-cart-gift-certificate .gift-code button','float','right','','','.w-cart-gift-certificate'),(908113,'watch','.w-product-bundle .bundle_item','float','left','','','.w-product-bundle'),(908114,'watch','.w-product-in-bundles .bundle_item','float','left','','','.w-product-in-bundles'),(908115,'watch','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(908116,'watch','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(908117,'watch','.w-cart-shipping-estimator .right-area','float','right','','','.w-cart-shipping-estimator'),(908118,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(908119,'watch','.w-product-configurator .item-content > div','float','left','5232','','.w-product-configurator'),(908120,'watch','.w-cart-give-away .ga_attributes > div','float','left','','','.w-cart-give-away'),(908121,'watch','.b-bottom .cart-options .option-item','float','left','','','.b-bottom'),(908122,'watch','.w-product-collection .right-area','float','left','','','.w-product-collection'),(908123,'watch','.w-product-collection .current-product','float','left','','','.w-product-collection'),(908124,'watch','.b-bottom .cart-options .cart-item','float','left','','','.b-bottom'),(908125,'watch','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(908126,'watch','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(908127,'watch','.w-cart-gift-certificate .gift-code button','float','right','','','.w-cart-gift-certificate'),(908128,'watch','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(908129,'watch','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(908130,'watch','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(908131,'watch','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(908132,'watch','.w-product-bundle .bundle_item','float','left','','','.w-product-bundle'),(908133,'watch','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(908134,'watch','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(908135,'watch','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(908136,'watch','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(908137,'watch','.w-list-b2b .select-attributes:nth-child(2n)','float','right','','','.w-list-b2b'),(908138,'watch','.b-products-listing .products-listing .radio-attributes .item-title','float','left','','','.b-products-listing'),(908139,'watch','.b-upload-files .remove-file','float','right','','','.b-upload-files'),(908140,'watch','.w-login-block .new','float','right','','','.w-login-block'),(908141,'watch','.w-cart-compare .product .image','float','left','','','.w-cart-compare'),(908142,'watch','.b-form .col-left','float','left','','','.b-form'),(908143,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(908145,'watch','.w-cart-gift-certificate .gift-code button','float','right','','','.w-cart-gift-certificate'),(908146,'watch','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(908147,'watch','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(908148,'watch','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(908149,'watch','.w-product-collection .right-area','float','left','','','.w-product-collection'),(908150,'watch','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(908151,'watch','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(908152,'watch','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(908153,'watch','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(908154,'watch','.b-form .addresses .address-item','float','left','','','.b-form'),(908155,'watch','.w-product-configurator .item-content > div','float','left','5232','','.w-product-configurator'),(908156,'watch','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(908157,'watch','.w-socials > li','float','left','','','.w-socials'),(908158,'watch','.w-cart-give-away .ga_column','float','left','','','.w-cart-give-away'),(908159,'watch','.b-select-suggest .select2-container-multi .select2-choices li','float','left','','','.b-select-suggest'),(908160,'watch','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(908161,'watch','.w-neighbour-checkout .bootstrap-switch','float','right','','','.w-neighbour-checkout'),(908162,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','float','left','3','','.b-warehouses-popup'),(908163,'watch','.w-product-collection .right-area','float','left','','','.w-product-collection'),(908164,'watch','.w-product-collection .current-product','float','left','','','.w-product-collection'),(908165,'watch','.w-product-bundle .bundle_item','float','left','','','.w-product-bundle'),(908166,'watch','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(908167,'watch','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(908168,'watch','.w-product-in-bundles .bundle_item','float','left','','','.w-product-in-bundles'),(908169,'watch','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(908170,'watch','.w-menu-horizontal .box','float','none','','','.w-menu-horizontal'),(908171,'watch','.w-login-block .new','float','right','','','.w-login-block'),(908172,'watch','.w-login-block .guest','float','right','','','.w-login-block'),(908173,'watch','.b-quantity .qty-input label','float','left','','','.b-quantity'),(908174,'watch','.w-brands .brands-listing > div','float','left','','','.w-brands'),(908176,'watch','.w-login-block .guest','float','right','','','.w-login-block'),(908177,'watch','.w-menu-big li','float','none','','','.w-menu-big'),(908178,'watch','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(908179,'watch','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(908180,'watch','.w-promo-code .btn','float','right','','','.w-promo-code'),(908181,'watch','.w-login-block .new','float','right','','','.w-login-block'),(908182,'watch','.w-product-configurator .item-content > div','float','left','5232','','.w-product-configurator'),(908183,'watch','.w-account-addresses-list .address-fields input[type=\"radio\"]','float','left','','','.w-account-addresses-list'),(908184,'watch','.w-account-addresses-list .addsess-suggestion-item','float','left','','','.w-account-addresses-list'),(908185,'watch','.b-products-listing .products-listing .bonus-points-price','float','left','3','','.b-products-listing'),(908186,'watch','.b-products-listing .products-listing a.btn.view-button','float','right','3','','.b-products-listing'),(908187,'watch','.b-products-listing .products-listing .compare input + span','float','right','','','.b-products-listing'),(908188,'watch','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','float','right','','','.b-products-listing'),(908189,'watch','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','float','right','','','.b-products-listing'),(908190,'watch','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','float','right','','','.b-products-listing'),(908191,'watch','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','float','right','','','.b-products-listing'),(908192,'watch','.b-products-listing .BlockBox.type-7 > .col, .b-products-listing .BlockBox.type-8 > .col, .b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col','float','left','','','.b-products-listing'),(908193,'watch','.b-products-listing .BlockBox.type-2 > .col, .b-products-listing .BlockBox.type-3 > .col, .b-products-listing .BlockBox.type-4 > .col, .b-products-listing .BlockBox.type-5 > .col, .b-products-listing .BlockBox.type-6 > .col','float','left','','','.b-products-listing'),(908194,'watch','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','float','right','','','.b-products-listing'),(908195,'watch','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','float','right','','','.b-products-listing'),(908196,'watch','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','float','right','','','.b-products-listing'),(908197,'watch','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','float','right','','','.b-products-listing'),(908198,'watch','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','float','right','','','.b-products-listing'),(908199,'watch','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','float','right','','','.b-products-listing'),(908200,'watch','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','float','right','','','.b-products-listing'),(908201,'watch','.b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col, .b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockB','float','left','','','.b-products-listing'),(908202,'watch','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','float','right','','','.b-products-listing'),(908203,'watch','.b-products-listing .products-listing .attribute-qty-block > span','float','left','','','.b-products-listing'),(908204,'watch','.b-products-listing .products-listing .item','float','none','','','.b-products-listing'),(908205,'watch','.b-products-listing .products-listing .mult-qty-input','float','right','','','.b-products-listing'),(908206,'watch','.b-products-listing .products-listing.align-left .item','float','left','','','.b-products-listing'),(908207,'watch','.b-products-listing .products-listing.align-right .item','float','right','','','.b-products-listing'),(908208,'watch','.b-products-listing .wedding-registry-count','float','right','','','.b-products-listing'),(908209,'watch','.w-checkout-gdpr .candlestick-wrapper','float','right','','','.w-checkout-gdpr'),(908210,'watch','.b-compare .compare-box-btn','float','right','','','.b-compare'),(908211,'watch','.w-cart-give-away .ga_img','float','left','','','.w-cart-give-away'),(908212,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(908213,'watch','.w-cart-compare .product-actions','float','right','','','.w-cart-compare'),(908214,'watch','.w-socials .post_item_img','float','left','','','.w-socials'),(908215,'watch','.w-promo-code .btn','float','right','','','.w-promo-code'),(908216,'watch','.w-product-collection .current-product','float','left','','','.w-product-collection'),(908217,'watch','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(908218,'watch','.w-login-block .returning','float','left','','','.w-login-block'),(908219,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(908220,'watch','.w-checkout-create-account .newsletter-switcher .bootstrap-switch','float','right','','','.w-checkout-create-account'),(908221,'watch','.w-checkout-shipping-address .addresses .address-item','float','left','','','.w-checkout-shipping-address'),(908222,'watch','.w-checkout-create-account .create-account-switcher','float','right','','','.w-checkout-create-account'),(908223,'watch','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(908224,'watch','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(908225,'watch','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(908226,'watch','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(908227,'watch','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(908228,'watch','.b-products-listing .products-listing .bonus-points-cost','float','left','3','','.b-products-listing'),(908229,'watch','.w-login-block .returning','float','left','','','.w-login-block'),(908230,'watch','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(908231,'watch','.w-promo-code .btn','float','right','','','.w-promo-code'),(908232,'watch','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(908233,'watch','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(908234,'watch','.w-product-configurator .item-content > div','float','left','5232','','.w-product-configurator'),(908235,'watch','.b-form .columns .col-2','float','left','','','.b-form'),(908236,'watch','.w-product-cross-sell .buy-all-checker','float','left','','','.w-product-cross-sell'),(908237,'watch','.w-cart-listing .item > div','float','left','','','.w-cart-listing'),(908238,'watch','.w-cart-listing .points-earn','float','left','3','','.w-cart-listing'),(908239,'watch','.w-cart-listing .points-redeem','float','left','3','','.w-cart-listing'),(908240,'watch','.w-cart-listing .right-area','float','left','','','.w-cart-listing'),(908241,'watch','.w-cart-listing .item .qty','float','right','5240','','.w-cart-listing'),(908242,'watch','.w-cart-listing .links','float','left','','','.w-cart-listing'),(908243,'watch','.w-cart-listing .item .price','float','left','5240','','.w-cart-listing'),(908244,'watch','.w-cart-gift-certificate .gift-code button','float','right','','','.w-cart-gift-certificate'),(908245,'watch','.w-cart-give-away .ga_price .checkBoxWrap','float','right','','','.w-cart-give-away'),(908248,'watch','.w-brands .brands-listing > div','float','left','','','.w-brands'),(908249,'watch','.order-summary .btn-2','float','none','5240','','.order-summary'),(908250,'watch','.w-promo-code .btn','float','right','','','.w-promo-code'),(908251,'watch','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(908252,'watch','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(908253,'watch','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(908254,'watch','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(908255,'watch','.w-checkout-billing-address .bootstrap-switch','float','right','','','.w-checkout-billing-address'),(908256,'watch','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(908257,'watch','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(908258,'watch','.w-brands .brands-listing > div','float','left','','','.w-brands'),(908259,'watch','.b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockBox.type-14 > .col, .b-products-listing .BlockBox.type-15 > .col, .b-products-listing .BlockBox.type-16 > .col','float','left','','','.b-products-listing'),(908260,'watch','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(908261,'watch','.w-product-reviews .write-review-button','float','right','','','.w-product-reviews'),(908262,'watch','.w-promo-code .btn','float','right','','','.w-promo-code'),(908263,'watch','.w-filters .handle-to','float','right','','','.w-filters'),(908264,'watch','.w-filters .handle-from','float','left','','','.w-filters'),(908265,'watch','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(908266,'watch','.w-cart-gift-certificate .gift-code button','float','right','','','.w-cart-gift-certificate'),(908267,'watch','.w-product-bundle .bundle_item','float','left','','','.w-product-bundle'),(908268,'watch','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(908269,'watch','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(908270,'watch','.w-cart-compare .js-cart_totals_container','float','left','','','.w-cart-compare'),(908271,'watch','.w-cart-compare .buttons','float','right','','','.w-cart-compare'),(908272,'watch','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(908273,'watch','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(908274,'watch','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(908275,'watch','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(908276,'watch','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(908277,'watch','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(908278,'watch','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(908279,'watch','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(908280,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(908281,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(908282,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(908283,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(908284,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(908285,'watch','.b-trade-approval .col-right','float','right','','','.b-trade-approval'),(908286,'watch','.b-trade-approval .col-left','float','left','','','.b-trade-approval'),(908287,'watch','.b-trade-approval .col-3','float','left','','','.b-trade-approval'),(908288,'watch','.w-catalog-compare .compare label','float','right','','','.w-catalog-compare'),(908289,'watch','.w-catalog-compare .buyButton','float','right','','','.w-catalog-compare'),(908290,'watch','.w-delivery-day .left-count','float','left','','','.w-delivery-day'),(908291,'watch','.w-delivery-day .left-text-left','float','left','','','.w-delivery-day'),(908292,'watch','.w-delivery-day .left-text-right','float','left','','','.w-delivery-day'),(908293,'watch','.w-filters .fsl_handle > div','float','left','','','.w-filters'),(908301,'watch','.checkout-index-wrap .dob-hide > div','float','right','','','.checkout-index-wrap'),(908302,'watch','.checkout-index-wrap .dob-hide label','float','left','','','.checkout-index-wrap'),(908303,'watch','.account-order-pay .history_info > div','float','left','','','.account-order-pay'),(908304,'watch','.account-sample-info .history_info > div','float','left','','','.account-sample-info'),(908305,'watch','.b-form .add-ab','float','right','','','.b-form'),(908306,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','float','right','','','.b-multi-page-checkout'),(908311,'watch','.w-menu-style-1 .box','float','none','','','.w-menu-style-1'),(908312,'watch','.w-menu-style-1 li','float','none','','','.w-menu-style-1'),(908313,'watch','.b-slick .slick-slide','float','left','','','.b-slick'),(908314,'watch','.b-slick [dir=\'rtl\'] .slick-slide','float','right','','','.b-slick'),(908315,'watch','.b-slick .slick-slide','float_important','important','','','.b-slick'),(908316,'watch','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-family','$font-1','','','.w-communication-new-topic'),(908317,'watch','.b-upload-file .snapshot','font-family','FontAwesome','3','','.b-upload-file'),(908318,'watch','.heading-4 .edit, h4 .edit','font-family','trueloaded','4','',''),(908319,'watch','.w-product-personal-catalog-button .btn','font-family','$font-2','','','.w-product-personal-catalog-button'),(908320,'watch','.heading-4 .edit, h4 .edit','font-family','$font-2','','',''),(908321,'watch','.message.success','font-family','trueloaded','3','',''),(908322,'watch','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(908323,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(908324,'watch','.w-delivery-location-location-list .deliveryListParrent','font-family','$font-1','','','.w-delivery-location-location-list'),(908325,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(908326,'watch','.b-form .checkbox-style:checked + .checkbox-span:before','font-family','FontAwesome','','','.b-form'),(908327,'watch','.w-filters .filter-box-head','font-family','$font-1','','','.w-filters'),(908328,'watch','.p-quick-order-index .paginate_button.previous','font-family','FontAwesome','3','','.p-quick-order-index'),(908329,'watch','.p-quick-order-index .paginate_button.next','font-family','FontAwesome','3','','.p-quick-order-index'),(908330,'watch','.w-cart-compare .cart-name a','font-family','$font-1','','','.w-cart-compare'),(908331,'watch','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(908333,'watch','.p-sample-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-sample-checkout-success'),(908334,'watch','.shipping-ico .heading-2','font-family','trueloaded','3','','.shipping-ico'),(908335,'watch','.p-sample-checkout-success .page-success .text-1, .p-sample-checkout-success .page-success .text-2, .p-sample-checkout-success .page-success .text-3','font-family','$font-1','','','.p-sample-checkout-success'),(908336,'watch','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(908337,'watch','.w-delivery-location-location-list .deliveryListParrent','font-family','$font-1','','','.w-delivery-location-location-list'),(908338,'watch','.testimonials .heading-3','font-family','trueloaded','3','',''),(908339,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(908340,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(908341,'watch','.w-promotions .nextdiscount .heading','font-family','FontAwesome','3','','.w-promotions'),(908342,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','font-family','FontAwesome','3','','.b-warehouses-popup'),(908343,'watch','.b-warehouses-popup .warehouses-popup-link','font-family','FontAwesome','3','','.b-warehouses-popup'),(908344,'watch','.b-preloader .preloader','font-family','FontAwesome','3','','.b-preloader'),(908345,'watch','.w-social-links a','font-family','FontAwesome','','','.w-social-links'),(908346,'watch','.b-bottom .closeable-heading','font-family','FontAwesome','3','','.b-bottom'),(908347,'watch','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(908348,'watch','.b-messages .messBtnMenuUnread','font-family','FontAwesome','3','','.b-messages'),(908349,'watch','.b-messages .messBtnMenuDelete','font-family','trueloaded','3','','.b-messages'),(908350,'watch','.b-messages span.starred::before','font-family','trueloaded','','','.b-messages'),(908351,'watch','.b-messages .messBtnMenuStarred','font-family','trueloaded','3','','.b-messages'),(908352,'watch','.b-messages .content_management_attach span','font-family','$font-2','','','.b-messages'),(908353,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','trueloaded','3','','.w-cart-gift-certificate'),(908354,'watch','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(908355,'watch','.p-payer-order-confirmation .ship-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(908356,'watch','.p-payer-order-confirmation .pay-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(908357,'watch','.p-payer-order-confirmation .order-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(908358,'watch','.p-payer-order-confirmation .discount-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(908359,'watch','.p-payer-order-confirmation .comment-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(908360,'watch','.p-payer-order-pay .ship-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(908361,'watch','.p-payer-order-pay .order-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(908362,'watch','.p-payer-order-pay .pay-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(908363,'watch','.p-payer-order-pay .discount-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(908364,'watch','.p-payer-order-pay .comment-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(908365,'watch','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(908366,'watch','.b-info .info strong','font-family','$font-1','','','.b-info'),(908367,'watch','.b-fancybox .fancybox-close','font-family','FontAwesome','3','','.b-fancybox'),(908368,'watch','.b-messages .select2-search-choice-close','font-family','trueloaded','3','','.b-messages'),(908370,'watch','.bell-ico .heading-2','font-family','trueloaded','3','','.bell-ico'),(908371,'watch','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(908372,'watch','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-family','FontAwesome','3','','.w-upload-customer-id-upload-customer-id-form'),(908373,'watch','.w-coupons-and-vauchers-checkout .btn-remove','font-family','trueloaded','3','','.w-coupons-and-vauchers-checkout'),(908374,'watch','.w-filters .open','font-family','FontAwesome','3','','.w-filters'),(908375,'watch','.w-categories h2.name','font-family','$font-1','','','.w-categories'),(908376,'watch','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(908377,'watch','.b-fancybox .fancybox-nav span','font-family','trueloaded','','','.b-fancybox'),(908379,'watch','.w-product-personal-catalog-button .btn','font-family','FontAwesome','3','','.w-product-personal-catalog-button'),(908380,'watch','.shipping-ico .heading-2','font-family','trueloaded','3','','.shipping-ico'),(908381,'watch','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','font-family','FontAwesome','3','','.w-checkout-contact-information'),(908382,'watch','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(908383,'watch','.no-found','font-family','$font-1','','',''),(908384,'watch','.view-all .btn','font-family','FontAwesome','4','',''),(908385,'watch','.w-product-personal-catalog-button .btn','font-family','FontAwesome','3','','.w-product-personal-catalog-button'),(908386,'watch','.w-catalog-listing-look .list','font-family','FontAwesome','3','','.w-catalog-listing-look'),(908387,'watch','.w-socials .post_item > div','font-family','FontAwesome','3','','.w-socials'),(908390,'watch','.w-cart-compare .price-cell','font-family','$font-1','','','.w-cart-compare'),(908391,'watch','.b-bottom .footerTitle','font-family','FontAwesome','5232,4','','.b-bottom'),(908392,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','trueloaded','3','','.w-cart-gift-certificate'),(908393,'watch','.b-rating .glyphicon-star','font-family','FontAwesome','3','','.b-rating'),(908394,'watch','.w-chat .w-chat-box a','font-family','FontAwesome','3','','.w-chat'),(908395,'watch','.w-product-personal-catalog-button .btn','font-family','$font-2','','','.w-product-personal-catalog-button'),(908396,'watch','.w-socials .post_item > div','font-family','FontAwesome','3','','.w-socials'),(908398,'watch','.w-cart-compare .product-actions .dropdown-toggle','font-family','FontAwesome','3','','.w-cart-compare'),(908399,'watch','.w-cart-compare .atr-col','font-family','FontAwesome','3','','.w-cart-compare'),(908401,'watch','.b-rating .glyphicon','font-family','FontAwesome','','','.b-rating'),(908402,'watch','.order-summary .price-row.ot_gv .title','font-family','trueloaded','3','','.order-summary'),(908403,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(908404,'watch','.w-product-wishlist-button .btn','font-family','$font-2','','','.w-product-wishlist-button'),(908405,'watch','.w-delivery-location-location-list .deliveryListParrent','font-family','$font-1','','','.w-delivery-location-location-list'),(908406,'watch','.w-socials .post_item > div','font-family','FontAwesome','3','','.w-socials'),(908407,'watch','.b-info .info','font-family','trueloaded','3','','.b-info'),(908408,'watch','.w-tabs .tab-li.tab-wishlist a','font-family','trueloaded','3','','.w-tabs'),(908409,'watch','.w-multi-cart-actions .cart-actions .dropdown-toggle','font-family','FontAwesome','3','','.w-multi-cart-actions'),(908410,'watch','.w-top-categories h2.name','font-family','$font-1','','','.w-top-categories'),(908413,'watch','.w-tabs .tab-a','font-family','$font-1','','','.w-tabs'),(908414,'watch','.w-socials .post_item > div','font-family','FontAwesome','3','','.w-socials'),(908415,'watch','.btn-edit','font-family','trueloaded','3','',''),(908417,'watch','.w-tabs .tab-li.tab-cart a','font-family','trueloaded','3','','.w-tabs'),(908418,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(908419,'watch','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(908420,'watch','.w-socials .post_item > div','font-family','FontAwesome','3','','.w-socials'),(908421,'watch','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(908422,'watch','.w-delivery-location-location-list .deliveryListParrent','font-family','$font-1','','','.w-delivery-location-location-list'),(908424,'watch','.w-product-wishlist-button .btn','font-family','$font-2','','','.w-product-wishlist-button'),(908425,'watch','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(908426,'watch','.btn-2','font-family','$font-2','','',''),(908427,'watch','.btn-1','font-family','$font-2','','',''),(908428,'watch','.heading-5, h5, .h-block h5','font-family','$font-1','','',''),(908429,'watch','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(908430,'watch','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(908431,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(908432,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(908433,'watch','.w-filters .input-checkbox:checked + .checkbox-span:before','font-family','FontAwesome','','','.w-filters'),(908434,'watch','.in-stock-icon','font-family','FontAwesome','3','',''),(908435,'watch','.out-stock-icon','font-family','FontAwesome','3','',''),(908436,'watch','.transit-icon','font-family','FontAwesome','3','',''),(908437,'watch','.heading-3 .edit, h3 .edit','font-family','trueloaded','4','',''),(908438,'watch','.heading-3 .edit, h3 .edit','font-family','$font-2','','',''),(908439,'watch','.b-info .info','font-family','trueloaded','3','','.b-info'),(908440,'watch','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(908441,'watch','.w-checkout-create-account .account-benefits strong','font-family','trueloaded','3','','.w-checkout-create-account'),(908442,'watch','.b-info .info strong','font-family','$font-1','','','.b-info'),(908443,'watch','.shipping-ico .heading-2','font-family','trueloaded','3','','.shipping-ico'),(908444,'watch','.savings-ico .heading-2','font-family','trueloaded','3','','.savings-ico'),(908445,'watch','.order-summary .heading-2','font-family','trueloaded','3','','.order-summary'),(908448,'watch','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(908449,'watch','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-family','$font-1','','','.w-multi-cart-cart-switcher'),(908450,'watch','.js-stock-icon','font-family','FontAwesome','3','',''),(908451,'watch','.b-switch .candlestick-wrapper .fa-check','font-family','FontAwesome','3','','.b-switch'),(908452,'watch','.b-switch .candlestick-wrapper .fa-times','font-family','FontAwesome','3','','.b-switch'),(908453,'watch','.b-info .info strong','font-family','$font-1','','','.b-info'),(908454,'watch','.w-product-personal-catalog-button .btn','font-family','$font-2','','','.w-product-personal-catalog-button'),(908455,'watch','.w-product-wishlist-button .btn','font-family','$font-2','','','.w-product-wishlist-button'),(908456,'watch','.w-product-personal-catalog-button .btn','font-family','FontAwesome','3','','.w-product-personal-catalog-button'),(908457,'watch','.w-top-categories .categories h2','font-family','inherit','','','.w-top-categories'),(908458,'watch','.btn','font-family','$font-2','','',''),(908459,'watch','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(908460,'watch','.heading-4, h4, .h-block h4','font-family','$font-1','','',''),(908461,'watch','.b-upload-file .upload-file-wrap .upload-remove','font-family','trueloaded','3','','.b-upload-file'),(908462,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-family','FontAwesome','','','.b-form'),(908463,'watch','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(908464,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(908465,'watch','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(908466,'watch','.w-reviews .heading-3','font-family','trueloaded','3','','.w-reviews'),(908467,'watch','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(908468,'watch','.b-info .info','font-family','trueloaded','3','','.b-info'),(908469,'watch','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(908470,'watch','.b-info .info strong','font-family','$font-1','','','.b-info'),(908471,'watch','.btn-del','font-family','FontAwesome','4','',''),(908472,'watch','.b-rating .glyphicon-star.coloron','font-family','FontAwesome','3','','.b-rating'),(908474,'watch','.w-cart-credit-amount .btn-remove','font-family','trueloaded','3','','.w-cart-credit-amount'),(908475,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(908476,'watch','.heading-6, h6, .h-block h6','font-family','$font-1','','',''),(908477,'watch','.closeable-heading','font-family','FontAwesome','3','',''),(908478,'watch','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(908479,'watch','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(908480,'watch','.b-bottom .pop-up-close','font-family','FontAwesome','3','','.b-bottom'),(908481,'watch','.b-info-popup .info-popup','font-family','trueloaded','3','','.b-info-popup'),(908482,'watch','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-family','FontAwesome','','','.b-products-listing'),(908483,'watch','.b-upload-files .remove-file','font-family','FontAwesome','3','','.b-upload-files'),(908484,'watch','.w-product-personal-catalog-button .btn','font-family','FontAwesome','3','','.w-product-personal-catalog-button'),(908485,'watch','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(908487,'watch','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(908488,'watch','.b-info .info','font-family','trueloaded','3','','.b-info'),(908489,'watch','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(908491,'watch','.w-product-personal-catalog-button .btn','font-family','FontAwesome','3','','.w-product-personal-catalog-button'),(908492,'watch','.w-product-personal-catalog-button .btn','font-family','$font-2','','','.w-product-personal-catalog-button'),(908493,'watch','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(908495,'watch','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(908496,'watch','.w-product-personal-catalog-button .btn','font-family','FontAwesome','3','','.w-product-personal-catalog-button'),(908497,'watch','.w-product-personal-catalog-button .btn','font-family','$font-2','','','.w-product-personal-catalog-button'),(908498,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','trueloaded','3','','.w-cart-gift-certificate'),(908499,'watch','.heading-3, h3, .h-block h3','font-family','$font-1','','',''),(908500,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-family','$font-2','','','.b-select-suggest'),(908501,'watch','.b-select-suggest .select2-search input','font-family','$font-2','','','.b-select-suggest'),(908502,'watch','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(908503,'watch','.w-product-personal-catalog-button .btn','font-family','$font-2','','','.w-product-personal-catalog-button'),(908504,'watch','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(908505,'watch','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(908506,'watch','.w-product-wishlist-button .btn','font-family','$font-2','','','.w-product-wishlist-button'),(908507,'watch','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(908508,'watch','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(908509,'watch','.b-products-listing .products-listing .bonus-points-price','font-family','FontAwesome','3','','.b-products-listing'),(908510,'watch','.b-products-listing .products-listing .bonus-points-cost','font-family','FontAwesome','3','','.b-products-listing'),(908511,'watch','.b-products-listing .products-listing a.btn.view-button','font-family','trueloaded','3','','.b-products-listing'),(908512,'watch','.b-products-listing .btn-preloader','font-family','FontAwesome','3','','.b-products-listing'),(908513,'watch','.b-products-listing .loader','font-family','FontAwesome','4','','.b-products-listing'),(908514,'watch','.b-products-listing .products-listing .btn-buy','font-family','trueloaded','3','','.b-products-listing'),(908515,'watch','.b-products-listing .products-listing h2','font-family','inherit','','','.b-products-listing'),(908516,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','trueloaded','3','','.w-cart-gift-certificate'),(908518,'watch','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(908519,'watch','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(908520,'watch','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(908521,'watch','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','font-family','FontAwesome','3','','.w-checkout-contact-information'),(908522,'watch','.w-product-wishlist-button .btn','font-family','$font-2','','','.w-product-wishlist-button'),(908523,'watch','.w-delivery-location-location-list .deliveryListParrent','font-family','$font-1','','','.w-delivery-location-location-list'),(908524,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(908525,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(908526,'watch','.b-form .eye-password','font-family','FontAwesome','3','','.b-form'),(908527,'watch','.heading-4 .right-text, h4 .right-text','font-family','$font-2','','',''),(908528,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-family','inherit','','',''),(908529,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-family','inherit','','','.b-h-inline'),(908530,'watch','h1, .heading-1','font-family','$font-1','','',''),(908532,'watch','.b-info .info strong','font-family','$font-1','','','.b-info'),(908533,'watch','.b-form .radio-button input[type=\"radio\"].no + span','font-family','FontAwesome','3','','.b-form'),(908534,'watch','.b-info .info','font-family','trueloaded','3','','.b-info'),(908535,'watch','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','font-family','FontAwesome','3','','.w-checkout-contact-information'),(908536,'watch','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(908537,'watch','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(908538,'watch','.w-tabs .tab-li.tab-quote a','font-family','trueloaded','3','','.w-tabs'),(908539,'watch','.w-delivery-location-location-list .deliveryListParrent','font-family','$font-1','','','.w-delivery-location-location-list'),(908540,'watch','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(908541,'watch','.b-info .info','font-family','trueloaded','3','','.b-info'),(908542,'watch','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','font-family','trueloaded','3','','.order-summary'),(908543,'watch','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(908544,'watch','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(908545,'watch','.w-product-cross-sell .buy-all-checker','font-family','FontAwesome','3','','.w-product-cross-sell'),(908546,'watch','.w-catalog-listing-look .b2b','font-family','FontAwesome','3','','.w-catalog-listing-look'),(908547,'watch','.w-catalog-listing-look .grid','font-family','FontAwesome','3','','.w-catalog-listing-look'),(908548,'watch','.checkbox input:checked + span:before','font-family','FontAwesome','','',''),(908549,'watch','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-family','trueloaded','3','','.w-cart-listing'),(908550,'watch','.w-cart-listing .points-earn','font-family','$font-2','','','.w-cart-listing'),(908551,'watch','.w-cart-listing .points-earn','font-family','trueloaded','3','','.w-cart-listing'),(908552,'watch','.w-cart-listing .points-redeem','font-family','$font-2','','','.w-cart-listing'),(908553,'watch','.w-cart-listing .points-redeem','font-family','FontAwesome','3','','.w-cart-listing'),(908554,'watch','.w-cart-listing .remove-btn','font-family','trueloaded','3','','.w-cart-listing'),(908555,'watch','.w-cart-give-away .ga_qty','font-family','$font-1','','','.w-cart-give-away'),(908556,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','trueloaded','3','','.w-cart-gift-certificate'),(908557,'watch','.w-cart-discount-coupon .btn-remove','font-family','trueloaded','3','','.w-cart-discount-coupon'),(908561,'watch','.w-tabs .accordion-heading','font-family','$font-1','','','.w-tabs'),(908562,'watch','.b-compare .clear_all','font-family','FontAwesome','4','','.b-compare'),(908563,'watch','.order-summary .price-row.ot_bonus_points .title','font-family','trueloaded','3','','.order-summary'),(908564,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','trueloaded','3','','.w-cart-gift-certificate'),(908565,'watch','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(908566,'watch','.w-checkout-credit-amount .btn-remove','font-family','trueloaded','3','','.w-checkout-credit-amount'),(908567,'watch','.w-product-wishlist-button .btn','font-family','$font-2','','','.w-product-wishlist-button'),(908568,'watch','.w-filters .view_more','font-family','FontAwesome','4','','.w-filters'),(908569,'watch','.w-filters span.close','font-family','FontAwesome','3','','.w-filters'),(908570,'watch','.w-filters .head-filter-widget','font-family','$font-1','','','.w-filters'),(908571,'watch','.w-quote .cart-box-link','font-family','trueloaded','3','','.w-quote'),(908572,'watch','.w-socials .post_item > div','font-family','FontAwesome','3','','.w-socials'),(908573,'watch','.b-dropdown .dropdown .dropdown-toggle','font-family','FontAwesome','4','','.b-dropdown'),(908574,'watch','.b-info .info strong','font-family','$font-1','','','.b-info'),(908575,'watch','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(908576,'watch','.heading-2, h2, .h-block h2','font-family','$font-1','','',''),(908577,'watch','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(908578,'watch','body','font-family','$font-2','','',''),(908579,'watch','.w-tabs .tab-li.tab-sample a','font-family','trueloaded','3','','.w-tabs'),(908580,'watch','.b-data-table table.dataTable thead td','font-family','$font-1','','','.b-data-table'),(908581,'watch','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(908582,'watch','.btn-3','font-family','$font-2','','',''),(908583,'watch','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(908585,'watch','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(908586,'watch','.w-filters .mobileCollapse','font-family','FontAwesome','4','','.w-filters'),(908587,'watch','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-family','FontAwesome','','','.w-filters'),(908588,'watch','.b-product-images .media-popup .mp-close','font-family','FontAwesome','3','','.b-product-images'),(908589,'watch','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','font-family','FontAwesome','3','','.b-menu-burger_icon'),(908590,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','font-family','FontAwesome','4','','.b-menu-style-1'),(908591,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > .parent > .no-link','font-family','FontAwesome','4','','.b-menu-style-1'),(908592,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','font-family','FontAwesome','4','','.b-menu-style-1'),(908593,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','font-family','FontAwesome','3','','.b-menu-style-2'),(908594,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','font-family','FontAwesome','3','','.b-menu-style-2'),(908595,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-family','FontAwesome','3','','.b-menu-style-2'),(908596,'watch','.w-account-personal-catalog .list-switcher a','font-family','$font-1','','','.w-account-personal-catalog'),(908597,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-family','$font-icons-2','3','','.w-catalog-compare'),(908598,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','font-family','$font-icons-1','','','.w-filters'),(908599,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','font-family','$font-icons-1','','','.w-filters'),(908600,'watch','.order-summary .icon','font-family','$font-icons-1','3','','.order-summary'),(908601,'watch','.w-cart-checkout-btn .with-card','font-family','$font-icons-1','4','','.w-cart-checkout-btn'),(908602,'watch','.w-cart-discount-coupon .title','font-family','$font-icons-1','4','','.w-cart-discount-coupon'),(908619,'watch','.catalog-product-wrap .pn-direction','font-family','$font-1','','','.catalog-product-wrap'),(908620,'watch','.catalog-product-wrap .pn-image','font-family','FontAwesome','3','','.catalog-product-wrap'),(908621,'watch','.checkout-index-wrap .comment-ico','font-family','trueloaded','3','','.checkout-index-wrap'),(908622,'watch','.checkout-index-wrap .discount-ico','font-family','trueloaded','3','','.checkout-index-wrap'),(908623,'watch','.checkout-index-wrap .order-ico','font-family','trueloaded','3','','.checkout-index-wrap'),(908624,'watch','.checkout-index-wrap .pay-ico','font-family','trueloaded','3','','.checkout-index-wrap'),(908625,'watch','.checkout-index-wrap .ship-ico','font-family','trueloaded','3','','.checkout-index-wrap'),(908626,'watch','.checkout-success-wrap .page-success .text-1','font-family','trueloaded','3','','.checkout-success-wrap'),(908627,'watch','.checkout-success-wrap .page-success .text-1, .checkout-success-wrap .page-success .text-2, .checkout-success-wrap .page-success .text-3','font-family','$font-1','','','.checkout-success-wrap'),(908628,'watch','.shopping-cart-index .gift-code .heading-4','font-family','FontAwesome','4','','.shopping-cart-index'),(908629,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-family','trueloaded','3','','.account-order-pay'),(908630,'watch','.account-samples .orders-table th','font-family','$font-1','','','.account-samples'),(908631,'watch','.account-samples .view_link','font-family','trueloaded','4','','.account-samples'),(908632,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-family','trueloaded','3','','.account-sample-info'),(908633,'watch','.checkout-order-confirmation .comment-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(908634,'watch','.checkout-order-confirmation .discount-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(908635,'watch','.checkout-order-confirmation .order-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(908636,'watch','.checkout-order-confirmation .pay-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(908637,'watch','.checkout-order-confirmation .prod-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(908638,'watch','.checkout-order-confirmation .ship-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(908640,'watch','.success-page .check-ico-block','font-family','trueloaded','3','','.success-page'),(908641,'watch','.success-page .comment-ico','font-family','trueloaded','3','','.success-page'),(908642,'watch','.success-page .discount-ico','font-family','trueloaded','3','','.success-page'),(908643,'watch','.success-page .order-ico','font-family','trueloaded','3','','.success-page'),(908644,'watch','.success-page .page-success .text-1','font-family','trueloaded','3','','.success-page'),(908645,'watch','.success-page .page-success .text-1, .success-page .page-success .text-2, .success-page .page-success .text-3','font-family','$font-1','','','.success-page'),(908646,'watch','.success-page .pay-ico','font-family','trueloaded','3','','.success-page'),(908647,'watch','.success-page .prod-ico','font-family','trueloaded','3','','.success-page'),(908648,'watch','.success-page .ship-ico','font-family','trueloaded','3','','.success-page'),(908649,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-family','$font-1','','','.b-multi-page-checkout'),(908650,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-family','FontAwesome','3','','.b-multi-page-checkout'),(908651,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-family','trueloaded','4','','.b-multi-page-checkout'),(908655,'watch','.w-bestsellers .heading-3','font-family','trueloaded','3','','.w-bestsellers'),(908656,'watch','.w-bestsellers .item','font-family','trueloaded','3','','.w-bestsellers'),(908657,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','font-family','FontAwesome','3','','.b-slick'),(908658,'watch','.w-catalog-paging .next','font-family','FontAwesome','3','','.w-catalog-paging'),(908659,'watch','.w-catalog-paging .prev','font-family','FontAwesome','3','','.w-catalog-paging'),(908660,'watch','.b-rating .glyphicon','font-family_important','important','','','.b-rating'),(908661,'watch','.w-communication-new-topic td.date-purchased','font-size','14','','','.w-communication-new-topic'),(908662,'watch','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-size','14','','','.w-communication-new-topic'),(908663,'watch','.b-email .price','font-size','14','','','.b-email'),(908664,'watch','.heading-4 .right-text, h4 .right-text','font-size','16','','',''),(908665,'watch','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(908666,'watch','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(908667,'watch','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(908669,'watch','.b-form .middle-form label','font-size','16','','','.b-form'),(908670,'watch','.b-email-editor .price','font-size','18','','','.b-email-editor'),(908671,'watch','.w-delivery-location-top-location-list .deliveryName a','font-size','21','','','.w-delivery-location-top-location-list'),(908672,'watch','.p-quick-order-index .paginate_button.previous','font-size','20','3','','.p-quick-order-index'),(908673,'watch','.b-email .qty','font-size','14','','','.b-email'),(908674,'watch','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','font-size','13','','','.p-quick-order-index'),(908675,'watch','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-size','14','','','.p-quick-order-index'),(908676,'watch','.p-quick-order-index .paginate_button.next','font-size','20','3','','.p-quick-order-index'),(908677,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.next','font-size','0','','','.p-quick-order-index'),(908678,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.previous','font-size','0','','','.p-quick-order-index'),(908679,'watch','.w-promotions .promo-item','font-size','24','','','.w-promotions'),(908681,'watch','.w-promotions .prom-multi-discount .promo-range','font-size','13','','','.w-promotions'),(908683,'watch','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(908685,'watch','.w-cart-compare .attributes-label','font-size','14','','','.w-cart-compare'),(908687,'watch','.w-personal-gift-status-bar .end-label','font-size','14','','','.w-personal-gift-status-bar'),(908688,'watch','.p-sample-checkout-success .page-success .text-1','font-size','60','','','.p-sample-checkout-success'),(908689,'watch','.shipping-ico .heading-2','font-size','32','3','','.shipping-ico'),(908690,'watch','.p-sample-checkout-success .page-success .text-3','font-size','27','','','.p-sample-checkout-success'),(908691,'watch','.p-sample-checkout-success .page-success .text-2','font-size','34','','','.p-sample-checkout-success'),(908692,'watch','.order-summary .heading-2','font-size','36','3','','.order-summary'),(908693,'watch','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(908694,'watch','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(908695,'watch','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(908696,'watch','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(908697,'watch','.w-promotions .prom-multi-discount .heading','font-size','26','','','.w-promotions'),(908698,'watch','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(908699,'watch','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(908700,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(908701,'watch','.b-email .heading-name','font-size','14','','','.b-email'),(908702,'watch','.testimonials .reviews-list span','font-size','22','','',''),(908703,'watch','.testimonials .rating','font-size','22','','',''),(908704,'watch','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(908705,'watch','.testimonials .reviews-list .date','font-size','14','','',''),(908706,'watch','.testimonials .date','font-size','14','','',''),(908707,'watch','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','font-size','14','','','.w-promotions'),(908708,'watch','.w-promotions .prom-multi-discount .promo-group','font-size','16','','','.w-promotions'),(908709,'watch','.w-promotions .nextdiscount .heading','font-size','26','','','.w-promotions'),(908710,'watch','.w-promotions .nextdiscount .heading','font-size','18','3','','.w-promotions'),(908711,'watch','.w-promotions .nextdiscount .promo-for-each','font-size','14','','','.w-promotions'),(908712,'watch','.w-promotions .nextdiscount .item-holder .name','font-size','14','','','.w-promotions'),(908713,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.p-quick-order-index'),(908714,'watch','.w-promotions .heading-3','font-size','48','','','.w-promotions'),(908715,'watch','.w-promotions .promo-salemaker .discount','font-size','13','','','.w-promotions'),(908716,'watch','.w-promotions .promo-salemaker .content a','font-size','14','','','.w-promotions'),(908717,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','font-size','16','','','.w-promotions'),(908718,'watch','.w-promotions .promo-cart-discount .promo-min-qty','font-size','13','','','.w-promotions'),(908719,'watch','.b-warehouses-popup .warehouses-popup .warehouse-name','font-size','16','','','.b-warehouses-popup'),(908720,'watch','.w-promotions .promo-cart-discount .item a','font-size','14','','','.w-promotions'),(908721,'watch','.b-warehouses-popup a.warehouses-popup-link','font-size','14','','','.b-warehouses-popup'),(908722,'watch','.b-warehouses-popup .warehouses-popup .heading','font-size','18','','','.b-warehouses-popup'),(908723,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','font-size','14','','','.b-warehouses-popup'),(908724,'watch','.b-preloader .preloader','font-size','40','3','','.b-preloader'),(908725,'watch','.w-chat .w-chat-box a','font-size','20','3','','.w-chat'),(908726,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(908727,'watch','.w-cart-compare .dropdown li','font-size','14','','','.w-cart-compare'),(908728,'watch','.w-cart-compare .attributes-cell','font-size','14','','','.w-cart-compare'),(908729,'watch','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(908730,'watch','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(908731,'watch','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(908732,'watch','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','font-size','12','3','','.order-summary'),(908733,'watch','.b-compare .compare-head','font-size','22','','','.b-compare'),(908734,'watch','.b-quantity .qty-box .smaller','font-size','31','','','.b-quantity'),(908735,'watch','.b-bottom .closeable-heading','font-size','20','3','','.b-bottom'),(908736,'watch','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(908737,'watch','.b-messages .messBtnMenuDelete','font-size','22','3','','.b-messages'),(908738,'watch','.w-product-collection .right-area .special','font-size','30','','','.w-product-collection'),(908739,'watch','.b-messages .content-messages .heading-2','font-size','26','','','.b-messages'),(908740,'watch','.b-messages span.starred::before','font-size','16','','','.b-messages'),(908741,'watch','.b-messages .messBtnMenuStarred','font-size','22','3','','.b-messages'),(908742,'watch','.b-messages .messBtnMenuUnread','font-size','22','3','','.b-messages'),(908743,'watch','.b-messages .messMenuButton span','font-size','14','','','.b-messages'),(908744,'watch','.b-messages .content_management_attach','font-size','14','','','.b-messages'),(908745,'watch','.b-messages .content_management_attach span','font-size','16','','','.b-messages'),(908746,'watch','.b-messages .content_management_attach button','font-size','14','','','.b-messages'),(908747,'watch','.b-messages .select2-search-choice-close','font-size','11','3','','.b-messages'),(908748,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','font-size','14','','',''),(908749,'watch','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(908750,'watch','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(908751,'watch','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(908752,'watch','.w-product-personal-catalog-button .btn','font-size','21','3','','.w-product-personal-catalog-button'),(908753,'watch','.w-product-collection .right-area .special','font-size','30','','','.w-product-collection'),(908754,'watch','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(908755,'watch','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(908756,'watch','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(908757,'watch','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(908758,'watch','.b-info .info strong','font-size','18','','','.b-info'),(908760,'watch','.w-product-in-bundles .product-link','font-size','16','','','.w-product-in-bundles'),(908761,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(908762,'watch','.w-product-personal-catalog-button .btn','font-size','14','','','.w-product-personal-catalog-button'),(908763,'watch','.p-payer-order-confirmation .ship-ico','font-size','30','3','','.p-payer-order-confirmation'),(908764,'watch','.p-payer-order-confirmation .pay-ico','font-size','30','3','','.p-payer-order-confirmation'),(908765,'watch','.p-payer-order-confirmation .order-ico','font-size','36','3','','.p-payer-order-confirmation'),(908766,'watch','.b-data-table table.dataTable thead td','font-size','16','','','.b-data-table'),(908767,'watch','.p-payer-order-confirmation .discount-ico','font-size','30','3','','.p-payer-order-confirmation'),(908768,'watch','.p-payer-order-pay .ship-ico','font-size','30','3','','.p-payer-order-pay'),(908769,'watch','.p-payer-order-confirmation .comment-ico','font-size','30','3','','.p-payer-order-confirmation'),(908770,'watch','.p-payer-order-pay .pay-ico','font-size','30','3','','.p-payer-order-pay'),(908771,'watch','.p-payer-order-pay .order-ico','font-size','36','3','','.p-payer-order-pay'),(908772,'watch','.p-payer-order-pay .comment-ico','font-size','30','3','','.p-payer-order-pay'),(908773,'watch','.p-payer-order-pay .discount-ico','font-size','30','3','','.p-payer-order-pay'),(908774,'watch','.w-checkout-terms .terms-box','font-size','13','','','.w-checkout-terms'),(908775,'watch','.w-cart-cart-tabs .w-tabs .tab-a','font-size','12','5232','','.w-cart-cart-tabs'),(908776,'watch','.order-summary .price-box .title','font-size','15','','','.order-summary'),(908777,'watch','.b-email .heading-qty','font-size','14','','','.b-email'),(908778,'watch','.b-email .model','font-size','14','','','.b-email'),(908779,'watch','.b-email .heading-name','font-size','14','','','.b-email'),(908780,'watch','.p-quote-checkout-success .page-success .text-2','font-size','30','5232','','.p-quote-checkout-success'),(908781,'watch','.w-product-properties li','font-size','14','','','.w-product-properties'),(908782,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(908783,'watch','.b-page-name .page-name','font-size','20','','','.b-page-name'),(908784,'watch','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(908785,'watch','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(908786,'watch','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(908787,'watch','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(908788,'watch','.w-product-properties li','font-size','14','','','.w-product-properties'),(908789,'watch','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(908790,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','font-size','10','','','.b-switch'),(908791,'watch','.b-quantity .qty-box .smaller','font-size','31','','','.b-quantity'),(908792,'watch','.shipping-ico .heading-2','font-size','32','3','','.shipping-ico'),(908793,'watch','.p-quick-order-index .value','font-size','20','','','.p-quick-order-index'),(908794,'watch','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-size','20','','','.w-upload-customer-id-upload-customer-id-form'),(908795,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-template','font-size','18','','','.w-upload-customer-id-upload-customer-id-form'),(908796,'watch','.b-switch .bootstrap-switch','font-size','16','','','.b-switch'),(908797,'watch','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(908798,'watch','.b-info .info strong','font-size','18','','','.b-info'),(908799,'watch','.b-email .qty','font-size','14','','','.b-email'),(908800,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(908801,'watch','.w-coupons-and-vauchers-checkout .btn-remove','font-size','12','','','.w-coupons-and-vauchers-checkout'),(908802,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','font-size','7','','','.b-switch'),(908804,'watch','.b-form .required-message','font-size','14','','','.b-form'),(908805,'watch','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(908806,'watch','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(908809,'watch','.b-email-editor .price','font-size','18','','','.b-email-editor'),(908810,'watch','.b-info-popup .info-popup div','font-size','14','','','.b-info-popup'),(908811,'watch','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-size','24','','','.w-multi-cart-cart-switcher'),(908812,'watch','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(908813,'watch','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(908814,'watch','.w-product-personal-catalog-button .btn','font-size','21','3','','.w-product-personal-catalog-button'),(908815,'watch','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(908816,'watch','.w-product-properties li','font-size','14','','','.w-product-properties'),(908817,'watch','.p-quote-checkout-success .page-success .text-2','font-size','30','5232','','.p-quote-checkout-success'),(908818,'watch','.w-personal-gift-status-bar .inform','font-size','24','4','','.w-personal-gift-status-bar'),(908819,'watch','.w-promo-code .holder','font-size','30','5261,3','','.w-promo-code'),(908820,'watch','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(908821,'watch','.no-found','font-size','1.4','','',''),(908822,'watch','.price','font-size','24','','',''),(908823,'watch','.w-product-personal-catalog-button .btn','font-size','14','','','.w-product-personal-catalog-button'),(908824,'watch','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(908826,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(908827,'watch','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(908828,'watch','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(908829,'watch','.w-product-personal-catalog-button .btn','font-size','14','','','.w-product-personal-catalog-button'),(908830,'watch','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(908831,'watch','.w-product-in-bundles .product-link','font-size','16','','','.w-product-in-bundles'),(908832,'watch','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(908833,'watch','.w-filters .input-checkbox:checked + .checkbox-span:before','font-size','28','','','.w-filters'),(908834,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','font-size','14','','','.b-switch'),(908835,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','font-size','14','','','.b-switch'),(908836,'watch','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(908837,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(908838,'watch','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(908839,'watch','.w-delivery-location-top-location-list .deliveryName a','font-size','21','','','.w-delivery-location-top-location-list'),(908840,'watch','.b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(908841,'watch','.w-personal-gift-status-bar .end-date','font-size','22','3','','.w-personal-gift-status-bar'),(908842,'watch','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(908843,'watch','.b-email .heading-model','font-size','14','','','.b-email'),(908844,'watch','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(908845,'watch','.b-info .info','font-size','30','3','','.b-info'),(908846,'watch','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(908847,'watch','.b-email .totals-label','font-size','18','','','.b-email'),(908848,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-size','18','','','.b-form'),(908849,'watch','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(908850,'watch','.w-reviews-content .rating','font-size','18','','','.w-reviews-content'),(908851,'watch','.w-reviews-content .date','font-size','13','','','.w-reviews-content'),(908852,'watch','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(908853,'watch','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(908854,'watch','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(908855,'watch','.w-reviews .date','font-size','13','','','.w-reviews'),(908856,'watch','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(908858,'watch','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(908859,'watch','h1','font-size','22','5240','',''),(908860,'watch','.b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(908861,'watch','.b-quantity .qty-box .smaller','font-size','31','','','.b-quantity'),(908862,'watch','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(908863,'watch','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(908864,'watch','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(908865,'watch','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(908866,'watch','.bell-ico .heading-2','font-size','32','3','','.bell-ico'),(908867,'watch','.w-personal-gift-status-bar .end-date','font-size','14','','','.w-personal-gift-status-bar'),(908868,'watch','.w-cart-compare .price-cell','font-size','18','','','.w-cart-compare'),(908869,'watch','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(908870,'watch','.w-cart-compare .price-label','font-size','14','','','.w-cart-compare'),(908871,'watch','.w-checkout-create-account .account-benefits','font-size','0.8','','','.w-checkout-create-account'),(908872,'watch','.w-cart-listing .price','font-size','18','','','.w-cart-listing'),(908873,'watch','.w-cart-compare .js-cart_totals_container b','font-size','16','','','.w-cart-compare'),(908874,'watch','.p-quote-checkout-success .page-success .text-2','font-size','30','5232','','.p-quote-checkout-success'),(908875,'watch','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(908876,'watch','.view-all .btn','font-size','0.8','4','',''),(908877,'watch','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(908878,'watch','.b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(908879,'watch','.btn-1','font-size','16','','',''),(908880,'watch','.b-form .privacy-row','font-size','16','','','.b-form'),(908881,'watch','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(908882,'watch','.b-email .name','font-size','14','','','.b-email'),(908883,'watch','.w-tabs .tab-li.tab-quote a','font-size','29','3','','.w-tabs'),(908884,'watch','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(908885,'watch','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(908886,'watch','.w-product-collection .right-area .special','font-size','30','','','.w-product-collection'),(908890,'watch','.w-tabs .tab-a','font-size','16','5240','','.w-tabs'),(908891,'watch','.w-tabs .tab-a','font-size','20','','','.w-tabs'),(908892,'watch','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(908894,'watch','.btn-edit','font-size','0.8','3','',''),(908895,'watch','.w-promo-code .holder','font-size','30','5261,3','','.w-promo-code'),(908896,'watch','.w-tabs .tab-li.tab-wishlist a','font-size','25','3','','.w-tabs'),(908897,'watch','.w-delivery-location-top-location-list .deliveryName a','font-size','21','','','.w-delivery-location-top-location-list'),(908898,'watch','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(908899,'watch','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(908900,'watch','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(908901,'watch','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(908902,'watch','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(908903,'watch','.w-personal-gift-status-bar .start-label','font-size','14','','','.w-personal-gift-status-bar'),(908904,'watch','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(908905,'watch','.heading-4 .edit, h4 .edit','font-size','16','','',''),(908906,'watch','.heading-6, h6, .h-block h6','font-size','16','','',''),(908907,'watch','.btn-2','font-size','18','','',''),(908909,'watch','.w-cart-compare .cart-name a','font-size','17','','','.w-cart-compare'),(908910,'watch','.w-cart-compare .delete-cart','font-size','12','','','.w-cart-compare'),(908911,'watch','.w-product-collection .right-area .special','font-size','30','','','.w-product-collection'),(908912,'watch','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(908913,'watch','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(908914,'watch','.w-product-personal-catalog-button .btn','font-size','21','3','','.w-product-personal-catalog-button'),(908915,'watch','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(908916,'watch','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(908917,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(908918,'watch','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(908919,'watch','.b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(908920,'watch','.p-sample-checkout-success .page-success .text-2','font-size','30','5232','','.p-sample-checkout-success'),(908921,'watch','.w-top-categories .categories h2','font-size','inherit','','','.w-top-categories'),(908922,'watch','.out-stock','font-size','14','','',''),(908923,'watch','.transit','font-size','14','','',''),(908924,'watch','.in-stock','font-size','14','','',''),(908925,'watch','.heading-3 .right-text, h3 .right-text','font-size','16','','',''),(908926,'watch','.heading-3 .edit, h3 .edit','font-size','14','4','',''),(908927,'watch','.heading-3 .edit, h3 .edit','font-size','16','','',''),(908928,'watch','.heading-5, h5, .h-block h5','font-size','17','','',''),(908929,'watch','.b-email .heading-model','font-size','14','','','.b-email'),(908930,'watch','.b-email .heading-price','font-size','14','','','.b-email'),(908931,'watch','.b-quantity .qty-box .smaller','font-size','31','','','.b-quantity'),(908932,'watch','.b-page-name .page-name','font-size','20','','','.b-page-name'),(908933,'watch','.b-info .info','font-size','30','3','','.b-info'),(908934,'watch','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(908935,'watch','.shipping-ico .heading-2','font-size','32','3','','.shipping-ico'),(908936,'watch','.w-cart-credit-amount .text','font-size','14','','','.w-cart-credit-amount'),(908937,'watch','.w-cart-discount-coupon .text','font-size','14','','','.w-cart-discount-coupon'),(908938,'watch','.order-summary .price-box .price-row.total','font-size','22','','','.order-summary'),(908939,'watch','.order-summary .price','font-size','18','','','.order-summary'),(908940,'watch','.savings-ico .heading-2','font-size','32','3','','.savings-ico'),(908941,'watch','.b-email .model','font-size','14','','','.b-email'),(908942,'watch','.b-email .name','font-size','14','','','.b-email'),(908943,'watch','.w-product-collection .right-area .special','font-size','30','','','.w-product-collection'),(908945,'watch','.testimonials .heading-3','font-size','37','3','',''),(908946,'watch','.js-stock','font-size','14','','',''),(908947,'watch','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(908948,'watch','.w-checkout-shipping-choice span','font-size','14','5261','','.w-checkout-shipping-choice'),(908949,'watch','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(908950,'watch','.w-product-personal-catalog-button .btn','font-size','14','','','.w-product-personal-catalog-button'),(908951,'watch','.w-product-in-bundles .product-link','font-size','16','','','.w-product-in-bundles'),(908952,'watch','.w-product-personal-catalog-button .btn','font-size','21','3','','.w-product-personal-catalog-button'),(908953,'watch','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(908954,'watch','.w-product-reviews .reviews-list .date','font-size','14','','','.w-product-reviews'),(908955,'watch','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(908956,'watch','.b-email-editor .price','font-size','18','','','.b-email-editor'),(908957,'watch','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(908958,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(908959,'watch','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(908960,'watch','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(908961,'watch','.w-product-properties li','font-size','14','','','.w-product-properties'),(908962,'watch','.b-email .model','font-size','14','','','.b-email'),(908964,'watch','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(908965,'watch','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(908966,'watch','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(908967,'watch','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(908968,'watch','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(908969,'watch','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(908970,'watch','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(908971,'watch','.heading-4, h4, .h-block h4','font-size','18','','',''),(908972,'watch','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(908973,'watch','.b-email .price','font-size','14','','','.b-email'),(908975,'watch','.b-email .name','font-size','14','','','.b-email'),(908976,'watch','.btn','font-size','16','','',''),(908977,'watch','.b-email .heading-model','font-size','14','','','.b-email'),(908978,'watch','.b-email .price','font-size','14','','','.b-email'),(908979,'watch','.b-email .heading-qty','font-size','14','','','.b-email'),(908985,'watch','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(908986,'watch','.b-email .qty','font-size','14','','','.b-email'),(908987,'watch','.b-email .heading-qty','font-size','14','','','.b-email'),(908988,'watch','.b-email .heading-name','font-size','14','','','.b-email'),(908989,'watch','.b-email .heading-price','font-size','14','','','.b-email'),(908990,'watch','.b-email .totals-label','font-size','18','','','.b-email'),(908991,'watch','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(908993,'watch','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(908994,'watch','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(908995,'watch','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(908997,'watch','.b-info .info','font-size','30','3','','.b-info'),(908998,'watch','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(908999,'watch','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(909000,'watch','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(909001,'watch','.w-promo-code .holder','font-size','30','5261,3','','.w-promo-code'),(909002,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(909003,'watch','.message.success','font-size','30','3','',''),(909004,'watch','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(909005,'watch','.w-reviews .heading-3','font-size','37','3','','.w-reviews'),(909006,'watch','.b-sub-totals .historyTotal table td','font-size','18','','','.b-sub-totals'),(909007,'watch','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(909008,'watch','.b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(909009,'watch','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(909010,'watch','.b-info .info','font-size','30','3','','.b-info'),(909011,'watch','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(909012,'watch','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(909013,'watch','.p-quote-checkout-success .page-success .text-1','font-size','40','5232','','.p-quote-checkout-success'),(909014,'watch','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(909016,'watch','.b-info .info strong','font-size','18','','','.b-info'),(909017,'watch','.b-form .checkbox-style:checked + .checkbox-span:before','font-size','18','','','.b-form'),(909018,'watch','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(909019,'watch','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(909020,'watch','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(909021,'watch','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(909023,'watch','.w-social-links a','font-size','30','5232','','.w-social-links'),(909024,'watch','.b-info .info strong','font-size','18','','','.b-info'),(909025,'watch','.b-email .name','font-size','14','','','.b-email'),(909026,'watch','.b-email .heading-qty','font-size','14','','','.b-email'),(909027,'watch','.p-quick-order-index .stock','font-size','12','','','.p-quick-order-index'),(909028,'watch','.b-email .price','font-size','14','','','.b-email'),(909029,'watch','.p-quote-checkout-success .page-success .text-1','font-size','40','5232','','.p-quote-checkout-success'),(909030,'watch','.w-cart-compare .js-cart_totals_container','font-size','14','','','.w-cart-compare'),(909031,'watch','.p-quote-checkout-success .page-success .text-1','font-size','40','5232','','.p-quote-checkout-success'),(909032,'watch','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(909033,'watch','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(909034,'watch','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(909035,'watch','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(909036,'watch','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(909037,'watch','.b-bottom .alert-message','font-size','18','','','.b-bottom'),(909038,'watch','.w-delivery-location-top-location-list .deliveryName a','font-size','21','','','.w-delivery-location-top-location-list'),(909039,'watch','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(909040,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(909041,'watch','.w-cart-compare .product .name a','font-size','14','','','.w-cart-compare'),(909042,'watch','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(909043,'watch','.b-email .totals-label','font-size','18','','','.b-email'),(909044,'watch','.w-checkout-credit-amount .btn-remove','font-size','12','','','.w-checkout-credit-amount'),(909046,'watch','.b-info-popup .info-popup','font-size','20','3','','.b-info-popup'),(909047,'watch','.b-info .info','font-size','30','3','','.b-info'),(909048,'watch','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(909049,'watch','.b-email .name','font-size','14','','','.b-email'),(909050,'watch','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(909051,'watch','.p-quote-checkout-success .page-success .text-1','font-size','40','5232','','.p-quote-checkout-success'),(909052,'watch','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(909053,'watch','.b-info .info strong','font-size','18','','','.b-info'),(909054,'watch','.b-email .price','font-size','14','','','.b-email'),(909055,'watch','.b-email .heading-model','font-size','14','','','.b-email'),(909056,'watch','.b-email .heading-name','font-size','14','','','.b-email'),(909057,'watch','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(909058,'watch','.b-email .heading-price','font-size','14','','','.b-email'),(909059,'watch','.b-email .model','font-size','14','','','.b-email'),(909060,'watch','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(909061,'watch','.order-summary .price-row.ot_coupon .title','font-size','18','3','','.order-summary'),(909062,'watch','.w-cart-shipping-estimator .address-item','font-size','14','','','.w-cart-shipping-estimator'),(909063,'watch','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','font-size','20','','','.b-products-listing'),(909064,'watch','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-size','20','','','.b-products-listing'),(909065,'watch','.b-products-listing .products-listing .attribute-qty-block','font-size','14','','','.b-products-listing'),(909066,'watch','.w-cart-credit-amount .btn-remove','font-size','12','','','.w-cart-credit-amount'),(909067,'watch','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(909068,'watch','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(909069,'watch','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(909070,'watch','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(909071,'watch','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(909073,'watch','.p-quick-order-index .in-stock, .p-quick-order-index .out-stock','font-size','12','','','.p-quick-order-index'),(909074,'watch','.b-email .heading-price','font-size','14','','','.b-email'),(909075,'watch','.b-email .name','font-size','14','','','.b-email'),(909076,'watch','.b-email .heading-name','font-size','14','','','.b-email'),(909077,'watch','.b-form .middle-form .middle-rating span','font-size','26','','','.b-form'),(909078,'watch','.b-info .info','font-size','30','3','','.b-info'),(909080,'watch','.b-quantity .qty-box .bigger','font-size','31','','','.b-quantity'),(909081,'watch','.w-product-customers-activity .customers-activity','font-size','16','','','.w-product-customers-activity'),(909082,'watch','.w-product-available-in-warehouses .heading','font-size','18','','','.w-product-available-in-warehouses'),(909083,'watch','.b-bottom .confirm-popup .confirm-text','font-size','20','','','.b-bottom'),(909084,'watch','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(909085,'watch','.b-email .qty','font-size','14','','','.b-email'),(909086,'watch','.b-page-name .page-name','font-size','20','','','.b-page-name'),(909090,'watch','.w-product-personal-catalog-button .btn','font-size','21','3','','.w-product-personal-catalog-button'),(909091,'watch','.w-product-personal-catalog-button .btn','font-size','14','','','.w-product-personal-catalog-button'),(909092,'watch','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(909093,'watch','.p-sample-checkout-success .page-success .text-1','font-size','80','3','','.p-sample-checkout-success'),(909094,'watch','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-size','22','','','.order-summary'),(909096,'watch','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(909097,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(909098,'watch','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(909099,'watch','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(909100,'watch','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(909101,'watch','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(909102,'watch','.w-product-in-bundles .product-link','font-size','16','','','.w-product-in-bundles'),(909103,'watch','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(909104,'watch','.w-product-properties li','font-size','14','','','.w-product-properties'),(909105,'watch','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(909106,'watch','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(909107,'watch','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(909108,'watch','.w-product-personal-catalog-button .btn','font-size','21','3','','.w-product-personal-catalog-button'),(909109,'watch','.w-menu-horizontal .menu-ico','font-size','23','','','.w-menu-horizontal'),(909110,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(909111,'watch','.w-promo-code .holder','font-size','30','5261,3','','.w-promo-code'),(909112,'watch','.w-categories h2.name','font-size','18','','','.w-categories'),(909113,'watch','.w-cart-checkout-btn a','font-size','17','5232','','.w-cart-checkout-btn'),(909114,'watch','.price .old','font-size','0.8','','',''),(909115,'watch','.b-quantity .qty-box .smaller','font-size','31','','','.b-quantity'),(909116,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(909117,'watch','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(909118,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(909119,'watch','.w-cart-compare .product-actions .dropdown-toggle','font-size','18','3','','.w-cart-compare'),(909120,'watch','.w-social-links a','font-size','26','','','.w-social-links'),(909121,'watch','.b-fancybox .fancybox-close','font-size','26','','','.b-fancybox'),(909122,'watch','.b-select-suggest .select2-search-choice-close','font-size','1','','','.b-select-suggest'),(909123,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-size','100','','','.b-select-suggest'),(909124,'watch','.b-select-suggest .select2-search input','font-size','1','','','.b-select-suggest'),(909125,'watch','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(909126,'watch','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(909127,'watch','.w-product-personal-catalog-button .btn','font-size','14','','','.w-product-personal-catalog-button'),(909128,'watch','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(909129,'watch','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(909130,'watch','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(909131,'watch','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(909132,'watch','.p-sample-checkout-success .page-success .text-1','font-size','40','5232','','.p-sample-checkout-success'),(909133,'watch','.w-cart-compare .product-actions','font-size','12','','','.w-cart-compare'),(909134,'watch','.w-delivery-location-top-location-list .deliveryName a','font-size','21','','','.w-delivery-location-top-location-list'),(909135,'watch','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(909136,'watch','.w-product-properties li','font-size','14','','','.w-product-properties'),(909137,'watch','.w-product-in-bundles .product-link','font-size','16','','','.w-product-in-bundles'),(909138,'watch','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(909139,'watch','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(909140,'watch','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(909141,'watch','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(909142,'watch','.w-personal-gift-status-bar .inform','font-size','14','','','.w-personal-gift-status-bar'),(909143,'watch','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(909144,'watch','.w-quote-products .empty','font-size','24','','','.w-quote-products'),(909145,'watch','.b-bottom .footerTitle','font-size','24','','','.b-bottom'),(909146,'watch','.w-account-addresses-list .addsess-suggestion-item','font-size','14','','','.w-account-addresses-list'),(909147,'watch','.w-communication-post .communication-post-date','font-size','14','','','.w-communication-post'),(909148,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.b-data-table'),(909149,'watch','.w-communication-post .communication-post-attach','font-size','14','','','.w-communication-post'),(909150,'watch','.b-products-listing .products-listing .bonusPoints','font-size','13','','','.b-products-listing'),(909151,'watch','.b-products-listing .products-listing .model','font-size','14','','','.b-products-listing'),(909152,'watch','.b-products-listing .btn-preloader','font-size','24','3','','.b-products-listing'),(909153,'watch','.b-products-listing .loader','font-size','30','4','','.b-products-listing'),(909154,'watch','.b-products-listing .products-listing h2','font-size','inherit','','','.b-products-listing'),(909155,'watch','.b-products-listing .promos-info .promo-name','font-size','14','','','.b-products-listing'),(909156,'watch','.b-products-listing .wedding-registry-count','font-size','14','','','.b-products-listing'),(909158,'watch','.w-quote .cart-box-link','font-size','1.5','3','','.w-quote'),(909159,'watch','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(909160,'watch','.p-quote-checkout-success .page-success .text-2','font-size','30','5232','','.p-quote-checkout-success'),(909161,'watch','.p-quote-checkout-success .page-success .text-1','font-size','40','5232','','.p-quote-checkout-success'),(909162,'watch','.b-quantity .qty-box .smaller','font-size','31','','','.b-quantity'),(909163,'watch','.b-email-editor .price','font-size','18','','','.b-email-editor'),(909164,'watch','.b-form .cart-popup .price','font-size','18','','','.b-form'),(909165,'watch','.b-email-editor .price','font-size','18','','','.b-email-editor'),(909166,'watch','.b-email .heading-model','font-size','14','','','.b-email'),(909167,'watch','.p-quote-checkout-success .page-success .text-1','font-size','40','5232','','.p-quote-checkout-success'),(909169,'watch','.w-top-categories h2.name','font-size','18','','','.w-top-categories'),(909170,'watch','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(909171,'watch','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(909172,'watch','.w-product-reviews .reviews-list span','font-size','22','','','.w-product-reviews'),(909173,'watch','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(909174,'watch','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(909175,'watch','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(909176,'watch','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(909177,'watch','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(909178,'watch','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(909179,'watch','.w-taxable .bootstrap-switch .bootstrap-switch-label','font-size','0','','','.w-taxable'),(909180,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-size','inherit','','',''),(909181,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-size','inherit','','','.b-h-inline'),(909182,'watch','h1, .heading-1','font-size','32','','',''),(909183,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','font-size','31','','','.w-communication-new-topic'),(909184,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','font-size','31','','','.w-communication-new-topic'),(909185,'watch','.b-page-name .page-name','font-size','20','','','.b-page-name'),(909186,'watch','.b-email .heading-price','font-size','14','','','.b-email'),(909187,'watch','.b-email .totals-label','font-size','18','','','.b-email'),(909188,'watch','.b-email .price','font-size','14','','','.b-email'),(909189,'watch','.b-email .heading-name','font-size','14','','','.b-email'),(909190,'watch','.b-bottom .popup-heading','font-size','16','','','.b-bottom'),(909191,'watch','.w-promo-code .holder','font-size','30','5261,3','','.w-promo-code'),(909192,'watch','.p-quote-checkout-success .page-success .text-2','font-size','30','5232','','.p-quote-checkout-success'),(909193,'watch','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(909194,'watch','.w-product-in-bundles .product-link','font-size','16','','','.w-product-in-bundles'),(909195,'watch','.w-product-collection .right-area .special','font-size','30','','','.w-product-collection'),(909196,'watch','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(909197,'watch','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(909198,'watch','.w-tabs .tab-li.tab-sample a','font-size','29','3','','.w-tabs'),(909199,'watch','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(909200,'watch','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(909201,'watch','.b-email .model','font-size','14','','','.b-email'),(909202,'watch','.w-cart-compare .atr-col','font-size','20','3','','.w-cart-compare'),(909203,'watch','.w-quote .cart-box-link','font-size','30','5240,3','','.w-quote'),(909204,'watch','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(909205,'watch','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(909206,'watch','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(909207,'watch','.b-email .qty','font-size','14','','','.b-email'),(909208,'watch','.b-email .model','font-size','14','','','.b-email'),(909209,'watch','.b-email .totals-label','font-size','18','','','.b-email'),(909210,'watch','.checkbox input:checked + span:before','font-size','18','','',''),(909211,'watch','.p-quick-order-index .dataTables_info','font-size','14','','','.p-quick-order-index'),(909212,'watch','.w-cart-listing .item .gift-wrap label','font-size','14','','','.w-cart-listing'),(909213,'watch','.w-cart-listing .item .attributes','font-size','14','','','.w-cart-listing'),(909214,'watch','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-size','12','','','.w-cart-listing'),(909215,'watch','.w-cart-listing .points-earn','font-size','14','','','.w-cart-listing'),(909216,'watch','.w-cart-listing .points-earn','font-size','14','3','','.w-cart-listing'),(909217,'watch','.w-cart-listing .points-redeem','font-size','14','','','.w-cart-listing'),(909218,'watch','.w-cart-listing .points-redeem','font-size','14','3','','.w-cart-listing'),(909219,'watch','.w-cart-listing .remove-btn','font-size','28','','','.w-cart-listing'),(909220,'watch','.w-cart-listing .remove-btn span','font-size','16','5240','','.w-cart-listing'),(909221,'watch','.w-cart-give-away .ga_name','font-size','16','','','.w-cart-give-away'),(909222,'watch','.w-cart-give-away .ga_qty','font-size','20','','','.w-cart-give-away'),(909223,'watch','.w-cart-give-away .ga_qty','font-size','17','5232','','.w-cart-give-away'),(909224,'watch','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(909225,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(909226,'watch','.w-cart-discount-coupon .btn-remove','font-size','12','','','.w-cart-discount-coupon'),(909232,'watch','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(909233,'watch','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(909234,'watch','.b-upload-file .snapshot','font-size','18','','','.b-upload-file'),(909235,'watch','.b-fancybox .fancybox-nav span','font-size','34','','','.b-fancybox'),(909236,'watch','.b-email-editor .price','font-size','18','','','.b-email-editor'),(909237,'watch','.b-email .heading-qty','font-size','14','','','.b-email'),(909238,'watch','.w-promo-code .holder','font-size','30','5261,3','','.w-promo-code'),(909240,'watch','.w-tabs .accordion-heading','font-size','20','','','.w-tabs'),(909241,'watch','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(909242,'watch','.w-tabs .tab-li.tab-cart a','font-size','29','3','','.w-tabs'),(909243,'watch','.b-compare .clear_all','font-size','16','4','','.b-compare'),(909244,'watch','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(909245,'watch','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(909246,'watch','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(909247,'watch','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(909248,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(909250,'watch','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(909251,'watch','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(909252,'watch','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(909253,'watch','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(909254,'watch','.w-checkout-create-account .account-benefits strong','font-size','18','3','','.w-checkout-create-account'),(909255,'watch','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(909256,'watch','.w-filters .head-filter-widget > span','font-size','18','5240','','.w-filters'),(909257,'watch','.w-filters .head-filter-widget','font-size','21','5245','','.w-filters'),(909258,'watch','.w-delivery-location-top-location-list .deliveryName a','font-size','21','','','.w-delivery-location-top-location-list'),(909259,'watch','.w-filters .filter-box-head','font-size','20','','','.w-filters'),(909260,'watch','.w-filters .view_more','font-size','16','4','','.w-filters'),(909261,'watch','.order-summary .btn-2, .order-summary .btn-3','font-size','15','','','.order-summary'),(909262,'watch','.w-chat .w-chat-box a','font-size','30','5240,3','','.w-chat'),(909263,'watch','.b-products-listing .products-listing .btn-buy','font-size','20','3','','.b-products-listing'),(909264,'watch','.b-bottom .pop-up-close','font-size','25','','','.b-bottom'),(909265,'watch','.w-filters .head-filter-widget','font-size','24','','','.w-filters'),(909266,'watch','.order-summary .price-row.ot_bonus_points .title','font-size','12','3','','.order-summary'),(909267,'watch','.b-form #payment_method .title','font-size','16','','','.b-form'),(909268,'watch','.p-quote-checkout-success .page-success .text-2','font-size','30','5232','','.p-quote-checkout-success'),(909269,'watch','.b-email .heading-model','font-size','14','','','.b-email'),(909270,'watch','.b-email .heading-qty','font-size','14','','','.b-email'),(909271,'watch','.b-page-name .page-name','font-size','20','','','.b-page-name'),(909272,'watch','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(909273,'watch','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(909274,'watch','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(909275,'watch','.heading-3, h3, .h-block h3','font-size','20','','',''),(909276,'watch','.heading-2, h2, .h-block h2','font-size','24','','',''),(909277,'watch','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(909278,'watch','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(909279,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(909280,'watch','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(909281,'watch','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(909282,'watch','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(909283,'watch','.btn-3','font-size','20','','',''),(909284,'watch','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(909285,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','font-size','20','','','.b-switch'),(909286,'watch','.b-page-name .page-name','font-size','20','','','.b-page-name'),(909287,'watch','.b-info .info strong','font-size','18','','','.b-info'),(909288,'watch','.b-form .middle-form label.slim','font-size','14','','','.b-form'),(909289,'watch','.b-email .heading-price','font-size','14','','','.b-email'),(909290,'watch','.b-select-suggest .select2-container .select2-choice abbr','font-size','1','','','.b-select-suggest'),(909291,'watch','.b-email .qty','font-size','14','','','.b-email'),(909292,'watch','.b-email .totals-label','font-size','18','','','.b-email'),(909293,'watch','.w-filters .mobileCollapse','font-size','20','4','','.w-filters'),(909294,'watch','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-size','28','','','.w-filters'),(909295,'watch','.b-product-images .media-popup .mp-close','font-size','50','','','.b-product-images'),(909296,'watch','.b-product-images .media-popup .slick-dots li','font-size','30','','','.b-product-images'),(909297,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','font-size','50','3','','.b-product-images'),(909298,'watch','.w-product-name h1','font-size','26','','','.w-product-name'),(909299,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(909300,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(909301,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(909302,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(909303,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(909304,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(909305,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(909306,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(909307,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(909308,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev63_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(909309,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','font-size','16','','','.b-menu-style-1'),(909310,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','font-size','18','','','.b-menu-style-1'),(909311,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','font-size','14','','','.b-menu-style-2'),(909312,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','font-size','14','','','.b-menu-style-2'),(909313,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','font-size','26','','','.b-menu-style-2'),(909314,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','font-size','20','3','','.b-menu-style-2'),(909315,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-size','20','3','','.b-menu-style-2'),(909316,'watch','.b-trade-approval .middle-form label','font-size','16','','','.b-trade-approval'),(909317,'watch','.w-account-personal-catalog .list-switcher a','font-size','20','','','.w-account-personal-catalog'),(909318,'watch','.w-catalog-compare .checkbox input:checked + span:before','font-size','24','','','.w-catalog-compare'),(909319,'watch','.w-catalog-compare .model','font-size','14','','','.w-catalog-compare'),(909320,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-size','26','3','','.w-catalog-compare'),(909321,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','font-size','0','','','.w-catalog-compare'),(909322,'watch','.w-catalog-compare .item .compare','font-size','0','','','.w-catalog-compare'),(909323,'watch','.w-catalog-compare .cross-box .different-all > div','font-size','15','','','.w-catalog-compare'),(909324,'watch','.w-catalog-compare .name','font-size','12','','','.w-catalog-compare'),(909325,'watch','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-size','40','','','.w-delivery-day'),(909326,'watch','.w-delivery-day .ends','font-size','26','','','.w-delivery-day'),(909327,'watch','.w-delivery-day .left-text-left','font-size','24','','','.w-delivery-day'),(909328,'watch','.w-delivery-day .left-text-right','font-size','24','','','.w-delivery-day'),(909329,'watch','.w-delivery-day .title','font-size','18','','','.w-delivery-day'),(909330,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span:before','font-size','28','','','.w-filters'),(909331,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','font-size','28','','','.w-filters'),(909332,'watch','.order-summary .icon','font-size','18','3','','.order-summary'),(909333,'watch','.order-summary .w-cart-listing .price','font-size','18','','','.order-summary'),(909334,'watch','.w-cart-checkout-btn .with-card','font-size','18','4','','.w-cart-checkout-btn'),(909335,'watch','.w-cart-discount-coupon .title','font-size','24','4','','.w-cart-discount-coupon'),(909336,'watch','.w-cart-discount-coupon .title','font-size','20','','','.w-cart-discount-coupon'),(909337,'watch','.w-cart-listing .item .remove-btn','font-size','18','5232','','.w-cart-listing'),(909370,'watch','.catalog-product-wrap .pn-direction','font-size','14','','','.catalog-product-wrap'),(909371,'watch','.catalog-product-wrap .pn-image','font-size','14','3','','.catalog-product-wrap'),(909372,'watch','.catalog-product-wrap .pn-name','font-size','14','','','.catalog-product-wrap'),(909373,'watch','.catalog-product-wrap .pn-direction','font-size','10','5240','','.catalog-product-wrap'),(909374,'watch','.checkout-index-wrap .comment-ico','font-size','30','3','','.checkout-index-wrap'),(909375,'watch','.checkout-index-wrap .discount-ico','font-size','30','3','','.checkout-index-wrap'),(909376,'watch','.checkout-index-wrap .order-ico','font-size','36','3','','.checkout-index-wrap'),(909377,'watch','.checkout-index-wrap .pay-ico','font-size','30','3','','.checkout-index-wrap'),(909378,'watch','.checkout-index-wrap .ship-ico','font-size','30','3','','.checkout-index-wrap'),(909379,'watch','.checkout-success-wrap .page-success .text-1','font-size','80','3','','.checkout-success-wrap'),(909380,'watch','.checkout-success-wrap .page-success .text-1','font-size','60','','','.checkout-success-wrap'),(909381,'watch','.checkout-success-wrap .page-success .text-2','font-size','34','','','.checkout-success-wrap'),(909382,'watch','.checkout-success-wrap .page-success .text-3','font-size','27','','','.checkout-success-wrap'),(909383,'watch','.checkout-success-wrap .page-success .text-1','font-size','40','5232','','.checkout-success-wrap'),(909384,'watch','.checkout-success-wrap .page-success .text-2','font-size','30','5232','','.checkout-success-wrap'),(909385,'watch','.shopping-cart-index .cart-page .empty','font-size','24','','','.shopping-cart-index'),(909386,'watch','.shopping-cart-index .gift-code .heading-4','font-size','20','5232','','.shopping-cart-index'),(909387,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-size','18','','','.account-order-pay'),(909388,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-size','22','3','','.account-order-pay'),(909389,'watch','.account-order-pay .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-order-pay'),(909390,'watch','.account-order-pay .history_attr','font-size','14','','','.account-order-pay'),(909391,'watch','.account-order-pay .not_fully_paid_td','font-size','30','','','.account-order-pay'),(909392,'watch','.account-samples .not_fully_paid_td','font-size','30','','','.account-samples'),(909393,'watch','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','font-size','16','','','.account-samples'),(909394,'watch','.account-samples .order_history_table h2','font-size','24','','','.account-samples'),(909395,'watch','.account-samples .order_history_table th','font-size','16','','','.account-samples'),(909396,'watch','.account-samples .view_link','font-size','18','4','','.account-samples'),(909397,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-size','18','','','.account-sample-info'),(909398,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-size','22','3','','.account-sample-info'),(909399,'watch','.account-sample-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-sample-info'),(909400,'watch','.account-sample-info .history_attr','font-size','14','','','.account-sample-info'),(909401,'watch','.account-sample-info .not_fully_paid_td','font-size','30','','','.account-sample-info'),(909402,'watch','.account-sample-info .popup-tracking-number-link','font-size','18','','','.account-sample-info'),(909403,'watch','.account-sample-info .trackings-nambers-label','font-size','20','','','.account-sample-info'),(909404,'watch','.checkout-order-confirmation .comment-ico','font-size','30','3','','.checkout-order-confirmation'),(909405,'watch','.checkout-order-confirmation .discount-ico','font-size','30','3','','.checkout-order-confirmation'),(909406,'watch','.checkout-order-confirmation .order-ico','font-size','36','3','','.checkout-order-confirmation'),(909407,'watch','.checkout-order-confirmation .pay-ico','font-size','30','3','','.checkout-order-confirmation'),(909408,'watch','.checkout-order-confirmation .price-box','font-size','16','','','.checkout-order-confirmation'),(909409,'watch','.checkout-order-confirmation .price-box .price','font-size','16','','','.checkout-order-confirmation'),(909410,'watch','.checkout-order-confirmation .price-box .price-row.total','font-size','22','','','.checkout-order-confirmation'),(909411,'watch','.checkout-order-confirmation .prod-ico','font-size','30','3','','.checkout-order-confirmation'),(909412,'watch','.checkout-order-confirmation .ship-ico','font-size','30','3','','.checkout-order-confirmation'),(909413,'watch','.checkout-login-wrap .password-forgotten-link','font-size','14','','','.checkout-login-wrap'),(909415,'watch','.success-page .check-ico-block','font-size','60','3','','.success-page'),(909416,'watch','.success-page .comment-ico','font-size','30','3','','.success-page'),(909417,'watch','.success-page .discount-ico','font-size','30','3','','.success-page'),(909418,'watch','.success-page .order-ico','font-size','36','3','','.success-page'),(909419,'watch','.success-page .order_totals .price','font-size','18','','','.success-page'),(909420,'watch','.success-page .page-success .text-1','font-size','30','','','.success-page'),(909421,'watch','.success-page .page-success .text-1','font-size','36','3','','.success-page'),(909422,'watch','.success-page .page-success .text-1','font-size','40','5232','','.success-page'),(909423,'watch','.success-page .page-success .text-2','font-size','24','','','.success-page'),(909424,'watch','.success-page .page-success .text-2','font-size','30','5232','','.success-page'),(909425,'watch','.success-page .page-success .text-3','font-size','20','','','.success-page'),(909426,'watch','.success-page .pay-ico','font-size','30','3','','.success-page'),(909427,'watch','.success-page .price-box','font-size','16','','','.success-page'),(909428,'watch','.success-page .price-box .price','font-size','16','','','.success-page'),(909429,'watch','.success-page .price-box .price-row.total','font-size','22','','','.success-page'),(909430,'watch','.success-page .price-row.total .price b','font-size','22','','','.success-page'),(909431,'watch','.success-page .prod-ico','font-size','30','3','','.success-page'),(909432,'watch','.success-page .ship-ico','font-size','30','3','','.success-page'),(909433,'watch','.success-page .w-cart-listing .history_attr','font-size','13','','','.success-page'),(909434,'watch','.success-page .w-cart-listing .name a','font-size','14','','','.success-page'),(909435,'watch','.success-page .w-cart-listing .price','font-size','16','','','.success-page'),(909436,'watch','.success-page .w-cart-listing .qty','font-size','14','','','.success-page'),(909437,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-size','24','','','.b-multi-page-checkout'),(909438,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-size','0.7','4','','.b-multi-page-checkout'),(909439,'watch','.w-bestsellers .heading-3','font-size','50','3','','.w-bestsellers'),(909440,'watch','.w-bestsellers .item','font-size','32','3','','.w-bestsellers'),(909441,'watch','.w-menu-style-1 .menu-ico','font-size','23','','','.w-menu-style-1'),(909442,'watch','.w-menu-style-1 > ul','font-size','16','','','.w-menu-style-1'),(909443,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','0','','','.b-slick'),(909444,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','20','3','','.b-slick'),(909445,'watch','.w-catalog-paging .next','font-size','20','3','','.w-catalog-paging'),(909446,'watch','.w-catalog-paging .prev','font-size','20','3','','.w-catalog-paging'),(909448,'watch','.b-rating .glyphicon','font-style','normal','','','.b-rating'),(909449,'watch','.b-switch .candlestick-wrapper .fa-times','font-style','normal','3','','.b-switch'),(909450,'watch','.b-switch .candlestick-wrapper .fa-check','font-style','normal','3','','.b-switch'),(909451,'watch','.b-select-suggest .select2-results li em','font-style','normal','','','.b-select-suggest'),(909452,'watch','.heading-4 .right-text, h4 .right-text','font-weight','400','','',''),(909453,'watch','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(909454,'watch','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(909455,'watch','.w-product-collection .title','font-weight','bold','','','.w-product-collection'),(909456,'watch','.w-product-personal-catalog-button .btn','font-weight','normal','3','','.w-product-personal-catalog-button'),(909457,'watch','.b-info .info strong','font-weight','400','','','.b-info'),(909458,'watch','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(909459,'watch','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(909460,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','font-weight','600','','','.b-switch'),(909461,'watch','.w-multi-cart-cart-switcher .dropdown-menu a','font-weight','bold','','','.w-multi-cart-cart-switcher'),(909462,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(909463,'watch','.p-quick-order-index .filters label','font-weight','700','','','.p-quick-order-index'),(909464,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.p-quick-order-index'),(909465,'watch','.w-promotions .prom-multi-discount .promo-range .value','font-weight','bold','','','.w-promotions'),(909466,'watch','.w-promotions .promo-date','font-weight','500','','','.w-promotions'),(909467,'watch','.w-personal-gift-status-bar .end-label','font-weight','bold','','','.w-personal-gift-status-bar'),(909468,'watch','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(909469,'watch','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(909470,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(909471,'watch','.testimonials .reviews-list span','font-weight','400','','',''),(909472,'watch','.testimonials .rating','font-weight','400','','',''),(909473,'watch','.testimonials .name','font-weight','700','','',''),(909474,'watch','.testimonials .heading-3','font-weight','400','3','',''),(909475,'watch','.testimonials .reviews-list .name','font-weight','700','','',''),(909476,'watch','.w-promotions .prom-multi-discount .heading','font-weight','300','','','.w-promotions'),(909477,'watch','.w-promotions .heading-3','font-weight','bold','','','.w-promotions'),(909478,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.p-quick-order-index'),(909479,'watch','.w-promotions .promo-salemaker .promo-manufacturers .heading','font-weight','300','','','.w-promotions'),(909480,'watch','.w-promotions .promo-salemaker .promo-conditions','font-weight','300','','','.w-promotions'),(909481,'watch','.w-promotions .promo-salemaker .discount .value','font-weight','700','','','.w-promotions'),(909482,'watch','.w-promotions .promo-cart-discount .slave .condition-holder .value','font-weight','bold','','','.w-promotions'),(909483,'watch','.w-promotions .promo-cart-discount .slave .heading','font-weight','300','','','.w-promotions'),(909484,'watch','.w-promotions .promo-cart-discount .promo-min-qty .value','font-weight','bold','','','.w-promotions'),(909485,'watch','.w-promotions .promo-cart-discount .master .heading','font-weight','300','','','.w-promotions'),(909486,'watch','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','font-weight','bold','','','.b-warehouses-popup'),(909487,'watch','.b-warehouses-popup .warehouses-popup .warehouse-name','font-weight','bold','','','.b-warehouses-popup'),(909488,'watch','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','font-weight','bold','','','.b-warehouses-popup'),(909489,'watch','.b-warehouses-popup .warehouses-popup .heading','font-weight','bold','','','.b-warehouses-popup'),(909490,'watch','.b-warehouses-popup a.warehouses-popup-link','font-weight','bold','','','.b-warehouses-popup'),(909491,'watch','.w-product-available-in-warehouses .warehouse-name','font-weight','bold','','','.w-product-available-in-warehouses'),(909492,'watch','.w-checkout-create-account .account-benefits strong','font-weight','normal','','','.w-checkout-create-account'),(909493,'watch','.w-cart-listing .name a','font-weight','bold','','','.w-cart-listing'),(909494,'watch','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(909495,'watch','.b-messages .messBtnMenuDelete','font-weight','normal','3','','.b-messages'),(909496,'watch','.b-messages span.starred::before','font-weight','normal','','','.b-messages'),(909497,'watch','.b-messages .messBtnMenuStarred','font-weight','normal','3','','.b-messages'),(909498,'watch','.b-messages .messMenuButton span','font-weight','600','','','.b-messages'),(909499,'watch','.b-messages .messBtnMenuUnread','font-weight','normal','3','','.b-messages'),(909500,'watch','.b-messages .messages-menu li a','font-weight','bold','2','','.b-messages'),(909501,'watch','.b-messages .content_management_attach','font-weight','600','','','.b-messages'),(909502,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','font-weight','600','','','.b-messages'),(909503,'watch','.w-reviews .author','font-weight','bold','','','.w-reviews'),(909504,'watch','.w-product-collection .together','font-weight','700','','','.w-product-collection'),(909505,'watch','.order-summary .price-box .price-row.total','font-weight','600','','','.order-summary'),(909506,'watch','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(909507,'watch','.w-product-personal-catalog-button .btn','font-weight','700','','','.w-product-personal-catalog-button'),(909508,'watch','.w-product-personal-catalog-button .btn','font-weight','normal','3','','.w-product-personal-catalog-button'),(909509,'watch','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(909510,'watch','.w-product-collection .title','font-weight','bold','','','.w-product-collection'),(909511,'watch','.p-payer-order-confirmation .cardinfo-label','font-weight','bold','','','.p-payer-order-confirmation'),(909512,'watch','.p-payer-order-pay .cardinfo-label','font-weight','bold','','','.p-payer-order-pay'),(909513,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','font-weight','bold','4','','.b-switch'),(909514,'watch','.b-rating .glyphicon','font-weight','400','','','.b-rating'),(909515,'watch','.p-quick-order-index .value','font-weight','bold','','','.p-quick-order-index'),(909516,'watch','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(909517,'watch','.b-table .table .headings td','font-weight','600','','','.b-table'),(909518,'watch','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(909519,'watch','.b-info .info strong','font-weight','400','','','.b-info'),(909520,'watch','.b-form .shipping-method .cost','font-weight','bold','','','.b-form'),(909521,'watch','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-weight','600','','','.p-quick-order-index'),(909522,'watch','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(909523,'watch','.w-delivery-location-top-location-list .deliveryName a','font-weight','bold','','','.w-delivery-location-top-location-list'),(909524,'watch','.btn-1','font-weight','600','','',''),(909525,'watch','.w-cart-listing .item .price','font-weight','bold','','','.w-cart-listing'),(909526,'watch','.w-checkout-totals .ot_code_ot_subtotal','font-weight','bold','','','.w-checkout-totals'),(909527,'watch','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(909528,'watch','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(909529,'watch','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(909530,'watch','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(909531,'watch','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(909532,'watch','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(909533,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(909534,'watch','.b-bottom .popup-heading','font-weight','bold','','','.b-bottom'),(909535,'watch','.b-form .middle-form label.slim','font-weight','400','','','.b-form'),(909536,'watch','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(909537,'watch','.w-checkout-shipping-choice span','font-weight','600','','','.w-checkout-shipping-choice'),(909538,'watch','.btn-3','font-weight','600','','',''),(909539,'watch','.w-reviews-content .author','font-weight','bold','','','.w-reviews-content'),(909540,'watch','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(909541,'watch','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(909542,'watch','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(909543,'watch','.w-cart-compare .js-cart_totals_container b','font-weight','600','','','.w-cart-compare'),(909544,'watch','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(909545,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(909546,'watch','.w-image-maps .default-links .item .title','font-weight','700','','','.w-image-maps'),(909547,'watch','.heading-4 .edit, h4 .edit','font-weight','400','','',''),(909548,'watch','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(909549,'watch','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(909550,'watch','.w-tabs .tab-li.tab-wishlist a','font-weight','normal','3','','.w-tabs'),(909551,'watch','.w-multi-cart-cart-switcher .cart-label','font-weight','600','','','.w-multi-cart-cart-switcher'),(909552,'watch','.w-multi-cart-actions .cart-actions','font-weight','600','','','.w-multi-cart-actions'),(909553,'watch','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(909554,'watch','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(909555,'watch','.w-product-personal-catalog-button .btn','font-weight','700','','','.w-product-personal-catalog-button'),(909556,'watch','.b-form .middle-form label','font-weight','600','','','.b-form'),(909557,'watch','.w-cart-credit-amount .amount-title','font-weight','bold','','','.w-cart-credit-amount'),(909558,'watch','.w-delivery-location-top-location-list .deliveryName a','font-weight','bold','','','.w-delivery-location-top-location-list'),(909559,'watch','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(909560,'watch','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(909561,'watch','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(909562,'watch','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(909563,'watch','.w-personal-gift-status-bar .end-date b','font-weight','bold','','','.w-personal-gift-status-bar'),(909564,'watch','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(909565,'watch','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(909566,'watch','.btn-2','font-weight','600','','',''),(909567,'watch','.heading-5, h5, .h-block h5','font-weight','600','','',''),(909568,'watch','.w-cart-compare .cart-name a','font-weight','600','','','.w-cart-compare'),(909569,'watch','.w-product-reviews .reviews-list span','font-weight','400','','','.w-product-reviews'),(909570,'watch','.b-table .table .headings td','font-weight','600','','','.b-table'),(909571,'watch','.w-delayed-despatch-checkout .heading','font-weight','bold','','','.w-delayed-despatch-checkout'),(909572,'watch','.w-top-categories .categories h2','font-weight','inherit','','','.w-top-categories'),(909573,'watch','.transit','font-weight','700','','',''),(909574,'watch','.out-stock','font-weight','700','','',''),(909575,'watch','.in-stock','font-weight','700','','',''),(909576,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','font-weight','bold','4','','.b-switch'),(909577,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','font-weight','bold','4','','.b-switch'),(909578,'watch','.b-delete-account .delete-box .delete-message','font-weight','normal','','','.b-delete-account'),(909579,'watch','.w-checkout-shipping-address .genders-title > div','font-weight','bold','','','.w-checkout-shipping-address'),(909580,'watch','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(909581,'watch','.w-product-personal-catalog-button .btn','font-weight','700','','','.w-product-personal-catalog-button'),(909582,'watch','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(909583,'watch','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(909584,'watch','.w-checkout-billing-address .btn-cancel','font-weight','500','','','.w-checkout-billing-address'),(909585,'watch','.js-stock','font-weight','700','','',''),(909586,'watch','.b-form #payment_method .title','font-weight','bold','','','.b-form'),(909587,'watch','.b-fancybox .fancybox-title-float-wrap .child','font-weight','bold','','','.b-fancybox'),(909588,'watch','.w-product-personal-catalog-button .btn','font-weight','700','','','.w-product-personal-catalog-button'),(909589,'watch','.w-product-personal-catalog-button .btn','font-weight','normal','3','','.w-product-personal-catalog-button'),(909590,'watch','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(909591,'watch','.w-reviews-content .product-name a','font-weight','bold','','','.w-reviews-content'),(909592,'watch','.w-product-reviews .reviews-list .name','font-weight','700','','','.w-product-reviews'),(909593,'watch','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(909594,'watch','.w-product-collection .title','font-weight','bold','','','.w-product-collection'),(909595,'watch','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(909596,'watch','.w-product-collection .together','font-weight','700','','','.w-product-collection'),(909597,'watch','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(909598,'watch','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(909599,'watch','.b-table .table .headings td','font-weight','600','','','.b-table'),(909600,'watch','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(909601,'watch','.w-tabs .tab-li.tab-cart a','font-weight','normal','3','','.w-tabs'),(909602,'watch','.btn','font-weight','600','','',''),(909603,'watch','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(909604,'watch','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(909605,'watch','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(909606,'watch','.w-personal-gift-status-bar .inform b','font-weight','bold','','','.w-personal-gift-status-bar'),(909607,'watch','.b-table .table .headings td','font-weight','600','','','.b-table'),(909608,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(909609,'watch','.w-reviews .heading-3','font-weight','400','3','','.w-reviews'),(909610,'watch','.w-reviews .product-name a','font-weight','bold','','','.w-reviews'),(909611,'watch','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(909612,'watch','.w-checkout-billing-address .genders-title > div','font-weight','bold','','','.w-checkout-billing-address'),(909613,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','font-weight','600','','','.b-switch'),(909614,'watch','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(909615,'watch','.w-cart-compare .atr-col','font-weight','600','','','.w-cart-compare'),(909616,'watch','.b-info .info strong','font-weight','400','','','.b-info'),(909617,'watch','.w-product-collection .together','font-weight','700','','','.w-product-collection'),(909618,'watch','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(909619,'watch','.w-product-collection .title','font-weight','bold','','','.w-product-collection'),(909620,'watch','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(909621,'watch','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(909622,'watch','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(909623,'watch','.w-product-collection .together','font-weight','700','','','.w-product-collection'),(909624,'watch','.b-bottom .alert-message','font-weight','bold','','','.b-bottom'),(909625,'watch','.w-image-maps .categories-items .item .title','font-weight','700','','','.w-image-maps'),(909626,'watch','.w-neighbour-checkout .text','font-weight','bold','','','.w-neighbour-checkout'),(909627,'watch','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-weight','600','','','.order-summary'),(909628,'watch','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(909629,'watch','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(909630,'watch','.w-product-collection .together','font-weight','700','','','.w-product-collection'),(909631,'watch','.b-info .info strong','font-weight','400','','','.b-info'),(909632,'watch','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(909633,'watch','.w-cart-compare .atr-col','font-weight','normal','3','','.w-cart-compare'),(909634,'watch','.w-tabs .tab-li.tab-quote a','font-weight','normal','3','','.w-tabs'),(909635,'watch','.b-info .info strong','font-weight','400','','','.b-info'),(909636,'watch','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(909637,'watch','.w-product-available-in-warehouses .heading','font-weight','bold','','','.w-product-available-in-warehouses'),(909638,'watch','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(909639,'watch','.w-product-personal-catalog-button .btn','font-weight','normal','3','','.w-product-personal-catalog-button'),(909640,'watch','.p-quick-order-index .dataTables_info','font-weight','500','','','.p-quick-order-index'),(909641,'watch','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(909642,'watch','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(909643,'watch','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(909644,'watch','.w-product-collection .together','font-weight','700','','','.w-product-collection'),(909645,'watch','.w-product-personal-catalog-button .btn','font-weight','normal','3','','.w-product-personal-catalog-button'),(909646,'watch','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(909647,'watch','.w-delayed-despatch-checkout-confirm .heading','font-weight','600','','','.w-delayed-despatch-checkout-confirm'),(909648,'watch','.w-delayed-despatch-checkout-confirm .heading','font-weight','bold','','','.w-delayed-despatch-checkout-confirm'),(909649,'watch','.w-coupons-and-vauchers-checkout .title','font-weight','bold','','','.w-coupons-and-vauchers-checkout'),(909650,'watch','.w-checkout-credit-amount .amount-title','font-weight','bold','','','.w-checkout-credit-amount'),(909651,'watch','.w-product-personal-catalog-button .btn','font-weight','700','','','.w-product-personal-catalog-button'),(909652,'watch','.b-pass-strength .pass-strength span','font-weight','bold','','','.b-pass-strength'),(909653,'watch','.b-table .table .headings td','font-weight','600','','','.b-table'),(909654,'watch','.w-quote .strong','font-weight','400','','','.w-quote'),(909655,'watch','.b-select-suggest .select2-results li.select2-result-with-children > .select2-result-label','font-weight','bold','','','.b-select-suggest'),(909656,'watch','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','font-weight','bold','','','.b-warehouses-popup'),(909657,'watch','.b-table .table .headings td','font-weight','600','','','.b-table'),(909658,'watch','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(909659,'watch','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(909660,'watch','.w-quote-products .empty','font-weight','700','','','.w-quote-products'),(909661,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.b-data-table'),(909662,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.b-data-table'),(909663,'watch','.w-communication-post .communication-post-author-name','font-weight','bold','','','.w-communication-post'),(909664,'watch','.b-products-listing .products-listing .name a','font-weight','bold','','','.b-products-listing'),(909665,'watch','.b-products-listing .products-listing .bonus-points span:first-child','font-weight','bold','','','.b-products-listing'),(909666,'watch','.b-products-listing .products-listing a.btn.view-button','font-weight','bold','','','.b-products-listing'),(909667,'watch','.b-products-listing .products-listing .btn-buy','font-weight','400','3','','.b-products-listing'),(909668,'watch','.b-products-listing .products-listing h2','font-weight','inherit','','','.b-products-listing'),(909669,'watch','.b-products-listing .promos-info .promo-name','font-weight','500','','','.b-products-listing'),(909670,'watch','.b-products-listing .wedding-registry-count','font-weight','bold','','','.b-products-listing'),(909673,'watch','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(909674,'watch','.b-form .form-inputs label > span','font-weight','bold','','','.b-form'),(909675,'watch','.w-product-collection .title','font-weight','bold','','','.w-product-collection'),(909676,'watch','.w-delivery-location-top-location-list .deliveryName a','font-weight','bold','','','.w-delivery-location-top-location-list'),(909677,'watch','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','font-weight','normal','','','.w-taxable'),(909678,'watch','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','font-weight','normal','','','.w-taxable'),(909679,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-weight','inherit','','',''),(909680,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-weight','inherit','','','.b-h-inline'),(909681,'watch','h1, .heading-1','font-weight','400','','',''),(909682,'watch','.w-product-personal-catalog-button .btn','font-weight','700','','','.w-product-personal-catalog-button'),(909683,'watch','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(909684,'watch','.w-tabs .tab-li.tab-sample a','font-weight','normal','3','','.w-tabs'),(909685,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(909686,'watch','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(909687,'watch','.b-form .shipping-method .title','font-weight','bold','','','.b-form'),(909688,'watch','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(909689,'watch','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(909690,'watch','.w-cart-listing .item .gift-wrap label','font-weight','700','','','.w-cart-listing'),(909691,'watch','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-weight','600','','','.w-cart-listing'),(909692,'watch','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-weight','normal','3','','.w-cart-listing'),(909693,'watch','.w-cart-listing .remove-btn span','font-weight','bold','5240','','.w-cart-listing'),(909694,'watch','.w-cart-give-away .ga_price','font-weight','700','','','.w-cart-give-away'),(909699,'watch','.w-image-maps .float-items .item .title','font-weight','700','','','.w-image-maps'),(909700,'watch','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(909701,'watch','.w-product-personal-catalog-button .btn','font-weight','normal','3','','.w-product-personal-catalog-button'),(909702,'watch','.w-product-custom-bundle .title','font-weight','bold','','','.w-product-custom-bundle'),(909703,'watch','.w-product-collection .title','font-weight','bold','','','.w-product-collection'),(909704,'watch','.b-form .address-item .firstname, .b-form .address-item .lastname','font-weight','bold','','','.b-form'),(909707,'watch','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(909708,'watch','.w-checkout-contact-information .contact-info-buttons a','font-weight','500','','','.w-checkout-contact-information'),(909709,'watch','.w-checkout-shipping-address .change-ab','font-weight','500','','','.w-checkout-shipping-address'),(909710,'watch','.w-checkout-billing-address .edit-ab','font-weight','500','','','.w-checkout-billing-address'),(909711,'watch','.w-checkout-billing-address .add-ab','font-weight','500','','','.w-checkout-billing-address'),(909712,'watch','.w-delivery-location-top-location-list .deliveryName a','font-weight','bold','','','.w-delivery-location-top-location-list'),(909713,'watch','.w-filters .view_more','font-weight','400','4','','.w-filters'),(909714,'watch','.w-delivery-location-top-location-list .deliveryName a','font-weight','bold','','','.w-delivery-location-top-location-list'),(909715,'watch','.b-bottom .footerTitle','font-weight','700','','','.b-bottom'),(909716,'watch','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(909717,'watch','.heading-2, h2, .h-block h2','font-weight','400','','',''),(909718,'watch','.b-data-table table.dataTable thead td','font-weight','700','','','.b-data-table'),(909719,'watch','.w-delivery-location-top-location-list .deliveryName a','font-weight','bold','','','.w-delivery-location-top-location-list'),(909720,'watch','.heading-6, h6, .h-block h6','font-weight','600','','',''),(909721,'watch','.b-info .info strong','font-weight','400','','','.b-info'),(909722,'watch','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(909723,'watch','.order-summary .price-row.ot_coupon .title','font-weight','bold','3','','.order-summary'),(909724,'watch','.w-personal-gift-status-bar .start-label','font-weight','bold','','','.w-personal-gift-status-bar'),(909725,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','font-weight','600','','','.b-menu-style-1'),(909726,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','font-weight','600','','','.b-menu-style-1'),(909727,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','font-weight','600','','','.b-menu-style-2'),(909728,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','font-weight','600','','','.b-menu-style-2'),(909729,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-weight','600','','','.b-menu-style-2'),(909730,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','font-weight','300','3','','.b-menu-style-2'),(909731,'watch','.b-personal-catalog-popup #personal_catalog_popup','font-weight','normal','','','.b-personal-catalog-popup'),(909732,'watch','.b-trade-approval .middle-form label','font-weight','600','','','.b-trade-approval'),(909733,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-weight','normal','3','','.w-catalog-compare'),(909734,'watch','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-weight','600','','','.w-delivery-day'),(909735,'watch','.w-delivery-day .ends-date','font-weight','600','','','.w-delivery-day'),(909736,'watch','.w-delivery-day .title','font-weight','bold','','','.w-delivery-day'),(909737,'watch','.w-delivery-day .left-text-left','font-weight','600','','','.w-delivery-day'),(909738,'watch','.w-delivery-day .left-text-right','font-weight','600','','','.w-delivery-day'),(909739,'watch','.w-cart-checkout-btn .with-card','font-weight','400','4','','.w-cart-checkout-btn'),(909740,'watch','.w-cart-discount-coupon .title','font-weight','400','4','','.w-cart-discount-coupon'),(909753,'watch','.catalog-product-wrap .pn-direction','font-weight','600','','','.catalog-product-wrap'),(909754,'watch','.checkout-index-wrap .cardinfo-label','font-weight','bold','','','.checkout-index-wrap'),(909755,'watch','.checkout-index-wrap .edit-address-popup .addresses .buttons a','font-weight','500','','','.checkout-index-wrap'),(909756,'watch','.checkout-index-wrap .edit-address-popup .edit-ab','font-weight','500','','','.checkout-index-wrap'),(909757,'watch','.shopping-cart-index .cart-page .empty','font-weight','700','','','.shopping-cart-index'),(909758,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-weight','normal','3','','.account-order-pay'),(909759,'watch','.account-order-pay .not_fully_paid_td','font-weight','700','','','.account-order-pay'),(909760,'watch','.account-samples .not_fully_paid_td','font-weight','700','','','.account-samples'),(909761,'watch','.account-samples .order_history_table h2','font-weight','normal','','','.account-samples'),(909762,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-weight','normal','3','','.account-sample-info'),(909763,'watch','.account-sample-info .not_fully_paid_td','font-weight','700','','','.account-sample-info'),(909764,'watch','.account-sample-info .popup-tracking-number-link','font-weight','600','','','.account-sample-info'),(909765,'watch','.account-sample-info .trackings-nambers-label','font-weight','600','','','.account-sample-info'),(909766,'watch','.b-bottom .btn-cancel, .b-bottom .add-ab','font-weight','600','','','.b-bottom'),(909767,'watch','.success-page .price-box .price-row.total','font-weight','500','','','.success-page'),(909768,'watch','.success-page .price-row.total .price b','font-weight','500','','','.success-page'),(909769,'watch','.success-page .w-cart-listing .name a','font-weight','500','','','.success-page'),(909770,'watch','.success-page .w-cart-listing .price','font-weight','normal','','','.success-page'),(909771,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-weight','normal','3','','.b-multi-page-checkout'),(909772,'watch','.b-sub-totals .historyTotal table tr.ot_total td','font-weight','bold','','','.b-sub-totals'),(909773,'watch','.w-bestsellers .counter','font-weight','600','','','.w-bestsellers'),(909774,'watch','.w-bestsellers .heading-3','font-weight','400','3','','.w-bestsellers'),(909775,'watch','.w-catalog-paging ','font-weight','700','2','','.w-catalog-paging'),(909777,'watch','.no-found','font_size_measure','em','','',''),(909778,'watch','.w-checkout-create-account .account-benefits','font_size_measure','em','','','.w-checkout-create-account'),(909779,'watch','.view-all .btn','font_size_measure','em','4','',''),(909780,'watch','.price .old','font_size_measure','em','','',''),(909781,'watch','.btn-edit','font_size_measure','em','3','',''),(909782,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font_size_measure','%','','','.b-select-suggest'),(909783,'watch','.b-select-suggest .select2-search input','font_size_measure','em','','','.b-select-suggest'),(909784,'watch','.w-quote .cart-box-link','font_size_measure','em','3','','.w-quote'),(909788,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font_size_measure','em','4','','.b-multi-page-checkout'),(909789,'watch','.w-promotions .prom-multi-discount .list','grid-auto-flow','dense','','','.w-promotions'),(909790,'watch','.w-promotions .prom-multi-discount .promo-group-4','grid-column','span 4','','','.w-promotions'),(909791,'watch','.w-promotions .prom-multi-discount .promo-group-2','grid-column','span 2','','','.w-promotions'),(909792,'watch','.w-promotions .prom-multi-discount .promo-group-3','grid-column','span 3','','','.w-promotions'),(909793,'watch','.w-cart-listing .points','grid-column','2 / 5','5232','','.w-cart-listing'),(909794,'watch','.w-cart-listing .qty','grid-column','1 / 3','5232','','.w-cart-listing'),(909795,'watch','.w-cart-listing .item .gift-wrap','grid-column','3 / 4','5232','','.w-cart-listing'),(909796,'watch','.w-cart-listing .name','grid-column','2 / 4','5232','','.w-cart-listing'),(909797,'watch','.w-cart-listing .price','grid-column','3 / 5','5232','','.w-cart-listing'),(909798,'watch','.w-reviews .author','grid-column','2/4','','','.w-reviews'),(909799,'watch','.w-cart-listing .promos-info','grid-column','1 / 2','5232','','.w-cart-listing'),(909800,'watch','.w-reviews-content .rating','grid-column','2','','','.w-reviews-content'),(909801,'watch','.w-reviews-content .date','grid-column','3','','','.w-reviews-content'),(909802,'watch','.w-reviews-content .review','grid-column','2/4','','','.w-reviews-content'),(909803,'watch','.w-reviews .date','grid-column','3','','','.w-reviews'),(909804,'watch','.w-reviews-content .author','grid-column','2/4','','','.w-reviews-content'),(909805,'watch','.w-reviews .product-name','grid-column','2/4','','','.w-reviews'),(909806,'watch','.w-reviews .product-image','grid-column','1','','','.w-reviews'),(909807,'watch','.w-reviews .rating','grid-column','2','','','.w-reviews'),(909808,'watch','.w-reviews .review','grid-column','2/4','','','.w-reviews'),(909809,'watch','.w-reviews-content .product-image','grid-column','1','','','.w-reviews-content'),(909810,'watch','.w-cart-listing .promos-info','grid-column','2 / 3','','','.w-cart-listing'),(909811,'watch','.w-cart-listing .qty','grid-column','4 / 5','','','.w-cart-listing'),(909812,'watch','.w-cart-listing .price','grid-column','5 / 6','','','.w-cart-listing'),(909813,'watch','.w-cart-listing .name','grid-column','3 / 4','','','.w-cart-listing'),(909814,'watch','.w-cart-listing .image','grid-column','2 / 3','','','.w-cart-listing'),(909815,'watch','.w-cart-listing .points','grid-column','4 / 6','','','.w-cart-listing'),(909816,'watch','.w-cart-listing .item .gift-wrap','grid-column','4 / 6','','','.w-cart-listing'),(909817,'watch','.w-cart-listing .actions','grid-column','3 / 6','','','.w-cart-listing'),(909818,'watch','.w-cart-listing .no-price .qty','grid-column','4 / 6','','','.w-cart-listing'),(909819,'watch','.w-cart-listing .actions','grid-column','1 / 4','5232','','.w-cart-listing'),(909820,'watch','.w-reviews-content .product-name','grid-column','2/4','','','.w-reviews-content'),(909821,'watch','.w-cart-listing .image','grid-column','1 / 2','5232','','.w-cart-listing'),(909822,'watch','.w-cart-listing .remove','grid-column','1 / 2','','','.w-cart-listing'),(909823,'watch','.w-account-personal-catalog div .price','grid-column','4 / 5','','','.w-account-personal-catalog'),(909824,'watch','.order-summary .w-cart-listing .item .name','grid-column','1/2','','','.order-summary'),(909825,'watch','.order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price','grid-column','3/4','','','.order-summary'),(909826,'watch','.order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty','grid-column','2/3','','','.order-summary'),(909827,'watch','.order-summary .w-cart-listing.type-2 .image','grid-column','1 / 3','','','.order-summary'),(909828,'watch','.w-cart-listing .item .remove','grid-column','4 / 4','5232','','.w-cart-listing'),(909829,'watch','.w-cart-listing .no-price .item .name','grid-column','2 / 6','5232','','.w-cart-listing'),(909830,'watch','.p-quote-checkout-index .w-cart-listing .image','grid-column','1 / 1','','','.p-quote-checkout-index'),(909831,'watch','.p-quote-checkout-index .w-cart-listing .name','grid-column','2 / 2','','','.p-quote-checkout-index'),(909832,'watch','.success-page .w-cart-listing .image','grid-column','1','','','.success-page'),(909833,'watch','.success-page .w-cart-listing .name','grid-column','2','','','.success-page'),(909834,'watch','.success-page .w-cart-listing .price','grid-column','3','','','.success-page'),(909835,'watch','.success-page .w-cart-listing .qty','grid-column','1','','','.success-page'),(909836,'watch','.success-page .w-cart-listing .sub-product .image','grid-column','1','','','.success-page'),(909837,'watch','.w-banner .banner-image','grid-column','1','','','.w-banner'),(909838,'watch','.w-banner .banner-text','grid-column','1','','','.w-banner'),(909839,'watch','.w-promotions .content','grid-column-end','3','','','.w-promotions'),(909840,'watch','.w-promotions .heading','grid-column-start','1','','','.w-promotions'),(909841,'watch','.w-promotions .condition','grid-column-start','2','','','.w-promotions'),(909842,'watch','.w-promotions .content','grid-column-start','1','','','.w-promotions'),(909843,'watch','.w-promotions .prom-multi-discount .products','grid-gap','4px','','','.w-promotions'),(909844,'watch','.w-promotions .prom-multi-discount .list','grid-gap','20px','','','.w-promotions'),(909845,'watch','.w-promotions .nextdiscount .content','grid-gap','3px','','','.w-promotions'),(909846,'watch','.w-cart-listing .name','grid-row','1 / 2','5232','','.w-cart-listing'),(909847,'watch','.w-cart-listing .promos-info','grid-row','1 / 5','5232','','.w-cart-listing'),(909848,'watch','.w-cart-listing .qty','grid-row','5 / 6','5232','','.w-cart-listing'),(909849,'watch','.w-cart-listing .price','grid-row','5 / 6','5232','','.w-cart-listing'),(909850,'watch','.w-reviews-content .product-name','grid-row','2','','','.w-reviews-content'),(909851,'watch','.w-reviews-content .date','grid-row','1','','','.w-reviews-content'),(909852,'watch','.w-reviews .author','grid-row','4','','','.w-reviews'),(909853,'watch','.w-reviews .date','grid-row','1','','','.w-reviews'),(909854,'watch','.w-reviews-content .author','grid-row','4','','','.w-reviews-content'),(909855,'watch','.w-reviews-content .review','grid-row','3','','','.w-reviews-content'),(909856,'watch','.w-reviews .product-image','grid-row','1/6','','','.w-reviews'),(909857,'watch','.w-reviews .product-name','grid-row','2','','','.w-reviews'),(909858,'watch','.w-reviews .rating','grid-row','1','','','.w-reviews'),(909859,'watch','.w-reviews .review','grid-row','3','','','.w-reviews'),(909860,'watch','.w-reviews-content .rating','grid-row','1','','','.w-reviews-content'),(909861,'watch','.w-reviews-content .product-image','grid-row','1/6','','','.w-reviews-content'),(909862,'watch','.w-cart-listing .remove','grid-row','1 / 6','','','.w-cart-listing'),(909863,'watch','.w-cart-listing .promos-info','grid-row','1 / 6','','','.w-cart-listing'),(909864,'watch','.w-cart-listing .image','grid-row','1 / 6','','','.w-cart-listing'),(909865,'watch','.w-cart-listing .name','grid-row','1 / 5','','','.w-cart-listing'),(909866,'watch','.w-cart-listing .price','grid-row','1 / 2','','','.w-cart-listing'),(909867,'watch','.w-cart-listing .actions','grid-row','5 / 6','','','.w-cart-listing'),(909868,'watch','.w-cart-listing .qty','grid-row','1 / 2','','','.w-cart-listing'),(909869,'watch','.w-cart-listing .actions','grid-row','6 / 7','5232','','.w-cart-listing'),(909870,'watch','.w-cart-listing .image','grid-row','1 / 1','5232','','.w-cart-listing'),(909871,'watch','.w-account-personal-catalog div .price','grid-row','1 / 2','','','.w-account-personal-catalog'),(909872,'watch','.w-cart-listing .points','grid-row','2 / 3','5232','','.w-cart-listing'),(909873,'watch','.order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price','grid-row','1/2','','','.order-summary'),(909874,'watch','.order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty','grid-row','1/2','','','.order-summary'),(909875,'watch','.w-cart-listing .item .remove','grid-row','1/1','5232','','.w-cart-listing'),(909876,'watch','.w-cart-listing .no-price .item .qty','grid-row','2 / 2','5232','','.w-cart-listing'),(909877,'watch','.w-cart-listing .no-price .item .remove','grid-row','2 / 2','5232','','.w-cart-listing'),(909878,'watch','.p-quote-checkout-index .w-cart-listing .image','grid-row','1 / 3','','','.p-quote-checkout-index'),(909879,'watch','.p-quote-checkout-index .w-cart-listing .name','grid-row','1 / 5','','','.p-quote-checkout-index'),(909880,'watch','.success-page .w-cart-listing .item > div','grid-row','1','','','.success-page'),(909881,'watch','.w-banner .banner-image','grid-row','1','','','.w-banner'),(909882,'watch','.w-banner .banner-item.text-bottom-text .banner-text','grid-row','2','','','.w-banner'),(909883,'watch','.w-banner .banner-text','grid-row','1','','','.w-banner'),(909884,'watch','.w-promotions .content','grid-row-start','2','','','.w-promotions'),(909885,'watch','.w-promotions .condition','grid-row-start','1','','','.w-promotions'),(909886,'watch','.w-promotions .heading','grid-row-start','1','','','.w-promotions'),(909887,'watch','.w-promotions .prom-multi-discount .list','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(909888,'watch','.w-promotions .prom-multi-discount .promo-group-4 .products','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(909889,'watch','.w-promotions .prom-multi-discount .promo-group-3 .products','grid-template-columns','1fr 1fr 1fr','','','.w-promotions'),(909890,'watch','.w-promotions .prom-multi-discount .products','grid-template-columns','1fr','','','.w-promotions'),(909891,'watch','.w-promotions .prom-multi-discount .promo-group-2 .products','grid-template-columns','1fr 1fr','','','.w-promotions'),(909892,'watch','.w-promotions .nextdiscount .content','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(909893,'watch','.w-reviews-content .item','grid-template-columns','170px 1fr 1fr','','','.w-reviews-content'),(909894,'watch','.w-reviews .item','grid-template-columns','140px 1fr 1fr','','','.w-reviews'),(909895,'watch','.w-cart-listing .item','grid-template-columns','50px 80px 1fr 150px 130px','5240','','.w-cart-listing'),(909896,'watch','.w-cart-listing .item','grid-template-columns','50px 120px 1fr 150px 200px','','','.w-cart-listing'),(909897,'watch','.w-cart-listing .item','grid-template-columns','80px 70px 1fr','5232','','.w-cart-listing'),(909898,'watch','.order-summary .w-cart-listing .headings','grid-template-columns','3fr 1fr 1fr','','','.order-summary'),(909899,'watch','.order-summary .w-cart-listing .item','grid-template-columns','3fr 1fr 1fr','','','.order-summary'),(909900,'watch','.w-cart-listing .no-price .item','grid-template-columns','80px 1fr','5232','','.w-cart-listing'),(909901,'watch','.p-quote-checkout-index .w-cart-listing .item','grid-template-columns','100px 1fr 200px','','','.p-quote-checkout-index'),(909902,'watch','.p-quote-checkout-index .w-cart-listing .item','grid-template-columns','100px 1fr 200px','5240','','.p-quote-checkout-index'),(909903,'watch','.success-page .w-cart-listing .item','grid-template-columns','80px 1fr 100px','','','.success-page'),(909904,'watch','.w-cart-listing .item','grid-template-rows','53px 1fr','','','.w-cart-listing'),(909905,'watch','.w-cart-listing .item','grid-template-rows','1fr','5232','','.w-cart-listing'),(909906,'watch','.order-summary .w-cart-listing .item','grid-template-rows','1fr','','','.order-summary'),(909907,'watch','.success-page .w-cart-listing .item','grid-template-rows','1fr','','','.success-page'),(909908,'watch','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','height','28','','','.b-switch'),(909909,'watch','.b-quantity .qty-box .smaller','height','35','','','.b-quantity'),(909910,'watch','.w-product-promotions select','height','29','','','.w-product-promotions'),(909911,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','height','20','3','','.b-switch'),(909912,'watch','.b-email-editor img','height','auto','','','.b-email-editor'),(909913,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.p-quick-order-index'),(909914,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.p-quick-order-index'),(909915,'watch','.w-product-images-additional .item-div','height','80','5261','','.w-product-images-additional'),(909916,'watch','.w-promotions .prom-multi-discount .products','height','calc(100% - 25px)','','','.w-promotions'),(909917,'watch','.w-promotions .prom-multi-discount .image img','height','auto','','','.w-promotions'),(909918,'watch','.w-promotions .promo-salemaker .image img','height','auto','','','.w-promotions'),(909919,'watch','.w-promotions .promo-cart-discount .image img','height','auto','','','.w-promotions'),(909920,'watch','.b-preloader .preloader','height','40','3','','.b-preloader'),(909921,'watch','.b-preloader .preloader','height','100','','','.b-preloader'),(909922,'watch','.b-messages .select2-container-multi input.select2-input','height','31','','','.b-messages'),(909923,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','height','35','','',''),(909924,'watch','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(909925,'watch','.w-product-promotions select','height','29','','','.w-product-promotions'),(909926,'watch','.p-payer-order-confirmation .input-wrapper','height','35','','','.p-payer-order-confirmation'),(909927,'watch','.p-payer-order-pay .input-wrapper','height','35','','','.p-payer-order-pay'),(909928,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','height','15','3','','.b-switch'),(909929,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','height','15','','','.b-switch'),(909930,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','height','15','','','.b-switch'),(909931,'watch','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(909932,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','height','15','','','.b-switch'),(909933,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','height','30','4','','.b-switch'),(909934,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg','height','15','','','.b-switch'),(909935,'watch','.b-quantity .qty-box .bigger','height','35','','','.b-quantity'),(909936,'watch','.b-fancybox #fancybox-loading div','height','44','','','.b-fancybox'),(909937,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','height','60','','','.b-switch'),(909938,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height','100','3','','.b-switch'),(909939,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-toggle','height','40','','','.b-switch'),(909940,'watch','.w-checkout-shipping-choice input:checked + span:before','height','10','','','.w-checkout-shipping-choice'),(909941,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','height','150','','','.w-upload-customer-id-upload-customer-id-form'),(909942,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file','height','100','','','.w-upload-customer-id-upload-customer-id-form'),(909943,'watch','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(909944,'watch','.b-switch .bootstrap-switch','height','28','','','.b-switch'),(909945,'watch','.b-quantity .qty-box .bigger','height','35','','','.b-quantity'),(909946,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','height','10','3','','.b-switch'),(909947,'watch','.b-quantity .qty-box .smaller','height','35','','','.b-quantity'),(909948,'watch','.w-personal-gift-status-bar .progress-bar','height','8','','','.w-personal-gift-status-bar'),(909949,'watch','.w-filters .input-checkbox:checked + .checkbox-span','height','24','','','.w-filters'),(909950,'watch','.b-info-popup .info-popup div','height','20','3','','.b-info-popup'),(909951,'watch','.b-quantity .qty-box .smaller','height','35','','','.b-quantity'),(909952,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','height','10','','','.b-switch'),(909953,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','height','10','','','.b-switch'),(909954,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','height','15','4','','.b-switch'),(909955,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-toggle','height','15','','','.b-switch'),(909956,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg','height','10','','','.b-switch'),(909957,'watch','.b-form .hide-billing-address','height','100','','','.b-form'),(909958,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','height','16','3','','.b-switch'),(909959,'watch','.b-select-suggest .select2-container .select2-choice abbr','height','12','','','.b-select-suggest'),(909960,'watch','.w-filters .ui-slider-handle','height','18','','','.w-filters'),(909962,'watch','.w-filters .ui-slider','height','7','','','.w-filters'),(909963,'watch','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(909964,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','height','16','','','.b-switch'),(909965,'watch','.b-switch .candlestick-wrapper','height','auto','','','.b-switch'),(909966,'watch','.b-switch .candlestick-wrapper .candlestick-bg','height','28','','','.b-switch'),(909967,'watch','.b-quantity .qty-box .smaller','height','35','','','.b-quantity'),(909968,'watch','.w-product-images-additional .item','height','80','5261','','.w-product-images-additional'),(909969,'watch','.b-bottom .cart-options .cart-item input[type=\"text\"]','height','25','','','.b-bottom'),(909970,'watch','.b-select-suggest .select2-measure-scrollbar','height','100','','','.b-select-suggest'),(909971,'watch','.b-form .radio-button input[type=\"radio\"].no + span','height','30','3','','.b-form'),(909972,'watch','.b-fancybox .fancybox-close','height','40','','','.b-fancybox'),(909973,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height','1','','','.b-select-suggest'),(909974,'watch','.w-product-images-additional .item','height','80','5261','','.w-product-images-additional'),(909975,'watch','.w-product-images-additional .item-div','height','80','5261','','.w-product-images-additional'),(909976,'watch','.b-quantity .qty-box .smaller','height','35','','','.b-quantity'),(909977,'watch','.b-quantity .qty-box .bigger','height','35','','','.b-quantity'),(909978,'watch','.w-product-images-additional .item-div','height','80','5261','','.w-product-images-additional'),(909979,'watch','.b-email-editor img','height','auto','','','.b-email-editor'),(909981,'watch','.w-product-images-additional .item-div','height','80','5261','','.w-product-images-additional'),(909982,'watch','.b-quantity .qty-box input','height','35','','','.b-quantity'),(909983,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','height','20','','','.b-switch'),(909984,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span','height','18','','','.b-form'),(909985,'watch','.w-product-promotions select','height','29','','','.w-product-promotions'),(909986,'watch','.w-product-promotions select','height','29','','','.w-product-promotions'),(909987,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height','60','','','.b-switch'),(909988,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','height','56','','','.b-switch'),(909989,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height','100','4','','.b-switch'),(909990,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','','','.b-switch'),(909991,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height','60','','','.b-switch'),(909992,'watch','.b-email-editor img','height','auto','','','.b-email-editor'),(909993,'watch','.b-quantity .qty-box .smaller','height','35','','','.b-quantity'),(909994,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','height','100','','','.b-switch'),(909995,'watch','.b-switch .candlestick-wrapper.candlestick-contents','height','56','','','.b-switch'),(909996,'watch','.w-product-promotions select','height','29','','','.w-product-promotions'),(909997,'watch','.b-fancybox .fancybox-nav','height','100','','','.b-fancybox'),(909998,'watch','.b-quantity .qty-box .bigger','height','35','','','.b-quantity'),(909999,'watch','.b-select-suggest .select2-container .select2-choice','height','35','','','.b-select-suggest'),(910000,'watch','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(910001,'watch','.w-personal-gift-status-bar .progress-bar-content','height','8','','','.w-personal-gift-status-bar'),(910002,'watch','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(910003,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','height','20','3','','.b-switch'),(910004,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','4','','.b-switch'),(910005,'watch','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(910006,'watch','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(910007,'watch','.b-quantity .qty-box input','height','35','','','.b-quantity'),(910008,'watch','.b-email-editor img','height','auto','','','.b-email-editor'),(910009,'watch','.w-product-images-additional .item-div','height','80','5261','','.w-product-images-additional'),(910010,'watch','.b-autocomplete .ui-autocomplete','height','300','','','.b-autocomplete'),(910011,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','','','.b-switch'),(910012,'watch','.b-quantity .qty-box .bigger','height','35','','','.b-quantity'),(910013,'watch','.b-form .checkbox-style:checked + .checkbox-span','height','18','','','.b-form'),(910014,'watch','.b-info-popup .info-popup','height','2','','','.b-info-popup'),(910015,'watch','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(910016,'watch','.b-quantity .qty-box input','height','35','','','.b-quantity'),(910017,'watch','.w-product-customers-activity .close','height','30','','','.w-product-customers-activity'),(910018,'watch','.b-email-editor img','height','auto','','','.b-email-editor'),(910019,'watch','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(910020,'watch','.w-menu-horizontal .menu-ico','height','54','','','.w-menu-horizontal'),(910021,'watch','.w-product-images-additional .item','height','80','5261','','.w-product-images-additional'),(910022,'watch','.w-product-images-additional .item-div','height','80','5261','','.w-product-images-additional'),(910023,'watch','.w-product-images-additional .item','height','80','5261','','.w-product-images-additional'),(910024,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','height','16','','','.b-switch'),(910025,'watch','.b-select-suggest .select2-search-choice-close','height','13','','','.b-select-suggest'),(910026,'watch','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','height','25','','','.b-datepicker'),(910027,'watch','.b-select-suggest .select2-search input','height','auto','','','.b-select-suggest'),(910028,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height','100','','','.b-select-suggest'),(910029,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow','height','100','','','.b-select-suggest'),(910030,'watch','.b-select-suggest .select2-drop-mask','height','auto','','','.b-select-suggest'),(910031,'watch','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(910032,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.b-data-table'),(910033,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.b-data-table'),(910034,'watch','.b-products-listing .btn-preloader','height','24','3','','.b-products-listing'),(910035,'watch','.b-products-listing .hover-box-content','height','20','3','','.b-products-listing'),(910036,'watch','.b-products-listing .loader','height','30','4','','.b-products-listing'),(910037,'watch','.b-products-listing .loader','height','100','3','','.b-products-listing'),(910038,'watch','.b-products-listing .products-listing .qty-input.hidden','height','100','3','','.b-products-listing'),(910039,'watch','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','height','auto','','','.b-products-listing'),(910040,'watch','.checkbox input + span','height','24','','',''),(910041,'watch','.checkbox input:not(checked) + span:before','height','22','','',''),(910042,'watch','.b-quantity .qty-box input','height','35','','','.b-quantity'),(910043,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','height','20','3','','.b-switch'),(910044,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','height','10','4','','.b-switch'),(910045,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-toggle','height','10','','','.b-switch'),(910046,'watch','.b-email-editor img','height','auto','','','.b-email-editor'),(910047,'watch','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height','100','','','.b-fancybox'),(910048,'watch','.w-product-promotions select','height','29','','','.w-product-promotions'),(910049,'watch','.b-quantity .qty-box .bigger','height','35','','','.b-quantity'),(910050,'watch','.b-quantity .qty-box input','height','35','','','.b-quantity'),(910051,'watch','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(910052,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','height','36','','','.w-communication-new-topic'),(910053,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','height','36','','','.w-communication-new-topic'),(910054,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','height','30','','','.w-communication-new-topic'),(910055,'watch','.w-communication-new-topic #communication_group_holder select','height','35','','','.w-communication-new-topic'),(910056,'watch','.w-catalog-listing-look .grid','height','31','','','.w-catalog-listing-look'),(910057,'watch','.w-catalog-listing-look .b2b','height','31','','','.w-catalog-listing-look'),(910058,'watch','.w-catalog-listing-look .list','height','31','','','.w-catalog-listing-look'),(910059,'watch','.w-cart-listing .remove-btn','height','30','','','.w-cart-listing'),(910060,'watch','.w-cart-listing .item .remove','height','45','5240','','.w-cart-listing'),(910061,'watch','.b-upload-file .snapshot','height','38','','','.b-upload-file'),(910062,'watch','.w-image-maps .svg-wrap svg','height','100','','','.w-image-maps'),(910063,'watch','.b-fancybox .fancybox-nav span','height','40','','','.b-fancybox'),(910064,'watch','.b-upload-file .upload-file-template','height','150','','','.b-upload-file'),(910065,'watch','.w-filters .ui-slider-range','height','6','','','.w-filters'),(910066,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','height','10','','','.b-switch'),(910067,'watch','.b-bottom .pop-up-close','height','31','','','.b-bottom'),(910068,'watch','.w-product-images-additional .item','height','80','5261','','.w-product-images-additional'),(910069,'watch','.w-product-images-additional .item','height','80','5261','','.w-product-images-additional'),(910070,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg','height','30','','','.b-switch'),(910071,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','height','30','','','.b-switch'),(910072,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','height','30','','','.b-switch'),(910073,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','height','30','3','','.b-switch'),(910074,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','height','30','','','.b-switch'),(910075,'watch','.b-quantity .qty-box input','height','35','','','.b-quantity'),(910076,'watch','.w-filters .input-checkbox:not(checked) + .checkbox-span','height','24','','','.w-filters'),(910077,'watch','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','height','auto','','','.b-product-images'),(910078,'watch','.b-product-images .media-popup .mp-big-images','height','calc(100vh - 150px)','','','.b-product-images'),(910079,'watch','.b-product-images .media-popup .mp-big-images .item','height','calc(100vh - 150px)','','','.b-product-images'),(910080,'watch','.b-product-images .media-popup .mp-close','height','100','','','.b-product-images'),(910081,'watch','.b-product-images .media-popup .mp-content','height','100','','','.b-product-images'),(910082,'watch','.b-product-images .media-popup .mp-small-images','height','100','','','.b-product-images'),(910083,'watch','.b-product-images .media-popup .mp-small-images .item','height','100','','','.b-product-images'),(910084,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','height','100','','','.b-product-images'),(910085,'watch','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','height','30','','','.b-menu-burger_icon'),(910086,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(910087,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(910088,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(910089,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(910090,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(910091,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height','100','','','.b-menu-open_from-left'),(910092,'watch','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(910093,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','height','28','','','.b-menu-style-2'),(910094,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','height','50','','','.b-menu-style-2'),(910095,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','height','24','','','.b-menu-style-2'),(910096,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','height','16','3','','.b-menu-style-2'),(910097,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','height','28','','','.b-menu-style-2'),(910098,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','height','16','3','','.b-menu-style-2'),(910099,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','height','24','','','.b-menu-style-2'),(910100,'watch','.w-account-subscription .info-popup','height','15','','','.w-account-subscription'),(910101,'watch','.w-catalog-compare span.btn-preloader','height','24','','','.w-catalog-compare'),(910102,'watch','.w-product-images .produst-image video, .w-product-images .produst-image iframe','height','100','','','.w-product-images'),(910103,'watch','.w-product-images .additional-vertical .additional-images','height','300','','','.w-product-images'),(910104,'watch','.w-product-images .additional-horizontal .item','height','100','','','.w-product-images'),(910105,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','height','24','','','.w-filters'),(910106,'watch','.order-summary .icon','height','30','','','.order-summary'),(910113,'watch','.catalog-product-wrap .pn-image','height','24','3','','.catalog-product-wrap'),(910114,'watch','.checkout-index-wrap .input-wrapper','height','35','','','.checkout-index-wrap'),(910115,'watch','.account-samples .orders-table .td-alignright','height','45','5240','','.account-samples'),(910116,'watch','.b-slick .slick-dots li','height','10','3','','.b-slick'),(910117,'watch','.fake-input','height','0','','',''),(910118,'watch','.hide-page','height','100','','',''),(910119,'watch','.success-page .w-cart-listing .qty','height','24','','','.success-page'),(910120,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-content','height','auto','','','.b-multi-page-checkout'),(910121,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','height','33','','','.b-multi-page-checkout'),(910122,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','height','35','3','','.b-multi-page-checkout'),(910123,'watch','.w-bestsellers .counter','height','32','','','.w-bestsellers'),(910124,'watch','.w-bestsellers .item','height','32','3','','.w-bestsellers'),(910125,'watch','.w-menu-style-1 .menu-ico','height','54','','','.w-menu-style-1'),(910126,'watch','.b-slick .slick-slide','height','100','','','.b-slick'),(910127,'watch','.b-slick .slick-vertical .slick-slide','height','auto','','','.b-slick'),(910128,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','height','40','','','.b-slick'),(910129,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','height','50','5240','','.b-slick'),(910130,'watch','.w-banner .carousel-text','height','100','','','.w-banner'),(910131,'watch','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height','100','','','.w-banner'),(910132,'watch','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height','100','','','.w-banner'),(910133,'watch','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height','100','','','.w-banner'),(910134,'watch','.w-catalog-paging ','height','30','2','','.w-catalog-paging'),(910135,'watch','.w-catalog-paging .next','height','30','','','.w-catalog-paging'),(910136,'watch','.w-catalog-paging .next-pages','height','30','','','.w-catalog-paging'),(910137,'watch','.w-catalog-paging .page-number','height','30','','','.w-catalog-paging'),(910138,'watch','.w-catalog-paging .paging-holder','height','30','','','.w-catalog-paging'),(910139,'watch','.w-catalog-paging .prev','height','30','','','.w-catalog-paging'),(910140,'watch','.w-catalog-paging .prev-pages','height','30','','','.w-catalog-paging'),(910141,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height','30','','','.w-catalog-paging'),(910142,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height_important','important','','','.b-select-suggest'),(910143,'watch','.b-select-suggest .select2-search input','height_important','important','','','.b-select-suggest'),(910144,'watch','.w-product-images .produst-image video, .w-product-images .produst-image iframe','height_important','important','','','.w-product-images'),(910145,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-content','height_important','important','','','.b-multi-page-checkout'),(910146,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height_important','important','','','.w-catalog-paging'),(910147,'watch','.b-preloader .preloader','height_measure','%','','','.b-preloader'),(910148,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height_measure','%','3','','.b-switch'),(910149,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file','height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(910150,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height_measure','%','4','','.b-switch'),(910151,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','height_measure','%','','','.b-switch'),(910152,'watch','.b-fancybox .fancybox-nav','height_measure','%','','','.b-fancybox'),(910153,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height_measure','%','','','.b-select-suggest'),(910154,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow','height_measure','%','','','.b-select-suggest'),(910155,'watch','.b-products-listing .loader','height_measure','%','3','','.b-products-listing'),(910156,'watch','.b-products-listing .products-listing .qty-input.hidden','height_measure','%','3','','.b-products-listing'),(910157,'watch','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height_measure','%','','','.b-fancybox'),(910158,'watch','.b-form .hide-billing-address','height_measure','%','','','.b-form'),(910159,'watch','.w-image-maps .svg-wrap svg','height_measure','%','','','.w-image-maps'),(910160,'watch','.b-product-images .media-popup .mp-content','height_measure','vh','','','.b-product-images'),(910161,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height_measure','vh','','','.b-menu-open_from-left'),(910162,'watch','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(910163,'watch','.w-product-images .produst-image video, .w-product-images .produst-image iframe','height_measure','%','','','.w-product-images'),(910165,'watch','.hide-page','height_measure','%','','',''),(910166,'watch','.b-slick .slick-slide','height_measure','%','','','.b-slick'),(910167,'watch','.w-banner .carousel-text','height_measure','%','','','.w-banner'),(910168,'watch','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height_measure','%','','','.w-banner'),(910169,'watch','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height_measure','%','','','.w-banner'),(910170,'watch','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height_measure','%','','','.w-banner'),(910171,'watch','.w-product-images .produst-image video, .w-product-images .produst-image iframe','height_measure_important','important','','','.w-product-images'),(910172,'watch','.w-promotions .promo-cart-discount .content','justify-content','center','','','.w-promotions'),(910173,'watch','.w-promotions .prom-multi-discount .products','justify-content','space-between','','','.w-promotions'),(910174,'watch','.w-promotions .promo-salemaker .content','justify-content','center','','','.w-promotions'),(910175,'watch','.b-products-listing .products-listing .attribute-qty-blocks','justify-content','space-between','','','.b-products-listing'),(910176,'watch','.p-quick-order-index .quick-order-total','justify-content','space-between','','','.p-quick-order-index'),(910177,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(910178,'watch','.w-personal-gift-status-bar .timeline','justify-content','center','','','.w-personal-gift-status-bar'),(910179,'watch','.w-checkout-shipping-choice span','justify-content','center','','','.w-checkout-shipping-choice'),(910180,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(910181,'watch','.order-summary .price-row','justify-content','space-between','','','.order-summary'),(910182,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(910183,'watch','.w-communication-post .communication-post-author','justify-content','space-between','','','.w-communication-post'),(910184,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(910185,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(910186,'watch','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(910187,'watch','.b-product-images .media-popup .mp-big-images .item','justify-content','center','','','.b-product-images'),(910188,'watch','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(910189,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','justify-content','space-between','','','.b-menu-style-1'),(910190,'watch','.w-catalog-compare .cross-box','justify-content','flex-end','','','.w-catalog-compare'),(910191,'watch','.w-product-images .img-holder','justify-content','center','','','.w-product-images'),(910192,'watch','.checkout-index-wrap .edit-address-popup .addresses .buttons','justify-content','space-between','','','.checkout-index-wrap'),(910193,'watch','.checkout-order-confirmation .price-row','justify-content','space-between','','','.checkout-order-confirmation'),(910194,'watch','.b-form .columns','justify-content','space-between','','','.b-form'),(910195,'watch','.b-slick .slick-dots','justify-content','center','','','.b-slick'),(910196,'watch','.hide-page','justify-content','center','','',''),(910197,'watch','.success-page .order_totals .price-row','justify-content','space-between','','','.success-page'),(910198,'watch','.success-page .price-row','justify-content','space-between','','','.success-page'),(910199,'watch','.w-checkout-totals .price-row','justify-content','space-between','','','.w-checkout-totals'),(910200,'watch','.b-form .formWrapBox','justify-content','space-between','','','.b-form'),(910202,'watch','.w-banner .banner-item.text-bottom-center .banner-text','justify-content','center','','','.w-banner'),(910203,'watch','.w-banner .banner-item.text-bottom-left .banner-text','justify-content','start','','','.w-banner'),(910204,'watch','.w-banner .banner-item.text-bottom-right .banner-text','justify-content','end','','','.w-banner'),(910205,'watch','.w-banner .banner-item.text-middle-center .banner-text','justify-content','center','','','.w-banner'),(910206,'watch','.w-banner .banner-item.text-middle-left .banner-text','justify-content','start','','','.w-banner'),(910207,'watch','.w-banner .banner-item.text-middle-right .banner-text','justify-content','end','','','.w-banner'),(910208,'watch','.w-banner .banner-item.text-top-center .banner-text','justify-content','center','','','.w-banner'),(910209,'watch','.w-banner .banner-item.text-top-left .banner-text','justify-content','start','','','.w-banner'),(910210,'watch','.w-banner .banner-item.text-top-right .banner-text','justify-content','end','','','.w-banner'),(910211,'watch','.w-banner .carousel .bottom-center','justify-content','center','','','.w-banner'),(910212,'watch','.w-banner .carousel .bottom-left','justify-content','flex-start','','','.w-banner'),(910213,'watch','.w-banner .carousel .bottom-right','justify-content','flex-end','','','.w-banner'),(910214,'watch','.w-banner .carousel .middle-center','justify-content','center','','','.w-banner'),(910215,'watch','.w-banner .carousel .middle-left','justify-content','flex-start','','','.w-banner'),(910216,'watch','.w-banner .carousel .middle-right','justify-content','flex-end','','','.w-banner'),(910217,'watch','.w-banner .carousel .top-center','justify-content','center','','','.w-banner'),(910218,'watch','.w-banner .carousel .top-left','justify-content','flex-start','','','.w-banner'),(910219,'watch','.w-banner .carousel .top-right','justify-content','flex-end','','','.w-banner'),(910220,'watch','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(910221,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','left','2','3','','.b-switch'),(910222,'watch','.w-promo-code .holder','left','12','5261,3','','.w-promo-code'),(910223,'watch','.p-quick-order-index .all-scroll-div','left','0','','','.p-quick-order-index'),(910224,'watch','.w-promo-code .holder','left','20','3','','.w-promo-code'),(910225,'watch','.testimonials .heading-3','left','0','3','',''),(910226,'watch','.testimonials .review','left','10','3','',''),(910227,'watch','.b-preloader .preloader','left','calc(50% - 20px)','3','','.b-preloader'),(910228,'watch','.b-preloader .preloader','left','0','','','.b-preloader'),(910229,'watch','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(910230,'watch','.w-checkout-terms .required-message','left','0','','','.w-checkout-terms'),(910231,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','left','15','','','.b-switch'),(910232,'watch','.b-fancybox #fancybox-loading','left','50','','','.b-fancybox'),(910233,'watch','.b-fancybox .fancybox-wrap','left','0','','','.b-fancybox'),(910234,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','left','100','','','.b-switch'),(910235,'watch','.w-promo-code .holder','left','20','3','','.w-promo-code'),(910236,'watch','.w-checkout-shipping-choice input:checked + span:before','left','50','','','.w-checkout-shipping-choice'),(910237,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(910238,'watch','.w-upload-customer-id-upload-customer-id-form .dz-details','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(910239,'watch','.b-info-popup .info-popup div','left','-11','3','','.b-info-popup'),(910240,'watch','.b-fancybox .fancybox-title-over-wrap','left','0','','','.b-fancybox'),(910241,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','left','10','','','.b-switch'),(910242,'watch','.w-product-personal-catalog-button .btn','left','0','3','','.w-product-personal-catalog-button'),(910243,'watch','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(910244,'watch','.w-product-personal-catalog-button .btn','left','0','3','','.w-product-personal-catalog-button'),(910245,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','left','20','','','.b-switch'),(910246,'watch','.w-cart-compare .dropdown .dropdown-menu','left','auto','','','.w-cart-compare'),(910247,'watch','.b-select-suggest .select2-measure-scrollbar','left','-10000','','','.b-select-suggest'),(910248,'watch','.b-fancybox .fancybox-tmp','left','-99999','','','.b-fancybox'),(910250,'watch','.b-info-popup .info-popup.top-left div','left','auto','','','.b-info-popup'),(910251,'watch','.b-info-popup .info-popup.top-left div','left','auto','3','','.b-info-popup'),(910252,'watch','.w-promo-code .holder','left','12','5261,3','','.w-promo-code'),(910253,'watch','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(910254,'watch','.w-promo-code .holder','left','20','3','','.w-promo-code'),(910255,'watch','.view-all','left','0','3','',''),(910257,'watch','.b-fancybox .fancybox-overlay','left','0','','','.b-fancybox'),(910259,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left','25','','','.b-switch'),(910260,'watch','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(910261,'watch','.w-multi-cart-actions .dropdown .dropdown-menu','left','auto','','','.w-multi-cart-actions'),(910262,'watch','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','left','0','','','.b-switch'),(910264,'watch','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(910265,'watch','.b-select-suggest .select2-drop-mask','left','0','','','.b-select-suggest'),(910266,'watch','.w-reviews .review','left','15','3','','.w-reviews'),(910268,'watch','.w-product-personal-catalog-button .btn','left','0','3','','.w-product-personal-catalog-button'),(910269,'watch','.b-fancybox .fancybox-prev','left','0','','','.b-fancybox'),(910270,'watch','.b-fancybox .fancybox-prev span','left','10','','','.b-fancybox'),(910272,'watch','.w-promo-code .holder','left','12','5261,3','','.w-promo-code'),(910273,'watch','.w-promo-code .holder','left','20','3','','.w-promo-code'),(910274,'watch','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(910275,'watch','.w-reviews .heading-3','left','0','3','','.w-reviews'),(910276,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','left','2','3','','.b-switch'),(910277,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left','4','3','','.b-switch'),(910278,'watch','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(910279,'watch','.w-reviews-content .review','left','15','3','','.w-reviews-content'),(910280,'watch','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(910281,'watch','.w-promo-code .holder','left','12','5261,3','','.w-promo-code'),(910282,'watch','.b-form .radio-button input[type=\"radio\"].no','left','-100','','','.b-form'),(910284,'watch','.w-product-personal-catalog-button .btn','left','0','3','','.w-product-personal-catalog-button'),(910285,'watch','.w-checkout-billing-address .addresses .address-item label input','left','0','','','.w-checkout-billing-address'),(910286,'watch','.w-promo-code .holder','left','12','5261,3','','.w-promo-code'),(910287,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','left','0','','','.b-switch'),(910288,'watch','.b-select-suggest .select2-container-multi .select2-search-choice-close','left','3','','','.b-select-suggest'),(910289,'watch','.w-menu-horizontal > ul > li > ul','left','0','','','.w-menu-horizontal'),(910290,'watch','.w-checkout-shipping-address .addresses .address-item label input','left','0','','','.w-checkout-shipping-address'),(910292,'watch','.w-image-maps .svg-wrap svg','left','0','','','.w-image-maps'),(910293,'watch','.w-product-personal-catalog-button .btn','left','0','3','','.w-product-personal-catalog-button'),(910294,'watch','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(910295,'watch','.b-products-listing .products-listing .promos-info','left','0','','','.b-products-listing'),(910296,'watch','.b-products-listing .hover-box-content','left','0','','','.b-products-listing'),(910297,'watch','.b-products-listing .hover-box-content','left','20','3','','.b-products-listing'),(910298,'watch','.b-products-listing .loader','left','calc(50% - 15px)','4','','.b-products-listing'),(910299,'watch','.b-products-listing .loader','left','0','3','','.b-products-listing'),(910300,'watch','.w-catalog-b2b-add-button ','left','0','','','.w-catalog-b2b-add-button'),(910301,'watch','.b-products-listing .products-listing .qty-input.hidden','left','0','3','','.b-products-listing'),(910302,'watch','.b-products-listing .promo','left','0','','','.b-products-listing'),(910303,'watch','.checkbox input','left','-20','','',''),(910305,'watch','.w-product-personal-catalog-button .btn','left','0','3','','.w-product-personal-catalog-button'),(910306,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left','0','','','.b-select-suggest'),(910307,'watch','.w-promo-code .holder','left','20','3','','.w-promo-code'),(910308,'watch','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(910309,'watch','.w-promo-code .holder','left','20','3','','.w-promo-code'),(910310,'watch','.w-promo-code .holder','left','12','5261,3','','.w-promo-code'),(910311,'watch','.w-cart-listing .item .remove','left','0','5240','','.w-cart-listing'),(910312,'watch','.w-cart-listing .remove-btn','left','10','5240','','.w-cart-listing'),(910313,'watch','.w-cart-listing .remove-btn span','left','5','5240','','.w-cart-listing'),(910315,'watch','.b-info-popup .info-popup div','left','40','','','.b-info-popup'),(910316,'watch','.w-product-reviews .reviews-list .review','left','10','3','','.w-product-reviews'),(910317,'watch','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(910318,'watch','.b-form .hide-billing-address','left','0','','','.b-form'),(910319,'watch','.w-menu-big > ul > li > ul','left','0','','','.w-menu-big'),(910320,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','left','40','','','.b-switch'),(910321,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','left','0','','','.w-image-maps'),(910322,'watch','.b-product-images .mp-shadow, .b-product-images .media-popup','left','0','','','.b-product-images'),(910323,'watch','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','left','0','','','.b-menu-lev_display-down'),(910324,'watch','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','left','0','','','.b-menu-lev_display-down'),(910325,'watch','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','left','0','','','.b-menu-lev_display-down'),(910326,'watch','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','left','0','','','.b-menu-lev_display-down'),(910327,'watch','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','left','0','','','.b-menu-lev_display-down'),(910328,'watch','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left','100','','','.b-menu-lev_display-lra'),(910329,'watch','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left','100','','','.b-menu-lev_display-lra'),(910330,'watch','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left','100','','','.b-menu-lev_display-lra'),(910331,'watch','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left','100','','','.b-menu-lev_display-lra'),(910332,'watch','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left','100','','','.b-menu-lev_display-lra'),(910333,'watch','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','left','auto','','','.b-menu-lev_display-lra'),(910334,'watch','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','left','auto','','','.b-menu-lev_display-lra'),(910335,'watch','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','left','auto','','','.b-menu-lev_display-lra'),(910336,'watch','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','left','auto','','','.b-menu-lev_display-lra'),(910337,'watch','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','left','auto','','','.b-menu-lev_display-lra'),(910338,'watch','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left','100','','','.b-menu-lev_display-right'),(910339,'watch','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left','100','','','.b-menu-lev_display-right'),(910340,'watch','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left','100','','','.b-menu-lev_display-right'),(910341,'watch','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left','100','','','.b-menu-lev_display-right'),(910342,'watch','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left','100','','','.b-menu-lev_display-right'),(910343,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left','100','','','.b-menu-lev_display-slide'),(910344,'watch','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left','100','','','.b-menu-lev_display-slide'),(910345,'watch','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left','100','','','.b-menu-lev_display-slide'),(910346,'watch','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left','100','','','.b-menu-lev_display-slide'),(910347,'watch','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left','100','','','.b-menu-lev_display-slide'),(910348,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left','-110','','','.b-menu-open_from-left'),(910349,'watch','.b-menu-open_from-left .bi-opened .menu-style[data-open_from=\"left\"] .menu-content','left','0','','','.b-menu-open_from-left'),(910350,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','left','0','','','.b-menu-style-1'),(910351,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','left','0','','','.b-menu-style-2'),(910352,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','left','0','','','.b-menu-style-2'),(910353,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','left','20','3','','.b-menu-style-2'),(910367,'watch','.catalog-product-wrap .prev-product','left','0','','','.catalog-product-wrap'),(910368,'watch','.catalog-product-wrap .prev-product .pn-image','left','20','3','','.catalog-product-wrap'),(910369,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','left','1','3','','.account-order-pay'),(910370,'watch','.account-order-pay .historyInfoColumn h2.title-delivery-address, .account-order-pay .historyInfoColumn h2.title-billing-address','left','10','3','','.account-order-pay'),(910371,'watch','.account-order-pay .historyInfoColumn h2.title-payment','left','10','3','','.account-order-pay'),(910372,'watch','.account-order-pay .not_fully_paid_td','left','15','','','.account-order-pay'),(910373,'watch','.account-samples .not_fully_paid_td','left','15','','','.account-samples'),(910374,'watch','.account-samples .orders-table .status-name','left','0','5240','','.account-samples'),(910375,'watch','.account-samples .orders-table .td-alignright','left','0','5240','','.account-samples'),(910376,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','left','1','3','','.account-sample-info'),(910377,'watch','.account-sample-info .historyInfoColumn h2.title-delivery-address, .account-sample-info .historyInfoColumn h2.title-billing-address','left','10','3','','.account-sample-info'),(910378,'watch','.account-sample-info .historyInfoColumn h2.title-payment','left','10','3','','.account-sample-info'),(910379,'watch','.account-sample-info .not_fully_paid_td','left','15','','','.account-sample-info'),(910380,'watch','.b-form .addresses .address-item input[type=\"radio\"]','left','0','','','.b-form'),(910381,'watch','.hide-page','left','0','','',''),(910382,'watch','.success-page .w-cart-listing .qty','left','60','','','.success-page'),(910383,'watch','.w-bestsellers .heading-3','left','0','3','','.w-bestsellers'),(910384,'watch','.w-menu-style-1 > ul > li > ul','left','0','','','.w-menu-style-1'),(910385,'watch','.b-slick .slick-track','left','0','','','.b-slick'),(910386,'watch','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left','50','','','.b-slick'),(910387,'watch','.b-slick button.slick-next','left','auto','','','.b-slick'),(910388,'watch','.b-slick button.slick-prev','left','0','','','.b-slick'),(910389,'watch','.w-banner .banner img + img','left','0','','','.w-banner'),(910390,'watch','.w-banner .carousel-text','left','0','','','.w-banner'),(910391,'watch','.w-banner .image-text-banner.bottom-left .text-banner','left','0','','','.w-banner'),(910392,'watch','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','left','0','','','.w-banner'),(910393,'watch','.w-banner .image-text-banner.top-left .text-banner','left','0','','','.w-banner'),(910394,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left_important','important','','','.b-select-suggest'),(910395,'watch','.b-form .radio-button input[type=\"radio\"].no','left_measure','vw','','','.b-form'),(910396,'watch','.b-fancybox #fancybox-loading','left_measure','%','','','.b-fancybox'),(910397,'watch','.w-checkout-shipping-choice input:checked + span:before','left_measure','%','','','.w-checkout-shipping-choice'),(910398,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left_measure','%','','','.b-switch'),(910399,'watch','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left_measure','%','','','.b-menu-lev_display-lra'),(910400,'watch','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left_measure','%','','','.b-menu-lev_display-lra'),(910401,'watch','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left_measure','%','','','.b-menu-lev_display-lra'),(910402,'watch','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left_measure','%','','','.b-menu-lev_display-lra'),(910403,'watch','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left_measure','%','','','.b-menu-lev_display-lra'),(910404,'watch','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left_measure','%','','','.b-menu-lev_display-right'),(910405,'watch','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left_measure','%','','','.b-menu-lev_display-right'),(910406,'watch','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left_measure','%','','','.b-menu-lev_display-right'),(910407,'watch','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left_measure','%','','','.b-menu-lev_display-right'),(910408,'watch','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left_measure','%','','','.b-menu-lev_display-right'),(910409,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left_measure','vw','','','.b-menu-lev_display-slide'),(910410,'watch','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left_measure','vw','','','.b-menu-lev_display-slide'),(910411,'watch','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left_measure','vw','','','.b-menu-lev_display-slide'),(910412,'watch','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left_measure','vw','','','.b-menu-lev_display-slide'),(910413,'watch','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left_measure','vw','','','.b-menu-lev_display-slide'),(910414,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left_measure','vw','','','.b-menu-open_from-left'),(910415,'watch','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left_measure','%','','','.b-slick'),(910416,'watch','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','line-height','1.2','','','.w-communication-new-topic'),(910417,'watch','.b-info-popup .info-popup div','line-height','30','3','','.b-info-popup'),(910418,'watch','.b-form .shipping-method .sub-title','line-height','1.3','','','.b-form'),(910419,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','line-height','12','','','.b-switch'),(910420,'watch','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line-height','30','','','.b-switch'),(910421,'watch','.w-tabs .tab-li.tab-cart a','line-height','0.75','3','','.w-tabs'),(910422,'watch','.message.success','line-height','1','3','',''),(910423,'watch','.heading-4 .edit, h4 .edit','line-height','20','','',''),(910424,'watch','.w-socials .post_item > div','line-height','19','','','.w-socials'),(910425,'watch','.p-quick-order-index .paginate_button.previous','line-height','26','3','','.p-quick-order-index'),(910426,'watch','.p-quick-order-index .paginate_button.next','line-height','26','3','','.p-quick-order-index'),(910427,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.p-quick-order-index'),(910428,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.p-quick-order-index'),(910430,'watch','.w-promotions .prom-multi-discount .promo-range','line-height','23','','','.w-promotions'),(910431,'watch','.w-quote .cart-box-link','line-height','39','5240,3','','.w-quote'),(910432,'watch','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(910434,'watch','.order-summary .heading-2','line-height','20','3','','.order-summary'),(910435,'watch','.shipping-ico .heading-2','line-height','10','3','','.shipping-ico'),(910436,'watch','.testimonials .heading-3','line-height','1','3','',''),(910437,'watch','.w-promotions .heading-3','line-height','1','','','.w-promotions'),(910438,'watch','.w-promotions .promo-salemaker .discount','line-height','23','','','.w-promotions'),(910439,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','line-height','23','','','.w-promotions'),(910440,'watch','.w-promotions .promo-cart-discount .promo-min-qty','line-height','23','','','.w-promotions'),(910441,'watch','.b-preloader .preloader','line-height','40','3','','.b-preloader'),(910442,'watch','.w-cart-compare .attributes-cell','line-height','22','','','.w-cart-compare'),(910444,'watch','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(910445,'watch','.b-quantity .qty-box .smaller','line-height','35','','','.b-quantity'),(910446,'watch','.b-bottom .closeable-heading','line-height','34','3','','.b-bottom'),(910447,'watch','.b-messages .messBtnMenuDelete','line-height','10','3','','.b-messages'),(910448,'watch','.b-messages span.starred::before','line-height','10','','','.b-messages'),(910449,'watch','.b-messages .messBtnMenuStarred','line-height','10','3','','.b-messages'),(910450,'watch','.b-messages .messBtnMenuUnread','line-height','10','3','','.b-messages'),(910451,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line-height','14','','','.b-messages'),(910452,'watch','.w-quote .cart-box-link','line-height','0.75','3','','.w-quote'),(910453,'watch','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(910454,'watch','.w-product-personal-catalog-button .btn','line-height','14','','','.w-product-personal-catalog-button'),(910455,'watch','.w-socials .post_item > div','line-height','19','','','.w-socials'),(910456,'watch','.p-payer-order-confirmation .ship-ico','line-height','20','3','','.p-payer-order-confirmation'),(910457,'watch','.p-payer-order-confirmation .order-ico','line-height','20','3','','.p-payer-order-confirmation'),(910458,'watch','.p-payer-order-confirmation .pay-ico','line-height','20','3','','.p-payer-order-confirmation'),(910459,'watch','.p-payer-order-confirmation .discount-ico','line-height','20','3','','.p-payer-order-confirmation'),(910460,'watch','.w-product-personal-catalog-button .btn','line-height','1','3','','.w-product-personal-catalog-button'),(910461,'watch','.p-payer-order-confirmation .comment-ico','line-height','20','3','','.p-payer-order-confirmation'),(910462,'watch','.p-payer-order-pay .ship-ico','line-height','20','3','','.p-payer-order-pay'),(910463,'watch','.p-payer-order-pay .pay-ico','line-height','20','3','','.p-payer-order-pay'),(910464,'watch','.p-payer-order-pay .order-ico','line-height','20','3','','.p-payer-order-pay'),(910465,'watch','.p-payer-order-pay .discount-ico','line-height','20','3','','.p-payer-order-pay'),(910466,'watch','.p-payer-order-pay .comment-ico','line-height','20','3','','.p-payer-order-pay'),(910467,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','line-height','15','','','.b-switch'),(910468,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','line-height','15','','','.b-switch'),(910469,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','line-height','15','','','.b-switch'),(910470,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','line-height','56','4','','.b-switch'),(910471,'watch','.b-quantity .qty-box .smaller','line-height','35','','','.b-quantity'),(910472,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','line-height','16','','','.b-switch'),(910473,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','line-height','10','','','.b-switch'),(910474,'watch','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','line-height','1.2','','','.p-quick-order-index'),(910475,'watch','.b-info .info','line-height','1','3','','.b-info'),(910476,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','line-height','15','','','.b-switch'),(910477,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','line-height','10','','','.b-switch'),(910478,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','line-height','10','','','.b-switch'),(910479,'watch','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(910480,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','line-height','12','','','.b-switch'),(910481,'watch','.w-product-personal-catalog-button .btn','line-height','14','','','.w-product-personal-catalog-button'),(910482,'watch','.bell-ico .heading-2','line-height','10','3','','.bell-ico'),(910483,'watch','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(910485,'watch','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(910486,'watch','.b-quantity .qty-box .bigger','line-height','35','','','.b-quantity'),(910487,'watch','.w-tabs .tab-li.tab-sample a','line-height','0.75','3','','.w-tabs'),(910488,'watch','.shipping-ico .heading-2','line-height','10','3','','.shipping-ico'),(910489,'watch','.w-cart-compare .compare-table','line-height','1.3','','','.w-cart-compare'),(910490,'watch','.b-quantity .qty-box .bigger','line-height','35','','','.b-quantity'),(910491,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line-height','18','','','.b-form'),(910492,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(910493,'watch','.w-checkout-shipping-choice span','line-height','19','','','.w-checkout-shipping-choice'),(910494,'watch','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(910495,'watch','.w-socials .post_item > div','line-height','19','','','.w-socials'),(910496,'watch','.b-info-popup .info-popup div','line-height','1.7','','','.b-info-popup'),(910497,'watch','.b-quantity .qty-box .smaller','line-height','35','','','.b-quantity'),(910498,'watch','.b-quantity .qty-box .bigger','line-height','35','','','.b-quantity'),(910499,'watch','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(910500,'watch','.w-checkout-shipping-address .addresses .address-item label','line-height','1.3','','','.w-checkout-shipping-address'),(910501,'watch','.w-tabs .tab-li.tab-wishlist a','line-height','0.75','3','','.w-tabs'),(910503,'watch','.w-socials .post_item > div','line-height','19','','','.w-socials'),(910504,'watch','.b-info .info','line-height','1','3','','.b-info'),(910505,'watch','.b-info-popup .info-popup','line-height','2','','','.b-info-popup'),(910507,'watch','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(910508,'watch','.btn-2','line-height','20','','',''),(910509,'watch','.w-cart-compare .delete-cart','line-height','1','','','.w-cart-compare'),(910510,'watch','.w-product-personal-catalog-button .btn','line-height','1','3','','.w-product-personal-catalog-button'),(910511,'watch','.b-quantity .qty-box .bigger','line-height','35','','','.b-quantity'),(910513,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span','line-height','22','','','.b-form'),(910514,'watch','.w-filters .input-checkbox:checked + .checkbox-span:before','line-height','22','','','.w-filters'),(910515,'watch','.heading-3 .right-text, h3 .right-text','line-height','20','','',''),(910516,'watch','.heading-3 .edit, h3 .edit','line-height','20','','',''),(910517,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','line-height','56','4','','.b-switch'),(910518,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','line-height','56','4','','.b-switch'),(910520,'watch','.shipping-ico .heading-2','line-height','10','3','','.shipping-ico'),(910521,'watch','.savings-ico .heading-2','line-height','10','3','','.savings-ico'),(910522,'watch','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(910523,'watch','.b-fancybox .fancybox-title-float-wrap .child','line-height','24','','','.b-fancybox'),(910524,'watch','.w-product-personal-catalog-button .btn','line-height','14','','','.w-product-personal-catalog-button'),(910525,'watch','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(910526,'watch','.w-product-personal-catalog-button .btn','line-height','1','3','','.w-product-personal-catalog-button'),(910527,'watch','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(910528,'watch','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(910529,'watch','.w-socials .post_item > div','line-height','19','','','.w-socials'),(910530,'watch','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(910531,'watch','.btn','line-height','20','','',''),(910532,'watch','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(910534,'watch','.b-info .info','line-height','1','3','','.b-info'),(910535,'watch','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(910536,'watch','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(910537,'watch','.w-reviews .heading-3','line-height','1','3','','.w-reviews'),(910538,'watch','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(910539,'watch','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(910540,'watch','.b-quantity .qty-box .smaller','line-height','35','','','.b-quantity'),(910541,'watch','.p-quick-order-index .stock','line-height','1.2','','','.p-quick-order-index'),(910542,'watch','.b-info .info','line-height','1','3','','.b-info'),(910543,'watch','.b-form .checkbox-style:checked + .checkbox-span:before','line-height','18','','','.b-form'),(910544,'watch','.w-cart-listing .links','line-height','35','','','.w-cart-listing'),(910545,'watch','.price .old','line-height','0.8','','',''),(910546,'watch','.w-product-personal-catalog-button .btn','line-height','14','','','.w-product-personal-catalog-button'),(910547,'watch','.w-cart-compare .price-cell','line-height','22','','','.w-cart-compare'),(910548,'watch','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(910549,'watch','.b-info .info','line-height','1','3','','.b-info'),(910550,'watch','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(910551,'watch','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(910552,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(910553,'watch','.w-multi-cart-cart-switcher .cart-label','line-height','20','','','.w-multi-cart-cart-switcher'),(910554,'watch','.b-quantity .qty-box .bigger','line-height','35','','','.b-quantity'),(910555,'watch','.b-bottom .pop-up-close','line-height','25','','','.b-bottom'),(910556,'watch','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(910557,'watch','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(910558,'watch','.w-personal-gift-status-bar .inform','line-height','14','4','','.w-personal-gift-status-bar'),(910559,'watch','.w-tabs .tab-li.tab-quote a','line-height','0.75','3','','.w-tabs'),(910560,'watch','.b-fancybox .fancybox-close','line-height','40','','','.b-fancybox'),(910561,'watch','.b-form .form-inputs div.required-message','line-height','1.3','','','.b-form'),(910562,'watch','.b-info .info','line-height','1','3','','.b-info'),(910563,'watch','.b-quantity .qty-box .bigger','line-height','35','','','.b-quantity'),(910564,'watch','.w-product-customers-activity .close','line-height','32','','','.w-product-customers-activity'),(910565,'watch','.w-product-personal-catalog-button .btn','line-height','1','3','','.w-product-personal-catalog-button'),(910566,'watch','.w-product-personal-catalog-button .btn','line-height','14','','','.w-product-personal-catalog-button'),(910567,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(910568,'watch','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(910569,'watch','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(910570,'watch','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(910571,'watch','.w-checkout-billing-address .addresses .address-item label','line-height','1.3','','','.w-checkout-billing-address'),(910573,'watch','.w-cart-compare .cart-name a','line-height','1.2','','','.w-cart-compare'),(910574,'watch','.w-personal-gift-status-bar .end-date','line-height','14','3','','.w-personal-gift-status-bar'),(910575,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(910576,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line-height','13','','','.b-select-suggest'),(910577,'watch','.w-product-personal-catalog-button .btn','line-height','1','3','','.w-product-personal-catalog-button'),(910578,'watch','.b-switch .bootstrap-switch','line-height','28','','','.b-switch'),(910579,'watch','.w-product-personal-catalog-button .btn','line-height','14','','','.w-product-personal-catalog-button'),(910580,'watch','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(910581,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.b-data-table'),(910582,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.b-data-table'),(910583,'watch','.b-products-listing .products-listing .name a','line-height','1.5','','','.b-products-listing'),(910584,'watch','.b-products-listing .btn-preloader','line-height','24','3','','.b-products-listing'),(910585,'watch','.b-products-listing .loader','line-height','30','4','','.b-products-listing'),(910586,'watch','.b-products-listing .products-listing .btn-buy','line-height','10','3','','.b-products-listing'),(910587,'watch','.checkbox input:not(checked) + span:before','line-height','24','','',''),(910590,'watch','.b-quantity .qty-box .smaller','line-height','35','','','.b-quantity'),(910591,'watch','.b-select-suggest .select2-container .select2-choice','line-height','26','','','.b-select-suggest'),(910592,'watch','.b-quantity .qty-box .smaller','line-height','35','','','.b-quantity'),(910593,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','line-height','10','','','.b-switch'),(910594,'watch','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(910595,'watch','.w-socials .post_item > div','line-height','19','','','.w-socials'),(910596,'watch','.order-summary .price-row.ot_coupon .title','line-height','22','3','','.order-summary'),(910597,'watch','.heading-4 .right-text, h4 .right-text','line-height','20','','',''),(910598,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','40','','','.w-communication-new-topic'),(910599,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','35','3','','.w-communication-new-topic'),(910600,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line-height','36','','','.w-communication-new-topic'),(910601,'watch','.btn-3','line-height','20','','',''),(910602,'watch','.w-product-personal-catalog-button .btn','line-height','1','3','','.w-product-personal-catalog-button'),(910603,'watch','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(910604,'watch','.b-form .radio-button input[type=\"radio\"].no + span','line-height','30','3','','.b-form'),(910605,'watch','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(910606,'watch','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(910607,'watch','.b-form .cart-popup .price','line-height','35','','','.b-form'),(910608,'watch','.w-menu-horizontal .menu-ico','line-height','54','','','.w-menu-horizontal'),(910609,'watch','.w-catalog-listing-look .grid','line-height','30','','','.w-catalog-listing-look'),(910610,'watch','.w-catalog-listing-look .b2b','line-height','30','','','.w-catalog-listing-look'),(910611,'watch','.w-catalog-listing-look .list','line-height','30','','','.w-catalog-listing-look'),(910612,'watch','.w-cart-listing .item .attributes','line-height','1.7','','','.w-cart-listing'),(910613,'watch','.w-cart-listing .points-earn','line-height','1','','','.w-cart-listing'),(910614,'watch','.w-cart-listing .points-redeem','line-height','1','','','.w-cart-listing'),(910615,'watch','.w-cart-listing .remove-btn','line-height','30','','','.w-cart-listing'),(910616,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(910618,'watch','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(910619,'watch','.b-fancybox .fancybox-nav span','line-height','40','','','.b-fancybox'),(910620,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(910621,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','line-height','30','','','.b-switch'),(910622,'watch','.w-checkout-create-account .account-benefits strong','line-height','16','3','','.w-checkout-create-account'),(910623,'watch','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(910624,'watch','.w-cart-compare .js-cart_totals_container','line-height','1.2','','','.w-cart-compare'),(910625,'watch','.btn-1','line-height','24','','',''),(910626,'watch','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(910627,'watch','.b-products-listing .products-listing .btn-preloader','line-height','8','','','.b-products-listing'),(910628,'watch','.price .special','line-height','0.8','','',''),(910629,'watch','.b-data-table table.dataTable thead td','line-height','1.5','','','.b-data-table'),(910630,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','line-height','30','','','.b-switch'),(910631,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','line-height','30','','','.b-switch'),(910632,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','line-height','30','','','.b-switch'),(910633,'watch','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(910634,'watch','.w-filters .input-checkbox:not(checked) + .checkbox-span','line-height','22','','','.w-filters'),(910635,'watch','.b-upload-file .snapshot','line-height','38','','','.b-upload-file'),(910636,'watch','.b-product-images .media-popup .mp-close','line-height','100','','','.b-product-images'),(910637,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','line-height','100','','','.b-product-images'),(910638,'watch','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line-height','30','','','.b-menu-burger_icon'),(910639,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(910640,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(910641,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(910642,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(910643,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(910644,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','line-height','1.2','','','.b-menu-style-1'),(910645,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','line-height','24','','','.b-menu-style-2'),(910646,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','line-height','24','','','.b-menu-style-2'),(910647,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','line-height','50','','','.b-menu-style-2'),(910648,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','line-height','16','3','','.b-menu-style-2'),(910649,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','line-height','16','3','','.b-menu-style-2'),(910650,'watch','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','line-height','1.3','','','.b-trade-approval'),(910651,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line-height','24','3','','.w-catalog-compare'),(910652,'watch','.w-catalog-compare td','line-height','1.5','','','.w-catalog-compare'),(910653,'watch','.w-catalog-compare span.btn-preloader','line-height','24','3','','.w-catalog-compare'),(910654,'watch','.w-delivery-day .ends','line-height','1','','','.w-delivery-day'),(910655,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','line-height','22','','','.w-filters'),(910656,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','line-height','22','','','.w-filters'),(910657,'watch','.order-summary .icon','line-height','30','','','.order-summary'),(910658,'watch','.w-cart-discount-coupon .title','line-height','0.75','4','','.w-cart-discount-coupon'),(910671,'watch','.catalog-product-wrap .pn-direction','line-height','1.2','','','.catalog-product-wrap'),(910672,'watch','.catalog-product-wrap .pn-image','line-height','24','3','','.catalog-product-wrap'),(910673,'watch','.checkout-index-wrap .comment-ico','line-height','20','3','','.checkout-index-wrap'),(910674,'watch','.checkout-index-wrap .discount-ico','line-height','20','3','','.checkout-index-wrap'),(910675,'watch','.checkout-index-wrap .order-ico','line-height','20','3','','.checkout-index-wrap'),(910676,'watch','.checkout-index-wrap .pay-ico','line-height','20','3','','.checkout-index-wrap'),(910677,'watch','.checkout-index-wrap .ship-ico','line-height','20','3','','.checkout-index-wrap'),(910678,'watch','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','line-height','20','','','.account-samples'),(910679,'watch','.account-samples .order_history_table th','line-height','16','','','.account-samples'),(910680,'watch','.account-samples .view_link','line-height','17','4','','.account-samples'),(910681,'watch','.account-samples .orders-table .td-alignright','line-height','35','5240','','.account-samples'),(910682,'watch','.checkout-order-confirmation .comment-ico','line-height','20','3','','.checkout-order-confirmation'),(910683,'watch','.checkout-order-confirmation .discount-ico','line-height','20','3','','.checkout-order-confirmation'),(910684,'watch','.checkout-order-confirmation .order-ico','line-height','20','3','','.checkout-order-confirmation'),(910685,'watch','.checkout-order-confirmation .pay-ico','line-height','20','3','','.checkout-order-confirmation'),(910686,'watch','.checkout-order-confirmation .prod-ico','line-height','20','3','','.checkout-order-confirmation'),(910687,'watch','.checkout-order-confirmation .ship-ico','line-height','20','3','','.checkout-order-confirmation'),(910688,'watch','.success-page .comment-ico','line-height','20','3','','.success-page'),(910689,'watch','.success-page .discount-ico','line-height','20','3','','.success-page'),(910690,'watch','.success-page .order-ico','line-height','20','3','','.success-page'),(910691,'watch','.success-page .page-success .text-1','line-height','20','3','','.success-page'),(910692,'watch','.success-page .pay-ico','line-height','20','3','','.success-page'),(910693,'watch','.success-page .prod-ico','line-height','20','3','','.success-page'),(910694,'watch','.success-page .ship-ico','line-height','20','3','','.success-page'),(910695,'watch','.success-page .w-cart-listing .qty','line-height','26','','','.success-page'),(910696,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line-height','31','','','.b-multi-page-checkout'),(910697,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line-height','35','3','','.b-multi-page-checkout'),(910698,'watch','.w-bestsellers .counter','line-height','34','','','.w-bestsellers'),(910699,'watch','.w-bestsellers .heading-3','line-height','1','3','','.w-bestsellers'),(910700,'watch','.w-bestsellers .item','line-height','33','3','','.w-bestsellers'),(910701,'watch','.w-menu-style-1 .menu-ico','line-height','54','','','.w-menu-style-1'),(910702,'watch','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line-height','36','','','.b-slick'),(910703,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','38','','','.b-slick'),(910704,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','48','5240','','.b-slick'),(910705,'watch','.w-catalog-paging ','line-height','30','2','','.w-catalog-paging'),(910706,'watch','.w-catalog-paging .next','line-height','30','','','.w-catalog-paging'),(910707,'watch','.w-catalog-paging .next','line-height','26','3','','.w-catalog-paging'),(910708,'watch','.w-catalog-paging .next-pages','line-height','30','','','.w-catalog-paging'),(910709,'watch','.w-catalog-paging .page-number','line-height','30','','','.w-catalog-paging'),(910710,'watch','.w-catalog-paging .prev','line-height','30','','','.w-catalog-paging'),(910711,'watch','.w-catalog-paging .prev','line-height','26','3','','.w-catalog-paging'),(910712,'watch','.w-catalog-paging .prev-pages','line-height','30','','','.w-catalog-paging'),(910713,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line-height','30','','','.w-catalog-paging'),(910714,'watch','.b-info-popup .info-popup div','line_height_measure','px','3','','.b-info-popup'),(910715,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(910716,'watch','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line_height_measure','px','','','.b-switch'),(910717,'watch','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(910718,'watch','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(910719,'watch','.b-form .radio-button input[type=\"radio\"].no + span','line_height_measure','px','3','','.b-form'),(910720,'watch','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(910721,'watch','.heading-4 .edit, h4 .edit','line_height_measure','px','','',''),(910722,'watch','.p-quick-order-index .paginate_button.next','line_height_measure','px','3','','.p-quick-order-index'),(910723,'watch','.p-quick-order-index .paginate_button.previous','line_height_measure','px','3','','.p-quick-order-index'),(910724,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.p-quick-order-index'),(910725,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.p-quick-order-index'),(910726,'watch','.w-promotions .prom-multi-discount .promo-range','line_height_measure','px','','','.w-promotions'),(910727,'watch','.shipping-ico .heading-2','line_height_measure','px','3','','.shipping-ico'),(910728,'watch','.w-promotions .promo-salemaker .discount','line_height_measure','px','','','.w-promotions'),(910729,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','line_height_measure','px','','','.w-promotions'),(910730,'watch','.w-promotions .promo-cart-discount .promo-min-qty','line_height_measure','px','','','.w-promotions'),(910731,'watch','.b-preloader .preloader','line_height_measure','px','3','','.b-preloader'),(910732,'watch','.w-cart-compare .attributes-cell','line_height_measure','px','','','.w-cart-compare'),(910733,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-messages'),(910734,'watch','.b-bottom .closeable-heading','line_height_measure','px','3','','.b-bottom'),(910735,'watch','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(910736,'watch','.b-messages .messBtnMenuDelete','line_height_measure','px','3','','.b-messages'),(910737,'watch','.b-messages .messBtnMenuStarred','line_height_measure','px','3','','.b-messages'),(910738,'watch','.b-messages span.starred::before','line_height_measure','px','','','.b-messages'),(910739,'watch','.b-messages .messBtnMenuUnread','line_height_measure','px','3','','.b-messages'),(910740,'watch','.p-payer-order-confirmation .ship-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(910741,'watch','.p-payer-order-confirmation .pay-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(910742,'watch','.p-payer-order-confirmation .order-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(910743,'watch','.p-payer-order-confirmation .discount-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(910744,'watch','.p-payer-order-confirmation .comment-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(910745,'watch','.p-payer-order-pay .ship-ico','line_height_measure','px','3','','.p-payer-order-pay'),(910746,'watch','.p-payer-order-pay .pay-ico','line_height_measure','px','3','','.p-payer-order-pay'),(910747,'watch','.p-payer-order-pay .order-ico','line_height_measure','px','3','','.p-payer-order-pay'),(910748,'watch','.p-payer-order-pay .discount-ico','line_height_measure','px','3','','.p-payer-order-pay'),(910749,'watch','.p-payer-order-pay .comment-ico','line_height_measure','px','3','','.p-payer-order-pay'),(910750,'watch','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(910751,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(910752,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(910753,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(910754,'watch','.order-summary .heading-2','line_height_measure','px','3','','.order-summary'),(910755,'watch','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(910756,'watch','.b-fancybox .fancybox-close','line_height_measure','px','','','.b-fancybox'),(910757,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','line_height_measure','px','4','','.b-switch'),(910758,'watch','.b-info-popup .info-popup','line_height_measure','px','','','.b-info-popup'),(910759,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(910760,'watch','.bell-ico .heading-2','line_height_measure','px','3','','.bell-ico'),(910761,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(910762,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(910763,'watch','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(910764,'watch','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(910765,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(910766,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(910767,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(910768,'watch','.b-switch .bootstrap-switch','line_height_measure','px','','','.b-switch'),(910769,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(910770,'watch','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(910771,'watch','.shipping-ico .heading-2','line_height_measure','px','3','','.shipping-ico'),(910772,'watch','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(910773,'watch','.w-checkout-shipping-choice span','line_height_measure','px','','','.w-checkout-shipping-choice'),(910774,'watch','.w-product-personal-catalog-button .btn','line_height_measure','px','','','.w-product-personal-catalog-button'),(910775,'watch','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(910776,'watch','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(910777,'watch','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(910778,'watch','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(910779,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(910780,'watch','.b-form .checkbox-style:checked + .checkbox-span:before','line_height_measure','px','','','.b-form'),(910782,'watch','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(910783,'watch','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(910784,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span','line_height_measure','px','','','.b-form'),(910785,'watch','.btn-2','line_height_measure','px','','',''),(910786,'watch','.w-filters .input-checkbox:checked + .checkbox-span:before','line_height_measure','px','','','.w-filters'),(910787,'watch','.w-personal-gift-status-bar .inform','line_height_measure','px','4','','.w-personal-gift-status-bar'),(910788,'watch','.heading-3 .right-text, h3 .right-text','line_height_measure','px','','',''),(910789,'watch','.heading-3 .edit, h3 .edit','line_height_measure','px','','',''),(910790,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','line_height_measure','px','4','','.b-switch'),(910791,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','line_height_measure','px','4','','.b-switch'),(910793,'watch','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(910794,'watch','.shipping-ico .heading-2','line_height_measure','px','3','','.shipping-ico'),(910795,'watch','.savings-ico .heading-2','line_height_measure','px','3','','.savings-ico'),(910796,'watch','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(910797,'watch','.b-fancybox .fancybox-title-float-wrap .child','line_height_measure','px','','','.b-fancybox'),(910798,'watch','.w-product-personal-catalog-button .btn','line_height_measure','px','','','.w-product-personal-catalog-button'),(910799,'watch','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(910800,'watch','.btn','line_height_measure','px','','',''),(910801,'watch','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(910802,'watch','.b-select-suggest .select2-container .select2-choice','line_height_measure','px','','','.b-select-suggest'),(910803,'watch','.w-cart-listing .links','line_height_measure','px','','','.w-cart-listing'),(910804,'watch','.w-product-personal-catalog-button .btn','line_height_measure','px','','','.w-product-personal-catalog-button'),(910805,'watch','.w-product-personal-catalog-button .btn','line_height_measure','px','','','.w-product-personal-catalog-button'),(910806,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(910807,'watch','.b-bottom .pop-up-close','line_height_measure','px','','','.b-bottom'),(910808,'watch','.w-product-personal-catalog-button .btn','line_height_measure','px','','','.w-product-personal-catalog-button'),(910809,'watch','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(910810,'watch','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(910811,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line_height_measure','px','','','.b-form'),(910812,'watch','.w-product-customers-activity .close','line_height_measure','px','','','.w-product-customers-activity'),(910814,'watch','.w-product-personal-catalog-button .btn','line_height_measure','px','','','.w-product-personal-catalog-button'),(910816,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(910817,'watch','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(910818,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-select-suggest'),(910819,'watch','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(910821,'watch','.w-cart-compare .price-cell','line_height_measure','px','','','.w-cart-compare'),(910822,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.b-data-table'),(910823,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.b-data-table'),(910824,'watch','.b-products-listing .btn-preloader','line_height_measure','px','3','','.b-products-listing'),(910825,'watch','.b-products-listing .loader','line_height_measure','px','4','','.b-products-listing'),(910826,'watch','.b-products-listing .products-listing .btn-buy','line_height_measure','px','3','','.b-products-listing'),(910827,'watch','.checkbox input:not(checked) + span:before','line_height_measure','px','','',''),(910829,'watch','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(910830,'watch','.w-quote .cart-box-link','line_height_measure','px','5240,3','','.w-quote'),(910831,'watch','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(910832,'watch','.order-summary .price-row.ot_coupon .title','line_height_measure','px','3','','.order-summary'),(910833,'watch','.w-checkout-create-account .account-benefits strong','line_height_measure','px','3','','.w-checkout-create-account'),(910834,'watch','.heading-4 .right-text, h4 .right-text','line_height_measure','px','','',''),(910835,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','','','.w-communication-new-topic'),(910836,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','3','','.w-communication-new-topic'),(910837,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line_height_measure','px','','','.w-communication-new-topic'),(910838,'watch','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(910839,'watch','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(910841,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(910842,'watch','.w-personal-gift-status-bar .end-date','line_height_measure','px','3','','.w-personal-gift-status-bar'),(910843,'watch','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(910844,'watch','.w-menu-horizontal .menu-ico','line_height_measure','px','','','.w-menu-horizontal'),(910845,'watch','.w-catalog-listing-look .grid','line_height_measure','px','','','.w-catalog-listing-look'),(910846,'watch','.w-catalog-listing-look .b2b','line_height_measure','px','','','.w-catalog-listing-look'),(910847,'watch','.w-catalog-listing-look .list','line_height_measure','px','','','.w-catalog-listing-look'),(910848,'watch','.w-cart-listing .remove-btn','line_height_measure','px','','','.w-cart-listing'),(910849,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(910851,'watch','.b-fancybox .fancybox-nav span','line_height_measure','px','','','.b-fancybox'),(910852,'watch','.w-multi-cart-cart-switcher .cart-label','line_height_measure','px','','','.w-multi-cart-cart-switcher'),(910853,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(910854,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(910855,'watch','.b-form .cart-popup .price','line_height_measure','px','','','.b-form'),(910856,'watch','.btn-1','line_height_measure','px','','',''),(910857,'watch','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(910858,'watch','.b-products-listing .products-listing .btn-preloader','line_height_measure','px','','','.b-products-listing'),(910859,'watch','.btn-3','line_height_measure','px','','',''),(910860,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(910861,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(910862,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(910863,'watch','.w-filters .input-checkbox:not(checked) + .checkbox-span','line_height_measure','px','','','.w-filters'),(910864,'watch','.b-upload-file .snapshot','line_height_measure','px','','','.b-upload-file'),(910865,'watch','.b-product-images .media-popup .mp-close','line_height_measure','px','','','.b-product-images'),(910866,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','line_height_measure','px','','','.b-product-images'),(910867,'watch','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line_height_measure','px','','','.b-menu-burger_icon'),(910868,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(910869,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(910870,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(910871,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(910872,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(910873,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','line_height_measure','px','','','.b-menu-style-2'),(910874,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','line_height_measure','px','','','.b-menu-style-2'),(910875,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','line_height_measure','px','','','.b-menu-style-2'),(910876,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','line_height_measure','px','3','','.b-menu-style-2'),(910877,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','line_height_measure','px','3','','.b-menu-style-2'),(910878,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line_height_measure','px','3','','.w-catalog-compare'),(910879,'watch','.w-catalog-compare span.btn-preloader','line_height_measure','px','3','','.w-catalog-compare'),(910880,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','line_height_measure','px','','','.w-filters'),(910881,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:checked + span:before','line_height_measure','px','','','.w-filters'),(910882,'watch','.order-summary .icon','line_height_measure','px','','','.order-summary'),(910895,'watch','.catalog-product-wrap .pn-image','line_height_measure','px','3','','.catalog-product-wrap'),(910896,'watch','.checkout-index-wrap .comment-ico','line_height_measure','px','3','','.checkout-index-wrap'),(910897,'watch','.checkout-index-wrap .discount-ico','line_height_measure','px','3','','.checkout-index-wrap'),(910898,'watch','.checkout-index-wrap .order-ico','line_height_measure','px','3','','.checkout-index-wrap'),(910899,'watch','.checkout-index-wrap .pay-ico','line_height_measure','px','3','','.checkout-index-wrap'),(910900,'watch','.checkout-index-wrap .ship-ico','line_height_measure','px','3','','.checkout-index-wrap'),(910901,'watch','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','line_height_measure','px','','','.account-samples'),(910902,'watch','.account-samples .order_history_table th','line_height_measure','px','','','.account-samples'),(910903,'watch','.account-samples .view_link','line_height_measure','px','4','','.account-samples'),(910904,'watch','.account-samples .orders-table .td-alignright','line_height_measure','px','5240','','.account-samples'),(910905,'watch','.checkout-order-confirmation .comment-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(910906,'watch','.checkout-order-confirmation .discount-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(910907,'watch','.checkout-order-confirmation .order-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(910908,'watch','.checkout-order-confirmation .pay-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(910909,'watch','.checkout-order-confirmation .prod-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(910910,'watch','.checkout-order-confirmation .ship-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(910911,'watch','.success-page .comment-ico','line_height_measure','px','3','','.success-page'),(910912,'watch','.success-page .discount-ico','line_height_measure','px','3','','.success-page'),(910913,'watch','.success-page .order-ico','line_height_measure','px','3','','.success-page'),(910914,'watch','.success-page .page-success .text-1','line_height_measure','px','3','','.success-page'),(910915,'watch','.success-page .pay-ico','line_height_measure','px','3','','.success-page'),(910916,'watch','.success-page .prod-ico','line_height_measure','px','3','','.success-page'),(910917,'watch','.success-page .ship-ico','line_height_measure','px','3','','.success-page'),(910918,'watch','.success-page .w-cart-listing .qty','line_height_measure','px','','','.success-page'),(910919,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line_height_measure','px','','','.b-multi-page-checkout'),(910920,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line_height_measure','px','3','','.b-multi-page-checkout'),(910921,'watch','.w-bestsellers .counter','line_height_measure','px','','','.w-bestsellers'),(910922,'watch','.w-bestsellers .item','line_height_measure','px','3','','.w-bestsellers'),(910923,'watch','.w-menu-style-1 .menu-ico','line_height_measure','px','','','.w-menu-style-1'),(910924,'watch','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line_height_measure','px','','','.b-slick'),(910925,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','','','.b-slick'),(910926,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','5240','','.b-slick'),(910927,'watch','.w-catalog-paging ','line_height_measure','px','2','','.w-catalog-paging'),(910928,'watch','.w-catalog-paging .next','line_height_measure','px','','','.w-catalog-paging'),(910929,'watch','.w-catalog-paging .next','line_height_measure','px','3','','.w-catalog-paging'),(910930,'watch','.w-catalog-paging .next-pages','line_height_measure','px','','','.w-catalog-paging'),(910931,'watch','.w-catalog-paging .page-number','line_height_measure','px','','','.w-catalog-paging'),(910932,'watch','.w-catalog-paging .prev','line_height_measure','px','','','.w-catalog-paging'),(910933,'watch','.w-catalog-paging .prev','line_height_measure','px','3','','.w-catalog-paging'),(910934,'watch','.w-catalog-paging .prev-pages','line_height_measure','px','','','.w-catalog-paging'),(910935,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line_height_measure','px','','','.w-catalog-paging'),(910936,'watch','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(910937,'watch','.p-quick-order-index ul.token-input-list','list-style','none','','','.p-quick-order-index'),(910941,'watch','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(910942,'watch','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(910943,'watch','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(910944,'watch','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(910945,'watch','.b-messages .messages-menu ul','list-style','none','','','.b-messages'),(910946,'watch','.w-sitemap-delivery-location > ul > li > ul','list-style','none','','','.w-sitemap-delivery-location'),(910947,'watch','.b-info .info ul','list-style','disc inside','','','.b-info'),(910948,'watch','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(910949,'watch','.w-sitemap-delivery-location > ul','list-style','none','','','.w-sitemap-delivery-location'),(910950,'watch','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(910951,'watch','.b-info .info ul','list-style','disc inside','','','.b-info'),(910952,'watch','.w-filters .filter-ul-content','list-style','none','','','.w-filters'),(910953,'watch','.w-menu-horizontal ul','list-style','none','','','.w-menu-horizontal'),(910954,'watch','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(910955,'watch','.b-info .info ul','list-style','disc inside','','','.b-info'),(910956,'watch','.b-info .info ul','list-style','disc inside','','','.b-info'),(910957,'watch','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(910958,'watch','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(910959,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(910960,'watch','.products-quick-index ul','list-style','none','','',''),(910961,'watch','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(910962,'watch','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(910963,'watch','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(910964,'watch','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(910965,'watch','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(910966,'watch','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(910967,'watch','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(910968,'watch','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(910969,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(910970,'watch','.w-tabs .tab-navigation','list-style','none','','','.w-tabs'),(910971,'watch','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(910972,'watch','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(910973,'watch','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(910974,'watch','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(910975,'watch','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(910976,'watch','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(910977,'watch','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(910978,'watch','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(910979,'watch','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(910980,'watch','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(910981,'watch','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(910982,'watch','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(910983,'watch','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(910984,'watch','.b-info .info ul','list-style','disc inside','','','.b-info'),(910985,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(910986,'watch','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(910987,'watch','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(910988,'watch','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(910989,'watch','.b-autocomplete .ui-autocomplete','list-style','none','','','.b-autocomplete'),(910990,'watch','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(910992,'watch','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(910993,'watch','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(910994,'watch','.b-select-suggest .select2-container-multi .select2-choices li','list-style','none','','','.b-select-suggest'),(910995,'watch','.b-select-suggest .select2-results li','list-style','none','','','.b-select-suggest'),(910996,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(910997,'watch','.w-menu-big ul','list-style','none','','','.w-menu-big'),(910999,'watch','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(911000,'watch','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(911001,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(911002,'watch','.products-quick-index .token-input-list','list-style','none','','',''),(911003,'watch','.b-info .info ul','list-style','disc inside','','','.b-info'),(911004,'watch','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(911005,'watch','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(911006,'watch','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(911007,'watch','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(911008,'watch','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(911009,'watch','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(911010,'watch','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(911011,'watch','.products-quick-index ul.token-input-list','list-style','none','','',''),(911012,'watch','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(911013,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(911014,'watch','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(911015,'watch','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','list-style','none','','','.b-menu-style'),(911016,'watch','.w-catalog-additional-images ul, .w-catalog-additional-images li','list-style','none','','','.w-catalog-additional-images'),(911017,'watch','.w-filters .filter-box-content ul','list-style','none','','','.w-filters'),(911022,'watch','.b-slick .slick-dots','list-style','none','','','.b-slick'),(911023,'watch','.w-menu-style-1 ul','list-style','none','','','.w-menu-style-1'),(911024,'watch','.b-form .middle-form','margin','0 auto','','','.b-form'),(911025,'watch','.w-product-in-bundles .bundle_item + .bundle_item','margin','0px auto 0px','','','.w-product-in-bundles'),(911026,'watch','.w-delivery-location-top-location-list .deliveryName','margin','5px auto','','','.w-delivery-location-top-location-list'),(911027,'watch','.b-messages .msv_btn .btn','margin','0px auto 0px','','','.b-messages'),(911028,'watch','.w-product-quantity .qty_packs .price_1','margin','0px auto 0px','4','','.w-product-quantity'),(911029,'watch','.w-product-quantity .qty_packs .price_1','margin','0px auto 0px','4','','.w-product-quantity'),(911030,'watch','.w-product-bundle .bundle_item + .bundle_item','margin','0px auto 0px','','','.w-product-bundle'),(911031,'watch','.w-product-in-bundles .bundle_item + .bundle_item','margin','0px auto 0px','','','.w-product-in-bundles'),(911032,'watch','.w-delivery-location-top-location-list .deliveryName','margin','5px auto','','','.w-delivery-location-top-location-list'),(911033,'watch','.w-product-bundle .bundle_item + .bundle_item','margin','0px auto 0px','','','.w-product-bundle'),(911034,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','margin','3px auto 3px','','','.b-select-suggest'),(911035,'watch','.b-select-suggest .select2-results','margin','4px auto 4px','','','.b-select-suggest'),(911036,'watch','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(911037,'watch','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(911038,'watch','.w-product-in-bundles .bundle_item + .bundle_item','margin','0px auto 0px','','','.w-product-in-bundles'),(911039,'watch','.w-product-bundle .bundle_item + .bundle_item','margin','0px auto 0px','','','.w-product-bundle'),(911040,'watch','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(911041,'watch','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin','0px auto 10px','','','.b-form'),(911042,'watch','.w-product-bundle .bundle_item + .bundle_item','margin','0px auto 0px','','','.w-product-bundle'),(911043,'watch','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(911044,'watch','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(911045,'watch','.w-product-quantity .qty_packs .price_1','margin','0px auto 0px','4','','.w-product-quantity'),(911046,'watch','.w-product-bundle .bundle_item + .bundle_item','margin','0px auto 0px','','','.w-product-bundle'),(911047,'watch','.w-product-quantity .qty_packs .price_1','margin','0px auto 0px','4','','.w-product-quantity'),(911048,'watch','.w-product-in-bundles .bundle_item + .bundle_item','margin','0px auto 0px','','','.w-product-in-bundles'),(911049,'watch','.w-catalog-b2b-add-button .b2b-add-box-wrap','margin','0 auto','','','.w-catalog-b2b-add-button'),(911050,'watch','.w-product-in-bundles .bundle_item + .bundle_item','margin','0px auto 0px','','','.w-product-in-bundles'),(911051,'watch','.w-delivery-location-top-location-list .deliveryName','margin','5px auto','','','.w-delivery-location-top-location-list'),(911052,'watch','.w-delivery-location-top-location-list .deliveryName','margin','5px auto','','','.w-delivery-location-top-location-list'),(911053,'watch','.b-form .terms-login .bootstrap-switch','margin','9px auto 0px','','','.b-form'),(911054,'watch','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','margin','0 0 0 auto','','','.w-cart-listing'),(911055,'watch','.w-product-quantity .qty_packs .price_1','margin','0px auto 0px','4','','.w-product-quantity'),(911056,'watch','.w-delivery-location-top-location-list .deliveryName','margin','5px auto','','','.w-delivery-location-top-location-list'),(911057,'watch','.w-delivery-location-top-location-list .deliveryName','margin','5px auto','','','.w-delivery-location-top-location-list'),(911058,'watch','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','margin','0 auto','','','.b-product-images'),(911059,'watch','.b-trade-approval .middle-form','margin','0 auto','','','.b-trade-approval'),(911062,'watch','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','margin','0 auto','','','.checkout-index-wrap'),(911063,'watch','.b-form .formWrapBox','margin','0 auto','','','.b-form'),(911064,'watch','.w-communication-new-topic #communication_group_holder input, .w-communication-new-topic select','margin-bottom','0','','','.w-communication-new-topic'),(911065,'watch','.w-checkout-billing-address .genders-title','margin-bottom','5','','','.w-checkout-billing-address'),(911066,'watch','.b-form .col-full-margin','margin-bottom','10','','','.b-form'),(911067,'watch','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(911068,'watch','.w-tabs .tab-li.tab-cart a','margin-bottom','7','3','','.w-tabs'),(911069,'watch','.p-sample-checkout-index .buttons','margin-bottom','20','','','.p-sample-checkout-index'),(911071,'watch','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(911072,'watch','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(911073,'watch','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(911074,'watch','.w-catalog-items-on-page select','margin-bottom','0','','','.w-catalog-items-on-page'),(911075,'watch','.b-form .message.error','margin-bottom','10','','','.b-form'),(911076,'watch','.w-delivery-location-top-location-list .deliveryList','margin-bottom','0','','','.w-delivery-location-top-location-list'),(911077,'watch','.w-delivery-location-top-location-list','margin-bottom','25','','','.w-delivery-location-top-location-list'),(911078,'watch','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(911079,'watch','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-bottom','0','','','.b-fancybox'),(911080,'watch','.p-quick-order-index .filters','margin-bottom','20','','','.p-quick-order-index'),(911081,'watch','.w-promotions .promo-date','margin-bottom','10','','','.w-promotions'),(911082,'watch','.w-promotions .promo-item','margin-bottom','30','','','.w-promotions'),(911083,'watch','.w-socials > li','margin-bottom','10','','','.w-socials'),(911084,'watch','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(911085,'watch','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(911089,'watch','.p-sample-checkout-index .buttons','margin-bottom','20','','','.p-sample-checkout-index'),(911090,'watch','.p-sample-checkout-index .price-box','margin-bottom','20','','','.p-sample-checkout-index'),(911091,'watch','.w-promotions .prom-multi-discount .heading','margin-bottom','10','','','.w-promotions'),(911092,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(911093,'watch','.w-delivery-location-top-location-list .deliveryList','margin-bottom','0','','','.w-delivery-location-top-location-list'),(911094,'watch','.w-delivery-location-top-location-list','margin-bottom','25','','','.w-delivery-location-top-location-list'),(911095,'watch','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(911096,'watch','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(911097,'watch','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(911098,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(911099,'watch','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(911100,'watch','.testimonials .reviews-list .name','margin-bottom','20','','',''),(911101,'watch','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(911102,'watch','.testimonials .heading-3','margin-bottom','10','','',''),(911103,'watch','.testimonials .name','margin-bottom','20','','',''),(911104,'watch','.b-products-listing .select-attributes','margin-bottom','10','','','.b-products-listing'),(911105,'watch','.b-products-listing .select-attributes select','margin-bottom','0','','','.b-products-listing'),(911106,'watch','.w-promotions .nextdiscount .promo-for-each','margin-bottom','10','','','.w-promotions'),(911107,'watch','.w-promotions .nextdiscount .heading','margin-bottom','20','','','.w-promotions'),(911108,'watch','.w-promotions .heading-3','margin-bottom','20','','','.w-promotions'),(911109,'watch','.w-promotions .promo-salemaker .item','margin-bottom','2','','','.w-promotions'),(911110,'watch','.w-promotions .promo-cart-discount .slave .item','margin-bottom','2','','','.w-promotions'),(911111,'watch','.w-promotions .promo-cart-discount .master .item','margin-bottom','12','','','.w-promotions'),(911112,'watch','.w-promotions .promo-cart-discount .master .heading','margin-bottom','10','','','.w-promotions'),(911113,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-bottom','20','','','.b-warehouses-popup'),(911114,'watch','.b-warehouses-popup .warehouses-popup .heading','margin-bottom','20','','','.b-warehouses-popup'),(911115,'watch','.w-info-content p','margin-bottom','10','','','.w-info-content'),(911117,'watch','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(911118,'watch','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(911119,'watch','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(911120,'watch','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(911121,'watch','.w-top-categories .categories','margin-bottom','0','5232','','.w-top-categories'),(911122,'watch','.b-messages .messages-menu ul','margin-bottom','0','','','.b-messages'),(911123,'watch','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(911124,'watch','.b-messages .messMenuButtonTop','margin-bottom','-39','','','.b-messages'),(911125,'watch','.b-messages .dataTables_wrapper > .top','margin-bottom','8','','','.b-messages'),(911126,'watch','.b-messages .messages-sidebar .heading-2','margin-bottom','20','','','.b-messages'),(911127,'watch','.b-messages .messages-menu li','margin-bottom','0','','','.b-messages'),(911128,'watch','.b-messages .messages-sidebar .btn-2','margin-bottom','20','','','.b-messages'),(911129,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-bottom','5','','','.b-messages'),(911130,'watch','.w-sitemap-delivery-location > ul > li > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(911131,'watch','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(911132,'watch','.w-product-in-bundles .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(911133,'watch','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(911134,'watch','.b-form .middle-form .bootstrap-switch','margin-bottom','15','','','.b-form'),(911135,'watch','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(911136,'watch','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(911137,'watch','.w-sitemap-delivery-location > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(911138,'watch','.p-payer-order-confirmation .input-wrapper','margin-bottom','10','','','.p-payer-order-confirmation'),(911139,'watch','.p-payer-order-confirmation .dob-hide','margin-bottom','-10','','','.p-payer-order-confirmation'),(911140,'watch','.p-payer-order-pay .input-wrapper','margin-bottom','10','','','.p-payer-order-pay'),(911141,'watch','.p-payer-order-pay .dob-hide','margin-bottom','-10','','','.p-payer-order-pay'),(911142,'watch','.p-quick-order-index ul.token-input-list','margin-bottom','0','','','.p-quick-order-index'),(911143,'watch','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(911144,'watch','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(911145,'watch','.b-info .info li','margin-bottom','0','','','.b-info'),(911146,'watch','.b-info .info ul','margin-bottom','0','','','.b-info'),(911147,'watch','.w-checkout-shipping-address .genders-title','margin-bottom','5','','','.w-checkout-shipping-address'),(911148,'watch','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(911149,'watch','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(911150,'watch','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(911151,'watch','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(911152,'watch','.p-sample-checkout-index .buttons','margin-bottom','20','','','.p-sample-checkout-index'),(911153,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(911154,'watch','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','margin-bottom','20','','','.w-upload-customer-id-upload-customer-id-form'),(911155,'watch','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(911156,'watch','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(911157,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-top-location-list'),(911158,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(911159,'watch','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(911160,'watch','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(911161,'watch','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(911162,'watch','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(911163,'watch','.w-filters .filter-box-head','margin-bottom','15','','','.w-filters'),(911164,'watch','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(911165,'watch','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(911166,'watch','.w-menu-horizontal li','margin-bottom','0','','','.w-menu-horizontal'),(911167,'watch','.w-menu-horizontal ul','margin-bottom','0','','','.w-menu-horizontal'),(911168,'watch','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(911169,'watch','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(911170,'watch','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(911171,'watch','.b-delete-account .delete-box > div','margin-bottom','10','','','.b-delete-account'),(911172,'watch','.w-info-content p','margin-bottom','10','','','.w-info-content'),(911173,'watch','.w-filters .input-checkbox','margin-bottom','0','','','.w-filters'),(911174,'watch','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(911175,'watch','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(911176,'watch','.b-form .newsletter-row','margin-bottom','10','','','.b-form'),(911177,'watch','.w-cart-give-away .ga_attributes > div','margin-bottom','1','','','.w-cart-give-away'),(911178,'watch','.w-cart-checkout-btn + .w-image','margin-bottom','-25','','','.w-cart-checkout-btn'),(911179,'watch','.b-info .info li','margin-bottom','0','','','.b-info'),(911180,'watch','.w-product-configurator .pc_row','margin-bottom','20','','','.w-product-configurator'),(911181,'watch','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(911182,'watch','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(911183,'watch','.heading-6, h6, .h-block h6','margin-bottom','5','','',''),(911184,'watch','.pop-up-content .buttons .left-buttons','margin-bottom','15','5240','',''),(911185,'watch','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(911186,'watch','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(911187,'watch','.w-communication-post .text-container','margin-bottom','20','','','.w-communication-post'),(911188,'watch','.w-product-in-bundles .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(911189,'watch','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(911190,'watch','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(911191,'watch','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(911192,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(911193,'watch','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(911194,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(911195,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(911196,'watch','.w-delivery-location-top-location-list','margin-bottom','25','','','.w-delivery-location-top-location-list'),(911197,'watch','.b-info .info ul','margin-bottom','0','','','.b-info'),(911198,'watch','.w-product-configurator .pc_row','margin-bottom','20','','','.w-product-configurator'),(911199,'watch','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(911200,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-bottom','0','','','.b-select-suggest'),(911201,'watch','.b-form .password-forgotten-link','margin-bottom','0','','','.b-form'),(911202,'watch','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(911203,'watch','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(911204,'watch','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(911205,'watch','.w-socials > li','margin-bottom','10','','','.w-socials'),(911207,'watch','.b-delete-account .delete-box span','margin-bottom','0','','','.b-delete-account'),(911208,'watch','.w-socials > li','margin-bottom','10','','','.w-socials'),(911209,'watch','.p-sample-checkout-index .buttons','margin-bottom','20','','','.p-sample-checkout-index'),(911210,'watch','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(911211,'watch','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(911212,'watch','.w-image-maps .default-links .item .title','margin-bottom','10','','','.w-image-maps'),(911213,'watch','.w-reviews .heading-3','margin-bottom','10','','','.w-reviews'),(911214,'watch','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(911215,'watch','.w-socials > li','margin-bottom','10','','','.w-socials'),(911216,'watch','.b-info .info li','margin-bottom','0','','','.b-info'),(911217,'watch','.w-checkout-shipping-address .addresses .address-item','margin-bottom','10','','','.w-checkout-shipping-address'),(911218,'watch','.w-checkout-billing-address .same-address','margin-bottom','10','','','.w-checkout-billing-address'),(911219,'watch','.b-form .required-message-wrap','margin-bottom','0','','','.b-form'),(911220,'watch','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(911221,'watch','.w-tabs .tab-li.tab-wishlist a','margin-bottom','7','3','','.w-tabs'),(911222,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(911223,'watch','.w-product-attributes .select-box:nth-child(2n+1)','margin-bottom','20','','','.w-product-attributes'),(911224,'watch','.w-product-bundle .bundle_item','margin-bottom','0','','','.w-product-bundle'),(911225,'watch','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(911226,'watch','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(911227,'watch','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(911228,'watch','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(911229,'watch','.w-tabs > .block','margin-bottom','20','','','.w-tabs'),(911230,'watch','.w-cart-cart-tabs .w-tabs .tab-navigation','margin-bottom','25','','','.w-cart-cart-tabs'),(911231,'watch','.w-tabs .tab-li','margin-bottom','0','','','.w-tabs'),(911232,'watch','.w-socials > li','margin-bottom','10','','','.w-socials'),(911233,'watch','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(911234,'watch','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(911236,'watch','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(911237,'watch','.w-tabs .tab-li.tab-sample a','margin-bottom','7','3','','.w-tabs'),(911238,'watch','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(911239,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-top-location-list'),(911240,'watch','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(911241,'watch','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(911242,'watch','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(911243,'watch','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(911244,'watch','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(911245,'watch','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(911246,'watch','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(911247,'watch','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(911248,'watch','.w-product-bundle .bundle_item','margin-bottom','0','','','.w-product-bundle'),(911249,'watch','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(911250,'watch','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(911251,'watch','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(911252,'watch','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(911253,'watch','.heading-5, h5, .h-block h5','margin-bottom','5','','',''),(911254,'watch','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(911255,'watch','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(911256,'watch','.w-filters .filter-ul-content','margin-bottom','0','','','.w-filters'),(911257,'watch','.heading-4, h4, .h-block h4','margin-bottom','5','','',''),(911258,'watch','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(911259,'watch','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(911260,'watch','.b-info .info ul','margin-bottom','0','','','.b-info'),(911261,'watch','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','margin-bottom','10','','','.b-form'),(911262,'watch','.order-summary .price-box','margin-bottom','10','','','.order-summary'),(911263,'watch','.b-form .addresses .address-item input[type=\"radio\"]','margin-bottom','0','','','.b-form'),(911264,'watch','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(911265,'watch','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(911266,'watch','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(911267,'watch','.w-image-maps .categories-items .item .title','margin-bottom','10','','','.w-image-maps'),(911268,'watch','.b-select-suggest .select2-drop-mask','margin-bottom','0','','','.b-select-suggest'),(911269,'watch','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(911270,'watch','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(911271,'watch','.w-top-categories .categories','margin-bottom','0','5245','','.w-top-categories'),(911272,'watch','.p-sample-checkout-index .buttons','margin-bottom','20','','','.p-sample-checkout-index'),(911273,'watch','.p-sample-checkout-index .price-box','margin-bottom','20','','','.p-sample-checkout-index'),(911274,'watch','.products-quick-index ul','margin-bottom','0','','',''),(911275,'watch','.w-checkout-gdpr .col-left','margin-bottom','20','5240','','.w-checkout-gdpr'),(911276,'watch','.w-product-in-bundles .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(911277,'watch','.w-top-categories .categories h2','margin-bottom','0','','','.w-top-categories'),(911278,'watch','.w-product-reviews .reviews-list .name','margin-bottom','20','','','.w-product-reviews'),(911279,'watch','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(911280,'watch','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(911281,'watch','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(911282,'watch','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(911283,'watch','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(911284,'watch','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(911285,'watch','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(911286,'watch','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(911287,'watch','.w-product-configurator .pc_row','margin-bottom','20','','','.w-product-configurator'),(911288,'watch','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(911289,'watch','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(911290,'watch','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(911291,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(911292,'watch','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(911293,'watch','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(911294,'watch','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(911295,'watch','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(911296,'watch','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(911297,'watch','.b-form .required-message','margin-bottom','0','','','.b-form'),(911298,'watch','.w-socials .post_item_img','margin-bottom','0','','','.w-socials'),(911299,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(911300,'watch','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(911301,'watch','.w-product-quantity .qty_packs .price_1','margin-bottom','0','4','','.w-product-quantity'),(911302,'watch','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(911303,'watch','.w-reviews .reviews-list','margin-bottom','20','','','.w-reviews'),(911304,'watch','.b-select-suggest .select2-container','margin-bottom','0','','','.b-select-suggest'),(911305,'watch','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(911306,'watch','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(911307,'watch','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(911308,'watch','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(911309,'watch','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(911310,'watch','.w-breadcrumb .breadcrumb-li','margin-bottom','0','','','.w-breadcrumb'),(911311,'watch','.w-checkout-create-account .heading-2','margin-bottom','0','','','.w-checkout-create-account'),(911312,'watch','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(911313,'watch','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(911314,'watch','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(911315,'watch','.w-product-bundle .bundle_item + .bundle_item','margin-bottom','0','','','.w-product-bundle'),(911316,'watch','.w-product-bundle .bundle_item','margin-bottom','0','','','.w-product-bundle'),(911317,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(911318,'watch','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(911319,'watch','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(911320,'watch','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(911321,'watch','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(911322,'watch','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(911323,'watch','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(911324,'watch','.b-form .col-full-padding','margin-bottom','10','','','.b-form'),(911325,'watch','.b-info .info li','margin-bottom','0','','','.b-info'),(911326,'watch','.b-info .info ul','margin-bottom','0','','','.b-info'),(911327,'watch','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(911328,'watch','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(911329,'watch','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','margin-bottom','15','','','.b-form'),(911330,'watch','.heading-3, h3, .h-block h3','margin-bottom','10','','',''),(911331,'watch','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(911332,'watch','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(911333,'watch','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(911334,'watch','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(911335,'watch','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(911336,'watch','.w-product-in-bundles .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(911337,'watch','.w-product-bundle .bundle_item','margin-bottom','0','','','.w-product-bundle'),(911338,'watch','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(911339,'watch','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(911340,'watch','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(911341,'watch','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(911342,'watch','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(911343,'watch','.b-form .form-inputs label > span','margin-bottom','1','','','.b-form'),(911344,'watch','.b-autocomplete .ui-autocomplete','margin-bottom','0','','','.b-autocomplete'),(911345,'watch','.b-bottom .cart-options .js-carts','margin-bottom','20','','','.b-bottom'),(911346,'watch','.b-bottom .cart-options .option-item','margin-bottom','5','','','.b-bottom'),(911347,'watch','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(911348,'watch','.b-bottom .cart-options .cart-item','margin-bottom','5','','','.b-bottom'),(911349,'watch','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(911350,'watch','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(911351,'watch','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(911352,'watch','.w-delivery-location-top-location-list .deliveryList','margin-bottom','0','','','.w-delivery-location-top-location-list'),(911353,'watch','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(911354,'watch','.b-select-suggest .select2-results .select2-result-label','margin-bottom','0','','','.b-select-suggest'),(911355,'watch','.w-breadcrumb .breadcrumb-li','margin-bottom','0','','','.w-breadcrumb'),(911356,'watch','.w-delivery-location-top-location-list .deliveryList','margin-bottom','0','','','.w-delivery-location-top-location-list'),(911357,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(911358,'watch','.w-delivery-location-top-location-list','margin-bottom','25','','','.w-delivery-location-top-location-list'),(911359,'watch','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(911360,'watch','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(911361,'watch','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(911362,'watch','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(911363,'watch','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(911364,'watch','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(911365,'watch','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(911366,'watch','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(911367,'watch','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(911368,'watch','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(911369,'watch','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(911370,'watch','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(911371,'watch','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(911372,'watch','.w-menu-big li','margin-bottom','0','','','.w-menu-big'),(911373,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(911374,'watch','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(911375,'watch','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(911376,'watch','.w-product-configurator .pc_row','margin-bottom','20','','','.w-product-configurator'),(911377,'watch','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(911378,'watch','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(911379,'watch','.b-fancybox .fancybox-error','margin-bottom','0','','','.b-fancybox'),(911380,'watch','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(911381,'watch','.w-cart-compare .product .image','margin-bottom','10','','','.w-cart-compare'),(911382,'watch','.p-sample-checkout-index .price-box','margin-bottom','20','','','.p-sample-checkout-index'),(911383,'watch','.w-checkout-billing-address .addresses .address-item','margin-bottom','10','','','.w-checkout-billing-address'),(911384,'watch','.b-bottom .confirm-popup .buttons .btn','margin-bottom','0','','','.b-bottom'),(911385,'watch','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-bottom','0','','','.b-switch'),(911386,'watch','.w-reviews-content .reviews-list','margin-bottom','20','','','.w-reviews-content'),(911387,'watch','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(911388,'watch','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(911389,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(911390,'watch','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(911391,'watch','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(911392,'watch','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(911393,'watch','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(911394,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-top-location-list'),(911395,'watch','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(911396,'watch','.b-form #shipping-address .radio-buttons','margin-bottom','10','','','.b-form'),(911397,'watch','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(911398,'watch','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(911399,'watch','.w-tabs .tab-navigation','margin-bottom','0','','','.w-tabs'),(911400,'watch','.b-info .info ul','margin-bottom','0','','','.b-info'),(911401,'watch','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(911402,'watch','.w-social-links a','margin-bottom','0','','','.w-social-links'),(911403,'watch','.p-sample-checkout-index .price-box','margin-bottom','20','','','.p-sample-checkout-index'),(911404,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-bottom','1','','','.b-select-suggest'),(911405,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-bottom','0','','','.b-select-suggest'),(911406,'watch','.b-select-suggest .select2-container-multi .select2-choices','margin-bottom','0','','','.b-select-suggest'),(911407,'watch','.w-info-content p','margin-bottom','10','','','.w-info-content'),(911408,'watch','.b-select-suggest .select2-results ul.select2-result-sub','margin-bottom','0','','','.b-select-suggest'),(911409,'watch','.b-select-suggest .select2-search input','margin-bottom','0','','','.b-select-suggest'),(911410,'watch','.b-select-suggest .select2-search','margin-bottom','0','','','.b-select-suggest'),(911411,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-top-location-list'),(911412,'watch','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(911413,'watch','.w-product-attributes .select-box:nth-child(2n+1)','margin-bottom','20','','','.w-product-attributes'),(911414,'watch','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(911415,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-top-location-list'),(911416,'watch','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(911417,'watch','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(911418,'watch','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(911419,'watch','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(911420,'watch','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(911421,'watch','.p-sample-checkout-index .buttons','margin-bottom','20','','','.p-sample-checkout-index'),(911422,'watch','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(911423,'watch','.order-summary .btn-2, .order-summary .btn-3','margin-bottom','15','','','.order-summary'),(911424,'watch','.w-product-attributes .select-box:nth-child(2n+1)','margin-bottom','20','','','.w-product-attributes'),(911425,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(911426,'watch','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(911427,'watch','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(911428,'watch','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(911429,'watch','.w-product-in-bundles .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(911430,'watch','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(911431,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(911432,'watch','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(911433,'watch','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(911434,'watch','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(911435,'watch','.b-bottom .content-item','margin-bottom','20','','','.b-bottom'),(911436,'watch','.b-form .middle-form .checkbox-holder','margin-bottom','15','','','.b-form'),(911437,'watch','.w-communication-new-topic .privacy-row','margin-bottom','10','','','.w-communication-new-topic'),(911438,'watch','.w-communication-post .communication-post-message','margin-bottom','20','','','.w-communication-post'),(911439,'watch','.w-communication-post .communication-post','margin-bottom','5','','','.w-communication-post'),(911440,'watch','.b-products-listing .products-listing .name','margin-bottom','5','','','.b-products-listing'),(911441,'watch','.b-products-listing .products-listing .model','margin-bottom','5','','','.b-products-listing'),(911442,'watch','.b-products-listing .products-listing .description','margin-bottom','5','','','.b-products-listing'),(911443,'watch','.b-products-listing .products-listing .bonusPoints','margin-bottom','7','','','.b-products-listing'),(911444,'watch','.b-products-listing .products-listing .description ul','margin-bottom','0','','','.b-products-listing'),(911445,'watch','.b-products-listing .products-listing .mult-qty-input','margin-bottom','3','','','.b-products-listing'),(911446,'watch','.b-products-listing .products-listing h2','margin-bottom','0','','','.b-products-listing'),(911447,'watch','.b-products-listing .promos-info','margin-bottom','-30','','','.b-products-listing'),(911448,'watch','.b-products-listing .wedding-registry-count','margin-bottom','10','','','.b-products-listing'),(911449,'watch','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(911450,'watch','.w-info-content p','margin-bottom','10','','','.w-info-content'),(911451,'watch','.w-checkout-gdpr .privacy-row','margin-bottom','0','','','.w-checkout-gdpr'),(911452,'watch','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(911453,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(911454,'watch','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(911455,'watch','.b-fancybox .fancybox-title-float-wrap','margin-bottom','-35','','','.b-fancybox'),(911456,'watch','.w-socials > li','margin-bottom','10','','','.w-socials'),(911457,'watch','.w-product-reviews .reviews-list','margin-bottom','10','','','.w-product-reviews'),(911458,'watch','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(911459,'watch','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(911460,'watch','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(911461,'watch','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(911462,'watch','.w-product-attributes .select-box:nth-child(2n+1)','margin-bottom','20','','','.w-product-attributes'),(911463,'watch','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(911464,'watch','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(911465,'watch','.w-info-content p','margin-bottom','10','','','.w-info-content'),(911466,'watch','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(911467,'watch','.w-delivery-location-top-location-list .deliveryList','margin-bottom','0','','','.w-delivery-location-top-location-list'),(911468,'watch','.w-breadcrumb .breadcrumb-li','margin-bottom','0','','','.w-breadcrumb'),(911469,'watch','.p-sample-checkout-index .price-box','margin-bottom','20','','','.p-sample-checkout-index'),(911470,'watch','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(911471,'watch','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(911472,'watch','.w-taxable label','margin-bottom','0','','','.w-taxable'),(911473,'watch','.w-taxable select','margin-bottom','0','','','.w-taxable'),(911474,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-bottom','0','','',''),(911475,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-bottom','0','','','.b-h-inline'),(911476,'watch','h1, .heading-1','margin-bottom','18','','',''),(911477,'watch','.w-communication-new-topic #rmaProductReturnButtonFilterHolder','margin-bottom','30','','','.w-communication-new-topic'),(911478,'watch','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(911479,'watch','.w-checkout-shipping-address #shippingchoice-choice','margin-bottom','10','','','.w-checkout-shipping-address'),(911480,'watch','.b-info .info li','margin-bottom','0','','','.b-info'),(911481,'watch','.w-product-reviews .write-review-button','margin-bottom','20','','','.w-product-reviews'),(911482,'watch','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(911483,'watch','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(911484,'watch','.w-product-bundle .bundle_item','margin-bottom','0','','','.w-product-bundle'),(911485,'watch','.w-tabs .tab-li.tab-quote a','margin-bottom','7','3','','.w-tabs'),(911486,'watch','.w-delivery-location-top-location-list','margin-bottom','25','','','.w-delivery-location-top-location-list'),(911487,'watch','.b-form .checkbox-style','margin-bottom','0','','','.b-form'),(911488,'watch','.b-info .info ul','margin-bottom','0','','','.b-info'),(911489,'watch','.products-quick-index .token-input-list','margin-bottom','0','','',''),(911490,'watch','.products-quick-index ul.token-input-list','margin-bottom','0','','',''),(911491,'watch','.w-cart-checkout-btn .or-text','margin-bottom','5','','','.w-cart-checkout-btn'),(911492,'watch','.b-compare .col-two','margin-bottom','15','','','.b-compare'),(911493,'watch','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(911494,'watch','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(911495,'watch','.w-cart-listing .item','margin-bottom','10','5240','','.w-cart-listing'),(911496,'watch','.w-cart-give-away .ga_wrapper','margin-bottom','25','','','.w-cart-give-away'),(911497,'watch','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(911498,'watch','.w-breadcrumb .breadcrumb-li','margin-bottom','0','','','.w-breadcrumb'),(911499,'watch','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(911501,'watch','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(911502,'watch','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(911503,'watch','.w-breadcrumb .breadcrumb-li','margin-bottom','0','','','.w-breadcrumb'),(911504,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(911505,'watch','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(911506,'watch','.w-image-maps .float-items .item .title','margin-bottom','10','','','.w-image-maps'),(911507,'watch','.w-info-content p','margin-bottom','10','','','.w-info-content'),(911508,'watch','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-bottom','0','','','.b-fancybox'),(911509,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(911510,'watch','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(911511,'watch','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(911512,'watch','.w-product-configurator .pc_row','margin-bottom','20','','','.w-product-configurator'),(911513,'watch','.w-product-bundle .bundle_item','margin-bottom','0','','','.w-product-bundle'),(911514,'watch','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(911515,'watch','.w-product-attributes .select-box:nth-child(2n+1)','margin-bottom','20','','','.w-product-attributes'),(911516,'watch','.w-filters .ui-slider','margin-bottom','0','','','.w-filters'),(911517,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(911518,'watch','.w-cart-sub-total','margin-bottom','20','','','.w-cart-sub-total'),(911519,'watch','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(911520,'watch','.w-breadcrumb .breadcrumb-li','margin-bottom','0','','','.w-breadcrumb'),(911521,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(911522,'watch','.p-sample-checkout-index .price-box','margin-bottom','20','','','.p-sample-checkout-index'),(911523,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-top-location-list'),(911524,'watch','.w-catalog-sorting select','margin-bottom','0','','','.w-catalog-sorting'),(911525,'watch','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(911526,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(911527,'watch','.b-info .info li','margin-bottom','0','','','.b-info'),(911528,'watch','.b-form .radio-buttons','margin-bottom','10','','','.b-form'),(911529,'watch','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(911530,'watch','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(911531,'watch','.w-product-attributes .select-box:nth-child(2n+1)','margin-bottom','20','','','.w-product-attributes'),(911532,'watch','.heading-2, h2, .h-block h2','margin-bottom','10','','',''),(911533,'watch','.w-product-configurator .pc_row','margin-bottom','20','','','.w-product-configurator'),(911534,'watch','.w-product-in-bundles .bundle_item + .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(911535,'watch','.w-product-in-bundles .bundle_item','margin-bottom','0','','','.w-product-in-bundles'),(911536,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(911537,'watch','.b-upload-files .upload-files','margin-bottom','20','','','.b-upload-files'),(911538,'watch','.w-communication-new-topic .text-container','margin-bottom','20','','','.w-communication-new-topic'),(911539,'watch','.b-form .addresses','margin-bottom','20','','','.b-form'),(911540,'watch','.w-delivery-location-top-location-list','margin-bottom','25','','','.w-delivery-location-top-location-list'),(911541,'watch','.w-delivery-location-top-location-list .deliveryList','margin-bottom','0','','','.w-delivery-location-top-location-list'),(911542,'watch','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(911543,'watch','.w-menu-big ul','margin-bottom','0','','','.w-menu-big'),(911544,'watch','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(911545,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(911546,'watch','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(911547,'watch','.b-product-images .media-popup .slick-dots','margin-bottom','0','','','.b-product-images'),(911548,'watch','.b-product-images .media-popup .slick-dots li','margin-bottom','0','','','.b-product-images'),(911549,'watch','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-bottom','0','','','.b-menu-style'),(911550,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li > a','margin-bottom','5','','','.b-menu-style-1'),(911551,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages','margin-bottom','10','','','.b-menu-style-2'),(911552,'watch','.b-personal-catalog-popup #personal_catalog_popup .lists-message-box','margin-bottom','20','','','.b-personal-catalog-popup'),(911553,'watch','.b-trade-approval .steps-bar','margin-bottom','25','','','.b-trade-approval'),(911554,'watch','.b-trade-approval .middle-form textarea','margin-bottom','15','','','.b-trade-approval'),(911555,'watch','.w-account-personal-catalog .list-switcher','margin-bottom','20','','','.w-account-personal-catalog'),(911556,'watch','.w-account-subscription .send-email','margin-bottom','20','','','.w-account-subscription'),(911557,'watch','.w-account-subscription .subscription-list','margin-bottom','20','','','.w-account-subscription'),(911558,'watch','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-bottom','0','','','.w-catalog-additional-images'),(911559,'watch','.w-catalog-compare .cross-box .return','margin-bottom','30','','','.w-catalog-compare'),(911560,'watch','.w-delivery-day .time-left','margin-bottom','30','','','.w-delivery-day'),(911561,'watch','.w-delivery-day .ends','margin-bottom','20','','','.w-delivery-day'),(911562,'watch','.w-filters .filter-box-content ul li','margin-bottom','10','','','.w-filters'),(911563,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-bottom','0','','','.w-filters'),(911564,'watch','.order-summary ','margin-bottom','20','','','.order-summary'),(911565,'watch','.w-cart-discount-coupon .discount-box','margin-bottom','10','','','.w-cart-discount-coupon'),(911566,'watch','.w-cart-discount-coupon .title','margin-bottom','0','','','.w-cart-discount-coupon'),(911582,'watch','.account-password-wrap .buttonedit','margin-bottom','0','','','.account-password-wrap'),(911583,'watch','.account-password-wrap .buttons','margin-bottom','20','','','.account-password-wrap'),(911584,'watch','.catalog-product-wrap .pn-direction','margin-bottom','15','','','.catalog-product-wrap'),(911585,'watch','.checkout-index-wrap .closeable-heading .heading-2','margin-bottom','0','','','.checkout-index-wrap'),(911586,'watch','.checkout-index-wrap .dob-hide','margin-bottom','-10','','','.checkout-index-wrap'),(911587,'watch','.checkout-index-wrap .edit-address-popup .addresses .address-item','margin-bottom','20','','','.checkout-index-wrap'),(911588,'watch','.checkout-index-wrap .input-wrapper','margin-bottom','10','','','.checkout-index-wrap'),(911589,'watch','.shopping-cart-index .closeable-heading .heading-2','margin-bottom','0','','','.shopping-cart-index'),(911590,'watch','.account-order-pay .buttons','margin-bottom','20','','','.account-order-pay'),(911591,'watch','.account-order-pay .history_info','margin-bottom','20','','','.account-order-pay'),(911592,'watch','.account-order-pay .history_info > div','margin-bottom','12','5240','','.account-order-pay'),(911593,'watch','.account-samples .buttonBox','margin-bottom','15','','','.account-samples'),(911594,'watch','.account-samples .order_history_table h2','margin-bottom','8','','','.account-samples'),(911595,'watch','.account-samples .orders-table .item','margin-bottom','10','5240','','.account-samples'),(911596,'watch','.account-sample-info .buttons','margin-bottom','20','','','.account-sample-info'),(911597,'watch','.account-sample-info .history_info','margin-bottom','20','','','.account-sample-info'),(911598,'watch','.account-sample-info .history_info > div','margin-bottom','12','5240','','.account-sample-info'),(911599,'watch','.b-form .columns','margin-bottom','10','','','.b-form'),(911600,'watch','.b-slick .slick-dots li','margin-bottom','0','','','.b-slick'),(911601,'watch','.success-page .order_totals','margin-bottom','30','','','.success-page'),(911602,'watch','.success-page .page-success .text-1','margin-bottom','0','3','','.success-page'),(911603,'watch','.success-page .w-order-products','margin-bottom','20','','','.success-page'),(911604,'watch','.b-multi-page-checkout .multi-page-checkout .buttons','margin-bottom','0','','','.b-multi-page-checkout'),(911605,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-step','margin-bottom','5','','','.b-multi-page-checkout'),(911609,'watch','.w-bestsellers .heading-3','margin-bottom','10','','','.w-bestsellers'),(911610,'watch','.w-bestsellers .item','margin-bottom','12','','','.w-bestsellers'),(911611,'watch','.payment-method-tf label','margin-bottom','10','','','.payment-method-tf'),(911612,'watch','.accout-box ','margin-bottom','30','','','.accout-box'),(911613,'watch','.accout-box select[data-type=\"vat_number\"]','margin-bottom','0','','','.accout-box'),(911614,'watch','.w-account-customer-additional-field .field-type-checkbox','margin-bottom','10','','','.w-account-customer-additional-field'),(911615,'watch','.w-account-customer-additional-field .field-type-text','margin-bottom','10','','','.w-account-customer-additional-field'),(911616,'watch','.w-menu-style-1 li','margin-bottom','0','','','.w-menu-style-1'),(911617,'watch','.w-menu-style-1 ul','margin-bottom','0','','','.w-menu-style-1'),(911618,'watch','.b-slick .slick-list','margin-bottom','0','','','.b-slick'),(911619,'watch','.heading-4 .edit, h4 .edit','margin-left','10','4','',''),(911620,'watch','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(911621,'watch','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(911622,'watch','.message.success','margin-left','-40','3','',''),(911623,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(911624,'watch','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(911626,'watch','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(911627,'watch','.w-catalog-items-on-page select','margin-left','10','','','.w-catalog-items-on-page'),(911628,'watch','.w-chat .w-chat-box','margin-left','5','','','.w-chat'),(911629,'watch','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-left','0','','','.b-fancybox'),(911630,'watch','.p-quick-order-index ul.token-input-list','margin-left','5','','','.p-quick-order-index'),(911631,'watch','.p-quick-order-index .filters .clear','margin-left','15','','','.p-quick-order-index'),(911632,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','margin-left','5','','','.p-quick-order-index'),(911633,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.p-quick-order-index'),(911634,'watch','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(911638,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(911639,'watch','.w-delivery-location-top-location-list','margin-left','0','','','.w-delivery-location-top-location-list'),(911640,'watch','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(911641,'watch','.w-delivery-location-top-location-list .deliveryList','margin-left','-1','','','.w-delivery-location-top-location-list'),(911642,'watch','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(911643,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(911644,'watch','.w-promotions .promo-salemaker .item','margin-left','2','','','.w-promotions'),(911645,'watch','.w-promotions .promo-cart-discount .slave .item','margin-left','2','','','.w-promotions'),(911646,'watch','.w-promotions .promo-cart-discount .master .item','margin-left','12','','','.w-promotions'),(911647,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','-17','3','','.b-warehouses-popup'),(911648,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','0','','','.b-warehouses-popup'),(911650,'watch','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(911651,'watch','.b-form .password-forgotten-link','margin-left','0','','','.b-form'),(911652,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(911653,'watch','.b-messages .messages-menu ul','margin-left','0','','','.b-messages'),(911654,'watch','.b-messages .msv_content','margin-left','0','','','.b-messages'),(911655,'watch','.b-messages .msv_history','margin-left','0','','','.b-messages'),(911656,'watch','.b-messages .messages-menu li','margin-left','0','','','.b-messages'),(911657,'watch','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(911658,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-left','5','','','.b-messages'),(911659,'watch','.w-sitemap-delivery-location > ul > li > ul','margin-left','0','','','.w-sitemap-delivery-location'),(911660,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-left','0','','','.w-delivery-location-top-location-list'),(911661,'watch','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(911662,'watch','.w-sitemap-delivery-location > ul','margin-left','0','','','.w-sitemap-delivery-location'),(911663,'watch','.b-fancybox #fancybox-loading','margin-left','-22','','','.b-fancybox'),(911664,'watch','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(911665,'watch','.b-quantity .qty-box input','margin-left','3','','','.b-quantity'),(911666,'watch','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(911667,'watch','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(911668,'watch','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(911669,'watch','.b-info .info','margin-left','-40','3','','.b-info'),(911670,'watch','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(911671,'watch','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(911672,'watch','.w-coupons-and-vauchers-checkout .btn-remove','margin-left','-30','','','.w-coupons-and-vauchers-checkout'),(911673,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-left','0','','','.w-delivery-location-top-location-list'),(911674,'watch','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(911675,'watch','.w-menu-horizontal li','margin-left','0','','','.w-menu-horizontal'),(911676,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(911677,'watch','.w-filters .input-checkbox','margin-left','0','','','.w-filters'),(911678,'watch','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(911679,'watch','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(911680,'watch','.b-info .info ul','margin-left','0','','','.b-info'),(911681,'watch','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(911682,'watch','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(911683,'watch','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(911684,'watch','.w-delivery-location-top-location-list','margin-left','0','','','.w-delivery-location-top-location-list'),(911685,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(911686,'watch','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','margin-left','7','3','','.order-summary'),(911687,'watch','.buttons .right-buttons .btn','margin-left','10','','',''),(911688,'watch','.w-product-bundle .bundle_item','margin-left','0','','','.w-product-bundle'),(911689,'watch','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(911690,'watch','.w-cart-gift-certificate .gift-code button','margin-left','15','','','.w-cart-gift-certificate'),(911691,'watch','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(911692,'watch','.w-top-categories .categories','margin-left','0','5232','','.w-top-categories'),(911693,'watch','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(911694,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-left','0','','','.w-delivery-location-top-location-list'),(911695,'watch','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(911696,'watch','.w-cart-checkout-btn + .w-image','margin-left','-25','','','.w-cart-checkout-btn'),(911697,'watch','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(911698,'watch','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(911699,'watch','.b-form .col-3 + .col-3','margin-left','3','','','.b-form'),(911700,'watch','.b-info .info','margin-left','-40','3','','.b-info'),(911701,'watch','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(911702,'watch','.w-breadcrumb .breadcrumb-li','margin-left','0','','','.w-breadcrumb'),(911703,'watch','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(911704,'watch','.w-cart-gift-certificate .gift-code button','margin-left','15','','','.w-cart-gift-certificate'),(911705,'watch','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(911706,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(911707,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-left','0','','','.b-select-suggest'),(911708,'watch','.w-breadcrumb .breadcrumb-li','margin-left','0','','','.w-breadcrumb'),(911709,'watch','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(911710,'watch','.w-socials > li','margin-left','10','','','.w-socials'),(911712,'watch','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(911713,'watch','.b-delete-account .delete-box span','margin-left','10','','','.b-delete-account'),(911714,'watch','.b-quantity .qty-box input','margin-left','3','','','.b-quantity'),(911715,'watch','.w-socials > li','margin-left','10','','','.w-socials'),(911716,'watch','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(911717,'watch','.w-breadcrumb .breadcrumb-li','margin-left','0','','','.w-breadcrumb'),(911718,'watch','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(911719,'watch','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(911720,'watch','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(911721,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(911722,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-left','0','','','.w-delivery-location-top-location-list'),(911723,'watch','.w-catalog-listing-look .list','margin-left','5','','','.w-catalog-listing-look'),(911724,'watch','.view-all .btn','margin-left','10','4','',''),(911725,'watch','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(911726,'watch','.w-socials > li','margin-left','10','','','.w-socials'),(911727,'watch','.b-info .info li','margin-left','0','','','.b-info'),(911728,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(911729,'watch','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(911730,'watch','.w-product-bundle .bundle_item','margin-left','0','','','.w-product-bundle'),(911731,'watch','.w-tabs .tab-navigation','margin-left','0','','','.w-tabs'),(911732,'watch','.w-tabs .tab-li','margin-left','0','','','.w-tabs'),(911733,'watch','.w-socials > li','margin-left','10','','','.w-socials'),(911735,'watch','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(911736,'watch','.b-info .info','margin-left','-40','3','','.b-info'),(911737,'watch','.b-info .info li','margin-left','0','','','.b-info'),(911738,'watch','.b-info .info ul','margin-left','0','','','.b-info'),(911739,'watch','.b-quantity .qty-box input','margin-left','3','','','.b-quantity'),(911740,'watch','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(911741,'watch','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(911742,'watch','.w-cart-credit-amount .btn-remove','margin-left','-30','','','.w-cart-credit-amount'),(911743,'watch','.b-products-listing .products-listing .bonus-points-cost','margin-left','-20','3','','.b-products-listing'),(911744,'watch','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(911745,'watch','.w-product-bundle .bundle_item','margin-left','0','','','.w-product-bundle'),(911746,'watch','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(911747,'watch','.heading-3 .right-text, h3 .right-text','margin-left','10','','',''),(911748,'watch','.w-product-reviews .reviews-list','margin-left','0','','','.w-product-reviews'),(911749,'watch','.b-products-listing .products-listing .bonus-points-price','margin-left','-20','3','','.b-products-listing'),(911750,'watch','.w-filters .filter-ul-content','margin-left','0','','','.w-filters'),(911751,'watch','.heading-3 .edit, h3 .edit','margin-left','10','4','',''),(911752,'watch','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-shipping-address'),(911753,'watch','.b-info .info ul','margin-left','0','','','.b-info'),(911754,'watch','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(911755,'watch','.w-cart-listing .points-earn','margin-left','10','','','.w-cart-listing'),(911756,'watch','.b-select-suggest .select2-drop-mask','margin-left','0','','','.b-select-suggest'),(911757,'watch','.w-delivery-location-top-location-list .deliveryList','margin-left','-1','','','.w-delivery-location-top-location-list'),(911758,'watch','.w-checkout-shipping-choice input:checked + span:before','margin-left','-5','','','.w-checkout-shipping-choice'),(911759,'watch','.products-quick-index ul','margin-left','0','','',''),(911760,'watch','.w-product-in-bundles .bundle_item','margin-left','0','','','.w-product-in-bundles'),(911761,'watch','.w-top-categories .categories h2','margin-left','0','','','.w-top-categories'),(911762,'watch','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(911763,'watch','.b-form .checkbox-style','margin-left','0','','','.b-form'),(911764,'watch','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(911765,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(911766,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(911767,'watch','.b-form .addresses .address-item input[type=\"radio\"]','margin-left','0','','','.b-form'),(911768,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(911769,'watch','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(911770,'watch','.b-form .columns .col-2:nth-child(2n)','margin-left','0','5261','','.b-form'),(911771,'watch','.w-product-quantity .qty_packs .price_1','margin-left','15','4','','.w-product-quantity'),(911772,'watch','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(911773,'watch','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(911774,'watch','.b-quantity .qty-box input','margin-left','3','','','.b-quantity'),(911775,'watch','.b-select-suggest .select2-container','margin-left','0','','','.b-select-suggest'),(911776,'watch','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(911777,'watch','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(911778,'watch','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(911779,'watch','.w-breadcrumb .breadcrumb-li','margin-left','0','','','.w-breadcrumb'),(911780,'watch','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(911781,'watch','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(911782,'watch','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(911783,'watch','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(911784,'watch','.w-product-bundle .bundle_item','margin-left','0','','','.w-product-bundle'),(911785,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(911786,'watch','.w-product-bundle .bundle_item + .bundle_item','margin-left','2','','','.w-product-bundle'),(911787,'watch','.b-info .info','margin-left','-40','3','','.b-info'),(911788,'watch','.b-info .info ul','margin-left','0','','','.b-info'),(911789,'watch','.b-info .info li','margin-left','0','','','.b-info'),(911790,'watch','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(911791,'watch','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(911792,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(911793,'watch','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(911794,'watch','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(911795,'watch','.w-checkout-credit-amount .btn-remove','margin-left','-30','','','.w-checkout-credit-amount'),(911796,'watch','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(911797,'watch','.b-info .info','margin-left','-40','3','','.b-info'),(911798,'watch','.b-autocomplete .ui-autocomplete','margin-left','0','','','.b-autocomplete'),(911799,'watch','.w-top-categories .categories','margin-left','-10','5245','','.w-top-categories'),(911800,'watch','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(911801,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(911802,'watch','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(911803,'watch','.b-select-suggest .select2-results .select2-result-label','margin-left','0','','','.b-select-suggest'),(911804,'watch','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(911805,'watch','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(911806,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(911807,'watch','.w-product-in-bundles .bundle_item','margin-left','0','','','.w-product-in-bundles'),(911808,'watch','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-billing-address'),(911809,'watch','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(911810,'watch','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(911811,'watch','.w-product-in-bundles .bundle_item','margin-left','0','','','.w-product-in-bundles'),(911812,'watch','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(911813,'watch','.b-fancybox .fancybox-error','margin-left','0','','','.b-fancybox'),(911814,'watch','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(911815,'watch','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(911816,'watch','.w-cart-compare .product .image','margin-left','0','','','.w-cart-compare'),(911817,'watch','.b-info .info li','margin-left','0','','','.b-info'),(911818,'watch','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(911819,'watch','.b-bottom .confirm-popup .buttons .btn','margin-left','20','','','.b-bottom'),(911820,'watch','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(911821,'watch','.w-breadcrumb .breadcrumb-li','margin-left','0','','','.w-breadcrumb'),(911822,'watch','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-left','0','','','.b-switch'),(911823,'watch','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(911824,'watch','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(911825,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-left','0','','','.w-delivery-location-top-location-list'),(911826,'watch','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(911827,'watch','.w-product-in-bundles .bundle_item','margin-left','0','','','.w-product-in-bundles'),(911828,'watch','.w-product-bundle .bundle_item','margin-left','0','','','.w-product-bundle'),(911829,'watch','.w-cart-give-away .ga_attributes > div','margin-left','1','','','.w-cart-give-away'),(911830,'watch','.w-cart-checkout-btn .or-text','margin-left','0','','','.w-cart-checkout-btn'),(911831,'watch','.w-cart-gift-certificate .gift-code button','margin-left','15','','','.w-cart-gift-certificate'),(911832,'watch','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(911833,'watch','.w-cart-give-away .ga_column','margin-left','2','','','.w-cart-give-away'),(911834,'watch','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(911835,'watch','.w-social-links a','margin-left','5','','','.w-social-links'),(911836,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(911837,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-left','0','','','.b-select-suggest'),(911838,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-left','0','','','.b-select-suggest'),(911839,'watch','.b-select-suggest .select2-container-multi .select2-choices','margin-left','0','','','.b-select-suggest'),(911840,'watch','.b-select-suggest .select2-results ul.select2-result-sub','margin-left','0','','','.b-select-suggest'),(911841,'watch','.b-select-suggest .select2-search input','margin-left','0','','','.b-select-suggest'),(911842,'watch','.b-select-suggest .select2-search','margin-left','0','','','.b-select-suggest'),(911843,'watch','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(911844,'watch','.w-product-in-bundles .bundle_item','margin-left','0','','','.w-product-in-bundles'),(911845,'watch','.w-socials > li','margin-left','10','','','.w-socials'),(911846,'watch','.w-delivery-location-top-location-list .deliveryList','margin-left','-1','','','.w-delivery-location-top-location-list'),(911847,'watch','.w-delivery-location-top-location-list','margin-left','0','','','.w-delivery-location-top-location-list'),(911848,'watch','.w-menu-horizontal ul','margin-left','0','','','.w-menu-horizontal'),(911849,'watch','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(911850,'watch','.b-quantity .qty-box input','margin-left','3','','','.b-quantity'),(911851,'watch','.b-quantity .qty-box input','margin-left','3','','','.b-quantity'),(911852,'watch','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(911853,'watch','.w-delivery-location-top-location-list','margin-left','0','','','.w-delivery-location-top-location-list'),(911854,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.b-data-table'),(911855,'watch','.w-catalog-b2b-add-button .add-b2b-products','margin-left','50','','','.w-catalog-b2b-add-button'),(911856,'watch','.b-products-listing .products-listing .description ul','margin-left','0','','','.b-products-listing'),(911857,'watch','.b-products-listing .products-listing h2','margin-left','0','','','.b-products-listing'),(911858,'watch','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(911859,'watch','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(911860,'watch','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(911861,'watch','.w-checkout-gdpr .privacy-row','margin-left','0','','','.w-checkout-gdpr'),(911862,'watch','.w-checkout-gdpr .bootstrap-switch','margin-left','25','','','.w-checkout-gdpr'),(911863,'watch','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(911864,'watch','.w-delivery-location-top-location-list .deliveryList','margin-left','-1','','','.w-delivery-location-top-location-list'),(911865,'watch','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(911866,'watch','.b-info .info','margin-left','-40','3','','.b-info'),(911867,'watch','.b-info .info li','margin-left','0','','','.b-info'),(911868,'watch','.w-socials > li','margin-left','10','','','.w-socials'),(911869,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(911870,'watch','.w-delivery-location-top-location-list','margin-left','0','','','.w-delivery-location-top-location-list'),(911871,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(911872,'watch','.w-taxable label','margin-left','5','','','.w-taxable'),(911873,'watch','.w-taxable select','margin-left','5','','','.w-taxable'),(911874,'watch','.heading-4 .right-text, h4 .right-text','margin-left','10','','',''),(911875,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-left','0','','',''),(911876,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-left','0','','','.b-h-inline'),(911877,'watch','.b-info .info ul','margin-left','0','','','.b-info'),(911878,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(911879,'watch','.products-quick-index ul.token-input-list','margin-left','0','','',''),(911880,'watch','.b-form .required-message','margin-left','0','','','.b-form'),(911881,'watch','.b-info .info li','margin-left','0','','','.b-info'),(911882,'watch','.w-catalog-listing-look .b2b','margin-left','5','','','.w-catalog-listing-look'),(911883,'watch','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(911884,'watch','.w-cart-sub-total','margin-left','0','','','.w-cart-sub-total'),(911885,'watch','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(911886,'watch','.w-cart-listing .points-earn','margin-left','-25','3','','.w-cart-listing'),(911887,'watch','.w-cart-listing .points-redeem','margin-left','-25','3','','.w-cart-listing'),(911888,'watch','.w-cart-listing .remove-btn','margin-left','0','5240','','.w-cart-listing'),(911889,'watch','.w-cart-gift-certificate .gift-code button','margin-left','15','','','.w-cart-gift-certificate'),(911890,'watch','.w-cart-give-away .ga_column','margin-left','0','5232','','.w-cart-give-away'),(911891,'watch','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(911892,'watch','.w-cart-discount-coupon .btn-remove','margin-left','-30','','','.w-cart-discount-coupon'),(911893,'watch','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(911894,'watch','.w-breadcrumb .breadcrumb-li','margin-left','0','','','.w-breadcrumb'),(911895,'watch','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(911897,'watch','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-left','0','','','.b-fancybox'),(911898,'watch','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(911899,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(911900,'watch','.w-cart-gift-certificate .gift-code button','margin-left','15','','','.w-cart-gift-certificate'),(911901,'watch','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(911902,'watch','.w-socials .post_item_img','margin-left','0','','','.w-socials'),(911903,'watch','.w-delivery-location-top-location-list .deliveryList','margin-left','-1','','','.w-delivery-location-top-location-list'),(911904,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(911905,'watch','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(911906,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(911907,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-left','0','','','.w-delivery-location-top-location-list'),(911908,'watch','.w-filters .view_more','margin-left','5','4','','.w-filters'),(911909,'watch','.w-cart-gift-certificate .gift-code button','margin-left','15','','','.w-cart-gift-certificate'),(911910,'watch','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(911911,'watch','.w-delivery-location-top-location-list .deliveryList','margin-left','-1','','','.w-delivery-location-top-location-list'),(911912,'watch','.products-quick-index .token-input-list','margin-left','0','','',''),(911913,'watch','.b-info .info ul','margin-left','0','','','.b-info'),(911914,'watch','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(911915,'watch','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(911916,'watch','.w-product-in-bundles .bundle_item + .bundle_item','margin-left','2','','','.w-product-in-bundles'),(911917,'watch','.w-product-in-bundles .bundle_item','margin-left','0','','','.w-product-in-bundles'),(911918,'watch','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(911919,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(911920,'watch','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(911921,'watch','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(911922,'watch','.w-delivery-location-top-location-list','margin-left','0','','','.w-delivery-location-top-location-list'),(911923,'watch','.w-product-bundle .bundle_item','margin-left','0','','','.w-product-bundle'),(911924,'watch','.w-menu-big ul','margin-left','0','','','.w-menu-big'),(911925,'watch','.w-menu-big li','margin-left','0','','','.w-menu-big'),(911926,'watch','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(911927,'watch','.b-form .required-message-wrap','margin-left','0','','','.b-form'),(911928,'watch','.b-product-images .media-popup .slick-dots','margin-left','0','','','.b-product-images'),(911929,'watch','.b-product-images .media-popup .slick-dots li','margin-left','5','','','.b-product-images'),(911930,'watch','.b-product-images .media-popup button.slick-prev:active','margin-left','-3','','','.b-product-images'),(911931,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(911932,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(911933,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(911934,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(911935,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(911936,'watch','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-left','0','','','.b-menu-style'),(911937,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > .parent > .no-link','margin-left','5','4','','.b-menu-style-1'),(911938,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button a','margin-left','10','4','','.b-menu-style-1'),(911939,'watch','.b-trade-approval .steps-bar','margin-left','0','','','.b-trade-approval'),(911940,'watch','.b-trade-approval .col-3 + .col-3','margin-left','3','','','.b-trade-approval'),(911941,'watch','.w-account-personal-catalog .list-switcher','margin-left','0','','','.w-account-personal-catalog'),(911942,'watch','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-left','0','','','.w-catalog-additional-images'),(911943,'watch','.w-delivery-day .left-count','margin-left','2','','','.w-delivery-day'),(911944,'watch','.w-delivery-day .left-text-right','margin-left','2','','','.w-delivery-day'),(911945,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-left','0','','','.w-filters'),(911946,'watch','.w-cart-checkout-btn .with-card','margin-left','15','4','','.w-cart-checkout-btn'),(911947,'watch','.w-cart-discount-coupon .title','margin-left','10','4','','.w-cart-discount-coupon'),(911959,'watch','.account-password-wrap .buttonedit','margin-left','0','','','.account-password-wrap'),(911960,'watch','.shopping-cart-index .closeable-heading .heading-2','margin-left','0','','','.shopping-cart-index'),(911961,'watch','.account-order-pay .buttons','margin-left','0','','','.account-order-pay'),(911962,'watch','.account-order-pay .history_info','margin-left','0','','','.account-order-pay'),(911963,'watch','.account-order-pay .history_info > div','margin-left','0','5240','','.account-order-pay'),(911964,'watch','.account-samples .buttonBox','margin-left','0','','','.account-samples'),(911965,'watch','.account-samples .order_history_table h2','margin-left','0','','','.account-samples'),(911966,'watch','.account-sample-info .buttons','margin-left','0','','','.account-sample-info'),(911967,'watch','.account-sample-info .history_info','margin-left','0','','','.account-sample-info'),(911968,'watch','.account-sample-info .history_info > div','margin-left','0','5240','','.account-sample-info'),(911969,'watch','.b-slick .slick-dots li','margin-left','5','','','.b-slick'),(911970,'watch','.success-page .page-success .text-1','margin-left','-50','3','','.success-page'),(911971,'watch','.b-multi-page-checkout .multi-page-checkout .buttons','margin-left','0','','','.b-multi-page-checkout'),(911972,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','margin-left','15','4','','.b-multi-page-checkout'),(911975,'watch','.accout-box select[data-type=\"vat_number\"]','margin-left','0','','','.accout-box'),(911976,'watch','.w-menu-style-1 li','margin-left','0','','','.w-menu-style-1'),(911977,'watch','.w-menu-style-1 ul','margin-left','0','','','.w-menu-style-1'),(911978,'watch','.b-slick .slick-list','margin-left','0','','','.b-slick'),(911979,'watch','.b-slick .slick-track','margin-left','auto','','','.b-slick'),(911980,'watch','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-left','-20','','','.b-slick'),(911981,'watch','.w-catalog-paging .next','margin-left','2','','','.w-catalog-paging'),(911982,'watch','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(911983,'watch','.w-checkout-billing-address .btn-cancel','margin-right','20','','','.w-checkout-billing-address'),(911984,'watch','.w-product-in-bundles .bundle_item','margin-right','2','','','.w-product-in-bundles'),(911985,'watch','.w-catalog-items-on-page select','margin-right','10','','','.w-catalog-items-on-page'),(911986,'watch','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(911987,'watch','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-right','0','','','.b-fancybox'),(911988,'watch','.p-quick-order-index ul.token-input-list','margin-right','30','','','.p-quick-order-index'),(911989,'watch','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(911990,'watch','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(911994,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(911995,'watch','.w-delivery-location-top-location-list .deliveryList','margin-right','-1','','','.w-delivery-location-top-location-list'),(911996,'watch','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(911997,'watch','.w-delivery-location-top-location-list','margin-right','0','','','.w-delivery-location-top-location-list'),(911998,'watch','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(911999,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(912000,'watch','.w-promotions .prom-multi-discount > .heading','margin-right','5','3','','.w-promotions'),(912001,'watch','.w-promotions .nextdiscount .heading','margin-right','10','3','','.w-promotions'),(912002,'watch','.w-promotions .icon','margin-right','15','','','.w-promotions'),(912003,'watch','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','margin-right','5','3','','.w-promotions'),(912004,'watch','.w-promotions .promo-salemaker .item','margin-right','2','','','.w-promotions'),(912005,'watch','.w-promotions .promo-cart-discount .slave .item','margin-right','2','','','.w-promotions'),(912006,'watch','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','margin-right','5','3','','.w-promotions'),(912007,'watch','.w-promotions .promo-cart-discount .master .item','margin-right','12','','','.w-promotions'),(912008,'watch','.b-warehouses-popup .warehouses-popup-link','margin-right','5','3','','.b-warehouses-popup'),(912009,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-right','20','','','.b-warehouses-popup'),(912010,'watch','.bell-ico .heading-2','margin-right','10','3','','.bell-ico'),(912011,'watch','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(912012,'watch','.w-checkout-create-account .account-benefits strong','margin-right','5','3','','.w-checkout-create-account'),(912014,'watch','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-right','0','','','.b-fancybox'),(912015,'watch','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(912016,'watch','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(912017,'watch','.w-product-bundle .bundle_item','margin-right','2','','','.w-product-bundle'),(912018,'watch','.w-delivery-location-top-location-list','margin-right','0','','','.w-delivery-location-top-location-list'),(912019,'watch','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(912020,'watch','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(912021,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(912022,'watch','.b-messages .messages-menu ul','margin-right','0','','','.b-messages'),(912023,'watch','.b-messages .messBtnMenuDelete','margin-right','8','3','','.b-messages'),(912024,'watch','.b-messages .messBtnMenuUnread','margin-right','8','3','','.b-messages'),(912025,'watch','.b-messages .msv_content','margin-right','0','','','.b-messages'),(912026,'watch','.b-messages .msv_history','margin-right','0','','','.b-messages'),(912027,'watch','.b-messages .messBtnMenuStarred','margin-right','8','3','','.b-messages'),(912028,'watch','.b-messages .messages-menu li','margin-right','0','','','.b-messages'),(912029,'watch','.b-messages .content_management_attach span::before','margin-right','5','','','.b-messages'),(912030,'watch','.b-messages .content_management_attach span','margin-right','10','','','.b-messages'),(912031,'watch','.w-tabs .tab-navigation','margin-right','0','','','.w-tabs'),(912032,'watch','.w-sitemap-delivery-location > ul > li > ul','margin-right','0','','','.w-sitemap-delivery-location'),(912033,'watch','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(912034,'watch','.shipping-ico .heading-2','margin-right','10','3','','.shipping-ico'),(912035,'watch','.w-product-bundle .bundle_item','margin-right','2','','','.w-product-bundle'),(912036,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(912037,'watch','.w-sitemap-delivery-location > ul','margin-right','0','','','.w-sitemap-delivery-location'),(912038,'watch','.p-payer-order-confirmation .order-ico','margin-right','10','3','','.p-payer-order-confirmation'),(912039,'watch','.p-payer-order-confirmation .ship-ico','margin-right','10','3','','.p-payer-order-confirmation'),(912040,'watch','.p-payer-order-confirmation .pay-ico','margin-right','10','3','','.p-payer-order-confirmation'),(912041,'watch','.p-payer-order-confirmation .discount-ico','margin-right','10','3','','.p-payer-order-confirmation'),(912042,'watch','.p-payer-order-confirmation .comment-ico','margin-right','10','3','','.p-payer-order-confirmation'),(912043,'watch','.p-payer-order-pay .order-ico','margin-right','10','3','','.p-payer-order-pay'),(912044,'watch','.p-payer-order-pay .ship-ico','margin-right','10','3','','.p-payer-order-pay'),(912045,'watch','.p-payer-order-pay .pay-ico','margin-right','10','3','','.p-payer-order-pay'),(912046,'watch','.p-payer-order-pay .discount-ico','margin-right','10','3','','.p-payer-order-pay'),(912047,'watch','.p-payer-order-pay .comment-ico','margin-right','10','3','','.p-payer-order-pay'),(912048,'watch','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(912049,'watch','.b-delete-account .delete-box span','margin-right','10','','','.b-delete-account'),(912050,'watch','.w-checkout-shipping-address .genders-title label','margin-right','20','','','.w-checkout-shipping-address'),(912051,'watch','.w-checkout-shipping-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-shipping-address'),(912052,'watch','.b-messages span.starred::before','margin-right','8','','','.b-messages'),(912053,'watch','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(912054,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(912055,'watch','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(912056,'watch','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(912057,'watch','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(912058,'watch','.w-delivery-location-top-location-list .deliveryList','margin-right','-1','','','.w-delivery-location-top-location-list'),(912059,'watch','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(912060,'watch','.w-menu-horizontal li','margin-right','0','','','.w-menu-horizontal'),(912061,'watch','.w-menu-horizontal ul','margin-right','0','','','.w-menu-horizontal'),(912062,'watch','.b-info .info ul','margin-right','0','','','.b-info'),(912063,'watch','.b-info .info li','margin-right','0','','','.b-info'),(912064,'watch','.shipping-ico .heading-2','margin-right','10','3','','.shipping-ico'),(912065,'watch','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(912066,'watch','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(912067,'watch','.b-info .info li','margin-right','0','','','.b-info'),(912068,'watch','.w-product-in-bundles .bundle_item','margin-right','2','','','.w-product-in-bundles'),(912069,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(912070,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(912071,'watch','.buttons .left-buttons .btn','margin-right','10','','',''),(912072,'watch','.out-stock-icon','margin-right','3','3','',''),(912073,'watch','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(912074,'watch','.w-breadcrumb .breadcrumb-li','margin-right','0','','','.w-breadcrumb'),(912075,'watch','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(912076,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(912077,'watch','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(912078,'watch','.w-product-in-bundles .bundle_item','margin-right','2','','','.w-product-in-bundles'),(912079,'watch','.w-filters .input-checkbox:checked + .checkbox-span','margin-right','10','','','.w-filters'),(912080,'watch','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(912081,'watch','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(912082,'watch','.w-breadcrumb .breadcrumb-li','margin-right','0','','','.w-breadcrumb'),(912083,'watch','.w-top-categories .categories','margin-right','-10','5245','','.w-top-categories'),(912084,'watch','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(912085,'watch','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(912086,'watch','.b-quantity .qty-box input','margin-right','3','','','.b-quantity'),(912087,'watch','.b-info .info li','margin-right','0','','','.b-info'),(912088,'watch','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(912089,'watch','.b-info .info ul','margin-right','0','','','.b-info'),(912090,'watch','.w-delivery-location-top-location-list .deliveryList','margin-right','-1','','','.w-delivery-location-top-location-list'),(912091,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-right','0','','','.w-delivery-location-top-location-list'),(912092,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-right','0','','','.b-select-suggest'),(912093,'watch','.w-socials > li','margin-right','10','','','.w-socials'),(912096,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(912097,'watch','.b-quantity .qty-box input','margin-right','3','','','.b-quantity'),(912098,'watch','.w-socials > li','margin-right','10','','','.w-socials'),(912099,'watch','.w-delivery-location-top-location-list','margin-right','0','','','.w-delivery-location-top-location-list'),(912100,'watch','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(912101,'watch','.b-info .info ul','margin-right','0','','','.b-info'),(912102,'watch','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(912103,'watch','.w-checkout-shipping-address .btn-cancel','margin-right','20','','','.w-checkout-shipping-address'),(912104,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(912105,'watch','.w-multi-cart-actions .cart-actions .dropdown-toggle','margin-right','10','3','','.w-multi-cart-actions'),(912106,'watch','.w-product-bundle .bundle_item','margin-right','2','','','.w-product-bundle'),(912107,'watch','.w-tabs .tab-li','margin-right','0','','','.w-tabs'),(912108,'watch','.w-socials > li','margin-right','10','','','.w-socials'),(912109,'watch','.b-quantity .qty-box input','margin-right','3','','','.b-quantity'),(912110,'watch','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(912111,'watch','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(912112,'watch','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(912113,'watch','.w-cart-listing .actions > div','margin-right','20','','','.w-cart-listing'),(912114,'watch','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(912115,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-right','0','','','.w-delivery-location-top-location-list'),(912116,'watch','.b-form .required-message-wrap','margin-right','0','','','.b-form'),(912117,'watch','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(912118,'watch','.w-product-in-bundles .bundle_item','margin-right','2','','','.w-product-in-bundles'),(912119,'watch','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(912120,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(912121,'watch','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(912122,'watch','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(912124,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(912125,'watch','.b-info .info li','margin-right','0','','','.b-info'),(912126,'watch','.b-info .info ul','margin-right','0','','','.b-info'),(912127,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-right','5','','','.b-messages'),(912128,'watch','.w-filters .filter-ul-content','margin-right','0','','','.w-filters'),(912129,'watch','.transit-icon','margin-right','3','3','',''),(912130,'watch','.in-stock-icon','margin-right','3','3','',''),(912131,'watch','.b-quantity .qty-box input','margin-right','3','','','.b-quantity'),(912132,'watch','.savings-ico .heading-2','margin-right','10','3','','.savings-ico'),(912133,'watch','.order-summary .heading-2','margin-right','10','3','','.order-summary'),(912134,'watch','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(912135,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(912136,'watch','.b-select-suggest .select2-drop-mask','margin-right','0','','','.b-select-suggest'),(912137,'watch','.js-stock-icon','margin-right','3','3','',''),(912138,'watch','.b-form .addresses .address-item input[type=\"radio\"]','margin-right','5','','','.b-form'),(912139,'watch','.products-quick-index ul','margin-right','0','','',''),(912140,'watch','.b-fancybox .fancybox-title-float-wrap .child','margin-right','-100','','','.b-fancybox'),(912141,'watch','.w-product-in-bundles .bundle_item','margin-right','2','','','.w-product-in-bundles'),(912142,'watch','.w-top-categories .categories h2','margin-right','0','','','.w-top-categories'),(912143,'watch','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(912144,'watch','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(912145,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(912146,'watch','.b-form .col-gender label','margin-right','20','','','.b-form'),(912147,'watch','.w-socials .post_item_img','margin-right','10','','','.w-socials'),(912148,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(912149,'watch','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(912150,'watch','.w-product-quantity .qty_packs .price_1','margin-right','25','4','','.w-product-quantity'),(912151,'watch','.w-product-in-bundles .bundle_item + .bundle_item','margin-right','0','','','.w-product-in-bundles'),(912152,'watch','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(912153,'watch','.b-select-suggest .select2-container.select2-allowclear .select2-choice .select2-chosen','margin-right','42','','','.b-select-suggest'),(912154,'watch','.b-select-suggest .select2-container .select2-choice > .select2-chosen','margin-right','26','','','.b-select-suggest'),(912155,'watch','.b-select-suggest .select2-container','margin-right','0','','','.b-select-suggest'),(912156,'watch','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(912157,'watch','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(912158,'watch','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(912159,'watch','.w-breadcrumb .breadcrumb-li','margin-right','0','','','.w-breadcrumb'),(912160,'watch','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(912161,'watch','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(912162,'watch','.w-checkout-billing-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-billing-address'),(912163,'watch','.b-info .info ul','margin-right','0','','','.b-info'),(912164,'watch','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(912165,'watch','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(912166,'watch','.w-product-bundle .bundle_item + .bundle_item','margin-right','0','','','.w-product-bundle'),(912167,'watch','.w-product-bundle .bundle_item','margin-right','2','','','.w-product-bundle'),(912168,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(912169,'watch','.b-info .info li','margin-right','0','','','.b-info'),(912170,'watch','.b-form .radio-buttons .radio-button','margin-right','30','','','.b-form'),(912171,'watch','.b-form .checkbox-style:checked + .checkbox-span','margin-right','5','','','.b-form'),(912172,'watch','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(912173,'watch','.w-menu-big ul','margin-right','0','','','.w-menu-big'),(912174,'watch','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(912175,'watch','.w-checkout-billing-address .genders-title label','margin-right','20','','','.w-checkout-billing-address'),(912176,'watch','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(912177,'watch','.b-autocomplete .ui-autocomplete','margin-right','0','','','.b-autocomplete'),(912178,'watch','.w-cart-checkout-btn + .w-image','margin-right','-25','','','.w-cart-checkout-btn'),(912179,'watch','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(912180,'watch','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(912181,'watch','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(912182,'watch','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(912183,'watch','.b-select-suggest .select2-results .select2-result-label','margin-right','0','','','.b-select-suggest'),(912184,'watch','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(912185,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-right','0','','','.w-delivery-location-top-location-list'),(912186,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(912187,'watch','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(912188,'watch','.w-menu-big li','margin-right','0','','','.w-menu-big'),(912189,'watch','.w-socials > li','margin-right','10','','','.w-socials'),(912190,'watch','.b-fancybox .fancybox-error','margin-right','0','','','.b-fancybox'),(912191,'watch','.w-cart-compare .product .image','margin-right','10','','','.w-cart-compare'),(912192,'watch','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(912193,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(912194,'watch','.b-form .radio-button input[type=\"radio\"].no + span','margin-right','5','3','','.b-form'),(912195,'watch','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-right','0','','','.b-switch'),(912196,'watch','.b-bottom .confirm-popup .buttons .btn','margin-right','20','','','.b-bottom'),(912197,'watch','.b-info .info ul','margin-right','0','','','.b-info'),(912198,'watch','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(912199,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(912200,'watch','.w-delivery-location-top-location-list','margin-right','0','','','.w-delivery-location-top-location-list'),(912201,'watch','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(912202,'watch','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(912203,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(912204,'watch','.w-delivery-location-top-location-list','margin-right','0','','','.w-delivery-location-top-location-list'),(912205,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(912206,'watch','.w-cart-checkout-btn .or-text','margin-right','0','','','.w-cart-checkout-btn'),(912207,'watch','.w-cart-give-away .ga_column','margin-right','2','','','.w-cart-give-away'),(912208,'watch','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(912209,'watch','.w-cart-compare .product-actions .dropdown-toggle','margin-right','8','3','','.w-cart-compare'),(912210,'watch','.w-social-links a','margin-right','5','','','.w-social-links'),(912211,'watch','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(912212,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-right','0','','','.b-select-suggest'),(912213,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-right','0','','','.b-select-suggest'),(912214,'watch','.b-select-suggest .select2-container-multi .select2-choices','margin-right','0','','','.b-select-suggest'),(912215,'watch','.b-select-suggest .select2-results ul.select2-result-sub','margin-right','0','','','.b-select-suggest'),(912216,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(912217,'watch','.b-select-suggest .select2-search input','margin-right','0','','','.b-select-suggest'),(912218,'watch','.b-select-suggest .select2-search','margin-right','0','','','.b-select-suggest'),(912219,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(912220,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(912221,'watch','.b-products-listing .products-listing .bonus-points-cost','margin-right','10','','','.b-products-listing'),(912222,'watch','.w-breadcrumb .breadcrumb-li','margin-right','0','','','.w-breadcrumb'),(912223,'watch','.w-product-bundle .bundle_item','margin-right','2','','','.w-product-bundle'),(912224,'watch','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(912225,'watch','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(912226,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(912227,'watch','.w-account-addresses-list .address-fields input[type=\"radio\"]','margin-right','10','','','.w-account-addresses-list'),(912228,'watch','.b-products-listing .products-listing .bonus-points-cost','margin-right','5','3','','.b-products-listing'),(912229,'watch','.b-products-listing .products-listing .btn-buy','margin-right','10','3','','.b-products-listing'),(912230,'watch','.b-products-listing .products-listing .description ul','margin-right','0','','','.b-products-listing'),(912231,'watch','.b-products-listing .products-listing h2','margin-right','0','','','.b-products-listing'),(912232,'watch','.b-quantity .qty-box input','margin-right','3','','','.b-quantity'),(912233,'watch','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(912234,'watch','.b-products-listing .products-listing .bonus-points-price','margin-right','10','','','.b-products-listing'),(912235,'watch','.w-checkout-gdpr .privacy-row','margin-right','0','','','.w-checkout-gdpr'),(912236,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(912237,'watch','.b-compare .compare-box-btn','margin-right','20','','','.b-compare'),(912238,'watch','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(912239,'watch','.w-socials > li','margin-right','10','','','.w-socials'),(912240,'watch','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(912241,'watch','.w-product-reviews .reviews-list','margin-right','0','','','.w-product-reviews'),(912242,'watch','.w-product-bundle .bundle_item','margin-right','2','','','.w-product-bundle'),(912243,'watch','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(912244,'watch','.b-products-listing .products-listing .radio-attributes label','margin-right','10','','','.b-products-listing'),(912245,'watch','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(912246,'watch','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(912247,'watch','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(912248,'watch','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(912249,'watch','.w-taxable label','margin-right','5','','','.w-taxable'),(912250,'watch','.w-taxable input[type=\"checkbox\"]','margin-right','5','','','.w-taxable'),(912251,'watch','.w-taxable select','margin-right','0','','','.w-taxable'),(912252,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-right','0','','',''),(912253,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-right','0','','','.b-h-inline'),(912254,'watch','.b-form .checkbox-style','margin-right','0','','','.b-form'),(912255,'watch','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(912256,'watch','.w-filters .open','margin-right','10','3','','.w-filters'),(912257,'watch','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(912258,'watch','.b-info .info li','margin-right','0','','','.b-info'),(912259,'watch','.products-quick-index .token-input-list','margin-right','0','','',''),(912260,'watch','.w-cart-give-away .ga_attributes > div','margin-right','1','','','.w-cart-give-away'),(912261,'watch','.w-product-cross-sell .buy-all-checker','margin-right','5','','','.w-product-cross-sell'),(912262,'watch','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(912263,'watch','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(912264,'watch','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','margin-right','10','3','','.w-cart-listing'),(912265,'watch','.w-cart-give-away .ga_img','margin-right','2','','','.w-cart-give-away'),(912266,'watch','.w-cart-give-away .ga_column','margin-right','0','5232','','.w-cart-give-away'),(912267,'watch','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(912268,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(912269,'watch','.w-breadcrumb .breadcrumb-li','margin-right','0','','','.w-breadcrumb'),(912270,'watch','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(912272,'watch','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(912273,'watch','.w-top-categories .categories','margin-right','0','5232','','.w-top-categories'),(912274,'watch','.w-socials > li','margin-right','10','','','.w-socials'),(912275,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(912276,'watch','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(912277,'watch','.w-delivery-location-top-location-list .deliveryList','margin-right','-1','','','.w-delivery-location-top-location-list'),(912278,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(912279,'watch','.w-breadcrumb .breadcrumb-li','margin-right','0','','','.w-breadcrumb'),(912280,'watch','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(912281,'watch','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(912282,'watch','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(912283,'watch','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(912284,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-right','0','','','.w-delivery-location-top-location-list'),(912285,'watch','.b-form .password-forgotten-link','margin-right','0','','','.b-form'),(912286,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-right','0','','','.w-delivery-location-top-location-list'),(912287,'watch','.shipping-ico .heading-2','margin-right','10','3','','.shipping-ico'),(912288,'watch','.w-catalog-listing-look .listing-look-title','margin-right','10','','','.w-catalog-listing-look'),(912289,'watch','.w-delivery-location-top-location-list .deliveryList','margin-right','-1','','','.w-delivery-location-top-location-list'),(912290,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-right','0','','','.w-delivery-location-top-location-list'),(912291,'watch','.w-filters .input-checkbox','margin-right','0','','','.w-filters'),(912292,'watch','.products-quick-index ul.token-input-list','margin-right','0','','',''),(912293,'watch','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(912294,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span','margin-right','5','','','.b-form'),(912295,'watch','.b-quantity .qty-box input','margin-right','3','','','.b-quantity'),(912296,'watch','.w-product-in-bundles .bundle_item','margin-right','2','','','.w-product-in-bundles'),(912297,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(912298,'watch','.w-cart-sub-total','margin-right','0','','','.w-cart-sub-total'),(912299,'watch','.w-delivery-location-top-location-list','margin-right','0','','','.w-delivery-location-top-location-list'),(912300,'watch','.w-delivery-location-top-location-list .deliveryList','margin-right','-1','','','.w-delivery-location-top-location-list'),(912302,'watch','.b-form .required-message','margin-right','0','','','.b-form'),(912303,'watch','.w-filters .input-checkbox:not(checked) + .checkbox-span','margin-right','10','','','.w-filters'),(912304,'watch','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(912305,'watch','.b-product-images .media-popup .slick-dots','margin-right','0','','','.b-product-images'),(912306,'watch','.b-product-images .media-popup .slick-dots li','margin-right','5','','','.b-product-images'),(912307,'watch','.b-product-images .media-popup button.slick-next:active','margin-right','-3','','','.b-product-images'),(912308,'watch','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-right','0','','','.b-menu-style'),(912309,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','margin-right','10','','','.b-menu-style-2'),(912310,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','margin-right','10','','','.b-menu-style-2'),(912311,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','margin-right','10','3','','.b-menu-style-2'),(912312,'watch','.b-trade-approval .steps-bar','margin-right','0','','','.b-trade-approval'),(912313,'watch','.w-account-personal-catalog .list-switcher','margin-right','0','','','.w-account-personal-catalog'),(912314,'watch','.w-account-subscription .info-popup','margin-right','20','','','.w-account-subscription'),(912315,'watch','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-right','0','','','.w-catalog-additional-images'),(912316,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-right','0','','','.w-filters'),(912317,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','margin-right','10','','','.w-filters'),(912329,'watch','.account-password-wrap .buttonedit','margin-right','0','','','.account-password-wrap'),(912330,'watch','.checkout-index-wrap .comment-ico','margin-right','10','3','','.checkout-index-wrap'),(912331,'watch','.checkout-index-wrap .discount-ico','margin-right','10','3','','.checkout-index-wrap'),(912332,'watch','.checkout-index-wrap .order-ico','margin-right','10','3','','.checkout-index-wrap'),(912333,'watch','.checkout-index-wrap .pay-ico','margin-right','10','3','','.checkout-index-wrap'),(912334,'watch','.checkout-index-wrap .ship-ico','margin-right','10','3','','.checkout-index-wrap'),(912335,'watch','.shopping-cart-index .closeable-heading .heading-2','margin-right','0','','','.shopping-cart-index'),(912336,'watch','.account-order-pay .buttons','margin-right','0','','','.account-order-pay'),(912337,'watch','.account-order-pay .history_info','margin-right','0','','','.account-order-pay'),(912338,'watch','.account-order-pay .history_info > div','margin-right','0','5240','','.account-order-pay'),(912339,'watch','.account-samples .buttonBox','margin-right','0','','','.account-samples'),(912340,'watch','.account-samples .order_history_table h2','margin-right','0','','','.account-samples'),(912341,'watch','.account-sample-info .buttons','margin-right','0','','','.account-sample-info'),(912342,'watch','.account-sample-info .history_info','margin-right','0','','','.account-sample-info'),(912343,'watch','.account-sample-info .history_info > div','margin-right','0','5240','','.account-sample-info'),(912344,'watch','.checkout-order-confirmation .comment-ico','margin-right','10','3','','.checkout-order-confirmation'),(912345,'watch','.checkout-order-confirmation .discount-ico','margin-right','10','3','','.checkout-order-confirmation'),(912346,'watch','.checkout-order-confirmation .order-ico','margin-right','10','3','','.checkout-order-confirmation'),(912347,'watch','.checkout-order-confirmation .pay-ico','margin-right','10','3','','.checkout-order-confirmation'),(912348,'watch','.checkout-order-confirmation .prod-ico','margin-right','10','3','','.checkout-order-confirmation'),(912349,'watch','.checkout-order-confirmation .ship-ico','margin-right','10','3','','.checkout-order-confirmation'),(912350,'watch','.b-slick .slick-dots li','margin-right','5','','','.b-slick'),(912351,'watch','.success-page .comment-ico','margin-right','10','3','','.success-page'),(912352,'watch','.success-page .discount-ico','margin-right','10','3','','.success-page'),(912353,'watch','.success-page .order-ico','margin-right','10','3','','.success-page'),(912354,'watch','.success-page .page-success .text-1','margin-right','10','3','','.success-page'),(912355,'watch','.success-page .pay-ico','margin-right','10','3','','.success-page'),(912356,'watch','.success-page .prod-ico','margin-right','10','3','','.success-page'),(912357,'watch','.success-page .ship-ico','margin-right','10','3','','.success-page'),(912358,'watch','.b-multi-page-checkout .multi-page-checkout .buttons','margin-right','0','','','.b-multi-page-checkout'),(912361,'watch','.w-bestsellers .counter','margin-right','15','','','.w-bestsellers'),(912362,'watch','.accout-box select[data-type=\"vat_number\"]','margin-right','0','','','.accout-box'),(912363,'watch','.w-menu-style-1 li','margin-right','0','','','.w-menu-style-1'),(912364,'watch','.w-menu-style-1 ul','margin-right','0','','','.w-menu-style-1'),(912365,'watch','.b-slick .slick-list','margin-right','0','','','.b-slick'),(912366,'watch','.b-slick .slick-track','margin-right','auto','','','.b-slick'),(912367,'watch','.w-catalog-paging .prev','margin-right','5','','','.w-catalog-paging'),(912368,'watch','.b-info .info ul','margin-top','0','','','.b-info'),(912369,'watch','.b-info .info li','margin-top','0','','','.b-info'),(912370,'watch','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(912371,'watch','.b-info .info ul','margin-top','0','','','.b-info'),(912372,'watch','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-top','0','','','.b-switch'),(912373,'watch','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(912374,'watch','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(912375,'watch','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(912376,'watch','.w-catalog-items-on-page select','margin-top','0','','','.w-catalog-items-on-page'),(912377,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-top','0','','','.w-delivery-location-top-location-list'),(912378,'watch','.p-quick-order-index ul.token-input-list','margin-top','0','','','.p-quick-order-index'),(912379,'watch','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(912383,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(912384,'watch','.w-delivery-location-top-location-list .deliveryList','margin-top','0','','','.w-delivery-location-top-location-list'),(912385,'watch','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(912386,'watch','.w-delivery-location-top-location-list','margin-top','25','','','.w-delivery-location-top-location-list'),(912387,'watch','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(912388,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(912389,'watch','.w-promotions .promo-salemaker .item','margin-top','2','','','.w-promotions'),(912390,'watch','.w-promotions .promo-salemaker .content','margin-top','-18','','','.w-promotions'),(912391,'watch','.w-promotions .promo-cart-discount .slave .item','margin-top','2','','','.w-promotions'),(912392,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-top','0','','','.b-warehouses-popup'),(912394,'watch','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(912395,'watch','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(912396,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(912397,'watch','.w-breadcrumb .breadcrumb-li','margin-top','0','','','.w-breadcrumb'),(912398,'watch','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(912399,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(912400,'watch','.w-delivery-location-top-location-list .deliveryList','margin-top','0','','','.w-delivery-location-top-location-list'),(912401,'watch','.b-messages .messages-menu ul','margin-top','0','','','.b-messages'),(912402,'watch','.b-messages .msv_content','margin-top','15','','','.b-messages'),(912403,'watch','.b-messages .msv_btn','margin-top','10','','','.b-messages'),(912404,'watch','.b-messages .msv_history','margin-top','15','','','.b-messages'),(912405,'watch','.b-messages .messages-menu li','margin-top','0','','','.b-messages'),(912406,'watch','.w-sitemap-delivery-location > ul > li > ul','margin-top','0','','','.w-sitemap-delivery-location'),(912407,'watch','.w-tabs .tab-navigation','margin-top','0','','','.w-tabs'),(912408,'watch','.w-socials > li','margin-top','10','','','.w-socials'),(912409,'watch','.w-product-in-bundles .bundle_item','margin-top','0','','','.w-product-in-bundles'),(912410,'watch','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(912411,'watch','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(912412,'watch','.w-breadcrumb .breadcrumb-li','margin-top','0','','','.w-breadcrumb'),(912413,'watch','.b-form .g-recaptcha','margin-top','10','','','.b-form'),(912414,'watch','.w-sitemap-delivery-location > ul','margin-top','0','','','.w-sitemap-delivery-location'),(912415,'watch','.p-payer-order-confirmation .dob-hide','margin-top','20','','','.p-payer-order-confirmation'),(912416,'watch','.p-payer-order-pay .dob-hide','margin-top','20','','','.p-payer-order-pay'),(912417,'watch','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(912418,'watch','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(912419,'watch','.b-info .info','margin-top','-8','3','','.b-info'),(912420,'watch','.b-fancybox #fancybox-loading','margin-top','-22','','','.b-fancybox'),(912421,'watch','.w-product-bundle .bundle_item','margin-top','0','','','.w-product-bundle'),(912422,'watch','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(912423,'watch','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(912424,'watch','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(912425,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-template .btn','margin-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(912426,'watch','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(912427,'watch','.b-info .info ul','margin-top','0','','','.b-info'),(912428,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(912429,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(912430,'watch','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(912431,'watch','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(912432,'watch','.w-menu-horizontal ul','margin-top','0','','','.w-menu-horizontal'),(912433,'watch','.w-menu-horizontal li','margin-top','0','','','.w-menu-horizontal'),(912434,'watch','.b-form .password-forgotten-link','margin-top','0','','','.b-form'),(912435,'watch','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(912436,'watch','.b-info .info li','margin-top','0','','','.b-info'),(912437,'watch','.b-info .info li','margin-top','0','','','.b-info'),(912438,'watch','.b-form .privacy-row','margin-top','10','','','.b-form'),(912439,'watch','.b-fancybox .fancybox-title-outside-wrap','margin-top','10','','','.b-fancybox'),(912440,'watch','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(912441,'watch','.b-info .info','margin-top','-8','3','','.b-info'),(912442,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(912443,'watch','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(912444,'watch','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(912445,'watch','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(912446,'watch','.w-socials > li','margin-top','10','','','.w-socials'),(912447,'watch','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(912448,'watch','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(912449,'watch','.w-product-bundle .bundle_item','margin-top','0','','','.w-product-bundle'),(912450,'watch','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(912451,'watch','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(912452,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(912453,'watch','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(912454,'watch','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(912455,'watch','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-top','0','','','.b-fancybox'),(912456,'watch','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(912457,'watch','.w-delivery-location-top-location-list','margin-top','25','','','.w-delivery-location-top-location-list'),(912458,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-top','0','','','.b-select-suggest'),(912459,'watch','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(912460,'watch','.w-socials > li','margin-top','10','','','.w-socials'),(912462,'watch','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(912463,'watch','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(912464,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-top','0','','','.w-delivery-location-top-location-list'),(912465,'watch','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(912466,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(912467,'watch','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(912468,'watch','.w-cart-give-away .ga_attributes > div','margin-top','1','','','.w-cart-give-away'),(912469,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(912470,'watch','.w-multi-cart-cart-switcher .cart-label','margin-top','-20','','','.w-multi-cart-cart-switcher'),(912471,'watch','.w-product-bundle .bundle_item','margin-top','0','','','.w-product-bundle'),(912472,'watch','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(912473,'watch','.w-tabs .tab-li','margin-top','0','','','.w-tabs'),(912474,'watch','.w-socials > li','margin-top','10','','','.w-socials'),(912475,'watch','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(912476,'watch','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(912477,'watch','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(912478,'watch','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(912479,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-top','0','','','.w-delivery-location-top-location-list'),(912480,'watch','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(912481,'watch','.b-form .required-message-wrap','margin-top','0','','','.b-form'),(912482,'watch','.w-breadcrumb .breadcrumb-li','margin-top','0','','','.w-breadcrumb'),(912483,'watch','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(912484,'watch','.w-product-in-bundles .bundle_item','margin-top','0','','','.w-product-in-bundles'),(912485,'watch','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(912486,'watch','.b-delete-account .delete-box span','margin-top','10','','','.b-delete-account'),(912487,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-top','0','','','.b-messages'),(912488,'watch','.w-filters .filter-ul-content','margin-top','0','','','.w-filters'),(912489,'watch','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(912490,'watch','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(912491,'watch','.p-quick-order-index .dataTables_info','margin-top','5','','','.p-quick-order-index'),(912492,'watch','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(912493,'watch','.b-select-suggest .select2-drop-mask','margin-top','0','','','.b-select-suggest'),(912494,'watch','.products-quick-index ul','margin-top','0','','',''),(912495,'watch','.w-top-categories .categories h2','margin-top','0','','','.w-top-categories'),(912496,'watch','.w-product-in-bundles .bundle_item','margin-top','0','','','.w-product-in-bundles'),(912497,'watch','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(912498,'watch','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(912499,'watch','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(912500,'watch','.b-autocomplete .ui-autocomplete','margin-top','0','','','.b-autocomplete'),(912501,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(912502,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(912503,'watch','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(912504,'watch','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(912505,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(912506,'watch','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(912507,'watch','.w-product-quantity .qty_packs .price_1','margin-top','0','4','','.w-product-quantity'),(912508,'watch','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(912509,'watch','.b-select-suggest .select2-container','margin-top','0','','','.b-select-suggest'),(912510,'watch','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(912511,'watch','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(912512,'watch','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(912513,'watch','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(912514,'watch','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(912515,'watch','.w-breadcrumb .breadcrumb-li','margin-top','0','','','.w-breadcrumb'),(912516,'watch','.b-info .info','margin-top','-8','3','','.b-info'),(912517,'watch','.b-info .info li','margin-top','0','','','.b-info'),(912518,'watch','.b-info .info ul','margin-top','0','','','.b-info'),(912519,'watch','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(912520,'watch','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(912521,'watch','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(912522,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(912523,'watch','.w-product-bundle .bundle_item','margin-top','0','','','.w-product-bundle'),(912524,'watch','.w-product-bundle .bundle_item + .bundle_item','margin-top','0','','','.w-product-bundle'),(912525,'watch','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(912526,'watch','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(912527,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(912528,'watch','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-top','0','','','.b-fancybox'),(912529,'watch','.w-product-in-bundles .bundle_item','margin-top','0','','','.w-product-in-bundles'),(912530,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(912531,'watch','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(912532,'watch','.b-info .info ul','margin-top','0','','','.b-info'),(912533,'watch','.w-top-categories .categories','margin-top','0','5232','','.w-top-categories'),(912534,'watch','.w-cart-checkout-btn .or-text','margin-top','-5','','','.w-cart-checkout-btn'),(912535,'watch','.w-promotions .promo-cart-discount .master .item','margin-top','12','','','.w-promotions'),(912536,'watch','.w-promotions .promo-cart-discount .master .image','margin-top','-16','','','.w-promotions'),(912537,'watch','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(912538,'watch','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(912539,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(912540,'watch','.w-delivery-location-top-location-list','margin-top','25','','','.w-delivery-location-top-location-list'),(912541,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-top','0','','','.w-delivery-location-top-location-list'),(912542,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(912543,'watch','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(912544,'watch','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(912545,'watch','.b-select-suggest .select2-results .select2-result-label','margin-top','0','','','.b-select-suggest'),(912546,'watch','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(912547,'watch','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(912548,'watch','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(912549,'watch','.b-info .info','margin-top','-8','3','','.b-info'),(912550,'watch','.b-form .required-message','margin-top','0','','','.b-form'),(912551,'watch','.w-menu-big ul','margin-top','0','','','.w-menu-big'),(912552,'watch','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(912553,'watch','.b-fancybox .fancybox-error','margin-top','0','','','.b-fancybox'),(912554,'watch','.b-info .info li','margin-top','0','','','.b-info'),(912555,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','margin-top','0','','','.b-switch'),(912556,'watch','.w-cart-compare .product .image','margin-top','0','','','.w-cart-compare'),(912557,'watch','.b-fancybox .fancybox-nav span','margin-top','-18','','','.b-fancybox'),(912558,'watch','.b-info .info','margin-top','-8','3','','.b-info'),(912559,'watch','.w-product-customers-activity .buttons','margin-top','10','','','.w-product-customers-activity'),(912560,'watch','.b-bottom .confirm-popup .buttons .btn','margin-top','0','','','.b-bottom'),(912561,'watch','.b-info .info li','margin-top','0','','','.b-info'),(912562,'watch','.b-info .info ul','margin-top','0','','','.b-info'),(912563,'watch','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(912564,'watch','.w-breadcrumb .breadcrumb-li','margin-top','0','','','.w-breadcrumb'),(912565,'watch','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(912566,'watch','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(912567,'watch','.w-menu-big li','margin-top','0','','','.w-menu-big'),(912568,'watch','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(912569,'watch','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(912570,'watch','.w-cart-checkout-btn + .w-image','margin-top','20','','','.w-cart-checkout-btn'),(912571,'watch','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(912572,'watch','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(912573,'watch','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(912574,'watch','.w-social-links a','margin-top','0','','','.w-social-links'),(912575,'watch','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(912576,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-top','1','','','.b-select-suggest'),(912577,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-top','0','','','.b-select-suggest'),(912578,'watch','.b-select-suggest .select2-container-multi .select2-choices','margin-top','0','','','.b-select-suggest'),(912579,'watch','.b-select-suggest .select2-results ul.select2-result-sub','margin-top','0','','','.b-select-suggest'),(912580,'watch','.w-checkout-shipping-address .change-ab','margin-top','5','','','.w-checkout-shipping-address'),(912581,'watch','.w-checkout-contact-information .contact-info-buttons','margin-top','5','','','.w-checkout-contact-information'),(912582,'watch','.b-select-suggest .select2-drop.select2-drop-above .select2-search input','margin-top','4','','','.b-select-suggest'),(912583,'watch','.b-select-suggest .select2-search input','margin-top','0','','','.b-select-suggest'),(912584,'watch','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(912585,'watch','.b-select-suggest .select2-search','margin-top','0','','','.b-select-suggest'),(912586,'watch','.b-select-suggest .select2-drop.select2-drop-above','margin-top','1','','','.b-select-suggest'),(912587,'watch','.b-select-suggest .select2-drop','margin-top','-1','','','.b-select-suggest'),(912588,'watch','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(912589,'watch','.w-product-bundle .bundle_item','margin-top','0','','','.w-product-bundle'),(912590,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(912591,'watch','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(912592,'watch','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(912593,'watch','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(912594,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(912595,'watch','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(912596,'watch','.w-product-bundle .bundle_item','margin-top','0','','','.w-product-bundle'),(912597,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(912598,'watch','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(912599,'watch','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(912600,'watch','.w-product-in-bundles .bundle_item','margin-top','0','','','.w-product-in-bundles'),(912601,'watch','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(912602,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(912603,'watch','.b-products-listing .products-listing .description ul','margin-top','0','','','.b-products-listing'),(912604,'watch','.b-products-listing .products-listing h2','margin-top','0','','','.b-products-listing'),(912605,'watch','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(912606,'watch','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(912607,'watch','.w-checkout-gdpr .privacy-row','margin-top','0','','','.w-checkout-gdpr'),(912608,'watch','.w-checkout-gdpr .bootstrap-switch','margin-top','0','','','.w-checkout-gdpr'),(912609,'watch','.w-delivery-location-top-location-list .deliveryList','margin-top','0','','','.w-delivery-location-top-location-list'),(912610,'watch','.b-form .checkbox-style','margin-top','0','','','.b-form'),(912611,'watch','.b-form .wedding-form .heading-2','margin-top','10','','','.b-form'),(912612,'watch','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(912613,'watch','.w-product-reviews .reviews-list','margin-top','10','','','.w-product-reviews'),(912614,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-top','0','','','.w-delivery-location-top-location-list'),(912615,'watch','.w-taxable label','margin-top','0','','','.w-taxable'),(912616,'watch','.w-taxable select','margin-top','0','','','.w-taxable'),(912617,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-top','0','','',''),(912618,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-top','0','','','.b-h-inline'),(912619,'watch','.w-communication-new-topic .files-box','margin-top','50','','','.w-communication-new-topic'),(912620,'watch','.b-form .addresses .address-item input[type=\"radio\"]','margin-top','0','','','.b-form'),(912621,'watch','.w-top-categories .categories','margin-top','0','5245','','.w-top-categories'),(912622,'watch','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(912623,'watch','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(912624,'watch','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(912625,'watch','.products-quick-index .token-input-list','margin-top','0','','',''),(912626,'watch','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(912627,'watch','.b-info .info','margin-top','-8','3','','.b-info'),(912628,'watch','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(912629,'watch','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(912630,'watch','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(912631,'watch','.w-cart-listing .points-earn','margin-top','-2','3','','.w-cart-listing'),(912632,'watch','.w-cart-listing .points-redeem','margin-top','-2','3','','.w-cart-listing'),(912633,'watch','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(912634,'watch','.w-breadcrumb .breadcrumb-li','margin-top','0','','','.w-breadcrumb'),(912635,'watch','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(912637,'watch','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(912638,'watch','.w-socials > li','margin-top','10','','','.w-socials'),(912639,'watch','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(912640,'watch','.w-delivery-location-top-location-list','margin-top','25','','','.w-delivery-location-top-location-list'),(912641,'watch','.w-filters .ui-slider','margin-top','5','','','.w-filters'),(912642,'watch','.w-checkout-billing-address .bootstrap-switch','margin-top','-2','','','.w-checkout-billing-address'),(912643,'watch','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(912644,'watch','.w-socials .post_item_img','margin-top','0','','','.w-socials'),(912645,'watch','.w-socials > li','margin-top','10','','','.w-socials'),(912646,'watch','.w-delivery-location-top-location-list','margin-top','25','','','.w-delivery-location-top-location-list'),(912647,'watch','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(912648,'watch','.w-delivery-location-top-location-list .deliveryList','margin-top','0','','','.w-delivery-location-top-location-list'),(912649,'watch','.w-cart-sub-total','margin-top','10','','','.w-cart-sub-total'),(912650,'watch','.w-delivery-location-top-location-list .deliveryList ul','margin-top','0','','','.w-delivery-location-top-location-list'),(912651,'watch','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(912652,'watch','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(912653,'watch','.w-filters .input-checkbox','margin-top','0','','','.w-filters'),(912654,'watch','.products-quick-index ul.token-input-list','margin-top','0','','',''),(912655,'watch','.w-product-in-bundles .bundle_item','margin-top','0','','','.w-product-in-bundles'),(912656,'watch','.w-product-in-bundles .bundle_item + .bundle_item','margin-top','0','','','.w-product-in-bundles'),(912657,'watch','.message.success','margin-top','-8','3','',''),(912658,'watch','.w-delivery-location-top-location-list .deliveryList','margin-top','0','','','.w-delivery-location-top-location-list'),(912659,'watch','.w-delivery-location-top-location-list','margin-top','25','','','.w-delivery-location-top-location-list'),(912660,'watch','.w-delivery-location-top-location-list .deliveryList','margin-top','0','','','.w-delivery-location-top-location-list'),(912661,'watch','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(912662,'watch','.b-product-images .media-popup .slick-dots','margin-top','0','','','.b-product-images'),(912663,'watch','.b-product-images .media-popup .slick-dots li','margin-top','0','','','.b-product-images'),(912664,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','margin-top','-50','','','.b-product-images'),(912665,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(912666,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(912667,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(912668,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(912669,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(912670,'watch','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-top','0','','','.b-menu-style'),(912671,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','margin-top','-8','3','','.b-menu-style-2'),(912672,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','margin-top','-10','3','','.b-menu-style-2'),(912673,'watch','.b-trade-approval .steps-bar','margin-top','0','','','.b-trade-approval'),(912674,'watch','.w-account-personal-catalog .list-switcher','margin-top','0','','','.w-account-personal-catalog'),(912675,'watch','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-top','0','','','.w-catalog-additional-images'),(912676,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','margin-top','0','','','.w-filters'),(912677,'watch','.w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp','margin-top','10','','','.w-cart-discount-coupon'),(912691,'watch','.account-password-wrap .buttonedit','margin-top','-40','','','.account-password-wrap'),(912692,'watch','.account-password-wrap .buttons','margin-top','-70','','','.account-password-wrap'),(912693,'watch','.checkout-index-wrap .dob-hide','margin-top','20','','','.checkout-index-wrap'),(912694,'watch','.shopping-cart-index .closeable-heading .heading-2','margin-top','0','','','.shopping-cart-index'),(912695,'watch','.account-order-pay .buttons','margin-top','20','','','.account-order-pay'),(912696,'watch','.account-order-pay .history_info','margin-top','0','','','.account-order-pay'),(912697,'watch','.account-order-pay .history_info > div','margin-top','0','5240','','.account-order-pay'),(912698,'watch','.account-samples .buttonBox','margin-top','15','','','.account-samples'),(912699,'watch','.account-samples .order_history_table h2','margin-top','0','','','.account-samples'),(912700,'watch','.account-sample-info .buttons','margin-top','20','','','.account-sample-info'),(912701,'watch','.account-sample-info .history_info','margin-top','0','','','.account-sample-info'),(912702,'watch','.account-sample-info .popup-tracking-number-link','margin-top','10','','','.account-sample-info'),(912703,'watch','.account-sample-info .history_info > div','margin-top','0','5240','','.account-sample-info'),(912704,'watch','.b-slick .slick-dots li','margin-top','0','','','.b-slick'),(912705,'watch','.success-page .page-success .text-1','margin-top','0','3','','.success-page'),(912706,'watch','.success-page .totals-line','margin-top','10','','','.success-page'),(912707,'watch','.b-multi-page-checkout .multi-page-checkout .buttons','margin-top','0','','','.b-multi-page-checkout'),(912711,'watch','.accout-box select[data-type=\"vat_number\"]','margin-top','0','','','.accout-box'),(912712,'watch','.w-menu-style-1 li','margin-top','0','','','.w-menu-style-1'),(912713,'watch','.w-menu-style-1 ul','margin-top','0','','','.w-menu-style-1'),(912714,'watch','.b-slick .slick-list','margin-top','0','','','.b-slick'),(912715,'watch','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-top','0','','','.b-slick'),(912716,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','margin-top','-20','','','.b-slick'),(912717,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top','0','','','.w-catalog-paging'),(912718,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top_important','important','','','.w-catalog-paging'),(912719,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(912720,'watch','.p-quick-order-index ul.token-input-list','margin_bottom_measure','pt','','','.p-quick-order-index'),(912721,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(912722,'watch','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(912723,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(912724,'watch','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(912725,'watch','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(912726,'watch','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(912727,'watch','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(912728,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(912729,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(912730,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(912731,'watch','.w-cart-give-away .ga_attributes > div','margin_bottom_measure','%','','','.w-cart-give-away'),(912732,'watch','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(912733,'watch','.p-quick-order-index ul.token-input-list','margin_left_measure','pt','','','.p-quick-order-index'),(912734,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(912735,'watch','.w-delivery-location-top-location-list .deliveryList','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(912736,'watch','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(912737,'watch','.w-delivery-location-top-location-list .deliveryList','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(912738,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_left_measure','pt','','','.b-warehouses-popup'),(912739,'watch','.w-delivery-location-top-location-list .deliveryList','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(912740,'watch','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(912741,'watch','.w-delivery-location-top-location-list .deliveryList','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(912742,'watch','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(912743,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(912744,'watch','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(912745,'watch','.w-product-bundle .bundle_item + .bundle_item','margin_left_measure','%','','','.w-product-bundle'),(912746,'watch','.w-cart-give-away .ga_column','margin_left_measure','%','','','.w-cart-give-away'),(912747,'watch','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(912748,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(912749,'watch','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(912750,'watch','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(912751,'watch','.w-taxable select','margin_left_measure','pt','','','.w-taxable'),(912752,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(912753,'watch','.w-delivery-location-top-location-list .deliveryList','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(912754,'watch','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(912755,'watch','.b-form .col-3 + .col-3','margin_left_measure','%','','','.b-form'),(912756,'watch','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(912757,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(912758,'watch','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(912759,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(912760,'watch','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(912761,'watch','.w-cart-give-away .ga_attributes > div','margin_left_measure','%','','','.w-cart-give-away'),(912762,'watch','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(912763,'watch','.w-product-in-bundles .bundle_item + .bundle_item','margin_left_measure','%','','','.w-product-in-bundles'),(912764,'watch','.w-delivery-location-top-location-list .deliveryList','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(912765,'watch','.b-trade-approval .col-3 + .col-3','margin_left_measure','%','','','.b-trade-approval'),(912766,'watch','.w-delivery-day .left-count','margin_left_measure','%','','','.w-delivery-day'),(912767,'watch','.w-delivery-day .left-text-right','margin_left_measure','%','','','.w-delivery-day'),(912768,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(912769,'watch','.w-delivery-location-top-location-list .deliveryList','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(912770,'watch','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(912771,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_right_measure','pt','','','.b-warehouses-popup'),(912772,'watch','.w-product-in-bundles .bundle_item','margin_right_measure','%','','','.w-product-in-bundles'),(912773,'watch','.p-quick-order-index ul.token-input-list','margin_right_measure','pt','','','.p-quick-order-index'),(912774,'watch','.w-product-bundle .bundle_item','margin_right_measure','%','','','.w-product-bundle'),(912775,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(912776,'watch','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(912777,'watch','.w-delivery-location-top-location-list .deliveryList','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(912778,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(912779,'watch','.w-product-bundle .bundle_item','margin_right_measure','%','','','.w-product-bundle'),(912780,'watch','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(912781,'watch','.w-product-bundle .bundle_item','margin_right_measure','%','','','.w-product-bundle'),(912782,'watch','.b-fancybox .fancybox-title-float-wrap .child','margin_right_measure','%','','','.b-fancybox'),(912783,'watch','.w-product-in-bundles .bundle_item','margin_right_measure','%','','','.w-product-in-bundles'),(912784,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(912785,'watch','.w-product-bundle .bundle_item','margin_right_measure','%','','','.w-product-bundle'),(912786,'watch','.w-delivery-location-top-location-list .deliveryList','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(912787,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(912788,'watch','.w-product-bundle .bundle_item','margin_right_measure','%','','','.w-product-bundle'),(912789,'watch','.w-delivery-location-top-location-list .deliveryList','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(912790,'watch','.w-cart-give-away .ga_column','margin_right_measure','%','','','.w-cart-give-away'),(912791,'watch','.w-product-in-bundles .bundle_item','margin_right_measure','%','','','.w-product-in-bundles'),(912792,'watch','.w-delivery-location-top-location-list .deliveryList','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(912793,'watch','.w-product-in-bundles .bundle_item','margin_right_measure','%','','','.w-product-in-bundles'),(912794,'watch','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(912795,'watch','.w-taxable select','margin_right_measure','pt','','','.w-taxable'),(912796,'watch','.w-product-in-bundles .bundle_item','margin_right_measure','%','','','.w-product-in-bundles'),(912797,'watch','.w-cart-give-away .ga_img','margin_right_measure','%','','','.w-cart-give-away'),(912798,'watch','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(912799,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(912800,'watch','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(912801,'watch','.w-cart-give-away .ga_attributes > div','margin_right_measure','%','','','.w-cart-give-away'),(912802,'watch','.w-product-in-bundles .bundle_item','margin_right_measure','%','','','.w-product-in-bundles'),(912803,'watch','.w-product-bundle .bundle_item','margin_right_measure','%','','','.w-product-bundle'),(912804,'watch','.w-delivery-location-top-location-list .deliveryList','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(912806,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(912807,'watch','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(912808,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(912809,'watch','.p-quick-order-index ul.token-input-list','margin_top_measure','pt','','','.p-quick-order-index'),(912810,'watch','.w-cart-give-away .ga_attributes > div','margin_top_measure','%','','','.w-cart-give-away'),(912811,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(912812,'watch','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(912813,'watch','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(912814,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(912815,'watch','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(912816,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(912817,'watch','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(912818,'watch','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(912819,'watch','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(912820,'watch','.w-promotions .prom-multi-discount .image img','max-height','80','','','.w-promotions'),(912821,'watch','.w-promotions .promo-salemaker .image img','max-height','80','','','.w-promotions'),(912822,'watch','.w-promotions .promo-cart-discount .image img','max-height','80','','','.w-promotions'),(912823,'watch','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(912824,'watch','.b-email-editor img','max-height','100','','','.b-email-editor'),(912825,'watch','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-height','100','','','.w-upload-customer-id-upload-customer-id-form'),(912826,'watch','.w-product-images-additional .item-img','max-height','70','5261','','.w-product-images-additional'),(912827,'watch','.w-product-images-additional .item-img','max-height','70','5261','','.w-product-images-additional'),(912828,'watch','.b-email-editor img','max-height','100','','','.b-email-editor'),(912829,'watch','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(912830,'watch','.b-fancybox .fancybox-tmp','max-height','99999','','','.b-fancybox'),(912831,'watch','.b-email-editor img','max-height','100','','','.b-email-editor'),(912832,'watch','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(912833,'watch','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(912834,'watch','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(912835,'watch','.b-fancybox .fancybox-image','max-height','100','','','.b-fancybox'),(912836,'watch','.b-email-editor img','max-height','100','','','.b-email-editor'),(912837,'watch','.b-email-editor img','max-height','100','','','.b-email-editor'),(912838,'watch','.w-product-images-additional .item-img','max-height','70','5261','','.w-product-images-additional'),(912839,'watch','.b-select-suggest .select2-results','max-height','200','','','.b-select-suggest'),(912840,'watch','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(912841,'watch','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-height','100','','','.b-products-listing'),(912842,'watch','.b-email-editor img','max-height','100','','','.b-email-editor'),(912843,'watch','.w-product-images-additional .item-img','max-height','70','5261','','.w-product-images-additional'),(912844,'watch','.w-product-images-additional .item-img','max-height','70','5261','','.w-product-images-additional'),(912845,'watch','.w-product-images-additional .item-img','max-height','70','5261','','.w-product-images-additional'),(912846,'watch','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max-height','100','','','.b-product-images'),(912847,'watch','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max-height','90','','','.b-product-images'),(912848,'watch','.b-product-images .media-popup .mp-small-images img','max-height','90','','','.b-product-images'),(912849,'watch','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','max-height','0','','','.b-menu-burger_icon'),(912850,'watch','.b-menu-burger_icon .bi-opened .menu-style[data-open_from=\"top\"] .menu-content','max-height','2000','','','.b-menu-burger_icon'),(912851,'watch','.w-product-images img','max-height','100','','','.w-product-images'),(912854,'watch','.w-checkout-guest-btn .btn-2','max-width','100','','','.w-checkout-guest-btn'),(912855,'watch','.w-product-images-additional .item-img','max-width','70','5261','','.w-product-images-additional'),(912856,'watch','.w-promotions .heading-3','max-width','calc(100% - 100px)','','','.w-promotions'),(912857,'watch','.w-promotions .promo-salemaker .item','max-width','calc(50% - 4px)','','','.w-promotions'),(912858,'watch','.w-promotions .promo-cart-discount .slave .item','max-width','calc(50% - 4px)','','','.w-promotions'),(912859,'watch','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(912860,'watch','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(912861,'watch','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-width','100','','','.w-upload-customer-id-upload-customer-id-form'),(912862,'watch','.b-fancybox .fancybox-tmp','max-width','99999','','','.b-fancybox'),(912863,'watch','.w-product-video .frame-video iframe','max-width','100','','','.w-product-video'),(912864,'watch','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(912865,'watch','.w-product-images-additional .item-img','max-width','70','5261','','.w-product-images-additional'),(912866,'watch','.w-product-video .frame-video iframe','max-width','100','','','.w-product-video'),(912867,'watch','.main-width, .type-1 > .block','max-width','1250','','',''),(912868,'watch','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(912869,'watch','textarea','max-width','100','','',''),(912870,'watch','.w-product-video .frame-video iframe','max-width','100','','','.w-product-video'),(912871,'watch','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(912872,'watch','.w-product-video .frame-video iframe','max-width','100','','','.w-product-video'),(912873,'watch','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(912874,'watch','.w-product-images-additional .item-img','max-width','70','5261','','.w-product-images-additional'),(912875,'watch','div.cart-popup','max-width','95','','',''),(912876,'watch','.b-form .middle-form','max-width','560','','','.b-form'),(912877,'watch','.b-email-editor img','max-width','100','','','.b-email-editor'),(912878,'watch','.w-product-images-additional .item-img','max-width','70','5261','','.w-product-images-additional'),(912879,'watch','.w-promotions .promo-cart-discount .master .item','max-width','calc(50% - 24px)','','','.w-promotions'),(912880,'watch','.b-email-editor img','max-width','100','','','.b-email-editor'),(912881,'watch','.w-product-video .frame-video iframe','max-width','100','','','.w-product-video'),(912882,'watch','.w-product-images-additional .item-img','max-width','70','5261','','.w-product-images-additional'),(912883,'watch','.w-catalog-b2b-add-button .b2b-add-box-wrap','max-width','1250','','','.w-catalog-b2b-add-button'),(912884,'watch','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-width','100','','','.b-products-listing'),(912885,'watch','.b-products-listing .promo','max-width','30','','','.b-products-listing'),(912886,'watch','.b-bottom .terms-info-popup','max-width','95','','','.b-bottom'),(912887,'watch','.w-checkout-create-btn .btn-2','max-width','100','','','.w-checkout-create-btn'),(912888,'watch','.b-email-editor img','max-width','100','','','.b-email-editor'),(912889,'watch','.b-fancybox .fancybox-image','max-width','100','','','.b-fancybox'),(912890,'watch','.b-bottom .popup-credit-amount .popup-box','max-width','960','','','.b-bottom'),(912891,'watch','.b-email-editor img','max-width','100','','','.b-email-editor'),(912892,'watch','.b-email-editor img','max-width','100','','','.b-email-editor'),(912893,'watch','.w-product-images-additional .item-img','max-width','70','5261','','.w-product-images-additional'),(912894,'watch','.b-email-editor img','max-width','100','','','.b-email-editor'),(912895,'watch','.w-product-video .frame-video iframe','max-width','100','','','.w-product-video'),(912896,'watch','.b-upload-files .attached-block','max-width','300','','','.b-upload-files'),(912897,'watch','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max-width','100','','','.b-product-images'),(912898,'watch','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max-width','100','','','.b-product-images'),(912899,'watch','.b-product-images .media-popup .mp-small-images img','max-width','90','','','.b-product-images'),(912900,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max-width','100','','','.b-menu-lev_display-slide'),(912901,'watch','.b-trade-approval .middle-form','max-width','560','','','.b-trade-approval'),(912902,'watch','.w-login-register .middle-form','max-width','100','','','.w-login-register'),(912905,'watch','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','max-width','600','','','.checkout-index-wrap'),(912906,'watch','.b-form .formWrapBox','max-width','500','','','.b-form'),(912908,'watch','.w-banner .banner-item.text-bottom-text .banner-text-holder','max-width','100','','','.w-banner'),(912909,'watch','.w-banner .banner-text-holder','max-width','500','','','.w-banner'),(912910,'watch','.w-banner .na-banner','max-width','200','','','.w-banner'),(912911,'watch','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(912912,'watch','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(912913,'watch','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(912914,'watch','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(912915,'watch','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(912916,'watch','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(912917,'watch','.b-fancybox .fancybox-image','max_height_measure','%','','','.b-fancybox'),(912918,'watch','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_height_measure','%','','','.b-products-listing'),(912919,'watch','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(912920,'watch','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max_height_measure','%','','','.b-product-images'),(912921,'watch','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max_height_measure','%','','','.b-product-images'),(912922,'watch','.b-product-images .media-popup .mp-small-images img','max_height_measure','%','','','.b-product-images'),(912923,'watch','.w-product-images img','max_height_measure','%','','','.w-product-images'),(912924,'watch','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(912925,'watch','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(912926,'watch','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(912927,'watch','.w-checkout-guest-btn .btn-2','max_width_measure','%','','','.w-checkout-guest-btn'),(912928,'watch','.w-checkout-create-btn .btn-2','max_width_measure','%','','','.w-checkout-create-btn'),(912929,'watch','.w-product-video .frame-video iframe','max_width_measure','%','','','.w-product-video'),(912930,'watch','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(912931,'watch','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(912932,'watch','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(912933,'watch','textarea','max_width_measure','%','','',''),(912934,'watch','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(912935,'watch','.w-product-video .frame-video iframe','max_width_measure','%','','','.w-product-video'),(912936,'watch','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(912937,'watch','div.cart-popup','max_width_measure','%','','',''),(912938,'watch','.w-product-video .frame-video iframe','max_width_measure','%','','','.w-product-video'),(912939,'watch','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(912940,'watch','.w-product-video .frame-video iframe','max_width_measure','%','','','.w-product-video'),(912941,'watch','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(912942,'watch','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(912943,'watch','.w-product-video .frame-video iframe','max_width_measure','%','','','.w-product-video'),(912944,'watch','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_width_measure','%','','','.b-products-listing'),(912945,'watch','.b-products-listing .promo','max_width_measure','%','','','.b-products-listing'),(912946,'watch','.b-bottom .terms-info-popup','max_width_measure','%','','','.b-bottom'),(912947,'watch','.b-fancybox .fancybox-image','max_width_measure','%','','','.b-fancybox'),(912948,'watch','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(912949,'watch','.w-product-video .frame-video iframe','max_width_measure','%','','','.w-product-video'),(912950,'watch','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(912951,'watch','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max_width_measure','%','','','.b-product-images'),(912952,'watch','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max_width_measure','%','','','.b-product-images'),(912953,'watch','.b-product-images .media-popup .mp-small-images img','max_width_measure','%','','','.b-product-images'),(912954,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max_width_measure','vw','','','.b-menu-lev_display-slide'),(912955,'watch','.w-login-register .middle-form','max_width_measure','%','','','.w-login-register'),(912956,'watch','.w-banner .banner-item.text-bottom-text .banner-text-holder','max_width_measure','%','','','.w-banner'),(912957,'watch','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(912958,'watch','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(912960,'watch','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(912961,'watch','.b-select-suggest .select2-results .select2-result-label','min-height','1','','','.b-select-suggest'),(912962,'watch','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(912963,'watch','.b-select-suggest .select2-container-multi .select2-choices','min-height','26','','','.b-select-suggest'),(912964,'watch','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(912965,'watch','.b-select-suggest .select2-search input','min-height','26','','','.b-select-suggest'),(912966,'watch','.b-select-suggest .select2-search','min-height','26','','','.b-select-suggest'),(912967,'watch','.b-select-suggest .select2-drop-mask','min-height','100','','','.b-select-suggest'),(912970,'watch','.w-cart-listing .item > div','min-height','1','','','.w-cart-listing'),(912971,'watch','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(912972,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','min-height','40','','','.b-menu-style-1'),(912973,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1','min-height','35','','','.b-menu-style-1'),(912974,'watch','.b-slick .slick-slide','min-height','1','','','.b-slick'),(912975,'watch','.w-communication-new-topic #communication_group_holder table','min-width','800','','','.w-communication-new-topic'),(912976,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.p-quick-order-index'),(912977,'watch','.p-quick-order-index .al_incart, .p-quick-order-index .al-incart','min-width','60','','','.p-quick-order-index'),(912978,'watch','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(912979,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.p-quick-order-index'),(912980,'watch','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(912981,'watch','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','min-width','150','','','.w-menu-horizontal'),(912982,'watch','.w-communication-post .btn-submit','min-width','200','','','.w-communication-post'),(912983,'watch','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','min-width','70','','','.b-form'),(912984,'watch','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(912985,'watch','.b-bottom .popup-box.popupCompare','min-width','800','','','.b-bottom'),(912986,'watch','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(912987,'watch','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(912988,'watch','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(912989,'watch','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(912990,'watch','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(912991,'watch','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(912992,'watch','.b-bottom .confirm-popup .buttons .btn','min-width','120','','','.b-bottom'),(912993,'watch','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(912994,'watch','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(912995,'watch','.b-select-suggest .select2-drop-mask','min-width','100','','','.b-select-suggest'),(912996,'watch','.w-menu-horizontal > ul > li > ul > li','min-width','150','','','.w-menu-horizontal'),(912997,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.b-data-table'),(912998,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.b-data-table'),(912999,'watch','.w-communication-new-topic .quantity','min-width','70','','','.w-communication-new-topic'),(913000,'watch','.w-communication-new-topic #communication_group_holder table table','min-width','0','','','.w-communication-new-topic'),(913001,'watch','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(913002,'watch','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','min-width','200','','','.b-menu-lev_display-down'),(913003,'watch','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','min-width','200','','','.b-menu-lev_display-down'),(913004,'watch','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','min-width','200','','','.b-menu-lev_display-down'),(913005,'watch','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','min-width','200','','','.b-menu-lev_display-down'),(913006,'watch','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','min-width','200','','','.b-menu-lev_display-down'),(913007,'watch','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','min-width','200','','','.b-menu-lev_display-left'),(913008,'watch','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','min-width','200','','','.b-menu-lev_display-left'),(913009,'watch','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','min-width','200','','','.b-menu-lev_display-left'),(913010,'watch','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','min-width','200','','','.b-menu-lev_display-left'),(913011,'watch','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','min-width','200','','','.b-menu-lev_display-left'),(913012,'watch','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','min-width','200','','','.b-menu-lev_display-lra'),(913013,'watch','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','min-width','200','','','.b-menu-lev_display-lra'),(913014,'watch','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','min-width','200','','','.b-menu-lev_display-lra'),(913015,'watch','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','min-width','200','','','.b-menu-lev_display-lra'),(913016,'watch','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','min-width','200','','','.b-menu-lev_display-lra'),(913017,'watch','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','min-width','200','','','.b-menu-lev_display-right'),(913018,'watch','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','min-width','200','','','.b-menu-lev_display-right'),(913019,'watch','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','min-width','200','','','.b-menu-lev_display-right'),(913020,'watch','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','min-width','200','','','.b-menu-lev_display-right'),(913021,'watch','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','min-width','200','','','.b-menu-lev_display-right'),(913022,'watch','.w-product-quantity-discounts .quantity-discounts .count','min-width','60','','','.w-product-quantity-discounts'),(913023,'watch','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','min-width','150','','','.w-menu-style-1'),(913024,'watch','.w-menu-style-1 > ul > li > ul > li ul','min-width','150','','','.w-menu-style-1'),(913025,'watch','.w-catalog-paging ','min-width','30','2','','.w-catalog-paging'),(913026,'watch','.w-catalog-paging .next','min-width','30','','','.w-catalog-paging'),(913027,'watch','.w-catalog-paging .next-pages','min-width','30','','','.w-catalog-paging'),(913028,'watch','.w-catalog-paging .page-number','min-width','30','','','.w-catalog-paging'),(913029,'watch','.w-catalog-paging .prev','min-width','30','','','.w-catalog-paging'),(913030,'watch','.w-catalog-paging .prev-pages','min-width','30','','','.w-catalog-paging'),(913031,'watch','.b-select-suggest .select2-results .select2-result-label','min_height_measure','em','','','.b-select-suggest'),(913032,'watch','.b-select-suggest .select2-drop-mask','min_height_measure','%','','','.b-select-suggest'),(913033,'watch','.b-select-suggest .select2-drop-mask','min_width_measure','%','','','.b-select-suggest'),(913034,'watch','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(913035,'watch','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','opacity','0','','','.b-switch'),(913036,'watch','.p-quick-order-index .paginate_button.next.disabled','opacity','0.3','3','','.p-quick-order-index'),(913037,'watch','.p-quick-order-index .paginate_button.previous.disabled','opacity','0.3','3','','.p-quick-order-index'),(913038,'watch','.b-fancybox #fancybox-loading','opacity','0.8','','','.b-fancybox'),(913039,'watch','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(913040,'watch','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(913041,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','opacity','0.5','','','.b-switch'),(913042,'watch','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(913043,'watch','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(913044,'watch','.b-form .hide-billing-address','opacity','0.7','','','.b-form'),(913045,'watch','.disabled-area','opacity','0.5','','',''),(913046,'watch','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(913047,'watch','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled.readonly','opacity','0.7','','','.b-switch'),(913048,'watch','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled','opacity','0.4','','','.b-switch'),(913049,'watch','.b-form .checkbox-style','opacity','0','','','.b-form'),(913050,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','opacity','0.5','','','.b-switch'),(913051,'watch','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','opacity','0.5','','','.b-switch'),(913052,'watch','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(913053,'watch','.b-select-suggest .select2-drop-mask','opacity','0','','','.b-select-suggest'),(913054,'watch','.b-products-listing .products-listing .qty-input.hidden','opacity','0.7','3','','.b-products-listing'),(913055,'watch','.b-form .required-message','opacity','0.5','1','','.b-form'),(913056,'watch','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(913057,'watch','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(913058,'watch','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(913059,'watch','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(913060,'watch','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(913061,'watch','.w-filters .input-checkbox','opacity','0','','','.w-filters'),(913062,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','opacity','0','','','.w-filters'),(913064,'watch','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-order-pay'),(913065,'watch','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-sample-info'),(913066,'watch','.b-slick button.slick-disabled','opacity','0.3','','','.b-slick'),(913067,'watch','.w-catalog-paging .paging span.prev, .w-catalog-paging .paging span.next','opacity','0.3','','','.w-catalog-paging'),(913068,'watch','.w-promotions .promo-cart-discount .slave .heading','order','1','','','.w-promotions'),(913069,'watch','.w-promotions .promo-cart-discount .slave .content','order','3','','','.w-promotions'),(913070,'watch','.w-promotions .promo-cart-discount .slave .condition','order','2','','','.w-promotions'),(913073,'watch','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','outline','none','','','.b-fancybox'),(913074,'watch','.b-select-suggest .select2-container .select2-choice abbr','outline','0','','','.b-select-suggest'),(913075,'watch','.b-switch .bootstrap-switch.bootstrap-switch-focused','outline','0','','','.b-switch'),(913076,'watch','.b-select-suggest .select2-search-choice-close','outline','none','','','.b-select-suggest'),(913077,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','outline','0','','','.b-select-suggest'),(913078,'watch','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(913079,'watch','.b-select-suggest .select2-container-active .select2-choice, .b-select-suggest .select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(913080,'watch','.b-select-suggest .select2-search input','outline','0','','','.b-select-suggest'),(913081,'watch','input:focus','outline','none','','',''),(913082,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline','0','','','.b-select-suggest'),(913083,'watch','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','outline','none','','','.b-fancybox'),(913084,'watch','.b-product-images .media-popup .mp-big-images .item','outline','none','','','.b-product-images'),(913085,'watch','.b-product-images .media-popup .mp-small-images .item','outline','none','','','.b-product-images'),(913086,'watch','.b-slick .slick-list:focus','outline','none','','','.b-slick'),(913087,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline_important','important','','','.b-select-suggest'),(913088,'watch','.w-communication-new-topic #communication_group_holder','overflow','auto','','','.w-communication-new-topic'),(913089,'watch','.b-form .shipping-method .sub-title','overflow','hidden','','','.b-form'),(913090,'watch','.p-quick-order-index .top','overflow','hidden','','','.p-quick-order-index'),(913091,'watch','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','overflow','hidden','','','.w-promotions'),(913092,'watch','.w-cart-compare .product .name','overflow','hidden','','','.w-cart-compare'),(913093,'watch','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(913094,'watch','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(913095,'watch','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(913096,'watch','.b-switch .bootstrap-switch','overflow','hidden','','','.b-switch'),(913097,'watch','.b-fancybox .fancybox-lock .fancybox-overlay','overflow','auto','','','.b-fancybox'),(913098,'watch','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(913099,'watch','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(913100,'watch','.b-select-suggest .select2-measure-scrollbar','overflow','scroll','','','.b-select-suggest'),(913101,'watch','.b-fancybox .fancybox-tmp','overflow','visible','','','.b-fancybox'),(913102,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow','hidden','','','.b-select-suggest'),(913103,'watch','.p-quick-order-index .bottom','overflow','hidden','','','.p-quick-order-index'),(913104,'watch','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(913106,'watch','.w-cart-listing .right-area','overflow','hidden','5240','','.w-cart-listing'),(913107,'watch','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(913108,'watch','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(913109,'watch','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(913111,'watch','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(913112,'watch','.b-fancybox .fancybox-inner','overflow','hidden','','','.b-fancybox'),(913113,'watch','.b-fancybox .fancybox-lock','overflow','hidden','','','.b-fancybox'),(913114,'watch','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(913115,'watch','.b-fancybox .fancybox-overlay','overflow','hidden','','','.b-fancybox'),(913116,'watch','.b-select-suggest .select2-container .select2-choice','overflow','hidden','','','.b-select-suggest'),(913117,'watch','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(913118,'watch','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(913119,'watch','.b-bottom .cart-options .options','overflow','hidden','','','.b-bottom'),(913120,'watch','.b-autocomplete .ui-autocomplete','overflow','auto','','','.b-autocomplete'),(913121,'watch','.b-upload-files .attach-active-holder','overflow','hidden','','','.b-upload-files'),(913122,'watch','.b-upload-files .added-file','overflow','hidden','','','.b-upload-files'),(913123,'watch','.b-fancybox .fancybox-lock body','overflow','hidden','','','.b-fancybox'),(913124,'watch','.w-checkout-shipping-choice input','overflow','hidden','','','.w-checkout-shipping-choice'),(913125,'watch','.w-checkout-shipping-choice #shippingchoice-choice','overflow','hidden','','','.w-checkout-shipping-choice'),(913126,'watch','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(913127,'watch','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(913128,'watch','.b-select-suggest .select2-container-multi .select2-choices','overflow','hidden','','','.b-select-suggest'),(913129,'watch','.b-preloader .preloader','overflow','hidden','3','','.b-preloader'),(913130,'watch','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(913131,'watch','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(913132,'watch','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(913133,'watch','.w-account-addresses-list ','overflow','hidden','','','.w-account-addresses-list'),(913134,'watch','.b-products-listing .btn-preloader','overflow','hidden','3','','.b-products-listing'),(913135,'watch','.b-products-listing .loader','overflow','hidden','4','','.b-products-listing'),(913136,'watch','.b-compare .compare-box-item','overflow','hidden','','','.b-compare'),(913138,'watch','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(913139,'watch','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(913140,'watch','.b-form .payment-method .item-radio label span','overflow','hidden','','','.b-form'),(913141,'watch','.w-quote .no-text','overflow','hidden','','','.w-quote'),(913142,'watch','.b-compare .col-two','overflow','hidden','','','.b-compare'),(913143,'watch','.w-cart-give-away .ga_ovr','overflow','hidden','','','.w-cart-give-away'),(913144,'watch','.w-cart-give-away .ga_wrapper','overflow','hidden','','','.w-cart-give-away'),(913145,'watch','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(913149,'watch','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(913150,'watch','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(913151,'watch','.w-cart-shipping-estimator .item .row','overflow','hidden','','','.w-cart-shipping-estimator'),(913152,'watch','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(913153,'watch','.b-upload-files .attached-block','overflow','hidden','','','.b-upload-files'),(913154,'watch','.b-upload-files .attach-block','overflow','hidden','','','.b-upload-files'),(913155,'watch','.b-select-suggest .select2-container .select2-choice > .select2-chosen','overflow','hidden','','','.b-select-suggest'),(913156,'watch','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','overflow','hidden','','','.b-menu-burger_icon'),(913157,'watch','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','overflow','auto','','','.b-menu-lev_display-width'),(913158,'watch','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','overflow','auto','','','.b-menu-lev_display-width'),(913159,'watch','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','overflow','auto','','','.b-menu-lev_display-width'),(913160,'watch','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','overflow','auto','','','.b-menu-lev_display-width'),(913161,'watch','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','overflow','auto','','','.b-menu-lev_display-width'),(913162,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','overflow','auto','','','.b-menu-lev_display-width_cont'),(913163,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','overflow','auto','','','.b-menu-lev_display-width_cont'),(913164,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','overflow','auto','','','.b-menu-lev_display-width_cont'),(913165,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','overflow','auto','','','.b-menu-lev_display-width_cont'),(913166,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','overflow','auto','','','.b-menu-lev_display-width_cont'),(913167,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','overflow','auto','','','.b-menu-open_from-left'),(913168,'watch','.b-trade-approval .steps-bar','overflow','hidden','','','.b-trade-approval'),(913169,'watch','.w-catalog-compare .compare','overflow','hidden','','','.w-catalog-compare'),(913170,'watch','.w-delivery-day .time-left','overflow','hidden','','','.w-delivery-day'),(913171,'watch','.w-product-images .slick-vertical + .produst-image','overflow','hidden','','','.w-product-images'),(913176,'watch','.account-order-pay .history_info','overflow','hidden','','','.account-order-pay'),(913177,'watch','.account-sample-info .history_info','overflow','hidden','','','.account-sample-info'),(913178,'watch','.fake-input','overflow','hidden','','',''),(913179,'watch','.payment-method-tf label','overflow','hidden','','','.payment-method-tf'),(913180,'watch','.b-slick .slick-list','overflow','hidden','','','.b-slick'),(913181,'watch','.w-banner .banner .image-box','overflow','hidden','','','.w-banner'),(913182,'watch','.w-catalog-paging .paging-holder','overflow','hidden','','','.w-catalog-paging'),(913183,'watch','.w-catalog-paging .paging-holder.slick-slider','overflow','visible','','','.w-catalog-paging'),(913184,'watch','.b-compare .compare_list','overflow-x','hidden','','','.b-compare'),(913185,'watch','.b-select-suggest .select2-results','overflow-x','hidden','','','.b-select-suggest'),(913186,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-x','hidden','','','.b-menu-lev_display-slide'),(913187,'watch','.b-compare .compare_list','overflow-y','auto','','','.b-compare'),(913188,'watch','.b-fancybox .fancybox-lock .fancybox-overlay','overflow-y','scroll','','','.b-fancybox'),(913189,'watch','.b-fancybox .fancybox-lock-test','overflow-y','hidden','','','.b-fancybox'),(913190,'watch','.b-select-suggest .select2-results','overflow-y','auto','','','.b-select-suggest'),(913191,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-y','auto','','','.b-menu-lev_display-slide'),(913192,'watch','.b-fancybox .fancybox-lock-test','overflow-y_important','important','','','.b-fancybox'),(913193,'watch','.b-fancybox .fancybox-lock','overflow_important','important','','','.b-fancybox'),(913194,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow_important','important','','','.b-select-suggest'),(913195,'watch','.b-fancybox .fancybox-tmp','overflow_important','important','','','.b-fancybox'),(913196,'watch','.b-fancybox .fancybox-lock body','overflow_important','important','','','.b-fancybox'),(913197,'watch','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-bottom','10','','','.w-communication-new-topic'),(913198,'watch','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(913199,'watch','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(913200,'watch','.b-email .heading-model','padding-bottom','5','','','.b-email'),(913201,'watch','.w-product-personal-catalog-button .btn','padding-bottom','0','','','.w-product-personal-catalog-button'),(913202,'watch','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(913203,'watch','.b-table .table td','padding-bottom','15','','','.b-table'),(913204,'watch','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(913205,'watch','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(913206,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(913207,'watch','.w-breadcrumb .breadcrumb-li','padding-bottom','0','','','.w-breadcrumb'),(913208,'watch','.w-product-images-additional .images','padding-bottom','20','5261','','.w-product-images-additional'),(913211,'watch','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(913212,'watch','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(913213,'watch','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(913214,'watch','.p-quick-order-index ul.token-input-list','padding-bottom','0','','','.p-quick-order-index'),(913215,'watch','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-bottom','7','','','.p-quick-order-index'),(913216,'watch','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-bottom','8','','','.p-quick-order-index'),(913217,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.p-quick-order-index'),(913218,'watch','.w-promotions .promo-item','padding-bottom','20','','','.w-promotions'),(913219,'watch','.w-top-categories h2.name','padding-bottom','3','','','.w-top-categories'),(913220,'watch','.w-cart-compare .attributes-label','padding-bottom','10','','','.w-cart-compare'),(913228,'watch','.w-personal-gift-status-bar .start-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(913229,'watch','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(913230,'watch','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(913231,'watch','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(913232,'watch','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(913233,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(913234,'watch','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(913235,'watch','.w-product-configurator .pc_item','padding-bottom','10','5240','','.w-product-configurator'),(913236,'watch','.testimonials .review','padding-bottom','10','','',''),(913237,'watch','.testimonials .heading-3','padding-bottom','10','','',''),(913238,'watch','.testimonials .reviews-list .name','padding-bottom','5','','',''),(913239,'watch','.testimonials .name','padding-bottom','5','','',''),(913240,'watch','.w-categories .image','padding-bottom','75','','','.w-categories'),(913241,'watch','.w-promotions .prom-multi-discount .promo-range','padding-bottom','0','','','.w-promotions'),(913242,'watch','.w-promotions .prom-multi-discount .promo-product','padding-bottom','20','','','.w-promotions'),(913243,'watch','.w-promotions .nextdiscount .promo-for-each','padding-bottom','2','','','.w-promotions'),(913244,'watch','.w-promotions .nextdiscount .content > div','padding-bottom','10','','','.w-promotions'),(913245,'watch','.w-promotions .promo-salemaker .item','padding-bottom','20','','','.w-promotions'),(913246,'watch','.w-promotions .promo-salemaker .discount','padding-bottom','0','','','.w-promotions'),(913247,'watch','.w-promotions .promo-cart-discount .slave .item','padding-bottom','20','','','.w-promotions'),(913248,'watch','.w-promotions .promo-cart-discount .slave .heading','padding-bottom','1','','','.w-promotions'),(913249,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','padding-bottom','0','','','.w-promotions'),(913250,'watch','.w-promotions .promo-cart-discount .promo-min-qty','padding-bottom','0','','','.w-promotions'),(913251,'watch','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-bottom','20','','','.b-warehouses-popup'),(913252,'watch','.w-product-available-in-warehouses .warehouse-item','padding-bottom','20','','','.w-product-available-in-warehouses'),(913253,'watch','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-bottom','6','','','.b-products-listing'),(913255,'watch','.w-cart-compare .attributes-cell','padding-bottom','8','','','.w-cart-compare'),(913257,'watch','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(913258,'watch','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(913259,'watch','.b-bottom .confirm-popup .confirm-text','padding-bottom','30','','','.b-bottom'),(913260,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-bottom','0','','','.w-delivery-location-top-location-list'),(913261,'watch','.b-messages .msv_btn','padding-bottom','12','','','.b-messages'),(913262,'watch','.b-messages .msv_content','padding-bottom','10','','','.b-messages'),(913263,'watch','.b-messages .msv_history','padding-bottom','10','','','.b-messages'),(913264,'watch','.b-messages .messMenuButton span','padding-bottom','10','','','.b-messages'),(913265,'watch','.b-messages .messages-menu li a','padding-bottom','8','','','.b-messages'),(913266,'watch','.b-messages .messages-menu li','padding-bottom','0','','','.b-messages'),(913267,'watch','.b-messages .messages-menu ul','padding-bottom','0','','','.b-messages'),(913268,'watch','.b-messages .content_management_attach button','padding-bottom','1','','','.b-messages'),(913269,'watch','.b-messages .email-heading','padding-bottom','15','','','.b-messages'),(913270,'watch','.b-messages .content_management_attach','padding-bottom','8','','','.b-messages'),(913271,'watch','.b-messages .emailLineTextArea textarea','padding-bottom','30','','','.b-messages'),(913272,'watch','.b-messages .msv_to_cc','padding-bottom','10','','','.b-messages'),(913273,'watch','.b-messages .emailBtn','padding-bottom','10','','','.b-messages'),(913274,'watch','.b-messages .dataTables_wrapper > .bottom','padding-bottom','4','','','.b-messages'),(913275,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-bottom','5','','','.b-messages'),(913276,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-bottom','6','','',''),(913277,'watch','.w-sitemap-delivery-location > ul > li > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(913279,'watch','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(913280,'watch','.w-reviews-content .item','padding-bottom','25','','','.w-reviews-content'),(913281,'watch','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(913282,'watch','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(913283,'watch','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(913284,'watch','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(913285,'watch','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(913286,'watch','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(913287,'watch','.w-sitemap-delivery-location > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(913288,'watch','.w-checkout-terms .required-message','padding-bottom','5','','','.w-checkout-terms'),(913289,'watch','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(913290,'watch','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(913291,'watch','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(913292,'watch','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(913293,'watch','.b-email .model','padding-bottom','5','','','.b-email'),(913294,'watch','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(913295,'watch','.w-checkout-shipping-address .edit-ab','padding-bottom','0','','','.w-checkout-shipping-address'),(913296,'watch','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(913297,'watch','.w-reviews-content .author','padding-bottom','20','','','.w-reviews-content'),(913298,'watch','.w-quote .cart-box-link','padding-bottom','5','5240','','.w-quote'),(913299,'watch','.w-promo-code .holder','padding-bottom','20','5261','','.w-promo-code'),(913300,'watch','.b-quantity .qty-box input','padding-bottom','5','','','.b-quantity'),(913301,'watch','.b-quantity .qty-box input','padding-bottom','5','','','.b-quantity'),(913302,'watch','.w-cart-listing .item .remove','padding-bottom','5','5240','','.w-cart-listing'),(913303,'watch','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(913304,'watch','.b-email .image','padding-bottom','5','','','.b-email'),(913305,'watch','.b-email .heading-price','padding-bottom','5','','','.b-email'),(913306,'watch','.b-email .heading-image','padding-bottom','5','','','.b-email'),(913307,'watch','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(913308,'watch','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(913309,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(913310,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-bottom','0','','','.w-delivery-location-top-location-list'),(913311,'watch','.w-filters .filter-ul-content','padding-bottom','0','','','.w-filters'),(913312,'watch','.w-filters .filter-box-head','padding-bottom','5','','','.w-filters'),(913313,'watch','.w-filters .filter-li-content','padding-bottom','15','','','.w-filters'),(913314,'watch','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(913315,'watch','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(913316,'watch','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(913317,'watch','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(913318,'watch','.w-menu-horizontal > ul > li > ul > li','padding-bottom','2','','','.w-menu-horizontal'),(913319,'watch','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-bottom','2','','','.w-menu-horizontal'),(913320,'watch','.w-menu-horizontal ul','padding-bottom','0','','','.w-menu-horizontal'),(913321,'watch','.w-tabs .tab-navigation','padding-bottom','0','','','.w-tabs'),(913322,'watch','.b-table .table td','padding-bottom','15','','','.b-table'),(913323,'watch','.b-email .heading-name','padding-bottom','5','','','.b-email'),(913324,'watch','.b-email .heading-model','padding-bottom','5','','','.b-email'),(913326,'watch','.w-product-configurator .pc_item','padding-bottom','10','5240','','.w-product-configurator'),(913327,'watch','.w-product-configurator .pc_attr','padding-bottom','5','5232','','.w-product-configurator'),(913328,'watch','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(913329,'watch','.b-email .totals-value','padding-bottom','5','','','.b-email'),(913330,'watch','.b-email .name','padding-bottom','5','','','.b-email'),(913331,'watch','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(913332,'watch','.b-email .qty','padding-bottom','5','','','.b-email'),(913333,'watch','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(913334,'watch','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(913335,'watch','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(913336,'watch','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(913337,'watch','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(913338,'watch','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(913339,'watch','.b-bottom .terms-info-popup .pop-up-content','padding-bottom','20','','','.b-bottom'),(913340,'watch','.w-cart-compare .dropdown .dropdown-menu','padding-bottom','5','','','.w-cart-compare'),(913341,'watch','.no-found','padding-bottom','20','','',''),(913342,'watch','textarea','padding-bottom','5','','',''),(913343,'watch','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(913344,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(913345,'watch','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(913346,'watch','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(913347,'watch','.p-quick-order-index .bottom','padding-bottom','10','','','.p-quick-order-index'),(913348,'watch','.w-chat .w-chat-box','padding-bottom','2','','','.w-chat'),(913350,'watch','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(913351,'watch','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(913352,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-bottom','10','','','.w-image-maps'),(913353,'watch','.b-table .table td','padding-bottom','15','','','.b-table'),(913354,'watch','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(913355,'watch','.message.success','padding-bottom','15','','',''),(913356,'watch','.w-personal-gift-status-bar .inform','padding-bottom','0','4','','.w-personal-gift-status-bar'),(913357,'watch','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(913358,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(913359,'watch','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(913360,'watch','.b-email .image','padding-bottom','5','','','.b-email'),(913361,'watch','.b-email .heading-price','padding-bottom','5','','','.b-email'),(913362,'watch','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-bottom','0','','','.b-fancybox'),(913363,'watch','.w-checkout-shipping-choice span','padding-bottom','4','','','.w-checkout-shipping-choice'),(913364,'watch','.b-info .info','padding-bottom','15','','','.b-info'),(913365,'watch','.b-email .model','padding-bottom','5','','','.b-email'),(913366,'watch','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(913367,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-bottom','0','','','.b-select-suggest'),(913368,'watch','.w-breadcrumb .breadcrumb-li','padding-bottom','0','','','.w-breadcrumb'),(913369,'watch','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(913370,'watch','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(913371,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(913372,'watch','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(913373,'watch','.w-reviews .review','padding-bottom','5','','','.w-reviews'),(913374,'watch','.w-socials > li','padding-bottom','15','','','.w-socials'),(913377,'watch','.b-quantity .qty-box input','padding-bottom','5','','','.b-quantity'),(913378,'watch','.b-info-popup .info-popup div','padding-bottom','10','','','.b-info-popup'),(913379,'watch','.b-form .payment-method .item','padding-bottom','7','','','.b-form'),(913380,'watch','.w-checkout-create-account .create-account','padding-bottom','10','','','.w-checkout-create-account'),(913381,'watch','.b-form .password-forgotten-link','padding-bottom','0','','','.b-form'),(913382,'watch','.b-quantity .qty-box input','padding-bottom','5','','','.b-quantity'),(913383,'watch','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(913384,'watch','.w-catalog-sorting .before','padding-bottom','0','','','.w-catalog-sorting'),(913386,'watch','.w-product-configurator .pc_attr','padding-bottom','5','5232','','.w-product-configurator'),(913387,'watch','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(913388,'watch','.b-email .qty','padding-bottom','5','','','.b-email'),(913389,'watch','.b-email .heading-price','padding-bottom','5','','','.b-email'),(913390,'watch','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(913391,'watch','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(913392,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(913393,'watch','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-bottom','3','','','.w-multi-cart-actions'),(913394,'watch','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(913395,'watch','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(913396,'watch','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(913397,'watch','.w-top-categories .item','padding-bottom','30','','','.w-top-categories'),(913398,'watch','.w-tabs > .block','padding-bottom','20','','','.w-tabs'),(913399,'watch','.w-tabs .accordion-heading','padding-bottom','6','2','','.w-tabs'),(913400,'watch','.w-tabs .accordion-heading','padding-bottom','9','5232','','.w-tabs'),(913401,'watch','.w-cart-cart-tabs .w-tabs > .block','padding-bottom','0','','','.w-cart-cart-tabs'),(913402,'watch','.w-tabs .tab-a','padding-bottom','12','','','.w-tabs'),(913403,'watch','.w-tabs .tab-li','padding-bottom','0','','','.w-tabs'),(913404,'watch','.w-socials > li','padding-bottom','15','','','.w-socials'),(913405,'watch','.b-info .info li','padding-bottom','0','','','.b-info'),(913406,'watch','.w-promo-code .holder','padding-bottom','20','5261','','.w-promo-code'),(913407,'watch','.b-bottom .popup-buttons','padding-bottom','15','','','.b-bottom'),(913408,'watch','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-bottom','7','','','.order-summary'),(913409,'watch','.b-quantity .qty-box input','padding-bottom','5','','','.b-quantity'),(913410,'watch','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(913411,'watch','.b-sub-totals .historyTotal td','padding-bottom','2','','','.b-sub-totals'),(913412,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-bottom','0','','','.w-delivery-location-top-location-list'),(913413,'watch','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(913414,'watch','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(913415,'watch','.b-form .required-message','padding-bottom','0','','','.b-form'),(913416,'watch','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(913417,'watch','.btn-1','padding-bottom','4','','',''),(913418,'watch','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(913419,'watch','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(913420,'watch','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(913421,'watch','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(913422,'watch','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(913423,'watch','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(913424,'watch','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(913425,'watch','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(913426,'watch','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(913427,'watch','.b-info .info','padding-bottom','15','','','.b-info'),(913428,'watch','.btn-3','padding-bottom','10','','',''),(913429,'watch','.b-products-listing .products-listing .buyButton .btn','padding-bottom','4','','','.b-products-listing'),(913430,'watch','.w-product-images-additional .images','padding-bottom','20','5261','','.w-product-images-additional'),(913431,'watch','.b-form .required-message-wrap','padding-bottom','0','','','.b-form'),(913432,'watch','.b-email .image','padding-bottom','5','','','.b-email'),(913433,'watch','.b-info .info li','padding-bottom','0','','','.b-info'),(913434,'watch','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(913435,'watch','.w-cart-discount-coupon .btn','padding-bottom','4','','','.w-cart-discount-coupon'),(913436,'watch','.b-email .heading-image','padding-bottom','5','','','.b-email'),(913437,'watch','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(913438,'watch','.b-email .heading-model','padding-bottom','5','','','.b-email'),(913439,'watch','.order-summary .price-row','padding-bottom','7','','','.order-summary'),(913440,'watch','.b-email .heading-model','padding-bottom','5','','','.b-email'),(913441,'watch','.b-email .price','padding-bottom','5','','','.b-email'),(913442,'watch','.b-email .heading-name','padding-bottom','5','','','.b-email'),(913443,'watch','.w-socials > li','padding-bottom','15','','','.w-socials'),(913444,'watch','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(913445,'watch','.b-upload-file .upload-file-template','padding-bottom','25','','','.b-upload-file'),(913447,'watch','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(913448,'watch','.b-select-suggest .select2-drop-mask','padding-bottom','0','','','.b-select-suggest'),(913449,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(913450,'watch','.w-quote .cart-box-link','padding-bottom','5','','','.w-quote'),(913451,'watch','.w-reviews .author','padding-bottom','10','','','.w-reviews'),(913452,'watch','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(913453,'watch','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(913454,'watch','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(913455,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(913457,'watch','.w-product-configurator .pc_item','padding-bottom','10','','','.w-product-configurator'),(913458,'watch','.w-product-configurator .pc_attr','padding-bottom','5','5232','','.w-product-configurator'),(913459,'watch','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(913460,'watch','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(913461,'watch','.b-email .price','padding-bottom','5','','','.b-email'),(913462,'watch','.b-fancybox .fancybox-title-float-wrap .child','padding-bottom','2','','','.b-fancybox'),(913463,'watch','.w-checkout-shipping-choice span','padding-bottom','4','5261','','.w-checkout-shipping-choice'),(913464,'watch','.w-product-personal-catalog-button .btn','padding-bottom','0','','','.w-product-personal-catalog-button'),(913465,'watch','.w-top-categories .categories h2','padding-bottom','0','','','.w-top-categories'),(913466,'watch','.w-top-categories .image','padding-bottom','75','','','.w-top-categories'),(913467,'watch','.w-product-reviews .reviews-list .review','padding-bottom','10','','','.w-product-reviews'),(913468,'watch','.w-product-reviews .reviews-list .name','padding-bottom','5','','','.w-product-reviews'),(913469,'watch','.w-reviews-content .rating','padding-bottom','10','','','.w-reviews-content'),(913470,'watch','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(913471,'watch','.b-email .totals-value','padding-bottom','5','','','.b-email'),(913472,'watch','.b-info .info ul','padding-bottom','0','','','.b-info'),(913473,'watch','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(913474,'watch','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(913475,'watch','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(913476,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(913477,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(913478,'watch','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(913479,'watch','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(913480,'watch','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(913481,'watch','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(913482,'watch','.w-product-configurator .pc_item','padding-bottom','10','','','.w-product-configurator'),(913483,'watch','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(913484,'watch','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(913485,'watch','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(913486,'watch','.b-table .table td','padding-bottom','15','','','.b-table'),(913487,'watch','.b-bottom .rfq-form','padding-bottom','0','','','.b-bottom'),(913488,'watch','.b-bottom .popup-simple','padding-bottom','20','','','.b-bottom'),(913489,'watch','.b-bottom .popup-heading','padding-bottom','12','','','.b-bottom'),(913490,'watch','.b-email .model','padding-bottom','5','','','.b-email'),(913491,'watch','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(913492,'watch','.b-email .image','padding-bottom','5','','','.b-email'),(913493,'watch','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(913494,'watch','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(913495,'watch','.b-email .image','padding-bottom','5','','','.b-email'),(913496,'watch','.b-email .name','padding-bottom','5','','','.b-email'),(913497,'watch','.b-email .heading-price','padding-bottom','5','','','.b-email'),(913498,'watch','.b-email .heading-model','padding-bottom','5','','','.b-email'),(913499,'watch','.b-email .totals-title','padding-bottom','5','','','.b-email'),(913500,'watch','.b-email .totals-value','padding-bottom','5','','','.b-email'),(913501,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(913502,'watch','.b-email .qty','padding-bottom','5','','','.b-email'),(913503,'watch','.b-email .model','padding-bottom','5','','','.b-email'),(913504,'watch','.b-email .price','padding-bottom','5','','','.b-email'),(913505,'watch','.b-email .heading-name','padding-bottom','5','','','.b-email'),(913506,'watch','.b-email .heading-image','padding-bottom','5','','','.b-email'),(913507,'watch','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(913508,'watch','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(913509,'watch','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(913510,'watch','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(913511,'watch','.w-checkout-shipping .sub-item','padding-bottom','5','','','.w-checkout-shipping'),(913512,'watch','.b-info .info','padding-bottom','15','','','.b-info'),(913513,'watch','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(913514,'watch','.b-email .totals-value','padding-bottom','5','','','.b-email'),(913515,'watch','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(913516,'watch','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(913517,'watch','.b-table .table td','padding-bottom','15','','','.b-table'),(913518,'watch','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(913519,'watch','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(913520,'watch','.w-promo-code .holder','padding-bottom','20','5261','','.w-promo-code'),(913521,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(913522,'watch','.b-form .center-buttons','padding-bottom','20','','','.b-form'),(913523,'watch','.b-form .shipping-method .input','padding-bottom','0','','','.b-form'),(913524,'watch','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(913525,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(913526,'watch','.w-reviews .item','padding-bottom','15','','','.w-reviews'),(913527,'watch','.w-reviews .product-name','padding-bottom','12','','','.w-reviews'),(913528,'watch','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(913529,'watch','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(913530,'watch','.b-select-suggest .select2-container .select2-choice','padding-bottom','0','','','.b-select-suggest'),(913531,'watch','.b-quantity .qty-box input','padding-bottom','5','','','.b-quantity'),(913532,'watch','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(913533,'watch','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(913534,'watch','.w-breadcrumb .breadcrumb-li','padding-bottom','0','','','.w-breadcrumb'),(913535,'watch','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(913536,'watch','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(913537,'watch','.w-cart-compare .price-label','padding-bottom','10','','','.w-cart-compare'),(913538,'watch','.b-info .info','padding-bottom','15','','','.b-info'),(913539,'watch','.b-info .info li','padding-bottom','0','','','.b-info'),(913540,'watch','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(913541,'watch','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(913543,'watch','.b-upload-files .upload-files','padding-bottom','10','','','.b-upload-files'),(913544,'watch','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(913545,'watch','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(913546,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(913547,'watch','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(913548,'watch','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(913549,'watch','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(913550,'watch','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(913551,'watch','.b-form .col-full-padding','padding-bottom','30','','','.b-form'),(913552,'watch','.w-product-configurator .pc_item','padding-bottom','10','5240','','.w-product-configurator'),(913553,'watch','.b-info .info ul','padding-bottom','0','','','.b-info'),(913554,'watch','.w-categories .item','padding-bottom','30','','','.w-categories'),(913555,'watch','.b-form .form-buttons','padding-bottom','50','','','.b-form'),(913556,'watch','.b-fancybox .fancybox-title-over-wrap','padding-bottom','10','','','.b-fancybox'),(913557,'watch','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(913558,'watch','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(913559,'watch','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(913560,'watch','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(913561,'watch','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(913562,'watch','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(913563,'watch','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(913564,'watch','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(913565,'watch','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(913566,'watch','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(913567,'watch','.w-cart-compare .delete-cart','padding-bottom','10','','','.w-cart-compare'),(913568,'watch','.w-personal-gift-status-bar .end-date','padding-bottom','0','3','','.w-personal-gift-status-bar'),(913569,'watch','.p-quick-order-index .all-scroll-div','padding-bottom','10','','','.p-quick-order-index'),(913570,'watch','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(913571,'watch','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(913572,'watch','.w-checkout-billing-address .same-address','padding-bottom','10','','','.w-checkout-billing-address'),(913573,'watch','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(913574,'watch','.b-email .heading-image','padding-bottom','5','','','.b-email'),(913575,'watch','.b-email .price','padding-bottom','5','','','.b-email'),(913576,'watch','.b-email .heading-name','padding-bottom','5','','','.b-email'),(913577,'watch','.b-email .model','padding-bottom','5','','','.b-email'),(913578,'watch','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-bottom','10','','','.b-bottom'),(913579,'watch','.w-cart-compare .cart-cell','padding-bottom','20','','','.w-cart-compare'),(913580,'watch','.w-promotions .promo-cart-discount .master .item','padding-bottom','20','','','.w-promotions'),(913581,'watch','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(913582,'watch','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(913583,'watch','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(913584,'watch','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(913585,'watch','.b-bottom .cart-options','padding-bottom','20','','','.b-bottom'),(913586,'watch','.b-bottom .alert-message','padding-bottom','20','','','.b-bottom'),(913587,'watch','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(913588,'watch','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(913589,'watch','.b-select-suggest .select2-results .select2-result-label','padding-bottom','4','','','.b-select-suggest'),(913590,'watch','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(913591,'watch','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(913592,'watch','.b-email .totals-title','padding-bottom','5','','','.b-email'),(913593,'watch','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(913594,'watch','.w-reviews-content .product-name','padding-bottom','20','','','.w-reviews-content'),(913595,'watch','.w-product-personal-catalog-button .btn','padding-bottom','0','','','.w-product-personal-catalog-button'),(913596,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(913597,'watch','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(913598,'watch','.b-email .name','padding-bottom','5','','','.b-email'),(913599,'watch','.b-email .heading-price','padding-bottom','5','','','.b-email'),(913600,'watch','.b-email .heading-image','padding-bottom','5','','','.b-email'),(913601,'watch','.b-email .heading-name','padding-bottom','5','','','.b-email'),(913602,'watch','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(913603,'watch','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(913604,'watch','.b-info .info ul','padding-bottom','0','','','.b-info'),(913605,'watch','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-bottom','4','','','.b-compare'),(913606,'watch','.b-bottom .pop-up-close','padding-bottom','1','','','.b-bottom'),(913607,'watch','.b-bottom .footerTitle','padding-bottom','9','5232','','.b-bottom'),(913608,'watch','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(913609,'watch','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(913610,'watch','.w-product-configurator .pc_item','padding-bottom','10','','','.w-product-configurator'),(913611,'watch','.w-cart-up-sell .w-list-type-1','padding-bottom','0','','','.w-cart-up-sell'),(913612,'watch','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','0','1','','.w-cart-up-sell'),(913613,'watch','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','1','','','.w-cart-up-sell'),(913614,'watch','.b-products-listing .products-listing .btn-buy','padding-bottom','4','','','.b-products-listing'),(913615,'watch','.b-upload-files .added-file','padding-bottom','5','','','.b-upload-files'),(913616,'watch','.w-menu-big ul','padding-bottom','0','','','.w-menu-big'),(913617,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(913618,'watch','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(913619,'watch','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(913620,'watch','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(913621,'watch','.w-categories h2.name','padding-bottom','3','','','.w-categories'),(913622,'watch','.b-bottom .header-info','padding-bottom','20','','','.b-bottom'),(913623,'watch','.b-bottom .popup-box-wrap','padding-bottom','10','','','.b-bottom'),(913624,'watch','.w-product-images-additional .images','padding-bottom','20','5261','','.w-product-images-additional'),(913625,'watch','.b-bottom .pop-up-info','padding-bottom','20','','','.b-bottom'),(913626,'watch','.b-email .price','padding-bottom','5','','','.b-email'),(913627,'watch','.b-fancybox .fancybox-error','padding-bottom','15','','','.b-fancybox'),(913628,'watch','.b-info .info li','padding-bottom','0','','','.b-info'),(913629,'watch','.w-product-customers-activity .customers-activity','padding-bottom','20','','','.w-product-customers-activity'),(913630,'watch','.b-compare .compare-box-item','padding-bottom','10','','','.b-compare'),(913631,'watch','.b-bottom .confirm-popup .buttons','padding-bottom','30','','','.b-bottom'),(913632,'watch','.b-compare .compare-head','padding-bottom','0','','','.b-compare'),(913633,'watch','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(913634,'watch','.b-email .heading-image','padding-bottom','5','','','.b-email'),(913635,'watch','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(913636,'watch','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(913637,'watch','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(913638,'watch','.b-info .info li','padding-bottom','0','','','.b-info'),(913639,'watch','.b-form .login-col-1','padding-bottom','0','','','.b-form'),(913640,'watch','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(913641,'watch','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(913642,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(913643,'watch','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(913644,'watch','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(913645,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-bottom','0','','','.w-delivery-location-top-location-list'),(913646,'watch','.w-checkout-billing-address .edit-ab','padding-bottom','0','','','.w-checkout-billing-address'),(913647,'watch','.w-checkout-shipping-choice #shippingchoice-choice','padding-bottom','7','','','.w-checkout-shipping-choice'),(913648,'watch','.w-promo-code .holder','padding-bottom','20','5261','','.w-promo-code'),(913649,'watch','.w-product-images-additional .images','padding-bottom','20','5261','','.w-product-images-additional'),(913650,'watch','.w-product-configurator .pc_attr','padding-bottom','5','5232','','.w-product-configurator'),(913651,'watch','.b-bottom .header-error','padding-bottom','20','','','.b-bottom'),(913652,'watch','.w-product-configurator .pc_item','padding-bottom','10','5240','','.w-product-configurator'),(913653,'watch','.w-tabs .accordion-heading','padding-bottom','8','','','.w-tabs'),(913654,'watch','.w-socials > li','padding-bottom','15','','','.w-socials'),(913655,'watch','.b-autocomplete .ui-autocomplete li','padding-bottom','3','','','.b-autocomplete'),(913656,'watch','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(913657,'watch','.w-cart-give-away .ga_column','padding-bottom','15','','','.w-cart-give-away'),(913658,'watch','.w-breadcrumb .breadcrumb-li','padding-bottom','0','','','.w-breadcrumb'),(913659,'watch','.w-cart-compare .price-cell','padding-bottom','8','','','.w-cart-compare'),(913660,'watch','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(913661,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(913662,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(913663,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-bottom','5','','','.b-select-suggest'),(913664,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-bottom','0','','','.b-select-suggest'),(913665,'watch','.b-select-suggest .select2-locked','padding-bottom','3','','','.b-select-suggest'),(913666,'watch','.b-select-suggest .select2-container-multi .select2-choices','padding-bottom','0','','','.b-select-suggest'),(913667,'watch','.b-select-suggest .select2-results','padding-bottom','0','','','.b-select-suggest'),(913668,'watch','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','5','','','.w-menu-horizontal'),(913669,'watch','.b-form .shipping-method .item + .item','padding-bottom','5','','','.b-form'),(913670,'watch','.b-select-suggest .select2-search input','padding-bottom','4','','','.b-select-suggest'),(913671,'watch','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(913672,'watch','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(913673,'watch','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(913674,'watch','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(913675,'watch','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(913676,'watch','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','12','5240','','.w-menu-horizontal'),(913677,'watch','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(913678,'watch','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(913679,'watch','.w-socials > li','padding-bottom','15','','','.w-socials'),(913680,'watch','.w-product-configurator .pc_item','padding-bottom','10','5240','','.w-product-configurator'),(913681,'watch','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(913682,'watch','.w-cart-compare .dropdown li','padding-bottom','5','','','.w-cart-compare'),(913683,'watch','.w-cart-compare .product-label','padding-bottom','15','','','.w-cart-compare'),(913684,'watch','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(913685,'watch','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(913686,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(913687,'watch','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(913688,'watch','.b-compare .col-two label','padding-bottom','5','','','.b-compare'),(913689,'watch','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(913692,'watch','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(913693,'watch','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(913694,'watch','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(913695,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(913696,'watch','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(913697,'watch','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(913698,'watch','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(913699,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(913700,'watch','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(913701,'watch','.w-account-addresses-list .addsess-suggestion-item','padding-bottom','20','','','.w-account-addresses-list'),(913702,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.b-data-table'),(913703,'watch','.w-communication-post .communication-post','padding-bottom','5','','','.w-communication-post'),(913704,'watch','.w-communication-post .communication-post-author','padding-bottom','10','','','.w-communication-post'),(913705,'watch','.b-products-listing .products-listing a.btn.view-button','padding-bottom','6','','','.b-products-listing'),(913706,'watch','.b-products-listing .products-listing .compare','padding-bottom','6','','','.b-products-listing'),(913707,'watch','.b-products-listing .in-cart','padding-bottom','4','','','.b-products-listing'),(913708,'watch','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-bottom','5','','','.w-catalog-b2b-add-button'),(913709,'watch','.b-products-listing .products-listing h2','padding-bottom','0','','','.b-products-listing'),(913710,'watch','.b-products-listing .promos-info .promo-item','padding-bottom','3','','','.b-products-listing'),(913711,'watch','.b-products-listing .promos-info .promo-name','padding-bottom','3','','','.b-products-listing'),(913717,'watch','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(913718,'watch','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(913719,'watch','.w-checkout-gdpr .privacy-row','padding-bottom','0','','','.w-checkout-gdpr'),(913720,'watch','.w-checkout-gdpr .terms-login','padding-bottom','0','','','.w-checkout-gdpr'),(913721,'watch','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(913722,'watch','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(913723,'watch','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(913724,'watch','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(913725,'watch','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(913726,'watch','.b-email .qty','padding-bottom','5','','','.b-email'),(913727,'watch','.b-email .name','padding-bottom','5','','','.b-email'),(913728,'watch','.b-email .heading-price','padding-bottom','5','','','.b-email'),(913729,'watch','.w-product-configurator .pc_attr','padding-bottom','5','5232','','.w-product-configurator'),(913730,'watch','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(913731,'watch','.w-reviews .heading-3','padding-bottom','15','','','.w-reviews'),(913732,'watch','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(913733,'watch','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(913734,'watch','.w-product-configurator .pc_item','padding-bottom','10','','','.w-product-configurator'),(913735,'watch','.w-personal-gift-status-bar .timeline','padding-bottom','16','','','.w-personal-gift-status-bar'),(913736,'watch','.w-breadcrumb .breadcrumb-li','padding-bottom','0','','','.w-breadcrumb'),(913737,'watch','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(913738,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(913739,'watch','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(913740,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(913741,'watch','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(913742,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-bottom','0','','',''),(913743,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-bottom','0','','','.b-h-inline'),(913744,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-bottom','0','','','.w-communication-new-topic'),(913745,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-bottom','5','','','.w-communication-new-topic'),(913746,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-bottom','5','','','.w-communication-new-topic'),(913747,'watch','.w-communication-new-topic #communication_topic_form .middle-form','padding-bottom','0','','','.w-communication-new-topic'),(913748,'watch','.b-info .info ul','padding-bottom','0','','','.b-info'),(913749,'watch','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(913750,'watch','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(913751,'watch','.b-bottom .popup-content','padding-bottom','15','','','.b-bottom'),(913752,'watch','.b-compare .compare_pagination','padding-bottom','10','','','.b-compare'),(913753,'watch','.w-promo-code .holder','padding-bottom','20','5261','','.w-promo-code'),(913754,'watch','.w-top-categories .item','padding-bottom','30','5232','','.w-top-categories'),(913755,'watch','.w-product-personal-catalog-button .btn','padding-bottom','0','','','.w-product-personal-catalog-button'),(913756,'watch','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(913757,'watch','.w-product-configurator .pc_item','padding-bottom','10','','','.w-product-configurator'),(913758,'watch','.w-product-personal-catalog-button .btn','padding-bottom','0','','','.w-product-personal-catalog-button'),(913759,'watch','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(913760,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(913761,'watch','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(913762,'watch','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(913763,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(913764,'watch','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(913765,'watch','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(913766,'watch','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(913767,'watch','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(913768,'watch','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-bottom','0','','','.b-fancybox'),(913769,'watch','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(913770,'watch','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(913771,'watch','.b-email .qty','padding-bottom','5','','','.b-email'),(913772,'watch','.b-email .totals-title','padding-bottom','5','','','.b-email'),(913773,'watch','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(913774,'watch','.b-email .name','padding-bottom','5','','','.b-email'),(913775,'watch','.products-quick-index .token-input-list','padding-bottom','0','','',''),(913776,'watch','.w-cart-compare .product','padding-bottom','10','','','.w-cart-compare'),(913777,'watch','.w-cart-compare .product-actions','padding-bottom','0','','','.w-cart-compare'),(913778,'watch','.w-product-configurator .pc_item','padding-bottom','10','5240','','.w-product-configurator'),(913779,'watch','.w-cart-shipping-estimator .address-item','padding-bottom','20','','','.w-cart-shipping-estimator'),(913780,'watch','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(913781,'watch','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(913782,'watch','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(913783,'watch','.b-info .info li','padding-bottom','0','','','.b-info'),(913784,'watch','.b-form .shipping-method .item','padding-bottom','5','','','.b-form'),(913785,'watch','.b-info .info','padding-bottom','15','','','.b-info'),(913786,'watch','.b-email .model','padding-bottom','5','','','.b-email'),(913787,'watch','.b-form .middle-form','padding-bottom','0','','','.b-form'),(913788,'watch','.b-email .totals-title','padding-bottom','5','','','.b-email'),(913789,'watch','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(913790,'watch','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(913791,'watch','.w-product-images-additional .images','padding-bottom','20','5261','','.w-product-images-additional'),(913792,'watch','.b-email .totals-value','padding-bottom','5','','','.b-email'),(913793,'watch','.w-cart-listing .item .gift-wrap label','padding-bottom','10','','','.w-cart-listing'),(913794,'watch','.w-cart-listing .item > div','padding-bottom','10','','','.w-cart-listing'),(913795,'watch','.w-cart-listing .points-earn','padding-bottom','10','','','.w-cart-listing'),(913796,'watch','.w-cart-listing .points-redeem','padding-bottom','10','','','.w-cart-listing'),(913797,'watch','.w-breadcrumb .breadcrumb-li','padding-bottom','0','','','.w-breadcrumb'),(913798,'watch','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(913804,'watch','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(913805,'watch','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(913806,'watch','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(913807,'watch','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(913808,'watch','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(913809,'watch','.b-email .totals-value','padding-bottom','5','','','.b-email'),(913810,'watch','.b-email .totals-title','padding-bottom','5','','','.b-email'),(913811,'watch','.b-email .price','padding-bottom','5','','','.b-email'),(913812,'watch','.b-email .name','padding-bottom','5','','','.b-email'),(913813,'watch','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(913814,'watch','.b-email .heading-name','padding-bottom','5','','','.b-email'),(913815,'watch','.b-email .image','padding-bottom','5','','','.b-email'),(913816,'watch','.w-product-images-additional .images','padding-bottom','20','5261','','.w-product-images-additional'),(913817,'watch','.w-promo-code .holder','padding-bottom','20','5261','','.w-promo-code'),(913818,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(913819,'watch','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(913820,'watch','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(913821,'watch','.w-product-configurator .pc_item','padding-bottom','10','','','.w-product-configurator'),(913822,'watch','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(913823,'watch','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(913824,'watch','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(913825,'watch','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(913826,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(913828,'watch','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(913829,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(913830,'watch','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(913831,'watch','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(913832,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(913833,'watch','.w-filters .fsl_handle','padding-bottom','15','','','.w-filters'),(913834,'watch','.w-filters .head-filter-widget','padding-bottom','0','5240','','.w-filters'),(913835,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-bottom','0','','','.w-delivery-location-top-location-list'),(913836,'watch','.w-filters .filter-box-content','padding-bottom','20','','','.w-filters'),(913837,'watch','.w-filters .ui-slider-range','padding-bottom','0','','','.w-filters'),(913838,'watch','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(913840,'watch','.w-filters .head-filter-widget','padding-bottom','10','','','.w-filters'),(913841,'watch','.b-autocomplete .ui-autocomplete','padding-bottom','2','','','.b-autocomplete'),(913842,'watch','.b-bottom .notify-form','padding-bottom','0','','','.b-bottom'),(913843,'watch','.order-summary .heading-2','padding-bottom','0','','','.order-summary'),(913844,'watch','.w-product-configurator .pc_attr','padding-bottom','5','5232','','.w-product-configurator'),(913845,'watch','.w-personal-gift-status-bar .end-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(913846,'watch','.b-compare .column_wrapper','padding-bottom','10','','','.b-compare'),(913847,'watch','.b-info .info','padding-bottom','15','','','.b-info'),(913848,'watch','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(913849,'watch','.b-email .heading-model','padding-bottom','5','','','.b-email'),(913850,'watch','.b-info .info ul','padding-bottom','0','','','.b-info'),(913851,'watch','.w-socials > li','padding-bottom','15','','','.w-socials'),(913852,'watch','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(913853,'watch','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(913854,'watch','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(913855,'watch','.w-reviews-content .review','padding-bottom','10','','','.w-reviews-content'),(913856,'watch','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(913857,'watch','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(913858,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom','0','','','.b-data-table'),(913859,'watch','.b-data-table table.dataTable tbody td','padding-bottom','10','','','.b-data-table'),(913860,'watch','.b-data-table table.dataTable thead td','padding-bottom','10','','','.b-data-table'),(913861,'watch','.w-product-personal-catalog-button .btn','padding-bottom','0','','','.w-product-personal-catalog-button'),(913862,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-bottom','0','','','.w-delivery-location-top-location-list'),(913863,'watch','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(913864,'watch','.b-compare .popupCompare .pop-up-content','padding-bottom','10','','','.b-compare'),(913865,'watch','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(913866,'watch','.btn-2','padding-bottom','12','','',''),(913867,'watch','.w-quote-products .empty','padding-bottom','100','','','.w-quote-products'),(913868,'watch','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(913869,'watch','.b-table .table td','padding-bottom','15','','','.b-table'),(913870,'watch','.b-info .info ul','padding-bottom','0','','','.b-info'),(913871,'watch','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(913872,'watch','.b-compare .col-gender','padding-bottom','10','','','.b-compare'),(913873,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(913874,'watch','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(913875,'watch','.b-email .totals-title','padding-bottom','5','','','.b-email'),(913876,'watch','.b-email .qty','padding-bottom','5','','','.b-email'),(913877,'watch','.btn','padding-bottom','4','','',''),(913878,'watch','.b-product-images .media-popup .mp-content','padding-bottom','0','','','.b-product-images'),(913879,'watch','.b-product-images .media-popup .mp-small-images .item','padding-bottom','10','','','.b-product-images'),(913880,'watch','.b-product-images .media-popup .slick-dots','padding-bottom','0','','','.b-product-images'),(913881,'watch','.b-product-images .media-popup .slick-dots li','padding-bottom','0','','','.b-product-images'),(913882,'watch','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-bottom','0','','','.b-menu-style'),(913883,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-bottom','5','','','.b-menu-style-1'),(913884,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-bottom','5','','','.b-menu-style-1'),(913885,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-bottom','20','','','.b-menu-style-1'),(913886,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-bottom','0','','','.b-menu-style-1'),(913887,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-bottom','5','','','.b-menu-style-2'),(913888,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-bottom','5','','','.b-menu-style-2'),(913889,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-bottom','0','','','.b-menu-style-2'),(913890,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-bottom','0','','','.b-menu-style-2'),(913891,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-bottom','10','','','.b-menu-style-2'),(913892,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-bottom','0','','','.b-menu-style-2'),(913893,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-bottom','5','','','.b-menu-style-2'),(913894,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-bottom','10','','','.b-menu-style-2'),(913895,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-bottom','5','','','.b-menu-style-2'),(913896,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-bottom','10','','','.b-menu-style-2'),(913897,'watch','.b-personal-catalog-popup #personal_catalog_popup','padding-bottom','20','','','.b-personal-catalog-popup'),(913898,'watch','.b-trade-approval .steps-bar li a','padding-bottom','7','','','.b-trade-approval'),(913899,'watch','.b-trade-approval .middle-form','padding-bottom','20','','','.b-trade-approval'),(913900,'watch','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-bottom','5','','','.b-trade-approval'),(913901,'watch','.b-trade-approval .steps-bar','padding-bottom','0','','','.b-trade-approval'),(913902,'watch','.b-trade-approval .center-buttons','padding-bottom','20','','','.b-trade-approval'),(913903,'watch','.w-account-personal-catalog .list-switcher','padding-bottom','0','','','.w-account-personal-catalog'),(913904,'watch','.w-account-personal-catalog .list-switcher a','padding-bottom','12','','','.w-account-personal-catalog'),(913905,'watch','.w-account-subscription .subscription-variant','padding-bottom','10','','','.w-account-subscription'),(913906,'watch','.w-catalog-additional-images li','padding-bottom','10','','','.w-catalog-additional-images'),(913907,'watch','.w-catalog-additional-images ul','padding-bottom','0','','','.w-catalog-additional-images'),(913908,'watch','.w-catalog-compare td','padding-bottom','10','','','.w-catalog-compare'),(913909,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-bottom','0','','','.w-catalog-compare'),(913910,'watch','.w-catalog-compare .cross-box .different-all > div','padding-bottom','11','2','','.w-catalog-compare'),(913911,'watch','.w-catalog-compare .cross-box .different-all > div','padding-bottom','10','','','.w-catalog-compare'),(913912,'watch','.w-delivery-day .left-count','padding-bottom','0','','','.w-delivery-day'),(913913,'watch','.w-delivery-day .left-text-left','padding-bottom','24','','','.w-delivery-day'),(913914,'watch','.w-delivery-day .left-text-right','padding-bottom','24','','','.w-delivery-day'),(913915,'watch','.w-top-text .top-text','padding-bottom','5','','','.w-top-text'),(913916,'watch','.w-cart-listing .points','padding-bottom','0','5232','','.w-cart-listing'),(913917,'watch','.w-product-images .additional-horizontal .item','padding-bottom','10','','','.w-product-images'),(913918,'watch','.w-filters .filter-box-content ul','padding-bottom','20','','','.w-filters'),(913919,'watch','.order-summary .w-cart-listing .item > div ~ div','padding-bottom','10','','','.order-summary'),(913920,'watch','.w-cart-discount-coupon .discount-box','padding-bottom','5','','','.w-cart-discount-coupon'),(913957,'watch','.catalog-product-wrap .next-product','padding-bottom','20','','','.catalog-product-wrap'),(913958,'watch','.catalog-product-wrap .pn-direction','padding-bottom','0','','','.catalog-product-wrap'),(913959,'watch','.catalog-product-wrap .pn-image','padding-bottom','20','','','.catalog-product-wrap'),(913960,'watch','.catalog-product-wrap .prev-product','padding-bottom','20','','','.catalog-product-wrap'),(913961,'watch','.catalog-product-wrap .next-product','padding-bottom','20','5240','','.catalog-product-wrap'),(913962,'watch','.catalog-product-wrap .pn-direction','padding-bottom','0','5240','','.catalog-product-wrap'),(913963,'watch','.catalog-product-wrap .prev-product','padding-bottom','20','5240','','.catalog-product-wrap'),(913964,'watch','.catalog-product-wrap .product > .box-block','padding-bottom','0','5240','','.catalog-product-wrap'),(913965,'watch','.checkout-index-wrap .checkout-cart-listing.main-listing','padding-bottom','30','','','.checkout-index-wrap'),(913966,'watch','.checkout-index-wrap .edit-address-popup','padding-bottom','20','','','.checkout-index-wrap'),(913967,'watch','.shopping-cart-index .cart-page .empty','padding-bottom','100','','','.shopping-cart-index'),(913968,'watch','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-bottom','10','','','.shopping-cart-index'),(913969,'watch','.account-order-pay .contentColumn','padding-bottom','10','','','.account-order-pay'),(913970,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-bottom','5','','','.account-order-pay'),(913971,'watch','.account-order-pay .history_info > div + div','padding-bottom','0','','','.account-order-pay'),(913972,'watch','.account-order-pay .history_info > div','padding-bottom','0','5240','','.account-order-pay'),(913973,'watch','.account-order-pay .history_info > div + div','padding-bottom','0','5240','','.account-order-pay'),(913974,'watch','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-bottom','10','','','.account-samples'),(913975,'watch','.account-samples .orders-table th','padding-bottom','2','','','.account-samples'),(913976,'watch','.account-samples .order_history_table th','padding-bottom','10','','','.account-samples'),(913977,'watch','.account-samples .view_link','padding-bottom','0','','','.account-samples'),(913978,'watch','.account-samples .orders-table .item','padding-bottom','60','5240','','.account-samples'),(913979,'watch','.account-samples .orders-table .td-alignright','padding-bottom','5','5240','','.account-samples'),(913980,'watch','.account-samples .orders-table td','padding-bottom','5','5240','','.account-samples'),(913981,'watch','.account-sample-info .contentColumn','padding-bottom','10','','','.account-sample-info'),(913982,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-bottom','5','','','.account-sample-info'),(913983,'watch','.account-sample-info .history_info > div + div','padding-bottom','0','','','.account-sample-info'),(913984,'watch','.account-sample-info .popup-tracking-number','padding-bottom','10','','','.account-sample-info'),(913985,'watch','.account-sample-info .history_info > div','padding-bottom','0','5240','','.account-sample-info'),(913986,'watch','.account-sample-info .history_info > div + div','padding-bottom','0','5240','','.account-sample-info'),(913987,'watch','.checkout-order-confirmation .price-row','padding-bottom','5','','','.checkout-order-confirmation'),(913988,'watch','.b-bottom .pop-up-content','padding-bottom','15','','','.b-bottom'),(913989,'watch','.b-form .columns .col-2','padding-bottom','0','','','.b-form'),(913990,'watch','.b-bottom .pop-up-content .buttons','padding-bottom','0','','','.b-bottom'),(913991,'watch','.b-slick .slick-dots li','padding-bottom','5','','','.b-slick'),(913994,'watch','.success-page .check-ico-block','padding-bottom','0','','','.success-page'),(913995,'watch','.success-page .order_totals .price-row','padding-bottom','5','','','.success-page'),(913996,'watch','.success-page .price-row','padding-bottom','5','','','.success-page'),(913997,'watch','.success-page .w-cart-listing .qty','padding-bottom','0','','','.success-page'),(913998,'watch','.b-multi-page-checkout .multi-page-checkout .buttons','padding-bottom','0','','','.b-multi-page-checkout'),(913999,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-bottom','20','','','.b-multi-page-checkout'),(914000,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-bottom','6','','','.b-multi-page-checkout'),(914001,'watch','.b-form .col-left','padding-bottom','0','','','.b-form'),(914002,'watch','.b-form .col-right','padding-bottom','0','','','.b-form'),(914005,'watch','.w-bestsellers .heading-3','padding-bottom','15','','','.w-bestsellers'),(914007,'watch','.w-account-customer-additional-field .tf-file','padding-bottom','5','','','.w-account-customer-additional-field'),(914008,'watch','.w-account-customer-additional-field .tf-file .remove','padding-bottom','0','','','.w-account-customer-additional-field'),(914009,'watch','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','5','','','.w-menu-style-1'),(914010,'watch','.w-menu-style-1 ul','padding-bottom','0','','','.w-menu-style-1'),(914011,'watch','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-bottom','12','5240','','.w-menu-style-1'),(914012,'watch','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-bottom','12','5240','','.w-menu-style-1'),(914013,'watch','.b-slick .slick-list','padding-bottom','0','','','.b-slick'),(914014,'watch','.b-slick .slick-vertical button.slick-next','padding-bottom','0','3','','.b-slick'),(914015,'watch','.b-slick .slick-vertical button.slick-prev','padding-bottom','0','3','','.b-slick'),(914016,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','padding-bottom','0','','','.b-slick'),(914017,'watch','.w-banner .banner-text','padding-bottom','20','','','.w-banner'),(914018,'watch','.w-banner .carousel-text > span','padding-bottom','20','','','.w-banner'),(914019,'watch','.w-catalog-paging .paging-item','padding-bottom','0','','','.w-catalog-paging'),(914020,'watch','.b-data-table table.dataTable tbody td','padding-bottom_important','important','','','.b-data-table'),(914021,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom_important','important','','','.b-data-table'),(914022,'watch','.b-data-table table.dataTable thead td','padding-bottom_important','important','','','.b-data-table'),(914023,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom_important','important','','','.b-data-table'),(914024,'watch','.w-cart-listing .points','padding-bottom_important','important','5232','','.w-cart-listing'),(914025,'watch','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-left','10','','','.w-communication-new-topic'),(914026,'watch','.b-email .heading-name','padding-left','10','','','.b-email'),(914027,'watch','.b-email .name','padding-left','10','','','.b-email'),(914028,'watch','.b-email .heading-image','padding-left','10','','','.b-email'),(914029,'watch','.b-email .heading-price','padding-left','10','','','.b-email'),(914030,'watch','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(914031,'watch','.b-products-listing .products-listing .compare','padding-left','6','','','.b-products-listing'),(914032,'watch','.b-quantity .qty-box input','padding-left','3','','','.b-quantity'),(914033,'watch','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(914034,'watch','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(914035,'watch','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(914036,'watch','.order-summary .btn-2, .order-summary .btn-3','padding-left','5','','','.order-summary'),(914037,'watch','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(914038,'watch','.w-promo-code .holder','padding-left','20','5261','','.w-promo-code'),(914041,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(914042,'watch','.b-email .totals-value','padding-left','10','','','.b-email'),(914043,'watch','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(914044,'watch','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-left','10','','','.p-quick-order-index'),(914045,'watch','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-left','10','','','.p-quick-order-index'),(914046,'watch','.p-quick-order-index ul.token-input-list','padding-left','0','','','.p-quick-order-index'),(914047,'watch','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(914048,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.p-quick-order-index'),(914049,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.p-quick-order-index'),(914050,'watch','.w-promotions .promo-item','padding-left','40','','','.w-promotions'),(914051,'watch','.w-top-categories h2.name','padding-left','3','','','.w-top-categories'),(914052,'watch','.w-cart-compare .attributes-label','padding-left','10','','','.w-cart-compare'),(914059,'watch','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(914060,'watch','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(914061,'watch','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(914062,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(914063,'watch','.b-email .heading-price','padding-left','10','','','.b-email'),(914064,'watch','.b-email .name','padding-left','10','','','.b-email'),(914065,'watch','.w-product-configurator .pc_attr','padding-left','0','5232','','.w-product-configurator'),(914066,'watch','.w-product-configurator .pc_item','padding-left','0','5240','','.w-product-configurator'),(914067,'watch','.testimonials .review','padding-left','10','','',''),(914068,'watch','.testimonials .heading-3','padding-left','55','','',''),(914069,'watch','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(914070,'watch','.w-categories .image','padding-left','0','','','.w-categories'),(914071,'watch','.w-promotions .prom-multi-discount .promo-range','padding-left','20','','','.w-promotions'),(914072,'watch','.w-promotions .prom-multi-discount .promo-product','padding-left','20','','','.w-promotions'),(914073,'watch','.w-promotions .nextdiscount .promo-for-each','padding-left','10','','','.w-promotions'),(914074,'watch','.w-promotions .nextdiscount .content > div','padding-left','10','','','.w-promotions'),(914075,'watch','.w-promotions .promo-salemaker .item','padding-left','20','','','.w-promotions'),(914076,'watch','.w-promotions .promo-salemaker .promo-manufacturers','padding-left','12','','','.w-promotions'),(914077,'watch','.w-promotions .promo-salemaker .discount','padding-left','20','','','.w-promotions'),(914078,'watch','.w-promotions .promo-cart-discount .slave .item','padding-left','20','','','.w-promotions'),(914079,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','padding-left','20','','','.w-promotions'),(914080,'watch','.w-promotions .promo-cart-discount .slave','padding-left','15','','','.w-promotions'),(914081,'watch','.w-promotions .promo-cart-discount .promo-min-qty','padding-left','20','','','.w-promotions'),(914082,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','padding-left','17','','','.b-warehouses-popup'),(914083,'watch','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-left','20','','','.b-warehouses-popup'),(914084,'watch','.w-product-available-in-warehouses .warehouse-item','padding-left','0','','','.w-product-available-in-warehouses'),(914085,'watch','.w-checkout-create-account .account-benefits ul','padding-left','20','','','.w-checkout-create-account'),(914086,'watch','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-left','2','','','.b-products-listing'),(914088,'watch','.w-cart-compare .dropdown li','padding-left','10','','','.w-cart-compare'),(914089,'watch','.w-cart-compare .attributes-cell','padding-left','20','','','.w-cart-compare'),(914092,'watch','.w-breadcrumb .breadcrumb-li','padding-left','0','','','.w-breadcrumb'),(914093,'watch','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(914094,'watch','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(914095,'watch','.w-login-block .new','padding-left','40','','','.w-login-block'),(914096,'watch','.b-bottom .confirm-popup .confirm-text','padding-left','0','','','.b-bottom'),(914097,'watch','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(914098,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(914099,'watch','.b-messages .messages-menu ul','padding-left','0','','','.b-messages'),(914100,'watch','.b-messages .development-content .type-6 .content','padding-left','0','','','.b-messages'),(914101,'watch','.b-messages .msv_btn','padding-left','0','','','.b-messages'),(914102,'watch','.b-messages .msv_content','padding-left','20','','','.b-messages'),(914103,'watch','.b-messages .msv_history','padding-left','20','','','.b-messages'),(914104,'watch','.b-messages .messMenuButton span','padding-left','15','','','.b-messages'),(914105,'watch','.b-messages .messages-menu li a','padding-left','0','','','.b-messages'),(914106,'watch','.b-messages .messages-menu li','padding-left','0','','','.b-messages'),(914107,'watch','.b-messages .content_management_attach button','padding-left','27','','','.b-messages'),(914108,'watch','.b-messages .email-heading','padding-left','15','','','.b-messages'),(914109,'watch','.b-messages .content_management_attach','padding-left','8','','','.b-messages'),(914110,'watch','.b-messages .emailLineTextArea textarea','padding-left','10','','','.b-messages'),(914111,'watch','.b-messages .msv_to_cc','padding-left','15','','','.b-messages'),(914112,'watch','.b-messages .emailBtn','padding-left','10','','','.b-messages'),(914113,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-left','10','','','.b-messages'),(914114,'watch','.w-sitemap-delivery-location > ul > li > ul','padding-left','0','','','.w-sitemap-delivery-location'),(914115,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-left','10','','',''),(914116,'watch','.w-sitemap-delivery-location > ul > li > ul ul','padding-left','20','','','.w-sitemap-delivery-location'),(914117,'watch','.w-tabs .tab-navigation','padding-left','0','','','.w-tabs'),(914118,'watch','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(914119,'watch','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(914120,'watch','.w-reviews-content .item','padding-left','0','','','.w-reviews-content'),(914121,'watch','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(914122,'watch','.w-product-configurator .pc_item','padding-left','0','','','.w-product-configurator'),(914123,'watch','.p-quick-order-index .bottom','padding-left','0','','','.p-quick-order-index'),(914124,'watch','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(914125,'watch','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(914126,'watch','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(914127,'watch','.w-sitemap-delivery-location > ul','padding-left','0','','','.w-sitemap-delivery-location'),(914128,'watch','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(914129,'watch','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(914130,'watch','.w-checkout-terms .required-message','padding-left','10','','','.w-checkout-terms'),(914131,'watch','.w-cart-listing .item .remove','padding-left','10','5240','','.w-cart-listing'),(914132,'watch','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(914133,'watch','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(914134,'watch','.w-socials > li','padding-left','15','','','.w-socials'),(914135,'watch','.b-info .info','padding-left','40','','','.b-info'),(914136,'watch','.b-form .required-message-wrap','padding-left','0','','','.b-form'),(914137,'watch','.b-email .image','padding-left','10','','','.b-email'),(914138,'watch','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(914139,'watch','.b-quantity .qty-box input','padding-left','3','','','.b-quantity'),(914140,'watch','.w-upload-customer-id-upload-customer-id-form .dz-preview','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(914141,'watch','.w-upload-customer-id-upload-customer-id-form .dz-details','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(914142,'watch','.b-table .table .headings td','padding-left','10','','','.b-table'),(914143,'watch','.b-info .info li','padding-left','0','','','.b-info'),(914144,'watch','.b-email .model','padding-left','10','','','.b-email'),(914145,'watch','.b-email .heading-name','padding-left','10','','','.b-email'),(914146,'watch','.b-email .heading-model','padding-left','10','','','.b-email'),(914147,'watch','.b-products-listing .products-listing .bonus-points-cost','padding-left','20','','','.b-products-listing'),(914148,'watch','.w-login-block .guest','padding-left','40','','','.w-login-block'),(914149,'watch','.w-login-block .new','padding-left','40','','','.w-login-block'),(914150,'watch','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(914151,'watch','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-left','10','','','.w-menu-horizontal'),(914152,'watch','.w-menu-horizontal > ul > li > ul > li','padding-left','10','','','.w-menu-horizontal'),(914153,'watch','.w-menu-horizontal ul','padding-left','0','','','.w-menu-horizontal'),(914154,'watch','.b-table .table td','padding-left','15','','','.b-table'),(914155,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(914156,'watch','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(914157,'watch','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(914158,'watch','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(914159,'watch','.w-product-images-additional .images','padding-left','0','5261','','.w-product-images-additional'),(914160,'watch','.b-form .login-col-1','padding-left','0','','','.b-form'),(914161,'watch','.b-email .heading-image','padding-left','10','','','.b-email'),(914162,'watch','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(914163,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(914164,'watch','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-left','0','','','.order-summary'),(914165,'watch','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(914166,'watch','.b-email .price','padding-left','10','','','.b-email'),(914167,'watch','.b-email .heading-model','padding-left','10','','','.b-email'),(914168,'watch','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-left','10','5245','',''),(914169,'watch','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(914170,'watch','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(914171,'watch','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(914172,'watch','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(914173,'watch','.w-product-properties li','padding-left','0','','','.w-product-properties'),(914174,'watch','.w-categories .item','padding-left','20','','','.w-categories'),(914175,'watch','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(914176,'watch','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(914177,'watch','.w-product-configurator .pc_item','padding-left','0','','','.w-product-configurator'),(914178,'watch','.b-bottom .terms-info-popup .pop-up-content','padding-left','20','','','.b-bottom'),(914179,'watch','.w-cart-compare .dropdown .dropdown-menu','padding-left','0','','','.w-cart-compare'),(914180,'watch','textarea','padding-left','10','','',''),(914181,'watch','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(914182,'watch','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(914183,'watch','.w-product-configurator .pc_item','padding-left','0','','','.w-product-configurator'),(914186,'watch','.w-socials > li','padding-left','15','','','.w-socials'),(914187,'watch','.w-reviews-content .review','padding-left','20','','','.w-reviews-content'),(914188,'watch','.w-filters .filter-ul-content','padding-left','0','','','.w-filters'),(914189,'watch','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(914190,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(914191,'watch','.message.success','padding-left','40','','',''),(914192,'watch','.p-quick-order-index .all-scroll-div','padding-left','0','','','.p-quick-order-index'),(914193,'watch','.w-personal-gift-status-bar .end-label','padding-left','5','','','.w-personal-gift-status-bar'),(914194,'watch','.w-product-configurator .pc_attr','padding-left','0','5232','','.w-product-configurator'),(914195,'watch','.w-promo-code .heading-4','padding-left','30','5261','','.w-promo-code'),(914196,'watch','.b-email .heading-model','padding-left','10','','','.b-email'),(914197,'watch','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(914198,'watch','.b-email .heading-name','padding-left','10','','','.b-email'),(914199,'watch','.b-email .name','padding-left','10','','','.b-email'),(914200,'watch','.b-email .qty','padding-left','10','','','.b-email'),(914201,'watch','.b-email .totals-value','padding-left','10','','','.b-email'),(914202,'watch','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-left','0','','','.b-fancybox'),(914203,'watch','.w-checkout-shipping-choice span','padding-left','0','','','.w-checkout-shipping-choice'),(914204,'watch','.b-info .info','padding-left','40','','','.b-info'),(914205,'watch','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(914206,'watch','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(914207,'watch','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(914208,'watch','.b-fancybox .fancybox-title-over-wrap','padding-left','10','','','.b-fancybox'),(914209,'watch','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(914210,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-left','0','','','.b-select-suggest'),(914211,'watch','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(914212,'watch','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(914213,'watch','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(914214,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(914215,'watch','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(914216,'watch','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(914217,'watch','.w-reviews .review','padding-left','10','','','.w-reviews'),(914218,'watch','.w-socials > li','padding-left','15','','','.w-socials'),(914221,'watch','.b-compare .popupCompare td.level-2:first-child','padding-left','12','','','.b-compare'),(914222,'watch','.b-info-popup .info-popup div','padding-left','15','','','.b-info-popup'),(914223,'watch','.b-form .payment-method .item','padding-left','0','','','.b-form'),(914224,'watch','.b-form .password-forgotten-link','padding-left','0','','','.b-form'),(914225,'watch','.b-quantity .qty-box input','padding-left','3','','','.b-quantity'),(914226,'watch','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(914227,'watch','.w-cart-compare .price-label','padding-left','10','','','.w-cart-compare'),(914228,'watch','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(914229,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-left','10','','','.w-image-maps'),(914230,'watch','.w-promo-code .holder','padding-left','20','5261','','.w-promo-code'),(914231,'watch','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(914232,'watch','.w-reviews .heading-3','padding-left','55','','','.w-reviews'),(914233,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(914235,'watch','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(914236,'watch','.b-email .name','padding-left','10','','','.b-email'),(914237,'watch','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(914238,'watch','.b-email .heading-name','padding-left','10','','','.b-email'),(914239,'watch','.b-email .heading-image','padding-left','10','','','.b-email'),(914240,'watch','.b-email .image','padding-left','10','','','.b-email'),(914241,'watch','.b-email .heading-qty','padding-left','10','','','.b-email'),(914242,'watch','.b-email .totals-value','padding-left','10','','','.b-email'),(914243,'watch','.b-email .price','padding-left','10','','','.b-email'),(914244,'watch','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(914245,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(914246,'watch','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-left','0','','','.w-multi-cart-actions'),(914247,'watch','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(914248,'watch','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(914249,'watch','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(914251,'watch','.w-top-categories .item','padding-left','20','','','.w-top-categories'),(914252,'watch','.w-tabs > .block','padding-left','20','','','.w-tabs'),(914253,'watch','.w-cart-cart-tabs .w-tabs > .block','padding-left','0','','','.w-cart-cart-tabs'),(914254,'watch','.w-tabs .accordion-heading','padding-left','8','5232','','.w-tabs'),(914255,'watch','.w-tabs .tab-a','padding-left','6','','','.w-tabs'),(914256,'watch','.w-tabs .tab-li','padding-left','0','','','.w-tabs'),(914257,'watch','.w-socials > li','padding-left','15','','','.w-socials'),(914260,'watch','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(914261,'watch','.b-bottom .popup-box-wrap','padding-left','10','','','.b-bottom'),(914262,'watch','.b-bottom .popup-buttons','padding-left','15','','','.b-bottom'),(914263,'watch','.w-product-configurator .pc_item','padding-left','0','5240','','.w-product-configurator'),(914264,'watch','.b-quantity .qty-box input','padding-left','3','','','.b-quantity'),(914265,'watch','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(914266,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(914267,'watch','.w-chat .w-chat-box','padding-left','12','','','.w-chat'),(914268,'watch','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(914269,'watch','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(914270,'watch','.b-form .required-message','padding-left','3','','','.b-form'),(914271,'watch','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(914272,'watch','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(914273,'watch','.w-quote .cart-box-link','padding-left','14','5240','','.w-quote'),(914274,'watch','.btn-1','padding-left','25','','',''),(914275,'watch','.b-autocomplete .ui-autocomplete li','padding-left','10','','','.b-autocomplete'),(914276,'watch','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(914277,'watch','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(914278,'watch','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(914279,'watch','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(914280,'watch','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(914281,'watch','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(914282,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(914283,'watch','.b-table .table td','padding-left','15','','','.b-table'),(914284,'watch','.b-table .table .headings td','padding-left','10','','','.b-table'),(914285,'watch','.w-socials > li','padding-left','15','','','.w-socials'),(914286,'watch','.w-login-block .guest','padding-left','40','','','.w-login-block'),(914287,'watch','.b-products-listing .products-listing .buyButton .btn','padding-left','10','','','.b-products-listing'),(914288,'watch','.w-product-images-additional .images','padding-left','0','5261','','.w-product-images-additional'),(914289,'watch','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block','padding-left','10','5245','',''),(914290,'watch','.b-products-listing .products-listing .bonus-points-price','padding-left','20','','','.b-products-listing'),(914291,'watch','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(914292,'watch','.b-email .heading-qty','padding-left','10','','','.b-email'),(914293,'watch','.order-summary .price-row','padding-left','0','','','.order-summary'),(914294,'watch','.b-email .heading-image','padding-left','10','','','.b-email'),(914295,'watch','.w-quote .no-text','padding-left','10','','','.w-quote'),(914296,'watch','.w-product-configurator .pc_item','padding-left','0','','','.w-product-configurator'),(914297,'watch','.b-select-suggest .select2-drop-mask','padding-left','0','','','.b-select-suggest'),(914298,'watch','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(914299,'watch','.w-product-properties li','padding-left','0','','','.w-product-properties'),(914300,'watch','.w-reviews .author','padding-left','10','','','.w-reviews'),(914302,'watch','.testimonials .answer','padding-left','30','','',''),(914303,'watch','.w-product-configurator .pc_attr','padding-left','0','5232','','.w-product-configurator'),(914304,'watch','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(914305,'watch','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(914306,'watch','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(914307,'watch','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(914308,'watch','.b-fancybox .fancybox-title-float-wrap .child','padding-left','20','','','.b-fancybox'),(914309,'watch','.w-checkout-shipping-choice span','padding-left','10','5261','','.w-checkout-shipping-choice'),(914310,'watch','.w-product-personal-catalog-button .btn','padding-left','25','','','.w-product-personal-catalog-button'),(914311,'watch','.w-top-categories .categories h2','padding-left','0','','','.w-top-categories'),(914312,'watch','.w-top-categories .image','padding-left','0','','','.w-top-categories'),(914313,'watch','.w-product-reviews .reviews-list .review','padding-left','10','','','.w-product-reviews'),(914314,'watch','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(914315,'watch','.b-email .model','padding-left','10','','','.b-email'),(914316,'watch','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(914317,'watch','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(914318,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(914319,'watch','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(914320,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(914321,'watch','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(914322,'watch','.w-product-properties li','padding-left','0','','','.w-product-properties'),(914323,'watch','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(914324,'watch','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(914325,'watch','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(914326,'watch','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(914327,'watch','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(914328,'watch','.b-email .price','padding-left','10','','','.b-email'),(914329,'watch','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(914330,'watch','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(914331,'watch','.w-product-configurator .pc_item','padding-left','0','','','.w-product-configurator'),(914332,'watch','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(914333,'watch','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(914334,'watch','.w-promo-code .heading-4','padding-left','30','5261','','.w-promo-code'),(914335,'watch','.w-product-images-additional .images','padding-left','0','5261','','.w-product-images-additional'),(914336,'watch','.b-bottom .popup-heading','padding-left','15','','','.b-bottom'),(914337,'watch','.b-bottom .popup-simple','padding-left','20','','','.b-bottom'),(914338,'watch','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(914339,'watch','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(914340,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(914341,'watch','.b-email .image','padding-left','10','','','.b-email'),(914342,'watch','.b-email .heading-qty','padding-left','10','','','.b-email'),(914343,'watch','.b-email .name','padding-left','10','','','.b-email'),(914344,'watch','.b-email .heading-price','padding-left','10','','','.b-email'),(914345,'watch','.b-email .heading-model','padding-left','10','','','.b-email'),(914346,'watch','.b-email .totals-value','padding-left','10','','','.b-email'),(914347,'watch','.b-email .qty','padding-left','10','','','.b-email'),(914348,'watch','.b-email .totals-title','padding-left','10','','','.b-email'),(914349,'watch','.b-email .model','padding-left','10','','','.b-email'),(914350,'watch','.b-email .heading-name','padding-left','10','','','.b-email'),(914351,'watch','.b-email .heading-image','padding-left','10','','','.b-email'),(914352,'watch','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(914353,'watch','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(914354,'watch','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(914355,'watch','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(914356,'watch','.w-checkout-create-account .create-account','padding-left','0','','','.w-checkout-create-account'),(914357,'watch','.w-checkout-shipping .sub-item','padding-left','0','','','.w-checkout-shipping'),(914358,'watch','.b-info .info','padding-left','40','','','.b-info'),(914359,'watch','.b-email .totals-value','padding-left','10','','','.b-email'),(914360,'watch','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(914361,'watch','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(914362,'watch','.b-table .table td','padding-left','15','','','.b-table'),(914363,'watch','.b-table .table .headings td','padding-left','10','','','.b-table'),(914364,'watch','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(914365,'watch','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(914366,'watch','.w-promo-code .holder','padding-left','20','5261','','.w-promo-code'),(914367,'watch','.w-promo-code .heading-4','padding-left','30','5261','','.w-promo-code'),(914368,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(914369,'watch','.b-form .shipping-method .input','padding-left','0','','','.b-form'),(914370,'watch','.b-form .center-buttons','padding-left','0','','','.b-form'),(914371,'watch','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(914372,'watch','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(914373,'watch','.b-info .info li','padding-left','0','','','.b-info'),(914374,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(914375,'watch','.w-reviews .item','padding-left','0','','','.w-reviews'),(914376,'watch','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(914377,'watch','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(914378,'watch','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(914379,'watch','.b-select-suggest .select2-container .select2-choice','padding-left','8','','','.b-select-suggest'),(914380,'watch','.b-sub-totals .historyTotal td','padding-left','5','','','.b-sub-totals'),(914381,'watch','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(914382,'watch','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(914383,'watch','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(914384,'watch','.w-breadcrumb .breadcrumb-li','padding-left','0','','','.w-breadcrumb'),(914385,'watch','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(914386,'watch','.w-personal-gift-status-bar .end-date','padding-left','5','3','','.w-personal-gift-status-bar'),(914387,'watch','.b-info .info','padding-left','40','','','.b-info'),(914388,'watch','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(914390,'watch','.b-upload-files .upload-files','padding-left','10','','','.b-upload-files'),(914391,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(914392,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(914393,'watch','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(914394,'watch','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(914395,'watch','.w-login-block .guest','padding-left','40','','','.w-login-block'),(914396,'watch','.w-login-block .new','padding-left','40','','','.w-login-block'),(914397,'watch','.w-product-images-additional .images','padding-left','0','5261','','.w-product-images-additional'),(914398,'watch','.w-checkout-shipping-address .edit-ab','padding-left','15','','','.w-checkout-shipping-address'),(914399,'watch','.b-info .info ul','padding-left','0','','','.b-info'),(914400,'watch','.b-info .info li','padding-left','0','','','.b-info'),(914401,'watch','.b-bottom .header-error','padding-left','20','','','.b-bottom'),(914402,'watch','.w-categories h2.name','padding-left','3','','','.w-categories'),(914403,'watch','.w-cart-discount-coupon .btn','padding-left','15','','','.w-cart-discount-coupon'),(914404,'watch','.b-form .form-buttons','padding-left','0','','','.b-form'),(914405,'watch','.b-form .payment-method .item-radio label span','padding-left','5','','','.b-form'),(914406,'watch','.w-checkout-billing-address .same-address','padding-left','10','','','.w-checkout-billing-address'),(914407,'watch','.btn-3','padding-left','25','','',''),(914408,'watch','.w-breadcrumb .breadcrumb-li','padding-left','0','','','.w-breadcrumb'),(914409,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(914410,'watch','.w-product-personal-catalog-button .btn','padding-left','25','','','.w-product-personal-catalog-button'),(914411,'watch','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(914412,'watch','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(914413,'watch','.w-cart-compare .delete-cart','padding-left','10','','','.w-cart-compare'),(914414,'watch','.w-cart-compare .price-cell','padding-left','20','','','.w-cart-compare'),(914415,'watch','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','60','','','.b-select-suggest'),(914416,'watch','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(914417,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(914418,'watch','.b-info .info','padding-left','40','','','.b-info'),(914419,'watch','.b-info .info li','padding-left','0','','','.b-info'),(914420,'watch','.b-email .totals-title','padding-left','10','','','.b-email'),(914421,'watch','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(914422,'watch','.b-email .heading-qty','padding-left','10','','','.b-email'),(914423,'watch','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','padding-left','10','','','.b-bottom'),(914424,'watch','.w-product-images-additional .images','padding-left','0','5261','','.w-product-images-additional'),(914425,'watch','.w-product-configurator .pc_attr','padding-left','0','5232','','.w-product-configurator'),(914426,'watch','.w-promo-code .heading-4','padding-left','30','5261','','.w-promo-code'),(914427,'watch','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-left','20','','','.b-bottom'),(914428,'watch','.b-bottom .cart-options .cart-item input[type=\"text\"]','padding-left','0','','','.b-bottom'),(914429,'watch','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-left','6','','','.b-compare'),(914430,'watch','.w-cart-compare .cart-cell','padding-left','7','','','.w-cart-compare'),(914431,'watch','.w-cart-compare .product','padding-left','15','','','.w-cart-compare'),(914432,'watch','.w-promotions .promo-cart-discount .master .item','padding-left','20','','','.w-promotions'),(914433,'watch','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(914434,'watch','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(914435,'watch','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(914436,'watch','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(914437,'watch','.w-product-configurator .pc_item','padding-left','0','','','.w-product-configurator'),(914438,'watch','.b-bottom .alert-message','padding-left','20','','','.b-bottom'),(914439,'watch','.b-bottom .cart-options','padding-left','20','','','.b-bottom'),(914440,'watch','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','5240','','.w-menu-horizontal'),(914441,'watch','.w-login-block .guest','padding-left','40','','','.w-login-block'),(914442,'watch','.b-select-suggest .select2-results .select2-result-label','padding-left','7','','','.b-select-suggest'),(914443,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(914444,'watch','.w-login-block .new','padding-left','40','','','.w-login-block'),(914445,'watch','.w-login-block .guest','padding-left','40','','','.w-login-block'),(914446,'watch','.w-quote .cart-box-link','padding-left','10','','','.w-quote'),(914447,'watch','.b-info .info ul','padding-left','0','','','.b-info'),(914448,'watch','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(914449,'watch','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(914450,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(914451,'watch','.b-email .totals-value','padding-left','10','','','.b-email'),(914452,'watch','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(914453,'watch','.b-info .info ul','padding-left','0','','','.b-info'),(914454,'watch','.b-email .totals-title','padding-left','10','','','.b-email'),(914455,'watch','.b-email .qty','padding-left','10','','','.b-email'),(914456,'watch','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(914457,'watch','.b-email .heading-price','padding-left','10','','','.b-email'),(914458,'watch','.b-bottom .rfq-form','padding-left','20','','','.b-bottom'),(914459,'watch','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(914460,'watch','.b-bottom .footerTitle','padding-left','0','5232','','.b-bottom'),(914461,'watch','.b-bottom .pop-up-close','padding-left','1','','','.b-bottom'),(914462,'watch','.w-product-personal-catalog-button .btn','padding-left','25','','','.w-product-personal-catalog-button'),(914463,'watch','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(914464,'watch','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(914465,'watch','.b-info .info li','padding-left','0','','','.b-info'),(914466,'watch','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(914467,'watch','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(914468,'watch','.w-cart-up-sell .w-list-type-1','padding-left','0','','','.w-cart-up-sell'),(914469,'watch','.w-cart-shipping-estimator .address-item','padding-left','0','','','.w-cart-shipping-estimator'),(914470,'watch','.w-cart-up-sell .w-list-type-1 .item','padding-left','20','1','','.w-cart-up-sell'),(914471,'watch','.w-cart-up-sell .w-list-type-1 .item','padding-left','21','','','.w-cart-up-sell'),(914472,'watch','.w-product-configurator .pc_item','padding-left','0','5240','','.w-product-configurator'),(914473,'watch','.b-products-listing .products-listing .btn-buy','padding-left','10','','','.b-products-listing'),(914474,'watch','.b-upload-files .added-file','padding-left','0','','','.b-upload-files'),(914475,'watch','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(914476,'watch','.w-menu-big ul','padding-left','0','','','.w-menu-big'),(914477,'watch','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(914478,'watch','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(914479,'watch','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(914480,'watch','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(914481,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(914482,'watch','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(914483,'watch','.w-promo-code .holder','padding-left','20','5261','','.w-promo-code'),(914484,'watch','.b-bottom .pop-up-info','padding-left','20','','','.b-bottom'),(914485,'watch','.b-email .heading-price','padding-left','10','','','.b-email'),(914486,'watch','.b-email .image','padding-left','10','','','.b-email'),(914487,'watch','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(914488,'watch','.b-fancybox .fancybox-error','padding-left','15','','','.b-fancybox'),(914489,'watch','.w-cart-compare .product .stock','padding-left','3','','','.w-cart-compare'),(914490,'watch','.b-fancybox .fancybox-next span','padding-left','4','3','','.b-fancybox'),(914491,'watch','.b-info .info','padding-left','40','','','.b-info'),(914492,'watch','.b-form .middle-form','padding-left','0','','','.b-form'),(914493,'watch','.b-info .info ul','padding-left','0','','','.b-info'),(914494,'watch','.w-product-customers-activity .customers-activity','padding-left','20','','','.w-product-customers-activity'),(914495,'watch','.b-table .table td','padding-left','15','','','.b-table'),(914496,'watch','.b-compare .compare-box-item','padding-left','10','','','.b-compare'),(914497,'watch','.b-compare .compare-head','padding-left','10','','','.b-compare'),(914498,'watch','.b-email .model','padding-left','10','','','.b-email'),(914499,'watch','.b-email .image','padding-left','10','','','.b-email'),(914500,'watch','.b-email .heading-qty','padding-left','10','','','.b-email'),(914501,'watch','.b-email .totals-title','padding-left','10','','','.b-email'),(914502,'watch','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(914503,'watch','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(914504,'watch','.b-table .table .headings td','padding-left','10','','','.b-table'),(914506,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(914507,'watch','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(914508,'watch','.w-product-properties li','padding-left','0','','','.w-product-properties'),(914509,'watch','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(914510,'watch','.w-product-personal-catalog-button .btn','padding-left','25','','','.w-product-personal-catalog-button'),(914512,'watch','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(914513,'watch','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(914514,'watch','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(914515,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(914516,'watch','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(914517,'watch','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(914518,'watch','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(914519,'watch','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(914520,'watch','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(914521,'watch','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(914522,'watch','.w-login-block .new','padding-left','40','','','.w-login-block'),(914523,'watch','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(914524,'watch','.w-login-block .guest','padding-left','40','','','.w-login-block'),(914525,'watch','.w-checkout-billing-address .edit-ab','padding-left','15','','','.w-checkout-billing-address'),(914526,'watch','.w-checkout-billing-address .addresses.address-main label','padding-left','0','','','.w-checkout-billing-address'),(914527,'watch','.w-checkout-billing-address .addresses .address-item label','padding-left','15','','','.w-checkout-billing-address'),(914528,'watch','.w-promo-code .holder','padding-left','20','5261','','.w-promo-code'),(914529,'watch','.w-promo-code .heading-4','padding-left','30','5261','','.w-promo-code'),(914530,'watch','.w-product-images-additional .images','padding-left','0','5261','','.w-product-images-additional'),(914531,'watch','.w-product-configurator .pc_attr','padding-left','0','5232','','.w-product-configurator'),(914532,'watch','.w-cart-checkout-btn a','padding-left','12','5232','','.w-cart-checkout-btn'),(914533,'watch','.w-tabs .accordion-heading','padding-left','6','','','.w-tabs'),(914534,'watch','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(914535,'watch','.b-bottom .header-info','padding-left','20','','','.b-bottom'),(914536,'watch','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(914537,'watch','.w-personal-gift-status-bar .start-label','padding-left','30','','','.w-personal-gift-status-bar'),(914538,'watch','.b-upload-file .upload-file-template','padding-left','1','','','.b-upload-file'),(914539,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(914540,'watch','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','padding-left','5','','','.b-switch'),(914541,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-left','5','','','.b-select-suggest'),(914542,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-left','18','','','.b-select-suggest'),(914543,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-left','5','','','.b-select-suggest'),(914544,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-left','0','','','.b-select-suggest'),(914545,'watch','.b-select-suggest .select2-locked','padding-left','5','','','.b-select-suggest'),(914546,'watch','.b-select-suggest .select2-container-multi .select2-choices','padding-left','0','','','.b-select-suggest'),(914547,'watch','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','100','','','.b-select-suggest'),(914548,'watch','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','120','','','.b-select-suggest'),(914549,'watch','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','110','','','.b-select-suggest'),(914550,'watch','.b-select-suggest .select2-results ul.select2-result-sub','padding-left','0','','','.b-select-suggest'),(914551,'watch','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','80','','','.b-select-suggest'),(914552,'watch','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','40','','','.b-select-suggest'),(914553,'watch','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','','','.w-menu-horizontal'),(914554,'watch','.b-select-suggest .select2-results','padding-left','4','','','.b-select-suggest'),(914555,'watch','.w-checkout-shipping-address .addresses .address-item label','padding-left','15','','','.w-checkout-shipping-address'),(914556,'watch','.b-select-suggest .select2-results ul.select2-result-sub > li .select2-result-label','padding-left','20','','','.b-select-suggest'),(914557,'watch','.b-form .shipping-method .item + .item','padding-left','0','','','.b-form'),(914558,'watch','.w-checkout-shipping-address .addresses.address-main label','padding-left','0','','','.w-checkout-shipping-address'),(914559,'watch','.b-select-suggest .select2-search input','padding-left','5','','','.b-select-suggest'),(914560,'watch','.b-select-suggest .select2-search','padding-left','4','','','.b-select-suggest'),(914561,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(914563,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(914564,'watch','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(914565,'watch','.w-cart-compare .product-label','padding-left','10','','','.w-cart-compare'),(914566,'watch','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(914567,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(914568,'watch','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(914569,'watch','.w-product-personal-catalog-button .btn','padding-left','25','','','.w-product-personal-catalog-button'),(914570,'watch','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(914571,'watch','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(914572,'watch','.b-table .table .headings td','padding-left','10','','','.b-table'),(914573,'watch','.b-compare .col-two label','padding-left','0','','','.b-compare'),(914575,'watch','.w-product-personal-catalog-button .btn','padding-left','25','','','.w-product-personal-catalog-button'),(914576,'watch','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(914577,'watch','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(914578,'watch','.w-product-configurator .pc_attr','padding-left','0','5232','','.w-product-configurator'),(914579,'watch','.b-bottom .notify-form','padding-left','20','','','.b-bottom'),(914580,'watch','.w-account-addresses-list .addsess-suggestion-item','padding-left','0','','','.w-account-addresses-list'),(914581,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.b-data-table'),(914582,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.b-data-table'),(914583,'watch','.w-communication-post .communication-post-author','padding-left','0','','','.w-communication-post'),(914584,'watch','.b-products-listing .products-listing a.btn.view-button','padding-left','0','','','.b-products-listing'),(914585,'watch','.b-products-listing .in-cart','padding-left','10','','','.b-products-listing'),(914586,'watch','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-left','5','','','.w-catalog-b2b-add-button'),(914587,'watch','.b-products-listing .products-listing h2','padding-left','0','','','.b-products-listing'),(914588,'watch','.b-products-listing .promos-info .promo-item','padding-left','0','','','.b-products-listing'),(914589,'watch','.b-products-listing .promos-info .promo-name','padding-left','15','','','.b-products-listing'),(914590,'watch','.blogsidebar','padding-left','35','','',''),(914596,'watch','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(914597,'watch','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(914598,'watch','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(914599,'watch','.b-quantity .qty-box input','padding-left','3','','','.b-quantity'),(914600,'watch','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(914601,'watch','.w-checkout-gdpr .terms-login','padding-left','0','','','.w-checkout-gdpr'),(914602,'watch','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(914603,'watch','.w-checkout-gdpr .privacy-row','padding-left','0','','','.w-checkout-gdpr'),(914604,'watch','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(914605,'watch','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(914606,'watch','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(914607,'watch','.b-compare .column_wrapper','padding-left','10','','','.b-compare'),(914608,'watch','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(914609,'watch','.b-email .price','padding-left','10','','','.b-email'),(914610,'watch','.b-email .heading-name','padding-left','10','','','.b-email'),(914611,'watch','.b-email .heading-model','padding-left','10','','','.b-email'),(914612,'watch','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(914613,'watch','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(914614,'watch','.w-product-configurator .pc_item','padding-left','0','5240','','.w-product-configurator'),(914616,'watch','.w-top-categories .item','padding-left','10','5232','','.w-top-categories'),(914617,'watch','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(914618,'watch','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(914619,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(914620,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(914621,'watch','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(914622,'watch','.w-personal-gift-status-bar .timeline','padding-left','10','','','.w-personal-gift-status-bar'),(914623,'watch','.w-personal-gift-status-bar .inform','padding-left','5','4','','.w-personal-gift-status-bar'),(914624,'watch','.b-table .table td','padding-left','15','','','.b-table'),(914625,'watch','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(914626,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-left','0','','',''),(914627,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-left','0','','','.b-h-inline'),(914628,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-left','5','','','.w-communication-new-topic'),(914629,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-left','10','','','.w-communication-new-topic'),(914630,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-left','5','','','.w-communication-new-topic'),(914631,'watch','.w-communication-new-topic #communication_topic_form .middle-form','padding-left','0','','','.w-communication-new-topic'),(914632,'watch','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(914633,'watch','.b-email .heading-price','padding-left','10','','','.b-email'),(914634,'watch','.b-email .image','padding-left','10','','','.b-email'),(914635,'watch','.btn-2','padding-left','25','','',''),(914636,'watch','.b-quantity .qty-box input','padding-left','3','','','.b-quantity'),(914637,'watch','.b-compare .compare_pagination','padding-left','0','','','.b-compare'),(914638,'watch','.b-bottom .popup-content','padding-left','15','','','.b-bottom'),(914639,'watch','.w-product-configurator .pc_item','padding-left','0','5240','','.w-product-configurator'),(914640,'watch','.w-reviews-content .author','padding-left','20','','','.w-reviews-content'),(914641,'watch','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(914642,'watch','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(914643,'watch','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(914644,'watch','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(914645,'watch','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(914646,'watch','.b-email .qty','padding-left','10','','','.b-email'),(914647,'watch','.w-login-block .new','padding-left','40','','','.w-login-block'),(914648,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(914649,'watch','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(914650,'watch','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(914651,'watch','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-left','0','','','.b-fancybox'),(914652,'watch','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(914653,'watch','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(914654,'watch','.b-email .heading-image','padding-left','10','','','.b-email'),(914655,'watch','.b-email .price','padding-left','10','','','.b-email'),(914656,'watch','.products-quick-index .token-input-list','padding-left','0','','',''),(914657,'watch','.w-product-configurator .pc_item','padding-left','0','5240','','.w-product-configurator'),(914658,'watch','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(914659,'watch','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(914660,'watch','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(914661,'watch','.b-info .info ul','padding-left','0','','','.b-info'),(914662,'watch','.b-form .shipping-method .item','padding-left','0','','','.b-form'),(914663,'watch','.b-email .model','padding-left','10','','','.b-email'),(914664,'watch','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(914665,'watch','.w-promo-code .holder','padding-left','20','5261','','.w-promo-code'),(914666,'watch','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(914667,'watch','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(914668,'watch','.w-cart-listing .item .gift-wrap label','padding-left','10','','','.w-cart-listing'),(914669,'watch','.w-cart-listing .item > div','padding-left','10','','','.w-cart-listing'),(914670,'watch','.w-cart-listing .points-earn','padding-left','25','','','.w-cart-listing'),(914671,'watch','.w-cart-listing .points-redeem','padding-left','25','','','.w-cart-listing'),(914672,'watch','.w-cart-listing .item .gift-wrap .value','padding-left','5','','','.w-cart-listing'),(914673,'watch','.w-cart-listing .item .gift-wrap','padding-left','0','5240','','.w-cart-listing'),(914674,'watch','.w-cart-give-away .ga_img','padding-left','1','','','.w-cart-give-away'),(914675,'watch','.w-breadcrumb .breadcrumb-li','padding-left','0','','','.w-breadcrumb'),(914676,'watch','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(914684,'watch','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(914685,'watch','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(914686,'watch','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(914687,'watch','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(914688,'watch','.b-info .info li','padding-left','0','','','.b-info'),(914689,'watch','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(914690,'watch','.b-email .heading-model','padding-left','10','','','.b-email'),(914691,'watch','.b-email .model','padding-left','10','','','.b-email'),(914692,'watch','.b-compare .col-gender','padding-left','0','','','.b-compare'),(914693,'watch','.w-socials > li','padding-left','15','','','.w-socials'),(914694,'watch','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(914695,'watch','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(914696,'watch','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(914697,'watch','.w-product-properties li','padding-left','0','','','.w-product-properties'),(914698,'watch','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(914699,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(914700,'watch','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(914701,'watch','.b-compare .popupCompare td.level-3:first-child','padding-left','18','','','.b-compare'),(914703,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(914704,'watch','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(914705,'watch','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(914706,'watch','.b-table .table .headings td','padding-left','10','','','.b-table'),(914707,'watch','.w-breadcrumb .breadcrumb-li','padding-left','0','','','.w-breadcrumb'),(914708,'watch','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(914709,'watch','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(914710,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(914711,'watch','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(914712,'watch','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(914713,'watch','.w-filters .fsl_handle','padding-left','0','','','.w-filters'),(914714,'watch','.w-filters .head-filter-widget','padding-left','10','5240','','.w-filters'),(914715,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(914716,'watch','.w-catalog-sorting .before','padding-left','0','','','.w-catalog-sorting'),(914717,'watch','.w-filters .ui-slider-range','padding-left','0','','','.w-filters'),(914718,'watch','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(914719,'watch','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(914720,'watch','.w-breadcrumb .breadcrumb-li','padding-left','0','','','.w-breadcrumb'),(914721,'watch','.w-filters .head-filter-widget','padding-left','0','','','.w-filters'),(914722,'watch','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(914723,'watch','.b-autocomplete .ui-autocomplete','padding-left','2','','','.b-autocomplete'),(914724,'watch','.w-promo-code .heading-4','padding-left','30','5261','','.w-promo-code'),(914725,'watch','.order-summary .heading-2','padding-left','25','','','.order-summary'),(914726,'watch','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(914727,'watch','.b-email .name','padding-left','10','','','.b-email'),(914728,'watch','.b-email .totals-title','padding-left','10','','','.b-email'),(914729,'watch','.b-email .heading-qty','padding-left','10','','','.b-email'),(914730,'watch','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(914731,'watch','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(914732,'watch','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(914733,'watch','.w-product-properties li','padding-left','0','','','.w-product-properties'),(914734,'watch','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(914735,'watch','.b-data-table table.dataTable tbody td','padding-left','20','','','.b-data-table'),(914736,'watch','.b-data-table table.dataTable thead td','padding-left','20','','','.b-data-table'),(914737,'watch','.b-compare .popupCompare .pop-up-content','padding-left','10','','','.b-compare'),(914738,'watch','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(914739,'watch','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(914740,'watch','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(914741,'watch','.b-table .table td','padding-left','15','','','.b-table'),(914742,'watch','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(914743,'watch','.b-info .info ul','padding-left','0','','','.b-info'),(914744,'watch','.b-email .qty','padding-left','10','','','.b-email'),(914745,'watch','.b-email .totals-title','padding-left','10','','','.b-email'),(914746,'watch','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(914748,'watch','.b-email .qty','padding-left','10','','','.b-email'),(914749,'watch','.b-email .price','padding-left','10','','','.b-email'),(914750,'watch','.btn','padding-left','25','','',''),(914751,'watch','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(914752,'watch','.b-product-images .media-popup .mp-content','padding-left','5','','','.b-product-images'),(914753,'watch','.b-product-images .media-popup .mp-small-images .item','padding-left','10','','','.b-product-images'),(914754,'watch','.b-product-images .media-popup .slick-dots','padding-left','0','','','.b-product-images'),(914755,'watch','.b-product-images .media-popup .slick-dots li','padding-left','0','','','.b-product-images'),(914756,'watch','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-left','0','','','.b-menu-style'),(914757,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-left','5','','','.b-menu-style-1'),(914758,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-left','20','','','.b-menu-style-1'),(914759,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-left','20','','','.b-menu-style-1'),(914760,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-left','20','','','.b-menu-style-1'),(914761,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-left','0','','','.b-menu-style-2'),(914762,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-left','0','','','.b-menu-style-2'),(914763,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-left','0','','','.b-menu-style-2'),(914764,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-left','0','','','.b-menu-style-2'),(914765,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-left','20','','','.b-menu-style-2'),(914766,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-left','0','','','.b-menu-style-2'),(914767,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-left','20','','','.b-menu-style-2'),(914768,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-left','20','','','.b-menu-style-2'),(914769,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-left','20','','','.b-menu-style-2'),(914770,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-left','50','','','.b-menu-style-2'),(914771,'watch','.b-personal-catalog-popup #personal_catalog_popup','padding-left','0','','','.b-personal-catalog-popup'),(914772,'watch','.b-trade-approval .steps-bar li a','padding-left','0','','','.b-trade-approval'),(914773,'watch','.b-trade-approval .middle-form','padding-left','0','','','.b-trade-approval'),(914774,'watch','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-left','5','','','.b-trade-approval'),(914775,'watch','.b-trade-approval .steps-bar','padding-left','12','','','.b-trade-approval'),(914776,'watch','.b-trade-approval .center-buttons','padding-left','0','','','.b-trade-approval'),(914777,'watch','.w-account-personal-catalog .list-switcher','padding-left','0','','','.w-account-personal-catalog'),(914778,'watch','.w-account-personal-catalog .list-switcher a','padding-left','6','','','.w-account-personal-catalog'),(914779,'watch','.w-account-subscription .subscription-variant','padding-left','10','','','.w-account-subscription'),(914780,'watch','.w-catalog-additional-images li','padding-left','10','','','.w-catalog-additional-images'),(914781,'watch','.w-catalog-additional-images ul','padding-left','0','','','.w-catalog-additional-images'),(914782,'watch','.w-catalog-compare td','padding-left','20','','','.w-catalog-compare'),(914783,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-left','0','','','.w-catalog-compare'),(914784,'watch','.w-catalog-compare .cross-box .different-all > div','padding-left','5','2','','.w-catalog-compare'),(914785,'watch','.w-catalog-compare .cross-box .different-all > div','padding-left','5','','','.w-catalog-compare'),(914786,'watch','.w-catalog-compare .cross-box .return','padding-left','20','','','.w-catalog-compare'),(914787,'watch','.w-delivery-day .left-count','padding-left','5','','','.w-delivery-day'),(914788,'watch','.w-top-text .top-text','padding-left','10','','','.w-top-text'),(914789,'watch','.w-cart-listing .points','padding-left','0','5232','','.w-cart-listing'),(914790,'watch','.w-product-images .additional-horizontal .item','padding-left','10','','','.w-product-images'),(914791,'watch','.w-filters .filter-box-content ul','padding-left','0','','','.w-filters'),(914792,'watch','.order-summary .w-cart-listing .item .name','padding-left','0','','','.order-summary'),(914793,'watch','.order-summary .w-cart-listing .item > div ~ div','padding-left','10','','','.order-summary'),(914794,'watch','.w-cart-discount-coupon .discount-box','padding-left','10','','','.w-cart-discount-coupon'),(914830,'watch','.catalog-product-wrap .next-product','padding-left','20','','','.catalog-product-wrap'),(914831,'watch','.catalog-product-wrap .next-product .pn-image','padding-left','2','3','','.catalog-product-wrap'),(914832,'watch','.catalog-product-wrap .pn-direction','padding-left','4','','','.catalog-product-wrap'),(914833,'watch','.catalog-product-wrap .pn-image','padding-left','5','','','.catalog-product-wrap'),(914834,'watch','.catalog-product-wrap .prev-product','padding-left','50','','','.catalog-product-wrap'),(914835,'watch','.catalog-product-wrap .next-product','padding-left','0','5240','','.catalog-product-wrap'),(914836,'watch','.catalog-product-wrap .pn-direction','padding-left','0','5240','','.catalog-product-wrap'),(914837,'watch','.catalog-product-wrap .prev-product','padding-left','0','5240','','.catalog-product-wrap'),(914838,'watch','.catalog-product-wrap .product > .box-block','padding-left','55','5240','','.catalog-product-wrap'),(914839,'watch','.checkout-index-wrap .checkout-cart-listing.main-listing','padding-left','30','','','.checkout-index-wrap'),(914840,'watch','.checkout-index-wrap .edit-address-popup','padding-left','20','','','.checkout-index-wrap'),(914841,'watch','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-left','20','','','.shopping-cart-index'),(914842,'watch','.account-order-pay .contentColumn','padding-left','40','','','.account-order-pay'),(914843,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-left','40','','','.account-order-pay'),(914844,'watch','.account-order-pay .history_info > div + div','padding-left','2','','','.account-order-pay'),(914845,'watch','.account-order-pay .history_info > div','padding-left','0','5240','','.account-order-pay'),(914846,'watch','.account-order-pay .history_info > div + div','padding-left','0','5240','','.account-order-pay'),(914847,'watch','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-left','10','','','.account-samples'),(914848,'watch','.account-samples .orders-table th','padding-left','10','','','.account-samples'),(914849,'watch','.account-samples .order_history_table th','padding-left','10','','','.account-samples'),(914850,'watch','.account-samples .view_link','padding-left','0','','','.account-samples'),(914851,'watch','.account-samples .orders-table .td-alignright','padding-left','10','5240','','.account-samples'),(914852,'watch','.account-samples .orders-table td','padding-left','10','5240','','.account-samples'),(914853,'watch','.account-sample-info .contentColumn','padding-left','40','','','.account-sample-info'),(914854,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-left','40','','','.account-sample-info'),(914855,'watch','.account-sample-info .history_info > div + div','padding-left','2','','','.account-sample-info'),(914856,'watch','.account-sample-info .popup-tracking-number','padding-left','10','','','.account-sample-info'),(914857,'watch','.account-sample-info .history_info > div','padding-left','0','5240','','.account-sample-info'),(914858,'watch','.account-sample-info .history_info > div + div','padding-left','0','5240','','.account-sample-info'),(914859,'watch','.checkout-order-confirmation .price-row','padding-left','0','','','.checkout-order-confirmation'),(914860,'watch','.b-bottom .pop-up-content','padding-left','15','','','.b-bottom'),(914861,'watch','.b-form .columns .col-2','padding-left','10','','','.b-form'),(914862,'watch','.b-bottom .pop-up-content .buttons','padding-left','0','','','.b-bottom'),(914863,'watch','.b-slick .slick-dots li','padding-left','5','','','.b-slick'),(914867,'watch','.success-page .check-ico-block','padding-left','10','','','.success-page'),(914868,'watch','.success-page .order-summary2 .btn-2','padding-left','50','','','.success-page'),(914869,'watch','.success-page .order_totals .price-row','padding-left','0','','','.success-page'),(914870,'watch','.success-page .price-row','padding-left','0','','','.success-page'),(914871,'watch','.success-page .w-cart-listing .item.sub-product','padding-left','50','','','.success-page'),(914872,'watch','.success-page .w-cart-listing .qty','padding-left','0','','','.success-page'),(914873,'watch','.success-page .w-cart-listing .sub-product .image','padding-left','0','','','.success-page'),(914874,'watch','.b-multi-page-checkout .multi-page-checkout .buttons','padding-left','0','','','.b-multi-page-checkout'),(914875,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-left','10','','','.b-multi-page-checkout'),(914876,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-left','10','','','.b-multi-page-checkout'),(914877,'watch','.b-form .col-left','padding-left','5','','','.b-form'),(914878,'watch','.b-form .col-right','padding-left','5','','','.b-form'),(914884,'watch','.w-bestsellers .heading-3','padding-left','55','','','.w-bestsellers'),(914886,'watch','.w-account-customer-additional-field .tf-file','padding-left','0','','','.w-account-customer-additional-field'),(914887,'watch','.w-account-customer-additional-field .tf-file .remove','padding-left','5','','','.w-account-customer-additional-field'),(914888,'watch','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','','','.w-menu-style-1'),(914889,'watch','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','','','.w-menu-style-1'),(914890,'watch','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-left','20','','','.w-menu-style-1'),(914891,'watch','.w-menu-style-1 ul','padding-left','0','','','.w-menu-style-1'),(914892,'watch','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-left','8','5240','','.w-menu-style-1'),(914893,'watch','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-left','20','5240','','.w-menu-style-1'),(914894,'watch','.b-slick .slick-list','padding-left','0','','','.b-slick'),(914895,'watch','.b-slick .slick-vertical button.slick-next','padding-left','0','3','','.b-slick'),(914896,'watch','.b-slick .slick-vertical button.slick-prev','padding-left','0','3','','.b-slick'),(914897,'watch','.b-slick button.slick-next','padding-left','4','3','','.b-slick'),(914898,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','padding-left','0','','','.b-slick'),(914899,'watch','.w-banner .banner-text','padding-left','20','','','.w-banner'),(914900,'watch','.w-banner .carousel-text > span','padding-left','20','','','.w-banner'),(914901,'watch','.w-catalog-paging ','padding-left','5','2','','.w-catalog-paging'),(914902,'watch','.w-catalog-paging .next','padding-left','5','','','.w-catalog-paging'),(914903,'watch','.w-catalog-paging .next-pages','padding-left','5','','','.w-catalog-paging'),(914904,'watch','.w-catalog-paging .page-number','padding-left','5','','','.w-catalog-paging'),(914905,'watch','.w-catalog-paging .paging-item','padding-left','2','','','.w-catalog-paging'),(914906,'watch','.w-catalog-paging .prev','padding-left','5','','','.w-catalog-paging'),(914907,'watch','.w-catalog-paging .prev-pages','padding-left','5','','','.w-catalog-paging'),(914908,'watch','.b-data-table table.dataTable tbody td','padding-left_important','important','','','.b-data-table'),(914909,'watch','.b-data-table table.dataTable thead td','padding-left_important','important','','','.b-data-table'),(914910,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left_important','important','','','.b-data-table'),(914911,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left_important','important','','','.b-data-table'),(914912,'watch','.w-cart-listing .points','padding-left_important','important','5232','','.w-cart-listing'),(914913,'watch','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-right','10','','','.w-communication-new-topic'),(914914,'watch','.b-email .image','padding-right','10','','','.b-email'),(914915,'watch','.w-product-configurator .pc_item','padding-right','0','5240','','.w-product-configurator'),(914916,'watch','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(914917,'watch','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(914918,'watch','.w-product-properties li','padding-right','5','','','.w-product-properties'),(914919,'watch','.order-summary .btn-2, .order-summary .btn-3','padding-right','5','','','.order-summary'),(914920,'watch','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(914921,'watch','.b-table .table td','padding-right','15','','','.b-table'),(914924,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(914925,'watch','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(914926,'watch','.b-form .required-message-wrap','padding-right','0','','','.b-form'),(914927,'watch','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-right','10','','','.p-quick-order-index'),(914928,'watch','.p-quick-order-index ul.token-input-list','padding-right','0','','','.p-quick-order-index'),(914929,'watch','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-right','10','','','.p-quick-order-index'),(914930,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.p-quick-order-index'),(914931,'watch','.w-promotions .promo-date > div','padding-right','50','','','.w-promotions'),(914932,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.p-quick-order-index'),(914933,'watch','.w-promotions .promo-item','padding-right','40','','','.w-promotions'),(914934,'watch','.w-socials > li','padding-right','15','','','.w-socials'),(914935,'watch','.w-cart-compare .attributes-label','padding-right','10','','','.w-cart-compare'),(914941,'watch','.w-personal-gift-status-bar .start-label','padding-right','5','','','.w-personal-gift-status-bar'),(914942,'watch','.w-personal-gift-status-bar .end-label','padding-right','30','','','.w-personal-gift-status-bar'),(914943,'watch','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(914944,'watch','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(914945,'watch','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(914946,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(914947,'watch','.b-email .image','padding-right','10','','','.b-email'),(914948,'watch','.b-email .heading-qty','padding-right','10','','','.b-email'),(914949,'watch','.b-email .totals-value','padding-right','10','','','.b-email'),(914950,'watch','.b-email .model','padding-right','10','','','.b-email'),(914951,'watch','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(914952,'watch','.testimonials .heading-3','padding-right','0','','',''),(914953,'watch','.testimonials .review','padding-right','10','','',''),(914954,'watch','.testimonials .reviews-list .name','padding-right','10','','',''),(914955,'watch','.testimonials .name','padding-right','10','','',''),(914956,'watch','.w-categories .image','padding-right','0','','','.w-categories'),(914957,'watch','.w-promotions .prom-multi-discount .promo-range','padding-right','20','','','.w-promotions'),(914958,'watch','.w-promotions .prom-multi-discount .promo-product','padding-right','20','','','.w-promotions'),(914959,'watch','.w-promotions .nextdiscount .item-holder .image','padding-right','10','','','.w-promotions'),(914960,'watch','.w-promotions .nextdiscount .content > div','padding-right','10','','','.w-promotions'),(914961,'watch','.w-promotions .master','padding-right','15','','','.w-promotions'),(914962,'watch','.w-promotions .nextdiscount .promo-for-each','padding-right','20','','','.w-promotions'),(914963,'watch','.w-promotions .heading','padding-right','10','','','.w-promotions'),(914964,'watch','.w-promotions .promo-salemaker .promo-categories','padding-right','12','','','.w-promotions'),(914965,'watch','.w-promotions .promo-salemaker .item','padding-right','20','','','.w-promotions'),(914966,'watch','.w-promotions .promo-salemaker .discount','padding-right','20','','','.w-promotions'),(914967,'watch','.w-promotions .promo-cart-discount .slave .item','padding-right','20','','','.w-promotions'),(914968,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','padding-right','20','','','.w-promotions'),(914969,'watch','.w-promotions .promo-cart-discount .promo-min-qty','padding-right','20','','','.w-promotions'),(914970,'watch','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-right','20','','','.b-warehouses-popup'),(914971,'watch','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-right','2','','','.b-products-listing'),(914973,'watch','.w-cart-compare .attributes-cell','padding-right','20','','','.w-cart-compare'),(914974,'watch','.b-table .table td','padding-right','15','','','.b-table'),(914975,'watch','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(914976,'watch','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(914978,'watch','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(914979,'watch','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(914980,'watch','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(914981,'watch','.w-breadcrumb .breadcrumb-li','padding-right','0','','','.w-breadcrumb'),(914982,'watch','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(914983,'watch','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(914984,'watch','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(914985,'watch','.b-bottom .confirm-popup .confirm-text','padding-right','0','','','.b-bottom'),(914986,'watch','.w-top-categories h2.name','padding-right','3','','','.w-top-categories'),(914987,'watch','.b-messages .messages-menu ul','padding-right','0','','','.b-messages'),(914988,'watch','.b-messages .development-content .type-6 .content','padding-right','40','','','.b-messages'),(914989,'watch','.b-messages .msv_btn','padding-right','0','','','.b-messages'),(914990,'watch','.b-messages .msv_content','padding-right','20','','','.b-messages'),(914991,'watch','.b-messages .msv_history','padding-right','20','','','.b-messages'),(914992,'watch','.b-messages .messMenuButton span','padding-right','15','','','.b-messages'),(914993,'watch','.b-messages .messages-menu li a','padding-right','0','','','.b-messages'),(914994,'watch','.b-messages .messages-menu li','padding-right','0','','','.b-messages'),(914995,'watch','.b-messages .content_management_attach button','padding-right','27','','','.b-messages'),(914996,'watch','.b-messages .email-heading','padding-right','15','','','.b-messages'),(914997,'watch','.b-messages .content_management_attach','padding-right','8','','','.b-messages'),(914998,'watch','.b-messages .emailLineTextArea textarea','padding-right','10','','','.b-messages'),(914999,'watch','.b-messages .msv_to_cc','padding-right','15','','','.b-messages'),(915000,'watch','.b-messages .emailBtn','padding-right','10','','','.b-messages'),(915001,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-right','10','','','.b-messages'),(915002,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-right','10','','',''),(915003,'watch','.w-sitemap-delivery-location > ul > li > ul > li','padding-right','20','','','.w-sitemap-delivery-location'),(915004,'watch','.w-quote .cart-box-link','padding-right','14','5240','','.w-quote'),(915005,'watch','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(915006,'watch','.w-reviews-content .item','padding-right','0','','','.w-reviews-content'),(915007,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(915008,'watch','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(915009,'watch','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(915010,'watch','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(915011,'watch','.w-sitemap-delivery-location > ul > li > ul','padding-right','0','','','.w-sitemap-delivery-location'),(915012,'watch','.w-sitemap-delivery-location > ul','padding-right','0','','','.w-sitemap-delivery-location'),(915013,'watch','.w-checkout-terms .required-message','padding-right','10','','','.w-checkout-terms'),(915014,'watch','.w-cart-listing .item .remove','padding-right','10','5240','','.w-cart-listing'),(915015,'watch','.b-table .table td','padding-right','15','','','.b-table'),(915016,'watch','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(915017,'watch','.b-info .info li','padding-right','0','','','.b-info'),(915018,'watch','.b-info .info ul','padding-right','0','','','.b-info'),(915019,'watch','.b-email .model','padding-right','10','','','.b-email'),(915020,'watch','.b-upload-file .upload-file-template','padding-right','1','','','.b-upload-file'),(915021,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(915022,'watch','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(915023,'watch','.b-email .heading-image','padding-right','10','','','.b-email'),(915024,'watch','.b-email .heading-image','padding-right','10','','','.b-email'),(915025,'watch','.b-email .heading-price','padding-right','10','','','.b-email'),(915026,'watch','.b-email .heading-name','padding-right','10','','','.b-email'),(915027,'watch','.w-product-properties li','padding-right','5','','','.w-product-properties'),(915028,'watch','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(915029,'watch','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(915030,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(915031,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(915032,'watch','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(915033,'watch','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(915034,'watch','.b-quantity .qty-box input','padding-right','3','','','.b-quantity'),(915035,'watch','.b-email .price','padding-right','10','','','.b-email'),(915036,'watch','.w-filters .filter-ul-content','padding-right','0','','','.w-filters'),(915037,'watch','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(915038,'watch','.w-login-block .returning','padding-right','40','','','.w-login-block'),(915039,'watch','.w-menu-horizontal > ul > li > ul > li','padding-right','10','','','.w-menu-horizontal'),(915040,'watch','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-right','10','','','.w-menu-horizontal'),(915041,'watch','.w-menu-horizontal ul','padding-right','0','','','.w-menu-horizontal'),(915042,'watch','.w-tabs .tab-navigation','padding-right','0','','','.w-tabs'),(915043,'watch','.b-email .heading-model','padding-right','10','','','.b-email'),(915044,'watch','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(915045,'watch','.b-email .heading-price','padding-right','10','','','.b-email'),(915047,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(915048,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(915049,'watch','.b-fancybox .fancybox-title-over-wrap','padding-right','10','','','.b-fancybox'),(915050,'watch','.b-email .image','padding-right','10','','','.b-email'),(915051,'watch','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(915052,'watch','.b-quantity .qty-box input','padding-right','3','','','.b-quantity'),(915053,'watch','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(915054,'watch','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(915055,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(915056,'watch','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(915057,'watch','.w-product-configurator .pc_item','padding-right','20','','','.w-product-configurator'),(915058,'watch','.w-product-personal-catalog-button .btn','padding-right','0','','','.w-product-personal-catalog-button'),(915059,'watch','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(915060,'watch','.w-product-configurator .pc_attr','padding-right','0','5232','','.w-product-configurator'),(915061,'watch','.b-table .table .headings td','padding-right','10','','','.b-table'),(915062,'watch','.b-sub-totals .historyTotal td','padding-right','5','','','.b-sub-totals'),(915063,'watch','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(915064,'watch','.b-email .heading-price','padding-right','10','','','.b-email'),(915065,'watch','.b-email .qty','padding-right','10','','','.b-email'),(915066,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-right','0','','','.w-delivery-location-top-location-list'),(915067,'watch','.w-cart-compare .dropdown .dropdown-menu','padding-right','0','','','.w-cart-compare'),(915068,'watch','textarea','padding-right','10','','',''),(915069,'watch','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(915070,'watch','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(915071,'watch','.w-product-personal-catalog-button .btn','padding-right','0','','','.w-product-personal-catalog-button'),(915072,'watch','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(915073,'watch','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(915074,'watch','.w-cart-compare .product','padding-right','15','','','.w-cart-compare'),(915076,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(915077,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(915078,'watch','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(915079,'watch','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(915080,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-right','10','','','.w-image-maps'),(915081,'watch','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(915082,'watch','.b-table .table .headings td','padding-right','10','','','.b-table'),(915083,'watch','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(915084,'watch','.b-form .payment-method .item','padding-right','0','','','.b-form'),(915085,'watch','.message.success','padding-right','0','','',''),(915086,'watch','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(915087,'watch','.w-promo-code .holder','padding-right','20','5261','','.w-promo-code'),(915088,'watch','.w-cart-discount-coupon .btn','padding-right','15','','','.w-cart-discount-coupon'),(915089,'watch','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(915090,'watch','.w-checkout-shipping-choice span','padding-right','0','','','.w-checkout-shipping-choice'),(915091,'watch','.b-info .info ul','padding-right','0','','','.b-info'),(915092,'watch','.w-product-configurator .pc_item','padding-right','20','','','.w-product-configurator'),(915093,'watch','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(915094,'watch','.b-email .heading-qty','padding-right','10','','','.b-email'),(915095,'watch','.p-quick-order-index .bottom','padding-right','0','','','.p-quick-order-index'),(915096,'watch','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(915097,'watch','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(915098,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-right','0','','','.b-select-suggest'),(915099,'watch','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(915100,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(915101,'watch','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(915102,'watch','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(915103,'watch','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(915104,'watch','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(915105,'watch','.w-reviews .review','padding-right','10','','','.w-reviews'),(915106,'watch','.w-socials > li','padding-right','15','','','.w-socials'),(915109,'watch','.b-info-popup .info-popup div','padding-right','15','','','.b-info-popup'),(915110,'watch','.b-form .password-forgotten-link','padding-right','0','','','.b-form'),(915111,'watch','.b-quantity .qty-box input','padding-right','3','','','.b-quantity'),(915113,'watch','.w-cart-compare .atr-col','padding-right','30','','','.w-cart-compare'),(915114,'watch','.w-reviews .author','padding-right','10','','','.w-reviews'),(915115,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(915116,'watch','.b-info .info ul','padding-right','0','','','.b-info'),(915117,'watch','.b-form .login-col-1','padding-right','20','','','.b-form'),(915118,'watch','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(915119,'watch','.w-promo-code .holder','padding-right','20','5261','','.w-promo-code'),(915120,'watch','.w-product-images-additional .images','padding-right','0','5261','','.w-product-images-additional'),(915121,'watch','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(915122,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(915123,'watch','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-right','0','','','.w-multi-cart-actions'),(915124,'watch','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(915125,'watch','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(915126,'watch','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(915127,'watch','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(915128,'watch','.w-top-categories .item','padding-right','20','','','.w-top-categories'),(915129,'watch','.w-tabs > .block','padding-right','20','','','.w-tabs'),(915130,'watch','.w-tabs .accordion-heading','padding-right','8','5232','','.w-tabs'),(915131,'watch','.w-cart-cart-tabs .w-tabs > .block','padding-right','0','','','.w-cart-cart-tabs'),(915132,'watch','.w-tabs .tab-a','padding-right','6','','','.w-tabs'),(915133,'watch','.w-tabs .tab-li','padding-right','0','','','.w-tabs'),(915134,'watch','.w-socials > li','padding-right','15','','','.w-socials'),(915135,'watch','.b-autocomplete .ui-autocomplete li','padding-right','10','','','.b-autocomplete'),(915136,'watch','.b-bottom .popup-buttons','padding-right','15','','','.b-bottom'),(915137,'watch','.b-bottom .popup-content','padding-right','15','','','.b-bottom'),(915138,'watch','.w-product-images-additional .images','padding-right','0','5261','','.w-product-images-additional'),(915139,'watch','.b-quantity .qty-box input','padding-right','3','','','.b-quantity'),(915140,'watch','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(915141,'watch','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(915142,'watch','.b-form .required-message','padding-right','3','','','.b-form'),(915143,'watch','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(915144,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-right','0','','','.w-delivery-location-top-location-list'),(915145,'watch','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(915146,'watch','.btn-1','padding-right','25','','',''),(915147,'watch','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(915148,'watch','.w-product-configurator .pc_item','padding-right','20','','','.w-product-configurator'),(915149,'watch','.w-reviews-content .review','padding-right','20','','','.w-reviews-content'),(915150,'watch','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(915151,'watch','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(915152,'watch','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(915153,'watch','.b-table .table .headings td','padding-right','10','','','.b-table'),(915154,'watch','.b-info .info','padding-right','0','','','.b-info'),(915155,'watch','.btn-3','padding-right','25','','',''),(915156,'watch','.w-filters .filter-widget-horizontal .filter-box','padding-right','20','','','.w-filters'),(915157,'watch','.w-product-images-additional .images','padding-right','0','5261','','.w-product-images-additional'),(915158,'watch','.b-products-listing .products-listing .buyButton .btn','padding-right','10','','','.b-products-listing'),(915159,'watch','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block','padding-right','10','5245','',''),(915160,'watch','.b-bottom .popup-heading','padding-right','15','','','.b-bottom'),(915161,'watch','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(915162,'watch','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(915163,'watch','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(915164,'watch','.b-info .info li','padding-right','0','','','.b-info'),(915165,'watch','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(915166,'watch','.b-email .totals-title','padding-right','10','','','.b-email'),(915167,'watch','.b-email .price','padding-right','10','','','.b-email'),(915168,'watch','.b-email .totals-value','padding-right','10','','','.b-email'),(915169,'watch','.b-email .heading-name','padding-right','10','','','.b-email'),(915170,'watch','.b-email .image','padding-right','10','','','.b-email'),(915171,'watch','.b-email .name','padding-right','10','','','.b-email'),(915172,'watch','.w-product-configurator .pc_attr','padding-right','0','5232','','.w-product-configurator'),(915173,'watch','.order-summary .price-row','padding-right','0','','','.order-summary'),(915174,'watch','.b-email .name','padding-right','10','','','.b-email'),(915175,'watch','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-right','0','','','.b-fancybox'),(915176,'watch','.w-socials > li','padding-right','15','','','.w-socials'),(915178,'watch','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(915179,'watch','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(915180,'watch','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(915181,'watch','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(915182,'watch','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(915183,'watch','.b-select-suggest .select2-drop-mask','padding-right','0','','','.b-select-suggest'),(915184,'watch','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(915185,'watch','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(915187,'watch','.w-quote .cart-box-link','padding-right','10','','','.w-quote'),(915188,'watch','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(915189,'watch','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(915190,'watch','.w-product-configurator .pc_item','padding-right','0','5240','','.w-product-configurator'),(915191,'watch','.w-product-configurator .pc_attr','padding-right','0','5232','','.w-product-configurator'),(915192,'watch','.w-product-configurator .pc_item','padding-right','0','5240','','.w-product-configurator'),(915193,'watch','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(915194,'watch','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(915195,'watch','.b-email .price','padding-right','10','','','.b-email'),(915196,'watch','.b-fancybox .fancybox-title-float-wrap .child','padding-right','20','','','.b-fancybox'),(915197,'watch','.w-checkout-shipping-choice span','padding-right','10','5261','','.w-checkout-shipping-choice'),(915198,'watch','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(915199,'watch','.w-product-personal-catalog-button .btn','padding-right','0','','','.w-product-personal-catalog-button'),(915200,'watch','.w-top-categories .categories h2','padding-right','0','','','.w-top-categories'),(915201,'watch','.w-top-categories .image','padding-right','0','','','.w-top-categories'),(915202,'watch','.w-product-reviews .reviews-list .review','padding-right','10','','','.w-product-reviews'),(915203,'watch','.w-reviews-content .product-image','padding-right','10','','','.w-reviews-content'),(915204,'watch','.w-product-reviews .reviews-list .name','padding-right','10','','','.w-product-reviews'),(915205,'watch','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(915206,'watch','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(915207,'watch','.b-email .name','padding-right','10','','','.b-email'),(915208,'watch','.b-fancybox .fancybox-prev span','padding-right','4','3','','.b-fancybox'),(915209,'watch','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(915210,'watch','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(915211,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(915212,'watch','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(915213,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(915214,'watch','.w-product-properties li','padding-right','5','','','.w-product-properties'),(915215,'watch','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(915216,'watch','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(915217,'watch','.w-product-configurator .pc_item','padding-right','20','','','.w-product-configurator'),(915218,'watch','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(915219,'watch','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(915220,'watch','.b-bottom .popup-simple','padding-right','20','','','.b-bottom'),(915221,'watch','.b-bottom .rfq-form','padding-right','20','','','.b-bottom'),(915222,'watch','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(915223,'watch','.b-email .heading-image','padding-right','10','','','.b-email'),(915224,'watch','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(915225,'watch','.b-email .model','padding-right','10','','','.b-email'),(915226,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(915227,'watch','.b-email .name','padding-right','10','','','.b-email'),(915228,'watch','.b-email .heading-price','padding-right','10','','','.b-email'),(915229,'watch','.b-email .heading-qty','padding-right','10','','','.b-email'),(915230,'watch','.b-email .image','padding-right','10','','','.b-email'),(915231,'watch','.b-email .price','padding-right','10','','','.b-email'),(915232,'watch','.b-email .heading-model','padding-right','10','','','.b-email'),(915233,'watch','.b-email .totals-title','padding-right','10','','','.b-email'),(915234,'watch','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(915235,'watch','.b-email .totals-value','padding-right','10','','','.b-email'),(915236,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(915237,'watch','.b-email .price','padding-right','10','','','.b-email'),(915238,'watch','.b-email .qty','padding-right','10','','','.b-email'),(915239,'watch','.b-email .heading-name','padding-right','10','','','.b-email'),(915240,'watch','.b-email .heading-image','padding-right','10','','','.b-email'),(915241,'watch','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(915242,'watch','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(915243,'watch','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(915244,'watch','.b-info .info li','padding-right','0','','','.b-info'),(915245,'watch','.w-checkout-shipping .sub-item','padding-right','0','','','.w-checkout-shipping'),(915246,'watch','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(915247,'watch','.b-table .table .headings td','padding-right','10','','','.b-table'),(915248,'watch','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(915249,'watch','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(915250,'watch','.w-promo-code .holder','padding-right','20','5261','','.w-promo-code'),(915251,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(915252,'watch','.b-form .center-buttons','padding-right','0','','','.b-form'),(915253,'watch','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(915254,'watch','.b-form .shipping-method .input','padding-right','10','','','.b-form'),(915255,'watch','.w-product-properties li','padding-right','5','','','.w-product-properties'),(915256,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(915257,'watch','.w-reviews .item','padding-right','0','','','.w-reviews'),(915258,'watch','.w-reviews .product-image','padding-right','20','','','.w-reviews'),(915259,'watch','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(915260,'watch','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(915261,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(915262,'watch','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(915263,'watch','.b-select-suggest .select2-container .select2-choice','padding-right','0','','','.b-select-suggest'),(915264,'watch','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(915265,'watch','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(915266,'watch','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(915267,'watch','.w-breadcrumb .breadcrumb-li','padding-right','0','','','.w-breadcrumb'),(915268,'watch','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(915269,'watch','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(915270,'watch','.b-info .info','padding-right','0','','','.b-info'),(915271,'watch','.b-info .info li','padding-right','0','','','.b-info'),(915272,'watch','.b-info .info ul','padding-right','0','','','.b-info'),(915273,'watch','.b-bottom .terms-info-popup .pop-up-content','padding-right','20','','','.b-bottom'),(915274,'watch','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','5240','','.w-menu-horizontal'),(915275,'watch','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(915276,'watch','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(915277,'watch','.b-upload-files .upload-files','padding-right','10','','','.b-upload-files'),(915278,'watch','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(915279,'watch','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(915280,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(915281,'watch','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(915282,'watch','.w-login-block .returning','padding-right','40','','','.w-login-block'),(915283,'watch','.b-form .form-buttons','padding-right','0','','','.b-form'),(915284,'watch','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(915285,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-right','0','','','.w-delivery-location-top-location-list'),(915286,'watch','.w-login-block .returning','padding-right','40','','','.w-login-block'),(915287,'watch','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(915288,'watch','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(915289,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(915290,'watch','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(915291,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(915292,'watch','.w-cart-compare .delete-cart','padding-right','10','','','.w-cart-compare'),(915293,'watch','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(915294,'watch','.b-email .name','padding-right','10','','','.b-email'),(915295,'watch','.b-email .totals-value','padding-right','10','','','.b-email'),(915296,'watch','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(915297,'watch','.b-email .qty','padding-right','10','','','.b-email'),(915298,'watch','.b-email .heading-name','padding-right','10','','','.b-email'),(915299,'watch','.b-email .heading-model','padding-right','10','','','.b-email'),(915300,'watch','.w-categories .item','padding-right','20','','','.w-categories'),(915301,'watch','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(915302,'watch','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(915303,'watch','.b-email .heading-image','padding-right','10','','','.b-email'),(915304,'watch','.b-email .heading-price','padding-right','10','','','.b-email'),(915305,'watch','.b-email .image','padding-right','10','','','.b-email'),(915306,'watch','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-right','20','','','.b-bottom'),(915307,'watch','.w-promo-code .holder','padding-right','20','5261','','.w-promo-code'),(915308,'watch','.b-compare .popupCompare .pop-up-content','padding-right','10','','','.b-compare'),(915309,'watch','.w-promotions .promo-cart-discount .master .item','padding-right','20','','','.w-promotions'),(915310,'watch','.w-product-configurator .pc_item','padding-right','0','5240','','.w-product-configurator'),(915311,'watch','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(915312,'watch','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(915313,'watch','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(915314,'watch','.b-bottom .cart-options','padding-right','20','','','.b-bottom'),(915315,'watch','.b-bottom .alert-message','padding-right','20','','','.b-bottom'),(915316,'watch','.b-select-suggest .select2-results .select2-result-label','padding-right','7','','','.b-select-suggest'),(915317,'watch','.w-personal-gift-status-bar .inform','padding-right','5','4','','.w-personal-gift-status-bar'),(915318,'watch','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(915319,'watch','.b-email .totals-title','padding-right','10','','','.b-email'),(915320,'watch','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(915321,'watch','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(915322,'watch','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(915323,'watch','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(915324,'watch','.b-email .heading-model','padding-right','10','','','.b-email'),(915325,'watch','.b-email .heading-qty','padding-right','10','','','.b-email'),(915326,'watch','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(915327,'watch','.b-info .info','padding-right','0','','','.b-info'),(915328,'watch','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(915329,'watch','.b-email .model','padding-right','10','','','.b-email'),(915330,'watch','.b-email .heading-model','padding-right','10','','','.b-email'),(915331,'watch','.b-bottom .footerTitle','padding-right','0','5232','','.b-bottom'),(915332,'watch','.b-bottom .pop-up-close','padding-right','1','','','.b-bottom'),(915333,'watch','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(915334,'watch','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(915335,'watch','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(915336,'watch','.w-cart-shipping-estimator .address-item','padding-right','10','','','.w-cart-shipping-estimator'),(915337,'watch','.w-cart-up-sell .w-list-type-1','padding-right','0','','','.w-cart-up-sell'),(915338,'watch','.w-cart-up-sell .w-list-type-1 .item','padding-right','21','','','.w-cart-up-sell'),(915339,'watch','.w-cart-up-sell .w-list-type-1 .item','padding-right','20','1','','.w-cart-up-sell'),(915340,'watch','.b-products-listing .products-listing .btn-buy','padding-right','10','','','.b-products-listing'),(915341,'watch','.b-upload-files .added-file','padding-right','0','','','.b-upload-files'),(915342,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(915343,'watch','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(915344,'watch','.w-product-personal-catalog-button .btn','padding-right','0','','','.w-product-personal-catalog-button'),(915345,'watch','.w-product-configurator .pc_attr','padding-right','0','5232','','.w-product-configurator'),(915346,'watch','.b-bottom .popup-box-wrap','padding-right','10','','','.b-bottom'),(915347,'watch','.b-bottom .pop-up-info','padding-right','20','','','.b-bottom'),(915348,'watch','.b-email .qty','padding-right','10','','','.b-email'),(915349,'watch','.b-email .name','padding-right','10','','','.b-email'),(915350,'watch','.b-email .heading-qty','padding-right','10','','','.b-email'),(915351,'watch','.b-fancybox .fancybox-error','padding-right','15','','','.b-fancybox'),(915352,'watch','.b-email .totals-title','padding-right','10','','','.b-email'),(915353,'watch','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(915354,'watch','.w-product-customers-activity .customers-activity','padding-right','20','','','.w-product-customers-activity'),(915355,'watch','.w-product-available-in-warehouses .warehouse-item','padding-right','20','','','.w-product-available-in-warehouses'),(915356,'watch','.b-table .table td','padding-right','15','','','.b-table'),(915357,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(915358,'watch','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(915359,'watch','.b-email .heading-name','padding-right','10','','','.b-email'),(915360,'watch','.b-email .heading-model','padding-right','10','','','.b-email'),(915361,'watch','.b-table .table .headings td','padding-right','10','','','.b-table'),(915362,'watch','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(915363,'watch','.w-product-personal-catalog-button .btn','padding-right','0','','','.w-product-personal-catalog-button'),(915364,'watch','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(915365,'watch','.w-cart-compare .price-label','padding-right','10','','','.w-cart-compare'),(915366,'watch','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(915367,'watch','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(915368,'watch','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(915369,'watch','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(915370,'watch','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(915371,'watch','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(915372,'watch','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(915373,'watch','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(915374,'watch','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(915375,'watch','.w-checkout-billing-address .edit-ab','padding-right','0','','','.w-checkout-billing-address'),(915376,'watch','.w-checkout-billing-address .addresses .address-item label','padding-right','10','','','.w-checkout-billing-address'),(915377,'watch','.w-promo-code .holder','padding-right','20','5261','','.w-promo-code'),(915378,'watch','.w-product-images-additional .images','padding-right','0','5261','','.w-product-images-additional'),(915379,'watch','.w-categories h2.name','padding-right','3','','','.w-categories'),(915380,'watch','.w-product-configurator .pc_attr','padding-right','0','5232','','.w-product-configurator'),(915381,'watch','.w-tabs .accordion-heading','padding-right','6','','','.w-tabs'),(915382,'watch','.w-socials > li','padding-right','15','','','.w-socials'),(915383,'watch','.w-product-images-additional .images','padding-right','0','5261','','.w-product-images-additional'),(915384,'watch','.w-promo-code .holder','padding-right','20','5261','','.w-promo-code'),(915385,'watch','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(915386,'watch','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','padding-right','5','','','.b-switch'),(915387,'watch','.p-quick-order-index .all-scroll-div','padding-right','0','','','.p-quick-order-index'),(915388,'watch','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(915389,'watch','.w-breadcrumb .breadcrumb-li','padding-right','0','','','.w-breadcrumb'),(915390,'watch','.w-cart-compare .price-cell','padding-right','20','','','.w-cart-compare'),(915391,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(915392,'watch','.w-checkout-shipping-address .edit-ab','padding-right','0','','','.w-checkout-shipping-address'),(915393,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(915394,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-right','5','','','.b-select-suggest'),(915395,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-right','0','','','.b-select-suggest'),(915396,'watch','.b-select-suggest .select2-locked','padding-right','5','','','.b-select-suggest'),(915397,'watch','.b-select-suggest .select2-container-multi .select2-choices','padding-right','0','','','.b-select-suggest'),(915398,'watch','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','','','.w-menu-horizontal'),(915399,'watch','.b-form .shipping-method .item + .item','padding-right','0','','','.b-form'),(915400,'watch','.w-checkout-shipping-address .addresses .address-item label','padding-right','10','','','.w-checkout-shipping-address'),(915401,'watch','.b-select-suggest .select2-search','padding-right','4','','','.b-select-suggest'),(915402,'watch','.b-select-suggest .select2-search input','padding-right','20','','','.b-select-suggest'),(915403,'watch','.b-select-suggest .select2-results','padding-right','4','','','.b-select-suggest'),(915404,'watch','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(915405,'watch','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(915406,'watch','.b-compare .compare-box-item','padding-right','10','','','.b-compare'),(915407,'watch','.w-cart-compare .product-label','padding-right','10','','','.w-cart-compare'),(915408,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-right','0','','','.w-delivery-location-top-location-list'),(915409,'watch','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(915410,'watch','.w-product-properties li','padding-right','5','','','.w-product-properties'),(915411,'watch','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(915412,'watch','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(915413,'watch','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(915414,'watch','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(915415,'watch','.b-quantity .qty-box input','padding-right','3','','','.b-quantity'),(915416,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(915417,'watch','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(915418,'watch','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(915419,'watch','.w-cart-compare .dropdown li','padding-right','10','','','.w-cart-compare'),(915420,'watch','.w-personal-gift-status-bar .end-date','padding-right','5','3','','.w-personal-gift-status-bar'),(915422,'watch','.w-login-block .returning','padding-right','40','','','.w-login-block'),(915423,'watch','.w-menu-big ul','padding-right','0','','','.w-menu-big'),(915424,'watch','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(915425,'watch','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(915426,'watch','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(915427,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-right','0','','','.w-delivery-location-top-location-list'),(915428,'watch','.b-bottom .notify-form','padding-right','20','','','.b-bottom'),(915429,'watch','.w-account-addresses-list .addsess-suggestion-item','padding-right','20','','','.w-account-addresses-list'),(915430,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.b-data-table'),(915431,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.b-data-table'),(915432,'watch','.w-communication-post .communication-post-author','padding-right','0','','','.w-communication-post'),(915433,'watch','.b-products-listing .products-listing a.btn.view-button','padding-right','0','','','.b-products-listing'),(915434,'watch','.b-products-listing .products-listing .compare','padding-right','6','','','.b-products-listing'),(915435,'watch','.b-products-listing .in-cart','padding-right','10','','','.b-products-listing'),(915436,'watch','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-right','5','','','.w-catalog-b2b-add-button'),(915437,'watch','.b-products-listing .products-listing h2','padding-right','0','','','.b-products-listing'),(915438,'watch','.b-products-listing .promos-info .promo-name','padding-right','15','','','.b-products-listing'),(915439,'watch','.b-products-listing .promos-info .promo-item','padding-right','10','','','.b-products-listing'),(915440,'watch','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(915446,'watch','.b-compare .col-two label','padding-right','0','','','.b-compare'),(915447,'watch','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(915448,'watch','.w-checkout-gdpr .privacy-row','padding-right','0','','','.w-checkout-gdpr'),(915449,'watch','.w-checkout-gdpr .terms-login','padding-right','0','','','.w-checkout-gdpr'),(915450,'watch','.b-table .table td','padding-right','15','','','.b-table'),(915451,'watch','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(915452,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(915453,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(915454,'watch','.b-info .info ul','padding-right','0','','','.b-info'),(915455,'watch','.b-form .middle-form','padding-right','0','','','.b-form'),(915456,'watch','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(915458,'watch','.w-checkout-billing-address .same-address','padding-right','10','','','.w-checkout-billing-address'),(915459,'watch','.w-reviews .heading-3','padding-right','0','','','.w-reviews'),(915460,'watch','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(915461,'watch','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(915462,'watch','.w-product-personal-catalog-button .btn','padding-right','0','','','.w-product-personal-catalog-button'),(915463,'watch','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(915464,'watch','.w-personal-gift-status-bar .timeline','padding-right','10','','','.w-personal-gift-status-bar'),(915465,'watch','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(915466,'watch','.w-catalog-sorting .before','padding-right','5','','','.w-catalog-sorting'),(915467,'watch','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(915468,'watch','.w-chat .w-chat-box','padding-right','12','','','.w-chat'),(915469,'watch','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(915470,'watch','.b-compare .compare-head','padding-right','10','','','.b-compare'),(915471,'watch','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(915472,'watch','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(915473,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-right','0','','',''),(915474,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-right','0','','','.b-h-inline'),(915475,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-right','0','','','.w-communication-new-topic'),(915476,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-right','10','','','.w-communication-new-topic'),(915477,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-right','5','','','.w-communication-new-topic'),(915478,'watch','.w-communication-new-topic #communication_topic_form .middle-form','padding-right','0','','','.w-communication-new-topic'),(915479,'watch','.b-info .info','padding-right','0','','','.b-info'),(915480,'watch','.b-info .info li','padding-right','0','','','.b-info'),(915481,'watch','.b-email .totals-title','padding-right','10','','','.b-email'),(915482,'watch','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(915483,'watch','.b-email .heading-qty','padding-right','10','','','.b-email'),(915484,'watch','.b-email .model','padding-right','10','','','.b-email'),(915485,'watch','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-right','6','','','.b-compare'),(915486,'watch','.btn-2','padding-right','25','','',''),(915487,'watch','.b-compare .compare_pagination','padding-right','0','','','.b-compare'),(915488,'watch','.w-product-images-additional .images','padding-right','0','5261','','.w-product-images-additional'),(915489,'watch','.b-bottom .header-info','padding-right','20','','','.b-bottom'),(915490,'watch','.w-cart-checkout-btn a','padding-right','12','5232','','.w-cart-checkout-btn'),(915491,'watch','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(915492,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(915493,'watch','.w-product-properties li','padding-right','5','','','.w-product-properties'),(915494,'watch','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(915495,'watch','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(915496,'watch','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-right','10','','','.order-summary'),(915497,'watch','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(915498,'watch','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(915499,'watch','.b-table .table td','padding-right','15','','','.b-table'),(915500,'watch','.b-info .info','padding-right','0','','','.b-info'),(915501,'watch','.b-info .info ul','padding-right','0','','','.b-info'),(915502,'watch','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-right','0','','','.b-fancybox'),(915503,'watch','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(915504,'watch','.products-quick-index .token-input-list','padding-right','0','','',''),(915505,'watch','.w-cart-compare .cart-cell','padding-right','7','','','.w-cart-compare'),(915506,'watch','.w-product-configurator .pc_item','padding-right','0','5240','','.w-product-configurator'),(915507,'watch','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(915508,'watch','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(915509,'watch','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(915510,'watch','.b-form .shipping-method .item','padding-right','0','','','.b-form'),(915511,'watch','.b-email .price','padding-right','10','','','.b-email'),(915512,'watch','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(915513,'watch','.b-email .heading-image','padding-right','10','','','.b-email'),(915514,'watch','.w-product-configurator .pc_attr','padding-right','0','5232','','.w-product-configurator'),(915515,'watch','.w-cart-listing .item .attributes strong','padding-right','10','','','.w-cart-listing'),(915516,'watch','.w-cart-listing .item .gift-wrap label','padding-right','10','','','.w-cart-listing'),(915517,'watch','.w-cart-listing .item > div','padding-right','10','','','.w-cart-listing'),(915518,'watch','.w-cart-listing .points-earn','padding-right','0','','','.w-cart-listing'),(915519,'watch','.w-cart-listing .points-redeem','padding-right','0','','','.w-cart-listing'),(915520,'watch','.w-cart-give-away .ga_img','padding-right','1','','','.w-cart-give-away'),(915521,'watch','.b-bottom .header-error','padding-right','20','','','.b-bottom'),(915522,'watch','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(915523,'watch','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(915524,'watch','.w-breadcrumb .breadcrumb-li','padding-right','0','','','.w-breadcrumb'),(915525,'watch','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(915526,'watch','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(915533,'watch','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(915534,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-right','0','','','.w-delivery-location-top-location-list'),(915535,'watch','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(915536,'watch','.w-breadcrumb .breadcrumb-li','padding-right','0','','','.w-breadcrumb'),(915537,'watch','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(915538,'watch','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(915539,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(915540,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(915541,'watch','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(915542,'watch','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(915543,'watch','.b-compare .col-gender','padding-right','0','','','.b-compare'),(915544,'watch','.b-email .qty','padding-right','10','','','.b-email'),(915545,'watch','.b-email .heading-price','padding-right','10','','','.b-email'),(915546,'watch','.w-product-configurator .pc_item','padding-right','0','5240','','.w-product-configurator'),(915547,'watch','.w-top-categories .item','padding-right','10','5232','','.w-top-categories'),(915548,'watch','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(915549,'watch','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(915550,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(915551,'watch','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(915552,'watch','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(915555,'watch','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(915556,'watch','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(915557,'watch','.w-socials > li','padding-right','15','','','.w-socials'),(915558,'watch','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(915559,'watch','.w-login-block .returning','padding-right','40','','','.w-login-block'),(915560,'watch','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(915561,'watch','.w-product-configurator .pc_item','padding-right','20','','','.w-product-configurator'),(915563,'watch','.w-filters .fsl_handle','padding-right','0','','','.w-filters'),(915564,'watch','.w-filters .head-filter-widget','padding-right','10','5240','','.w-filters'),(915565,'watch','.w-filters .ui-slider-range','padding-right','0','','','.w-filters'),(915566,'watch','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(915567,'watch','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(915568,'watch','.w-filters .head-filter-widget','padding-right','0','','','.w-filters'),(915569,'watch','.w-filters .handle_tit','padding-right','5','','','.w-filters'),(915570,'watch','.b-autocomplete .ui-autocomplete','padding-right','2','','','.b-autocomplete'),(915571,'watch','.order-summary .heading-2','padding-right','25','','','.order-summary'),(915572,'watch','.b-compare .column_wrapper','padding-right','10','','','.b-compare'),(915573,'watch','.b-email .totals-value','padding-right','10','','','.b-email'),(915574,'watch','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(915575,'watch','.b-email .model','padding-right','10','','','.b-email'),(915576,'watch','.b-email .heading-name','padding-right','10','','','.b-email'),(915577,'watch','.b-info .info li','padding-right','0','','','.b-info'),(915578,'watch','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(915579,'watch','.w-reviews-content .author','padding-right','20','','','.w-reviews-content'),(915580,'watch','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-right','10','5245','',''),(915581,'watch','.w-product-configurator .pc_item','padding-right','20','','','.w-product-configurator'),(915582,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(915583,'watch','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(915584,'watch','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(915585,'watch','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(915586,'watch','.w-login-block .returning','padding-right','40','','','.w-login-block'),(915587,'watch','.b-data-table table.dataTable tbody td','padding-right','20','','','.b-data-table'),(915588,'watch','.b-data-table table.dataTable thead td','padding-right','20','','','.b-data-table'),(915589,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(915590,'watch','.b-table .table .headings td','padding-right','10','','','.b-table'),(915591,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(915592,'watch','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(915593,'watch','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(915594,'watch','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(915595,'watch','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(915596,'watch','.w-breadcrumb .breadcrumb-li','padding-right','0','','','.w-breadcrumb'),(915597,'watch','.w-checkout-create-account .create-account','padding-right','0','','','.w-checkout-create-account'),(915598,'watch','.b-info .info','padding-right','0','','','.b-info'),(915599,'watch','.b-email .totals-title','padding-right','10','','','.b-email'),(915600,'watch','.b-email .totals-value','padding-right','10','','','.b-email'),(915601,'watch','.b-email .qty','padding-right','10','','','.b-email'),(915602,'watch','.btn','padding-right','25','','',''),(915603,'watch','.b-quantity .qty-box input','padding-right','3','','','.b-quantity'),(915604,'watch','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(915605,'watch','.b-product-images .media-popup .mp-content','padding-right','5','','','.b-product-images'),(915606,'watch','.b-product-images .media-popup .mp-small-images .item','padding-right','10','','','.b-product-images'),(915607,'watch','.b-product-images .media-popup .slick-dots','padding-right','0','','','.b-product-images'),(915608,'watch','.b-product-images .media-popup .slick-dots li','padding-right','0','','','.b-product-images'),(915609,'watch','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-right','0','','','.b-menu-style'),(915610,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-right','5','','','.b-menu-style-1'),(915611,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-right','20','','','.b-menu-style-1'),(915612,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-right','20','','','.b-menu-style-1'),(915613,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-right','20','','','.b-menu-style-1'),(915614,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-right','20','','','.b-menu-style-2'),(915615,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-right','20','','','.b-menu-style-2'),(915616,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-right','0','','','.b-menu-style-2'),(915617,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-right','0','','','.b-menu-style-2'),(915618,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-right','20','','','.b-menu-style-2'),(915619,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-right','0','','','.b-menu-style-2'),(915620,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-right','20','','','.b-menu-style-2'),(915621,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-right','20','','','.b-menu-style-2'),(915622,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-right','50','','','.b-menu-style-2'),(915623,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-right','30','','','.b-menu-style-2'),(915624,'watch','.b-personal-catalog-popup #personal_catalog_popup','padding-right','0','','','.b-personal-catalog-popup'),(915625,'watch','.b-trade-approval .steps-bar li a','padding-right','0','','','.b-trade-approval'),(915626,'watch','.b-trade-approval .middle-form','padding-right','0','','','.b-trade-approval'),(915627,'watch','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-right','5','','','.b-trade-approval'),(915628,'watch','.b-trade-approval .steps-bar','padding-right','0','','','.b-trade-approval'),(915629,'watch','.b-trade-approval .center-buttons','padding-right','0','','','.b-trade-approval'),(915630,'watch','.w-account-personal-catalog .list-switcher','padding-right','0','','','.w-account-personal-catalog'),(915631,'watch','.w-account-personal-catalog .list-switcher a','padding-right','6','','','.w-account-personal-catalog'),(915632,'watch','.w-account-subscription .subscription-variant','padding-right','10','','','.w-account-subscription'),(915633,'watch','.w-catalog-additional-images li','padding-right','10','','','.w-catalog-additional-images'),(915634,'watch','.w-catalog-additional-images ul','padding-right','0','','','.w-catalog-additional-images'),(915635,'watch','.w-catalog-compare td','padding-right','20','','','.w-catalog-compare'),(915636,'watch','.w-catalog-compare .image','padding-right','10','','','.w-catalog-compare'),(915637,'watch','.w-catalog-compare .cross-box .different-all > div','padding-right','5','2','','.w-catalog-compare'),(915638,'watch','.w-catalog-compare .cross-box .different-all > div','padding-right','5','','','.w-catalog-compare'),(915639,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-right','0','','','.w-catalog-compare'),(915640,'watch','.w-delivery-day .left-count','padding-right','5','','','.w-delivery-day'),(915641,'watch','.w-top-text .top-text','padding-right','10','','','.w-top-text'),(915642,'watch','.w-cart-listing .points','padding-right','0','5232','','.w-cart-listing'),(915643,'watch','.w-product-images .additional-horizontal .item','padding-right','10','','','.w-product-images'),(915644,'watch','.w-filters .filter-box-content ul','padding-right','0','','','.w-filters'),(915645,'watch','.order-summary .w-cart-listing .item > div ~ div','padding-right','0','','','.order-summary'),(915646,'watch','.w-cart-discount-coupon .discount-box','padding-right','10','','','.w-cart-discount-coupon'),(915682,'watch','.catalog-product-wrap .next-product','padding-right','50','','','.catalog-product-wrap'),(915683,'watch','.catalog-product-wrap .pn-direction','padding-right','4','','','.catalog-product-wrap'),(915684,'watch','.catalog-product-wrap .pn-image','padding-right','5','','','.catalog-product-wrap'),(915685,'watch','.catalog-product-wrap .prev-product','padding-right','20','','','.catalog-product-wrap'),(915686,'watch','.catalog-product-wrap .prev-product .pn-image','padding-right','2','3','','.catalog-product-wrap'),(915687,'watch','.catalog-product-wrap .next-product','padding-right','0','5240','','.catalog-product-wrap'),(915688,'watch','.catalog-product-wrap .pn-direction','padding-right','0','5240','','.catalog-product-wrap'),(915689,'watch','.catalog-product-wrap .prev-product','padding-right','0','5240','','.catalog-product-wrap'),(915690,'watch','.catalog-product-wrap .product > .box-block','padding-right','55','5240','','.catalog-product-wrap'),(915691,'watch','.checkout-index-wrap .checkout-cart-listing.main-listing','padding-right','30','','','.checkout-index-wrap'),(915692,'watch','.checkout-index-wrap .edit-address-popup','padding-right','20','','','.checkout-index-wrap'),(915693,'watch','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-right','20','','','.shopping-cart-index'),(915694,'watch','.account-order-pay .contentColumn','padding-right','10','','','.account-order-pay'),(915695,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-right','0','','','.account-order-pay'),(915696,'watch','.account-order-pay .history_attr div strong, .account-order-pay .history_attr div span','padding-right','10','','','.account-order-pay'),(915697,'watch','.account-order-pay .history_info > div + div','padding-right','0','','','.account-order-pay'),(915698,'watch','.account-order-pay .history_info > div','padding-right','0','5240','','.account-order-pay'),(915699,'watch','.account-order-pay .history_info > div + div','padding-right','0','5240','','.account-order-pay'),(915700,'watch','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-right','10','','','.account-samples'),(915701,'watch','.account-samples .orders-table th','padding-right','10','','','.account-samples'),(915702,'watch','.account-samples .order_history_table th','padding-right','10','','','.account-samples'),(915703,'watch','.account-samples .view_link','padding-right','20','','','.account-samples'),(915704,'watch','.account-samples .orders-table .td-alignright','padding-right','10','5240','','.account-samples'),(915705,'watch','.account-samples .orders-table td','padding-right','10','5240','','.account-samples'),(915706,'watch','.account-sample-info .contentColumn','padding-right','10','','','.account-sample-info'),(915707,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-right','0','','','.account-sample-info'),(915708,'watch','.account-sample-info .history_attr div strong, .account-sample-info .history_attr div span','padding-right','10','','','.account-sample-info'),(915709,'watch','.account-sample-info .history_info > div + div','padding-right','0','','','.account-sample-info'),(915710,'watch','.account-sample-info .popup-tracking-number','padding-right','10','','','.account-sample-info'),(915711,'watch','.account-sample-info .history_info > div','padding-right','0','5240','','.account-sample-info'),(915712,'watch','.account-sample-info .history_info > div + div','padding-right','0','5240','','.account-sample-info'),(915713,'watch','.checkout-order-confirmation .price-row','padding-right','0','','','.checkout-order-confirmation'),(915714,'watch','.b-bottom .pop-up-content','padding-right','15','','','.b-bottom'),(915715,'watch','.b-form .columns .col-2','padding-right','10','','','.b-form'),(915716,'watch','.b-bottom .pop-up-content .buttons','padding-right','0','','','.b-bottom'),(915717,'watch','.b-slick .slick-dots li','padding-right','5','','','.b-slick'),(915720,'watch','.success-page .check-ico-block','padding-right','0','','','.success-page'),(915721,'watch','.success-page .order-summary2 .btn-2','padding-right','50','','','.success-page'),(915722,'watch','.success-page .order_totals .price-row','padding-right','0','','','.success-page'),(915723,'watch','.success-page .price-row','padding-right','0','','','.success-page'),(915724,'watch','.success-page .w-cart-listing .price','padding-right','0','','','.success-page'),(915725,'watch','.success-page .w-cart-listing .qty','padding-right','0','','','.success-page'),(915726,'watch','.b-multi-page-checkout .multi-page-checkout .buttons','padding-right','0','','','.b-multi-page-checkout'),(915727,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-right','10','','','.b-multi-page-checkout'),(915728,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-right','10','','','.b-multi-page-checkout'),(915729,'watch','.b-form .col-left','padding-right','5','','','.b-form'),(915730,'watch','.b-form .col-right','padding-right','5','','','.b-form'),(915731,'watch','.b-form .addresses .address-item','padding-right','20','','','.b-form'),(915734,'watch','.w-bestsellers .heading-3','padding-right','0','','','.w-bestsellers'),(915736,'watch','.w-account-customer-additional-field .tf-file','padding-right','0','','','.w-account-customer-additional-field'),(915737,'watch','.w-account-customer-additional-field .tf-file .remove','padding-right','5','','','.w-account-customer-additional-field'),(915738,'watch','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','','','.w-menu-style-1'),(915739,'watch','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','','','.w-menu-style-1'),(915740,'watch','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','padding-right','20','','','.w-menu-style-1'),(915741,'watch','.w-menu-style-1 ul','padding-right','0','','','.w-menu-style-1'),(915742,'watch','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-right','8','5240','','.w-menu-style-1'),(915743,'watch','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-right','20','5240','','.w-menu-style-1'),(915744,'watch','.b-slick .slick-list','padding-right','0','','','.b-slick'),(915745,'watch','.b-slick .slick-vertical button.slick-next','padding-right','0','3','','.b-slick'),(915746,'watch','.b-slick .slick-vertical button.slick-prev','padding-right','0','3','','.b-slick'),(915747,'watch','.b-slick button.slick-prev','padding-right','4','3','','.b-slick'),(915748,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','padding-right','0','','','.b-slick'),(915749,'watch','.w-banner .banner-text','padding-right','20','','','.w-banner'),(915750,'watch','.w-banner .carousel-text > span','padding-right','20','','','.w-banner'),(915751,'watch','.w-catalog-paging ','padding-right','5','2','','.w-catalog-paging'),(915752,'watch','.w-catalog-paging .next','padding-right','5','','','.w-catalog-paging'),(915753,'watch','.w-catalog-paging .next-pages','padding-right','5','','','.w-catalog-paging'),(915754,'watch','.w-catalog-paging .page-number','padding-right','5','','','.w-catalog-paging'),(915755,'watch','.w-catalog-paging .paging-item','padding-right','2','','','.w-catalog-paging'),(915756,'watch','.w-catalog-paging .prev','padding-right','5','','','.w-catalog-paging'),(915757,'watch','.w-catalog-paging .prev-pages','padding-right','5','','','.w-catalog-paging'),(915758,'watch','.b-data-table table.dataTable tbody td','padding-right_important','important','','','.b-data-table'),(915759,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right_important','important','','','.b-data-table'),(915760,'watch','.b-data-table table.dataTable thead td','padding-right_important','important','','','.b-data-table'),(915761,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right_important','important','','','.b-data-table'),(915762,'watch','.w-cart-listing .points','padding-right_important','important','5232','','.w-cart-listing'),(915763,'watch','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-top','10','','','.w-communication-new-topic'),(915764,'watch','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(915765,'watch','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(915766,'watch','.heading-4 .edit, h4 .edit','padding-top','2','','',''),(915767,'watch','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(915768,'watch','.b-info .info','padding-top','20','','','.b-info'),(915769,'watch','.b-form .password-forgotten-link','padding-top','15','','','.b-form'),(915770,'watch','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(915771,'watch','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(915772,'watch','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(915773,'watch','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(915776,'watch','.w-cart-discount-coupon .btn','padding-top','6','','','.w-cart-discount-coupon'),(915777,'watch','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(915778,'watch','.b-email .totals-title','padding-top','5','','','.b-email'),(915779,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-top','0','','','.w-delivery-location-top-location-list'),(915780,'watch','.p-quick-order-index ul.token-input-list','padding-top','0','','','.p-quick-order-index'),(915781,'watch','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-top','7','','','.p-quick-order-index'),(915782,'watch','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-top','8','','','.p-quick-order-index'),(915783,'watch','.w-promotions .promo-item','padding-top','30','','','.w-promotions'),(915784,'watch','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(915785,'watch','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(915786,'watch','.w-cart-compare .attributes-label','padding-top','10','','','.w-cart-compare'),(915794,'watch','.w-personal-gift-status-bar .end-label','padding-top','0','','','.w-personal-gift-status-bar'),(915795,'watch','.p-sample-checkout-success .page-success .text-1','padding-top','120','','','.p-sample-checkout-success'),(915796,'watch','.w-personal-gift-status-bar .start-label','padding-top','0','','','.w-personal-gift-status-bar'),(915797,'watch','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(915798,'watch','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(915799,'watch','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(915800,'watch','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(915801,'watch','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(915802,'watch','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(915803,'watch','.b-email .heading-image','padding-top','5','','','.b-email'),(915804,'watch','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(915805,'watch','.w-product-images-additional .images','padding-top','10','5261','','.w-product-images-additional'),(915806,'watch','.testimonials .reviews-list .name','padding-top','5','','',''),(915807,'watch','.testimonials .heading-3','padding-top','7','','',''),(915808,'watch','.testimonials .review','padding-top','10','','',''),(915809,'watch','.testimonials .name','padding-top','5','','',''),(915810,'watch','.testimonials .reviews-list .answer .name','padding-top','10','','',''),(915811,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(915812,'watch','.w-categories .image','padding-top','0','','','.w-categories'),(915813,'watch','.w-promotions .prom-multi-discount .promo-range','padding-top','0','','','.w-promotions'),(915814,'watch','.w-promotions .prom-multi-discount .promo-product','padding-top','20','','','.w-promotions'),(915815,'watch','.w-catalog-items-on-page .before, .w-catalog-items-on-page .after','padding-top','5','','','.w-catalog-items-on-page'),(915816,'watch','.w-promotions .nextdiscount .content > div','padding-top','10','','','.w-promotions'),(915817,'watch','.w-promotions .nextdiscount .promo-for-each','padding-top','3','','','.w-promotions'),(915818,'watch','.w-promotions .promo-salemaker .item','padding-top','20','','','.w-promotions'),(915819,'watch','.w-promotions .promo-salemaker .discount','padding-top','0','','','.w-promotions'),(915820,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.p-quick-order-index'),(915821,'watch','.w-promotions .promo-cart-discount .slave .item','padding-top','20','','','.w-promotions'),(915822,'watch','.w-promotions .promo-cart-discount .slave .condition-holder','padding-top','0','','','.w-promotions'),(915823,'watch','.w-promotions .promo-cart-discount .promo-min-qty','padding-top','0','','','.w-promotions'),(915824,'watch','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-top','20','','','.b-warehouses-popup'),(915825,'watch','.w-product-available-in-warehouses .warehouse-item','padding-top','0','','','.w-product-available-in-warehouses'),(915826,'watch','.w-chat .w-chat-box','padding-top','2','','','.w-chat'),(915827,'watch','.w-cart-give-away .ga_column','padding-top','15','','','.w-cart-give-away'),(915828,'watch','.w-cart-compare .attributes-cell','padding-top','8','','','.w-cart-compare'),(915829,'watch','.p-quick-order-index .bottom','padding-top','10','','','.p-quick-order-index'),(915831,'watch','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(915832,'watch','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(915833,'watch','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(915834,'watch','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(915835,'watch','.b-messages .messages-menu ul','padding-top','0','','','.b-messages'),(915836,'watch','.b-messages .messages-menu li','padding-top','0','','','.b-messages'),(915837,'watch','.b-messages .messMenuButton span','padding-top','10','','','.b-messages'),(915838,'watch','.b-messages .msv_btn','padding-top','12','','','.b-messages'),(915839,'watch','.b-messages .msv_content','padding-top','10','','','.b-messages'),(915840,'watch','.b-messages .msv_history','padding-top','10','','','.b-messages'),(915841,'watch','.b-messages .messages-menu li a','padding-top','10','','','.b-messages'),(915842,'watch','.b-messages .email-heading','padding-top','15','','','.b-messages'),(915843,'watch','.b-messages .content_management_attach button','padding-top','1','','','.b-messages'),(915844,'watch','.b-messages .content_management_attach','padding-top','8','','','.b-messages'),(915845,'watch','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(915846,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','padding-top','4','','','.b-messages'),(915847,'watch','.b-messages .emailBtn','padding-top','10','','','.b-messages'),(915848,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-top','5','','','.b-messages'),(915849,'watch','.b-messages .msv_to_cc','padding-top','10','','','.b-messages'),(915850,'watch','.b-messages .messMenuButtonTop','padding-top','5','','','.b-messages'),(915851,'watch','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-top','4','','',''),(915852,'watch','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(915853,'watch','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(915854,'watch','.w-breadcrumb .breadcrumb-li','padding-top','0','','','.w-breadcrumb'),(915855,'watch','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(915856,'watch','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(915857,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(915858,'watch','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(915859,'watch','.w-product-properties li','padding-top','5','','','.w-product-properties'),(915860,'watch','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(915861,'watch','.w-sitemap-delivery-location > ul > li > ul','padding-top','0','','','.w-sitemap-delivery-location'),(915862,'watch','.w-sitemap-delivery-location > ul','padding-top','0','','','.w-sitemap-delivery-location'),(915863,'watch','.p-payer-order-confirmation .dob-hide label','padding-top','5','','','.p-payer-order-confirmation'),(915864,'watch','.p-payer-order-pay .dob-hide label','padding-top','5','','','.p-payer-order-pay'),(915865,'watch','.w-checkout-terms .required-message','padding-top','5','','','.w-checkout-terms'),(915866,'watch','.w-cart-listing .item .remove','padding-top','5','5240','','.w-cart-listing'),(915867,'watch','.b-table .table td','padding-top','15','','','.b-table'),(915868,'watch','.b-table .table .headings td','padding-top','5','','','.b-table'),(915869,'watch','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(915870,'watch','.b-email .heading-image','padding-top','5','','','.b-email'),(915871,'watch','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(915872,'watch','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(915873,'watch','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(915874,'watch','.b-quantity .qty-box input','padding-top','5','','','.b-quantity'),(915875,'watch','.w-reviews-content .item','padding-top','20','','','.w-reviews-content'),(915876,'watch','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(915877,'watch','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(915878,'watch','.b-email .heading-name','padding-top','5','','','.b-email'),(915879,'watch','.b-email .heading-price','padding-top','5','','','.b-email'),(915880,'watch','.b-email .heading-model','padding-top','5','','','.b-email'),(915881,'watch','.p-quick-order-index .all-scroll-div','padding-top','10','','','.p-quick-order-index'),(915882,'watch','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(915883,'watch','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(915884,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-template','padding-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(915885,'watch','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(915886,'watch','.b-email .name','padding-top','5','','','.b-email'),(915887,'watch','.b-email .qty','padding-top','5','','','.b-email'),(915888,'watch','.b-email .heading-qty','padding-top','5','','','.b-email'),(915889,'watch','.b-email .heading-model','padding-top','5','','','.b-email'),(915890,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(915891,'watch','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(915892,'watch','.w-filters .filter-ul-content','padding-top','0','','','.w-filters'),(915893,'watch','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(915894,'watch','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(915895,'watch','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-top','2','','','.w-menu-horizontal'),(915896,'watch','.w-menu-horizontal ul','padding-top','0','','','.w-menu-horizontal'),(915897,'watch','.w-tabs .tab-navigation','padding-top','0','','','.w-tabs'),(915898,'watch','.w-promo-code .holder','padding-top','20','5261','','.w-promo-code'),(915899,'watch','.b-info .info ul','padding-top','0','','','.b-info'),(915900,'watch','.w-promo-code .holder','padding-top','20','5261','','.w-promo-code'),(915901,'watch','.w-product-images-additional .images','padding-top','10','5261','','.w-product-images-additional'),(915902,'watch','.p-quote-checkout-success .page-success .text-1','padding-top','5','5232','','.p-quote-checkout-success'),(915903,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(915904,'watch','.b-fancybox .fancybox-title-over-wrap','padding-top','10','','','.b-fancybox'),(915905,'watch','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(915906,'watch','.b-fancybox .fancybox-title-inside-wrap','padding-top','10','','','.b-fancybox'),(915907,'watch','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(915908,'watch','.b-info .info ul','padding-top','0','','','.b-info'),(915909,'watch','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(915910,'watch','.w-multi-cart-cart-switcher .carts-switcher','padding-top','20','','','.w-multi-cart-cart-switcher'),(915911,'watch','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(915912,'watch','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(915913,'watch','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(915914,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(915915,'watch','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(915916,'watch','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(915917,'watch','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(915918,'watch','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(915919,'watch','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-top','0','','','.b-fancybox'),(915920,'watch','.w-cart-compare .dropdown li','padding-top','5','','','.w-cart-compare'),(915921,'watch','.no-found','padding-top','20','','',''),(915922,'watch','.b-upload-files .attached-block','padding-top','10','','','.b-upload-files'),(915923,'watch','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(915924,'watch','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(915925,'watch','.w-product-configurator .pc_item','padding-top','10','5240','','.w-product-configurator'),(915926,'watch','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(915927,'watch','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(915928,'watch','.w-product-personal-catalog-button .btn','padding-top','0','','','.w-product-personal-catalog-button'),(915929,'watch','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(915930,'watch','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(915931,'watch','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(915932,'watch','.message.success','padding-top','20','','',''),(915933,'watch','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(915934,'watch','.w-cart-compare .dropdown .dropdown-menu','padding-top','5','','','.w-cart-compare'),(915935,'watch','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(915936,'watch','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(915937,'watch','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(915938,'watch','.b-email .heading-qty','padding-top','5','','','.b-email'),(915939,'watch','.b-email .model','padding-top','5','','','.b-email'),(915940,'watch','.b-email .totals-title','padding-top','5','','','.b-email'),(915941,'watch','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(915942,'watch','.b-info .info','padding-top','20','','','.b-info'),(915943,'watch','.b-info .info li','padding-top','0','','','.b-info'),(915944,'watch','.b-info .info li','padding-top','0','','','.b-info'),(915945,'watch','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(915946,'watch','.w-breadcrumb .breadcrumb-li','padding-top','0','','','.w-breadcrumb'),(915947,'watch','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(915948,'watch','.b-email .totals-value','padding-top','5','','','.b-email'),(915949,'watch','.b-email .heading-name','padding-top','5','','','.b-email'),(915950,'watch','.b-email .name','padding-top','5','','','.b-email'),(915951,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-top','0','','','.b-select-suggest'),(915952,'watch','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(915953,'watch','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(915954,'watch','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(915955,'watch','.w-reviews .review','padding-top','10','','','.w-reviews'),(915956,'watch','.w-socials > li','padding-top','15','','','.w-socials'),(915959,'watch','.w-cart-compare .product','padding-top','10','','','.w-cart-compare'),(915960,'watch','.b-info-popup .info-popup div','padding-top','10','','','.b-info-popup'),(915962,'watch','.w-quote .cart-box-link','padding-top','5','','','.w-quote'),(915963,'watch','.b-quantity .qty-box input','padding-top','5','','','.b-quantity'),(915964,'watch','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(915965,'watch','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-top','7','','','.order-summary'),(915966,'watch','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(915967,'watch','.w-breadcrumb .breadcrumb-li','padding-top','0','','','.w-breadcrumb'),(915968,'watch','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(915969,'watch','.b-products-listing .select-attributes .item-title','padding-top','2','','','.b-products-listing'),(915970,'watch','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(915971,'watch','.w-reviews .author','padding-top','0','','','.w-reviews'),(915972,'watch','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(915973,'watch','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(915974,'watch','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(915975,'watch','.b-email .heading-model','padding-top','5','','','.b-email'),(915976,'watch','.b-email .model','padding-top','5','','','.b-email'),(915977,'watch','textarea','padding-top','5','','',''),(915978,'watch','.p-quote-checkout-success .page-success .text-1','padding-top','5','5232','','.p-quote-checkout-success'),(915979,'watch','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(915980,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(915981,'watch','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-top','3','','','.w-multi-cart-actions'),(915982,'watch','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(915983,'watch','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(915984,'watch','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(915985,'watch','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(915986,'watch','.w-top-categories h2.name','padding-top','3','','','.w-top-categories'),(915987,'watch','.w-top-categories .item','padding-top','5','','','.w-top-categories'),(915988,'watch','.w-tabs .accordion-heading','padding-top','9','5232','','.w-tabs'),(915989,'watch','.w-tabs > .block','padding-top','20','','','.w-tabs'),(915990,'watch','.w-cart-cart-tabs .w-tabs > .block','padding-top','0','','','.w-cart-cart-tabs'),(915991,'watch','.w-tabs .tab-a','padding-top','14','','','.w-tabs'),(915992,'watch','.w-tabs .tab-a','padding-top','12','2','','.w-tabs'),(915993,'watch','.w-tabs .tab-li','padding-top','0','','','.w-tabs'),(915994,'watch','.w-socials > li','padding-top','15','','','.w-socials'),(915996,'watch','.order-summary > div','padding-top','10','','','.order-summary'),(915997,'watch','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(915998,'watch','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(915999,'watch','.b-bottom .popup-buttons','padding-top','15','','','.b-bottom'),(916000,'watch','.b-autocomplete .ui-autocomplete li','padding-top','3','','','.b-autocomplete'),(916001,'watch','.b-bottom .popup-content','padding-top','15','','','.b-bottom'),(916002,'watch','.w-product-configurator .pc_attr','padding-top','5','5232','','.w-product-configurator'),(916003,'watch','.b-quantity .qty-box input','padding-top','5','','','.b-quantity'),(916004,'watch','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(916005,'watch','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(916006,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-top','0','','','.w-delivery-location-top-location-list'),(916007,'watch','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(916008,'watch','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(916009,'watch','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(916010,'watch','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(916011,'watch','.btn-1','padding-top','5','','',''),(916012,'watch','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(916013,'watch','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(916014,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(916015,'watch','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(916016,'watch','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(916017,'watch','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(916018,'watch','.p-sample-checkout-success .page-success .text-1','padding-top','5','5232','','.p-sample-checkout-success'),(916019,'watch','.b-info .info ul','padding-top','0','','','.b-info'),(916020,'watch','.b-messages .emailLineTextArea textarea','padding-top','30','','','.b-messages'),(916021,'watch','.btn-3','padding-top','12','','',''),(916022,'watch','.b-bottom .confirm-popup .confirm-text','padding-top','40','','','.b-bottom'),(916023,'watch','.w-product-images-additional .images','padding-top','10','5261','','.w-product-images-additional'),(916024,'watch','.b-products-listing .products-listing .buyButton .btn','padding-top','5','','','.b-products-listing'),(916025,'watch','.heading-3 .right-text, h3 .right-text','padding-top','3','','',''),(916026,'watch','.b-bottom .popup-heading','padding-top','10','','','.b-bottom'),(916027,'watch','.b-form .shipping-method .item + .item','padding-top','5','','','.b-form'),(916028,'watch','.heading-3 .edit, h3 .edit','padding-top','2','','',''),(916029,'watch','.b-info .info li','padding-top','0','','','.b-info'),(916030,'watch','.b-email .model','padding-top','5','','','.b-email'),(916031,'watch','.b-upload-file .upload-file-template','padding-top','25','','','.b-upload-file'),(916032,'watch','.p-quote-checkout-success .page-success .text-1','padding-top','5','5232','','.p-quote-checkout-success'),(916033,'watch','.b-form .middle-form','padding-top','20','','','.b-form'),(916034,'watch','.b-email .qty','padding-top','5','','','.b-email'),(916035,'watch','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(916036,'watch','.b-email .heading-price','padding-top','5','','','.b-email'),(916037,'watch','.w-socials > li','padding-top','15','','','.w-socials'),(916038,'watch','.order-summary .price-row','padding-top','7','','','.order-summary'),(916039,'watch','.b-email .model','padding-top','5','','','.b-email'),(916040,'watch','.b-email .image','padding-top','5','','','.b-email'),(916041,'watch','.w-product-configurator .pc_item','padding-top','10','5240','','.w-product-configurator'),(916042,'watch','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(916043,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(916044,'watch','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(916045,'watch','.b-select-suggest .select2-drop-mask','padding-top','0','','','.b-select-suggest'),(916047,'watch','.w-reviews-content .review','padding-top','20','','','.w-reviews-content'),(916048,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(916049,'watch','.w-product-configurator .pc_item','padding-top','10','5240','','.w-product-configurator'),(916050,'watch','.w-product-configurator .pc_attr','padding-top','5','5232','','.w-product-configurator'),(916051,'watch','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(916052,'watch','.b-email .price','padding-top','5','','','.b-email'),(916053,'watch','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(916054,'watch','.b-fancybox .fancybox-title-float-wrap .child','padding-top','2','','','.b-fancybox'),(916055,'watch','.w-checkout-shipping-choice span','padding-top','7','5261','','.w-checkout-shipping-choice'),(916056,'watch','.w-product-personal-catalog-button .btn','padding-top','0','','','.w-product-personal-catalog-button'),(916057,'watch','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(916058,'watch','.w-top-categories .categories h2','padding-top','0','','','.w-top-categories'),(916059,'watch','.w-top-categories .image','padding-top','0','','','.w-top-categories'),(916060,'watch','.w-product-reviews .reviews-list .review','padding-top','10','','','.w-product-reviews'),(916061,'watch','.w-product-reviews .reviews-list .name','padding-top','5','','','.w-product-reviews'),(916062,'watch','.b-email .heading-qty','padding-top','5','','','.b-email'),(916063,'watch','.b-email .name','padding-top','5','','','.b-email'),(916064,'watch','.b-form .required-message','padding-top','0','','','.b-form'),(916065,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(916066,'watch','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(916067,'watch','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(916068,'watch','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(916069,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(916070,'watch','.w-product-properties li','padding-top','5','','','.w-product-properties'),(916071,'watch','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(916072,'watch','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(916073,'watch','.w-product-configurator .pc_item','padding-top','10','','','.w-product-configurator'),(916074,'watch','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(916075,'watch','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(916076,'watch','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(916077,'watch','.p-quote-checkout-success .page-success .text-1','padding-top','5','5232','','.p-quote-checkout-success'),(916078,'watch','.w-promo-code .holder','padding-top','20','5261','','.w-promo-code'),(916079,'watch','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(916080,'watch','.b-bottom .popup-simple','padding-top','20','','','.b-bottom'),(916081,'watch','.b-bottom .rfq-form','padding-top','0','','','.b-bottom'),(916082,'watch','.b-email .heading-model','padding-top','5','','','.b-email'),(916083,'watch','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(916084,'watch','.b-email .price','padding-top','5','','','.b-email'),(916085,'watch','.b-email .heading-name','padding-top','5','','','.b-email'),(916086,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(916087,'watch','.b-email .model','padding-top','5','','','.b-email'),(916088,'watch','.b-email .heading-price','padding-top','5','','','.b-email'),(916089,'watch','.b-email .heading-qty','padding-top','5','','','.b-email'),(916090,'watch','.b-email .heading-model','padding-top','5','','','.b-email'),(916091,'watch','.b-email .qty','padding-top','5','','','.b-email'),(916092,'watch','.b-email .totals-value','padding-top','5','','','.b-email'),(916093,'watch','.b-email .totals-title','padding-top','5','','','.b-email'),(916094,'watch','.b-email .image','padding-top','5','','','.b-email'),(916095,'watch','.b-email .price','padding-top','5','','','.b-email'),(916096,'watch','.b-email .qty','padding-top','5','','','.b-email'),(916097,'watch','.b-email .name','padding-top','5','','','.b-email'),(916098,'watch','.b-email .heading-image','padding-top','5','','','.b-email'),(916099,'watch','.b-email .heading-name','padding-top','5','','','.b-email'),(916100,'watch','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(916101,'watch','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(916102,'watch','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(916103,'watch','.w-checkout-shipping .sub-item','padding-top','5','','','.w-checkout-shipping'),(916104,'watch','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(916105,'watch','.b-table .table .headings td','padding-top','5','','','.b-table'),(916106,'watch','.b-table .table td','padding-top','15','','','.b-table'),(916107,'watch','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(916108,'watch','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(916109,'watch','.w-promo-code .holder','padding-top','20','5261','','.w-promo-code'),(916110,'watch','.w-socials > li','padding-top','15','','','.w-socials'),(916111,'watch','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(916112,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(916113,'watch','.b-form .center-buttons','padding-top','20','','','.b-form'),(916114,'watch','.b-form .shipping-method .input','padding-top','0','','','.b-form'),(916115,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(916116,'watch','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(916117,'watch','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(916118,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(916119,'watch','.w-reviews .heading-3','padding-top','7','','','.w-reviews'),(916120,'watch','.w-checkout-shipping-address .edit-ab','padding-top','5','','','.w-checkout-shipping-address'),(916121,'watch','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(916122,'watch','.b-select-suggest .select2-container .select2-choice','padding-top','0','','','.b-select-suggest'),(916123,'watch','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(916124,'watch','.w-breadcrumb .breadcrumb-li','padding-top','0','','','.w-breadcrumb'),(916125,'watch','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(916126,'watch','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(916127,'watch','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(916128,'watch','.b-info .info','padding-top','20','','','.b-info'),(916129,'watch','.b-info .info li','padding-top','0','','','.b-info'),(916130,'watch','.b-bottom .terms-info-popup .pop-up-content','padding-top','20','','','.b-bottom'),(916131,'watch','.w-checkout-create-account .create-account-switcher','padding-top','3','','','.w-checkout-create-account'),(916132,'watch','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','12','5240','','.w-menu-horizontal'),(916133,'watch','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(916134,'watch','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(916135,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(916136,'watch','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(916137,'watch','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(916138,'watch','.w-product-configurator .pc_attr','padding-top','5','5232','','.w-product-configurator'),(916139,'watch','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(916140,'watch','.w-product-images-additional .images','padding-top','10','5261','','.w-product-images-additional'),(916141,'watch','.b-info .info ul','padding-top','0','','','.b-info'),(916142,'watch','.b-form .login-col-1','padding-top','40','','','.b-form'),(916143,'watch','.b-form .form-buttons','padding-top','17','','','.b-form'),(916144,'watch','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(916145,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(916146,'watch','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(916147,'watch','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(916148,'watch','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(916149,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(916150,'watch','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(916151,'watch','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(916152,'watch','.w-product-configurator .pc_item','padding-top','10','','','.w-product-configurator'),(916153,'watch','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(916154,'watch','.w-cart-compare .delete-cart','padding-top','10','','','.w-cart-compare'),(916155,'watch','.w-catalog-listing-look .listing-look-title','padding-top','4','','','.w-catalog-listing-look'),(916156,'watch','.b-table .table td','padding-top','15','','','.b-table'),(916157,'watch','.b-email .heading-price','padding-top','5','','','.b-email'),(916158,'watch','.b-email .image','padding-top','5','','','.b-email'),(916159,'watch','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(916160,'watch','.b-email .price','padding-top','5','','','.b-email'),(916161,'watch','.w-product-images-additional .images','padding-top','10','5261','','.w-product-images-additional'),(916162,'watch','.b-bottom .cart-options .heading-4','padding-top','10','','','.b-bottom'),(916163,'watch','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-top','0','','','.b-bottom'),(916164,'watch','.b-compare .popupCompare .pop-up-content','padding-top','0','','','.b-compare'),(916165,'watch','.w-promotions .promo-cart-discount .master .item','padding-top','0','','','.w-promotions'),(916166,'watch','.w-product-personal-catalog-button .btn','padding-top','0','','','.w-product-personal-catalog-button'),(916167,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(916168,'watch','.b-bottom .alert-message','padding-top','20','','','.b-bottom'),(916169,'watch','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(916170,'watch','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(916171,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-top','0','','','.w-delivery-location-top-location-list'),(916172,'watch','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(916173,'watch','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(916174,'watch','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(916175,'watch','.w-product-properties li','padding-top','5','','','.w-product-properties'),(916176,'watch','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(916177,'watch','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(916178,'watch','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(916179,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(916180,'watch','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(916181,'watch','.b-email .image','padding-top','5','','','.b-email'),(916182,'watch','.b-bottom .cart-options','padding-top','20','','','.b-bottom'),(916183,'watch','.b-info .info','padding-top','20','','','.b-info'),(916184,'watch','.b-email .totals-title','padding-top','5','','','.b-email'),(916185,'watch','.b-email .price','padding-top','5','','','.b-email'),(916186,'watch','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(916187,'watch','.b-email .image','padding-top','5','','','.b-email'),(916188,'watch','.b-email .heading-image','padding-top','5','','','.b-email'),(916189,'watch','.b-email .heading-qty','padding-top','5','','','.b-email'),(916190,'watch','.b-bottom .footerTitle','padding-top','9','5232','','.b-bottom'),(916191,'watch','.b-bottom .pop-up-info','padding-top','20','','','.b-bottom'),(916192,'watch','.b-bottom .pop-up-close','padding-top','1','','','.b-bottom'),(916193,'watch','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(916194,'watch','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(916195,'watch','.w-cart-up-sell .w-list-type-1','padding-top','0','','','.w-cart-up-sell'),(916196,'watch','.w-cart-up-sell .w-list-type-1 .item','padding-top','1','','','.w-cart-up-sell'),(916197,'watch','.w-cart-shipping-estimator .address-item','padding-top','0','','','.w-cart-shipping-estimator'),(916198,'watch','.w-cart-up-sell .w-list-type-1 .item','padding-top','0','1','','.w-cart-up-sell'),(916199,'watch','.b-products-listing .products-listing .btn-buy','padding-top','5','','','.b-products-listing'),(916200,'watch','.b-upload-files .added-file','padding-top','5','','','.b-upload-files'),(916201,'watch','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(916202,'watch','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(916203,'watch','.w-product-configurator .pc_item','padding-top','10','','','.w-product-configurator'),(916204,'watch','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(916205,'watch','.w-product-properties li','padding-top','5','','','.w-product-properties'),(916206,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(916207,'watch','.w-socials > li','padding-top','15','','','.w-socials'),(916208,'watch','.w-product-configurator .pc_item','padding-top','10','5240','','.w-product-configurator'),(916209,'watch','.w-personal-gift-status-bar .end-date','padding-top','0','3','','.w-personal-gift-status-bar'),(916210,'watch','.p-quote-checkout-success .page-success .text-1','padding-top','5','5232','','.p-quote-checkout-success'),(916211,'watch','.b-bottom .popup-box-wrap','padding-top','10','','','.b-bottom'),(916212,'watch','.b-fancybox .fancybox-error','padding-top','15','','','.b-fancybox'),(916213,'watch','.b-info .info','padding-top','20','','','.b-info'),(916214,'watch','.b-info .info ul','padding-top','0','','','.b-info'),(916215,'watch','.b-form .privacy-row','padding-top','10','','','.b-form'),(916216,'watch','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(916217,'watch','.b-form .payment-method .item','padding-top','7','','','.b-form'),(916218,'watch','.b-form .required-message-wrap','padding-top','0','','','.b-form'),(916219,'watch','.w-product-customers-activity .customers-activity','padding-top','35','','','.w-product-customers-activity'),(916220,'watch','.b-table .table .headings td','padding-top','5','','','.b-table'),(916221,'watch','.b-email .name','padding-top','5','','','.b-email'),(916222,'watch','.b-email .heading-price','padding-top','5','','','.b-email'),(916223,'watch','.w-product-personal-catalog-button .btn','padding-top','0','','','.w-product-personal-catalog-button'),(916224,'watch','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(916225,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(916226,'watch','.w-product-personal-catalog-button .btn','padding-top','0','','','.w-product-personal-catalog-button'),(916227,'watch','.w-product-properties li','padding-top','5','','','.w-product-properties'),(916228,'watch','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(916229,'watch','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(916230,'watch','.w-checkout-billing-address .edit-ab','padding-top','5','','','.w-checkout-billing-address'),(916231,'watch','.w-checkout-shipping-choice span','padding-top','7','','','.w-checkout-shipping-choice'),(916232,'watch','.w-promo-code .holder','padding-top','20','5261','','.w-promo-code'),(916233,'watch','.w-product-images-additional .images','padding-top','10','5261','','.w-product-images-additional'),(916234,'watch','.w-categories .item','padding-top','5','','','.w-categories'),(916235,'watch','.w-product-configurator .pc_attr','padding-top','5','5232','','.w-product-configurator'),(916236,'watch','.w-tabs .accordion-heading','padding-top','6','','','.w-tabs'),(916237,'watch','.w-socials > li','padding-top','15','','','.w-socials'),(916238,'watch','.b-form .shipping-method .sub-title','padding-top','2','','','.b-form'),(916239,'watch','.w-categories h2.name','padding-top','3','','','.w-categories'),(916240,'watch','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(916241,'watch','.b-quantity .qty-box input','padding-top','5','','','.b-quantity'),(916242,'watch','.b-table .table .headings td','padding-top','5','','','.b-table'),(916243,'watch','.w-catalog-sorting .before','padding-top','5','','','.w-catalog-sorting'),(916244,'watch','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(916246,'watch','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(916247,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(916248,'watch','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(916249,'watch','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(916250,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(916251,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-top','0','','','.b-select-suggest'),(916252,'watch','.b-select-suggest .select2-locked','padding-top','3','','','.b-select-suggest'),(916253,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-top','5','','','.b-select-suggest'),(916254,'watch','.b-select-suggest .select2-container-multi .select2-choices','padding-top','0','','','.b-select-suggest'),(916255,'watch','.b-select-suggest .select2-results .select2-result-label','padding-top','3','','','.b-select-suggest'),(916256,'watch','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','5','','','.w-menu-horizontal'),(916257,'watch','.b-select-suggest .select2-results','padding-top','0','','','.b-select-suggest'),(916258,'watch','.b-select-suggest .select2-container .select2-choice > .select2-chosen','padding-top','4','','','.b-select-suggest'),(916259,'watch','.b-select-suggest .select2-search input','padding-top','4','','','.b-select-suggest'),(916260,'watch','.w-product-configurator .pc_item','padding-top','10','','','.w-product-configurator'),(916261,'watch','.b-bottom .notify-form','padding-top','0','','','.b-bottom'),(916262,'watch','.b-select-suggest .select2-drop-auto-width .select2-search','padding-top','4','','','.b-select-suggest'),(916263,'watch','.w-neighbour-checkout .neighbour-comment-box','padding-top','10','','','.w-neighbour-checkout'),(916264,'watch','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(916265,'watch','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(916266,'watch','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(916267,'watch','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(916268,'watch','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(916269,'watch','.w-personal-gift-status-bar .inform','padding-top','0','4','','.w-personal-gift-status-bar'),(916271,'watch','.w-checkout-billing-address .same-address','padding-top','10','','','.w-checkout-billing-address'),(916272,'watch','.w-menu-horizontal > ul > li > ul > li','padding-top','2','','','.w-menu-horizontal'),(916273,'watch','.w-menu-big ul','padding-top','0','','','.w-menu-big'),(916274,'watch','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(916275,'watch','.w-cart-compare .product-label','padding-top','15','','','.w-cart-compare'),(916276,'watch','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(916277,'watch','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(916278,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(916279,'watch','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(916280,'watch','.w-product-configurator .pc_item','padding-top','10','','','.w-product-configurator'),(916281,'watch','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(916282,'watch','.b-sub-totals .historyTotal td','padding-top','2','','','.b-sub-totals'),(916283,'watch','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(916284,'watch','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(916285,'watch','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(916286,'watch','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(916287,'watch','.w-cart-compare .price-cell','padding-top','8','','','.w-cart-compare'),(916290,'watch','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(916291,'watch','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(916292,'watch','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(916293,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(916294,'watch','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(916295,'watch','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(916296,'watch','.w-account-addresses-list .addsess-suggestion-item','padding-top','0','','','.w-account-addresses-list'),(916297,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top','0','','','.b-data-table'),(916298,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.b-data-table'),(916299,'watch','.w-communication-post .communication-post-author','padding-top','10','','','.w-communication-post'),(916300,'watch','.b-products-listing .products-listing a.btn.view-button','padding-top','6','','','.b-products-listing'),(916301,'watch','.b-products-listing .products-listing .compare','padding-top','6','','','.b-products-listing'),(916302,'watch','.b-products-listing .in-cart','padding-top','5','','','.b-products-listing'),(916303,'watch','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-top','4','','','.b-products-listing'),(916304,'watch','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-top','5','','','.w-catalog-b2b-add-button'),(916305,'watch','.b-products-listing .products-listing h2','padding-top','0','','','.b-products-listing'),(916306,'watch','.b-products-listing .promos-info .promo-name','padding-top','3','','','.b-products-listing'),(916307,'watch','.b-products-listing .promos-info .promo-item','padding-top','3','','','.b-products-listing'),(916313,'watch','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(916314,'watch','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(916315,'watch','.b-quantity .qty-box input','padding-top','5','','','.b-quantity'),(916316,'watch','.p-quote-checkout-success .page-success .text-1','padding-top','5','5232','','.p-quote-checkout-success'),(916317,'watch','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(916318,'watch','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(916319,'watch','.w-checkout-gdpr .privacy-row','padding-top','0','','','.w-checkout-gdpr'),(916320,'watch','.w-checkout-gdpr .terms-login','padding-top','0','','','.w-checkout-gdpr'),(916321,'watch','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(916322,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow b','padding-top','3','3','','.b-select-suggest'),(916323,'watch','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(916324,'watch','.b-table .table .headings td','padding-top','5','','','.b-table'),(916325,'watch','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(916326,'watch','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(916327,'watch','.b-compare .compare-box-item','padding-top','10','','','.b-compare'),(916328,'watch','.b-email .heading-qty','padding-top','5','','','.b-email'),(916329,'watch','.b-bottom .header-info','padding-top','20','','','.b-bottom'),(916330,'watch','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(916331,'watch','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(916332,'watch','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(916333,'watch','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(916334,'watch','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(916335,'watch','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(916336,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-top','0','','','.w-delivery-location-top-location-list'),(916337,'watch','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(916338,'watch','.b-quantity .qty-box input','padding-top','5','','','.b-quantity'),(916339,'watch','.b-compare .compare-head','padding-top','10','','','.b-compare'),(916340,'watch','.heading-4 .right-text, h4 .right-text','padding-top','4','','',''),(916341,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-top','0','','',''),(916342,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-top','0','','','.b-h-inline'),(916343,'watch','h1, .heading-1','padding-top','20','','',''),(916344,'watch','.w-communication-new-topic .topick-left-col','padding-top','24','','','.w-communication-new-topic'),(916345,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-top','0','','','.w-communication-new-topic'),(916346,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-top','5','','','.w-communication-new-topic'),(916347,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-top','5','','','.w-communication-new-topic'),(916348,'watch','.w-communication-new-topic #communication_topic_form .middle-form','padding-top','20','','','.w-communication-new-topic'),(916349,'watch','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(916350,'watch','.b-email .heading-image','padding-top','5','','','.b-email'),(916351,'watch','.b-email .price','padding-top','5','','','.b-email'),(916352,'watch','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-top','4','','','.b-compare'),(916353,'watch','.w-product-configurator .pc_attr','padding-top','5','5232','','.w-product-configurator'),(916355,'watch','.w-product-configurator .pc_item','padding-top','10','5240','','.w-product-configurator'),(916356,'watch','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(916357,'watch','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(916358,'watch','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(916359,'watch','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(916360,'watch','.w-cart-compare .price-label','padding-top','10','','','.w-cart-compare'),(916361,'watch','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(916362,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(916363,'watch','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(916364,'watch','.b-table .table td','padding-top','15','','','.b-table'),(916365,'watch','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(916366,'watch','.b-info .info li','padding-top','0','','','.b-info'),(916367,'watch','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(916368,'watch','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(916369,'watch','.b-email .model','padding-top','5','','','.b-email'),(916370,'watch','.b-email .totals-value','padding-top','5','','','.b-email'),(916371,'watch','.b-email .heading-name','padding-top','5','','','.b-email'),(916372,'watch','.products-quick-index .token-input-list','padding-top','0','','',''),(916373,'watch','.w-cart-compare .cart-cell','padding-top','0','','','.w-cart-compare'),(916374,'watch','.w-product-configurator .pc_item','padding-top','10','5240','','.w-product-configurator'),(916376,'watch','.w-reviews .item','padding-top','15','','','.w-reviews'),(916377,'watch','.w-quote .cart-box-link','padding-top','5','5240','','.w-quote'),(916378,'watch','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(916379,'watch','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(916380,'watch','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(916381,'watch','.w-product-configurator .pc_attr','padding-top','5','5232','','.w-product-configurator'),(916382,'watch','.b-email .name','padding-top','5','','','.b-email'),(916383,'watch','.b-form .shipping-method .item','padding-top','0','','','.b-form'),(916384,'watch','.b-email .heading-name','padding-top','5','','','.b-email'),(916385,'watch','.b-email .qty','padding-top','5','','','.b-email'),(916386,'watch','.b-email .totals-value','padding-top','5','','','.b-email'),(916387,'watch','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(916388,'watch','.b-email .heading-model','padding-top','5','','','.b-email'),(916389,'watch','.b-compare .col-two label','padding-top','5','','','.b-compare'),(916390,'watch','.w-product-personal-catalog-button .btn','padding-top','0','','','.w-product-personal-catalog-button'),(916391,'watch','.w-cart-listing .item .attributes','padding-top','5','','','.w-cart-listing'),(916392,'watch','.w-cart-listing .item .gift-wrap label','padding-top','10','','','.w-cart-listing'),(916393,'watch','.w-cart-listing .item > div','padding-top','10','','','.w-cart-listing'),(916394,'watch','.w-cart-listing .points-earn','padding-top','0','','','.w-cart-listing'),(916395,'watch','.w-cart-listing .points-redeem','padding-top','0','','','.w-cart-listing'),(916396,'watch','.b-bottom .header-error','padding-top','20','','','.b-bottom'),(916397,'watch','.w-breadcrumb .breadcrumb-li','padding-top','0','','','.w-breadcrumb'),(916398,'watch','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(916404,'watch','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(916405,'watch','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(916406,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-top','0','','','.w-delivery-location-top-location-list'),(916407,'watch','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(916408,'watch','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(916409,'watch','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(916410,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-top','10','','','.w-image-maps'),(916411,'watch','.b-info .info ul','padding-top','0','','','.b-info'),(916412,'watch','.b-compare .col-gender','padding-top','0','','','.b-compare'),(916413,'watch','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(916414,'watch','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-top','0','','','.b-fancybox'),(916415,'watch','.b-compare .compare_pagination','padding-top','10','','','.b-compare'),(916416,'watch','.w-top-categories .item','padding-top','5','5232','','.w-top-categories'),(916417,'watch','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(916418,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(916419,'watch','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(916420,'watch','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(916423,'watch','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(916424,'watch','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(916425,'watch','.b-table .table td','padding-top','15','','','.b-table'),(916426,'watch','.w-breadcrumb .breadcrumb-li','padding-top','0','','','.w-breadcrumb'),(916427,'watch','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(916428,'watch','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(916429,'watch','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(916430,'watch','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(916431,'watch','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(916432,'watch','.w-filters .fsl_handle','padding-top','20','','','.w-filters'),(916433,'watch','.w-filters .head-filter-widget','padding-top','0','5240','','.w-filters'),(916434,'watch','.w-filters .ui-slider-range','padding-top','0','','','.w-filters'),(916435,'watch','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(916436,'watch','.w-delivery-location-top-location-list .deliveryList ul','padding-top','0','','','.w-delivery-location-top-location-list'),(916437,'watch','.w-filters .head-filter-widget','padding-top','0','','','.w-filters'),(916438,'watch','.b-autocomplete .ui-autocomplete','padding-top','2','','','.b-autocomplete'),(916439,'watch','.w-promo-code .holder','padding-top','20','5261','','.w-promo-code'),(916441,'watch','.order-summary .heading-2','padding-top','10','','','.order-summary'),(916442,'watch','.b-compare .column_wrapper','padding-top','0','','','.b-compare'),(916443,'watch','.b-email .image','padding-top','5','','','.b-email'),(916444,'watch','.b-email .heading-price','padding-top','5','','','.b-email'),(916445,'watch','.b-email .heading-image','padding-top','5','','','.b-email'),(916446,'watch','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(916447,'watch','.b-table .table .headings td','padding-top','5','','','.b-table'),(916448,'watch','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(916449,'watch','.w-product-configurator .pc_item','padding-top','10','','','.w-product-configurator'),(916450,'watch','.w-product-properties li','padding-top','5','','','.w-product-properties'),(916451,'watch','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(916452,'watch','.w-reviews-content .author','padding-top','0','','','.w-reviews-content'),(916453,'watch','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(916454,'watch','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(916455,'watch','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(916456,'watch','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(916457,'watch','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(916458,'watch','.price .old','padding-top','0.3','','',''),(916459,'watch','.b-data-table table.dataTable tbody td','padding-top','10','','','.b-data-table'),(916460,'watch','.b-data-table table.dataTable thead td','padding-top','10','','','.b-data-table'),(916461,'watch','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(916462,'watch','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(916463,'watch','.b-table .table td','padding-top','15','','','.b-table'),(916464,'watch','.btn-2','padding-top','14','','',''),(916465,'watch','.w-quote-products .empty','padding-top','100','','','.w-quote-products'),(916466,'watch','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(916467,'watch','.b-info .info li','padding-top','0','','','.b-info'),(916468,'watch','.b-info .info','padding-top','20','','','.b-info'),(916469,'watch','.w-checkout-create-account .create-account','padding-top','10','','','.w-checkout-create-account'),(916470,'watch','.b-email .totals-title','padding-top','5','','','.b-email'),(916471,'watch','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(916472,'watch','.b-upload-files .upload-files','padding-top','0','','','.b-upload-files'),(916473,'watch','.b-email .totals-value','padding-top','5','','','.b-email'),(916474,'watch','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(916475,'watch','.b-email .totals-value','padding-top','5','','','.b-email'),(916476,'watch','.b-email .totals-title','padding-top','5','','','.b-email'),(916477,'watch','.b-email .qty','padding-top','5','','','.b-email'),(916478,'watch','.btn','padding-top','5','','',''),(916479,'watch','.w-personal-gift-status-bar .timeline','padding-top','16','','','.w-personal-gift-status-bar'),(916480,'watch','.b-product-images .media-popup .mp-content','padding-top','0','','','.b-product-images'),(916481,'watch','.b-product-images .media-popup .mp-small-images .item','padding-top','10','','','.b-product-images'),(916482,'watch','.b-product-images .media-popup .slick-dots','padding-top','0','','','.b-product-images'),(916483,'watch','.b-product-images .media-popup .slick-dots li','padding-top','0','','','.b-product-images'),(916484,'watch','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-top','0','','','.b-menu-style'),(916485,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-1 > li > .no-link','padding-top','5','','','.b-menu-style-1'),(916486,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','padding-top','5','','','.b-menu-style-1'),(916487,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','padding-top','20','','','.b-menu-style-1'),(916488,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3','padding-top','40','','','.b-menu-style-1'),(916489,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','padding-top','0','','','.b-menu-style-1'),(916490,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .current','padding-top','5','','','.b-menu-style-2'),(916491,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current','padding-top','5','','','.b-menu-style-2'),(916492,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','padding-top','0','','','.b-menu-style-2'),(916493,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','padding-top','0','','','.b-menu-style-2'),(916494,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','padding-top','10','','','.b-menu-style-2'),(916495,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item a','padding-top','0','','','.b-menu-style-2'),(916496,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','padding-top','5','','','.b-menu-style-2'),(916497,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .component-item','padding-top','10','','','.b-menu-style-2'),(916498,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .no-link','padding-top','5','','','.b-menu-style-2'),(916499,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-html_box','padding-top','7','','','.b-menu-style-2'),(916500,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','padding-top','10','','','.b-menu-style-2'),(916501,'watch','.b-personal-catalog-popup #personal_catalog_popup','padding-top','20','','','.b-personal-catalog-popup'),(916502,'watch','.b-trade-approval .steps-bar li a','padding-top','7','','','.b-trade-approval'),(916503,'watch','.b-trade-approval .middle-form','padding-top','20','','','.b-trade-approval'),(916504,'watch','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-top','5','','','.b-trade-approval'),(916505,'watch','.b-trade-approval .steps-bar','padding-top','0','','','.b-trade-approval'),(916506,'watch','.b-trade-approval .center-buttons','padding-top','20','','','.b-trade-approval'),(916507,'watch','.w-account-personal-catalog .list-switcher','padding-top','0','','','.w-account-personal-catalog'),(916508,'watch','.w-account-personal-catalog .list-switcher a','padding-top','14','','','.w-account-personal-catalog'),(916509,'watch','.w-account-personal-catalog .list-switcher a','padding-top','12','2','','.w-account-personal-catalog'),(916510,'watch','.w-account-subscription .subscription-variant','padding-top','10','','','.w-account-subscription'),(916511,'watch','.w-catalog-additional-images li','padding-top','10','','','.w-catalog-additional-images'),(916512,'watch','.w-catalog-additional-images ul','padding-top','0','','','.w-catalog-additional-images'),(916513,'watch','.w-catalog-compare td','padding-top','10','','','.w-catalog-compare'),(916514,'watch','.w-catalog-compare .cross-box .different-all > div','padding-top','12','','','.w-catalog-compare'),(916515,'watch','.w-catalog-compare .cross-box .different-all > div','padding-top','10','2','','.w-catalog-compare'),(916516,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-top','0','','','.w-catalog-compare'),(916517,'watch','.w-delivery-day .left-count','padding-top','5','','','.w-delivery-day'),(916518,'watch','.w-delivery-day .left-text-left','padding-top','24','','','.w-delivery-day'),(916519,'watch','.w-delivery-day .left-text-right','padding-top','24','','','.w-delivery-day'),(916520,'watch','.w-top-text .top-text','padding-top','5','','','.w-top-text'),(916521,'watch','.w-product-images .slick-vertical + .produst-image','padding-top','400','','','.w-product-images'),(916522,'watch','.w-cart-listing .points','padding-top','0','5232','','.w-cart-listing'),(916523,'watch','.w-product-images .additional-horizontal .item','padding-top','10','','','.w-product-images'),(916524,'watch','.w-filters .filter-box-content ul','padding-top','0','','','.w-filters'),(916525,'watch','.order-summary .w-cart-listing .item > div ~ div','padding-top','0','','','.order-summary'),(916526,'watch','.w-cart-discount-coupon .discount-box','padding-top','5','','','.w-cart-discount-coupon'),(916559,'watch','.catalog-product-wrap .next-product','padding-top','20','','','.catalog-product-wrap'),(916560,'watch','.catalog-product-wrap .pn-direction','padding-top','0','','','.catalog-product-wrap'),(916561,'watch','.catalog-product-wrap .pn-image','padding-top','20','','','.catalog-product-wrap'),(916562,'watch','.catalog-product-wrap .pn-name','padding-top','15','','','.catalog-product-wrap'),(916563,'watch','.catalog-product-wrap .prev-product','padding-top','20','','','.catalog-product-wrap'),(916564,'watch','.catalog-product-wrap .next-product','padding-top','20','5240','','.catalog-product-wrap'),(916565,'watch','.catalog-product-wrap .pn-direction','padding-top','0','5240','','.catalog-product-wrap'),(916566,'watch','.catalog-product-wrap .prev-product','padding-top','20','5240','','.catalog-product-wrap'),(916567,'watch','.catalog-product-wrap .product > .box-block','padding-top','0','5240','','.catalog-product-wrap'),(916568,'watch','.checkout-index-wrap .checkout-cart-listing.main-listing','padding-top','30','','','.checkout-index-wrap'),(916569,'watch','.checkout-index-wrap .closeable-heading + .closeable-content','padding-top','10','','','.checkout-index-wrap'),(916570,'watch','.checkout-index-wrap .dob-hide label','padding-top','5','','','.checkout-index-wrap'),(916571,'watch','.checkout-index-wrap .edit-address-popup','padding-top','20','','','.checkout-index-wrap'),(916572,'watch','.checkout-success-wrap .page-success .text-1','padding-top','120','','','.checkout-success-wrap'),(916573,'watch','.checkout-success-wrap .page-success .text-1','padding-top','5','5232','','.checkout-success-wrap'),(916574,'watch','.shopping-cart-index .cart-page .empty','padding-top','100','','','.shopping-cart-index'),(916575,'watch','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-top','0','','','.shopping-cart-index'),(916576,'watch','.account-order-pay .contentColumn','padding-top','10','','','.account-order-pay'),(916577,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-top','5','','','.account-order-pay'),(916578,'watch','.account-order-pay .history_attr','padding-top','5','','','.account-order-pay'),(916579,'watch','.account-order-pay .history_info > div + div','padding-top','0','','','.account-order-pay'),(916580,'watch','.account-order-pay .history_info > div','padding-top','0','5240','','.account-order-pay'),(916581,'watch','.account-order-pay .history_info > div + div','padding-top','0','5240','','.account-order-pay'),(916582,'watch','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-top','10','','','.account-samples'),(916583,'watch','.account-samples .orders-table th','padding-top','2','','','.account-samples'),(916584,'watch','.account-samples .order_history_table th','padding-top','10','','','.account-samples'),(916585,'watch','.account-samples .view_link','padding-top','0','','','.account-samples'),(916586,'watch','.account-samples .orders-table .td-alignright','padding-top','5','5240','','.account-samples'),(916587,'watch','.account-samples .orders-table td','padding-top','5','5240','','.account-samples'),(916588,'watch','.account-sample-info .contentColumn','padding-top','10','','','.account-sample-info'),(916589,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-top','5','','','.account-sample-info'),(916590,'watch','.account-sample-info .history_attr','padding-top','5','','','.account-sample-info'),(916591,'watch','.account-sample-info .history_info > div + div','padding-top','0','','','.account-sample-info'),(916592,'watch','.account-sample-info .popup-tracking-number','padding-top','10','','','.account-sample-info'),(916593,'watch','.account-sample-info .history_info > div','padding-top','0','5240','','.account-sample-info'),(916594,'watch','.account-sample-info .history_info > div + div','padding-top','0','5240','','.account-sample-info'),(916595,'watch','.checkout-order-confirmation .price-row','padding-top','5','','','.checkout-order-confirmation'),(916596,'watch','.checkout-login-wrap .password-forgotten-link','padding-top','0','','','.checkout-login-wrap'),(916597,'watch','.b-bottom .pop-up-content','padding-top','15','','','.b-bottom'),(916598,'watch','.b-form .columns .col-2','padding-top','0','','','.b-form'),(916599,'watch','.b-bottom .pop-up-content .buttons','padding-top','10','','','.b-bottom'),(916600,'watch','.b-slick .slick-dots li','padding-top','5','','','.b-slick'),(916603,'watch','.success-page .check-ico-block','padding-top','20','','','.success-page'),(916604,'watch','.success-page .order_totals .price-row','padding-top','5','','','.success-page'),(916605,'watch','.success-page .page-success .text-1','padding-top','5','5232','','.success-page'),(916606,'watch','.success-page .price-row','padding-top','5','','','.success-page'),(916607,'watch','.success-page .totals-line','padding-top','10','','','.success-page'),(916608,'watch','.success-page .w-cart-listing .qty','padding-top','0','','','.success-page'),(916609,'watch','.b-multi-page-checkout .multi-page-checkout','padding-top','20','','','.b-multi-page-checkout'),(916610,'watch','.b-multi-page-checkout .multi-page-checkout .buttons','padding-top','0','','','.b-multi-page-checkout'),(916611,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-top','20','','','.b-multi-page-checkout'),(916612,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-top','8','','','.b-multi-page-checkout'),(916613,'watch','.b-form .col-left','padding-top','0','','','.b-form'),(916614,'watch','.b-form .col-right','padding-top','0','','','.b-form'),(916617,'watch','.w-bestsellers .heading-3','padding-top','7','','','.w-bestsellers'),(916619,'watch','.w-account-customer-additional-field .tf-file','padding-top','5','','','.w-account-customer-additional-field'),(916620,'watch','.w-account-customer-additional-field .tf-file .remove','padding-top','0','','','.w-account-customer-additional-field'),(916621,'watch','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','6','','','.w-menu-style-1'),(916622,'watch','.w-menu-style-1 ul','padding-top','0','','','.w-menu-style-1'),(916623,'watch','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','padding-top','12','5240','','.w-menu-style-1'),(916624,'watch','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','padding-top','12','5240','','.w-menu-style-1'),(916625,'watch','.b-slick .slick-list','padding-top','0','','','.b-slick'),(916626,'watch','.b-slick .slick-vertical button.slick-next','padding-top','0','3','','.b-slick'),(916627,'watch','.b-slick .slick-vertical button.slick-prev','padding-top','0','3','','.b-slick'),(916628,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','padding-top','0','','','.b-slick'),(916629,'watch','.w-banner .banner-text','padding-top','20','','','.w-banner'),(916630,'watch','.w-banner .carousel-text > span','padding-top','20','','','.w-banner'),(916631,'watch','.w-catalog-paging .paging-item','padding-top','0','','','.w-catalog-paging'),(916632,'watch','.b-data-table table.dataTable tbody td','padding-top_important','important','','','.b-data-table'),(916633,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top_important','important','','','.b-data-table'),(916634,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top_important','important','','','.b-data-table'),(916635,'watch','.b-data-table table.dataTable thead td','padding-top_important','important','','','.b-data-table'),(916636,'watch','.w-cart-listing .points','padding-top_important','important','5232','','.w-cart-listing'),(916637,'watch','.success-page .totals-line','padding-top_important','important','','','.success-page'),(916638,'watch','.w-categories .image','padding_bottom_measure','%','','','.w-categories'),(916639,'watch','.w-top-categories .image','padding_bottom_measure','%','','','.w-top-categories'),(916640,'watch','.b-upload-file .upload-file-template','padding_left_measure','%','','','.b-upload-file'),(916641,'watch','.w-cart-give-away .ga_img','padding_left_measure','%','','','.w-cart-give-away'),(916642,'watch','.b-product-images .media-popup .mp-content','padding_left_measure','%','','','.b-product-images'),(916645,'watch','.account-order-pay .history_info > div + div','padding_left_measure','%','','','.account-order-pay'),(916646,'watch','.account-sample-info .history_info > div + div','padding_left_measure','%','','','.account-sample-info'),(916647,'watch','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(916648,'watch','.b-upload-file .upload-file-template','padding_right_measure','%','','','.b-upload-file'),(916649,'watch','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(916650,'watch','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(916651,'watch','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(916652,'watch','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(916653,'watch','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(916654,'watch','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(916655,'watch','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(916656,'watch','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(916657,'watch','.w-cart-give-away .ga_img','padding_right_measure','%','','','.w-cart-give-away'),(916658,'watch','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(916659,'watch','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(916660,'watch','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(916661,'watch','.b-product-images .media-popup .mp-content','padding_right_measure','%','','','.b-product-images'),(916663,'watch','.price .old','padding_top_measure','em','','',''),(916664,'watch','.b-slick .slick-slide.dragging img','pointer-events','none','','','.b-slick'),(916665,'watch','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(916666,'watch','.w-checkout-shipping-address .addresses .address-item label','position','relative','','','.w-checkout-shipping-address'),(916667,'watch','.b-form .radio-buttons .radio-button','position','relative','','','.b-form'),(916668,'watch','.w-checkout-billing-address .addresses .address-item label','position','relative','','','.w-checkout-billing-address'),(916669,'watch','.b-info .info','position','relative','3','','.b-info'),(916670,'watch','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position','absolute','','','.b-switch'),(916671,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','position','relative','3','','.b-switch'),(916672,'watch','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(916673,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(916674,'watch','.b-fancybox .filter-listing-preloader','position','absolute','','','.b-fancybox'),(916675,'watch','.b-fancybox .filter-listing-loader','position','absolute','','','.b-fancybox'),(916676,'watch','.w-promotions .prom-multi-discount > .heading','position','relative','3','','.w-promotions'),(916677,'watch','.w-promotions .prom-multi-discount .promo-range','position','relative','','','.w-promotions'),(916678,'watch','.w-promotions .promo-date','position','relative','','','.w-promotions'),(916682,'watch','.shipping-ico .heading-2','position','relative','3','','.shipping-ico'),(916683,'watch','.p-sample-checkout-success .page-success > div','position','relative','','','.p-sample-checkout-success'),(916684,'watch','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(916685,'watch','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(916686,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(916687,'watch','.testimonials .reviews-list span','position','relative','','',''),(916688,'watch','.testimonials .heading-3','position','relative','','',''),(916689,'watch','.testimonials .review','position','absolute','3','',''),(916690,'watch','.testimonials .review','position','relative','','',''),(916691,'watch','.testimonials .rating','position','relative','','',''),(916692,'watch','.testimonials .heading-3','position','absolute','3','',''),(916693,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(916694,'watch','.w-promotions .prom-multi-discount .products','position','relative','','','.w-promotions'),(916695,'watch','.w-promotions .icon','position','relative','','','.w-promotions'),(916696,'watch','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','position','relative','3','','.w-promotions'),(916697,'watch','.w-promotions .promo-salemaker .discount','position','relative','','','.w-promotions'),(916698,'watch','.w-promotions .promo-cart-discount .slave .content','position','relative','','','.w-promotions'),(916699,'watch','.w-promotions .promo-cart-discount .promo-min-qty','position','relative','','','.w-promotions'),(916700,'watch','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','position','relative','3','','.w-promotions'),(916701,'watch','.b-preloader .preloader','position','absolute','3','','.b-preloader'),(916702,'watch','.b-preloader .preloader','position','absolute','','','.b-preloader'),(916703,'watch','.w-checkout-create-account .account-benefits strong','position','relative','3','','.w-checkout-create-account'),(916704,'watch','.w-cart-compare .cart-cell > div','position','relative','','','.w-cart-compare'),(916705,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(916706,'watch','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(916707,'watch','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(916708,'watch','.closeable-heading','position','absolute','3','',''),(916709,'watch','.closeable-heading','position','relative','','',''),(916710,'watch','.b-messages .messBtnMenuDelete','position','relative','3','','.b-messages'),(916711,'watch','.b-messages .messMenuButton span','position','relative','','','.b-messages'),(916712,'watch','.b-messages .messBtnMenuStarred','position','relative','3','','.b-messages'),(916713,'watch','.b-messages span.starred::before','position','relative','','','.b-messages'),(916714,'watch','.b-messages .messBtnMenuUnread','position','relative','3','','.b-messages'),(916715,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-messages'),(916716,'watch','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(916717,'watch','.w-product-personal-catalog-button .btn','position','absolute','3','','.w-product-personal-catalog-button'),(916718,'watch','.b-info-popup .info-popup div','position','absolute','3','','.b-info-popup'),(916719,'watch','.b-info .info','position','relative','','','.b-info'),(916720,'watch','.p-payer-order-confirmation .order-ico','position','relative','3','','.p-payer-order-confirmation'),(916721,'watch','.p-payer-order-confirmation .comment-ico','position','relative','3','','.p-payer-order-confirmation'),(916722,'watch','.p-payer-order-confirmation .discount-ico','position','relative','3','','.p-payer-order-confirmation'),(916723,'watch','.p-payer-order-pay .order-ico','position','relative','3','','.p-payer-order-pay'),(916724,'watch','.w-checkout-terms .terms-box','position','relative','','','.w-checkout-terms'),(916725,'watch','.p-payer-order-pay .discount-ico','position','relative','3','','.p-payer-order-pay'),(916726,'watch','.p-payer-order-pay .comment-ico','position','relative','3','','.p-payer-order-pay'),(916727,'watch','.w-checkout-terms .required-message-wrap','position','static','','','.w-checkout-terms'),(916728,'watch','.w-checkout-terms input[type=\"checkbox\"]','position','relative','','','.w-checkout-terms'),(916729,'watch','.w-checkout-shipping-address .genders-title input','position','relative','','','.w-checkout-shipping-address'),(916730,'watch','.b-fancybox #fancybox-loading','position','fixed','','','.b-fancybox'),(916731,'watch','.b-form .radio-button input[type=\"radio\"]','position','relative','','','.b-form'),(916732,'watch','.b-fancybox .fancybox-wrap','position','absolute','','','.b-fancybox'),(916733,'watch','.b-upload-file .snapshot','position','absolute','','','.b-upload-file'),(916735,'watch','.b-rating .glyphicon','position','relative','','','.b-rating'),(916736,'watch','.w-checkout-shipping-choice input:checked + span:before','position','absolute','','','.w-checkout-shipping-choice'),(916737,'watch','.shipping-ico .heading-2','position','relative','3','','.shipping-ico'),(916738,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(916739,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(916740,'watch','.w-upload-customer-id-upload-customer-id-form .upload-remove','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(916741,'watch','.w-upload-customer-id-upload-customer-id-form .dz-details','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(916742,'watch','.b-switch .bootstrap-switch','position','relative','','','.b-switch'),(916743,'watch','.b-info .info','position','relative','','','.b-info'),(916744,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(916745,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(916746,'watch','.w-coupons-and-vauchers-checkout .btn-remove','position','relative','','','.w-coupons-and-vauchers-checkout'),(916747,'watch','.b-products-listing .products-listing .radio-attributes input','position','relative','','','.b-products-listing'),(916748,'watch','.b-products-listing .products-listing .btn-buy','position','relative','3','','.b-products-listing'),(916749,'watch','.b-form .col-3','position','relative','','','.b-form'),(916750,'watch','.w-menu-horizontal li','position','relative','','','.w-menu-horizontal'),(916751,'watch','.b-info .info','position','relative','','','.b-info'),(916752,'watch','.b-form .billing-address','position','relative','','','.b-form'),(916753,'watch','.w-quote .cart-box-link','position','relative','','','.w-quote'),(916754,'watch','.b-form .form-buttons','position','relative','','','.b-form'),(916755,'watch','.b-fancybox .fancybox-title-over-wrap','position','absolute','','','.b-fancybox'),(916756,'watch','.b-fancybox .fancybox-title-outside-wrap','position','relative','','','.b-fancybox'),(916757,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','position','absolute','','','.b-switch'),(916758,'watch','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(916760,'watch','.w-cart-compare .atr-col','position','relative','','','.w-cart-compare'),(916761,'watch','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(916762,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','position','relative','','','.b-switch'),(916763,'watch','.b-switch .candlestick-wrapper','position','relative','','','.b-switch'),(916764,'watch','.b-bottom .footerTitle','position','absolute','5232,4','','.b-bottom'),(916765,'watch','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(916766,'watch','.b-select-suggest .select2-measure-scrollbar','position','absolute','','','.b-select-suggest'),(916767,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position','absolute','','','.b-select-suggest'),(916768,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(916769,'watch','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(916770,'watch','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(916771,'watch','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(916772,'watch','.w-reviews .review','position','relative','','','.w-reviews'),(916773,'watch','.w-reviews .heading-3','position','relative','','','.w-reviews'),(916774,'watch','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(916776,'watch','.b-info-popup .info-popup div','position','absolute','','','.b-info-popup'),(916777,'watch','.bell-ico .heading-2','position','relative','3','','.bell-ico'),(916778,'watch','.b-select-suggest .select2-search-choice-close','position','absolute','','','.b-select-suggest'),(916779,'watch','.view-all','position','absolute','3','',''),(916780,'watch','.view-all','position','relative','','',''),(916781,'watch','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(916782,'watch','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(916783,'watch','.view-all .btn','position','relative','','',''),(916786,'watch','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(916788,'watch','.b-form .checkbox-style','position','absolute','','','.b-form'),(916790,'watch','.edit-link','position','relative','','',''),(916791,'watch','.message.success','position','relative','3','',''),(916793,'watch','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(916794,'watch','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(916795,'watch','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(916796,'watch','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(916797,'watch','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(916798,'watch','.shipping-ico .heading-2','position','relative','3','','.shipping-ico'),(916799,'watch','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(916800,'watch','.b-upload-file .upload-remove','position','absolute','','','.b-upload-file'),(916801,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','position','absolute','','','.b-switch'),(916802,'watch','.b-info .info','position','relative','3','','.b-info'),(916804,'watch','.order-summary .heading-2','position','relative','3','','.order-summary'),(916805,'watch','.savings-ico .heading-2','position','relative','3','','.savings-ico'),(916806,'watch','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(916807,'watch','.w-multi-cart-actions .cart-actions','position','relative','','','.w-multi-cart-actions'),(916808,'watch','.w-reviews .review','position','absolute','3','','.w-reviews'),(916809,'watch','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(916811,'watch','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(916812,'watch','.b-form .addresses .address-item input[type=\"radio\"]','position','relative','','','.b-form'),(916813,'watch','.w-product-personal-catalog-button .btn','position','relative','','','.w-product-personal-catalog-button'),(916814,'watch','.w-product-personal-catalog-button .btn','position','absolute','3','','.w-product-personal-catalog-button'),(916815,'watch','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(916816,'watch','.w-product-reviews .reviews-list .review','position','relative','','','.w-product-reviews'),(916817,'watch','.b-fancybox .fancybox-skin','position','relative','','','.b-fancybox'),(916818,'watch','.b-fancybox .fancybox-overlay-fixed','position','fixed','','','.b-fancybox'),(916819,'watch','.b-fancybox .fancybox-overlay','position','absolute','','','.b-fancybox'),(916820,'watch','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(916821,'watch','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(916824,'watch','.b-pass-strength .pass-strength span','position','absolute','','','.b-pass-strength'),(916826,'watch','.b-fancybox .fancybox-nav','position','absolute','','','.b-fancybox'),(916827,'watch','.b-info .info','position','relative','3','','.b-info'),(916828,'watch','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(916829,'watch','.w-promo-code .holder','position','relative','','','.w-promo-code'),(916830,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(916831,'watch','.b-form .shipping-method .input input','position','relative','','','.b-form'),(916832,'watch','.w-reviews .heading-3','position','absolute','3','','.w-reviews'),(916833,'watch','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(916834,'watch','.b-select-suggest .select2-container .select2-choice','position','relative','','','.b-select-suggest'),(916835,'watch','.b-select-suggest .select2-container','position','relative','','','.b-select-suggest'),(916836,'watch','.b-info .info','position','relative','3','','.b-info'),(916837,'watch','.b-info .info','position','relative','','','.b-info'),(916838,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','position','relative','3','','.b-switch'),(916839,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','position','relative','3','','.b-switch'),(916841,'watch','.b-form .hide-billing-address','position','absolute','','','.b-form'),(916842,'watch','.b-form .radio-button input[type=\"radio\"].no','position','absolute','','','.b-form'),(916843,'watch','.b-form .payment-method .item-radio input','position','relative','','','.b-form'),(916844,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(916845,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(916846,'watch','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(916847,'watch','.w-product-personal-catalog-button .btn','position','absolute','3','','.w-product-personal-catalog-button'),(916848,'watch','.w-reviews-content .review','position','absolute','3','','.w-reviews-content'),(916849,'watch','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(916850,'watch','.w-product-personal-catalog-button .btn','position','relative','','','.w-product-personal-catalog-button'),(916851,'watch','.p-quick-order-index .all-scroll-div','position','fixed','','','.p-quick-order-index'),(916852,'watch','.w-checkout-billing-address .genders-title input','position','relative','','','.w-checkout-billing-address'),(916853,'watch','.b-form .required-message-wrap','position','relative','','','.b-form'),(916854,'watch','.b-form .radio-button input[type=\"radio\"].no + span','position','relative','3','','.b-form'),(916855,'watch','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(916856,'watch','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(916857,'watch','.w-promotions .promo-cart-discount .slave .condition','position','relative','','','.w-promotions'),(916858,'watch','.w-product-personal-catalog-button .btn','position','relative','','','.w-product-personal-catalog-button'),(916859,'watch','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(916860,'watch','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(916861,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(916863,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(916864,'watch','.w-checkout-credit-amount .btn-remove','position','relative','','','.w-checkout-credit-amount'),(916866,'watch','.w-promo-code .holder','position','relative','','','.w-promo-code'),(916867,'watch','.b-info-popup .info-popup','position','relative','3','','.b-info-popup'),(916868,'watch','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(916869,'watch','.w-product-personal-catalog-button .btn','position','absolute','3','','.w-product-personal-catalog-button'),(916870,'watch','.b-autocomplete .ui-autocomplete','position','absolute','','','.b-autocomplete'),(916871,'watch','.b-info .info','position','relative','','','.b-info'),(916872,'watch','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(916873,'watch','.b-bottom .footerTitle','position','relative','5232','','.b-bottom'),(916874,'watch','.b-info-popup .info-popup','position','relative','','','.b-info-popup'),(916875,'watch','.b-upload-files .attach-active-holder .attach-file','position','absolute','','','.b-upload-files'),(916876,'watch','.w-cart-credit-amount .btn-remove','position','relative','','','.w-cart-credit-amount'),(916877,'watch','.w-product-personal-catalog-button .btn','position','relative','','','.w-product-personal-catalog-button'),(916878,'watch','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(916879,'watch','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(916880,'watch','.b-fancybox .fancybox-close','position','absolute','','','.b-fancybox'),(916881,'watch','.b-form .required-message','position','absolute','','','.b-form'),(916882,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(916883,'watch','.b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner','position','relative','','','.b-fancybox'),(916884,'watch','.w-product-customers-activity .customers-activity','position','fixed','','','.w-product-customers-activity'),(916885,'watch','.w-product-customers-activity .close','position','absolute','','','.w-product-customers-activity'),(916887,'watch','.w-product-personal-catalog-button .btn','position','relative','','','.w-product-personal-catalog-button'),(916888,'watch','.w-product-personal-catalog-button .btn','position','absolute','3','','.w-product-personal-catalog-button'),(916889,'watch','.w-cart-compare .remove-cart','position','absolute','','','.w-cart-compare'),(916890,'watch','.w-promo-code .holder','position','relative','','','.w-promo-code'),(916891,'watch','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(916892,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(916893,'watch','.w-checkout-billing-address .addresses .address-item label input','position','absolute','','','.w-checkout-billing-address'),(916894,'watch','.w-checkout-shipping-choice input:checked + span','position','relative','','','.w-checkout-shipping-choice'),(916895,'watch','.w-checkout-shipping-choice input','position','absolute','','','.w-checkout-shipping-choice'),(916897,'watch','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(916898,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(916899,'watch','.w-quote .cart-box','position','relative','','','.w-quote'),(916900,'watch','.w-product-reviews .reviews-list span','position','relative','','','.w-product-reviews'),(916901,'watch','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(916902,'watch','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(916903,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-select-suggest'),(916904,'watch','.b-select-suggest .select2-container-multi .select2-choices','position','relative','','','.b-select-suggest'),(916905,'watch','.b-select-suggest .select2-results','position','relative','','','.b-select-suggest'),(916906,'watch','.w-image-maps .svg-wrap svg','position','absolute','','','.w-image-maps'),(916907,'watch','.w-checkout-shipping-address .addresses .address-item label input','position','absolute','','','.w-checkout-shipping-address'),(916908,'watch','.w-neighbour-checkout .bootstrap-switch','position','relative','','','.w-neighbour-checkout'),(916909,'watch','.b-select-suggest .select2-search','position','relative','','','.b-select-suggest'),(916910,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow','position','absolute','','','.b-select-suggest'),(916911,'watch','.b-select-suggest .select2-drop','position','absolute','','','.b-select-suggest'),(916912,'watch','.b-select-suggest .select2-drop-mask','position','fixed','','','.b-select-suggest'),(916913,'watch','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(916915,'watch','.w-product-personal-catalog-button .btn','position','relative','','','.w-product-personal-catalog-button'),(916916,'watch','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(916918,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','position','absolute','','','.b-switch'),(916919,'watch','.b-pass-strength .pass-strength','position','relative','','','.b-pass-strength'),(916920,'watch','.p-sample-checkout-success .page-success','position','relative','','','.p-sample-checkout-success'),(916921,'watch','.w-menu-big li','position','static','','','.w-menu-big'),(916922,'watch','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(916923,'watch','.w-promo-code .holder','position','relative','','','.w-promo-code'),(916924,'watch','.w-account-addresses-list .address-fields input[type=\"radio\"]','position','relative','','','.w-account-addresses-list'),(916925,'watch','.b-products-listing .products-listing .promos-info','position','absolute','','','.b-products-listing'),(916926,'watch','.b-products-listing .products-listing .image','position','relative','','','.b-products-listing'),(916927,'watch','.b-products-listing .hover-box-content','position','absolute','3','','.b-products-listing'),(916928,'watch','.b-products-listing .hover-box','position','relative','','','.b-products-listing'),(916929,'watch','.b-products-listing .hover-box-content','position','absolute','','','.b-products-listing'),(916930,'watch','.b-products-listing .loader','position','absolute','4','','.b-products-listing'),(916931,'watch','.b-products-listing .loader','position','absolute','3','','.b-products-listing'),(916932,'watch','.b-products-listing .loader','position','relative','','','.b-products-listing'),(916933,'watch','.w-catalog-b2b-add-button ','position','fixed','','','.w-catalog-b2b-add-button'),(916934,'watch','.b-products-listing .products-listing .qty-input.hidden','position','absolute','3','','.b-products-listing'),(916935,'watch','.b-products-listing .promo','position','absolute','','','.b-products-listing'),(916936,'watch','.b-products-listing .promo-icon','position','relative','','','.b-products-listing'),(916937,'watch','.b-products-listing .promos-info','position','relative','','','.b-products-listing'),(916938,'watch','.checkbox input:not(checked) + span:before','position','absolute','','',''),(916939,'watch','.checkbox input','position','ablolute','','',''),(916944,'watch','.w-promo-code .holder','position','relative','','','.w-promo-code'),(916945,'watch','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(916946,'watch','.b-form .hide-box','position','relative','','','.b-form'),(916947,'watch','.b-info .info','position','relative','','','.b-info'),(916948,'watch','.b-fancybox .fancybox-title','position','relative','','','.b-fancybox'),(916949,'watch','.b-fancybox .fancybox-title-float-wrap','position','absolute','','','.b-fancybox'),(916950,'watch','.w-personal-gift-status-bar .end-date','position','relative','3','','.w-personal-gift-status-bar'),(916952,'watch','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(916953,'watch','.w-product-personal-catalog-button .btn','position','absolute','3','','.w-product-personal-catalog-button'),(916954,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(916955,'watch','.w-taxable input[type=\"radio\"]','position','relative','','','.w-taxable'),(916956,'watch','.b-form .eye-password-wrap','position','relative','','','.b-form'),(916957,'watch','.b-form .eye-password','position','absolute','','','.b-form'),(916958,'watch','.w-taxable input[type=\"checkbox\"]','position','relative','','','.w-taxable'),(916959,'watch','.b-info .info','position','relative','3','','.b-info'),(916960,'watch','.b-fancybox .fancybox-tmp','position','absolute','','','.b-fancybox'),(916961,'watch','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(916962,'watch','.b-datepicker .datepicker-dropdown','position','absolute','','','.b-datepicker'),(916963,'watch','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(916966,'watch','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(916967,'watch','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(916968,'watch','.b-info .info','position','relative','3','','.b-info'),(916969,'watch','.b-form .columns .col-2','position','relative','','','.b-form'),(916970,'watch','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','position','relative','3','','.order-summary'),(916971,'watch','.w-cart-compare .atr-col','position','absolute','3','','.w-cart-compare'),(916972,'watch','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(916973,'watch','.w-promo-code .holder','position','relative','','','.w-promo-code'),(916974,'watch','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(916975,'watch','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(916976,'watch','.w-menu-horizontal ul ul','position','absolute','','','.w-menu-horizontal'),(916977,'watch','.w-cart-listing .item','position','relative','','','.w-cart-listing'),(916978,'watch','.w-cart-listing .item .gift-wrap label','position','relative','','','.w-cart-listing'),(916979,'watch','.w-cart-listing .remove-btn span','position','relative','5240','','.w-cart-listing'),(916980,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(916981,'watch','.w-cart-discount-coupon .btn-remove','position','relative','','','.w-cart-discount-coupon'),(916986,'watch','.w-image-maps .svg-wrap','position','relative','','','.w-image-maps'),(916987,'watch','.b-fancybox .fancybox-nav span','position','absolute','','','.b-fancybox'),(916988,'watch','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(916989,'watch','.w-personal-gift-status-bar .inform','position','relative','4','','.w-personal-gift-status-bar'),(916991,'watch','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(916992,'watch','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(916993,'watch','.w-product-reviews .reviews-list .review','position','absolute','3','','.w-product-reviews'),(916994,'watch','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(916995,'watch','.w-filters .input-checkbox','position','absolute','','','.w-filters'),(916996,'watch','.w-filters .head-filter-widget','position','relative','','','.w-filters'),(916997,'watch','.b-bottom .pop-up-close','position','absolute','','','.b-bottom'),(916998,'watch','.w-reviews-content .review','position','relative','','','.w-reviews-content'),(917000,'watch','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(917001,'watch','.b-form .same-address','position','relative','','','.b-form'),(917002,'watch','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(917003,'watch','.w-menu-big ','position','relative','','','.w-menu-big'),(917004,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(917005,'watch','.w-menu-big > ul > li > ul','position','absolute','','','.w-menu-big'),(917006,'watch','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(917007,'watch','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(917008,'watch','.b-select-suggest .select2-container .select2-choice abbr','position','absolute','','','.b-select-suggest'),(917009,'watch','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(917010,'watch','.w-filters .mobileCollapse','position','absolute','','','.w-filters'),(917011,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','position','fixed','','','.w-image-maps'),(917012,'watch','.b-product-images .media-popup .mp-close','position','absolute','','','.b-product-images'),(917013,'watch','.b-product-images .mp-shadow, .b-product-images .media-popup','position','fixed','','','.b-product-images'),(917014,'watch','.b-menu-burger_icon .menu-style[data-burger_icon]','position','relative','','','.b-menu-burger_icon'),(917015,'watch','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-1 > li','position','relative','','','.b-menu-lev_display-down'),(917016,'watch','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','position','absolute','','','.b-menu-lev_display-down'),(917017,'watch','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-2 > li','position','relative','','','.b-menu-lev_display-down'),(917018,'watch','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','position','absolute','','','.b-menu-lev_display-down'),(917019,'watch','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-3 > li','position','relative','','','.b-menu-lev_display-down'),(917020,'watch','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','position','absolute','','','.b-menu-lev_display-down'),(917021,'watch','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-4 > li','position','relative','','','.b-menu-lev_display-down'),(917022,'watch','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','position','absolute','','','.b-menu-lev_display-down'),(917023,'watch','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-5 > li','position','relative','','','.b-menu-lev_display-down'),(917024,'watch','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','position','absolute','','','.b-menu-lev_display-down'),(917025,'watch','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-1 > li','position','relative','','','.b-menu-lev_display-left'),(917026,'watch','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','position','absolute','','','.b-menu-lev_display-left'),(917027,'watch','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-2 > li','position','relative','','','.b-menu-lev_display-left'),(917028,'watch','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','position','absolute','','','.b-menu-lev_display-left'),(917029,'watch','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-3 > li','position','relative','','','.b-menu-lev_display-left'),(917030,'watch','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','position','absolute','','','.b-menu-lev_display-left'),(917031,'watch','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-4 > li','position','relative','','','.b-menu-lev_display-left'),(917032,'watch','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','position','absolute','','','.b-menu-lev_display-left'),(917033,'watch','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-5 > li','position','relative','','','.b-menu-lev_display-left'),(917034,'watch','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','position','absolute','','','.b-menu-lev_display-left'),(917035,'watch','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-1 > li','position','relative','','','.b-menu-lev_display-lra'),(917036,'watch','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','position','absolute','','','.b-menu-lev_display-lra'),(917037,'watch','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-2 > li','position','relative','','','.b-menu-lev_display-lra'),(917038,'watch','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','position','absolute','','','.b-menu-lev_display-lra'),(917039,'watch','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-3 > li','position','relative','','','.b-menu-lev_display-lra'),(917040,'watch','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','position','absolute','','','.b-menu-lev_display-lra'),(917041,'watch','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-4 > li','position','relative','','','.b-menu-lev_display-lra'),(917042,'watch','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','position','absolute','','','.b-menu-lev_display-lra'),(917043,'watch','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-5 > li','position','relative','','','.b-menu-lev_display-lra'),(917044,'watch','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','position','absolute','','','.b-menu-lev_display-lra'),(917045,'watch','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right'),(917046,'watch','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','position','absolute','','','.b-menu-lev_display-right'),(917047,'watch','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right'),(917048,'watch','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','position','absolute','','','.b-menu-lev_display-right'),(917049,'watch','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right'),(917050,'watch','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','position','absolute','','','.b-menu-lev_display-right'),(917051,'watch','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right'),(917052,'watch','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','position','absolute','','','.b-menu-lev_display-right'),(917053,'watch','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right'),(917054,'watch','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','position','absolute','','','.b-menu-lev_display-right'),(917055,'watch','.b-menu-lev_display-right_top .menu-style[data-lev2_display=\"right_top\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right_top'),(917056,'watch','.b-menu-lev_display-right_top .menu-style[data-lev3_display=\"right_top\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right_top'),(917057,'watch','.b-menu-lev_display-right_top .menu-style[data-lev4_display=\"right_top\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right_top'),(917058,'watch','.b-menu-lev_display-right_top .menu-style[data-lev5_display=\"right_top\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right_top'),(917059,'watch','.b-menu-lev_display-right_top .menu-style[data-lev6_display=\"right_top\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right_top'),(917060,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .level-1','position','relative','','','.b-menu-lev_display-slide'),(917061,'watch','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] .level-2','position','relative','','','.b-menu-lev_display-slide'),(917062,'watch','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','position','absolute','','','.b-menu-lev_display-slide'),(917063,'watch','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] .level-3','position','relative','','','.b-menu-lev_display-slide'),(917064,'watch','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','position','absolute','','','.b-menu-lev_display-slide'),(917065,'watch','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] .level-4','position','relative','','','.b-menu-lev_display-slide'),(917066,'watch','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','position','absolute','','','.b-menu-lev_display-slide'),(917067,'watch','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] .level-5','position','relative','','','.b-menu-lev_display-slide'),(917068,'watch','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','position','absolute','','','.b-menu-lev_display-slide'),(917069,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','position','absolute','','','.b-menu-lev_display-slide'),(917070,'watch','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width'),(917071,'watch','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','position','absolute','','','.b-menu-lev_display-width'),(917072,'watch','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width'),(917073,'watch','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','position','absolute','','','.b-menu-lev_display-width'),(917074,'watch','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width'),(917075,'watch','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','position','absolute','','','.b-menu-lev_display-width'),(917076,'watch','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width'),(917077,'watch','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','position','absolute','','','.b-menu-lev_display-width'),(917078,'watch','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width'),(917079,'watch','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','position','absolute','','','.b-menu-lev_display-width'),(917080,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width_cont'),(917081,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','position','absolute','','','.b-menu-lev_display-width_cont'),(917082,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width_cont'),(917083,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','position','absolute','','','.b-menu-lev_display-width_cont'),(917084,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width_cont'),(917085,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','position','absolute','','','.b-menu-lev_display-width_cont'),(917086,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width_cont'),(917087,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','position','absolute','','','.b-menu-lev_display-width_cont'),(917088,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width_cont'),(917089,'watch','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','position','absolute','','','.b-menu-lev_display-width_cont'),(917090,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(917091,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(917092,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(917093,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(917094,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(917095,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','position','fixed','','','.b-menu-open_from-left'),(917096,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','position','absolute','','','.b-menu-style-1'),(917097,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','position','static','','','.b-menu-style-2'),(917098,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] a, .b-menu-style-2 .menu-style[data-style=\"2\"] .no-link','position','relative','','','.b-menu-style-2'),(917099,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','position','absolute','3','','.b-menu-style-2'),(917100,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','position','static','','','.b-menu-style-2'),(917101,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','position','relative','','','.b-menu-style-2'),(917102,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','position','absolute','3','','.b-menu-style-2'),(917103,'watch','.w-catalog-compare .compare .checkbox span','position','relative','','','.w-catalog-compare'),(917104,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','position','absolute','','','.w-filters'),(917105,'watch','.order-summary .icon','position','absolute','3','','.order-summary'),(917106,'watch','.order-summary .icon','position','relative','','','.order-summary'),(917107,'watch','.w-cart-discount-coupon .title','position','relative','','','.w-cart-discount-coupon'),(917138,'watch','.catalog-product-wrap .pn-image','position','absolute','3','','.catalog-product-wrap'),(917139,'watch','.catalog-product-wrap .prev-next-product','position','fixed','','','.catalog-product-wrap'),(917140,'watch','.checkout-index-wrap .comment-ico','position','relative','3','','.checkout-index-wrap'),(917141,'watch','.checkout-index-wrap .discount-ico','position','relative','3','','.checkout-index-wrap'),(917142,'watch','.checkout-index-wrap .order-ico','position','relative','3','','.checkout-index-wrap'),(917143,'watch','.checkout-success-wrap .page-success','position','relative','','','.checkout-success-wrap'),(917144,'watch','.checkout-success-wrap .page-success > div','position','relative','','','.checkout-success-wrap'),(917145,'watch','.shopping-cart-index .gift-code .heading-4','position','absolute','4','','.shopping-cart-index'),(917146,'watch','.shopping-cart-index .gift-code .heading-4','position','relative','5232','','.shopping-cart-index'),(917147,'watch','.account-order-pay .account_history_info.account_history_info_due','position','relative','','','.account-order-pay'),(917148,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','position','relative','','','.account-order-pay'),(917149,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','position','absolute','3','','.account-order-pay'),(917150,'watch','.account-order-pay .not_fully_paid_td','position','absolute','','','.account-order-pay'),(917151,'watch','.account-samples .moduleRowDue td','position','relative','','','.account-samples'),(917152,'watch','.account-samples .not_fully_paid_td','position','absolute','','','.account-samples'),(917153,'watch','.account-samples .view_link','position','relative','','','.account-samples'),(917154,'watch','.account-samples .view_link','position','absolute','4','','.account-samples'),(917155,'watch','.account-samples .orders-table .item','position','relative','5240','','.account-samples'),(917156,'watch','.account-samples .orders-table .order-total','position','absolute','5240','','.account-samples'),(917157,'watch','.account-samples .orders-table .status-name','position','absolute','5240','','.account-samples'),(917158,'watch','.account-samples .orders-table .td-alignright','position','absolute','5240','','.account-samples'),(917159,'watch','.account-sample-info .account_history_info.account_history_info_due','position','relative','','','.account-sample-info'),(917160,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','position','relative','','','.account-sample-info'),(917161,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','position','absolute','3','','.account-sample-info'),(917162,'watch','.account-sample-info .not_fully_paid_td','position','absolute','','','.account-sample-info'),(917163,'watch','.checkout-order-confirmation .comment-ico','position','relative','3','','.checkout-order-confirmation'),(917164,'watch','.checkout-order-confirmation .discount-ico','position','relative','3','','.checkout-order-confirmation'),(917165,'watch','.checkout-order-confirmation .order-ico','position','relative','3','','.checkout-order-confirmation'),(917166,'watch','.b-form .addresses .address-item','position','relative','','','.b-form'),(917167,'watch','.hide-page','position','fixed','','',''),(917168,'watch','.success-page .comment-ico','position','relative','3','','.success-page'),(917169,'watch','.success-page .discount-ico','position','relative','3','','.success-page'),(917170,'watch','.success-page .order-ico','position','relative','3','','.success-page'),(917171,'watch','.success-page .page-success','position','relative','','','.success-page'),(917172,'watch','.success-page .page-success .text-1','position','relative','','','.success-page'),(917173,'watch','.success-page .page-success > div','position','relative','','','.success-page'),(917174,'watch','.success-page .w-cart-listing .qty','position','relative','','','.success-page'),(917175,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','position','relative','4','','.b-multi-page-checkout'),(917181,'watch','.w-bestsellers .counter','position','relative','','','.w-bestsellers'),(917182,'watch','.w-bestsellers .heading-3','position','absolute','3','','.w-bestsellers'),(917183,'watch','.w-bestsellers .heading-3','position','relative','','','.w-bestsellers'),(917184,'watch','.w-bestsellers .item','position','absolute','3','','.w-bestsellers'),(917185,'watch','.w-bestsellers .item','position','relative','','','.w-bestsellers'),(917186,'watch','.w-menu-style-1 li','position','relative','','','.w-menu-style-1'),(917187,'watch','.w-menu-style-1 ul ul','position','absolute','','','.w-menu-style-1'),(917188,'watch','.b-slick .slick-list','position','relative','','','.b-slick'),(917189,'watch','.b-slick .slick-slider','position','relative','','','.b-slick'),(917190,'watch','.b-slick .slick-track','position','relative','','','.b-slick'),(917191,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','position','absolute','','','.b-slick'),(917192,'watch','.w-banner .banner','position','relative','','','.w-banner'),(917193,'watch','.w-banner .banner img + img','position','absolute','','','.w-banner'),(917194,'watch','.w-banner .carousel .item','position','relative','','','.w-banner'),(917195,'watch','.w-banner .carousel-text','position','absolute','','','.w-banner'),(917196,'watch','.w-banner .image-text-banner','position','relative','','','.w-banner'),(917197,'watch','.w-banner .image-text-banner .text-banner','position','absolute','','','.w-banner'),(917198,'watch','.w-catalog-paging .paging-holder','position','relative','','','.w-catalog-paging'),(917199,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','position','static','','','.w-catalog-paging'),(917200,'watch','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position_important','important','','','.b-switch'),(917201,'watch','.b-autocomplete .ui-autocomplete','position_important','important','','','.b-autocomplete'),(917202,'watch','.w-checkout-billing-address .addresses .address-item label input','position_important','important','','','.w-checkout-billing-address'),(917203,'watch','.w-checkout-shipping-address .addresses .address-item label input','position_important','important','','','.w-checkout-shipping-address'),(917204,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position_important','important','','','.b-select-suggest'),(917206,'watch','.w-socials .post_item > div','right','10','3','','.w-socials'),(917208,'watch','.b-upload-file .snapshot','right','5','','','.b-upload-file'),(917209,'watch','.w-upload-customer-id-upload-customer-id-form .upload-remove','right','5','','','.w-upload-customer-id-upload-customer-id-form'),(917210,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','right','0','','','.b-switch'),(917211,'watch','.w-cart-compare .dropdown .dropdown-menu','right','0','','','.w-cart-compare'),(917212,'watch','.closeable-heading','right','0','3','',''),(917213,'watch','.b-bottom .footerTitle','right','0','5232,4','','.b-bottom'),(917214,'watch','.w-socials .post_item > div','right','10','3','','.w-socials'),(917215,'watch','.b-info-popup .info-popup.top-left div','right','13','3','','.b-info-popup'),(917217,'watch','.w-socials .post_item > div','right','10','3','','.w-socials'),(917218,'watch','.w-socials .post_item > div','right','10','3','','.w-socials'),(917220,'watch','.w-cart-compare .atr-col','right','0','3','','.w-cart-compare'),(917221,'watch','.w-multi-cart-actions .dropdown .dropdown-menu','right','0','','','.w-multi-cart-actions'),(917222,'watch','.w-socials .post_item > div','right','10','3','','.w-socials'),(917223,'watch','.b-pass-strength .pass-strength span','right','25','','','.b-pass-strength'),(917224,'watch','.b-info-popup .info-popup.top-left div','right','-10','','','.b-info-popup'),(917225,'watch','.b-fancybox .fancybox-overlay-fixed','right','0','','','.b-fancybox'),(917226,'watch','.w-cart-compare .remove-cart','right','0','','','.w-cart-compare'),(917227,'watch','.b-fancybox .fancybox-close','right','10','','','.b-fancybox'),(917228,'watch','.b-fancybox .fancybox-next','right','0','','','.b-fancybox'),(917229,'watch','.b-fancybox .fancybox-next span','right','10','','','.b-fancybox'),(917230,'watch','.w-product-customers-activity .customers-activity','right','20','','','.w-product-customers-activity'),(917231,'watch','.w-product-customers-activity .close','right','5','','','.w-product-customers-activity'),(917232,'watch','.b-select-suggest .select2-search-choice-close','right','3','','','.b-select-suggest'),(917233,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow','right','0','','','.b-select-suggest'),(917235,'watch','.b-fancybox .fancybox-title-float-wrap','right','50','','','.b-fancybox'),(917236,'watch','.b-form .eye-password','right','5','','','.b-form'),(917238,'watch','.b-upload-file .upload-remove','right','10','','','.b-upload-file'),(917239,'watch','.w-socials .post_item > div','right','10','3','','.w-socials'),(917241,'watch','.b-bottom .pop-up-close','right','6','','','.b-bottom'),(917242,'watch','.w-menu-big > ul > li > ul','right','0','','','.w-menu-big'),(917243,'watch','.b-select-suggest .select2-container .select2-choice abbr','right','24','','','.b-select-suggest'),(917244,'watch','.w-filters .mobileCollapse','right','12','','','.w-filters'),(917245,'watch','.b-product-images .media-popup .mp-close','right','20','','','.b-product-images'),(917246,'watch','.b-product-images .mp-shadow, .b-product-images .media-popup','right','0','','','.b-product-images'),(917247,'watch','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right','100','','','.b-menu-lev_display-left'),(917248,'watch','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right','100','','','.b-menu-lev_display-left'),(917249,'watch','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right','100','','','.b-menu-lev_display-left'),(917250,'watch','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right','100','','','.b-menu-lev_display-left'),(917251,'watch','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right','100','','','.b-menu-lev_display-left'),(917252,'watch','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right','100','','','.b-menu-lev_display-lra'),(917253,'watch','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right','100','','','.b-menu-lev_display-lra'),(917254,'watch','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right','100','','','.b-menu-lev_display-lra'),(917255,'watch','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right','100','','','.b-menu-lev_display-lra'),(917256,'watch','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right','100','','','.b-menu-lev_display-lra'),(917257,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','right','10','3','','.b-menu-style-2'),(917258,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .level-2 .parent > .no-link','right','40','3','','.b-menu-style-2'),(917259,'watch','.order-summary .icon','right','0','3','','.order-summary'),(917264,'watch','.catalog-product-wrap .next-product','right','0','','','.catalog-product-wrap'),(917265,'watch','.catalog-product-wrap .next-product .pn-image','right','20','3','','.catalog-product-wrap'),(917266,'watch','.shopping-cart-index .gift-code .heading-4','right','0','4','','.shopping-cart-index'),(917267,'watch','.account-samples .orders-table .order-total','right','0','5240','','.account-samples'),(917268,'watch','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','right','auto','','','.b-slick'),(917269,'watch','.b-slick button.slick-next','right','0','','','.b-slick'),(917270,'watch','.b-slick button.slick-prev','right','auto','','','.b-slick'),(917271,'watch','.w-banner .image-text-banner.bottom-right .text-banner','right','0','','','.w-banner'),(917272,'watch','.w-banner .image-text-banner.middle-right .text-banner','right','0','','','.w-banner'),(917273,'watch','.w-banner .image-text-banner.top-right .text-banner','right','0','','','.w-banner'),(917274,'watch','.b-fancybox .fancybox-title-float-wrap','right_measure','%','','','.b-fancybox'),(917275,'watch','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right_measure','%','','','.b-menu-lev_display-left'),(917276,'watch','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right_measure','%','','','.b-menu-lev_display-left'),(917277,'watch','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right_measure','%','','','.b-menu-lev_display-left'),(917278,'watch','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right_measure','%','','','.b-menu-lev_display-left'),(917279,'watch','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right_measure','%','','','.b-menu-lev_display-left'),(917280,'watch','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right_measure','%','','','.b-menu-lev_display-lra'),(917281,'watch','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right_measure','%','','','.b-menu-lev_display-lra'),(917282,'watch','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right_measure','%','','','.b-menu-lev_display-lra'),(917283,'watch','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right_measure','%','','','.b-menu-lev_display-lra'),(917284,'watch','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right_measure','%','','','.b-menu-lev_display-lra'),(917285,'watch','.b-info-popup .info-popup.top-left div','rotate','-135','3','','.b-info-popup'),(917286,'watch','.w-checkout-shipping-choice input:checked + span:before','rotate','45','','','.w-checkout-shipping-choice'),(917287,'watch','.b-info-popup .info-popup div','rotate','-45','3','','.b-info-popup'),(917288,'watch','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','stroke-width','0','','','.w-image-maps'),(917289,'watch','.w-image-maps rect:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(917290,'watch','.w-image-maps circle:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(917291,'watch','.w-image-maps polygon:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(917292,'watch','.w-tabs .tab-navigation','table-layout','fixed','','','.w-tabs'),(917293,'watch','.w-communication-new-topic .orders-id','text-align','center','','','.w-communication-new-topic'),(917294,'watch','.w-communication-new-topic .model','text-align','center','','','.w-communication-new-topic'),(917295,'watch','.w-communication-new-topic .date-purchased','text-align','right','','','.w-communication-new-topic'),(917296,'watch','.w-communication-new-topic .quantity','text-align','center','','','.w-communication-new-topic'),(917297,'watch','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(917298,'watch','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(917299,'watch','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(917300,'watch','.w-product-wishlist-button .btn','text-align','center','5232','','.w-product-wishlist-button'),(917301,'watch','.b-email .price','text-align','right','','','.b-email'),(917302,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.p-quick-order-index'),(917303,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.p-quick-order-index'),(917304,'watch','.w-promotions .promo-date','text-align','center','','','.w-promotions'),(917305,'watch','.w-promotions .promo-item','text-align','center','','','.w-promotions'),(917307,'watch','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(917309,'watch','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(917310,'watch','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(917311,'watch','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(917312,'watch','.b-email .heading-model','text-align','center','','','.b-email'),(917313,'watch','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(917314,'watch','.w-delivery-location-top-location-list .deliveryName','text-align','center','','','.w-delivery-location-top-location-list'),(917315,'watch','.w-categories .item','text-align','center','','','.w-categories'),(917316,'watch','.w-promotions .prom-multi-discount .heading','text-align','center','','','.w-promotions'),(917317,'watch','.b-products-listing .products-listing .btn-preloader','text-align','center','','','.b-products-listing'),(917318,'watch','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(917319,'watch','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(917320,'watch','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(917321,'watch','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(917322,'watch','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(917323,'watch','.b-messages .development-content','text-align','left','','','.b-messages'),(917324,'watch','.b-messages .msv_to_cc, .b-messages .msv_btn','text-align','left','','','.b-messages'),(917325,'watch','.b-messages .msv_content','text-align','left','','','.b-messages'),(917326,'watch','.b-messages .msv_history','text-align','left','','','.b-messages'),(917327,'watch','.b-messages .attach-view','text-align','left','','','.b-messages'),(917328,'watch','.b-messages .messages-sidebar .heading-2','text-align','center','','','.b-messages'),(917329,'watch','.b-messages .messages-sidebar .btn-2','text-align','center','','','.b-messages'),(917330,'watch','.b-messages .emailBtn','text-align','right','','','.b-messages'),(917331,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','text-align','left','','','.b-messages'),(917332,'watch','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(917333,'watch','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(917334,'watch','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align','left','','','.p-quick-order-index'),(917335,'watch','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(917336,'watch','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(917337,'watch','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(917338,'watch','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(917339,'watch','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(917340,'watch','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(917341,'watch','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(917342,'watch','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(917343,'watch','.w-checkout-terms .terms-box','text-align','left','','','.w-checkout-terms'),(917344,'watch','.w-checkout-terms .required-message','text-align','left','','','.w-checkout-terms'),(917345,'watch','.w-cart-listing .price','text-align','right','5232','','.w-cart-listing'),(917346,'watch','.b-email .heading-model','text-align','center','','','.b-email'),(917347,'watch','.b-email .heading-qty','text-align','center','','','.b-email'),(917348,'watch','.b-email .heading-price','text-align','right','','','.b-email'),(917349,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','text-align','center','','','.b-switch'),(917350,'watch','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(917351,'watch','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(917352,'watch','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(917353,'watch','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(917354,'watch','.order-summary .price-box .title','text-align','left','','','.order-summary'),(917355,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','text-align','center','','','.w-upload-customer-id-upload-customer-id-form'),(917356,'watch','.b-switch .bootstrap-switch','text-align','left','','','.b-switch'),(917357,'watch','.b-quantity .qty-box input','text-align','center','','','.b-quantity'),(917358,'watch','.b-page-name .page-name','text-align','center','','','.b-page-name'),(917359,'watch','.b-email .totals-label','text-align','right','','','.b-email'),(917360,'watch','.w-coupons-and-vauchers-checkout .btn-remove','text-align','center','','','.w-coupons-and-vauchers-checkout'),(917361,'watch','.w-login-block .buttons','text-align','right','','','.w-login-block'),(917362,'watch','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(917363,'watch','.w-product-configurator .pc_qty','text-align','left','5232','','.w-product-configurator'),(917364,'watch','.b-email .heading-qty','text-align','center','','','.b-email'),(917365,'watch','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(917366,'watch','.b-email .totals-value','text-align','right','','','.b-email'),(917367,'watch','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(917368,'watch','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(917369,'watch','.w-product-configurator .pc_qty','text-align','left','5232','','.w-product-configurator'),(917370,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','text-align','center','','','.b-switch'),(917371,'watch','.b-email .totals-value','text-align','right','','','.b-email'),(917372,'watch','.b-email .qty','text-align','center','','','.b-email'),(917373,'watch','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(917374,'watch','.pop-up-content .buttons .btn-2','text-align','center','5240','',''),(917375,'watch','.pop-up-content .buttons .btn','text-align','center','5240','',''),(917376,'watch','.no-found','text-align','center','','',''),(917377,'watch','.w-product-quantity .qty-input','text-align','left','','','.w-product-quantity'),(917378,'watch','.w-login-block .buttons','text-align','right','','','.w-login-block'),(917379,'watch','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(917380,'watch','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(917381,'watch','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','text-align','center','','','.w-product-buttons'),(917382,'watch','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(917383,'watch','.p-quick-order-index .all-scroll-div td + td','text-align','right','','','.p-quick-order-index'),(917384,'watch','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(917385,'watch','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(917386,'watch','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(917387,'watch','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(917388,'watch','.b-email-editor .price','text-align','center','','','.b-email-editor'),(917389,'watch','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(917390,'watch','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(917391,'watch','.b-email .model','text-align','center','','','.b-email'),(917392,'watch','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(917393,'watch','.w-delivery-location-top-location-list .deliveryName','text-align','center','','','.w-delivery-location-top-location-list'),(917394,'watch','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(917395,'watch','.b-form .wedding-form .heading-2','text-align','left','','','.b-form'),(917396,'watch','.b-email .heading-price','text-align','right','','','.b-email'),(917397,'watch','.b-email .price','text-align','right','','','.b-email'),(917398,'watch','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(917399,'watch','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(917400,'watch','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(917401,'watch','.w-product-quantity .qty-input','text-align','left','','','.w-product-quantity'),(917402,'watch','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(917403,'watch','.b-quantity .qty-box input','text-align','center','','','.b-quantity'),(917404,'watch','.w-top-categories .categories','text-align','center','','','.w-top-categories'),(917405,'watch','.w-success-continue-btn','text-align','center','5240','','.w-success-continue-btn'),(917406,'watch','.b-page-name .page-name','text-align','center','','','.b-page-name'),(917407,'watch','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(917408,'watch','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(917409,'watch','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(917410,'watch','.b-quantity .qty-box input','text-align','center','','','.b-quantity'),(917411,'watch','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(917412,'watch','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(917413,'watch','.w-product-configurator .pc_qty','text-align','left','5232','','.w-product-configurator'),(917414,'watch','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(917415,'watch','.b-page-name .page-name','text-align','center','','','.b-page-name'),(917416,'watch','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(917417,'watch','.b-email .heading-qty','text-align','center','','','.b-email'),(917418,'watch','.w-product-collection .item','text-align','center','','','.w-product-collection'),(917419,'watch','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(917420,'watch','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','text-align','center','','','.w-product-buttons'),(917421,'watch','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(917422,'watch','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(917423,'watch','.w-tabs .tab-a','text-align','center','','','.w-tabs'),(917424,'watch','.b-quantity .qty-box input','text-align','center','','','.b-quantity'),(917425,'watch','.w-delivery-location-top-location-list .deliveryName','text-align','center','','','.w-delivery-location-top-location-list'),(917426,'watch','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(917427,'watch','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','text-align','center','','','.w-product-buttons'),(917428,'watch','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(917429,'watch','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(917430,'watch','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(917431,'watch','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(917432,'watch','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(917433,'watch','.w-product-quantity .qty-input','text-align','left','','','.w-product-quantity'),(917434,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','text-align','center','','','.b-switch'),(917435,'watch','.b-switch .bootstrap-switch .bootstrap-switch-label','text-align','center','','','.b-switch'),(917436,'watch','.b-social-login .social-login','text-align','center','','','.b-social-login'),(917437,'watch','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(917438,'watch','.b-page-name .page-name','text-align','center','','','.b-page-name'),(917439,'watch','.b-email .price','text-align','right','','','.b-email'),(917440,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','text-align','center','','','.b-switch'),(917441,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','text-align','center','','','.b-switch'),(917442,'watch','.b-email .totals-title','text-align','right','','','.b-email'),(917443,'watch','.b-email .heading-model','text-align','center','','','.b-email'),(917444,'watch','.b-email .totals-label','text-align','right','','','.b-email'),(917445,'watch','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(917446,'watch','.b-email .totals-value','text-align','right','','','.b-email'),(917447,'watch','.w-cart-credit-amount input','text-align','center','','','.w-cart-credit-amount'),(917448,'watch','.b-email .heading-qty','text-align','center','','','.b-email'),(917449,'watch','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','text-align','center','','','.w-product-buttons'),(917450,'watch','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(917451,'watch','.w-reviews .date','text-align','right','','','.w-reviews'),(917452,'watch','.w-success-continue-btn','text-align','center','5240','','.w-success-continue-btn'),(917453,'watch','.w-product-configurator .pc_qty','text-align','left','5232','','.w-product-configurator'),(917454,'watch','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(917455,'watch','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(917456,'watch','.w-top-categories .item','text-align','center','','','.w-top-categories'),(917457,'watch','.w-reviews-content .product-image','text-align','center','','','.w-reviews-content'),(917458,'watch','.b-email .model','text-align','center','','','.b-email'),(917459,'watch','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(917460,'watch','.w-product-quantity .qty-input','text-align','left','','','.w-product-quantity'),(917461,'watch','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(917462,'watch','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(917463,'watch','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(917464,'watch','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(917465,'watch','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(917466,'watch','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(917467,'watch','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(917468,'watch','.b-email .heading-price','text-align','right','','','.b-email'),(917469,'watch','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(917470,'watch','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(917471,'watch','.b-email .heading-price','text-align','right','','','.b-email'),(917472,'watch','.b-email .price','text-align','right','','','.b-email'),(917473,'watch','.b-email .totals-title','text-align','right','','','.b-email'),(917474,'watch','.b-email .totals-value','text-align','right','','','.b-email'),(917475,'watch','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(917476,'watch','.b-email .heading-model','text-align','center','','','.b-email'),(917477,'watch','.b-email .qty','text-align','center','','','.b-email'),(917478,'watch','.b-email .model','text-align','center','','','.b-email'),(917479,'watch','.b-email .totals-label','text-align','right','','','.b-email'),(917480,'watch','.b-email .heading-qty','text-align','center','','','.b-email'),(917481,'watch','.w-product-collection .item','text-align','center','','','.w-product-collection'),(917482,'watch','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(917483,'watch','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(917484,'watch','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(917485,'watch','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(917486,'watch','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(917487,'watch','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(917488,'watch','.b-form .center-buttons','text-align','center','','','.b-form'),(917489,'watch','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(917490,'watch','.w-reviews .product-image','text-align','center','','','.w-reviews'),(917491,'watch','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(917492,'watch','.b-sub-totals .historyTotal table td','text-align','right','','','.b-sub-totals'),(917493,'watch','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(917494,'watch','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(917495,'watch','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(917496,'watch','.b-quantity .qty-box input','text-align','center','','','.b-quantity'),(917497,'watch','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(917498,'watch','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(917499,'watch','.b-social-login .social-login','text-align','center','','','.b-social-login'),(917500,'watch','.w-success-continue-btn','text-align','center','5240','','.w-success-continue-btn'),(917501,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','text-align','center','3','','.b-switch'),(917502,'watch','.b-social-login .social-login','text-align','center','','','.b-social-login'),(917503,'watch','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(917504,'watch','.w-login-block .buttons','text-align','right','','','.w-login-block'),(917505,'watch','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(917506,'watch','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','text-align','center','','','.p-quick-order-index'),(917507,'watch','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(917508,'watch','.w-cart-checkout-btn a','text-align','center','5232','','.w-cart-checkout-btn'),(917509,'watch','.w-product-collection .item','text-align','center','','','.w-product-collection'),(917510,'watch','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(917511,'watch','.w-categories .categories','text-align','center','','','.w-categories'),(917512,'watch','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(917513,'watch','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(917514,'watch','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(917515,'watch','.w-product-collection .item','text-align','center','','','.w-product-collection'),(917516,'watch','.w-login-block .buttons','text-align','right','','','.w-login-block'),(917517,'watch','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(917518,'watch','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(917519,'watch','.view-all','text-align','center','','',''),(917520,'watch','.b-page-name .page-name','text-align','center','','','.b-page-name'),(917521,'watch','.b-form .message.error','text-align','center','','','.b-form'),(917522,'watch','.b-email .qty','text-align','center','','','.b-email'),(917523,'watch','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','text-align','center','3','','.w-checkout-contact-information'),(917524,'watch','.b-email .model','text-align','center','','','.b-email'),(917525,'watch','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','text-align','center','3','','.w-checkout-contact-information'),(917526,'watch','.w-product-wishlist-button .btn','text-align','center','5232','','.w-product-wishlist-button'),(917527,'watch','.b-email .heading-qty','text-align','center','','','.b-email'),(917528,'watch','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(917529,'watch','.b-email .totals-value','text-align','right','','','.b-email'),(917530,'watch','.w-product-wishlist-button .btn','text-align','center','5232','','.w-product-wishlist-button'),(917531,'watch','.b-bottom .cart-options .js-carts','text-align','center','','','.b-bottom'),(917532,'watch','.b-bottom .cart-options .heading-4','text-align','center','','','.b-bottom'),(917533,'watch','.b-bottom .cart-options .heading-3','text-align','center','','','.b-bottom'),(917534,'watch','.b-bottom .cart-options .buttons','text-align','center','','','.b-bottom'),(917535,'watch','.b-bottom .alert-message','text-align','center','','','.b-bottom'),(917536,'watch','.w-checkout-credit-amount .btn-remove','text-align','center','','','.w-checkout-credit-amount'),(917537,'watch','.w-delivery-location-top-location-list .deliveryName','text-align','center','','','.w-delivery-location-top-location-list'),(917538,'watch','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(917539,'watch','.b-products-listing .btn-choose-options','text-align','center','','','.b-products-listing'),(917540,'watch','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(917541,'watch','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(917542,'watch','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(917543,'watch','.w-product-wishlist-button .btn','text-align','center','5232','','.w-product-wishlist-button'),(917544,'watch','.b-email-editor .price','text-align','center','','','.b-email-editor'),(917545,'watch','.b-email .qty','text-align','center','','','.b-email'),(917546,'watch','.b-email-editor .price','text-align','center','','','.b-email-editor'),(917547,'watch','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(917548,'watch','.w-product-collection .item','text-align','center','','','.w-product-collection'),(917549,'watch','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(917550,'watch','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(917551,'watch','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(917552,'watch','.order-summary .price-row.ot_gv .title','text-align','center','3','','.order-summary'),(917553,'watch','.w-cart-credit-amount .btn-remove','text-align','center','','','.w-cart-credit-amount'),(917554,'watch','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(917555,'watch','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(917556,'watch','.b-email .qty','text-align','center','','','.b-email'),(917557,'watch','.b-email-editor .price','text-align','center','','','.b-email-editor'),(917558,'watch','.b-fancybox .fancybox-close','text-align','center','','','.b-fancybox'),(917559,'watch','.w-product-customers-activity .customers-activity','text-align','center','','','.w-product-customers-activity'),(917560,'watch','.w-product-customers-activity .close','text-align','center','','','.w-product-customers-activity'),(917561,'watch','.b-bottom .confirm-popup .buttons','text-align','center','','','.b-bottom'),(917562,'watch','.b-bottom .confirm-popup .confirm-text','text-align','center','','','.b-bottom'),(917563,'watch','.b-email .totals-title','text-align','right','','','.b-email'),(917564,'watch','.b-email .totals-label','text-align','right','','','.b-email'),(917565,'watch','.b-email .price','text-align','right','','','.b-email'),(917566,'watch','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(917567,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','text-align','center','3','','.b-switch'),(917568,'watch','.w-quote-products .empty','text-align','center','','','.w-quote-products'),(917569,'watch','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(917570,'watch','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(917571,'watch','.w-menu-horizontal .menu-ico','text-align','center','','','.w-menu-horizontal'),(917572,'watch','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(917573,'watch','.w-checkout-credit-amount .cot_gv_amount','text-align','center','','','.w-checkout-credit-amount'),(917574,'watch','.w-product-configurator .pc_qty','text-align','left','5232','','.w-product-configurator'),(917575,'watch','.w-product-wishlist-button .btn','text-align','center','5232','','.w-product-wishlist-button'),(917576,'watch','.w-success-continue-btn','text-align','center','5240','','.w-success-continue-btn'),(917577,'watch','.b-page-name .page-name','text-align','center','','','.b-page-name'),(917578,'watch','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-align','left','','','.b-switch'),(917579,'watch','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-align','right','','','.b-switch'),(917580,'watch','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(917581,'watch','.b-social-login .social-login','text-align','center','','','.b-social-login'),(917582,'watch','.b-products-listing .products-listing .buyButton .btn','text-align','center','','','.b-products-listing'),(917583,'watch','.w-product-quantity .qty-input','text-align','left','','','.w-product-quantity'),(917584,'watch','.w-menu-big li li li','text-align','left','','','.w-menu-big'),(917585,'watch','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(917586,'watch','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(917587,'watch','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(917588,'watch','.w-menu-horizontal .box','text-align','center','','','.w-menu-horizontal'),(917589,'watch','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(917590,'watch','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(917591,'watch','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(917592,'watch','.b-social-login .social-login','text-align','center','','','.b-social-login'),(917593,'watch','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(917594,'watch','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(917595,'watch','.w-login-block .buttons','text-align','right','','','.w-login-block'),(917596,'watch','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','text-align','center','','','.w-product-buttons'),(917597,'watch','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(917598,'watch','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(917599,'watch','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(917600,'watch','.w-cart-listing .links','text-align','center','','','.w-cart-listing'),(917601,'watch','.w-product-wishlist-button .btn','text-align','center','5232','','.w-product-wishlist-button'),(917602,'watch','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(917603,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.b-data-table'),(917604,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.b-data-table'),(917605,'watch','.w-communication-post .communication-post-attach','text-align','right','','','.w-communication-post'),(917606,'watch','.b-products-listing .products-listing .image','text-align','center','','','.b-products-listing'),(917607,'watch','.b-products-listing .products-listing','text-align','center','','','.b-products-listing'),(917608,'watch','.b-products-listing .products-listing .btn-buy','text-align','center','','','.b-products-listing'),(917609,'watch','.w-catalog-b2b-add-button .b2b-add-box-wrap','text-align','right','','','.w-catalog-b2b-add-button'),(917610,'watch','.b-products-listing .products-listing .properties','text-align','left','','','.b-products-listing'),(917611,'watch','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','text-align','left','','','.b-products-listing'),(917612,'watch','.b-products-listing .show-ofstock-products','text-align','center','','','.b-products-listing'),(917613,'watch','.checkbox input:checked + span:before','text-align','center','','',''),(917614,'watch','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(917615,'watch','.p-sample-checkout-success .page-success','text-align','center','','','.p-sample-checkout-success'),(917616,'watch','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(917617,'watch','.b-products-listing .products-listing .in-cart','text-align','center','','','.b-products-listing'),(917618,'watch','.b-email-editor .price','text-align','center','','','.b-email-editor'),(917619,'watch','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(917620,'watch','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','text-align','center','3','','.w-checkout-contact-information'),(917621,'watch','.b-fancybox .fancybox-title-float-wrap','text-align','center','','','.b-fancybox'),(917622,'watch','.b-email .model','text-align','center','','','.b-email'),(917623,'watch','.w-product-quantity .qty-input','text-align','left','','','.w-product-quantity'),(917624,'watch','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(917625,'watch','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(917626,'watch','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(917627,'watch','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(917628,'watch','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(917629,'watch','.order-summary .price-row.ot_coupon .title','text-align','center','3','','.order-summary'),(917630,'watch','h1, .heading-1','text-align','center','','',''),(917631,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','text-align','center','','','.w-communication-new-topic'),(917632,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','text-align','center','','','.w-communication-new-topic'),(917633,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(5), .w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(7)','text-align','center','','','.w-communication-new-topic'),(917634,'watch','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(917635,'watch','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(917636,'watch','.b-email .heading-model','text-align','center','','','.b-email'),(917637,'watch','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(917638,'watch','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(917639,'watch','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(917640,'watch','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(917641,'watch','.b-email .model','text-align','center','','','.b-email'),(917642,'watch','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(917643,'watch','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(917644,'watch','.b-email .totals-title','text-align','right','','','.b-email'),(917645,'watch','.b-email .heading-price','text-align','right','','','.b-email'),(917646,'watch','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(917647,'watch','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(917648,'watch','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(917649,'watch','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(917650,'watch','.b-email .totals-label','text-align','right','','','.b-email'),(917651,'watch','.b-email .totals-title','text-align','right','','','.b-email'),(917652,'watch','.b-email .price','text-align','right','','','.b-email'),(917653,'watch','.b-email .heading-price','text-align','right','','','.b-email'),(917654,'watch','.b-compare .compare-head','text-align','left','','','.b-compare'),(917655,'watch','.w-product-configurator .pc_qty','text-align','left','5232','','.w-product-configurator'),(917656,'watch','.w-menu-horizontal ul ul li','text-align','left','','','.w-menu-horizontal'),(917658,'watch','.b-email .heading-model','text-align','center','','','.b-email'),(917659,'watch','.w-catalog-listing-look .grid','text-align','center','','','.w-catalog-listing-look'),(917660,'watch','.w-catalog-listing-look .b2b','text-align','center','','','.w-catalog-listing-look'),(917661,'watch','.w-catalog-listing-look .list','text-align','center','','','.w-catalog-listing-look'),(917662,'watch','.w-cart-listing .image','text-align','center','','','.w-cart-listing'),(917663,'watch','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(917664,'watch','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','text-align','left','','','.w-cart-listing'),(917665,'watch','.w-cart-listing .points-earn','text-align','left','','','.w-cart-listing'),(917666,'watch','.w-cart-listing .points-redeem','text-align','left','','','.w-cart-listing'),(917667,'watch','.w-cart-listing .no-price .qty','text-align','right','','','.w-cart-listing'),(917668,'watch','.w-cart-listing .remove-btn','text-align','center','','','.w-cart-listing'),(917669,'watch','.w-cart-listing .price','text-align','right','','','.w-cart-listing'),(917670,'watch','.w-cart-listing .remove','text-align','center','','','.w-cart-listing'),(917671,'watch','.w-cart-listing .item .qty','text-align','right','5240','','.w-cart-listing'),(917672,'watch','.w-cart-listing .item .price','text-align','right','5240','','.w-cart-listing'),(917673,'watch','.w-cart-give-away .ga_img','text-align','center','','','.w-cart-give-away'),(917674,'watch','.w-cart-discount-coupon .btn-remove','text-align','center','','','.w-cart-discount-coupon'),(917676,'watch','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(917677,'watch','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(917678,'watch','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(917679,'watch','.b-fancybox .fancybox-nav span','text-align','center','','','.b-fancybox'),(917680,'watch','.w-success-continue-btn','text-align','center','5240','','.w-success-continue-btn'),(917681,'watch','.w-tabs .accordion-heading','text-align','center','','','.w-tabs'),(917682,'watch','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(917683,'watch','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(917684,'watch','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(917685,'watch','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(917686,'watch','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(917687,'watch','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','text-align','center','','','.p-quick-order-index'),(917688,'watch','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(917689,'watch','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(917690,'watch','.b-products-listing .products-listing .mult-qty-input','text-align','right','','','.b-products-listing'),(917691,'watch','.w-delivery-location-top-location-list .deliveryName','text-align','center','','','.w-delivery-location-top-location-list'),(917692,'watch','.w-login-block .buttons','text-align','right','','','.w-login-block'),(917693,'watch','.w-filters .handle-to','text-align','right','','','.w-filters'),(917694,'watch','.w-delivery-location-top-location-list .deliveryName','text-align','center','','','.w-delivery-location-top-location-list'),(917695,'watch','.order-summary .box','text-align','center','','','.order-summary'),(917696,'watch','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(917697,'watch','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(917698,'watch','.b-bottom .pop-up-close','text-align','center','','','.b-bottom'),(917699,'watch','.order-summary .heading-2','text-align','left','','','.order-summary'),(917700,'watch','.order-summary .price-row.ot_bonus_points .title','text-align','center','3','','.order-summary'),(917701,'watch','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','text-align','center','','','.w-product-buttons'),(917702,'watch','.w-success-continue-btn','text-align','center','5240','','.w-success-continue-btn'),(917703,'watch','.b-form .radio-button input[type=\"radio\"].no + span','text-align','center','3','','.b-form'),(917704,'watch','.b-social-login .social-login','text-align','center','','','.b-social-login'),(917705,'watch','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(917706,'watch','.w-reviews-content .date','text-align','right','','','.w-reviews-content'),(917707,'watch','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(917708,'watch','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(917709,'watch','.b-data-table table.dataTable tbody td:last-child','text-align','right','','','.b-data-table'),(917710,'watch','.b-data-table .dt-body-center','text-align','center','','','.b-data-table'),(917711,'watch','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(917712,'watch','.w-product-collection .item','text-align','center','','','.w-product-collection'),(917713,'watch','.w-menu-big li a, .w-menu-big li .no-link','text-align','left','','','.w-menu-big'),(917714,'watch','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(917715,'watch','.b-upload-file .upload-file-template','text-align','center','','','.b-upload-file'),(917716,'watch','.b-quantity .qty-box input','text-align','center','','','.b-quantity'),(917717,'watch','.b-email-editor .price','text-align','center','','','.b-email-editor'),(917718,'watch','.b-email .totals-value','text-align','right','','','.b-email'),(917719,'watch','.b-email .totals-label','text-align','right','','','.b-email'),(917720,'watch','.b-email .totals-title','text-align','right','','','.b-email'),(917721,'watch','.b-email .qty','text-align','center','','','.b-email'),(917722,'watch','.b-upload-file .snapshot','text-align','center','','','.b-upload-file'),(917723,'watch','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(917724,'watch','.b-product-images .media-popup .mp-close','text-align','center','','','.b-product-images'),(917725,'watch','.b-product-images .media-popup .mp-small-images','text-align','center','','','.b-product-images'),(917726,'watch','.b-product-images .media-popup .mp-small-images .item','text-align','center','','','.b-product-images'),(917727,'watch','.b-product-images .media-popup .slick-dots','text-align','center','','','.b-product-images'),(917728,'watch','.b-product-images .media-popup .slick-dots li','text-align','center','','','.b-product-images'),(917729,'watch','.w-product-name h1','text-align','left','','','.w-product-name'),(917730,'watch','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','text-align','center','','','.b-menu-burger_icon'),(917731,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(917732,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(917733,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(917734,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(917735,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(917736,'watch','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(917737,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','text-align','center','','','.b-menu-style-2'),(917738,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','text-align','center','','','.b-menu-style-2'),(917739,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .close-menu','text-align','right','','','.b-menu-style-2'),(917740,'watch','.b-personal-catalog-popup #personal_catalog_popup','text-align','left','','','.b-personal-catalog-popup'),(917741,'watch','.b-trade-approval .steps-bar li','text-align','center','','','.b-trade-approval'),(917742,'watch','.b-trade-approval .steps-bar li a','text-align','center','','','.b-trade-approval'),(917743,'watch','.b-trade-approval .orders-table td:nth-child(1), .b-trade-approval .orders-table th:nth-child(1)','text-align','left','','','.b-trade-approval'),(917744,'watch','.b-trade-approval .orders-table td:nth-child(2)','text-align','right','','','.b-trade-approval'),(917745,'watch','.b-trade-approval .w-login-block label','text-align','left','','','.b-trade-approval'),(917746,'watch','.b-trade-approval .steps-bar','text-align','left','','','.b-trade-approval'),(917747,'watch','.b-trade-approval .center-buttons','text-align','center','','','.b-trade-approval'),(917748,'watch','.b-trade-approval .comments','text-align','left','','','.b-trade-approval'),(917749,'watch','.w-account-personal-catalog .list-switcher a','text-align','center','','','.w-account-personal-catalog'),(917750,'watch','.w-catalog-additional-images ul, .w-catalog-additional-images li','text-align','center','','','.w-catalog-additional-images'),(917751,'watch','.w-catalog-compare .cross-box .different-all > div','text-align','center','','','.w-catalog-compare'),(917752,'watch','.w-delivery-day .time-left','text-align','center','','','.w-delivery-day'),(917753,'watch','.w-top-text .top-text','text-align','center','','','.w-top-text'),(917754,'watch','.order-summary .w-cart-listing .item .name','text-align','left','','','.order-summary'),(917755,'watch','.order-summary .w-cart-listing.type-2 .image','text-align','left','','','.order-summary'),(917756,'watch','.w-cart-discount-coupon .title','text-align','left','','','.w-cart-discount-coupon'),(917774,'watch','.catalog-product-wrap .prev-next-product','text-align','center','','','.catalog-product-wrap'),(917775,'watch','.checkout-success-wrap .page-success','text-align','center','','','.checkout-success-wrap'),(917776,'watch','.shopping-cart-index .cart-page .empty','text-align','center','','','.shopping-cart-index'),(917777,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-align','left','','','.account-order-pay'),(917778,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-align','left','3','','.account-order-pay'),(917779,'watch','.account-order-pay .tableForm th','text-align','left','','','.account-order-pay'),(917780,'watch','.account-samples .orders-table td.td-alignright','text-align','right','','','.account-samples'),(917781,'watch','.account-samples .orders-table th','text-align','left','','','.account-samples'),(917782,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-align','left','','','.account-sample-info'),(917783,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-align','left','3','','.account-sample-info'),(917784,'watch','.account-sample-info .popup-tracking-number','text-align','center','','','.account-sample-info'),(917785,'watch','.account-sample-info .tableForm th','text-align','left','','','.account-sample-info'),(917786,'watch','.account-sample-info .trackings-nambers','text-align','center','','','.account-sample-info'),(917787,'watch','.checkout-order-confirmation .price-box .title','text-align','left','','','.checkout-order-confirmation'),(917788,'watch','.success-page .page-success .text-1','text-align','center','','','.success-page'),(917789,'watch','.success-page .price-box .title','text-align','left','','','.success-page'),(917790,'watch','.success-page .w-cart-listing .qty','text-align','center','','','.success-page'),(917791,'watch','.b-multi-page-checkout .messageBox .info','text-align','left','','','.b-multi-page-checkout'),(917792,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','text-align','center','','','.b-multi-page-checkout'),(917793,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','text-align','center','3','','.b-multi-page-checkout'),(917795,'watch','.w-bestsellers .counter','text-align','center','','','.w-bestsellers'),(917796,'watch','.w-bestsellers .item','text-align','center','3','','.w-bestsellers'),(917797,'watch','.w-menu-style-1 .box','text-align','center','','','.w-menu-style-1'),(917798,'watch','.w-menu-style-1 .menu-ico','text-align','center','','','.w-menu-style-1'),(917799,'watch','.w-menu-style-1 > ul','text-align','center','','','.w-menu-style-1'),(917800,'watch','.w-menu-style-1 ul ul li','text-align','left','','','.w-menu-style-1'),(917801,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','text-align','center','','','.b-slick'),(917802,'watch','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','text-align','center','','','.w-banner'),(917803,'watch','.w-banner .single_banner','text-align','center','','','.w-banner'),(917804,'watch','.w-catalog-paging ','text-align','center','2','','.w-catalog-paging'),(917805,'watch','.w-catalog-paging .next','text-align','center','','','.w-catalog-paging'),(917806,'watch','.w-catalog-paging .next-pages','text-align','center','','','.w-catalog-paging'),(917807,'watch','.w-catalog-paging .p-blog-index','text-align','right','','','.w-catalog-paging'),(917808,'watch','.w-catalog-paging .page-number','text-align','center','','','.w-catalog-paging'),(917809,'watch','.w-catalog-paging .prev','text-align','center','','','.w-catalog-paging'),(917810,'watch','.w-catalog-paging .prev-pages','text-align','center','','','.w-catalog-paging'),(917811,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align','center','','','.w-catalog-paging'),(917812,'watch','.w-success-continue-btn','text-align_important','important','5240','','.w-success-continue-btn'),(917813,'watch','.w-success-continue-btn','text-align_important','important','5240','','.w-success-continue-btn'),(917814,'watch','.w-success-continue-btn','text-align_important','important','5240','','.w-success-continue-btn'),(917815,'watch','.w-success-continue-btn','text-align_important','important','5240','','.w-success-continue-btn'),(917816,'watch','.w-success-continue-btn','text-align_important','important','5240','','.w-success-continue-btn'),(917817,'watch','.w-success-continue-btn','text-align_important','important','5240','','.w-success-continue-btn'),(917818,'watch','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align_important','important','','','.p-quick-order-index'),(917819,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align_important','important','','','.w-catalog-paging'),(917820,'watch','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(917821,'watch','.b-fancybox a.fancybox-close','text-decoration','none','1','','.b-fancybox'),(917822,'watch','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(917823,'watch','.w-chat .w-chat-box a','text-decoration','none','1','','.w-chat'),(917825,'watch','.w-socials > li a','text-decoration','none','','','.w-socials'),(917826,'watch','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(917827,'watch','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(917828,'watch','.price .old','text-decoration','line-through','','',''),(917829,'watch','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(917830,'watch','.b-select-suggest .select2-result-selectable .select2-match, .b-select-suggest .select2-result-unselectable .select2-match','text-decoration','underline','','','.b-select-suggest'),(917831,'watch','.w-socials > li a','text-decoration','none','','','.w-socials'),(917832,'watch','.w-tabs .tab-a','text-decoration','none','','','.w-tabs'),(917833,'watch','.w-socials > li a','text-decoration','none','','','.w-socials'),(917834,'watch','.btn-edit','text-decoration','none','1','',''),(917835,'watch','.w-socials > li a','text-decoration','none','','','.w-socials'),(917836,'watch','.heading-3 .right-text, h3 .right-text','text-decoration','none','','',''),(917837,'watch','.w-socials > li a','text-decoration','none','','','.w-socials'),(917838,'watch','.w-image-maps .categories-items .item a','text-decoration','none','1','','.w-image-maps'),(917839,'watch','.w-social-links a','text-decoration','none','1','','.w-social-links'),(917840,'watch','.w-chat .w-chat-box a','text-decoration','none','','','.w-chat'),(917841,'watch','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(917842,'watch','.w-socials > li a','text-decoration','none','','','.w-socials'),(917843,'watch','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(917844,'watch','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(917845,'watch','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(917846,'watch','.b-select-suggest .select2-container .select2-choice','text-decoration','none','','','.b-select-suggest'),(917847,'watch','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(917848,'watch','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(917849,'watch','.w-cart-listing .remove-btn','text-decoration','none','','','.w-cart-listing'),(917852,'watch','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(917853,'watch','.w-image-maps .float-items .item a','text-decoration','none','1','','.w-image-maps'),(917854,'watch','.b-fancybox .fancybox-nav','text-decoration','none','','','.b-fancybox'),(917855,'watch','.w-tabs .accordion-heading','text-decoration','none','','','.w-tabs'),(917856,'watch','.b-select-suggest .select2-container .select2-choice abbr','text-decoration','none','','','.b-select-suggest'),(917857,'watch','.w-filters .mobileCollapse','text-decoration','none','1','','.w-filters'),(917858,'watch','.w-account-personal-catalog .list-switcher a','text-decoration','none','','','.w-account-personal-catalog'),(917865,'watch','.catalog-product-wrap a.prev-next-product','text-decoration','none','1','','.catalog-product-wrap'),(917866,'watch','.account-samples .orders-table a, .account-samples .order-info a','text-decoration','none','1','','.account-samples'),(917867,'watch','.account-samples .view_link','text-decoration','underline','','','.account-samples'),(917868,'watch','.w-menu-style-1 > ul > li > a, .w-menu-style-1 > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(917869,'watch','.w-menu-style-1 > ul > li > ul > li > a, .w-menu-style-1 > ul > li > ul > li > .no-link','text-decoration','none','1','','.w-menu-style-1'),(917870,'watch','.w-menu-style-1 > ul > li > ul > li > ul li a, .w-menu-style-1 > ul > li > ul > li > ul li .no-link','text-decoration','none','1','','.w-menu-style-1'),(917871,'watch','.w-catalog-paging a','text-decoration','none','1','','.w-catalog-paging'),(917872,'watch','.w-catalog-paging span','text-decoration','none','1','','.w-catalog-paging'),(917873,'watch','.b-select-suggest .select2-container .select2-choice > .select2-chosen','text-overflow','ellipsis','','','.b-select-suggest'),(917874,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(917875,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(917876,'watch','.b-fancybox .fancybox-skin','text-shadow','none','','','.b-fancybox'),(917877,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(917878,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(917879,'watch','.b-fancybox .fancybox-title','text-shadow','none','','','.b-fancybox'),(917880,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(917881,'watch','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(917882,'watch','.heading-4 .right-text, h4 .right-text','text-transform','none','','',''),(917883,'watch','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(917884,'watch','.w-product-personal-catalog-button .btn','text-transform','none','','','.w-product-personal-catalog-button'),(917885,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-transform','uppercase','','','.b-switch'),(917886,'watch','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(917887,'watch','.p-sample-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-sample-checkout-success'),(917888,'watch','.p-sample-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-sample-checkout-success'),(917889,'watch','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(917890,'watch','.w-promotions .heading-3','text-transform','uppercase','','','.w-promotions'),(917891,'watch','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(917892,'watch','.btn-2','text-transform','uppercase','','',''),(917893,'watch','.b-messages .content-messages .heading-2','text-transform','none','','','.b-messages'),(917894,'watch','.heading-4 .edit, h4 .edit','text-transform','none','','',''),(917895,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','text-transform','uppercase','4','','.b-switch'),(917896,'watch','.w-product-personal-catalog-button .btn','text-transform','none','','','.w-product-personal-catalog-button'),(917897,'watch','.w-personal-gift-status-bar .end-date','text-transform','uppercase','','','.w-personal-gift-status-bar'),(917898,'watch','.btn-1','text-transform','uppercase','','',''),(917899,'watch','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(917900,'watch','.w-product-personal-catalog-button .btn','text-transform','none','','','.w-product-personal-catalog-button'),(917901,'watch','.b-info .info strong','text-transform','uppercase','','','.b-info'),(917902,'watch','.b-info .info strong','text-transform','uppercase','','','.b-info'),(917903,'watch','.w-checkout-shipping-choice span','text-transform','uppercase','','','.w-checkout-shipping-choice'),(917904,'watch','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(917905,'watch','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(917906,'watch','.w-tabs .tab-a','text-transform','uppercase','','','.w-tabs'),(917908,'watch','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(917909,'watch','.w-cart-compare .cart-name a','text-transform','uppercase','','','.w-cart-compare'),(917910,'watch','.w-product-personal-catalog-button .btn','text-transform','none','','','.w-product-personal-catalog-button'),(917911,'watch','.heading-3 .edit, h3 .edit','text-transform','none','','',''),(917912,'watch','.b-info .info strong','text-transform','uppercase','','','.b-info'),(917913,'watch','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(917914,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','text-transform','uppercase','4','','.b-switch'),(917915,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','text-transform','uppercase','4','','.b-switch'),(917916,'watch','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','text-transform','uppercase','','','.w-multi-cart-cart-switcher'),(917917,'watch','.w-product-personal-catalog-button .btn','text-transform','none','','','.w-product-personal-catalog-button'),(917918,'watch','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(917919,'watch','.w-top-categories .categories h2','text-transform','inherit','','','.w-top-categories'),(917920,'watch','.heading-4, h4, .h-block h4','text-transform','uppercase','','',''),(917921,'watch','.btn','text-transform','uppercase','','',''),(917922,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-transform','uppercase','','','.b-switch'),(917923,'watch','.b-info .info strong','text-transform','uppercase','','','.b-info'),(917924,'watch','.w-categories h2.name','text-transform','uppercase','','','.w-categories'),(917925,'watch','.w-product-personal-catalog-button .btn','text-transform','none','','','.w-product-personal-catalog-button'),(917926,'watch','.b-bottom .cart-options .heading-4','text-transform','none','','','.b-bottom'),(917927,'watch','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(917928,'watch','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(917929,'watch','.b-info .info strong','text-transform','uppercase','','','.b-info'),(917930,'watch','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(917931,'watch','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(917932,'watch','.w-personal-gift-status-bar .inform','text-transform','uppercase','','','.w-personal-gift-status-bar'),(917933,'watch','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(917934,'watch','.b-products-listing .products-listing a.btn.view-button','text-transform','none','','','.b-products-listing'),(917935,'watch','.b-products-listing .products-listing h2','text-transform','inherit','','','.b-products-listing'),(917936,'watch','.w-top-categories h2.name','text-transform','uppercase','','','.w-top-categories'),(917937,'watch','.w-taxable .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-on','text-transform','none','','','.w-taxable'),(917938,'watch','.w-taxable .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .w-taxable .bootstrap-switch .bootstrap-switch-handle-off','text-transform','none','','','.w-taxable'),(917939,'watch','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','text-transform','inherit','','',''),(917940,'watch','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','text-transform','inherit','','','.b-h-inline'),(917941,'watch','h1, .heading-1','text-transform','uppercase','','',''),(917942,'watch','.btn-3','text-transform','uppercase','','',''),(917943,'watch','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(917944,'watch','.b-info .info strong','text-transform','uppercase','','','.b-info'),(917945,'watch','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','text-transform','uppercase','','','.w-cart-listing'),(917947,'watch','.w-tabs .accordion-heading','text-transform','uppercase','','','.w-tabs'),(917948,'watch','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(917949,'watch','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(917950,'watch','.w-filters .filter-box-head','text-transform','uppercase','','','.w-filters'),(917951,'watch','.w-filters .head-filter-widget','text-transform','uppercase','','','.w-filters'),(917952,'watch','.heading-3, h3, .h-block h3','text-transform','uppercase','','',''),(917953,'watch','.heading-2, h2, .h-block h2','text-transform','uppercase','','',''),(917954,'watch','.w-account-personal-catalog .list-switcher a','text-transform','uppercase','','','.w-account-personal-catalog'),(917963,'watch','.catalog-product-wrap .pn-direction','text-transform','uppercase','','','.catalog-product-wrap'),(917964,'watch','.checkout-success-wrap .page-success .text-1','text-transform','uppercase','','','.checkout-success-wrap'),(917965,'watch','.checkout-success-wrap .page-success .text-2','text-transform','uppercase','','','.checkout-success-wrap'),(917966,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-transform','uppercase','','','.account-order-pay'),(917967,'watch','.account-order-pay .not_fully_paid_td','text-transform','uppercase','','','.account-order-pay'),(917968,'watch','.account-samples .not_fully_paid_td','text-transform','uppercase','','','.account-samples'),(917969,'watch','.account-samples .order_history_table h2','text-transform','uppercase','','','.account-samples'),(917970,'watch','.account-samples .order_history_table th','text-transform','none','','','.account-samples'),(917971,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-transform','uppercase','','','.account-sample-info'),(917972,'watch','.account-sample-info .not_fully_paid_td','text-transform','uppercase','','','.account-sample-info'),(917973,'watch','.success-page .page-success .text-1','text-transform','uppercase','','','.success-page'),(917974,'watch','.success-page .page-success .text-2','text-transform','uppercase','','','.success-page'),(917975,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading','text-transform','uppercase','','','.b-multi-page-checkout'),(917976,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','text-transform','none','','','.b-multi-page-checkout'),(917977,'watch','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_color','#222','','','.b-fancybox'),(917978,'watch','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left','0','','','.b-fancybox'),(917979,'watch','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left_measure','','','','.b-fancybox'),(917980,'watch','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size','2','','','.b-fancybox'),(917981,'watch','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size_measure','px','','','.b-fancybox'),(917982,'watch','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top','1','','','.b-fancybox'),(917983,'watch','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top_measure','px','','','.b-fancybox'),(917984,'watch','.b-pass-strength .pass-strength span','top','6','','','.b-pass-strength'),(917985,'watch','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(917986,'watch','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','top','0','','','.b-switch'),(917987,'watch','.w-promotions .prom-multi-discount > .heading','top','2','3','','.w-promotions'),(917988,'watch','.w-promotions .promo-date','top','-10','','','.w-promotions'),(917990,'watch','.shipping-ico .heading-2','top','5','3','','.shipping-ico'),(917991,'watch','.w-promo-code .holder','top','2','5261,3','','.w-promo-code'),(917992,'watch','.testimonials .rating','top','2','','',''),(917993,'watch','.testimonials .heading-3','top','0','3','',''),(917994,'watch','.testimonials .reviews-list span','top','2','','',''),(917995,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(917996,'watch','.w-promotions .prom-multi-discount .products','top','-13','','','.w-promotions'),(917997,'watch','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','top','2','3','','.w-promotions'),(917998,'watch','.w-promotions .promo-cart-discount .slave .content','top','-17','','','.w-promotions'),(917999,'watch','.w-promotions .promo-cart-discount .promo-min-qty','top','-19','','','.w-promotions'),(918000,'watch','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','top','2','3','','.w-promotions'),(918001,'watch','.b-preloader .preloader','top','calc(50% - 20px)','3','','.b-preloader'),(918002,'watch','.b-preloader .preloader','top','0','','','.b-preloader'),(918003,'watch','.b-messages .messBtnMenuDelete','top','3','3','','.b-messages'),(918004,'watch','.b-messages span.starred::before','top','3','','','.b-messages'),(918005,'watch','.b-messages .messBtnMenuStarred','top','3','3','','.b-messages'),(918006,'watch','.b-messages .messBtnMenuUnread','top','3','3','','.b-messages'),(918007,'watch','.b-messages .select2-container-multi .select2-choices .select2-search-choice','top','5','','','.b-messages'),(918010,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(918011,'watch','.w-product-personal-catalog-button .btn','top','1','3','','.w-product-personal-catalog-button'),(918012,'watch','.p-payer-order-confirmation .order-ico','top','7','3','','.p-payer-order-confirmation'),(918013,'watch','.p-payer-order-confirmation .discount-ico','top','3','3','','.p-payer-order-confirmation'),(918014,'watch','.p-payer-order-confirmation .comment-ico','top','7','3','','.p-payer-order-confirmation'),(918015,'watch','.p-payer-order-pay .order-ico','top','7','3','','.p-payer-order-pay'),(918016,'watch','.p-payer-order-pay .discount-ico','top','3','3','','.p-payer-order-pay'),(918017,'watch','.p-payer-order-pay .comment-ico','top','7','3','','.p-payer-order-pay'),(918018,'watch','.w-checkout-terms .required-message','top','40','','','.w-checkout-terms'),(918019,'watch','.w-checkout-terms input[type=\"checkbox\"]','top','2','','','.w-checkout-terms'),(918020,'watch','.b-info .info','top','3','3','','.b-info'),(918021,'watch','.w-checkout-shipping-address .genders-title input','top','2','','','.w-checkout-shipping-address'),(918022,'watch','.b-fancybox #fancybox-loading','top','50','','','.b-fancybox'),(918023,'watch','.b-form .form-buttons','top','10','','','.b-form'),(918024,'watch','.b-rating .glyphicon','top','1','','','.b-rating'),(918025,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(918026,'watch','.w-upload-customer-id-upload-customer-id-form .upload-remove','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(918027,'watch','.w-upload-customer-id-upload-customer-id-form .dz-details','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(918028,'watch','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(918029,'watch','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(918030,'watch','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(918032,'watch','.b-info .info','top','3','3','','.b-info'),(918033,'watch','.b-form .shipping-method .input input','top','2','','','.b-form'),(918035,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','top','8','','','.b-switch'),(918036,'watch','.b-fancybox .fancybox-tmp','top','-99999','','','.b-fancybox'),(918037,'watch','.w-filters .ui-slider-handle','top','-5','','','.w-filters'),(918038,'watch','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','top','-1','3','','.order-summary'),(918039,'watch','.view-all','top','50','3','',''),(918040,'watch','.b-products-listing .products-listing .btn-buy','top','3','3','','.b-products-listing'),(918041,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','top','-2','','','.b-switch'),(918042,'watch','.shipping-ico .heading-2','top','5','3','','.shipping-ico'),(918043,'watch','.b-switch .candlestick-wrapper','top','-2','','','.b-switch'),(918044,'watch','.closeable-heading','top','0','3','',''),(918045,'watch','.b-bottom .footerTitle','top','8','5232,4','','.b-bottom'),(918046,'watch','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(918047,'watch','.b-info-popup .info-popup div','top','15','3','','.b-info-popup'),(918048,'watch','.b-form .form-inputs div.required-message','top','-15','','','.b-form'),(918049,'watch','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(918050,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top','0','','','.b-select-suggest'),(918051,'watch','.b-form .hide-billing-address','top','0','','','.b-form'),(918052,'watch','.b-select-suggest .select2-measure-scrollbar','top','-10000','','','.b-select-suggest'),(918053,'watch','.w-socials .post_item > div','top','10','3','','.w-socials'),(918054,'watch','.w-cart-compare .atr-col','top','0','3','','.w-cart-compare'),(918055,'watch','.b-info-popup .info-popup.top-left div','top','auto','3','','.b-info-popup'),(918056,'watch','.b-info-popup .info-popup div','top','-12','','','.b-info-popup'),(918057,'watch','.shipping-ico .heading-2','top','5','3','','.shipping-ico'),(918058,'watch','.bell-ico .heading-2','top','5','3','','.bell-ico'),(918060,'watch','.w-socials .post_item > div','top','10','3','','.w-socials'),(918061,'watch','.w-socials .post_item > div','top','10','3','','.w-socials'),(918062,'watch','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(918064,'watch','.w-socials .post_item > div','top','10','3','','.w-socials'),(918067,'watch','.message.success','top','3','3','',''),(918068,'watch','.b-form .middle-form .required-message','top','-15','','','.b-form'),(918069,'watch','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(918070,'watch','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(918071,'watch','.w-socials .post_item > div','top','10','3','','.w-socials'),(918072,'watch','.b-info-popup .info-popup.top-left div','top','auto','','','.b-info-popup'),(918073,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(918074,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','top','8','','','.b-switch'),(918075,'watch','.b-form .radio-button input[type=\"radio\"]','top','2','','','.b-form'),(918076,'watch','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(918077,'watch','.w-personal-gift-status-bar .end-date','top','4','3','','.w-personal-gift-status-bar'),(918078,'watch','.order-summary .heading-2','top','7','3','','.order-summary'),(918079,'watch','.savings-ico .heading-2','top','5','3','','.savings-ico'),(918081,'watch','.w-multi-cart-actions .cart-actions','top','-3','','','.w-multi-cart-actions'),(918082,'watch','.w-product-personal-catalog-button .btn','top','1','3','','.w-product-personal-catalog-button'),(918083,'watch','.w-product-personal-catalog-button .btn','top','1','3','','.w-product-personal-catalog-button'),(918084,'watch','.b-fancybox .fancybox-overlay','top','0','','','.b-fancybox'),(918085,'watch','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(918086,'watch','.b-info .info','top','3','3','','.b-info'),(918087,'watch','.w-promo-code .holder','top','19','3','','.w-promo-code'),(918088,'watch','.w-promo-code .holder','top','2','5261,3','','.w-promo-code'),(918089,'watch','.w-reviews .review','top','-16','3','','.w-reviews'),(918090,'watch','.w-reviews .heading-3','top','0','3','','.w-reviews'),(918091,'watch','.b-info .info','top','3','3','','.b-info'),(918092,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','top','4','3','','.b-switch'),(918093,'watch','.w-menu-horizontal ul ul ul','top','0','','','.w-menu-horizontal'),(918096,'watch','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(918097,'watch','.b-form .payment-method .item-radio input','top','5','','','.b-form'),(918098,'watch','.w-product-personal-catalog-button .btn','top','1','3','','.w-product-personal-catalog-button'),(918099,'watch','.w-checkout-billing-address .genders-title input','top','2','','','.w-checkout-billing-address'),(918100,'watch','.w-promo-code .holder','top','2','5261,3','','.w-promo-code'),(918101,'watch','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(918102,'watch','.w-menu-horizontal > ul > li > ul','top','100','','','.w-menu-horizontal'),(918103,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(918104,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(918105,'watch','.b-info-popup .info-popup','top','4','3','','.b-info-popup'),(918106,'watch','.b-form .radio-button input[type=\"radio\"].no + span','top','1','3','','.b-form'),(918107,'watch','.w-promo-code .holder','top','2','5261,3','','.w-promo-code'),(918108,'watch','.w-personal-gift-status-bar .inform','top','3','4','','.w-personal-gift-status-bar'),(918109,'watch','.b-upload-files .attach-active-holder .attach-file','top','-200','','','.b-upload-files'),(918110,'watch','.w-product-personal-catalog-button .btn','top','1','3','','.w-product-personal-catalog-button'),(918111,'watch','.w-promo-code .holder','top','2','5261,3','','.w-promo-code'),(918112,'watch','.b-fancybox .fancybox-close','top','10','','','.b-fancybox'),(918113,'watch','.w-product-customers-activity .close','top','5','','','.w-product-customers-activity'),(918114,'watch','.w-reviews-content .review','top','-16','3','','.w-reviews-content'),(918116,'watch','.w-cart-compare .remove-cart','top','0','','','.w-cart-compare'),(918117,'watch','.w-promo-code .holder','top','19','3','','.w-promo-code'),(918118,'watch','.w-promo-code .holder','top','19','3','','.w-promo-code'),(918119,'watch','.w-promo-code .holder','top','2','5261,3','','.w-promo-code'),(918120,'watch','.w-checkout-shipping-choice input','top','-200','','','.w-checkout-shipping-choice'),(918122,'watch','.w-socials .post_item > div','top','10','3','','.w-socials'),(918123,'watch','.w-product-reviews .reviews-list span','top','2','','','.w-product-reviews'),(918124,'watch','.b-select-suggest .select2-search-choice-close','top','4','','','.b-select-suggest'),(918125,'watch','.w-image-maps .svg-wrap svg','top','0','','','.w-image-maps'),(918126,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(918127,'watch','.w-neighbour-checkout .bootstrap-switch','top','-2','','','.w-neighbour-checkout'),(918128,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow','top','0','','','.b-select-suggest'),(918129,'watch','.b-select-suggest .select2-drop-mask','top','0','','','.b-select-suggest'),(918130,'watch','.b-select-suggest .select2-drop','top','100','','','.b-select-suggest'),(918132,'watch','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(918133,'watch','.w-product-personal-catalog-button .btn','top','1','3','','.w-product-personal-catalog-button'),(918135,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','top','4','3','','.b-switch'),(918136,'watch','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(918137,'watch','.w-checkout-create-account .account-benefits strong','top','3','3','','.w-checkout-create-account'),(918138,'watch','.w-promo-code .holder','top','19','3','','.w-promo-code'),(918139,'watch','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(918140,'watch','.w-account-addresses-list .address-fields input[type=\"radio\"]','top','4','','','.w-account-addresses-list'),(918141,'watch','.b-products-listing .products-listing .promos-info','top','0','','','.b-products-listing'),(918142,'watch','.b-products-listing .hover-box-content','top','-10','3','','.b-products-listing'),(918143,'watch','.b-products-listing .hover-box-content','top','40','','','.b-products-listing'),(918144,'watch','.b-products-listing .loader','top','calc(50% - 15px)','4','','.b-products-listing'),(918145,'watch','.b-products-listing .loader','top','0','3','','.b-products-listing'),(918146,'watch','.b-products-listing .products-listing .qty-input.hidden','top','0','3','','.b-products-listing'),(918147,'watch','.b-products-listing .promo','top','0','','','.b-products-listing'),(918152,'watch','.w-promo-code .holder','top','19','3','','.w-promo-code'),(918153,'watch','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(918154,'watch','.w-checkout-gdpr .candlestick-wrapper','top','0','','','.w-checkout-gdpr'),(918155,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(918156,'watch','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(918157,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(918158,'watch','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(918159,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','top','0','','','.b-switch'),(918160,'watch','.b-form .eye-password','top','5','','','.b-form'),(918161,'watch','.w-taxable input[type=\"radio\"]','top','2','','','.w-taxable'),(918162,'watch','.w-taxable input[type=\"checkbox\"]','top','2','','','.w-taxable'),(918163,'watch','.b-form .radio-button + .required-message-wrap .required-message','top','-5','','','.b-form'),(918164,'watch','.b-info .info','top','3','3','','.b-info'),(918165,'watch','.b-products-listing .products-listing .radio-attributes input','top','2','','','.b-products-listing'),(918168,'watch','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(918169,'watch','.w-promo-code .holder','top','19','3','','.w-promo-code'),(918170,'watch','.b-info .info','top','3','3','','.b-info'),(918171,'watch','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(918172,'watch','.w-cart-listing .remove-btn span','top','-7','5240','','.w-cart-listing'),(918173,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(918175,'watch','.b-upload-file .upload-remove','top','5','','','.b-upload-file'),(918176,'watch','.b-fancybox .fancybox-nav span','top','50','','','.b-fancybox'),(918177,'watch','.b-fancybox .fancybox-nav','top','0','','','.b-fancybox'),(918178,'watch','.b-form .addresses .address-item input[type=\"radio\"]','top','3','','','.b-form'),(918179,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(918180,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(918181,'watch','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(918182,'watch','.b-bottom .pop-up-close','top','7','','','.b-bottom'),(918183,'watch','.b-switch .bootstrap-switch .bootstrap-switch-container','top','0','','','.b-switch'),(918184,'watch','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(918185,'watch','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(918186,'watch','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(918187,'watch','.b-fancybox .fancybox-wrap','top','0','','','.b-fancybox'),(918188,'watch','.w-menu-big > ul > li > ul','top','100','','','.w-menu-big'),(918189,'watch','.b-select-suggest .select2-container .select2-choice abbr','top','8','','','.b-select-suggest'),(918190,'watch','.w-filters .mobileCollapse','top','1','','','.w-filters'),(918191,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','top','0','','','.w-image-maps'),(918192,'watch','.b-product-images .media-popup .mp-close','top','20','','','.b-product-images'),(918193,'watch','.b-product-images .mp-shadow, .b-product-images .media-popup','top','0','','','.b-product-images'),(918194,'watch','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top','100','','','.b-menu-lev_display-down'),(918195,'watch','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top','100','','','.b-menu-lev_display-down'),(918196,'watch','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top','100','','','.b-menu-lev_display-down'),(918197,'watch','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top','100','','','.b-menu-lev_display-down'),(918198,'watch','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top','100','','','.b-menu-lev_display-down'),(918199,'watch','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','top','0','','','.b-menu-lev_display-left'),(918200,'watch','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','top','0','','','.b-menu-lev_display-left'),(918201,'watch','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','top','0','','','.b-menu-lev_display-left'),(918202,'watch','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','top','0','','','.b-menu-lev_display-left'),(918203,'watch','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','top','0','','','.b-menu-lev_display-left'),(918204,'watch','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','top','0','','','.b-menu-lev_display-lra'),(918205,'watch','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','top','0','','','.b-menu-lev_display-lra'),(918206,'watch','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','top','0','','','.b-menu-lev_display-lra'),(918207,'watch','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','top','0','','','.b-menu-lev_display-lra'),(918208,'watch','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','top','0','','','.b-menu-lev_display-lra'),(918209,'watch','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','top','0','','','.b-menu-lev_display-right'),(918210,'watch','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','top','0','','','.b-menu-lev_display-right'),(918211,'watch','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','top','0','','','.b-menu-lev_display-right'),(918212,'watch','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','top','0','','','.b-menu-lev_display-right'),(918213,'watch','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','top','0','','','.b-menu-lev_display-right'),(918214,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','top','0','','','.b-menu-lev_display-slide'),(918215,'watch','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','top','0','','','.b-menu-lev_display-slide'),(918216,'watch','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','top','0','','','.b-menu-lev_display-slide'),(918217,'watch','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','top','0','','','.b-menu-lev_display-slide'),(918218,'watch','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','top','0','','','.b-menu-lev_display-slide'),(918219,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','top','0','','','.b-menu-open_from-left'),(918220,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > .goto-button','top','8','','','.b-menu-style-1'),(918221,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select','top','0','','','.b-menu-style-2'),(918222,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','top','50','3','','.b-menu-style-2'),(918223,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select','top','0','','','.b-menu-style-2'),(918224,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','top','50','3','','.b-menu-style-2'),(918225,'watch','.order-summary .icon','top','0','3','','.order-summary'),(918236,'watch','.catalog-product-wrap .pn-image','top','120','3','','.catalog-product-wrap'),(918237,'watch','.catalog-product-wrap .prev-next-product','top','calc(50% - 200px)','','','.catalog-product-wrap'),(918238,'watch','.checkout-index-wrap .comment-ico','top','7','3','','.checkout-index-wrap'),(918239,'watch','.checkout-index-wrap .discount-ico','top','3','3','','.checkout-index-wrap'),(918240,'watch','.checkout-index-wrap .order-ico','top','7','3','','.checkout-index-wrap'),(918241,'watch','.shopping-cart-index .gift-code .heading-4','top','0','4','','.shopping-cart-index'),(918242,'watch','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','top','2','3','','.account-order-pay'),(918243,'watch','.account-order-pay .not_fully_paid_td','top','19','','','.account-order-pay'),(918244,'watch','.account-samples .not_fully_paid_td','top','19','','','.account-samples'),(918245,'watch','.account-samples .view_link','top','4','4','','.account-samples'),(918246,'watch','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','top','2','3','','.account-sample-info'),(918247,'watch','.account-sample-info .not_fully_paid_td','top','19','','','.account-sample-info'),(918248,'watch','.checkout-order-confirmation .comment-ico','top','7','3','','.checkout-order-confirmation'),(918249,'watch','.checkout-order-confirmation .discount-ico','top','3','3','','.checkout-order-confirmation'),(918250,'watch','.checkout-order-confirmation .order-ico','top','7','3','','.checkout-order-confirmation'),(918251,'watch','.hide-page','top','0','','',''),(918252,'watch','.success-page .comment-ico','top','7','3','','.success-page'),(918253,'watch','.success-page .discount-ico','top','3','3','','.success-page'),(918254,'watch','.success-page .order-ico','top','7','3','','.success-page'),(918255,'watch','.success-page .page-success .text-1','top','7','3','','.success-page'),(918256,'watch','.success-page .w-cart-listing .qty','top','10','','','.success-page'),(918257,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','top','-2','4','','.b-multi-page-checkout'),(918258,'watch','.w-bestsellers .heading-3','top','0','3','','.w-bestsellers'),(918259,'watch','.w-menu-style-1 > ul > li > ul','top','100','','','.w-menu-style-1'),(918260,'watch','.w-menu-style-1 ul ul ul','top','0','','','.w-menu-style-1'),(918261,'watch','.b-slick .slick-track','top','0','','','.b-slick'),(918262,'watch','.b-slick .slick-vertical button.slick-next','top','auto','','','.b-slick'),(918263,'watch','.b-slick .slick-vertical button.slick-prev','top','0','','','.b-slick'),(918264,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','top','50','','','.b-slick'),(918265,'watch','.w-banner .banner img + img','top','0','','','.w-banner'),(918266,'watch','.w-banner .carousel-text','top','0','','','.w-banner'),(918267,'watch','.w-banner .image-text-banner.bottom-center .text-banner','top','auto','','','.w-banner'),(918268,'watch','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','top','0','','','.w-banner'),(918269,'watch','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','top','0','','','.w-banner'),(918270,'watch','.w-banner .image-text-banner.top-left .text-banner','top','0','','','.w-banner'),(918271,'watch','.w-banner .image-text-banner.top-right .text-banner','top','0','','','.w-banner'),(918272,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top','0','','','.w-catalog-paging'),(918273,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top_important','important','','','.b-select-suggest'),(918274,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top_important','important','','','.w-catalog-paging'),(918275,'watch','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(918277,'watch','.b-fancybox #fancybox-loading','top_measure','%','','','.b-fancybox'),(918278,'watch','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(918279,'watch','.view-all','top_measure','%','3','',''),(918280,'watch','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(918281,'watch','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(918282,'watch','.w-menu-horizontal > ul > li > ul','top_measure','%','','','.w-menu-horizontal'),(918283,'watch','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(918284,'watch','.b-select-suggest .select2-drop','top_measure','%','','','.b-select-suggest'),(918285,'watch','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(918286,'watch','.b-fancybox .fancybox-nav span','top_measure','%','','','.b-fancybox'),(918287,'watch','.w-menu-big > ul > li > ul','top_measure','%','','','.w-menu-big'),(918288,'watch','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top_measure','%','','','.b-menu-lev_display-down'),(918289,'watch','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top_measure','%','','','.b-menu-lev_display-down'),(918290,'watch','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top_measure','%','','','.b-menu-lev_display-down'),(918291,'watch','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top_measure','%','','','.b-menu-lev_display-down'),(918292,'watch','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top_measure','%','','','.b-menu-lev_display-down'),(918293,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .parent > a, .b-menu-style-2 .menu-style[data-style=\"2\"] .parent > .no-link','top_measure','%','3','','.b-menu-style-2'),(918294,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .back-button','top_measure','%','3','','.b-menu-style-2'),(918296,'watch','.w-menu-style-1 > ul > li > ul','top_measure','%','','','.w-menu-style-1'),(918297,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','top_measure','%','','','.b-slick'),(918298,'watch','.b-slick .slick-slider','touch-action','pan-y','','','.b-slick'),(918299,'watch','.b-products-listing .hover-box-content','transform','rotate( 45deg )','3','','.b-products-listing'),(918300,'watch','.b-switch .bootstrap-switch .bootstrap-switch-container','transform','translate3d(0, 0, 0)','','','.b-switch'),(918301,'watch','.b-product-images .media-popup .mp-close','transform','scale(1.5)','1','','.b-product-images'),(918302,'watch','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','transform','scale(1.2)','1','','.b-product-images'),(918303,'watch','.b-product-images .media-popup .slick-list:first-child .slick-track','transform','none','','','.b-product-images'),(918304,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','transform','scale(1.5)','1','','.b-product-images'),(918305,'watch','.b-menu-lev_display-slide .menu-style .slide-parent','transform','translateX(-100vw)','','','.b-menu-lev_display-slide'),(918306,'watch','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','transform','translate3d(0, 0, 0)','','','.b-slick'),(918307,'watch','.b-product-images .media-popup .slick-list:first-child .slick-track','transform_important','important','','','.b-product-images'),(918308,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','transition','0.3s','','','.b-switch'),(918309,'watch','.b-switch .bootstrap-switch','transition','border-color ease-in-out .15s, box-shadow ease-in-out .15s','','','.b-switch'),(918310,'watch','.b-switch .bootstrap-switch.bootstrap-switch-animate .bootstrap-switch-container','transition','margin-left 0.5s','','','.b-switch'),(918311,'watch','.b-product-images .media-popup .mp-close','transition','transform 0.3s, color 0.3s','','','.b-product-images'),(918312,'watch','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','transition','transform 0.3s','','','.b-product-images'),(918313,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','transition','transform 0.3s, color 0.3s','','','.b-product-images'),(918314,'watch','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','transition','max-height 1s','','','.b-menu-burger_icon'),(918315,'watch','.b-menu-lev_display-slide .menu-style ul','transition','visibility 300ms, transform 300ms','','','.b-menu-lev_display-slide'),(918316,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','transition','left 300ms','','','.b-menu-open_from-left'),(918318,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','user-select','none','','','.b-select-suggest'),(918319,'watch','.b-select-suggest .select2-results .select2-result-label','user-select','none','','','.b-select-suggest'),(918320,'watch','.b-select-suggest .select2-container .select2-choice','user-select','none','','','.b-select-suggest'),(918321,'watch','.b-slick .slick-slider','user-select','none','','','.b-slick'),(918322,'watch','.b-email .name','vertical-align','top','','','.b-email'),(918323,'watch','.b-quantity .qty-box input','vertical-align','top','','','.b-quantity'),(918324,'watch','.w-tabs .tab-li.tab-cart a','vertical-align','middle','3','','.w-tabs'),(918325,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.p-quick-order-index'),(918326,'watch','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.p-quick-order-index'),(918328,'watch','.b-email .model','vertical-align','top','','','.b-email'),(918329,'watch','.w-categories .item','vertical-align','top','','','.w-categories'),(918330,'watch','.w-promotions .heading-3','vertical-align','top','','','.w-promotions'),(918331,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','vertical-align','top','','','.b-warehouses-popup'),(918332,'watch','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(918333,'watch','.b-upload-file .upload-file-template','vertical-align','top','','','.b-upload-file'),(918334,'watch','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(918335,'watch','.b-messages .msv_to_cc div span','vertical-align','middle','','','.b-messages'),(918336,'watch','.w-product-configurator .item-content > div','vertical-align','middle','','','.w-product-configurator'),(918337,'watch','.b-quantity .qty-box input','vertical-align','top','','','.b-quantity'),(918338,'watch','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(918339,'watch','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(918340,'watch','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(918341,'watch','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(918342,'watch','.w-product-configurator .item-content > div','vertical-align','middle','','','.w-product-configurator'),(918343,'watch','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(918344,'watch','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(918345,'watch','.b-email .price','vertical-align','top','','','.b-email'),(918346,'watch','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(918347,'watch','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(918348,'watch','.b-quantity .qty-box input','vertical-align','top','','','.b-quantity'),(918349,'watch','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(918350,'watch','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(918351,'watch','.b-switch .bootstrap-switch','vertical-align','middle','','','.b-switch'),(918352,'watch','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','vertical-align','middle','','','.w-menu-horizontal'),(918353,'watch','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(918354,'watch','.w-filters .input-checkbox:checked + .checkbox-span','vertical-align','middle','','','.w-filters'),(918355,'watch','.b-email .name','vertical-align','top','','','.b-email'),(918356,'watch','.b-email .qty','vertical-align','top','','','.b-email'),(918357,'watch','.b-email .image','vertical-align','top','','','.b-email'),(918358,'watch','.b-form .checkbox-style:checked + .checkbox-span','vertical-align','middle','','','.b-form'),(918359,'watch','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','vertical-align','middle','','','.b-form'),(918360,'watch','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(918361,'watch','.w-product-configurator .item-content > div','vertical-align','middle','','','.w-product-configurator'),(918362,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','vertical-align','top','','','.b-switch'),(918363,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','vertical-align','middle','','','.b-switch'),(918364,'watch','.b-switch .candlestick-wrapper','vertical-align','middle','','','.b-switch'),(918365,'watch','.order-summary .price-row.ot_gv .title','vertical-align','top','3','','.order-summary'),(918366,'watch','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(918367,'watch','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(918368,'watch','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(918369,'watch','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(918370,'watch','.b-quantity .qty-box input','vertical-align','top','','','.b-quantity'),(918371,'watch','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(918372,'watch','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(918373,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(918374,'watch','.w-tabs .tab-li.tab-wishlist a','vertical-align','middle','3','','.w-tabs'),(918375,'watch','.w-product-configurator .item-content > div','vertical-align','middle','','','.w-product-configurator'),(918376,'watch','.w-tabs .tab-li','vertical-align','bottom','','','.w-tabs'),(918377,'watch','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(918378,'watch','.b-quantity .qty-box input','vertical-align','top','','','.b-quantity'),(918379,'watch','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(918380,'watch','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(918381,'watch','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(918382,'watch','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(918383,'watch','.b-email .image','vertical-align','top','','','.b-email'),(918384,'watch','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(918385,'watch','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(918386,'watch','.w-checkout-billing-address .genders-title > div','vertical-align','top','','','.w-checkout-billing-address'),(918387,'watch','.w-checkout-shipping-address .genders-title > div','vertical-align','top','','','.w-checkout-shipping-address'),(918388,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span','vertical-align','middle','','','.b-form'),(918389,'watch','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(918390,'watch','.b-email .qty','vertical-align','top','','','.b-email'),(918391,'watch','.b-email .price','vertical-align','top','','','.b-email'),(918392,'watch','.b-email .price','vertical-align','top','','','.b-email'),(918393,'watch','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(918394,'watch','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(918395,'watch','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(918396,'watch','.w-top-categories .item','vertical-align','top','','','.w-top-categories'),(918397,'watch','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(918398,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(918399,'watch','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(918400,'watch','.b-email .qty','vertical-align','top','','','.b-email'),(918401,'watch','.b-email .name','vertical-align','top','','','.b-email'),(918402,'watch','.b-email .model','vertical-align','top','','','.b-email'),(918403,'watch','.b-email .price','vertical-align','top','','','.b-email'),(918404,'watch','.b-email .image','vertical-align','top','','','.b-email'),(918405,'watch','.w-product-configurator .item-content > div','vertical-align','middle','','','.w-product-configurator'),(918406,'watch','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(918407,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(918408,'watch','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(918409,'watch','.w-cart-discount-coupon .btn','vertical-align','top','','','.w-cart-discount-coupon'),(918410,'watch','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(918411,'watch','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(918412,'watch','.b-email .price','vertical-align','top','','','.b-email'),(918413,'watch','.b-email .model','vertical-align','top','','','.b-email'),(918414,'watch','.b-email .model','vertical-align','top','','','.b-email'),(918415,'watch','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(918416,'watch','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(918417,'watch','.b-email .model','vertical-align','top','','','.b-email'),(918418,'watch','.b-compare .compare_select_items','vertical-align','middle','','','.b-compare'),(918419,'watch','.b-email .name','vertical-align','top','','','.b-email'),(918420,'watch','.b-email .image','vertical-align','top','','','.b-email'),(918421,'watch','.w-tabs .tab-li.tab-quote a','vertical-align','middle','3','','.w-tabs'),(918422,'watch','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(918423,'watch','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(918424,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(918425,'watch','.b-email .price','vertical-align','top','','','.b-email'),(918426,'watch','.w-cart-compare .product-label','vertical-align','bottom','','','.w-cart-compare'),(918427,'watch','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(918428,'watch','.w-product-available-in-warehouses .warehouse-item','vertical-align','top','','','.w-product-available-in-warehouses'),(918429,'watch','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(918430,'watch','.b-quantity .qty-box input','vertical-align','top','','','.b-quantity'),(918431,'watch','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(918432,'watch','.w-cart-compare .product-actions .dropdown-toggle','vertical-align','middle','3','','.w-cart-compare'),(918433,'watch','.w-menu-big li li','vertical-align','top','','','.w-menu-big'),(918434,'watch','.w-cart-compare .product-cell','vertical-align','top','','','.w-cart-compare'),(918435,'watch','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(918436,'watch','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(918437,'watch','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(918438,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.b-data-table');
INSERT INTO `themes_styles` VALUES (918439,'watch','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.b-data-table'),(918440,'watch','.b-products-listing .products-listing .item','vertical-align','top','','','.b-products-listing'),(918441,'watch','.checkbox input + span','vertical-align','middle','','',''),(918442,'watch','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(918443,'watch','.b-email .name','vertical-align','top','','','.b-email'),(918444,'watch','.b-email .image','vertical-align','top','','','.b-email'),(918445,'watch','.b-email .qty','vertical-align','top','','','.b-email'),(918446,'watch','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(918447,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(918448,'watch','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(918449,'watch','.order-summary .price-row.ot_coupon .title','vertical-align','top','3','','.order-summary'),(918450,'watch','.w-tabs .tab-li.tab-sample a','vertical-align','middle','3','','.w-tabs'),(918451,'watch','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(918452,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','','','.w-communication-new-topic'),(918453,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','3','','.w-communication-new-topic'),(918454,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','vertical-align','top','','','.w-communication-new-topic'),(918455,'watch','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','vertical-align','bottom','','','.w-communication-new-topic'),(918456,'watch','.w-quote .no-text','vertical-align','top','','','.w-quote'),(918457,'watch','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(918458,'watch','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(918459,'watch','.b-email .qty','vertical-align','top','','','.b-email'),(918460,'watch','.b-email .name','vertical-align','top','','','.b-email'),(918461,'watch','.w-quote .cart-box-link','vertical-align','middle','3','','.w-quote'),(918462,'watch','.b-email .image','vertical-align','top','','','.b-email'),(918463,'watch','.w-catalog-listing-look .grid','vertical-align','top','','','.w-catalog-listing-look'),(918464,'watch','.w-catalog-listing-look .b2b','vertical-align','top','','','.w-catalog-listing-look'),(918465,'watch','.w-catalog-listing-look .list','vertical-align','top','','','.w-catalog-listing-look'),(918466,'watch','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(918468,'watch','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','vertical-align','top','','','.b-fancybox'),(918469,'watch','.b-email .model','vertical-align','top','','','.b-email'),(918470,'watch','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(918472,'watch','.order-summary .price-row.ot_bonus_points .title','vertical-align','top','3','','.order-summary'),(918473,'watch','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align','top','','','.b-switch'),(918474,'watch','.w-product-configurator .item-content > div','vertical-align','middle','','','.w-product-configurator'),(918475,'watch','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','vertical-align','top','','','.b-fancybox'),(918476,'watch','.w-menu-big li a, .w-menu-big li .no-link','vertical-align','middle','','','.w-menu-big'),(918477,'watch','.b-email .qty','vertical-align','top','','','.b-email'),(918478,'watch','.w-filters .input-checkbox:not(checked) + .checkbox-span','vertical-align','middle','','','.w-filters'),(918479,'watch','.b-product-images .media-popup .mp-small-images .item','vertical-align','top','','','.b-product-images'),(918480,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','vertical-align','middle','3','','.w-catalog-compare'),(918481,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','vertical-align','middle','','','.w-filters'),(918482,'watch','.w-cart-checkout-btn .with-card','vertical-align','middle','4','','.w-cart-checkout-btn'),(918483,'watch','.w-cart-discount-coupon .title','vertical-align','middle','4','','.w-cart-discount-coupon'),(918487,'watch','.account-samples .view_link','vertical-align','middle','4','','.account-samples'),(918488,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','vertical-align','middle','3','','.b-multi-page-checkout'),(918489,'watch','.w-menu-style-1 li a, .w-menu-style-1 li .no-link','vertical-align','middle','','','.w-menu-style-1'),(918490,'watch','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','vertical-align','middle','','','.w-banner'),(918491,'watch','.w-catalog-paging ','vertical-align','top','2','','.w-catalog-paging'),(918492,'watch','.w-catalog-paging .next','vertical-align','top','','','.w-catalog-paging'),(918493,'watch','.w-catalog-paging .next-pages','vertical-align','top','','','.w-catalog-paging'),(918494,'watch','.w-catalog-paging .page-number','vertical-align','top','','','.w-catalog-paging'),(918495,'watch','.w-catalog-paging .prev','vertical-align','top','','','.w-catalog-paging'),(918496,'watch','.w-catalog-paging .prev-pages','vertical-align','top','','','.w-catalog-paging'),(918497,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','vertical-align','top','','','.w-catalog-paging'),(918498,'watch','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align_important','important','','','.b-switch'),(918499,'watch','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(918500,'watch','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(918501,'watch','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(918502,'watch','.b-fancybox .fancybox-tmp','visibility','hidden','','','.b-fancybox'),(918503,'watch','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(918504,'watch','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(918505,'watch','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(918506,'watch','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(918507,'watch','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(918508,'watch','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(918509,'watch','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(918510,'watch','.b-upload-files .attach-active-holder .attach-file','visibility','hidden','','','.b-upload-files'),(918511,'watch','.b-fancybox .fancybox-nav:hover span','visibility','visible','','','.b-fancybox'),(918512,'watch','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(918513,'watch','.b-fancybox .fancybox-opened .fancybox-title','visibility','visible','','','.b-fancybox'),(918514,'watch','.checkbox input','visibility','hidden','','',''),(918515,'watch','.b-fancybox .fancybox-title','visibility','hidden','','','.b-fancybox'),(918516,'watch','.b-fancybox .fancybox-nav span','visibility','hidden','','','.b-fancybox'),(918517,'watch','.b-form .radio-button input[type=\"radio\"].no','visibility','hidden','','','.b-form'),(918518,'watch','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(918519,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','visibility','hidden','','','.b-menu-lev_display-slide'),(918520,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-1 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(918521,'watch','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','visibility','hidden','','','.b-menu-lev_display-slide'),(918522,'watch','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','visibility','hidden','','','.b-menu-lev_display-slide'),(918523,'watch','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','visibility','hidden','','','.b-menu-lev_display-slide'),(918524,'watch','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','visibility','hidden','','','.b-menu-lev_display-slide'),(918525,'watch','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-2 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(918526,'watch','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-4 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(918527,'watch','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-5 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(918528,'watch','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-3 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(918529,'watch','.b-slick .slick-loading .slick-slide','visibility','hidden','','','.b-slick'),(918530,'watch','.b-slick .slick-loading .slick-track','visibility','hidden','','','.b-slick'),(918531,'watch','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(918532,'watch','.b-fancybox .fancybox-title-float-wrap .child','white-space','nowrap','','','.b-fancybox'),(918533,'watch','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(918534,'watch','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(918535,'watch','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(918536,'watch','.w-checkout-shipping-choice span','white-space','nowrap','5261','','.w-checkout-shipping-choice'),(918537,'watch','.b-select-suggest .select2-container .select2-choice > .select2-chosen','white-space','nowrap','','','.b-select-suggest'),(918538,'watch','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(918539,'watch','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(918540,'watch','.w-menu-horizontal > ul','white-space','nowrap','','','.w-menu-horizontal'),(918541,'watch','.w-menu-horizontal > ul','white-space','normal','5240','','.w-menu-horizontal'),(918542,'watch','.b-fancybox .fancybox-error','white-space','nowrap','','','.b-fancybox'),(918543,'watch','.w-catalog-sorting .before','white-space','nowrap','','','.w-catalog-sorting'),(918544,'watch','.b-select-suggest .select2-search','white-space','nowrap','','','.b-select-suggest'),(918545,'watch','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','white-space','nowrap','','','.b-select-suggest'),(918546,'watch','.b-select-suggest .select2-container .select2-choice','white-space','nowrap','','','.b-select-suggest'),(918547,'watch','.w-cart-listing .remove-btn','white-space','nowrap','5240','','.w-cart-listing'),(918550,'watch','.account-samples .view_link','white-space','nowrap','','','.account-samples'),(918551,'watch','.w-menu-style-1 > ul','white-space','nowrap','','','.w-menu-style-1'),(918552,'watch','.w-communication-new-topic .model','width','100','','','.w-communication-new-topic'),(918553,'watch','.w-communication-new-topic .date-purchased','width','130','','','.w-communication-new-topic'),(918554,'watch','.w-communication-new-topic .request-type','width','150','','','.w-communication-new-topic'),(918555,'watch','.w-communication-new-topic .return-reason','width','150','','','.w-communication-new-topic'),(918556,'watch','.b-form .col-left','width','50','','','.b-form'),(918557,'watch','.b-quantity .qty-input input','width','40','','','.b-quantity'),(918558,'watch','.b-email img','width','60','','','.b-email'),(918559,'watch','.b-quantity .qty-input input','width','40','','','.b-quantity'),(918560,'watch','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(918561,'watch','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(918562,'watch','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(918563,'watch','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(918564,'watch','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(918565,'watch','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(918566,'watch','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(918567,'watch','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(918568,'watch','.b-quantity .qty-box .bigger','width','35','','','.b-quantity'),(918569,'watch','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(918570,'watch','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(918571,'watch','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(918572,'watch','.w-product-images-additional .item','width','80','5261','','.w-product-images-additional'),(918574,'watch','.w-delivery-location-top-location-list .deliveryList li','width','23','','','.w-delivery-location-top-location-list'),(918575,'watch','.b-email .totals-value','width','30','','','.b-email'),(918576,'watch','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(918577,'watch','.w-promotions .prom-multi-discount .image img','width','auto','','','.w-promotions'),(918578,'watch','.w-promotions .promo-salemaker > div','width','50','','','.w-promotions'),(918579,'watch','.w-promotions .promo-cart-discount > div','width','50','','','.w-promotions'),(918583,'watch','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width','100','','','.p-sample-checkout-login'),(918584,'watch','.w-delivery-location-top-location-list .deliveryList li','width','23','','','.w-delivery-location-top-location-list'),(918585,'watch','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(918586,'watch','.b-email .image','width','100','','','.b-email'),(918587,'watch','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(918588,'watch','.w-product-configurator .pc_item','width','100','5240','','.w-product-configurator'),(918589,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(918590,'watch','.w-categories .item','width','25','','','.w-categories'),(918591,'watch','.w-promotions .prom-multi-discount .list','width','100','','','.w-promotions'),(918592,'watch','.w-promotions .nextdiscount .item-holder .image','width','40','','','.w-promotions'),(918593,'watch','.w-promotions .nextdiscount .item-holder .name','width','60','','','.w-promotions'),(918594,'watch','.w-promotions .icon','width','45','','','.w-promotions'),(918595,'watch','.w-promotions .promo-salemaker .image img','width','auto','','','.w-promotions'),(918596,'watch','.w-promotions .promo-salemaker .item','width','50','','','.w-promotions'),(918597,'watch','.w-promotions .promo-cart-discount .slave .item','width','calc(50% - 4px)','','','.w-promotions'),(918598,'watch','.w-promotions .promo-cart-discount .image img','width','auto','','','.w-promotions'),(918599,'watch','.b-warehouses-popup .warehouses-popup','width','570','','','.b-warehouses-popup'),(918600,'watch','.b-warehouses-popup .warehouses-popup .warehouse-item','width','230','','','.b-warehouses-popup'),(918601,'watch','.b-preloader .preloader','width','40','3','','.b-preloader'),(918602,'watch','.b-preloader .preloader','width','100','','','.b-preloader'),(918603,'watch','.b-products-listing .products-listing .attribute-qty-block','width','47','','','.b-products-listing'),(918604,'watch','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(918605,'watch','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(918606,'watch','.w-brands .brands-listing > div','width','16','','','.w-brands'),(918607,'watch','.w-cart-continue-btn a','width','100','5232','','.w-cart-continue-btn'),(918608,'watch','.w-delivery-location-top-location-list .deliveryList li','width','23','','','.w-delivery-location-top-location-list'),(918609,'watch','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(918610,'watch','.order-summary .price-row.ot_gv .title','width','32','3','','.order-summary'),(918611,'watch','.w-brands .brands-listing > div','width','16','','','.w-brands'),(918612,'watch','.w-login-block .returning','width','50','','','.w-login-block'),(918613,'watch','.w-product-images-additional .item','width','80','5261','','.w-product-images-additional'),(918614,'watch','.w-product-images-additional .additional-images','width','80','5261','','.w-product-images-additional'),(918615,'watch','.b-products-listing .select-attributes select','width','66','','','.b-products-listing'),(918616,'watch','.b-messages .box-block.type-6 > .block:nth-child(1)','width','25','','','.b-messages'),(918617,'watch','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(918618,'watch','.b-messages .msv_to_cc div span.msv_to_cc_bold','width','100','','','.b-messages'),(918619,'watch','.b-messages .messages-sidebar .btn-2','width','100','','','.b-messages'),(918620,'watch','.b-messages .pre_upload','width','auto','','','.b-messages'),(918621,'watch','.b-messages .email-line input','width','100','','','.b-messages'),(918622,'watch','.b-messages .email-line label','width','150','','','.b-messages'),(918623,'watch','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(918624,'watch','.b-messages #DataTables_Table_0_wrapper table.dataTable thead td:last-child, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td:last-child','width','200','','','.b-messages'),(918625,'watch','.w-sitemap-delivery-location > ul > li > ul > li','width','25','','','.w-sitemap-delivery-location'),(918627,'watch','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(918628,'watch','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(918629,'watch','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(918630,'watch','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(918631,'watch','.b-bottom .terms-info-popup','width','1000','','','.b-bottom'),(918632,'watch','.w-product-bundle .bundle_item','width','48','','','.w-product-bundle'),(918633,'watch','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(918634,'watch','.b-form .col-right','width','100','5240','','.b-form'),(918635,'watch','.w-product-personal-catalog-button .btn','width','160','','','.w-product-personal-catalog-button'),(918636,'watch','.w-product-attributes .select','width','100','','','.w-product-attributes'),(918637,'watch','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(918638,'watch','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(918639,'watch','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(918640,'watch','.w-product-collection .chosen-products','width','50','','','.w-product-collection'),(918641,'watch','.p-payer-order-confirmation .order-summary2 .btn-2','width','100','','','.p-payer-order-confirmation'),(918642,'watch','.p-payer-order-confirmation .dob-hide > div','width','48','','','.p-payer-order-confirmation'),(918643,'watch','.p-payer-order-pay .order-summary2 .btn-2','width','100','','','.p-payer-order-pay'),(918644,'watch','.p-payer-order-pay .dob-hide > div','width','48','','','.p-payer-order-pay'),(918645,'watch','.w-checkout-terms .required-message','width','100','','','.w-checkout-terms'),(918646,'watch','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(918647,'watch','.w-checkout-create-btn .btn-2','width','240','','','.w-checkout-create-btn'),(918648,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','width','15','','','.b-switch'),(918649,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-toggle','width','40','','','.b-switch'),(918650,'watch','.b-fancybox #fancybox-loading div','width','44','','','.b-fancybox'),(918651,'watch','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','width','79','','','.b-datepicker'),(918652,'watch','.b-email .image','width','100','','','.b-email'),(918653,'watch','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','width','25','3','','.w-checkout-contact-information'),(918654,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','width','100','','','.b-switch'),(918655,'watch','.b-quantity .qty-box .smaller','width','35','','','.b-quantity'),(918656,'watch','.w-product-attributes .select','width','100','','','.w-product-attributes'),(918657,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','width','15','','','.b-switch'),(918658,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width','20','3','','.b-switch'),(918659,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','width','150','','','.w-upload-customer-id-upload-customer-id-form'),(918660,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(918661,'watch','.w-upload-customer-id-upload-customer-id-form .dz-details','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(918662,'watch','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(918663,'watch','.b-quantity .qty-box .smaller','width','35','','','.b-quantity'),(918664,'watch','.b-email .image','width','100','','','.b-email'),(918665,'watch','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(918666,'watch','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(918667,'watch','.w-login-block .input','width','100','','','.w-login-block'),(918668,'watch','.w-login-block .guest','width','50','','','.w-login-block'),(918669,'watch','.w-login-block .new','width','50','','','.w-login-block'),(918670,'watch','.w-menu-horizontal li','width','auto','','','.w-menu-horizontal'),(918671,'watch','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(918672,'watch','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(918673,'watch','.w-login-block .input','width','100','','','.w-login-block'),(918674,'watch','.b-form .checkbox-style:checked + .checkbox-span','width','15','','','.b-form'),(918675,'watch','.w-delayed-despatch-checkout #delivery_date','width','150','','','.w-delayed-despatch-checkout'),(918676,'watch','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(918677,'watch','.w-product-images-additional .item-div','width','80','5261','','.w-product-images-additional'),(918678,'watch','.w-product-wishlist-button .btn','width','100','5232','','.w-product-wishlist-button'),(918679,'watch','.b-fancybox .fancybox-lock','width','auto','','','.b-fancybox'),(918680,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','width','15','','','.b-switch'),(918681,'watch','.w-product-collection .current-product','width','25','','','.w-product-collection'),(918682,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','width','10','','','.b-switch'),(918683,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','width','10','','','.b-switch'),(918684,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs','width','30','','','.b-switch'),(918685,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-toggle','width','15','','','.b-switch'),(918686,'watch','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(918687,'watch','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(918688,'watch','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(918689,'watch','.w-promo-code .promo-code-form','width','100','5240','','.w-promo-code'),(918690,'watch','.b-email .totals-value','width','30','','','.b-email'),(918691,'watch','.b-email .totals-title','width','70','','','.b-email'),(918692,'watch','.w-filters .ui-slider-handle','width','15','','','.w-filters'),(918693,'watch','.pop-up-content .buttons .btn-2','width','100','5240','',''),(918694,'watch','.pop-up-content .buttons .btn','width','100','5240','',''),(918695,'watch','.pop-up-content .buttons .left-buttons','width','100','5240','',''),(918696,'watch','.pop-up-content .buttons .right-buttons','width','100','5240','',''),(918697,'watch','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(918698,'watch','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(918699,'watch','.w-login-block .returning','width','50','','','.w-login-block'),(918701,'watch','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(918702,'watch','.w-product-in-bundles .bundle_item','width','48','','','.w-product-in-bundles'),(918703,'watch','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(918704,'watch','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(918705,'watch','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(918706,'watch','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(918707,'watch','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(918708,'watch','.b-products-listing .btn-choose-options','width','100','','','.b-products-listing'),(918709,'watch','.w-filters .input-checkbox:checked + .checkbox-span','width','24','','','.w-filters'),(918710,'watch','.w-filters .ui-slider','width','92','','','.w-filters'),(918711,'watch','.w-checkout-shipping-choice input:checked + span:before','width','10','','','.w-checkout-shipping-choice'),(918712,'watch','.b-switch .candlestick-wrapper','width','60','','','.b-switch'),(918713,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','width','20','3','','.b-switch'),(918714,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(918715,'watch','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(918716,'watch','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(918717,'watch','.b-email .image','width','100','','','.b-email'),(918718,'watch','.b-email .totals-value','width','30','','','.b-email'),(918719,'watch','.b-email .heading-image','width','100','','','.b-email'),(918720,'watch','.b-email .products-table','width','100','','','.b-email'),(918721,'watch','.b-form .login-col-1','width','25','','','.b-form'),(918722,'watch','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(918724,'watch','.b-select-suggest .select2-container','width','100','','','.b-select-suggest'),(918725,'watch','.b-select-suggest .select2-measure-scrollbar','width','100','','','.b-select-suggest'),(918726,'watch','.b-email-editor img','width','auto','','','.b-email-editor'),(918727,'watch','.b-form .middle-form .dob-input input[type=\"text\"]','width','48','','','.b-form'),(918728,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width','1','','','.b-select-suggest'),(918729,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(918730,'watch','.w-brands .brands-listing > div','width','16','','','.w-brands'),(918731,'watch','.b-quantity .qty-box .smaller','width','35','','','.b-quantity'),(918732,'watch','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(918733,'watch','.w-product-in-bundles .bundle_item','width','48','','','.w-product-in-bundles'),(918734,'watch','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(918735,'watch','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(918736,'watch','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(918737,'watch','.w-socials .post_item_img','width','100','','','.w-socials'),(918739,'watch','.b-info-popup .info-popup div','width','250','','','.b-info-popup'),(918740,'watch','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5240','','.w-promo-code'),(918741,'watch','.b-quantity .qty-box input','width','60','','','.b-quantity'),(918742,'watch','.b-quantity .qty-box .smaller','width','35','','','.b-quantity'),(918743,'watch','.b-quantity .qty-box .bigger','width','35','','','.b-quantity'),(918744,'watch','.w-brands .brands-listing > div','width','16','','','.w-brands'),(918745,'watch','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(918746,'watch','.w-delivery-location-top-location-list .deliveryList li','width','23','','','.w-delivery-location-top-location-list'),(918747,'watch','.w-cart-listing .right-area','width','100','5240','','.w-cart-listing'),(918748,'watch','.w-product-images-additional .additional-images','width','80','5261','','.w-product-images-additional'),(918749,'watch','.w-product-configurator .pc_item','width','100','5240','','.w-product-configurator'),(918750,'watch','.w-promo-code .promo-text','width','100','5240','','.w-promo-code'),(918751,'watch','.w-product-wishlist-button .btn','width','100','5232','','.w-product-wishlist-button'),(918752,'watch','.w-cart-continue-btn a','width','100','5232','','.w-cart-continue-btn'),(918753,'watch','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(918754,'watch','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(918755,'watch','.w-cart-order-total.box','width','100','5232','','.w-cart-order-total'),(918756,'watch','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(918757,'watch','.b-quantity .qty-box .bigger','width','35','','','.b-quantity'),(918758,'watch','.b-info-popup .info-popup div','width','20','3','','.b-info-popup'),(918759,'watch','.b-email .totals-value','width','30','','','.b-email'),(918760,'watch','.b-email .heading-image','width','100','','','.b-email'),(918761,'watch','.b-email .heading-image','width','100','','','.b-email'),(918762,'watch','.view-all','width','100','3','',''),(918763,'watch','.w-promo-code .promo-code-form','width','100','5240','','.w-promo-code'),(918764,'watch','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5240','','.w-promo-code'),(918765,'watch','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(918766,'watch','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(918767,'watch','.w-product-attributes .select','width','100','','','.w-product-attributes'),(918768,'watch','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(918769,'watch','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(918770,'watch','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(918771,'watch','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(918772,'watch','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(918773,'watch','.w-product-bundle .bundle_item','width','48','','','.w-product-bundle'),(918774,'watch','.w-product-collection .chosen-products','width','50','','','.w-product-collection'),(918775,'watch','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(918776,'watch','.w-product-collection .current-product','width','25','','','.w-product-collection'),(918777,'watch','.w-product-collection .right-area','width','25','','','.w-product-collection'),(918780,'watch','.b-form .columns .col-2','width','50','','','.b-form'),(918781,'watch','.b-bottom .popup-box.popupCompare','width','80','','','.b-bottom'),(918782,'watch','.w-promo-code .promo-code-form','width','100','5240','','.w-promo-code'),(918783,'watch','.w-cart-continue-btn a','width','100','5232','','.w-cart-continue-btn'),(918784,'watch','.b-quantity .qty-box input','width','60','','','.b-quantity'),(918785,'watch','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(918786,'watch','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(918787,'watch','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(918788,'watch','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(918789,'watch','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(918790,'watch','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(918791,'watch','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(918792,'watch','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(918793,'watch','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(918794,'watch','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(918795,'watch','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(918796,'watch','.b-quantity .qty-input input','width','40','','','.b-quantity'),(918797,'watch','.w-checkout-guest-btn .btn-2','width','240','','','.w-checkout-guest-btn'),(918798,'watch','textarea','width','100','','',''),(918799,'watch','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(918800,'watch','.w-product-properties li','width','50','','','.w-product-properties'),(918801,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(918802,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','width','100','','','.b-switch'),(918803,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','width','100','','','.b-switch'),(918804,'watch','.b-switch .bootstrap-switch .bootstrap-switch-label','width','30','','','.b-switch'),(918805,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(918806,'watch','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(918807,'watch','.b-email-editor img','width','auto','','','.b-email-editor'),(918808,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','width','100','','','.b-switch'),(918809,'watch','.b-quantity .qty-box input','width','60','','','.b-quantity'),(918810,'watch','.b-form .checkbox-style','width','0','','','.b-form'),(918811,'watch','.b-email .image','width','100','','','.b-email'),(918812,'watch','.b-email .totals-title','width','70','','','.b-email'),(918813,'watch','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','width','25','3','','.w-checkout-contact-information'),(918814,'watch','.b-form .addresses .address-item','width','48','','','.b-form'),(918815,'watch','.w-categories .item','width','50','5232','','.w-categories'),(918816,'watch','.order-summary .btn-2, .order-summary .btn-3','width','100','','','.order-summary'),(918817,'watch','.order-summary .price-box .price','width','auto','','','.order-summary'),(918818,'watch','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(918819,'watch','.b-email .totals-table','width','100','','','.b-email'),(918820,'watch','.w-socials .post_item_img','width','100','','','.w-socials'),(918821,'watch','.w-product-configurator .item-content','width','100','5240','','.w-product-configurator'),(918822,'watch','.w-product-collection .right-area','width','25','','','.w-product-collection'),(918823,'watch','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(918824,'watch','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(918825,'watch','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(918826,'watch','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(918827,'watch','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(918828,'watch','.w-list-b2b .select-attributes','width','47','','','.w-list-b2b'),(918829,'watch','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(918830,'watch','.w-product-configurator .pc_item','width','100','5240','','.w-product-configurator'),(918831,'watch','.w-promo-code .promo-text','width','100','5240','','.w-promo-code'),(918832,'watch','.w-product-configurator .item-content','width','100','5240','','.w-product-configurator'),(918833,'watch','.w-checkout-shipping-choice label','width','50','','','.w-checkout-shipping-choice'),(918834,'watch','.b-switch .candlestick-wrapper.candlestick-contents','width','306','','','.b-switch'),(918835,'watch','.b-email .products-table','width','100','','','.b-email'),(918836,'watch','.w-checkout-shipping-choice label','width','auto','5261','','.w-checkout-shipping-choice'),(918837,'watch','.w-checkout-create-account .col-2','width','100','5240','','.w-checkout-create-account'),(918838,'watch','.w-product-in-bundles .bundle_item','width','48','','','.w-product-in-bundles'),(918839,'watch','.w-product-personal-catalog-button .btn','width','160','','','.w-product-personal-catalog-button'),(918840,'watch','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(918841,'watch','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(918842,'watch','.w-top-categories .item','width','25','','','.w-top-categories'),(918843,'watch','.w-checkout-billing-address .addresses .address-item','width','50','','','.w-checkout-billing-address'),(918844,'watch','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(918845,'watch','.w-product-properties li','width','50','','','.w-product-properties'),(918846,'watch','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(918847,'watch','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(918848,'watch','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(918849,'watch','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(918850,'watch','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(918851,'watch','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(918852,'watch','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(918853,'watch','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(918854,'watch','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(918855,'watch','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(918856,'watch','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(918857,'watch','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(918858,'watch','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(918859,'watch','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(918860,'watch','.w-cart-give-away .ga_attributes select','width','100','','','.w-cart-give-away'),(918861,'watch','.w-cart-checkout-btn a','width','100','5232','','.w-cart-checkout-btn'),(918862,'watch','.b-autocomplete .ui-autocomplete','width','200','','','.b-autocomplete'),(918863,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(918864,'watch','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(918865,'watch','.w-socials .post_item_img','width','100','','','.w-socials'),(918867,'watch','.b-email .totals-value','width','30','','','.b-email'),(918868,'watch','.b-email .totals-table','width','100','','','.b-email'),(918869,'watch','.b-email .totals-title','width','70','','','.b-email'),(918870,'watch','.b-email .heading-image','width','100','','','.b-email'),(918871,'watch','.b-email img','width','60','','','.b-email'),(918872,'watch','.b-email .products-table','width','100','','','.b-email'),(918873,'watch','.b-email .image','width','100','','','.b-email'),(918874,'watch','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(918875,'watch','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(918876,'watch','.w-product-collection .right-area','width','25','','','.w-product-collection'),(918877,'watch','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(918878,'watch','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(918879,'watch','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(918880,'watch','.b-form .col-right','width','50','','','.b-form'),(918881,'watch','.b-email img','width','60','','','.b-email'),(918882,'watch','.w-cart-continue-btn a','width','100','5232','','.w-cart-continue-btn'),(918883,'watch','.w-product-wishlist-button .btn','width','100','5232','','.w-product-wishlist-button'),(918884,'watch','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5240','','.w-promo-code'),(918885,'watch','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(918886,'watch','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(918887,'watch','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(918888,'watch','.w-promo-code .promo-code-form','width','100','5240','','.w-promo-code'),(918889,'watch','.w-promo-code .promo-text','width','100','5240','','.w-promo-code'),(918890,'watch','.b-form .columns .col-2','width','100','5261','','.b-form'),(918891,'watch','.b-select-suggest .select2-container .select2-choice abbr','width','12','','','.b-select-suggest'),(918892,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(918893,'watch','.b-quantity .qty-input input','width','40','','','.b-quantity'),(918894,'watch','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(918895,'watch','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(918896,'watch','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(918897,'watch','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(918898,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','width','20','','','.b-switch'),(918899,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','width','28','','','.b-switch'),(918900,'watch','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(918901,'watch','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(918902,'watch','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(918903,'watch','.w-login-block .new','width','50','','','.w-login-block'),(918904,'watch','.w-login-block .guest','width','50','','','.w-login-block'),(918905,'watch','.w-login-block .input','width','100','','','.w-login-block'),(918906,'watch','.w-login-block .returning','width','50','','','.w-login-block'),(918907,'watch','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(918908,'watch','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(918909,'watch','div.cart-popup','width','850','','',''),(918910,'watch','.w-cart-give-away .ga_column','width','46','','','.w-cart-give-away'),(918911,'watch','.w-cart-give-away .ga_attributes > div','width','48','','','.w-cart-give-away'),(918912,'watch','.w-product-collection .chosen-products','width','50','','','.w-product-collection'),(918913,'watch','.w-product-collection .right-area','width','25','','','.w-product-collection'),(918914,'watch','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width','100','','','.b-form'),(918915,'watch','.b-products-listing .products-listing .buyButton .btn','width','100','','','.b-products-listing'),(918916,'watch','.w-image-maps .svg-wrap svg','width','100','','','.w-image-maps'),(918917,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(918918,'watch','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(918919,'watch','.w-login-block .guest','width','50','','','.w-login-block'),(918920,'watch','.w-login-block .new','width','50','','','.w-login-block'),(918921,'watch','.w-cart-shipping-estimator .right-area','width','48','','','.w-cart-shipping-estimator'),(918922,'watch','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(918923,'watch','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(918924,'watch','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(918925,'watch','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(918926,'watch','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(918927,'watch','.w-product-collection .chosen-products','width','50','','','.w-product-collection'),(918928,'watch','.w-product-collection .current-product','width','25','','','.w-product-collection'),(918929,'watch','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(918930,'watch','.w-checkout-credit-amount .btn-remove','width','25','','','.w-checkout-credit-amount'),(918931,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(918932,'watch','.w-checkout-credit-amount .cot_gv_amount','width','150','','','.w-checkout-credit-amount'),(918933,'watch','.p-quick-order-index .all-scroll-div','width','100','','','.p-quick-order-index'),(918934,'watch','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(918935,'watch','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(918936,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(918937,'watch','.b-email-editor img','width','auto','','','.b-email-editor'),(918938,'watch','.b-form .col-left','width','100','5240','','.b-form'),(918939,'watch','.b-email .totals-title','width','70','','','.b-email'),(918940,'watch','.b-email .totals-table','width','100','','','.b-email'),(918941,'watch','.w-product-images-additional .additional-images','width','80','5261','','.w-product-images-additional'),(918942,'watch','.w-product-images-additional .item','width','80','5261','','.w-product-images-additional'),(918943,'watch','.b-bottom .cart-options .option-item','width','50','','','.b-bottom'),(918944,'watch','.w-product-configurator .pc_item','width','100','5240','','.w-product-configurator'),(918945,'watch','.w-promotions .promo-cart-discount .master .item','width','calc(50% - 24px)','','','.w-promotions'),(918946,'watch','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(918947,'watch','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(918948,'watch','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(918949,'watch','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(918950,'watch','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(918951,'watch','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(918952,'watch','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(918953,'watch','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(918954,'watch','.b-bottom .cart-options .cart-item','width','50','','','.b-bottom'),(918955,'watch','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(918956,'watch','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(918957,'watch','.w-cart-shipping-estimator .left-area','width','48','','','.w-cart-shipping-estimator'),(918958,'watch','.w-login-block .returning','width','50','','','.w-login-block'),(918959,'watch','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(918960,'watch','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(918961,'watch','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(918962,'watch','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(918963,'watch','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(918964,'watch','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(918965,'watch','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(918966,'watch','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(918967,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(918968,'watch','.w-product-collection .current-product','width','25','','','.w-product-collection'),(918969,'watch','.b-email img','width','60','','','.b-email'),(918970,'watch','.b-form .col-3','width','31.33','','','.b-form'),(918971,'watch','.b-email .products-table','width','100','','','.b-email'),(918972,'watch','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(918973,'watch','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width','100','','','.b-form'),(918974,'watch','.w-product-configurator .item-content','width','100','5240','','.w-product-configurator'),(918975,'watch','.w-login-block .input','width','100','','','.w-login-block'),(918976,'watch','.b-products-listing .products-listing .radio-attributes .item-title','width','33','','','.b-products-listing'),(918977,'watch','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','width','35','','','.b-products-listing'),(918978,'watch','.w-login-block .guest','width','50','','','.w-login-block'),(918979,'watch','.w-product-collection .right-area','width','25','','','.w-product-collection'),(918980,'watch','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(918981,'watch','.w-product-collection .chosen-products','width','50','','','.w-product-collection'),(918982,'watch','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(918983,'watch','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(918984,'watch','.w-product-in-bundles .bundle_item','width','48','','','.w-product-in-bundles'),(918985,'watch','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(918986,'watch','.w-product-wishlist-button .btn','width','100','5232','','.w-product-wishlist-button'),(918987,'watch','.w-product-images-additional .item-div','width','80','5261','','.w-product-images-additional'),(918988,'watch','.b-bottom .popup-box','width','530','','','.b-bottom'),(918989,'watch','.b-email .totals-table','width','100','','','.b-email'),(918990,'watch','.b-email img','width','60','','','.b-email'),(918991,'watch','.b-form .login-col-2','width','50','','','.b-form'),(918992,'watch','.b-fancybox .fancybox-close','width','40','','','.b-fancybox'),(918993,'watch','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(918994,'watch','.w-cart-compare .product .image','width','50','','','.w-cart-compare'),(918995,'watch','.w-product-customers-activity .customers-activity','width','255','','','.w-product-customers-activity'),(918996,'watch','.w-product-customers-activity .close','width','30','','','.w-product-customers-activity'),(918997,'watch','.b-form .hide-billing-address','width','100','','','.b-form'),(918998,'watch','.b-quantity .qty-box .smaller','width','35','','','.b-quantity'),(918999,'watch','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(919000,'watch','.b-email-editor img','width','auto','','','.b-email-editor'),(919001,'watch','.w-top-categories .item','width','50','5232','','.w-top-categories'),(919002,'watch','.w-product-personal-catalog-button .btn','width','160','','','.w-product-personal-catalog-button'),(919003,'watch','.w-personal-gift-status-bar .progress-bar','width','230','','','.w-personal-gift-status-bar'),(919004,'watch','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(919005,'watch','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(919006,'watch','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(919007,'watch','.w-product-in-bundles .bundle_item','width','48','','','.w-product-in-bundles'),(919008,'watch','.w-product-properties li','width','50','','','.w-product-properties'),(919009,'watch','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(919010,'watch','.w-product-bundle .bundle_item','width','48','','','.w-product-bundle'),(919011,'watch','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(919012,'watch','.w-product-attributes .select','width','100','','','.w-product-attributes'),(919013,'watch','.w-checkout-billing-address .addresses.address-main .address-item','width','100','','','.w-checkout-billing-address'),(919014,'watch','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width','150','','','.w-coupons-and-vauchers-checkout'),(919015,'watch','.w-checkout-shipping-address .addresses.address-main .address-item','width','100','','','.w-checkout-shipping-address'),(919016,'watch','.w-checkout-shipping-choice #shippingchoice-choice','width','430','','','.w-checkout-shipping-choice'),(919017,'watch','.w-product-images-additional .item-div','width','80','5261','','.w-product-images-additional'),(919018,'watch','.w-product-images-additional .item','width','80','5261','','.w-product-images-additional'),(919019,'watch','.w-product-images-additional .additional-images','width','80','5261','','.w-product-images-additional'),(919020,'watch','.w-cart-order-total.box','width','100','5232','','.w-cart-order-total'),(919021,'watch','.w-product-wishlist-button .btn','width','100','5232','','.w-product-wishlist-button'),(919022,'watch','.w-promo-code .promo-code-form','width','100','5240','','.w-promo-code'),(919023,'watch','.w-cart-checkout-btn ','width','100','5232','','.w-cart-checkout-btn'),(919024,'watch','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5240','','.w-promo-code'),(919025,'watch','.w-cart-continue-btn a','width','100','5232','','.w-cart-continue-btn'),(919026,'watch','.w-promo-code .promo-text','width','100','5240','','.w-promo-code'),(919027,'watch','.w-product-configurator .item-content','width','100','5240','','.w-product-configurator'),(919028,'watch','.w-cart-order-total.box','width','100','5232','','.w-cart-order-total'),(919029,'watch','.w-product-images-additional .item-div','width','80','5261','','.w-product-images-additional'),(919030,'watch','.b-quantity .qty-box .bigger','width','35','','','.b-quantity'),(919031,'watch','.b-quantity .qty-box input','width','60','','','.b-quantity'),(919032,'watch','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(919033,'watch','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(919034,'watch','.b-select-suggest .select2-search-choice-close','width','12','','','.b-select-suggest'),(919035,'watch','.b-select-suggest .select2-search input','width','100','','','.b-select-suggest'),(919036,'watch','.b-select-suggest .select2-search','width','100','','','.b-select-suggest'),(919037,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow','width','18','','','.b-select-suggest'),(919038,'watch','.b-select-suggest .select2-drop-auto-width','width','auto','','','.b-select-suggest'),(919039,'watch','.b-select-suggest .select2-drop','width','100','','','.b-select-suggest'),(919040,'watch','.b-select-suggest .select2-drop-mask','width','auto','','','.b-select-suggest'),(919041,'watch','.w-product-configurator .pc_item','width','100','5240','','.w-product-configurator'),(919042,'watch','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(919043,'watch','.w-product-properties li','width','50','','','.w-product-properties'),(919044,'watch','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(919045,'watch','.w-socials .post_item_img','width','100','','','.w-socials'),(919046,'watch','.w-tabs .tab-navigation','width','100','','','.w-tabs'),(919047,'watch','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(919048,'watch','.w-login-block .returning','width','50','','','.w-login-block'),(919049,'watch','.w-categories .item','width','100','5261','','.w-categories'),(919050,'watch','.w-product-in-bundles .bundle_item','width','48','','','.w-product-in-bundles'),(919051,'watch','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(919052,'watch','.w-product-collection .current-product','width','25','','','.w-product-collection'),(919053,'watch','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(919054,'watch','.w-product-bundle .bundle_item','width','48','','','.w-product-bundle'),(919055,'watch','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(919056,'watch','.b-email-editor img','width','auto','','','.b-email-editor'),(919057,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width','20','3','','.b-switch'),(919058,'watch','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(919059,'watch','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(919060,'watch','.w-socials .post_item_img','width','100','','','.w-socials'),(919062,'watch','.w-login-block .guest','width','50','','','.w-login-block'),(919063,'watch','.w-login-block .returning','width','50','','','.w-login-block'),(919064,'watch','.w-menu-big li','width','auto','','','.w-menu-big'),(919065,'watch','.w-product-collection .current-product','width','25','','','.w-product-collection'),(919066,'watch','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(919067,'watch','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(919068,'watch','.w-cart-listing .links','width','19','','','.w-cart-listing'),(919069,'watch','.w-cart-order-total.box','width','100','5232','','.w-cart-order-total'),(919070,'watch','.w-account-addresses-list .addsess-suggestion-item','width','50','','','.w-account-addresses-list'),(919071,'watch','.b-products-listing .products-listing a.btn.view-button','width','100','','','.b-products-listing'),(919072,'watch','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width','80','','','.b-products-listing'),(919073,'watch','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width','60','','','.b-products-listing'),(919074,'watch','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width','40','','','.b-products-listing'),(919075,'watch','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width','20','','','.b-products-listing'),(919076,'watch','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width','40','','','.b-products-listing'),(919077,'watch','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width','20','','','.b-products-listing'),(919078,'watch','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width','60','','','.b-products-listing'),(919079,'watch','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width','60','','','.b-products-listing'),(919080,'watch','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width','20','','','.b-products-listing'),(919081,'watch','.b-products-listing .BlockBox.type-14 > .col','width','25','','','.b-products-listing'),(919082,'watch','.b-products-listing .BlockBox.type-15 > .col','width','20','','','.b-products-listing'),(919083,'watch','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width','50','','','.b-products-listing'),(919084,'watch','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(919085,'watch','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(919086,'watch','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width','33.33','','','.b-products-listing'),(919087,'watch','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width','50','','','.b-products-listing'),(919088,'watch','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(919089,'watch','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width','66.66','','','.b-products-listing'),(919090,'watch','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width','66.66','','','.b-products-listing'),(919091,'watch','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(919092,'watch','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width','25','','','.b-products-listing'),(919093,'watch','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width','25','','','.b-products-listing'),(919094,'watch','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width','75','','','.b-products-listing'),(919095,'watch','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width','75','','','.b-products-listing'),(919096,'watch','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width','25','','','.b-products-listing'),(919097,'watch','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width','50','','','.b-products-listing'),(919098,'watch','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width','25','','','.b-products-listing'),(919099,'watch','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width','20','','','.b-products-listing'),(919100,'watch','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width','80','','','.b-products-listing'),(919101,'watch','.b-products-listing .btn-preloader','width','24','3','','.b-products-listing'),(919102,'watch','.b-products-listing .hover-box-content','width','20','3','','.b-products-listing'),(919103,'watch','.b-products-listing .loader','width','30','4','','.b-products-listing'),(919104,'watch','.b-products-listing .loader','width','100','3','','.b-products-listing'),(919105,'watch','.b-products-listing .products-listing .attribute-qty-block > span','width','50','','','.b-products-listing'),(919106,'watch','.b-products-listing .products-listing .attributes select','width','100','','','.b-products-listing'),(919107,'watch','.b-products-listing .products-listing .btn-buy','width','100','','','.b-products-listing'),(919108,'watch','.w-catalog-b2b-add-button ','width','100','','','.w-catalog-b2b-add-button'),(919109,'watch','.b-products-listing .products-listing .item','width','25','','','.b-products-listing'),(919110,'watch','.b-products-listing .products-listing .qty-input.hidden','width','100','3','','.b-products-listing'),(919111,'watch','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','width','auto','','','.b-products-listing'),(919112,'watch','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width','100','','','.b-products-listing'),(919113,'watch','.checkbox input:not(checked) + span:before','width','22','','',''),(919114,'watch','.checkbox input + span','width','24','','',''),(919116,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width','100','','','.b-select-suggest'),(919117,'watch','.b-quantity .qty-box .bigger','width','35','','','.b-quantity'),(919118,'watch','.b-quantity .qty-box input','width','60','','','.b-quantity'),(919119,'watch','.b-products-listing .products-listing .in-cart','width','100','','','.b-products-listing'),(919120,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-toggle','width','10','','','.b-switch'),(919121,'watch','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','width','10','','','.b-switch'),(919122,'watch','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','width','25','3','','.w-checkout-contact-information'),(919123,'watch','.b-form .radio-button input[type=\"radio\"].no + span','width','30','3','','.b-form'),(919124,'watch','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width','100','','','.b-fancybox'),(919125,'watch','.b-email .heading-image','width','100','','','.b-email'),(919126,'watch','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(919127,'watch','.w-product-images-additional .additional-images','width','80','5261','','.w-product-images-additional'),(919128,'watch','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5240','','.w-promo-code'),(919129,'watch','.w-socials .post_item_img','width','100','','','.w-socials'),(919130,'watch','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(919131,'watch','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(919132,'watch','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(919133,'watch','.w-product-properties li','width','50','','','.w-product-properties'),(919134,'watch','.w-product-personal-catalog-button .btn','width','160','','','.w-product-personal-catalog-button'),(919135,'watch','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(919136,'watch','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(919137,'watch','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(919138,'watch','.w-cart-credit-amount .btn-remove','width','25','','','.w-cart-credit-amount'),(919139,'watch','.w-coupons-and-vauchers-checkout .btn-remove','width','25','','','.w-coupons-and-vauchers-checkout'),(919140,'watch','.b-products-listing .select-attributes .item-title','width','33','','','.b-products-listing'),(919141,'watch','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(919142,'watch','.w-delivery-location-top-location-list .deliveryList li','width','23','','','.w-delivery-location-top-location-list'),(919143,'watch','.order-summary .price-row.ot_coupon .title','width','32','3','','.order-summary'),(919144,'watch','.b-quantity .qty-input input','width','40','','','.b-quantity'),(919145,'watch','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterSku\"]','width','60','','','.w-communication-new-topic'),(919146,'watch','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterOrderId\"]','width','60','','','.w-communication-new-topic'),(919147,'watch','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterName\"]','width','100','','','.w-communication-new-topic'),(919148,'watch','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateFrom\"]','width','60','','','.w-communication-new-topic'),(919149,'watch','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateTo\"]','width','60','','','.w-communication-new-topic'),(919150,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','width','36','','','.w-communication-new-topic'),(919151,'watch','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','width','36','','','.w-communication-new-topic'),(919152,'watch','.w-communication-new-topic .middle-form select','width','100','','','.w-communication-new-topic'),(919153,'watch','.w-login-block .input','width','100','','','.w-login-block'),(919154,'watch','.w-checkout-shipping-address .addresses .address-item','width','50','','','.w-checkout-shipping-address'),(919155,'watch','.b-form .checkbox-style:not(checked) + .checkbox-span','width','15','','','.b-form'),(919156,'watch','.w-checkout-shipping-choice #shippingchoice-choice','width','auto','5261','','.w-checkout-shipping-choice'),(919157,'watch','.b-email img','width','60','','','.b-email'),(919158,'watch','.w-cart-continue-btn a','width','100','5232','','.w-cart-continue-btn'),(919159,'watch','.b-bottom .popup-credit-amount .popup-box','width','100','','','.b-bottom'),(919160,'watch','.w-product-images-additional .item','width','80','5261','','.w-product-images-additional'),(919161,'watch','.w-promo-code .promo-code-form','width','100','5240','','.w-promo-code'),(919162,'watch','.w-product-properties li','width','50','','','.w-product-properties'),(919163,'watch','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(919164,'watch','.w-product-personal-catalog-button .btn','width','160','','','.w-product-personal-catalog-button'),(919165,'watch','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(919166,'watch','.w-product-bundle .bundle_item','width','48','','','.w-product-bundle'),(919167,'watch','.w-product-collection .right-area','width','25','','','.w-product-collection'),(919168,'watch','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(919169,'watch','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(919170,'watch','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(919171,'watch','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(919172,'watch','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(919173,'watch','.b-email .products-table','width','100','','','.b-email'),(919174,'watch','.b-email .totals-title','width','70','','','.b-email'),(919175,'watch','.w-login-block .new','width','50','','','.w-login-block'),(919176,'watch','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(919177,'watch','.b-email-editor img','width','auto','','','.b-email-editor'),(919178,'watch','.b-email .heading-image','width','100','','','.b-email'),(919179,'watch','.w-product-configurator .pc_item','width','100','5240','','.w-product-configurator'),(919180,'watch','.w-product-configurator .item-content','width','100','5240','','.w-product-configurator'),(919181,'watch','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(919182,'watch','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(919183,'watch','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(919184,'watch','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(919185,'watch','.b-compare .col-two label','width','20','','','.b-compare'),(919186,'watch','.w-cart-order-total.box','width','100','5232','','.w-cart-order-total'),(919187,'watch','.w-promo-code .promo-text','width','100','5240','','.w-promo-code'),(919188,'watch','.w-menu-horizontal .menu-ico','width','54','','','.w-menu-horizontal'),(919189,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(919190,'watch','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(919191,'watch','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(919192,'watch','.w-product-personal-catalog-button .btn','width','160','','','.w-product-personal-catalog-button'),(919193,'watch','.w-catalog-listing-look .grid','width','31','','','.w-catalog-listing-look'),(919194,'watch','.w-catalog-listing-look .b2b','width','31','','','.w-catalog-listing-look'),(919195,'watch','.w-catalog-listing-look .list','width','31','','','.w-catalog-listing-look'),(919196,'watch','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','width','130','','','.w-cart-listing'),(919197,'watch','.w-cart-listing .remove-btn','width','30','','','.w-cart-listing'),(919198,'watch','.w-cart-listing .right-area','width','35','','','.w-cart-listing'),(919199,'watch','.w-cart-listing .item .image','width','80','5240','','.w-cart-listing'),(919200,'watch','.w-cart-listing .item .remove','width','100','5240','','.w-cart-listing'),(919201,'watch','.w-cart-give-away .ga_img','width','30','','','.w-cart-give-away'),(919202,'watch','.w-cart-give-away .ga_column','width','100','5232','','.w-cart-give-away'),(919203,'watch','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(919204,'watch','.w-cart-discount-coupon input[type=\"text\"]','width','100','','','.w-cart-discount-coupon'),(919205,'watch','.w-cart-discount-coupon .btn-remove','width','25','','','.w-cart-discount-coupon'),(919207,'watch','.w-brands .brands-listing > div','width','16','','','.w-brands'),(919208,'watch','.b-upload-file .snapshot','width','38','','','.b-upload-file'),(919209,'watch','.b-fancybox .fancybox-nav span','width','40','','','.b-fancybox'),(919210,'watch','.b-fancybox .fancybox-nav','width','40','','','.b-fancybox'),(919211,'watch','.b-email .totals-table','width','100','','','.b-email'),(919212,'watch','.w-product-images-additional .item','width','80','5261','','.w-product-images-additional'),(919213,'watch','.b-upload-file .upload-file-template','width','150','','','.b-upload-file'),(919214,'watch','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(919215,'watch','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(919216,'watch','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(919217,'watch','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(919218,'watch','.w-product-attributes .select','width','100','','','.w-product-attributes'),(919219,'watch','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(919220,'watch','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(919221,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(919222,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(919223,'watch','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(919224,'watch','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(919225,'watch','.b-switch .candlestick-wrapper.candlestick-size-sm','width','45','','','.b-switch'),(919226,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','width','40','','','.b-switch'),(919227,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(919228,'watch','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(919229,'watch','.w-login-block .new','width','50','','','.w-login-block'),(919230,'watch','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(919231,'watch','.w-product-configurator .item-content','width','100','5240','','.w-product-configurator'),(919232,'watch','.w-filters .handle-to','width','50','','','.w-filters'),(919233,'watch','.w-filters .handle-from','width','50','','','.w-filters'),(919234,'watch','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(919235,'watch','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5240','','.w-promo-code'),(919236,'watch','.order-summary .price-row.ot_bonus_points .title','width','32','3','','.order-summary'),(919237,'watch','.w-delivery-location-top-location-list .deliveryList li','width','23','','','.w-delivery-location-top-location-list'),(919238,'watch','.w-filters .input-checkbox','width','0','','','.w-filters'),(919239,'watch','.b-bottom .pop-up-close','width','31','','','.b-bottom'),(919240,'watch','.w-product-images-additional .item-div','width','80','5261','','.w-product-images-additional'),(919241,'watch','.w-promo-code .promo-text','width','100','5240','','.w-promo-code'),(919242,'watch','.w-product-images-additional .additional-images','width','80','5261','','.w-product-images-additional'),(919243,'watch','.w-product-images-additional .item-div','width','80','5261','','.w-product-images-additional'),(919244,'watch','.w-cart-order-total.box','width','100','5232','','.w-cart-order-total'),(919245,'watch','.b-compare .col-two select','width','80','','','.b-compare'),(919246,'watch','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(919247,'watch','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(919248,'watch','.w-product-bundle .bundle_item','width','48','','','.w-product-bundle'),(919249,'watch','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(919250,'watch','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(919251,'watch','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(919252,'watch','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(919253,'watch','.w-product-attributes .select','width','100','','','.w-product-attributes'),(919254,'watch','.w-product-wishlist-button .btn','width','100','5232','','.w-product-wishlist-button'),(919255,'watch','.b-quantity .qty-input input','width','40','','','.b-quantity'),(919256,'watch','.b-quantity .qty-box .bigger','width','35','','','.b-quantity'),(919257,'watch','.b-quantity .qty-box input','width','60','','','.b-quantity'),(919258,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(919259,'watch','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(919260,'watch','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(919261,'watch','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(919262,'watch','.w-product-collection .chosen-products','width','50','','','.w-product-collection'),(919263,'watch','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(919264,'watch','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(919265,'watch','.w-login-block .new','width','50','','','.w-login-block'),(919266,'watch','.w-login-block .input','width','100','','','.w-login-block'),(919267,'watch','.w-login-block .guest','width','50','','','.w-login-block'),(919268,'watch','.b-products-listing .products-listing .btn-preloader','width','100','','','.b-products-listing'),(919269,'watch','.w-communication-new-topic .btn-submit','width','200','','','.w-communication-new-topic'),(919270,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(919271,'watch','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(919272,'watch','.w-cart-credit-amount input[type=\"text\"]','width','150','','','.w-cart-credit-amount'),(919273,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg','width','120','','','.b-switch'),(919274,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','width','40','','','.b-switch'),(919275,'watch','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','width','40','','','.b-switch'),(919276,'watch','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(919277,'watch','.b-quantity .qty-box .smaller','width','35','','','.b-quantity'),(919278,'watch','.b-email .products-table','width','100','','','.b-email'),(919279,'watch','.b-email .totals-value','width','30','','','.b-email'),(919280,'watch','.b-email .totals-title','width','70','','','.b-email'),(919281,'watch','.b-email .totals-table','width','100','','','.b-email'),(919282,'watch','.w-filters .mobileCollapse','width','17','','','.w-filters'),(919283,'watch','.w-filters .input-txt-keywords','width','100','','','.w-filters'),(919284,'watch','.w-filters .input-txt','width','60','','','.w-filters'),(919285,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','width','250','','','.w-image-maps'),(919286,'watch','.w-filters .input-checkbox:not(checked) + .checkbox-span','width','24','','','.w-filters'),(919287,'watch','.w-brands .brands-listing > div','width','16','','','.w-brands'),(919288,'watch','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','width','auto','','','.b-product-images'),(919289,'watch','.b-product-images .media-popup .mp-close','width','100','','','.b-product-images'),(919290,'watch','.b-product-images .media-popup .mp-small-images .item','width','150','','','.b-product-images'),(919291,'watch','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','width','100','','','.b-product-images'),(919292,'watch','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','width','30','','','.b-menu-burger_icon'),(919293,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width','100','','','.b-menu-lev_display-slide'),(919294,'watch','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width','100','','','.b-menu-lev_display-slide'),(919295,'watch','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width','100','','','.b-menu-lev_display-slide'),(919296,'watch','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width','100','','','.b-menu-lev_display-slide'),(919297,'watch','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width','100','','','.b-menu-lev_display-slide'),(919298,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(919299,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(919300,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(919301,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(919302,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(919303,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width','100','','','.b-menu-open_from-left'),(919304,'watch','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(919305,'watch','.b-menu-style-1 .menu-style[data-lev2_display=\"width\"] .level-2 > li','width','300','','','.b-menu-style-1'),(919306,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','width','100','','','.b-menu-style-1'),(919307,'watch','.b-menu-style-1 .menu-style[data-lev2_display=\"width_cont\"] .level-2 > li','width','300','','','.b-menu-style-1'),(919308,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','width','100','','','.b-menu-style-1'),(919309,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .currencies-title','width','40','','','.b-menu-style-2'),(919310,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .burger-icon','width','50','','','.b-menu-style-2'),(919311,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .select img','width','36','','','.b-menu-style-2'),(919312,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-languages .current img','width','40','','','.b-menu-style-2'),(919313,'watch','.b-menu-style-2 .menu-style[data-style=\"2\"] .w-currencies .select-link','width','36','','','.b-menu-style-2'),(919314,'watch','.b-trade-approval .steps-bar','width','100','','','.b-trade-approval'),(919315,'watch','.b-trade-approval .col-right','width','48','','','.b-trade-approval'),(919316,'watch','.b-trade-approval .col-left','width','48','','','.b-trade-approval'),(919317,'watch','.b-trade-approval .col-3','width','31.33','','','.b-trade-approval'),(919318,'watch','.w-account-personal-catalog .list-switcher','width','100','','','.w-account-personal-catalog'),(919319,'watch','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','width','auto','','','.w-catalog-compare'),(919320,'watch','.w-catalog-compare .cross-box .different-all > div','width','50','','','.w-catalog-compare'),(919321,'watch','.w-product-images .produst-image video, .w-product-images .produst-image iframe','width','100','','','.w-product-images'),(919322,'watch','.w-product-images .additional-vertical .produst-image','width','calc(100% - 100px)','','','.w-product-images'),(919323,'watch','.w-product-images .additional-vertical .additional-images','width','100','','','.w-product-images'),(919324,'watch','.w-filters .fsl_handle > div','width','50','','','.w-filters'),(919325,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]','width','0','','','.w-filters'),(919326,'watch','.w-filters .filter-box-content ul li label input[type=\"checkbox\"]:not(checked) + span','width','24','','','.w-filters'),(919349,'watch','.catalog-product-wrap .pn-image','width','24','3','','.catalog-product-wrap'),(919350,'watch','.catalog-product-wrap .prev-next-product','width','190','','','.catalog-product-wrap'),(919351,'watch','.catalog-product-wrap .next-product','width','60','5240','','.catalog-product-wrap'),(919352,'watch','.catalog-product-wrap .prev-product','width','60','5240','','.catalog-product-wrap'),(919353,'watch','.checkout-index-wrap .dob-hide > div','width','48','','','.checkout-index-wrap'),(919354,'watch','.checkout-index-wrap .edit-address-popup','width','1000','','','.checkout-index-wrap'),(919355,'watch','.checkout-index-wrap .edit-address-popup .addresses .address-item','width','33','','','.checkout-index-wrap'),(919356,'watch','.checkout-index-wrap .edit-address-popup .addresses .buttons','width','100','','','.checkout-index-wrap'),(919357,'watch','.checkout-index-wrap .order-summary2 .btn-2','width','100','','','.checkout-index-wrap'),(919358,'watch','.account-order-pay .history_info > div','width','33.3','','','.account-order-pay'),(919359,'watch','.account-order-pay .not_fully_paid_td','width','300','','','.account-order-pay'),(919360,'watch','.account-order-pay .history_info > div','width','100','5240','','.account-order-pay'),(919361,'watch','.account-samples .not_fully_paid_td','width','300','','','.account-samples'),(919362,'watch','.account-samples .orders-table .hidden','width','130','5240','','.account-samples'),(919363,'watch','.account-samples .orders-table .td-alignright','width','100','5240','','.account-samples'),(919364,'watch','.account-sample-info .history_info > div','width','33.3','','','.account-sample-info'),(919365,'watch','.account-sample-info .not_fully_paid_td','width','300','','','.account-sample-info'),(919366,'watch','.account-sample-info .history_info > div','width','100','5240','','.account-sample-info'),(919367,'watch','.checkout-order-confirmation .order-summary2 .btn-2','width','100','','','.checkout-order-confirmation'),(919368,'watch','.checkout-login-wrap .col-left, .checkout-login-wrap .col-right','width','100','','','.checkout-login-wrap'),(919369,'watch','.checkout-login-wrap .middle-form .btn-2','width','100','','','.checkout-login-wrap'),(919370,'watch','.b-form .center-buttons','width','100','','','.b-form'),(919371,'watch','.b-form .password-row','width','100','','','.b-form'),(919372,'watch','.b-form .col-gender','width','100','','','.b-form'),(919373,'watch','.b-slick .slick-dots li','width','10','3','','.b-slick'),(919374,'watch','.hide-page','width','100','','',''),(919375,'watch','.success-page .w-cart-listing .qty','width','24','','','.success-page'),(919376,'watch','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','width','33','','','.b-multi-page-checkout'),(919377,'watch','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','width','35','3','','.b-multi-page-checkout'),(919380,'watch','.w-bestsellers .counter','width','31','','','.w-bestsellers'),(919381,'watch','.w-bestsellers .item','width','31','3','','.w-bestsellers'),(919384,'watch','.accout-box select[data-type=\"vat_number\"]','width','40','','','.accout-box'),(919385,'watch','.w-account-customer-additional-field .field-type-checkbox label','width','40','','','.w-account-customer-additional-field'),(919386,'watch','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width','60','','','.w-account-customer-additional-field'),(919387,'watch','.w-account-customer-additional-field .field-type-text label','width','40','','','.w-account-customer-additional-field'),(919388,'watch','.w-menu-style-1 .menu-ico','width','54','','','.w-menu-style-1'),(919389,'watch','.w-menu-style-1 li','width','auto','','','.w-menu-style-1'),(919390,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','width','40','','','.b-slick'),(919391,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','width','50','5240','','.b-slick'),(919392,'watch','.w-banner .banner-text-holder','width','100','','','.w-banner'),(919393,'watch','.w-banner .carousel-text','width','100','','','.w-banner'),(919394,'watch','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width','100','','','.w-banner'),(919395,'watch','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width','100','','','.w-banner'),(919396,'watch','.w-catalog-paging .paging-holder','width','150','','','.w-catalog-paging'),(919397,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width','30','','','.w-catalog-paging'),(919398,'watch','.b-warehouses-popup .warehouses-popup','width_important','important','','','.b-warehouses-popup'),(919399,'watch','.b-messages .pre_upload','width_important','important','','','.b-messages'),(919400,'watch','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width_important','important','3','','.b-switch'),(919401,'watch','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width_important','important','3','','.b-switch'),(919402,'watch','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width_important','important','','','.b-select-suggest'),(919403,'watch','.w-checkout-credit-amount .cot_gv_amount','width_important','important','','','.w-checkout-credit-amount'),(919404,'watch','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width_important','important','','','.w-coupons-and-vauchers-checkout'),(919405,'watch','.w-cart-credit-amount input[type=\"text\"]','width_important','important','','','.w-cart-credit-amount'),(919406,'watch','.w-product-images .produst-image video, .w-product-images .produst-image iframe','width_important','important','','','.w-product-images'),(919407,'watch','.checkout-index-wrap .edit-address-popup','width_important','important','','','.checkout-index-wrap'),(919410,'watch','.accout-box select[data-type=\"vat_number\"]','width_important','important','','','.accout-box'),(919411,'watch','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width_important','important','','','.w-catalog-paging'),(919412,'watch','.b-form .col-right','width_measure','%','5240','','.b-form'),(919413,'watch','.b-form .login-col-2','width_measure','%','','','.b-form'),(919414,'watch','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(919415,'watch','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(919416,'watch','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(919417,'watch','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(919418,'watch','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(919419,'watch','.order-summary .btn-2, .order-summary .btn-3','width_measure','%','','','.order-summary'),(919420,'watch','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(919421,'watch','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(919422,'watch','.w-promotions .promo-salemaker > div','width_measure','%','','','.w-promotions'),(919423,'watch','.w-promotions .promo-cart-discount > div','width_measure','%','','','.w-promotions'),(919427,'watch','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width_measure','%','','','.p-sample-checkout-login'),(919428,'watch','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(919429,'watch','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(919430,'watch','.w-product-configurator .item-content','width_measure','%','5240','','.w-product-configurator'),(919431,'watch','.w-product-configurator .pc_item','width_measure','%','5240','','.w-product-configurator'),(919432,'watch','.w-promotions .prom-multi-discount .list','width_measure','%','','','.w-promotions'),(919433,'watch','.w-promotions .nextdiscount .item-holder .name','width_measure','%','','','.w-promotions'),(919434,'watch','.w-promotions .nextdiscount .item-holder .image','width_measure','%','','','.w-promotions'),(919435,'watch','.w-promotions .promo-salemaker .item','width_measure','%','','','.w-promotions'),(919436,'watch','.b-preloader .preloader','width_measure','%','','','.b-preloader'),(919437,'watch','.b-products-listing .products-listing .attribute-qty-block','width_measure','%','','','.b-products-listing'),(919438,'watch','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(919439,'watch','.w-cart-continue-btn a','width_measure','%','5232','','.w-cart-continue-btn'),(919440,'watch','.w-cart-checkout-btn ','width_measure','%','5232','','.w-cart-checkout-btn'),(919441,'watch','.b-messages .box-block.type-6 > .block:nth-child(1)','width_measure','%','','','.b-messages'),(919442,'watch','.b-messages .messages-sidebar .btn-2','width_measure','%','','','.b-messages'),(919443,'watch','.b-messages .email-line input','width_measure','%','','','.b-messages'),(919444,'watch','.w-sitemap-delivery-location > ul > li > ul > li','width_measure','%','','','.w-sitemap-delivery-location'),(919445,'watch','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(919446,'watch','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(919447,'watch','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(919448,'watch','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(919449,'watch','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(919450,'watch','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(919451,'watch','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(919452,'watch','.p-payer-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-confirmation'),(919453,'watch','.p-payer-order-confirmation .dob-hide > div','width_measure','%','','','.p-payer-order-confirmation'),(919454,'watch','.p-payer-order-pay .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-pay'),(919455,'watch','.p-payer-order-pay .dob-hide > div','width_measure','%','','','.p-payer-order-pay'),(919456,'watch','.w-checkout-terms .required-message','width_measure','%','','','.w-checkout-terms'),(919457,'watch','.b-form .checkbox-style:checked + .checkbox-span','width_measure','x','','','.b-form'),(919458,'watch','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(919459,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(919460,'watch','.w-upload-customer-id-upload-customer-id-form .dz-details','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(919461,'watch','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(919462,'watch','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(919463,'watch','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(919464,'watch','.w-login-block .input','width_measure','%','','','.w-login-block'),(919465,'watch','.w-login-block .guest','width_measure','%','','','.w-login-block'),(919466,'watch','.w-login-block .new','width_measure','%','','','.w-login-block'),(919467,'watch','.w-login-block .returning','width_measure','%','','','.w-login-block'),(919468,'watch','.w-product-wishlist-button .btn','width_measure','%','5232','','.w-product-wishlist-button'),(919469,'watch','.w-cart-order-total.box','width_measure','%','5232','','.w-cart-order-total'),(919470,'watch','.w-product-configurator .pc_item','width_measure','%','5240','','.w-product-configurator'),(919471,'watch','.w-cart-give-away .ga_attributes select','width_measure','%','','','.w-cart-give-away'),(919472,'watch','.w-categories .item','width_measure','%','5232','','.w-categories'),(919473,'watch','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(919474,'watch','.b-email .totals-title','width_measure','%','','','.b-email'),(919475,'watch','.b-email .totals-table','width_measure','%','','','.b-email'),(919476,'watch','.w-login-block .input','width_measure','%','','','.w-login-block'),(919477,'watch','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(919478,'watch','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(919479,'watch','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(919480,'watch','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(919481,'watch','.w-cart-order-total.box','width_measure','%','5232','','.w-cart-order-total'),(919482,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(919483,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(919484,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(919485,'watch','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(919486,'watch','.b-products-listing .select-attributes .item-title','width_measure','%','','','.b-products-listing'),(919487,'watch','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(919488,'watch','.pop-up-content .buttons .btn','width_measure','%','5240','',''),(919489,'watch','.pop-up-content .buttons .right-buttons','width_measure','%','5240','',''),(919490,'watch','.pop-up-content .buttons .btn-2','width_measure','%','5240','',''),(919491,'watch','.pop-up-content .buttons .left-buttons','width_measure','%','5240','',''),(919492,'watch','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(919493,'watch','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(919494,'watch','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(919495,'watch','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(919496,'watch','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(919497,'watch','.w-product-configurator .item-content','width_measure','%','5240','','.w-product-configurator'),(919498,'watch','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(919499,'watch','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(919500,'watch','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(919501,'watch','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(919502,'watch','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(919503,'watch','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(919504,'watch','.w-login-block .input','width_measure','%','','','.w-login-block'),(919505,'watch','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(919506,'watch','.w-filters .ui-slider','width_measure','%','','','.w-filters'),(919507,'watch','.w-cart-give-away .ga_column','width_measure','%','','','.w-cart-give-away'),(919508,'watch','.w-product-wishlist-button .btn','width_measure','%','5232','','.w-product-wishlist-button'),(919509,'watch','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(919510,'watch','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(919511,'watch','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(919513,'watch','.w-promo-code .promo-text','width_measure','%','5240','','.w-promo-code'),(919514,'watch','.w-tabs .tab-navigation','width_measure','%','','','.w-tabs'),(919515,'watch','.b-products-listing .select-attributes select','width_measure','%','','','.b-products-listing'),(919516,'watch','.w-cart-listing .right-area','width_measure','%','5240','','.w-cart-listing'),(919517,'watch','.p-quick-order-index .all-scroll-div','width_measure','%','','','.p-quick-order-index'),(919518,'watch','.w-cart-order-total.box','width_measure','%','5232','','.w-cart-order-total'),(919519,'watch','.view-all','width_measure','%','3','',''),(919520,'watch','.b-form .columns .col-2','width_measure','%','','','.b-form'),(919521,'watch','.b-email .totals-title','width_measure','%','','','.b-email'),(919522,'watch','.w-cart-checkout-btn a','width_measure','%','5232','','.w-cart-checkout-btn'),(919523,'watch','.w-cart-order-total.box','width_measure','%','5232','','.w-cart-order-total'),(919524,'watch','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(919525,'watch','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(919526,'watch','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(919527,'watch','.w-product-attributes .select','width_measure','%','','','.w-product-attributes'),(919528,'watch','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(919529,'watch','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(919530,'watch','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(919531,'watch','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(919532,'watch','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(919533,'watch','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(919534,'watch','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(919535,'watch','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(919536,'watch','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(919537,'watch','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(919538,'watch','.w-top-categories .item','width_measure','%','','','.w-top-categories'),(919540,'watch','.b-bottom .popup-box.popupCompare','width_measure','%','','','.b-bottom'),(919541,'watch','.w-cart-order-total.box','width_measure','%','5232','','.w-cart-order-total'),(919542,'watch','.w-promo-code .promo-text','width_measure','%','5240','','.w-promo-code'),(919543,'watch','.w-product-configurator .pc_item','width_measure','%','5240','','.w-product-configurator'),(919544,'watch','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(919545,'watch','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(919546,'watch','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(919547,'watch','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(919548,'watch','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(919549,'watch','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(919550,'watch','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(919551,'watch','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(919552,'watch','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(919553,'watch','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(919554,'watch','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(919555,'watch','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(919556,'watch','.b-form .login-col-1','width_measure','%','','','.b-form'),(919557,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(919558,'watch','.b-email .products-table','width_measure','%','','','.b-email'),(919559,'watch','.w-product-properties li','width_measure','%','','','.w-product-properties'),(919560,'watch','.w-product-configurator .item-content','width_measure','%','5240','','.w-product-configurator'),(919561,'watch','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(919562,'watch','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(919563,'watch','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(919564,'watch','.w-list-b2b .select-attributes','width_measure','%','','','.w-list-b2b'),(919565,'watch','.w-product-properties li','width_measure','%','','','.w-product-properties'),(919566,'watch','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(919567,'watch','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(919568,'watch','.w-checkout-shipping-choice label','width_measure','%','','','.w-checkout-shipping-choice'),(919569,'watch','.b-products-listing .btn-choose-options','width_measure','%','','','.b-products-listing'),(919570,'watch','.b-email .products-table','width_measure','%','','','.b-email'),(919571,'watch','.w-checkout-create-account .col-2','width_measure','%','5240','','.w-checkout-create-account'),(919572,'watch','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(919573,'watch','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(919574,'watch','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(919575,'watch','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(919576,'watch','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(919577,'watch','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(919578,'watch','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(919579,'watch','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(919580,'watch','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(919581,'watch','.w-product-wishlist-button .btn','width_measure','%','5232','','.w-product-wishlist-button'),(919582,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(919583,'watch','.b-email .products-table','width_measure','%','','','.b-email'),(919584,'watch','.b-email .totals-title','width_measure','%','','','.b-email'),(919585,'watch','.b-email .totals-value','width_measure','%','','','.b-email'),(919586,'watch','.b-email .totals-table','width_measure','%','','','.b-email'),(919587,'watch','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(919588,'watch','.b-email .products-table','width_measure','%','','','.b-email'),(919589,'watch','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(919590,'watch','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(919591,'watch','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(919592,'watch','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(919593,'watch','.w-product-configurator .item-content','width_measure','%','5240','','.w-product-configurator'),(919594,'watch','.w-cart-continue-btn a','width_measure','%','5232','','.w-cart-continue-btn'),(919595,'watch','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(919596,'watch','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(919597,'watch','.w-promo-code .promo-code-form','width_measure','%','5240','','.w-promo-code'),(919598,'watch','.w-promo-code .promo-text','width_measure','%','5240','','.w-promo-code'),(919599,'watch','.b-form .columns .col-2','width_measure','%','5261','','.b-form'),(919600,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(919601,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(919602,'watch','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(919603,'watch','.w-login-block .input','width_measure','%','','','.w-login-block'),(919604,'watch','.w-login-block .returning','width_measure','%','','','.w-login-block'),(919605,'watch','.w-login-block .new','width_measure','%','','','.w-login-block'),(919606,'watch','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(919607,'watch','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(919608,'watch','.w-login-block .guest','width_measure','%','','','.w-login-block'),(919609,'watch','.b-form .col-left','width_measure','%','','','.b-form'),(919610,'watch','.w-product-configurator .pc_item','width_measure','%','5240','','.w-product-configurator'),(919611,'watch','.w-cart-give-away .ga_attributes > div','width_measure','%','','','.w-cart-give-away'),(919612,'watch','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(919613,'watch','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(919614,'watch','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(919615,'watch','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(919616,'watch','.w-image-maps .svg-wrap svg','width_measure','%','','','.w-image-maps'),(919617,'watch','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width_measure','%','','','.b-form'),(919618,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(919619,'watch','.w-cart-listing .links','width_measure','%','','','.w-cart-listing'),(919620,'watch','.w-login-block .returning','width_measure','%','','','.w-login-block'),(919621,'watch','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(919622,'watch','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(919623,'watch','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(919624,'watch','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(919625,'watch','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(919626,'watch','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(919627,'watch','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(919628,'watch','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(919629,'watch','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(919630,'watch','.w-login-block .guest','width_measure','%','','','.w-login-block'),(919631,'watch','.w-login-block .new','width_measure','%','','','.w-login-block'),(919632,'watch','.w-cart-shipping-estimator .left-area','width_measure','%','','','.w-cart-shipping-estimator'),(919633,'watch','.b-form .col-right','width_measure','%','','','.b-form'),(919634,'watch','.b-email .totals-title','width_measure','%','','','.b-email'),(919635,'watch','.b-email .products-table','width_measure','%','','','.b-email'),(919636,'watch','.b-bottom .cart-options .option-item','width_measure','%','','','.b-bottom'),(919637,'watch','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(919638,'watch','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(919639,'watch','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(919640,'watch','.b-bottom .cart-options .cart-item','width_measure','%','','','.b-bottom'),(919641,'watch','.w-login-block .guest','width_measure','%','','','.w-login-block'),(919642,'watch','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(919643,'watch','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(919644,'watch','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(919645,'watch','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(919646,'watch','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(919647,'watch','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(919648,'watch','.b-email .totals-table','width_measure','%','','','.b-email'),(919649,'watch','.b-email .totals-value','width_measure','%','','','.b-email'),(919650,'watch','.w-promo-code .promo-text','width_measure','%','5240','','.w-promo-code'),(919651,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(919652,'watch','.b-products-listing .products-listing .radio-attributes .item-title','width_measure','%','','','.b-products-listing'),(919653,'watch','.w-login-block .returning','width_measure','%','','','.w-login-block'),(919654,'watch','.w-product-attributes .select','width_measure','%','','','.w-product-attributes'),(919655,'watch','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(919656,'watch','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(919657,'watch','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(919658,'watch','.w-cart-continue-btn a','width_measure','%','5232','','.w-cart-continue-btn'),(919659,'watch','.b-email .totals-value','width_measure','%','','','.b-email'),(919660,'watch','.b-form .col-left','width_measure','%','5240','','.b-form'),(919661,'watch','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(919662,'watch','.b-form .middle-form .dob-input input[type=\"text\"]','width_measure','%','','','.b-form'),(919663,'watch','.w-top-categories .item','width_measure','%','5232','','.w-top-categories'),(919664,'watch','.w-categories .item','width_measure','%','5261','','.w-categories'),(919665,'watch','.w-product-properties li','width_measure','%','','','.w-product-properties'),(919666,'watch','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(919667,'watch','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(919668,'watch','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(919669,'watch','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(919670,'watch','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(919671,'watch','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(919672,'watch','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(919673,'watch','.w-checkout-billing-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-billing-address'),(919674,'watch','.w-checkout-shipping-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-shipping-address'),(919675,'watch','.w-cart-order-total.box','width_measure','%','5232','','.w-cart-order-total'),(919676,'watch','.w-product-wishlist-button .btn','width_measure','%','5232','','.w-product-wishlist-button'),(919677,'watch','.w-cart-continue-btn a','width_measure','%','5232','','.w-cart-continue-btn'),(919678,'watch','.w-promo-code .promo-text','width_measure','%','5240','','.w-promo-code'),(919679,'watch','.w-promo-code .promo-code-form','width_measure','%','5240','','.w-promo-code'),(919680,'watch','.w-product-configurator .pc_item','width_measure','%','5240','','.w-product-configurator'),(919681,'watch','.w-promo-code .promo-text','width_measure','%','5240','','.w-promo-code'),(919682,'watch','.w-checkout-billing-address .addresses .address-item','width_measure','%','','','.w-checkout-billing-address'),(919683,'watch','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(919684,'watch','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(919685,'watch','.b-products-listing .products-listing .buyButton .btn','width_measure','%','','','.b-products-listing'),(919686,'watch','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(919687,'watch','.b-select-suggest .select2-search input','width_measure','%','','','.b-select-suggest'),(919688,'watch','.b-select-suggest .select2-search','width_measure','%','','','.b-select-suggest'),(919689,'watch','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width_measure','%','','','.b-select-suggest'),(919690,'watch','.b-select-suggest .select2-drop','width_measure','%','','','.b-select-suggest'),(919691,'watch','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(919692,'watch','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(919693,'watch','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(919694,'watch','.w-login-block .input','width_measure','%','','','.w-login-block'),(919695,'watch','.w-login-block .new','width_measure','%','','','.w-login-block'),(919696,'watch','.w-product-configurator .item-content','width_measure','%','5240','','.w-product-configurator'),(919697,'watch','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(919698,'watch','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(919699,'watch','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(919700,'watch','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(919701,'watch','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(919702,'watch','.w-login-block .returning','width_measure','%','','','.w-login-block'),(919703,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(919705,'watch','.w-login-block .returning','width_measure','%','','','.w-login-block'),(919706,'watch','.w-product-attributes .select','width_measure','%','','','.w-product-attributes'),(919707,'watch','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(919708,'watch','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(919709,'watch','.w-product-properties li','width_measure','%','','','.w-product-properties'),(919710,'watch','.w-cart-continue-btn a','width_measure','%','5232','','.w-cart-continue-btn'),(919711,'watch','.w-product-wishlist-button .btn','width_measure','%','5232','','.w-product-wishlist-button'),(919712,'watch','.w-account-addresses-list .addsess-suggestion-item','width_measure','%','','','.w-account-addresses-list'),(919713,'watch','.b-products-listing .products-listing a.btn.view-button','width_measure','%','','','.b-products-listing'),(919714,'watch','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(919715,'watch','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(919716,'watch','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(919717,'watch','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(919718,'watch','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(919719,'watch','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(919720,'watch','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(919721,'watch','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(919722,'watch','.b-products-listing .BlockBox.type-14 > .col','width_measure','%','','','.b-products-listing'),(919723,'watch','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(919724,'watch','.b-products-listing .BlockBox.type-15 > .col','width_measure','%','','','.b-products-listing'),(919725,'watch','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(919726,'watch','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(919727,'watch','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(919728,'watch','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(919729,'watch','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(919730,'watch','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(919731,'watch','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(919732,'watch','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(919733,'watch','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(919734,'watch','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(919735,'watch','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(919736,'watch','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(919737,'watch','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(919738,'watch','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(919739,'watch','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(919740,'watch','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(919741,'watch','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(919742,'watch','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(919743,'watch','.b-products-listing .loader','width_measure','%','3','','.b-products-listing'),(919744,'watch','.b-products-listing .products-listing .attribute-qty-block > span','width_measure','%','','','.b-products-listing'),(919745,'watch','.b-products-listing .products-listing .attributes select','width_measure','%','','','.b-products-listing'),(919746,'watch','.b-products-listing .products-listing .btn-buy','width_measure','%','','','.b-products-listing'),(919747,'watch','.b-products-listing .products-listing .item','width_measure','%','','','.b-products-listing'),(919748,'watch','.w-catalog-b2b-add-button ','width_measure','%','','','.w-catalog-b2b-add-button'),(919749,'watch','.b-products-listing .products-listing .qty-input.hidden','width_measure','%','3','','.b-products-listing'),(919750,'watch','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width_measure','%','','','.b-products-listing'),(919752,'watch','.b-products-listing .products-listing .in-cart','width_measure','%','','','.b-products-listing'),(919753,'watch','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(919754,'watch','.b-select-suggest .select2-container','width_measure','%','','','.b-select-suggest'),(919755,'watch','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(919756,'watch','.b-email .totals-table','width_measure','%','','','.b-email'),(919757,'watch','.b-email .totals-value','width_measure','%','','','.b-email'),(919758,'watch','.b-email .totals-title','width_measure','%','','','.b-email'),(919759,'watch','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width_measure','%','','','.b-fancybox'),(919760,'watch','.w-promo-code .promo-code-form','width_measure','%','5240','','.w-promo-code'),(919761,'watch','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(919762,'watch','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(919763,'watch','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(919764,'watch','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(919765,'watch','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(919766,'watch','.w-product-attributes .select','width_measure','%','','','.w-product-attributes'),(919767,'watch','.w-communication-new-topic .middle-form select','width_measure','%','','','.w-communication-new-topic'),(919768,'watch','.b-form .hide-billing-address','width_measure','%','','','.b-form'),(919769,'watch','.b-email .totals-value','width_measure','%','','','.b-email'),(919770,'watch','.b-email .products-table','width_measure','%','','','.b-email'),(919771,'watch','.b-bottom .popup-credit-amount .popup-box','width_measure','%','','','.b-bottom'),(919772,'watch','.w-promo-code .promo-code-form','width_measure','%','5240','','.w-promo-code'),(919773,'watch','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(919774,'watch','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(919775,'watch','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(919776,'watch','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(919777,'watch','.w-login-block .new','width_measure','%','','','.w-login-block'),(919778,'watch','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(919779,'watch','.w-product-configurator .item-content','width_measure','%','5240','','.w-product-configurator'),(919780,'watch','.w-product-configurator .pc_item','width_measure','%','5240','','.w-product-configurator'),(919781,'watch','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(919782,'watch','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(919783,'watch','.b-compare .col-two label','width_measure','%','','','.b-compare'),(919784,'watch','.b-form .addresses .address-item','width_measure','%','','','.b-form'),(919785,'watch','.w-cart-continue-btn a','width_measure','%','5232','','.w-cart-continue-btn'),(919786,'watch','.w-cart-shipping-estimator .right-area','width_measure','%','','','.w-cart-shipping-estimator'),(919787,'watch','.w-cart-listing .right-area','width_measure','%','','','.w-cart-listing'),(919788,'watch','.w-cart-listing .item .remove','width_measure','%','5240','','.w-cart-listing'),(919789,'watch','.w-cart-give-away .ga_img','width_measure','%','','','.w-cart-give-away'),(919790,'watch','.w-cart-give-away .ga_column','width_measure','%','5232','','.w-cart-give-away'),(919791,'watch','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(919792,'watch','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(919793,'watch','.b-fancybox .fancybox-nav','width_measure','%','','','.b-fancybox'),(919794,'watch','.w-promo-code .promo-code-form','width_measure','%','5240','','.w-promo-code'),(919795,'watch','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(919796,'watch','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(919797,'watch','.w-product-properties li','width_measure','%','','','.w-product-properties'),(919798,'watch','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(919799,'watch','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(919800,'watch','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(919801,'watch','.w-product-attributes .select','width_measure','%','','','.w-product-attributes'),(919802,'watch','.w-login-block .input','width_measure','%','','','.w-login-block'),(919803,'watch','.w-login-block .new','width_measure','%','','','.w-login-block'),(919804,'watch','.w-login-block .guest','width_measure','%','','','.w-login-block'),(919805,'watch','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(919806,'watch','.w-checkout-shipping-address .addresses .address-item','width_measure','%','','','.w-checkout-shipping-address'),(919807,'watch','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(919808,'watch','.w-login-block .guest','width_measure','%','','','.w-login-block'),(919809,'watch','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(919810,'watch','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(919811,'watch','.w-filters .handle-from','width_measure','%','','','.w-filters'),(919812,'watch','.w-promo-code .promo-code-form','width_measure','%','5240','','.w-promo-code'),(919813,'watch','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(919814,'watch','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(919815,'watch','.w-filters .handle-to','width_measure','%','','','.w-filters'),(919816,'watch','.w-categories .item','width_measure','%','','','.w-categories'),(919817,'watch','.w-product-properties li','width_measure','%','','','.w-product-properties'),(919818,'watch','.b-compare .col-two select','width_measure','%','','','.b-compare'),(919819,'watch','.b-email .totals-table','width_measure','%','','','.b-email'),(919820,'watch','.b-form .col-3','width_measure','%','','','.b-form'),(919821,'watch','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(919822,'watch','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(919823,'watch','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(919824,'watch','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(919825,'watch','.w-product-attributes .select','width_measure','%','','','.w-product-attributes'),(919826,'watch','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(919827,'watch','textarea','width_measure','%','','',''),(919828,'watch','.w-product-wishlist-button .btn','width_measure','%','5232','','.w-product-wishlist-button'),(919829,'watch','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(919830,'watch','.b-products-listing .products-listing .btn-preloader','width_measure','%','','','.b-products-listing'),(919831,'watch','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(919832,'watch','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(919833,'watch','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(919834,'watch','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(919835,'watch','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(919836,'watch','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width_measure','%','','','.b-form'),(919837,'watch','.b-email .totals-title','width_measure','%','','','.b-email'),(919838,'watch','.b-email .totals-value','width_measure','%','','','.b-email'),(919839,'watch','.b-email .totals-table','width_measure','%','','','.b-email'),(919840,'watch','.w-filters .input-txt-keywords','width_measure','%','','','.w-filters'),(919841,'watch','.w-filters .input-txt','width_measure','%','','','.w-filters'),(919842,'watch','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width_measure','vw','','','.b-menu-lev_display-slide'),(919843,'watch','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width_measure','vw','','','.b-menu-lev_display-slide'),(919844,'watch','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width_measure','vw','','','.b-menu-lev_display-slide'),(919845,'watch','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width_measure','vw','','','.b-menu-lev_display-slide'),(919846,'watch','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width_measure','vw','','','.b-menu-lev_display-slide'),(919847,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_measure','vw','','','.b-menu-open_from-left'),(919848,'watch','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(919849,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > a, .b-menu-style-1 .menu-style[data-style=\"1\"] .level-2 > li > .no-link','width_measure','%','','','.b-menu-style-1'),(919850,'watch','.b-menu-style-1 .menu-style[data-style=\"1\"] .level-3 > li','width_measure','%','','','.b-menu-style-1'),(919851,'watch','.b-trade-approval .steps-bar','width_measure','%','','','.b-trade-approval'),(919852,'watch','.b-trade-approval .col-right','width_measure','%','','','.b-trade-approval'),(919853,'watch','.b-trade-approval .col-left','width_measure','%','','','.b-trade-approval'),(919854,'watch','.b-trade-approval .col-3','width_measure','%','','','.b-trade-approval'),(919855,'watch','.w-account-personal-catalog .list-switcher','width_measure','%','','','.w-account-personal-catalog'),(919856,'watch','.w-catalog-compare .cross-box .different-all > div','width_measure','%','','','.w-catalog-compare'),(919857,'watch','.w-product-images .produst-image video, .w-product-images .produst-image iframe','width_measure','%','','','.w-product-images'),(919858,'watch','.w-filters .fsl_handle > div','width_measure','%','','','.w-filters'),(919859,'watch','.w-cart-discount-coupon input[type=\"text\"]','width_measure','%','','','.w-cart-discount-coupon'),(919873,'watch','.checkout-index-wrap .dob-hide > div','width_measure','%','','','.checkout-index-wrap'),(919874,'watch','.checkout-index-wrap .edit-address-popup .addresses .address-item','width_measure','%','','','.checkout-index-wrap'),(919875,'watch','.checkout-index-wrap .edit-address-popup .addresses .buttons','width_measure','%','','','.checkout-index-wrap'),(919876,'watch','.checkout-index-wrap .order-summary2 .btn-2','width_measure','%','','','.checkout-index-wrap'),(919877,'watch','.account-order-pay .history_info > div','width_measure','%','','','.account-order-pay'),(919878,'watch','.account-order-pay .history_info > div','width_measure','%','5240','','.account-order-pay'),(919879,'watch','.account-samples .orders-table .td-alignright','width_measure','%','5240','','.account-samples'),(919880,'watch','.account-sample-info .history_info > div','width_measure','%','','','.account-sample-info'),(919881,'watch','.account-sample-info .history_info > div','width_measure','%','5240','','.account-sample-info'),(919882,'watch','.checkout-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.checkout-order-confirmation'),(919883,'watch','.checkout-login-wrap .col-left, .checkout-login-wrap .col-right','width_measure','%','','','.checkout-login-wrap'),(919884,'watch','.checkout-login-wrap .middle-form .btn-2','width_measure','%','','','.checkout-login-wrap'),(919885,'watch','.b-form .center-buttons','width_measure','%','','','.b-form'),(919886,'watch','.b-form .password-row','width_measure','%','','','.b-form'),(919887,'watch','.b-form .col-gender','width_measure','%','','','.b-form'),(919888,'watch','.hide-page','width_measure','%','','',''),(919891,'watch','.w-account-customer-additional-field .field-type-checkbox label','width_measure','%','','','.w-account-customer-additional-field'),(919892,'watch','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width_measure','%','','','.w-account-customer-additional-field'),(919893,'watch','.w-account-customer-additional-field .field-type-text label','width_measure','%','','','.w-account-customer-additional-field'),(919894,'watch','.w-banner .banner-text-holder','width_measure','%','','','.w-banner'),(919895,'watch','.w-banner .carousel-text','width_measure','%','','','.w-banner'),(919896,'watch','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width_measure','%','','','.w-banner'),(919897,'watch','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width_measure','%','','','.w-banner'),(919898,'watch','.w-product-images .produst-image video, .w-product-images .produst-image iframe','width_measure_important','important','','','.w-product-images'),(919899,'watch','.b-form .same-address','z-index','80','','','.b-form'),(919900,'watch','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','z-index','-1','','','.b-switch'),(919901,'watch','.b-fancybox .filter-listing-loader','z-index','100000','','','.b-fancybox'),(919902,'watch','.b-fancybox .filter-listing-preloader','z-index','100001','','','.b-fancybox'),(919903,'watch','.w-promotions .prom-multi-discount .promo-range','z-index','1','','','.w-promotions'),(919904,'watch','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(919907,'watch','.p-sample-checkout-success .page-success > div','z-index','1','','','.p-sample-checkout-success'),(919908,'watch','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(919909,'watch','.b-preloader .preloader','z-index','10','','','.b-preloader'),(919910,'watch','.b-messages .messMenuButton span','z-index','1','','','.b-messages'),(919911,'watch','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(919912,'watch','.b-fancybox #fancybox-loading','z-index','8060','','','.b-fancybox'),(919913,'watch','.b-fancybox .fancybox-wrap','z-index','8020','','','.b-fancybox'),(919914,'watch','.w-upload-customer-id-upload-customer-id-form .upload-file','z-index','10','','','.w-upload-customer-id-upload-customer-id-form'),(919915,'watch','.w-menu-horizontal > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-horizontal'),(919916,'watch','.w-menu-horizontal > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-horizontal'),(919917,'watch','.w-menu-horizontal > ul > li > ul > li > ul','z-index','23','','','.w-menu-horizontal'),(919918,'watch','.w-quote .cart-box-link','z-index','1','','','.w-quote'),(919919,'watch','.b-switch .bootstrap-switch','z-index','0','','','.b-switch'),(919921,'watch','.b-info-popup .info-popup div','z-index','1000','','','.b-info-popup'),(919922,'watch','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(919923,'watch','.edit-link','z-index','1','','',''),(919924,'watch','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(919925,'watch','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(919926,'watch','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','z-index','0','','','.b-switch'),(919927,'watch','.b-switch .bootstrap-switch .bootstrap-switch-label','z-index','100','','','.b-switch'),(919928,'watch','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(919929,'watch','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(919930,'watch','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(919931,'watch','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(919932,'watch','.b-fancybox .fancybox-overlay','z-index','8010','','','.b-fancybox'),(919933,'watch','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(919934,'watch','.w-menu-horizontal > ul','z-index','21','','','.w-menu-horizontal'),(919935,'watch','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','z-index','1','','','.b-switch'),(919937,'watch','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(919938,'watch','.w-promotions .promo-cart-discount .slave .condition','z-index','1','','','.w-promotions'),(919939,'watch','.w-menu-horizontal > ul > li > ul','z-index','22','','','.w-menu-horizontal'),(919940,'watch','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(919941,'watch','.b-fancybox .fancybox-close','z-index','8040','','','.b-fancybox'),(919942,'watch','.b-fancybox .fancybox-opened','z-index','8030','','','.b-fancybox'),(919943,'watch','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(919944,'watch','.b-datepicker .datepicker-dropdown','z-index','1000','','','.b-datepicker'),(919945,'watch','.w-quote .cart-box','z-index','100','','','.w-quote'),(919946,'watch','.p-sample-checkout-success .page-success','z-index','-1','','','.p-sample-checkout-success'),(919947,'watch','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','z-index','1','','','.b-switch'),(919948,'watch','.b-select-suggest .select2-search','z-index','10000','','','.b-select-suggest'),(919949,'watch','.b-select-suggest .select2-drop-mask','z-index','9998','','','.b-select-suggest'),(919950,'watch','.b-select-suggest .select2-drop','z-index','9999','','','.b-select-suggest'),(919951,'watch','.w-menu-big li','z-index','20','','','.w-menu-big'),(919952,'watch','.b-bottom .pop-up-close','z-index','1','','','.b-bottom'),(919953,'watch','.w-catalog-b2b-add-button ','z-index','1','','','.w-catalog-b2b-add-button'),(919954,'watch','.b-products-listing .promos-info','z-index','1','','','.b-products-listing'),(919955,'watch','.b-autocomplete .ui-autocomplete','z-index','1000','','','.b-autocomplete'),(919957,'watch','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(919958,'watch','.b-form .form-inputs div.required-message','z-index','1','','','.b-form'),(919959,'watch','.b-fancybox .fancybox-title','z-index','8050','','','.b-fancybox'),(919960,'watch','.b-fancybox .fancybox-title-float-wrap','z-index','8050','','','.b-fancybox'),(919961,'watch','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(919962,'watch','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(919963,'watch','.b-form .eye-password-wrap','z-index','1','','','.b-form'),(919964,'watch','.b-form .eye-password','z-index','1','','','.b-form'),(919965,'watch','.b-form .hide-billing-address','z-index','70','','','.b-form'),(919966,'watch','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(919968,'watch','.b-fancybox .fancybox-nav span','z-index','8040','','','.b-fancybox'),(919969,'watch','.b-fancybox .fancybox-nav','z-index','8040','','','.b-fancybox'),(919970,'watch','.w-menu-big > ul > li > ul','z-index','100','','','.w-menu-big'),(919971,'watch','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','z-index','1000','','','.w-image-maps'),(919972,'watch','.b-product-images .media-popup .mp-close','z-index','1','','','.b-product-images'),(919973,'watch','.b-product-images .mp-shadow, .b-product-images .media-popup','z-index','1000','','','.b-product-images'),(919974,'watch','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(919975,'watch','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(919976,'watch','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(919977,'watch','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(919978,'watch','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(919979,'watch','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(919980,'watch','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(919981,'watch','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(919982,'watch','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(919983,'watch','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(919984,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(919985,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(919986,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(919987,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(919988,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(919989,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(919990,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(919991,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(919992,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(919993,'watch','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(919994,'watch','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','z-index','1000','','','.b-menu-open_from-left'),(919998,'watch','.checkout-success-wrap .page-success','z-index','-1','','','.checkout-success-wrap'),(919999,'watch','.checkout-success-wrap .page-success > div','z-index','1','','','.checkout-success-wrap'),(920001,'watch','.hide-page','z-index','100000','','',''),(920002,'watch','.success-page .page-success > div','z-index','1','','','.success-page'),(920004,'watch','.w-menu-style-1 > ul','z-index','21','','','.w-menu-style-1'),(920005,'watch','.w-menu-style-1 > ul > li > ul','z-index','22','','','.w-menu-style-1'),(920006,'watch','.w-menu-style-1 > ul > li > ul > li > ul','z-index','23','','','.w-menu-style-1'),(920007,'watch','.w-menu-style-1 > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-style-1'),(920008,'watch','.w-menu-style-1 > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-style-1'),(920009,'watch','.b-slick button.slick-prev, .b-slick button.slick-next','z-index','1','','','.b-slick'),(920010,'watch','.w-banner .banner img + img','z-index','-1','','','.w-banner'),(920011,'watch','.w-banner .banner-text','z-index','1','','','.w-banner'),(920012,'printshop','.b-slick .slick-slider','-khtml-user-select','none','','','.b-slick'),(920013,'printshop','.b-fancybox .fancybox-skin','-moz-border-radius','4px','','','.b-fancybox'),(920014,'printshop','.b-fancybox .fancybox-title-float-wrap .child','-moz-border-radius','15px','','','.b-fancybox'),(920015,'printshop','.b-fancybox .fancybox-opened .fancybox-skin','-moz-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(920016,'printshop','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-moz-box-sizing','border-box','','','.b-select-suggest'),(920017,'printshop','.b-rating .glyphicon','-moz-osx-font-smoothing','grayscale','','','.b-rating'),(920018,'printshop','.b-products-listing .hover-box-content','-moz-transform','rotate( 45deg )','3','','.b-products-listing'),(920019,'printshop','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-moz-transform','translate3d(0, 0, 0)','','','.b-slick'),(920020,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-moz-user-select','none','','','.b-select-suggest'),(920021,'printshop','.b-select-suggest .select2-container .select2-choice','-moz-user-select','none','','','.b-select-suggest'),(920022,'printshop','.b-select-suggest .select2-results .select2-result-label','-moz-user-select','none','','','.b-select-suggest'),(920023,'printshop','.b-slick .slick-slider','-moz-user-select','none','','','.b-slick'),(920024,'printshop','.b-slick .slick-slider','-ms-touch-action','pan-y','','','.b-slick'),(920025,'printshop','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(920026,'printshop','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(920027,'printshop','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(920028,'printshop','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(920029,'printshop','.b-products-listing .hover-box-content','-ms-transform','rotate( 45deg )','3','','.b-products-listing'),(920030,'printshop','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-ms-transform','translate3d(0, 0, 0)','','','.b-slick'),(920032,'printshop','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(920033,'printshop','.w-checkout-shipping-choice input:checked + span:before','-ms-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(920034,'printshop','.w-sample .cart-box-link','-ms-transform','rotate(45deg)','4','','.w-sample'),(920035,'printshop','.b-select-suggest .select2-container .select2-choice','-ms-user-select','none','','','.b-select-suggest'),(920036,'printshop','.b-select-suggest .select2-results .select2-result-label','-ms-user-select','none','','','.b-select-suggest'),(920037,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-ms-user-select','none','','','.b-select-suggest'),(920038,'printshop','.b-slick .slick-slider','-ms-user-select','none','','','.b-slick'),(920039,'printshop','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-o-transform','translate3d(0, 0, 0)','','','.b-slick'),(920040,'printshop','.b-fancybox .fancybox-title-float-wrap .child','-webkit-border-radius','15px','','','.b-fancybox'),(920041,'printshop','.b-fancybox .fancybox-skin','-webkit-border-radius','4px','','','.b-fancybox'),(920042,'printshop','.b-fancybox .fancybox-opened .fancybox-skin','-webkit-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(920043,'printshop','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-webkit-box-sizing','border-box','','','.b-select-suggest'),(920044,'printshop','.b-rating .glyphicon','-webkit-font-smoothing','antialiased','','','.b-rating'),(920045,'printshop','.b-fancybox .fancybox-type-iframe .fancybox-inner','-webkit-overflow-scrolling','touch','','','.b-fancybox'),(920046,'printshop','.b-fancybox .fancybox-nav','-webkit-tap-highlight-color','rgba(0,0,0,0)','','','.b-fancybox'),(920047,'printshop','.b-select-suggest .select2-results','-webkit-tap-highlight-color','rgba(0, 0, 0, 0)','','','.b-select-suggest'),(920048,'printshop','.b-slick .slick-slider','-webkit-tap-highlight-color','transparent','','','.b-slick'),(920049,'printshop','.b-select-suggest .select2-container .select2-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(920050,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(920051,'printshop','.b-select-suggest .select2-results .select2-result-label','-webkit-touch-callout','none','','','.b-select-suggest'),(920052,'printshop','.b-slick .slick-slider','-webkit-touch-callout','none','','','.b-slick'),(920053,'printshop','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(920054,'printshop','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(920055,'printshop','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(920056,'printshop','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(920057,'printshop','.b-products-listing .hover-box-content','-webkit-transform','rotate( 45deg )','3','','.b-products-listing'),(920058,'printshop','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-webkit-transform','translate3d(0, 0, 0)','','','.b-slick'),(920060,'printshop','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(920061,'printshop','.w-checkout-shipping-choice input:checked + span:before','-webkit-transform','rotate(45deg)','','','.w-checkout-shipping-choice'),(920062,'printshop','.w-sample .cart-box-link','-webkit-transform','rotate(45deg)','4','','.w-sample'),(920063,'printshop','.b-select-suggest .select2-container .select2-choice','-webkit-user-select','none','','','.b-select-suggest'),(920064,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-user-select','none','','','.b-select-suggest'),(920065,'printshop','.b-select-suggest .select2-results .select2-result-label','-webkit-user-select','none','','','.b-select-suggest'),(920066,'printshop','.b-slick .slick-slider','-webkit-user-select','none','','','.b-slick'),(920067,'printshop','.p-wedding-registry-search .search-form','align-items','center','','','.p-wedding-registry-search'),(920068,'printshop','.w-promotions .promo-cart-discount','align-items','flex-start','','','.w-promotions'),(920069,'printshop','.b-messages .email-line','align-items','center','','','.b-messages'),(920070,'printshop','.p-quick-order-index .quick-order-total','align-items','center','','','.p-quick-order-index'),(920071,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(920072,'printshop','.b-products-listing .select-attributes','align-items','center','','','.b-products-listing'),(920073,'printshop','.order-summary .price-row','align-items','baseline','','','.order-summary'),(920074,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(920075,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(920076,'printshop','.w-personal-gift-status-bar .timeline','align-items','center','','','.w-personal-gift-status-bar'),(920077,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(920078,'printshop','.b-products-listing .products-listing .attribute-qty-block','align-items','center','','','.b-products-listing'),(920079,'printshop','.b-products-listing .promos-info .promo-item','align-items','center','','','.b-products-listing'),(920080,'printshop','.w-taxable form','align-items','center','','','.w-taxable'),(920081,'printshop','.w-cart-listing .item .gift-wrap label','align-items','center','','','.w-cart-listing'),(920082,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(920083,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(920084,'printshop','.b-product-images .media-popup .mp-big-images .item','align-items','center','','','.b-product-images'),(920085,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(920086,'printshop','.w-account-subscription .subscription-variant','align-items','center','','','.w-account-subscription'),(920087,'printshop','.w-catalog-compare .cross-box .different-all','align-items','flex-end','','','.w-catalog-compare'),(920088,'printshop','.w-product-images .img-holder','align-items','center','','','.w-product-images'),(920091,'printshop','.w-quote .cart-box-link','align-items','center','','','.w-quote'),(920092,'printshop','.w-product-images .additional-vertical','align-items','stretch','','','.w-product-images'),(920093,'printshop','.w-files-catalog-widgets-files-catalog .image','align-items','center','','','.w-files-catalog-widgets-files-catalog'),(920094,'printshop','.w-sample .cart-box-link','align-items','center','','','.w-sample'),(920095,'printshop','.w-filters-simple .filter-row','align-items','flex-end','','','.w-filters-simple'),(920096,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(920097,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(920098,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(920099,'printshop','.w-predefined-promotion .promo-cart-discount','align-items','flex-start','','','.w-predefined-promotion'),(920100,'printshop','.w-supplier-purchase-supplier-products .item','align-items','center','','','.w-supplier-purchase-supplier-products'),(920101,'printshop','.w-supplier-purchase-supplier-products .qty_col','align-items','center','','','.w-supplier-purchase-supplier-products'),(920103,'printshop','.tripleLine .banner','align-items','center','5363','','.tripleLine'),(920104,'printshop','.p-payer-order-pay .price-row','align-items','baseline','','','.p-payer-order-pay'),(920105,'printshop','.p-payer-order-confirmation .price-row','align-items','baseline','','','.p-payer-order-confirmation'),(920106,'printshop','.tripleLine .banner-holder','align-items','center','5363','','.tripleLine'),(920108,'printshop','.checkout-order-confirmation .price-row','align-items','baseline','','','.checkout-order-confirmation'),(920109,'printshop','.hide-page','align-items','center','','',''),(920110,'printshop','.success-page .order_totals .price-row','align-items','baseline','','','.success-page'),(920111,'printshop','.success-page .price-row','align-items','baseline','','','.success-page'),(920112,'printshop','.w-checkout-totals .price-row','align-items','center','','','.w-checkout-totals'),(920114,'printshop','.w-account-customer-additional-field .field-type-text','align-items','center','','','.w-account-customer-additional-field'),(920115,'printshop','.w-banner .banner-item.text-bottom-center .banner-text','align-items','end','','','.w-banner'),(920116,'printshop','.w-banner .banner-item.text-bottom-left .banner-text','align-items','end','','','.w-banner'),(920117,'printshop','.w-banner .banner-item.text-bottom-right .banner-text','align-items','end','','','.w-banner'),(920118,'printshop','.w-banner .banner-item.text-middle-center .banner-text','align-items','center','','','.w-banner'),(920119,'printshop','.w-banner .banner-item.text-middle-left .banner-text','align-items','center','','','.w-banner'),(920120,'printshop','.w-banner .banner-item.text-middle-right .banner-text','align-items','center','','','.w-banner'),(920121,'printshop','.w-banner .banner-item.text-top-center .banner-text','align-items','start','','','.w-banner'),(920122,'printshop','.w-banner .banner-item.text-top-left .banner-text','align-items','start','','','.w-banner'),(920123,'printshop','.w-banner .banner-item.text-top-right .banner-text','align-items','start','','','.w-banner'),(920124,'printshop','.w-banner .carousel .bottom-center','align-items','flex-end','','','.w-banner'),(920125,'printshop','.w-banner .carousel .bottom-left','align-items','flex-end','','','.w-banner'),(920126,'printshop','.w-banner .carousel .bottom-right','align-items','flex-end','','','.w-banner'),(920127,'printshop','.w-banner .carousel .middle-center','align-items','center','','','.w-banner'),(920128,'printshop','.w-banner .carousel .middle-left','align-items','center','','','.w-banner'),(920129,'printshop','.w-banner .carousel .middle-right','align-items','center','','','.w-banner'),(920130,'printshop','.w-banner .carousel .top-center','align-items','flex-start','','','.w-banner'),(920131,'printshop','.w-banner .carousel .top-left','align-items','flex-start','','','.w-banner'),(920132,'printshop','.w-banner .carousel .top-right','align-items','flex-start','','','.w-banner'),(920133,'printshop','.w-cart-listing .remove','align-self','center','','','.w-cart-listing'),(920134,'printshop','.w-account-personal-catalog .check-box','align-self','flex-end','5363','','.w-account-personal-catalog'),(920135,'printshop','.b-preloader .preloader','animation','load8 1.5s infinite linear','3','','.b-preloader'),(920136,'printshop','.w-product-customers-activity .customers-activity','animation','customers-activity-show 4s ease-in-out','','','.w-product-customers-activity'),(920137,'printshop','.w-product-customers-activity .customers-activity.closed','animation','customers-activity-hide 2s ease-in-out','','','.w-product-customers-activity'),(920138,'printshop','.b-products-listing .btn-preloader','animation','load8 1.5s infinite linear','3','','.b-products-listing'),(920139,'printshop','.b-products-listing .loader','animation','load8 1.5s infinite linear','4','','.b-products-listing'),(920140,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.p-quick-order-index'),(920141,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(920142,'printshop','.b-fancybox .fancybox-title-float-wrap .child','background','transparent','','','.b-fancybox'),(920143,'printshop','.w-filters .ui-slider','background','none','','','.w-filters'),(920144,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','background','none','','','.b-select-suggest'),(920145,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.p-quick-order-index'),(920146,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(920147,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(920148,'printshop','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','background','none','','','.b-products-listing'),(920149,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(920150,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background','transparent','','','.b-select-suggest'),(920151,'printshop','.b-select-suggest .select2-results .select2-highlighted em','background','transparent','','','.b-select-suggest'),(920152,'printshop','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','background','transparent','','','.b-select-suggest'),(920153,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(920154,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.b-data-table'),(920155,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','background','inherit','','','.w-contact-contacts'),(920156,'printshop','.w-filters .ui-slider-range','background','none','','','.w-filters'),(920157,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.b-data-table'),(920158,'printshop','.w-top-categories .categories h2','background','none','','','.w-top-categories'),(920159,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','background','none','','','.b-product-images'),(920160,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','background','none','','','.w-catalog-compare'),(920161,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','background','none','','','.b-products-listing'),(920162,'printshop','.w-product-personal-catalog-button .btn','background','none','','','.w-product-personal-catalog-button'),(920163,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','background','none','','','.b-products-listing'),(920164,'printshop','.w-product-designer-designer .prodDesignerType','background','none','','','.w-product-designer-designer'),(920165,'printshop','.w-communication-post .btn.refresh','background','none','','','.w-communication-post'),(920166,'printshop','.w-rma-returns-history .column:last-child .title','background','transparent','','','.w-rma-returns-history'),(920167,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','background','none','','','.w-rma-returns-history'),(920168,'printshop','.middleBanner .btn-1','background','none','','','.middleBanner'),(920169,'printshop','.bottomBanner .btn-1','background','none','','','.bottomBanner'),(920170,'printshop','.topBanner .content .btn','background','none','','','.topBanner'),(920171,'printshop','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','background','none','','','.w-promotions-widgets-promotion-icons-desc'),(920172,'printshop','.b-select-suggest .select2-container .select2-choice','background-clip','padding-box','','','.b-select-suggest'),(920173,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','background-clip','padding-box','','','.b-select-suggest'),(920174,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow','background-clip','padding-box','','','.b-select-suggest'),(920175,'printshop','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(920176,'printshop','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(920177,'printshop','.b-fancybox .filter-listing-loader','background-color','$fancybox-bg-1','','','.b-fancybox'),(920178,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','$content-bg-2','','','.p-quick-order-index'),(920179,'printshop','.w-promotions .promo-item','background-color','$content-bg-2','','','.w-promotions'),(920181,'printshop','.testimonials .review','background-color','$content-bg-2','','',''),(920182,'printshop','.w-promotions .prom-multi-discount .promo-range','background-color','$content-bg-1','','','.w-promotions'),(920183,'printshop','.w-promotions .prom-multi-discount .promo-product','background-color','$content-bg-1','','','.w-promotions'),(920184,'printshop','.w-promotions .nextdiscount .promo-for-each','background-color','$content-bg-2','','','.w-promotions'),(920185,'printshop','.w-promotions .nextdiscount .content > div','background-color','$content-bg-1','','','.w-promotions'),(920186,'printshop','.w-promotions .promo-salemaker .item','background-color','$content-bg-1','','','.w-promotions'),(920187,'printshop','.w-promotions .promo-salemaker .discount','background-color','$content-bg-1','','','.w-promotions'),(920188,'printshop','.w-promotions .promo-cart-discount .slave .item','background-color','$content-bg-1','','','.w-promotions'),(920189,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','background-color','$content-bg-1','','','.w-promotions'),(920190,'printshop','.b-preloader .preloader','background-color','$shadow-bg-2','','','.b-preloader'),(920191,'printshop','.w-cart-compare .attributes-cell','background-color','$content-bg-2','','','.w-cart-compare'),(920192,'printshop','.b-messages .msv_history','background-color','$content-bg-2','','','.b-messages'),(920193,'printshop','.b-messages .email-heading','background-color','$content-bg-2','','','.b-messages'),(920194,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','background-color','$content-bg-2','','','.b-messages'),(920195,'printshop','.w-reviews .author','background-color','$content-bg-1','','','.w-reviews'),(920196,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.p-quick-order-index'),(920197,'printshop','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','background-color','$content-bg-2','','','.order-summary'),(920198,'printshop','.b-fancybox .fancybox-close','background-color','$fancybox-bg-1','','','.b-fancybox'),(920199,'printshop','.b-messages .msv_to_cc','background-color','$content-bg-2','','','.b-messages'),(920200,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','background-color','$transparent','3','','.b-switch'),(920201,'printshop','.w-checkout-shipping-choice input:checked + span:before','background-color','$highlight-box-bg-1','','','.w-checkout-shipping-choice'),(920202,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','background-color','$content-bg-2','','','.w-upload-customer-id-upload-customer-id-form'),(920203,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-details','background-color','$content-bg-1','','','.w-upload-customer-id-upload-customer-id-form'),(920204,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','background-color','$switch-nc-bg-1','3','','.b-switch'),(920206,'printshop','.w-menu-horizontal > ul > li > ul > li > ul','background-color','$content-bg-1','','','.w-menu-horizontal'),(920207,'printshop','.b-fancybox .fancybox-title-float-wrap .child','background-color','$fancybox-bg-1','','','.b-fancybox'),(920208,'printshop','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(920209,'printshop','.b-info-popup .info-popup div','background-color','$content-bg-1','','','.b-info-popup'),(920211,'printshop','.w-filters .ui-slider','background-color','$highlight-box-bg-1','','','.w-filters'),(920212,'printshop','.b-switch .candlestick-wrapper .candlestick-bg','background-color','$switch-nc-bg-1','','','.b-switch'),(920213,'printshop','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(920214,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-color','$content-bg-2','','','.b-select-suggest'),(920215,'printshop','.w-reviews .review','background-color','$content-bg-2','','','.w-reviews'),(920217,'printshop','.p-quick-order-index .all-scroll-div','background-color','$highlight-box-bg-1','','','.p-quick-order-index'),(920219,'printshop','.btn-1','background-color','$btn-bg-2','','',''),(920220,'printshop','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(920221,'printshop','.b-fancybox .fancybox-overlay','background-color','$fancybox-bg-1','','','.b-fancybox'),(920222,'printshop','.b-bottom .popup-box.popupCompare','background-color','$content-bg-2','','','.b-bottom'),(920224,'printshop','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(920225,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','background-color','$switch-off-bg-2','','','.b-switch'),(920226,'printshop','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(920227,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','background-color','$transparent','4','','.b-switch'),(920228,'printshop','.b-form .required-message','background-color','$attention-background','','','.b-form'),(920229,'printshop','.b-switch .candlestick-wrapper .candlestick-bg.off','background-color','$switch-off-bg-2','','','.b-switch'),(920230,'printshop','.b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-off','background-color','$switch-off-bg-2','3','','.b-switch'),(920231,'printshop','.b-switch .candlestick-wrapper .candlestick-bg.on','background-color','$switch-on-bg-1','','','.b-switch'),(920232,'printshop','.b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-on','background-color','$switch-off-bg-2','4','','.b-switch'),(920233,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','background-color','$switch-handle-bg-3','','','.b-switch'),(920234,'printshop','.b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-on','background-color','$switch-on-bg-1','4','','.b-switch'),(920235,'printshop','.b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-off','background-color','$switch-on-bg-1','3','','.b-switch'),(920236,'printshop','.w-product-reviews .reviews-list .review','background-color','$content-bg-2','','','.w-product-reviews'),(920237,'printshop','.b-fancybox .fancybox-skin','background-color','$fancybox-bg-1','','','.b-fancybox'),(920238,'printshop','.b-info-popup .info-popup div','background-color','$content-bg-1','3','','.b-info-popup'),(920239,'printshop','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(920240,'printshop','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(920241,'printshop','.btn','background-color','$btn-bg-1','','',''),(920242,'printshop','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(920243,'printshop','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(920244,'printshop','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','background-color','$content-bg-2','','','.b-select-suggest'),(920245,'printshop','.w-personal-gift-status-bar .timeline','background-color','$content-bg-2','','','.w-personal-gift-status-bar'),(920246,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','background-color','$switch-off-bg-2','','','.b-switch'),(920247,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label','background-color','$switch-handle-bg-3','3','','.b-switch'),(920248,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','background-color','$switch-nc-bg-1','4','','.b-switch'),(920249,'printshop','.b-form .hide-billing-address','background-color','$content-bg-1','','','.b-form'),(920250,'printshop','.w-reviews-content .author','background-color','$content-bg-2','','','.w-reviews-content'),(920252,'printshop','.w-personal-gift-status-bar .progress-bar-content','background-color','$highlight-box-bg-1','','','.w-personal-gift-status-bar'),(920253,'printshop','.w-cart-compare .price-cell','background-color','$content-bg-2','','','.w-cart-compare'),(920254,'printshop','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(920255,'printshop','.b-compare .popupCompare .pop-up-content','background-color','$content-bg-2','','','.b-compare'),(920256,'printshop','.w-promotions .promo-cart-discount .master .item','background-color','$content-bg-1','','','.w-promotions'),(920257,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','background-color','$content-bg-1','','','.w-promotions'),(920258,'printshop','.b-bottom .around-pop-up','background-color','$shadow-bg-1','','','.b-bottom'),(920259,'printshop','.w-cart-compare .price-block + .attributes-block .attributes-cell','background-color','$content-bg-1','','','.w-cart-compare'),(920260,'printshop','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(920261,'printshop','.b-bottom .pop-up-content','background-color','$content-bg-1','','','.b-bottom'),(920263,'printshop','.b-bottom .popup-box','background-color','$content-bg-1','','','.b-bottom'),(920264,'printshop','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(920265,'printshop','.w-product-customers-activity .customers-activity','background-color','$content-bg-2','','','.w-product-customers-activity'),(920267,'printshop','.w-checkout-shipping-choice input:checked + span','background-color','$highlight-box-bg-1','','','.w-checkout-shipping-choice'),(920268,'printshop','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(920269,'printshop','.b-autocomplete .ui-autocomplete li','background-color','$content-bg-2','1','','.b-autocomplete'),(920270,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label','background-color','$switch-handle-bg-3','3','','.b-switch'),(920271,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','background-color','$switch-on-bg-1','','','.b-switch'),(920272,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-color','$content-bg-2','','','.b-select-suggest'),(920273,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus','background-color','$content-bg-2','','','.b-select-suggest'),(920274,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color','$content-bg-1','','','.b-select-suggest'),(920275,'printshop','.b-select-suggest .select2-container-multi .select2-choices','background-color','$content-bg-1','','','.b-select-suggest'),(920276,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-color','$content-bg-2','','','.b-select-suggest'),(920277,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-color','$content-bg-2','','','.b-select-suggest'),(920278,'printshop','.b-select-suggest .select2-results .select2-highlighted ul','background-color','$content-bg-1','','','.b-select-suggest'),(920279,'printshop','.b-select-suggest .select2-more-results','background-color','$content-bg-2','','','.b-select-suggest'),(920280,'printshop','.b-select-suggest .select2-more-results.select2-active','background-color','$content-bg-2','','','.b-select-suggest'),(920281,'printshop','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','background-color','$content-bg-2','','','.b-select-suggest'),(920282,'printshop','.b-select-suggest .select2-results .select2-highlighted','background-color','$content-bg-2','','','.b-select-suggest'),(920283,'printshop','.b-select-suggest .select2-results .select2-disabled','background-color','$content-bg-2','','','.b-select-suggest'),(920284,'printshop','.b-select-suggest .select2-results li em','background-color','$content-bg-2','','','.b-select-suggest'),(920285,'printshop','.w-menu-horizontal > ul > li > ul','background-color','$content-bg-1','','','.w-menu-horizontal'),(920286,'printshop','.b-select-suggest .select2-search input','background-color','$content-bg-1','','','.b-select-suggest'),(920287,'printshop','.b-select-suggest .select2-search input.select2-active','background-color','$content-bg-1','','','.b-select-suggest'),(920288,'printshop','.b-select-suggest .select2-drop-mask','background-color','$content-bg-1','','','.b-select-suggest'),(920289,'printshop','.b-select-suggest .select2-drop','background-color','$content-bg-1','','','.b-select-suggest'),(920292,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','$content-bg-2','','','.b-data-table'),(920293,'printshop','.b-products-listing .loader','background-color','$shadow-bg-2','3','','.b-products-listing'),(920294,'printshop','.w-catalog-b2b-add-button ','background-color','$highlight-box-bg-1','','','.w-catalog-b2b-add-button'),(920295,'printshop','.b-products-listing .products-listing .qty-input.hidden','background-color','$content-bg-1','3','','.b-products-listing'),(920296,'printshop','.checkbox input:checked + span','background-color','$checkbox-bg-1','','',''),(920297,'printshop','.checkbox input + span','background-color','$checkbox-bg-1','','',''),(920298,'printshop','.b-autocomplete .ui-autocomplete','background-color','$content-bg-1','','','.b-autocomplete'),(920300,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','background-color','$switch-handle-bg-3','3','','.b-switch'),(920301,'printshop','.b-compare .compare-box-item','background-color','$content-bg-2','','','.b-compare'),(920303,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','background-color','$content-bg-2','','','.w-communication-new-topic'),(920304,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','background-color','$content-bg-2','','','.w-communication-new-topic'),(920305,'printshop','.b-datepicker .datepicker-dropdown','background-color','$content-bg-1','','','.b-datepicker'),(920306,'printshop','.b-bottom .popup-heading','background-color','$content-bg-2','','','.b-bottom'),(920307,'printshop','.w-personal-gift-status-bar .progress-bar','background-color','$content-bg-1','','','.w-personal-gift-status-bar'),(920309,'printshop','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(920310,'printshop','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(920311,'printshop','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(920312,'printshop','.b-compare .vary td','background-color','$content-bg-2','','','.b-compare'),(920314,'printshop','.b-fancybox .fancybox-nav span','background-color','$fancybox-bg-1','','','.b-fancybox'),(920315,'printshop','.w-tabs .tab-a','background-color','$tab-nav-bg-1','2','','.w-tabs'),(920318,'printshop','.w-filters .head-filter-widget','background-color','$highlight-box-bg-1','5342','','.w-filters'),(920319,'printshop','.w-filters .ui-slider-range','background-color','$highlight-box-bg-1','','','.w-filters'),(920320,'printshop','body','background-color','$content-bg-1','','',''),(920321,'printshop','.w-reviews-content .review','background-color','$content-bg-2','','','.w-reviews-content'),(920322,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.b-data-table'),(920323,'printshop','.b-compare .popupCompare table','background-color','$content-bg-1','','','.b-compare'),(920325,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','background-color','$content-bg-1','','','.w-image-maps'),(920326,'printshop','.b-product-images .mp-shadow','background-color','$image-popup-bg-1','','','.b-product-images'),(920327,'printshop','.b-trade-approval .steps-bar','background-color','$content-bg-2','','','.b-trade-approval'),(920328,'printshop','.b-trade-approval .steps-bar li.current a','background-color','$highlight-box-bg-1','','','.b-trade-approval'),(920329,'printshop','.w-account-personal-catalog .list-switcher a','background-color','$content-bg-1','2','','.w-account-personal-catalog'),(920330,'printshop','.w-catalog-compare tr','background-color','$content-bg-2','1','','.w-catalog-compare'),(920331,'printshop','.w-catalog-compare .compare .checkbox input:checked + span','background-color','$content-bg-1','','','.w-catalog-compare'),(920332,'printshop','.w-catalog-compare .compare-fix-bar','background-color','$content-bg-1','','','.w-catalog-compare'),(920333,'printshop','.w-catalog-compare .cross-box .different-all > div','background-color','$content-bg-1','2','','.w-catalog-compare'),(920334,'printshop','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','background-color','$content-bg-1','','','.w-delivery-day'),(920335,'printshop','.w-delivery-day .left-count','background-color','$highlight-box-bg-1','','','.w-delivery-day'),(920336,'printshop','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','background-color','$highlight-box-bg-4','','','.b-cookie-notice'),(920338,'printshop','.tripleBanner .w-html_box','background-color','$content-bg-2','','','.tripleBanner'),(920339,'printshop','.tripleBanner .w-html_box','background-color','$highlight-box-bg-4','3','','.tripleBanner'),(920340,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','background-color','$content-bg-2','','','.b-slick'),(920341,'printshop','.menu-header .burger-icon','background-color','$highlight-box-bg-4','5342','','.menu-header'),(920342,'printshop','.btn-2','background-color','$btn-bg-3','','',''),(920343,'printshop','.w-catalog-listing-look .b2b','background-color','$highlight-box-bg-2','2','','.w-catalog-listing-look'),(920344,'printshop','.w-catalog-listing-look .grid','background-color','$highlight-box-bg-2','2','','.w-catalog-listing-look'),(920345,'printshop','.w-catalog-listing-look .list','background-color','$highlight-box-bg-2','2','','.w-catalog-listing-look'),(920346,'printshop','.LeftCategories ul li a','background-color','$content-bg-2','1','','.LeftCategories'),(920347,'printshop','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','background-color','$content-bg-2','','','.w-filters'),(920348,'printshop','.w-subscribers .btn-submit','background-color','$highlight-box-bg-4','','','.w-subscribers'),(920349,'printshop','.w-quote .cart-box-link','background-color','$highlight-box-bg-4','3','','.w-quote'),(920350,'printshop','.w-quote .cart-content','background-color','$content-bg-1','','','.w-quote'),(920351,'printshop','.w-quote .current-multi-cart.item','background-color','$content-bg-2','','','.w-quote'),(920352,'printshop','.w-quote .multicart a.name','background-color','$content-bg-2','1','','.w-quote'),(920353,'printshop','.w-product-sale-ends .left-count','background-color','$highlight-box-bg-4','','','.w-product-sale-ends'),(920354,'printshop','.w-product-sale-ends .left-count-days','background-color','$content-bg-1','','','.w-product-sale-ends'),(920355,'printshop','.w-product-sale-ends .left-count-hours','background-color','$content-bg-1','','','.w-product-sale-ends'),(920356,'printshop','.w-compare ','background-color','$content-bg-1','','','.w-compare'),(920357,'printshop','.w-files-catalog-widgets-files-catalog .name','background-color','$highlight-box-bg-1','','','.w-files-catalog-widgets-files-catalog'),(920358,'printshop','.w-sample .cart-box-link','background-color','$highlight-box-bg-4','3','','.w-sample'),(920359,'printshop','.w-sample .cart-content','background-color','$content-bg-1','','','.w-sample'),(920360,'printshop','.w-sample .current-multi-cart.item','background-color','$content-bg-2','','','.w-sample'),(920361,'printshop','.w-sample .multicart a.name','background-color','$content-bg-2','1','','.w-sample'),(920362,'printshop','.w-cart-order-reference .btn','background-color','$content-bg-1','','','.w-cart-order-reference'),(920363,'printshop','.w-cart-gift-certificate .btn','background-color','$content-bg-1','','','.w-cart-gift-certificate'),(920364,'printshop','.b-pagination .pagination span','background-color','$highlight-box-bg-2','2','','.b-pagination'),(920365,'printshop','.w-product-properties-filters-widgets-chosen-filters .item','background-color','$highlight-box-bg-4','','','.w-product-properties-filters-widgets-chosen-filters'),(920366,'printshop','.p-sample-checkout-index .order-summary .heading-2','background-color','$content-bg-2','3','','.p-sample-checkout-index'),(920367,'printshop','.p-sample-checkout-index .order-summary .heading-2','background-color','$content-bg-2','4','','.p-sample-checkout-index'),(920368,'printshop','.w-account-personal-catalog .list-row-action ul','background-color','$content-bg-1','','','.w-account-personal-catalog'),(920369,'printshop','.w-delivery-location-location-list .deliveryListParrent a','background-color','$highlight-box-bg-4','','','.w-delivery-location-location-list'),(920370,'printshop','.w-sale-category .badge','background-color','$highlight-box-bg-1','','','.w-sale-category'),(920371,'printshop','.w-sale-category .left-count','background-color','$highlight-box-bg-1','','','.w-sale-category'),(920372,'printshop','.w-sale-category .left-count-days','background-color','$content-bg-1','','','.w-sale-category'),(920373,'printshop','.w-sale-category .left-count-hours','background-color','$content-bg-1','','','.w-sale-category'),(920374,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','background-color','$content-bg-1','','','.w-product-properties-icons'),(920375,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content:before','background-color','$content-bg-1','','','.w-product-properties-icons'),(920376,'printshop','.w-delivery-location-product-categories .name','background-color','$highlight-box-bg-4','','','.w-delivery-location-product-categories'),(920377,'printshop','.w-product-designer-designer .grnamebox .title-sortable','background-color','$highlight-box-bg-4','','','.w-product-designer-designer'),(920378,'printshop','.w-press-reviews-widgets-press-reviews ','background-color','$content-bg-1','','','.w-press-reviews-widgets-press-reviews'),(920379,'printshop','.w-press-reviews-widgets-press-reviews-list .item','background-color','$content-bg-1','','','.w-press-reviews-widgets-press-reviews-list'),(920380,'printshop','.w-support-system-listing .support-head','background-color','$content-bg-2','','','.w-support-system-listing'),(920381,'printshop','.w-support-system-listing .product_icon','background-color','$content-bg-1','','','.w-support-system-listing'),(920382,'printshop','.w-rma-returns-history .column .title','background-color','$highlight-box-bg-1','','','.w-rma-returns-history'),(920383,'printshop','.w-rma-returns-history table.dataTable tbody tr.odd, .w-rma-returns-history table.dataTable.display tbody tr.odd','background-color','$content-bg-2','','','.w-rma-returns-history'),(920384,'printshop','.w-rma-returns-history thead tr','background-color','$highlight-box-bg-1','','','.w-rma-returns-history'),(920385,'printshop','.b-products-listing .promos-info .promo-name-span','background-color','$highlight-box-bg-2','','','.b-products-listing'),(920386,'printshop','.w-predefined-promotion .nextdiscount .content > div','background-color','$content-bg-1','','','.w-predefined-promotion'),(920387,'printshop','.w-predefined-promotion .nextdiscount .promo-for-each','background-color','$content-bg-2','','','.w-predefined-promotion'),(920388,'printshop','.w-predefined-promotion .prom-multi-discount .promo-product','background-color','$content-bg-1','','','.w-predefined-promotion'),(920389,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','background-color','$content-bg-1','','','.w-predefined-promotion'),(920390,'printshop','.w-predefined-promotion .promo-cart-discount .master .item','background-color','$content-bg-1','','','.w-predefined-promotion'),(920391,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','background-color','$content-bg-1','','','.w-predefined-promotion'),(920392,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','background-color','$content-bg-1','','','.w-predefined-promotion'),(920393,'printshop','.w-predefined-promotion .promo-cart-discount .slave .item','background-color','$content-bg-1','','','.w-predefined-promotion'),(920394,'printshop','.w-predefined-promotion .promo-item','background-color','$content-bg-2','','','.w-predefined-promotion'),(920395,'printshop','.w-predefined-promotion .promo-salemaker .discount','background-color','$content-bg-1','','','.w-predefined-promotion'),(920396,'printshop','.w-predefined-promotion .promo-salemaker .item','background-color','$content-bg-1','','','.w-predefined-promotion'),(920399,'printshop','.heading-1','background-color','$content-bg-2','4','',''),(920400,'printshop','h1','background-color','$content-bg-2','4','',''),(920401,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','background-color','$content-bg-1','','','.w-filters'),(920402,'printshop','.cartTitle >div','background-color','$content-bg-2','4','','.cartTitle'),(920403,'printshop','.btn-3','background-color','$btn-bg-4','','',''),(920404,'printshop','.topBanner .ourPick .bottom','background-color','$main-banner-bg-1','','','.topBanner'),(920405,'printshop','.w-cart-discount-coupon .discount-box','background-color','$content-bg-2','','','.w-cart-discount-coupon'),(920406,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','background-color','$highlight-box-bg-2','','','.p-quote-checkout-index'),(920415,'printshop','.account-samples .orders-table th','background-color','$content-bg-2','','','.account-samples'),(920416,'printshop','.account-samples .order_history_table th','background-color','$content-bg-2','','','.account-samples'),(920417,'printshop','.catalog-product-wrap .prev-next-product','background-color','$shadow-bg-2','','','.catalog-product-wrap'),(920418,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','background-color','$highlight-box-bg-2','','','.checkout-index-wrap'),(920419,'printshop','.checkout-index-wrap .hiding-box .checkout-cart-listing','background-color','$content-bg-1','','','.checkout-index-wrap'),(920420,'printshop','.index-wrap .heading-2','background-color','$content-bg-2','4','','.index-wrap'),(920421,'printshop','.index-wrap h2','background-color','$content-bg-2','4','','.index-wrap'),(920422,'printshop','.b-slick .slick-dots li','background-color','$content-bg-2','3','','.b-slick'),(920423,'printshop','.b-slick .slick-dots li.slick-active','background-color','$highlight-box-bg-1','3','','.b-slick'),(920424,'printshop','.hide-page','background-color','$shadow-bg-2','','',''),(920425,'printshop','.success-page .w-cart-listing .qty','background-color','$highlight-box-bg-2','','','.success-page'),(920426,'printshop','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','background-color','$highlight-box-bg-1','','','.b-multi-page-checkout'),(920427,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','background-color','$highlight-box-bg-2','3','','.b-multi-page-checkout'),(920434,'printshop','.w-catalog-paging ','background-color','$highlight-box-bg-2','2','','.w-catalog-paging'),(920437,'printshop','.w-sale .badge','background-color','$highlight-box-bg-1','','','.w-sale'),(920438,'printshop','.w-sale .left-count','background-color','$highlight-box-bg-1','','','.w-sale'),(920439,'printshop','.w-sale .left-count-days','background-color','$content-bg-1','','','.w-sale'),(920440,'printshop','.w-sale .left-count-hours','background-color','$content-bg-1','','','.w-sale'),(920441,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.p-quick-order-index'),(920442,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color_important','important','','','.b-select-suggest'),(920443,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.b-data-table'),(920444,'printshop','.b-select-suggest .select2-container .select2-choice abbr','background-image','url(\'\')','','','.b-select-suggest'),(920445,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-image','none','','','.b-select-suggest'),(920446,'printshop','.b-select-suggest .select2-search input','background-image','url(\'\')','','','.b-select-suggest'),(920447,'printshop','.b-select-suggest .select2-more-results.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(920448,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(920449,'printshop','.b-select-suggest .select2-search input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(920450,'printshop','.b-select-suggest .select2-search-choice-close','background-image','url(\'\')','','','.b-select-suggest'),(920451,'printshop','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-image','url(\'\')','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(920452,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-image','none','','','.b-select-suggest'),(920453,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-image','none','','','.b-select-suggest'),(920454,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-image','none','','','.b-select-suggest'),(920455,'printshop','.b-select-suggest .select2-results li','background-image','none','','','.b-select-suggest'),(920456,'printshop','.p-wedding-registry-search .main-content','background-image','url(\'\')','','','.p-wedding-registry-search'),(920460,'printshop','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.account-order-pay'),(920461,'printshop','.account-samples .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.account-samples'),(920462,'printshop','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.account-sample-info'),(920463,'printshop','.b-select-suggest .select2-search input','background-position','100% -21px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(920464,'printshop','.b-select-suggest .select2-container .select2-choice abbr','background-position','right -11px','1','','.b-select-suggest'),(920465,'printshop','.w-top-categories .image','background-position','50% 50%','','','.w-top-categories'),(920466,'printshop','.p-wedding-registry-search .main-content','background-position','50% 0','','','.p-wedding-registry-search'),(920467,'printshop','.b-select-suggest .select2-container .select2-choice abbr','background-position','top right','','','.b-select-suggest'),(920468,'printshop','.w-categories .image','background-position','50% 50%','','','.w-categories'),(920469,'printshop','.b-select-suggest .select2-search input','background-position','100% -22px','','','.b-select-suggest'),(920470,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close','background-position','right -11px','','','.b-select-suggest'),(920471,'printshop','.b-select-suggest .select2-search-choice-close','background-position','top right','','','.b-select-suggest'),(920472,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close','background-position','right -11px','1','','.b-select-suggest'),(920473,'printshop','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow b','background-position','-18px 1px','','','.b-select-suggest'),(920474,'printshop','.tripleBanner .w-html_box','background-position','50% 50%','3','','.tripleBanner'),(920475,'printshop','.bottomBanner .icon-box > div','background-position-x','center','3','','.bottomBanner'),(920476,'printshop','.b-select-suggest .select2-search input','background-position_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(920477,'printshop','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(920478,'printshop','.p-wedding-registry-search .main-content','background-repeat','no-repeat','','','.p-wedding-registry-search'),(920479,'printshop','.b-select-suggest .select2-container .select2-choice abbr','background-repeat','no-repeat','','','.b-select-suggest'),(920480,'printshop','.b-select-suggest .select2-search-choice-close','background-repeat','no-repeat','','','.b-select-suggest'),(920481,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(920482,'printshop','.b-select-suggest .select2-more-results.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(920483,'printshop','.b-select-suggest .select2-search input','background-repeat','no-repeat','','','.b-select-suggest'),(920484,'printshop','.b-select-suggest .select2-search input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(920485,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','','.b-select-suggest'),(920486,'printshop','.tripleBanner .w-html_box','background-repeat','no-repeat','3','','.tripleBanner'),(920487,'printshop','.bottomBanner .icon-box > div','background-repeat','no-repeat','3','','.bottomBanner'),(920488,'printshop','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(920489,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat_important','important','','','.b-select-suggest'),(920490,'printshop','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size','60px 40px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(920491,'printshop','.w-top-categories .image','background-size','cover','','','.w-top-categories'),(920492,'printshop','.w-categories .image','background-size','cover','','','.w-categories'),(920493,'printshop','.bottomBanner .icon-box > div','background-size','50%','5347,3','','.bottomBanner'),(920494,'printshop','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(920495,'printshop','.tripleBanner .returns.w-html_box','background_image','themes/printshop/img/returns.webp','3','','.tripleBanner'),(920496,'printshop','.tripleBanner .warranty.w-html_box','background_image','themes/printshop/img/warranty.webp','3','','.tripleBanner'),(920497,'printshop','.tripleBanner .track.w-html_box','background_image','themes/printshop/img/track.webp','3','','.tripleBanner'),(920498,'printshop','.warrantyProduct .warranty','background_image','themes/printshop/img/calendar.webp','3','','.warrantyProduct'),(920499,'printshop','.warrantyProduct .delivery','background_image','themes/printshop/img/wallet.webp','3','','.warrantyProduct'),(920500,'printshop','.bottomBanner .icon-box > div.copy','background_image','themes/printshop/img/copy.png','3','','.bottomBanner'),(920501,'printshop','.bottomBanner .icon-box > div.fax','background_image','themes/printshop/img/fax.png','3','','.bottomBanner'),(920502,'printshop','.bottomBanner .icon-box > div.print','background_image','themes/printshop/img/print.png','3','','.bottomBanner'),(920503,'printshop','.bottomBanner .icon-box > div.scan','background_image','themes/printshop/img/scan.png','3','','.bottomBanner'),(920504,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.p-quick-order-index'),(920505,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background_important','important','','','.b-select-suggest'),(920506,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.b-data-table'),(920507,'printshop','.w-product-designer-designer .prodDesignerType','background_important','important','','','.w-product-designer-designer'),(920508,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','background_important','important','','','.w-rma-returns-history'),(920509,'printshop','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(920510,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','1','','.p-quick-order-index'),(920511,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.p-quick-order-index'),(920512,'printshop','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(920513,'printshop','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(920514,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(920515,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.p-quick-order-index'),(920516,'printshop','.b-messages .select2-container-multi input.select2-input','border','none','','','.b-messages'),(920517,'printshop','.b-messages .emailLineTextArea textarea','border','none','','','.b-messages'),(920518,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border','none','3','','.b-switch'),(920519,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(920520,'printshop','.b-switch .candlestick-wrapper .candlestick-bg','border','none','','','.b-switch'),(920521,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(920522,'printshop','.b-autocomplete .ui-autocomplete li','border','none','','','.b-autocomplete'),(920523,'printshop','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(920524,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(920525,'printshop','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(920526,'printshop','.w-cart-cart-tabs .w-tabs > .block','border','none','','','.w-cart-cart-tabs'),(920527,'printshop','.b-bottom .popup-box.popupCompare','border','none','','','.b-bottom'),(920528,'printshop','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(920529,'printshop','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(920530,'printshop','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(920531,'printshop','.w-top-categories .categories h2','border','none','','','.w-top-categories'),(920532,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border','none','4','','.b-switch'),(920533,'printshop','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(920534,'printshop','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(920535,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border','none','','','.b-switch'),(920536,'printshop','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(920537,'printshop','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(920538,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(920539,'printshop','.b-form .checkbox-style','border','none','','','.b-form'),(920540,'printshop','.b-sub-totals .historyTotal table','border','none','','','.b-sub-totals'),(920541,'printshop','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(920542,'printshop','.b-bottom .cart-options .heading-4','border','none','','','.b-bottom'),(920543,'printshop','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(920544,'printshop','.b-products-listing .products-listing .wishlistButton .checkbox input + span','border','none','','','.b-products-listing'),(920545,'printshop','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','border','none','','','.b-products-listing'),(920546,'printshop','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(920547,'printshop','.b-compare .compare-head','border','none','','','.b-compare'),(920548,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.p-quick-order-index'),(920549,'printshop','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(920550,'printshop','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(920551,'printshop','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(920552,'printshop','.w-contact-contacts table td','border','none','','','.w-contact-contacts'),(920553,'printshop','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(920554,'printshop','.b-sub-totals .historyTotal td','border','none','','','.b-sub-totals'),(920555,'printshop','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(920556,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.b-data-table'),(920557,'printshop','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(920558,'printshop','.w-checkout-gdpr .privacy-row','border','none','','','.w-checkout-gdpr'),(920559,'printshop','.b-autocomplete .ui-autocomplete li','border','none','1','','.b-autocomplete'),(920560,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','border','none','','','.w-communication-new-topic'),(920561,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','border','none','','','.w-communication-new-topic'),(920562,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','border','none','','','.w-communication-new-topic'),(920563,'printshop','.w-contact-contacts table','border','none','','','.w-contact-contacts'),(920564,'printshop','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(920565,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','border','none','','','.w-contact-contacts'),(920566,'printshop','.w-filters .input-checkbox','border','none','','','.w-filters'),(920567,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','border','none','','',''),(920568,'printshop','.b-data-table table.dataTable thead td','border','none','','','.b-data-table'),(920569,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.b-data-table'),(920570,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.b-data-table'),(920571,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border','none','','','.b-product-images'),(920572,'printshop','.b-trade-approval .w-login-block .heading-3','border','none','','','.b-trade-approval'),(920573,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','border','none','','','.w-catalog-compare'),(920574,'printshop','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','border','none','','','.b-cookie-notice'),(920575,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','border','none','','','.b-slick'),(920576,'printshop','.b-bottom div + .info','border','none','','','.b-bottom'),(920577,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','border','none','','','.b-products-listing'),(920578,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','border','none','','','.w-rma-returns-history'),(920579,'printshop','.b-quantity .qty-box input[type=\"text\"]','border','none','','','.b-quantity'),(920580,'printshop','.w-cart-cart-tabs .w-tabs .tab-li','border','none','2','','.w-cart-cart-tabs'),(920581,'printshop','.order-summary .w-cart-listing .headings','border','none','','','.order-summary'),(920582,'printshop','.order-summary .w-cart-listing .item','border','none','','','.order-summary'),(920583,'printshop','.w-quote-products .w-cart-listing .item .gift-wrap label','border','none','','','.w-quote-products'),(920587,'printshop','.account-samples .orders-table tr:first-child','border','none','','','.account-samples'),(920588,'printshop','.w-promotions .heading-3','border-bottom','none','','','.w-promotions'),(920589,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable.no-footer','border-bottom','none','','','.b-messages'),(920590,'printshop','.w-cart-shipping-estimator .addresses','border-bottom','none','','','.w-cart-shipping-estimator'),(920591,'printshop','.w-account-personal-catalog .list-switcher a','border-bottom','none','2','','.w-account-personal-catalog'),(920592,'printshop','.w-catalog-compare .cross-box .different-all > div','border-bottom','none','2','','.w-catalog-compare'),(920593,'printshop','.w-tabs .tab-li','border-bottom','none','2','','.w-tabs'),(920594,'printshop','.w-predefined-promotion .heading-3','border-bottom','none','','','.w-predefined-promotion'),(920595,'printshop','.w-filters .filter-widget-horizontal .filter-box-head','border-bottom','none','','','.w-filters'),(920597,'printshop','.b-upload-file .upload-file-template','border-bottom-color','$content-border-3','','','.b-upload-file'),(920598,'printshop','.w-promotions .prom-multi-discount .promo-range','border-bottom-color','$attention-border','','','.w-promotions'),(920599,'printshop','.w-promo-code .holder','border-bottom-color','$content-border-3','','','.w-promo-code'),(920601,'printshop','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-3','','','.b-dropdown'),(920602,'printshop','.testimonials .review','border-bottom-color','$transparent','3','',''),(920603,'printshop','.w-promotions .promo-salemaker .discount','border-bottom-color','$warning-border','','','.w-promotions'),(920604,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-color','$attention-border','','','.w-promotions'),(920605,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-color','$attention-border','','','.w-promotions'),(920606,'printshop','.w-cart-give-away .ga_column','border-bottom-color','$content-border-3','','','.w-cart-give-away'),(920607,'printshop','.w-cart-compare .cart-cell > div','border-bottom-color','$content-border-3','','','.w-cart-compare'),(920608,'printshop','.b-messages .msv_btn','border-bottom-color','$content-border-3','','','.b-messages'),(920609,'printshop','.b-messages .content_management_attach button','border-bottom-color','$highlight-box-border-1','','','.b-messages'),(920610,'printshop','.b-messages .content_management_attach','border-bottom-color','$content-border-3','','','.b-messages'),(920611,'printshop','.b-messages .email-heading','border-bottom-color','$content-border-3','','','.b-messages'),(920612,'printshop','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-color','$content-border-3','','','.b-messages'),(920613,'printshop','.b-messages .msv_to_cc','border-bottom-color','$content-border-3','','','.b-messages'),(920614,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-color','$content-border-3','','','.b-messages'),(920615,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-bottom-color','$content-border-1','','',''),(920616,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-color','$content-border-3','','','.b-messages'),(920617,'printshop','.b-messages .dataTables_wrapper > .bottom','border-bottom-color','$content-border-3','','','.b-messages'),(920618,'printshop','.w-socials > li','border-bottom-color','$content-border-3','','','.w-socials'),(920619,'printshop','.w-product-reviews .reviews-list .review','border-bottom-color','$transparent','3','','.w-product-reviews'),(920620,'printshop','.b-form .required-error','border-bottom-color','$attention-border','','','.b-form'),(920621,'printshop','.b-upload-file .snapshot','border-bottom-color','$content-border-1','','','.b-upload-file'),(920622,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-color','$switch-nc-border-1','','','.b-switch'),(920623,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(920624,'printshop','.w-filters .filter-box-head','border-bottom-color','$content-border-3','','','.w-filters'),(920625,'printshop','.b-upload-file .upload-file-template div','border-bottom-color','$content-border-3','','','.b-upload-file'),(920626,'printshop','.w-checkout-shipping-choice span','border-bottom-color','$highlight-box-border-1','','','.w-checkout-shipping-choice'),(920627,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-color','$content-border-3','','','.b-select-suggest'),(920628,'printshop','.w-socials > li','border-bottom-color','$content-border-3','','','.w-socials'),(920629,'printshop','.b-info-popup .info-popup div','border-bottom-color','$content-border-3','','','.b-info-popup'),(920630,'printshop','.w-promo-code .holder','border-bottom-color','$content-border-3','','','.w-promo-code'),(920631,'printshop','.w-tabs > .block','border-bottom-color','$tab-content-border-1','','','.w-tabs'),(920632,'printshop','.w-tabs .accordion-heading','border-bottom-color','$tab-nav-border-1','2','','.w-tabs'),(920633,'printshop','.w-socials > li','border-bottom-color','$content-border-3','','','.w-socials'),(920634,'printshop','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-3','','','.b-dropdown'),(920635,'printshop','.w-cart-compare .compare-table','border-bottom-color','$content-border-3','','','.w-cart-compare'),(920636,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-color','$switch-handle-bg-3','','','.b-switch'),(920637,'printshop','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-3','','','.b-dropdown'),(920638,'printshop','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-3','','','.b-dropdown'),(920639,'printshop','.w-socials > li','border-bottom-color','$content-border-3','','','.w-socials'),(920640,'printshop','.w-socials > li','border-bottom-color','$content-border-3','','','.w-socials'),(920641,'printshop','.w-reviews-content .review','border-bottom-color','$content-border-3','3','','.w-reviews-content'),(920642,'printshop','.w-promo-code .holder','border-bottom-color','$content-border-3','','','.w-promo-code'),(920643,'printshop','.b-select-suggest .select2-container.select2-drop-above .select2-choice','border-bottom-color','$content-border-3','','','.b-select-suggest'),(920644,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-color','$switch-nc-border-1','4','','.b-switch'),(920646,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-color','$checkbox-border-1','3','','.b-form'),(920647,'printshop','.w-cart-products .checkout-attention-message','border-bottom-color','$attention-border','','','.w-cart-products'),(920648,'printshop','.w-cart-products .checkout-attention-message','border-bottom-color','$attention-border','','','.w-cart-products'),(920649,'printshop','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-bottom-color','$content-border-3','','','.b-bottom'),(920650,'printshop','.w-socials > li','border-bottom-color','$content-border-3','','','.w-socials'),(920651,'printshop','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-bottom-color','$content-bg-1','','','.b-bottom'),(920652,'printshop','textarea','border-bottom-color','$content-border-1','','',''),(920653,'printshop','.b-bottom .popup-box','border-bottom-color','$content-border-3','','','.b-bottom'),(920654,'printshop','.w-product-customers-activity .customers-activity','border-bottom-color','$content-border-3','','','.w-product-customers-activity'),(920655,'printshop','.w-tabs .accordion-heading','border-bottom-color','$tab-nav-border-2','','','.w-tabs'),(920656,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-color','$content-border-3','','','.b-select-suggest'),(920657,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-color','$content-border-3','','','.b-select-suggest'),(920658,'printshop','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-color','$content-border-3','','','.b-select-suggest'),(920659,'printshop','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-color','$content-border-3','','','.b-select-suggest'),(920660,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-color','$content-border-3','','','.b-select-suggest'),(920661,'printshop','.b-select-suggest .select2-dropdown-open .select2-choice','border-bottom-color','$transparent','','','.b-select-suggest'),(920662,'printshop','.b-select-suggest .select2-drop-active','border-bottom-color','$content-border-3','','','.b-select-suggest'),(920663,'printshop','.b-select-suggest .select2-drop','border-bottom-color','$content-border-3','','','.b-select-suggest'),(920664,'printshop','.w-cart-products .checkout-attention-message','border-bottom-color','$attention-border','','','.w-cart-products'),(920665,'printshop','.w-promo-code .holder','border-bottom-color','$content-border-3','','','.w-promo-code'),(920666,'printshop','.b-form input.required-error','border-bottom-color','$attention-border','','','.b-form'),(920667,'printshop','.w-communication-post .communication-post','border-bottom-color','$content-border-3','','','.w-communication-post'),(920668,'printshop','.checkbox input + span','border-bottom-color','$checkbox-border-1','','',''),(920669,'printshop','.checkbox input:checked + span','border-bottom-color','$checkbox-border-1','','',''),(920670,'printshop','.b-autocomplete .ui-autocomplete','border-bottom-color','$content-border-3','','','.b-autocomplete'),(920673,'printshop','.w-promo-code .holder','border-bottom-color','$content-border-3','','','.w-promo-code'),(920674,'printshop','.b-select-suggest .select2-container .select2-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(920675,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-color','$switch-nc-border-1','3','','.b-switch'),(920676,'printshop','.w-reviews .review','border-bottom-color','$content-bg-2','3','','.w-reviews'),(920677,'printshop','.w-reviews-content .item','border-bottom-color','$content-border-3','','','.w-reviews-content'),(920678,'printshop','.b-upload-files .upload-files','border-bottom-color','$content-border-3','','','.b-upload-files'),(920679,'printshop','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-3','','','.b-dropdown'),(920680,'printshop','.w-reviews .item','border-bottom-color','$content-border-3','','','.w-reviews'),(920681,'printshop','.w-promo-code .holder','border-bottom-color','$content-border-3','','','.w-promo-code'),(920682,'printshop','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-3','','','.b-dropdown'),(920683,'printshop','.b-select-suggest .select2-search input','border-bottom-color','$content-border-3','','','.b-select-suggest'),(920684,'printshop','.w-cart-products .checkout-attention-message','border-bottom-color','$attention-border','','','.w-cart-products'),(920685,'printshop','.w-cart-listing .item .gift-wrap label','border-bottom-color','$content-border-3','','','.w-cart-listing'),(920686,'printshop','.w-cart-listing .item','border-bottom-color','$content-border-3','5342','','.w-cart-listing'),(920688,'printshop','.w-cart-products .checkout-attention-message','border-bottom-color','$attention-border','','','.w-cart-products'),(920689,'printshop','.b-data-table table.dataTable.no-footer','border-bottom-color','$content-border-3','','','.b-data-table'),(920690,'printshop','.w-cart-products .checkout-attention-message','border-bottom-color','$attention-border','','','.w-cart-products'),(920691,'printshop','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-color','$content-border-1','','','.b-compare'),(920692,'printshop','.b-compare .compare_pagination','border-bottom-color','$content-border-3','','','.b-compare'),(920693,'printshop','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-bottom-color','$image-popup-border-1','','','.b-product-images'),(920694,'printshop','.b-trade-approval .orders-table th','border-bottom-color','$content-border-3','','','.b-trade-approval'),(920695,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-color','$content-border-3','','','.b-trade-approval'),(920696,'printshop','.w-account-personal-catalog .list-switcher a','border-bottom-color','$content-border-3','','','.w-account-personal-catalog'),(920697,'printshop','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-color','$content-bg-1','','','.w-catalog-compare'),(920698,'printshop','.w-catalog-compare .cross-box .different-all > div','border-bottom-color','$content-border-3','','','.w-catalog-compare'),(920699,'printshop','.w-delivery-day .left-text-left','border-bottom-color','$content-border-3','','','.w-delivery-day'),(920700,'printshop','.w-delivery-day .left-text-right','border-bottom-color','$content-border-3','','','.w-delivery-day'),(920702,'printshop','.w-filters .filter-widget','border-bottom-color','$content-border-3','','','.w-filters'),(920703,'printshop','.w-quote .cart-content','border-bottom-color','$content-border-3','','','.w-quote'),(920704,'printshop','.w-quote .cart-total','border-bottom-color','$content-border-3','','','.w-quote'),(920705,'printshop','.w-quote .multicart .item','border-bottom-color','$content-border-3','','','.w-quote'),(920706,'printshop','.b-product-images .additional-images .active img','border-bottom-color','$image-popup-border-2','','','.b-product-images'),(920707,'printshop','.b-product-images .additional-images img','border-bottom-color','$image-popup-border-1','','','.b-product-images'),(920708,'printshop','.w-product-sale-ends .left-text-left','border-bottom-color','$content-border-1','','','.w-product-sale-ends'),(920709,'printshop','.w-product-sale-ends .left-text-right','border-bottom-color','$content-border-1','','','.w-product-sale-ends'),(920710,'printshop','.w-product-quantity .qty_packs .qty-input','border-bottom-color','$content-border-3','','','.w-product-quantity'),(920711,'printshop','.warrantyProduct .warranty, .warrantyProduct .delivery','border-bottom-color','$content-border-3','','','.warrantyProduct'),(920712,'printshop','.w-sample .cart-box-link','border-bottom-color','$highlight-box-border-1','4','','.w-sample'),(920713,'printshop','.w-sample .cart-content','border-bottom-color','$content-border-3','','','.w-sample'),(920714,'printshop','.w-sample .cart-total','border-bottom-color','$content-border-3','','','.w-sample'),(920715,'printshop','.w-sample .multicart .item','border-bottom-color','$content-border-3','','','.w-sample'),(920716,'printshop','.w-product-video .item img, .w-product-video .item video','border-bottom-color','$content-border-1','','','.w-product-video'),(920717,'printshop','.w-product-video .item.active img, .w-product-video .item.active video','border-bottom-color','$warning-border','','','.w-product-video'),(920718,'printshop','.shipping-ico .heading-3','border-bottom-color','$content-border-3','','','.shipping-ico'),(920719,'printshop','.w-cart-order-reference .btn','border-bottom-color','$highlight-box-border-1','','','.w-cart-order-reference'),(920720,'printshop','.w-cart-gift-certificate .btn','border-bottom-color','$highlight-box-border-1','','','.w-cart-gift-certificate'),(920722,'printshop','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-bottom-color','$highlight-box-border-2','','','.b-pagination'),(920723,'printshop','.b-pagination .pagination .next-pages','border-bottom-color','$content-border-3','','','.b-pagination'),(920724,'printshop','.b-pagination .pagination .page-number','border-bottom-color','$content-border-3','','','.b-pagination'),(920725,'printshop','.b-pagination .pagination .prev-pages','border-bottom-color','$content-border-3','','','.b-pagination'),(920726,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-bottom-color','$content-border-3','','','.b-pagination'),(920727,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-bottom-color','$content-border-3','','','.b-pagination'),(920728,'printshop','.b-pagination .pagination span','border-bottom-color','$highlight-box-border-2','2','','.b-pagination'),(920729,'printshop','.w-product-multi-inventory .radio-attributes','border-bottom-color','$content-border-3','','','.w-product-multi-inventory'),(920730,'printshop','.w-product-multi-inventory .radio-attributes .option-item','border-bottom-color','$content-border-3','','','.w-product-multi-inventory'),(920731,'printshop','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-bottom-color','$highlight-box-border-1','','','.w-product-multi-inventory'),(920732,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-bottom-color','$content-border-3','','','.w-account-personal-catalog'),(920733,'printshop','.w-account-personal-catalog .list-row-action ul','border-bottom-color','$content-border-3','','','.w-account-personal-catalog'),(920734,'printshop','.b-products-listing .products-listing .radio-attributes','border-bottom-color','$content-border-3','','','.b-products-listing'),(920735,'printshop','.b-products-listing .products-listing .radio-attributes .option','border-bottom-color','$content-border-3','','','.b-products-listing'),(920736,'printshop','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-bottom-color','$highlight-box-border-1','','','.b-products-listing'),(920737,'printshop','.w-product-attributes .radio-attributes','border-bottom-color','$content-border-3','','','.w-product-attributes'),(920738,'printshop','.w-product-attributes .radio-attributes .option-item','border-bottom-color','$content-border-3','','','.w-product-attributes'),(920739,'printshop','.w-product-attributes .radio-attributes input:checked + .option-item','border-bottom-color','$highlight-box-border-1','','','.w-product-attributes'),(920740,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(920741,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-bottom-color','$attention-border','','','.w-questionnaire-widgets-questionnaire'),(920742,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-bottom-color','$message-border','','','.w-questionnaire-widgets-questionnaire'),(920743,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-bottom-color','$attention-border','1','','.w-questionnaire-widgets-questionnaire'),(920744,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-bottom-color','$message-border','1','','.w-questionnaire-widgets-questionnaire'),(920745,'printshop','.w-product-groups .radioBox label .containerBlock','border-bottom-color','$content-border-3','','','.w-product-groups'),(920746,'printshop','.w-product-groups .radioBox label .containerBlock.selected','border-bottom-color','$highlight-box-border-2','','','.w-product-groups'),(920747,'printshop','.w-product-groups .radioBox label input:checked + .containerBlock','border-bottom-color','$highlight-box-border-2','','','.w-product-groups'),(920748,'printshop','.w-delivery-location-top-location-list .deliveryName','border-bottom-color','$content-border-1','','','.w-delivery-location-top-location-list'),(920749,'printshop','.w-delivery-location-location-list .deliveryName','border-bottom-color','$content-border-1','','','.w-delivery-location-location-list'),(920750,'printshop','.w-delivery-location-location-list .deliveryList li a','border-bottom-color','$content-border-1','','','.w-delivery-location-location-list'),(920751,'printshop','.w-delivery-location-location-list .deliveryList li a','border-bottom-color','$highlight-box-border-1','1','','.w-delivery-location-location-list'),(920752,'printshop','.w-sale-category .left-text-left','border-bottom-color','$content-border-3','','','.w-sale-category'),(920753,'printshop','.w-sale-category .left-text-right','border-bottom-color','$content-border-3','','','.w-sale-category'),(920754,'printshop','.w-sale-category .sale-holder','border-bottom-color','$content-border-3','','','.w-sale-category'),(920755,'printshop','.w-catalog-delivery-locations .name','border-bottom-color','$content-border-1','','','.w-catalog-delivery-locations'),(920756,'printshop','.w-product-designer-designer .prodDesignerType label','border-bottom-color','$content-border-1','','','.w-product-designer-designer'),(920757,'printshop','.w-press-reviews-widgets-press-reviews-small ','border-bottom-color','$content-border-3','','','.w-press-reviews-widgets-press-reviews-small'),(920758,'printshop','.b-products-listing .productGroup label a','border-bottom-color','$highlight-box-border-1','','','.b-products-listing'),(920759,'printshop','.w-support-system-listing .support-head','border-bottom-color','$content-border-1','','','.w-support-system-listing'),(920760,'printshop','.w-support-system-listing .product_icon','border-bottom-color','$content-border-1','','','.w-support-system-listing'),(920761,'printshop','.w-rma-returns-history .topRow','border-bottom-color','$content-border-3','','','.w-rma-returns-history'),(920762,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-color','$attention-border','','','.w-predefined-promotion'),(920763,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-color','$attention-border','','','.w-predefined-promotion'),(920764,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-color','$attention-border','','','.w-predefined-promotion'),(920765,'printshop','.w-predefined-promotion .promo-salemaker .discount','border-bottom-color','$warning-border','','','.w-predefined-promotion'),(920766,'printshop','.w-supplier-purchase-supplier-products .item','border-bottom-color','$content-border-1','','','.w-supplier-purchase-supplier-products'),(920768,'printshop','.btn-1','border-bottom-color','$btn-border-2','','',''),(920769,'printshop','.w-categories h2.name','border-bottom-color','$content-border-3','','','.w-categories'),(920770,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','border-bottom-color','$content-border-3','','','.w-filters'),(920771,'printshop','.b-quantity .qty-box','border-bottom-color','$content-border-3','','','.b-quantity'),(920772,'printshop','.w-product-model ','border-bottom-color','$content-border-3','','','.w-product-model'),(920773,'printshop','.w-tabs .tab-li','border-bottom-color','$tab-nav-border-2','','','.w-tabs'),(920774,'printshop','.w-checkout-billing-address .same-address','border-bottom-color','$content-border-3','','','.w-checkout-billing-address'),(920775,'printshop','.btn-3','border-bottom-color','$btn-border-4','','',''),(920776,'printshop','.middleBanner .btn-1','border-bottom-color','$additional-banner-border-2','','','.middleBanner'),(920777,'printshop','.bottomBanner .btn-1','border-bottom-color','$additional-banner-border-2','','','.bottomBanner'),(920778,'printshop','.w-product-personal-catalog-button .btn','border-bottom-color','$highlight-box-border-2','','','.w-product-personal-catalog-button'),(920779,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-bottom-color','$highlight-box-border-2','','','.b-products-listing'),(920780,'printshop','.topBanner .content .btn','border-bottom-color','$main-banner-border-1','','','.topBanner'),(920781,'printshop','.topBanner .ourPick .top','border-bottom-color','$main-banner-bg-1','','','.topBanner'),(920782,'printshop','.topBanner .ourPick','border-bottom-color','$main-banner-bg-1','4','','.topBanner'),(920783,'printshop','.topBanner .ourPick','border-bottom-color','$main-banner-bg-1','3','','.topBanner'),(920784,'printshop','.w-promotions-widgets-promotion-icons-desc .w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','border-bottom-color','$content-border-3','','','.w-promotions-widgets-promotion-icons-desc'),(920785,'printshop','.order-summary .checkout-cart-listing.summary-listing','border-bottom-color','$content-border-3','','','.order-summary'),(920786,'printshop','.p-quote-checkout-index .input-wrapper','border-bottom-color','$content-border-3','','','.p-quote-checkout-index'),(920790,'printshop','.account-samples .orders-table .item','border-bottom-color','$content-border-3','5342','','.account-samples'),(920791,'printshop','.catalog-product-wrap .pn-image','border-bottom-color','$content-border-3','3','','.catalog-product-wrap'),(920792,'printshop','.shopping-cart-index .btn-3','border-bottom-color','$highlight-box-border-1','','','.shopping-cart-index'),(920793,'printshop','.checkout-index-wrap .input-wrapper','border-bottom-color','$content-border-3','','','.checkout-index-wrap'),(920794,'printshop','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-color','$highlight-box-border-1','','','.b-multi-page-checkout'),(920795,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-color','$content-border-3','','','.b-multi-page-checkout'),(920796,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-color','$content-border-3','','','.b-multi-page-checkout'),(920798,'printshop','.footer-menu .level-1 > li','border-bottom-color','$footer-menu-border-1','5342','','.footer-menu'),(920799,'printshop','.w-catalog-paging ','border-bottom-color','#CCCCCC','2','','.w-catalog-paging'),(920800,'printshop','.w-catalog-paging .next','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(920801,'printshop','.w-catalog-paging .next-pages','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(920802,'printshop','.w-catalog-paging .page-number','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(920803,'printshop','.w-catalog-paging .prev','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(920804,'printshop','.w-catalog-paging .prev-pages','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(920805,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(920807,'printshop','.w-sale .left-text-left','border-bottom-color','$content-border-3','','','.w-sale'),(920808,'printshop','.w-sale .left-text-right','border-bottom-color','$content-border-3','','','.w-sale'),(920809,'printshop','.w-sale .sale-holder','border-bottom-color','$content-border-3','','','.w-sale'),(920810,'printshop','.b-data-table table.dataTable.no-footer','border-bottom-color_important','important','','','.b-data-table'),(920811,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-left-radius','15','4','','.b-switch'),(920812,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.p-quick-order-index'),(920813,'printshop','.w-promotions .prom-multi-discount .promo-range','border-bottom-left-radius','12','','','.w-promotions'),(920814,'printshop','.w-promotions .promo-salemaker .discount','border-bottom-left-radius','12','','','.w-promotions'),(920815,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-left-radius','12','','','.w-promotions'),(920816,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-left-radius','12','','','.w-promotions'),(920817,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.p-quick-order-index'),(920818,'printshop','.w-personal-gift-status-bar .progress-bar','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(920819,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-left-radius','5','','','.b-messages'),(920820,'printshop','.b-fancybox .fancybox-close','border-bottom-left-radius','50','','','.b-fancybox'),(920821,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-left-radius','25','','','.b-switch'),(920822,'printshop','.b-upload-file .snapshot','border-bottom-left-radius','50','','','.b-upload-file'),(920823,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-left-radius','15','3','','.b-switch'),(920824,'printshop','.b-switch .candlestick-wrapper .candlestick-bg','border-bottom-left-radius','15','','','.b-switch'),(920825,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(920826,'printshop','.w-checkout-shipping-choice label:last-child span','border-bottom-left-radius','0','','','.w-checkout-shipping-choice'),(920827,'printshop','.w-checkout-shipping-choice label:first-child span','border-bottom-left-radius','16','','','.w-checkout-shipping-choice'),(920828,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-bottom-left-radius','0','4','','.b-switch'),(920829,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-bottom-left-radius','0','3','','.b-switch'),(920830,'printshop','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-left-radius','15','','','.b-fancybox'),(920831,'printshop','.b-fancybox .fancybox-skin','border-bottom-left-radius','4','','','.b-fancybox'),(920832,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-bottom-left-radius','50','3','','.b-switch'),(920833,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-left-radius','50','3','','.b-form'),(920834,'printshop','.b-fancybox .fancybox-nav span','border-bottom-left-radius','50','','','.b-fancybox'),(920835,'printshop','.w-product-customers-activity .customers-activity','border-bottom-left-radius','0','','','.w-product-customers-activity'),(920836,'printshop','.w-product-customers-activity .close','border-bottom-left-radius','50','','','.w-product-customers-activity'),(920837,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(920838,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.b-data-table'),(920839,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.b-data-table'),(920840,'printshop','.b-products-listing .promos-info .promo-name','border-bottom-left-radius','0','','','.b-products-listing'),(920841,'printshop','.w-personal-gift-status-bar .progress-bar-content','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(920842,'printshop','.b-switch .bootstrap-switch','border-bottom-left-radius','14','','','.b-switch'),(920843,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-left-radius','25','','','.b-switch'),(920844,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-bottom-left-radius','0','','','.b-product-images'),(920845,'printshop','.b-trade-approval .steps-bar','border-bottom-left-radius','18','','','.b-trade-approval'),(920846,'printshop','.w-delivery-day .left-count','border-bottom-left-radius','3','','','.w-delivery-day'),(920847,'printshop','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-left-radius','3','','','.w-delivery-day'),(920849,'printshop','.menu-header .burger-icon','border-bottom-left-radius','50','5342','','.menu-header'),(920850,'printshop','.w-quote .cart-box-link','border-bottom-left-radius','50','3','','.w-quote'),(920851,'printshop','.w-product-sale-ends .left-count','border-bottom-left-radius','3','','','.w-product-sale-ends'),(920852,'printshop','.w-product-sale-ends .left-count-days','border-bottom-left-radius','3','','','.w-product-sale-ends'),(920853,'printshop','.w-product-sale-ends .left-count-hours','border-bottom-left-radius','3','','','.w-product-sale-ends'),(920854,'printshop','.w-sample .cart-box-link','border-bottom-left-radius','50','3','','.w-sample'),(920855,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-left-radius','50','','','.w-questionnaire-widgets-questionnaire'),(920856,'printshop','.w-sale-category .badge','border-bottom-left-radius','50','','','.w-sale-category'),(920857,'printshop','.w-sale-category .left-count','border-bottom-left-radius','3','','','.w-sale-category'),(920858,'printshop','.w-sale-category .left-count-days','border-bottom-left-radius','3','','','.w-sale-category'),(920859,'printshop','.w-sale-category .left-count-hours','border-bottom-left-radius','3','','','.w-sale-category'),(920860,'printshop','.b-products-listing .productGroup label a','border-bottom-left-radius','3','','','.b-products-listing'),(920861,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-left-radius','12','','','.w-predefined-promotion'),(920862,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-left-radius','12','','','.w-predefined-promotion'),(920863,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-left-radius','12','','','.w-predefined-promotion'),(920864,'printshop','.w-predefined-promotion .promo-salemaker .discount','border-bottom-left-radius','12','','','.w-predefined-promotion'),(920866,'printshop','.btn','border-bottom-left-radius','5','','',''),(920867,'printshop','.btn-1','border-bottom-left-radius','5','','',''),(920868,'printshop','.btn-2','border-bottom-left-radius','5','','',''),(920869,'printshop','.w-catalog-listing-look .b2b','border-bottom-left-radius','5','','','.w-catalog-listing-look'),(920870,'printshop','.w-catalog-listing-look .grid','border-bottom-left-radius','5','','','.w-catalog-listing-look'),(920871,'printshop','.w-catalog-listing-look .list','border-bottom-left-radius','5','','','.w-catalog-listing-look'),(920872,'printshop','.btn-3','border-bottom-left-radius','5','','',''),(920873,'printshop','.middleBanner .btn-1','border-bottom-left-radius','3','','','.middleBanner'),(920874,'printshop','.bottomBanner .btn-1','border-bottom-left-radius','3','','','.bottomBanner'),(920875,'printshop','.topBanner .content .btn','border-bottom-left-radius','3','','','.topBanner'),(920876,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','border-bottom-left-radius','5','','','.p-quote-checkout-index'),(920878,'printshop','.catalog-product-wrap .pn-image','border-bottom-left-radius','50','3','','.catalog-product-wrap'),(920879,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','border-bottom-left-radius','5','','','.checkout-index-wrap'),(920880,'printshop','.b-slick .slick-dots li','border-bottom-left-radius','50','3','','.b-slick'),(920881,'printshop','.success-page .w-cart-listing .qty','border-bottom-left-radius','50','','','.success-page'),(920882,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-left-radius','50','','','.b-multi-page-checkout'),(920883,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-left-radius','50','3','','.b-multi-page-checkout'),(920884,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-left-radius','0','','','.w-catalog-paging'),(920885,'printshop','.w-sale .badge','border-bottom-left-radius','50','','','.w-sale'),(920886,'printshop','.w-sale .left-count','border-bottom-left-radius','3','','','.w-sale'),(920887,'printshop','.w-sale .left-count-days','border-bottom-left-radius','3','','','.w-sale'),(920888,'printshop','.w-sale .left-count-hours','border-bottom-left-radius','3','','','.w-sale'),(920889,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-bottom-right-radius','0','4','','.b-switch'),(920890,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-right-radius','15','4','','.b-switch'),(920891,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.p-quick-order-index'),(920892,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.p-quick-order-index'),(920893,'printshop','.w-promotions .prom-multi-discount .promo-range','border-bottom-right-radius','12','','','.w-promotions'),(920894,'printshop','.w-promotions .promo-salemaker .discount','border-bottom-right-radius','12','','','.w-promotions'),(920895,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-right-radius','12','','','.w-promotions'),(920896,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-right-radius','12','','','.w-promotions'),(920897,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-right-radius','5','','','.b-messages'),(920898,'printshop','.b-fancybox .fancybox-close','border-bottom-right-radius','50','','','.b-fancybox'),(920899,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-right-radius','25','','','.b-switch'),(920900,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-bottom-right-radius','0','3','','.b-switch'),(920901,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-right-radius','15','3','','.b-switch'),(920902,'printshop','.b-switch .candlestick-wrapper .candlestick-bg','border-bottom-right-radius','15','','','.b-switch'),(920903,'printshop','.w-checkout-shipping-choice label:last-child span','border-bottom-right-radius','16','','','.w-checkout-shipping-choice'),(920904,'printshop','.w-checkout-shipping-choice label:first-child span','border-bottom-right-radius','0','','','.w-checkout-shipping-choice'),(920905,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(920906,'printshop','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-right-radius','15','','','.b-fancybox'),(920907,'printshop','.b-fancybox .fancybox-skin','border-bottom-right-radius','4','','','.b-fancybox'),(920908,'printshop','.b-upload-file .snapshot','border-bottom-right-radius','50','','','.b-upload-file'),(920909,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-bottom-right-radius','50','3','','.b-switch'),(920910,'printshop','.b-fancybox .fancybox-nav span','border-bottom-right-radius','50','','','.b-fancybox'),(920911,'printshop','.w-product-customers-activity .close','border-bottom-right-radius','50','','','.w-product-customers-activity'),(920912,'printshop','.w-product-customers-activity .customers-activity','border-bottom-right-radius','0','','','.w-product-customers-activity'),(920913,'printshop','.w-personal-gift-status-bar .progress-bar','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(920914,'printshop','.b-switch .bootstrap-switch','border-bottom-right-radius','14','','','.b-switch'),(920915,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.b-data-table'),(920916,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.b-data-table'),(920917,'printshop','.b-products-listing .promos-info .promo-name','border-bottom-right-radius','8','','','.b-products-listing'),(920918,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(920919,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-right-radius','50','3','','.b-form'),(920920,'printshop','.w-personal-gift-status-bar .progress-bar-content','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(920921,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-right-radius','25','','','.b-switch'),(920922,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-bottom-right-radius','0','','','.b-product-images'),(920923,'printshop','.b-trade-approval .steps-bar','border-bottom-right-radius','18','','','.b-trade-approval'),(920924,'printshop','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-right-radius','3','','','.w-delivery-day'),(920925,'printshop','.w-delivery-day .left-count','border-bottom-right-radius','3','','','.w-delivery-day'),(920927,'printshop','.menu-header .burger-icon','border-bottom-right-radius','50','5342','','.menu-header'),(920928,'printshop','.w-quote .cart-box-link','border-bottom-right-radius','50','3','','.w-quote'),(920929,'printshop','.w-product-sale-ends .left-count','border-bottom-right-radius','3','','','.w-product-sale-ends'),(920930,'printshop','.w-product-sale-ends .left-count-days','border-bottom-right-radius','3','','','.w-product-sale-ends'),(920931,'printshop','.w-product-sale-ends .left-count-hours','border-bottom-right-radius','3','','','.w-product-sale-ends'),(920932,'printshop','.w-sample .cart-box-link','border-bottom-right-radius','50','3','','.w-sample'),(920933,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-right-radius','50','','','.w-questionnaire-widgets-questionnaire'),(920934,'printshop','.w-sale-category .badge','border-bottom-right-radius','50','','','.w-sale-category'),(920935,'printshop','.w-sale-category .left-count','border-bottom-right-radius','3','','','.w-sale-category'),(920936,'printshop','.w-sale-category .left-count-days','border-bottom-right-radius','3','','','.w-sale-category'),(920937,'printshop','.w-sale-category .left-count-hours','border-bottom-right-radius','3','','','.w-sale-category'),(920938,'printshop','.b-products-listing .productGroup label a','border-bottom-right-radius','3','','','.b-products-listing'),(920939,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-right-radius','12','','','.w-predefined-promotion'),(920940,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-right-radius','12','','','.w-predefined-promotion'),(920941,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-right-radius','12','','','.w-predefined-promotion'),(920942,'printshop','.w-predefined-promotion .promo-salemaker .discount','border-bottom-right-radius','12','','','.w-predefined-promotion'),(920944,'printshop','.btn','border-bottom-right-radius','5','','',''),(920945,'printshop','.btn-1','border-bottom-right-radius','5','','',''),(920946,'printshop','.btn-2','border-bottom-right-radius','5','','',''),(920947,'printshop','.w-catalog-listing-look .b2b','border-bottom-right-radius','5','','','.w-catalog-listing-look'),(920948,'printshop','.w-catalog-listing-look .grid','border-bottom-right-radius','5','','','.w-catalog-listing-look'),(920949,'printshop','.w-catalog-listing-look .list','border-bottom-right-radius','5','','','.w-catalog-listing-look'),(920950,'printshop','.btn-3','border-bottom-right-radius','5','','',''),(920951,'printshop','.middleBanner .btn-1','border-bottom-right-radius','3','','','.middleBanner'),(920952,'printshop','.bottomBanner .btn-1','border-bottom-right-radius','3','','','.bottomBanner'),(920953,'printshop','.topBanner .content .btn','border-bottom-right-radius','3','','','.topBanner'),(920954,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','border-bottom-right-radius','5','','','.p-quote-checkout-index'),(920956,'printshop','.catalog-product-wrap .pn-image','border-bottom-right-radius','50','3','','.catalog-product-wrap'),(920957,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','border-bottom-right-radius','5','','','.checkout-index-wrap'),(920958,'printshop','.b-slick .slick-dots li','border-bottom-right-radius','50','3','','.b-slick'),(920959,'printshop','.success-page .w-cart-listing .qty','border-bottom-right-radius','50','','','.success-page'),(920960,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-right-radius','50','','','.b-multi-page-checkout'),(920961,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-right-radius','50','3','','.b-multi-page-checkout'),(920962,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-right-radius','0','','','.w-catalog-paging'),(920963,'printshop','.w-sale .badge','border-bottom-right-radius','50','','','.w-sale'),(920964,'printshop','.w-sale .left-count','border-bottom-right-radius','3','','','.w-sale'),(920965,'printshop','.w-sale .left-count-days','border-bottom-right-radius','3','','','.w-sale'),(920966,'printshop','.w-sale .left-count-hours','border-bottom-right-radius','3','','','.w-sale'),(920967,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(920968,'printshop','.b-upload-file .upload-file-template div','border-bottom-style','dotted','','','.b-upload-file'),(920969,'printshop','.w-promotions .prom-multi-discount .promo-range','border-bottom-width','1','','','.w-promotions'),(920971,'printshop','.testimonials .review','border-bottom-width','7','3','',''),(920972,'printshop','.w-promotions .promo-salemaker .discount','border-bottom-width','1','','','.w-promotions'),(920973,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-width','1','','','.w-promotions'),(920974,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-width','1','','','.w-promotions'),(920975,'printshop','.b-upload-file .upload-file-template div','border-bottom-width','1','','','.b-upload-file'),(920976,'printshop','.w-cart-compare .cart-cell > div','border-bottom-width','1','','','.w-cart-compare'),(920977,'printshop','.w-filters .filter-box-head','border-bottom-width','1','','','.w-filters'),(920978,'printshop','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-bottom-width','1','','','.b-bottom'),(920979,'printshop','.b-messages .msv_btn','border-bottom-width','1','','','.b-messages'),(920980,'printshop','.b-messages .email-heading','border-bottom-width','1','','','.b-messages'),(920981,'printshop','.b-messages .content_management_attach button','border-bottom-width','1','','','.b-messages'),(920982,'printshop','.b-messages .content_management_attach','border-bottom-width','1','','','.b-messages'),(920983,'printshop','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-width','2','','','.b-messages'),(920984,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-width','1','','','.b-messages'),(920985,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-width','1','','','.b-messages'),(920986,'printshop','.b-messages .dataTables_wrapper > .bottom','border-bottom-width','1','','','.b-messages'),(920987,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-bottom-width','1','','',''),(920988,'printshop','.b-messages .msv_to_cc','border-bottom-width','1','','','.b-messages'),(920989,'printshop','.w-product-reviews .reviews-list .review','border-bottom-width','7','3','','.w-product-reviews'),(920990,'printshop','.w-reviews .review','border-bottom-width','8','3','','.w-reviews'),(920991,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(920992,'printshop','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(920993,'printshop','.w-tabs .accordion-heading','border-bottom-width','1','','','.w-tabs'),(920994,'printshop','.b-form .required-error','border-bottom-width','1','','','.b-form'),(920995,'printshop','.w-socials > li','border-bottom-width','1','','','.w-socials'),(920996,'printshop','.b-bottom .popup-heading','border-bottom-width','1','','','.b-bottom'),(920997,'printshop','.w-checkout-shipping-choice span','border-bottom-width','2','','','.w-checkout-shipping-choice'),(920998,'printshop','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(920999,'printshop','.w-socials > li','border-bottom-width','1','','','.w-socials'),(921002,'printshop','.b-info-popup .info-popup div','border-bottom-width','1','','','.b-info-popup'),(921003,'printshop','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(921004,'printshop','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(921005,'printshop','.w-tabs > .block','border-bottom-width','1','','','.w-tabs'),(921006,'printshop','.w-tabs .accordion-heading','border-bottom-width','3','2','','.w-tabs'),(921007,'printshop','.w-socials > li','border-bottom-width','1','','','.w-socials'),(921008,'printshop','.w-cart-give-away .ga_column','border-bottom-width','1','','','.w-cart-give-away'),(921009,'printshop','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(921010,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-width','4','','','.b-switch'),(921011,'printshop','.w-filters .ui-slider-handle','border-bottom-width','0','','','.w-filters'),(921012,'printshop','.w-filters .ui-slider','border-bottom-width','0','','','.w-filters'),(921013,'printshop','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(921014,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-width','2','3','','.b-form'),(921015,'printshop','.b-upload-file .upload-file-template','border-bottom-width','1','','','.b-upload-file'),(921016,'printshop','.w-socials > li','border-bottom-width','1','','','.w-socials'),(921017,'printshop','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(921018,'printshop','.w-reviews .item','border-bottom-width','1','','','.w-reviews'),(921019,'printshop','.b-select-suggest .select2-container .select2-choice','border-bottom-width','1','','','.b-select-suggest'),(921020,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-width','2','4','','.b-switch'),(921022,'printshop','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(921023,'printshop','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-width','1','','','.b-compare'),(921024,'printshop','.w-cart-compare .compare-table','border-bottom-width','1','','','.w-cart-compare'),(921025,'printshop','.w-reviews-content .review','border-bottom-width','8','3','','.w-reviews-content'),(921026,'printshop','textarea','border-bottom-width','1','','',''),(921027,'printshop','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-bottom-width','1','','','.b-bottom'),(921028,'printshop','.b-bottom .footerTitle','border-bottom-width','1','5333','','.b-bottom'),(921029,'printshop','.w-socials > li','border-bottom-width','1','','','.w-socials'),(921030,'printshop','.b-bottom .popup-box','border-bottom-width','1','','','.b-bottom'),(921031,'printshop','.w-product-customers-activity .customers-activity','border-bottom-width','1','','','.w-product-customers-activity'),(921032,'printshop','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(921033,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(921034,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(921035,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(921036,'printshop','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(921037,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-width','1','','','.b-select-suggest'),(921038,'printshop','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(921039,'printshop','.b-select-suggest .select2-search input','border-bottom-width','1','','','.b-select-suggest'),(921040,'printshop','.b-select-suggest .select2-drop-active','border-bottom-width','1','','','.b-select-suggest'),(921041,'printshop','.b-select-suggest .select2-drop','border-bottom-width','1','','','.b-select-suggest'),(921042,'printshop','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(921043,'printshop','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(921044,'printshop','.w-communication-post .communication-post','border-bottom-width','1','','','.w-communication-post'),(921045,'printshop','.checkbox input:checked + span','border-bottom-width','1','','',''),(921046,'printshop','.checkbox input + span','border-bottom-width','1','','',''),(921047,'printshop','.b-autocomplete .ui-autocomplete','border-bottom-width','1','','','.b-autocomplete'),(921050,'printshop','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(921051,'printshop','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(921052,'printshop','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(921053,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-width','2','3','','.b-switch'),(921054,'printshop','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(921055,'printshop','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(921056,'printshop','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(921057,'printshop','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(921058,'printshop','.w-cart-listing .item .gift-wrap label','border-bottom-width','1','','','.w-cart-listing'),(921059,'printshop','.w-cart-listing .item','border-bottom-width','1','5342','','.w-cart-listing'),(921062,'printshop','.w-socials > li','border-bottom-width','1','','','.w-socials'),(921064,'printshop','.w-reviews-content .item','border-bottom-width','1','','','.w-reviews-content'),(921065,'printshop','.w-filters .ui-slider-range','border-bottom-width','0','','','.w-filters'),(921066,'printshop','.b-upload-files .upload-files','border-bottom-width','1','','','.b-upload-files'),(921067,'printshop','.b-compare .compare_pagination','border-bottom-width','1','','','.b-compare'),(921068,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-width','3','','','.b-switch'),(921069,'printshop','.b-upload-file .snapshot','border-bottom-width','1','','','.b-upload-file'),(921070,'printshop','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-bottom-width','2','','','.b-product-images'),(921071,'printshop','.b-trade-approval .orders-table th','border-bottom-width','1','','','.b-trade-approval'),(921072,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-width','2','','','.b-trade-approval'),(921073,'printshop','.w-account-personal-catalog .list-switcher a','border-bottom-width','1','','','.w-account-personal-catalog'),(921074,'printshop','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-width','1','','','.w-catalog-compare'),(921075,'printshop','.w-catalog-compare .cross-box .different-all > div','border-bottom-width','1','','','.w-catalog-compare'),(921076,'printshop','.w-delivery-day .left-text-right','border-bottom-width','2','','','.w-delivery-day'),(921077,'printshop','.w-delivery-day .left-text-left','border-bottom-width','2','','','.w-delivery-day'),(921078,'printshop','.b-slick .slick-vertical .slick-slide','border-bottom-width','1','','','.b-slick'),(921079,'printshop','.w-filters .filter-widget','border-bottom-width','1','','','.w-filters'),(921080,'printshop','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-bottom-width','0','','','.w-filters'),(921081,'printshop','.w-quote .cart-content','border-bottom-width','1','','','.w-quote'),(921082,'printshop','.w-quote .cart-total','border-bottom-width','1','','','.w-quote'),(921083,'printshop','.w-quote .multicart .item','border-bottom-width','1','','','.w-quote'),(921084,'printshop','.b-product-images .additional-images .active img','border-bottom-width','2','','','.b-product-images'),(921085,'printshop','.b-product-images .additional-images img','border-bottom-width','2','','','.b-product-images'),(921086,'printshop','.w-product-sale-ends .left-text-left','border-bottom-width','2','','','.w-product-sale-ends'),(921087,'printshop','.w-product-sale-ends .left-text-right','border-bottom-width','2','','','.w-product-sale-ends'),(921088,'printshop','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(921089,'printshop','.warrantyProduct .warranty, .warrantyProduct .delivery','border-bottom-width','1','','','.warrantyProduct'),(921090,'printshop','.w-sample .cart-box-link','border-bottom-width','1','4','','.w-sample'),(921091,'printshop','.w-sample .cart-content','border-bottom-width','1','','','.w-sample'),(921092,'printshop','.w-sample .cart-total','border-bottom-width','1','','','.w-sample'),(921093,'printshop','.w-sample .multicart .item','border-bottom-width','1','','','.w-sample'),(921094,'printshop','.w-product-video .item img, .w-product-video .item video','border-bottom-width','2','','','.w-product-video'),(921095,'printshop','.w-product-video .item.active img, .w-product-video .item.active video','border-bottom-width','2','','','.w-product-video'),(921096,'printshop','.shipping-ico .heading-3','border-bottom-width','1','','','.shipping-ico'),(921097,'printshop','.w-cart-order-reference .btn','border-bottom-width','2','','','.w-cart-order-reference'),(921098,'printshop','.w-cart-gift-certificate .btn','border-bottom-width','2','','','.w-cart-gift-certificate'),(921100,'printshop','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-bottom-width','1','','','.b-pagination'),(921101,'printshop','.b-pagination .pagination .next-pages','border-bottom-width','1','','','.b-pagination'),(921102,'printshop','.b-pagination .pagination .page-number','border-bottom-width','1','','','.b-pagination'),(921103,'printshop','.b-pagination .pagination .prev-pages','border-bottom-width','1','','','.b-pagination'),(921104,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-bottom-width','1','','','.b-pagination'),(921105,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-bottom-width','1','','','.b-pagination'),(921106,'printshop','.b-pagination .pagination span','border-bottom-width','1','2','','.b-pagination'),(921107,'printshop','.w-product-multi-inventory .radio-attributes','border-bottom-width','1','','','.w-product-multi-inventory'),(921108,'printshop','.w-product-multi-inventory .radio-attributes .option-item','border-bottom-width','2','','','.w-product-multi-inventory'),(921109,'printshop','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-bottom-width','2','','','.w-product-multi-inventory'),(921110,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-bottom-width','1','','','.w-account-personal-catalog'),(921111,'printshop','.w-account-personal-catalog .list-row-action ul','border-bottom-width','1','','','.w-account-personal-catalog'),(921112,'printshop','.b-products-listing .products-listing .radio-attributes','border-bottom-width','1','','','.b-products-listing'),(921113,'printshop','.b-products-listing .products-listing .radio-attributes .option','border-bottom-width','2','','','.b-products-listing'),(921114,'printshop','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-bottom-width','2','','','.b-products-listing'),(921115,'printshop','.w-product-attributes .radio-attributes','border-bottom-width','1','','','.w-product-attributes'),(921116,'printshop','.w-product-attributes .radio-attributes .option-item','border-bottom-width','2','','','.w-product-attributes'),(921117,'printshop','.w-product-attributes .radio-attributes input:checked + .option-item','border-bottom-width','2','','','.w-product-attributes'),(921118,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-width','2','','','.w-questionnaire-widgets-questionnaire'),(921119,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-bottom-width','2','','','.w-questionnaire-widgets-questionnaire'),(921120,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-bottom-width','2','','','.w-questionnaire-widgets-questionnaire'),(921121,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-bottom-width','2','1','','.w-questionnaire-widgets-questionnaire'),(921122,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-bottom-width','2','1','','.w-questionnaire-widgets-questionnaire'),(921123,'printshop','.w-product-groups .radioBox label .containerBlock','border-bottom-width','2','','','.w-product-groups'),(921124,'printshop','.w-product-groups .radioBox label .containerBlock.selected','border-bottom-width','2','','','.w-product-groups'),(921125,'printshop','.w-product-groups .radioBox label input:checked + .containerBlock','border-bottom-width','2','','','.w-product-groups'),(921126,'printshop','.w-delivery-location-top-location-list .deliveryName','border-bottom-width','1','','','.w-delivery-location-top-location-list'),(921127,'printshop','.w-delivery-location-location-list .deliveryName','border-bottom-width','1','','','.w-delivery-location-location-list'),(921128,'printshop','.w-delivery-location-location-list .deliveryList li a','border-bottom-width','2','','','.w-delivery-location-location-list'),(921129,'printshop','.w-delivery-location-location-list .deliveryList li a','border-bottom-width','2','1','','.w-delivery-location-location-list'),(921130,'printshop','.w-sale-category .left-text-left','border-bottom-width','2','','','.w-sale-category'),(921131,'printshop','.w-sale-category .left-text-right','border-bottom-width','2','','','.w-sale-category'),(921132,'printshop','.w-sale-category .sale-holder','border-bottom-width','2','','','.w-sale-category'),(921133,'printshop','.w-catalog-delivery-locations .name','border-bottom-width','1','','','.w-catalog-delivery-locations'),(921134,'printshop','.w-product-designer-designer .prodDesignerType label','border-bottom-width','1','','','.w-product-designer-designer'),(921135,'printshop','.w-press-reviews-widgets-press-reviews-small ','border-bottom-width','1','','','.w-press-reviews-widgets-press-reviews-small'),(921136,'printshop','.b-products-listing .productGroup label a','border-bottom-width','1','','','.b-products-listing'),(921137,'printshop','.w-support-system-listing .support-head','border-bottom-width','1','','','.w-support-system-listing'),(921138,'printshop','.w-support-system-listing .product_icon','border-bottom-width','1','','','.w-support-system-listing'),(921139,'printshop','.w-rma-returns-history .topRow','border-bottom-width','1','','','.w-rma-returns-history'),(921140,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-width','1','','','.w-predefined-promotion'),(921141,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-width','1','','','.w-predefined-promotion'),(921142,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-width','1','','','.w-predefined-promotion'),(921143,'printshop','.w-predefined-promotion .promo-salemaker .discount','border-bottom-width','1','','','.w-predefined-promotion'),(921144,'printshop','.w-supplier-purchase-supplier-products .item','border-bottom-width','1','','','.w-supplier-purchase-supplier-products'),(921146,'printshop','.btn-1','border-bottom-width','2','','',''),(921147,'printshop','.w-categories h2.name','border-bottom-width','1','','','.w-categories'),(921148,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','border-bottom-width','1','','','.w-filters'),(921149,'printshop','.b-quantity .qty-box','border-bottom-width','2','','','.b-quantity'),(921150,'printshop','.w-product-model ','border-bottom-width','1','','','.w-product-model'),(921151,'printshop','.w-cart-listing .headings','border-bottom-width','1','','','.w-cart-listing'),(921152,'printshop','.w-cart-listing .item','border-bottom-width','1','','','.w-cart-listing'),(921153,'printshop','.w-tabs .tab-li','border-bottom-width','1','','','.w-tabs'),(921154,'printshop','.w-cart-cart-tabs .tab-li','border-bottom-width','0','','','.w-cart-cart-tabs'),(921155,'printshop','.w-checkout-billing-address .same-address','border-bottom-width','1','','','.w-checkout-billing-address'),(921156,'printshop','.btn-3','border-bottom-width','2','','',''),(921157,'printshop','.w-cart-cart-tabs .w-tabs .tab-li','border-bottom-width','0','','','.w-cart-cart-tabs'),(921158,'printshop','.middleBanner .btn-1','border-bottom-width','1','','','.middleBanner'),(921159,'printshop','.bottomBanner .btn-1','border-bottom-width','1','','','.bottomBanner'),(921160,'printshop','.w-product-personal-catalog-button .btn','border-bottom-width','2','','','.w-product-personal-catalog-button'),(921161,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-bottom-width','2','','','.b-products-listing'),(921163,'printshop','.topBanner .content .btn','border-bottom-width','1','','','.topBanner'),(921164,'printshop','.topBanner .ourPick','border-bottom-width','23','3','','.topBanner'),(921165,'printshop','.topBanner .ourPick','border-bottom-width','23','4','','.topBanner'),(921166,'printshop','.topBanner .ourPick .top','border-bottom-width','1','','','.topBanner'),(921167,'printshop','.topBanner .ourPick','border-bottom-width','15','5347,3','','.topBanner'),(921168,'printshop','.topBanner .ourPick','border-bottom-width','15','5347,4','','.topBanner'),(921169,'printshop','.topBanner .ourPick','border-bottom-width','10','5363,3','','.topBanner'),(921170,'printshop','.topBanner .ourPick','border-bottom-width','10','5363,4','','.topBanner'),(921171,'printshop','.w-promotions-widgets-promotion-icons-desc .w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','border-bottom-width','1','','','.w-promotions-widgets-promotion-icons-desc'),(921172,'printshop','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item:last-of-type','border-bottom-width','0','','','.w-promotions-widgets-promotion-icons-desc'),(921173,'printshop','.order-summary .checkout-cart-listing.summary-listing','border-bottom-width','1','','','.order-summary'),(921174,'printshop','.p-quote-checkout-index .input-wrapper','border-bottom-width','2','','','.p-quote-checkout-index'),(921176,'printshop','.account-address-book .address_book h1','border-bottom-width','1','','','.account-address-book'),(921177,'printshop','.account-address-book .address_book h2','border-bottom-width','1','','','.account-address-book'),(921182,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','border-bottom-width','1','','','.account-order-pay'),(921183,'printshop','.account-samples .orders-table .item','border-bottom-width','1','5342','','.account-samples'),(921184,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','border-bottom-width','1','','','.account-sample-info'),(921185,'printshop','.catalog-product-wrap .pn-image','border-bottom-width','2','3','','.catalog-product-wrap'),(921186,'printshop','.catalog-product-wrap .prev-next-product','border-bottom-width','1','','','.catalog-product-wrap'),(921187,'printshop','.shopping-cart-index .btn-3','border-bottom-width','2','','','.shopping-cart-index'),(921188,'printshop','.checkout-index-wrap .input-wrapper','border-bottom-width','2','','','.checkout-index-wrap'),(921189,'printshop','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(921190,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(921191,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-width','1','','','.b-multi-page-checkout'),(921193,'printshop','.footer-menu .level-1 > li','border-bottom-width','1','5342','','.footer-menu'),(921194,'printshop','.w-catalog-paging ','border-bottom-width','1','2','','.w-catalog-paging'),(921195,'printshop','.w-catalog-paging .next','border-bottom-width','1','','','.w-catalog-paging'),(921196,'printshop','.w-catalog-paging .next-pages','border-bottom-width','1','','','.w-catalog-paging'),(921197,'printshop','.w-catalog-paging .page-number','border-bottom-width','1','','','.w-catalog-paging'),(921198,'printshop','.w-catalog-paging .prev','border-bottom-width','1','','','.w-catalog-paging'),(921199,'printshop','.w-catalog-paging .prev-pages','border-bottom-width','1','','','.w-catalog-paging'),(921200,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-width','1','','','.w-catalog-paging'),(921202,'printshop','.w-sale .left-text-left','border-bottom-width','2','','','.w-sale'),(921203,'printshop','.w-sale .left-text-right','border-bottom-width','2','','','.w-sale'),(921204,'printshop','.w-sale .sale-holder','border-bottom-width','2','','','.w-sale'),(921205,'printshop','.b-compare .popupCompare table','border-collapse','collapse','','','.b-compare'),(921206,'printshop','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','border-left','none','','','.b-select-suggest'),(921207,'printshop','.w-promotions .prom-multi-discount .promo-range','border-left-color','$attention-border','','','.w-promotions'),(921208,'printshop','.w-cart-compare .attributes-block td:nth-child(1)','border-left-color','$content-border-3','','','.w-cart-compare'),(921210,'printshop','.testimonials .review','border-left-color','$content-border-1','3','',''),(921211,'printshop','.w-promotions .promo-salemaker .discount','border-left-color','$warning-border','','','.w-promotions'),(921212,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-color','$attention-border','','','.w-promotions'),(921213,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border-left-color','$attention-border','','','.w-promotions'),(921214,'printshop','.w-cart-compare .cart-cell > div','border-left-color','$content-border-3','','','.w-cart-compare'),(921215,'printshop','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-3','','','.b-dropdown'),(921216,'printshop','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-left-color','$content-border-3','','','.b-bottom'),(921217,'printshop','.b-messages .content_management_attach button','border-left-color','$highlight-box-border-1','','','.b-messages'),(921218,'printshop','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-color','$content-border-3','','','.b-messages'),(921219,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-left-color','$content-border-1','','',''),(921220,'printshop','.w-promo-code .holder','border-left-color','$content-border-3','','','.w-promo-code'),(921221,'printshop','.w-cart-products .checkout-attention-message','border-left-color','$attention-border','','','.w-cart-products'),(921222,'printshop','.w-socials > li','border-left-color','$content-border-3','','','.w-socials'),(921223,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-left-color','$switch-nc-border-1','','','.b-switch'),(921224,'printshop','.w-cart-products .checkout-attention-message','border-left-color','$attention-border','','','.w-cart-products'),(921225,'printshop','.w-cart-products .checkout-attention-message','border-left-color','$attention-border','','','.w-cart-products'),(921226,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(921227,'printshop','.b-info-popup .info-popup div','border-left-color','$content-border-3','3','','.b-info-popup'),(921228,'printshop','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-color','$content-border-1','','','.b-compare'),(921229,'printshop','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-3','','','.b-dropdown'),(921230,'printshop','.b-form .required-error','border-left-color','$attention-border','','','.b-form'),(921231,'printshop','.w-socials > li','border-left-color','$content-border-3','','','.w-socials'),(921232,'printshop','.b-info-popup .info-popup div','border-left-color','$content-border-3','','','.b-info-popup'),(921233,'printshop','.w-checkout-shipping-choice label:first-child span','border-left-color','$highlight-box-border-1','','','.w-checkout-shipping-choice'),(921234,'printshop','.w-product-reviews .reviews-list .review','border-left-color','$content-border-3','3','','.w-product-reviews'),(921235,'printshop','.w-promo-code .holder','border-left-color','$content-border-3','','','.w-promo-code'),(921236,'printshop','.w-tabs > .block','border-left-color','$tab-content-border-1','','','.w-tabs'),(921237,'printshop','.w-socials > li','border-left-color','$content-border-3','','','.w-socials'),(921238,'printshop','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-3','','','.b-dropdown'),(921239,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-left-color','$switch-handle-bg-3','','','.b-switch'),(921240,'printshop','.w-reviews .review','border-left-color','$content-bg-2','3','','.w-reviews'),(921241,'printshop','.w-reviews-content .review','border-left-color','$content-border-3','3','','.w-reviews-content'),(921242,'printshop','.w-promo-code .holder','border-left-color','$content-border-3','','','.w-promo-code'),(921243,'printshop','.b-select-suggest .select2-container .select2-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(921244,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-left-color','$switch-nc-border-1','4','','.b-switch'),(921246,'printshop','.w-cart-products .checkout-attention-message','border-left-color','$attention-border','','','.w-cart-products'),(921247,'printshop','.w-socials > li','border-left-color','$content-border-3','','','.w-socials'),(921248,'printshop','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-left-color','$content-bg-1','','','.b-bottom'),(921249,'printshop','textarea','border-left-color','$content-border-1','','',''),(921250,'printshop','.b-bottom .popup-box','border-left-color','$content-border-3','','','.b-bottom'),(921251,'printshop','.w-product-customers-activity .customers-activity','border-left-color','$content-border-3','','','.w-product-customers-activity'),(921252,'printshop','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-3','','','.b-dropdown'),(921253,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border-left-color','$checkbox-border-1','3','','.b-form'),(921254,'printshop','.w-cart-compare .price-block td:nth-child(1)','border-left-color','$content-border-3','','','.w-cart-compare'),(921255,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-color','$content-border-3','','','.b-select-suggest'),(921256,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-color','$content-border-3','','','.b-select-suggest'),(921257,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-color','$content-border-3','','','.b-select-suggest'),(921258,'printshop','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-color','$content-border-3','','','.b-select-suggest'),(921259,'printshop','.b-select-suggest .select2-container-multi .select2-choices','border-left-color','$content-border-3','','','.b-select-suggest'),(921260,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-color','$content-border-3','','','.b-select-suggest'),(921261,'printshop','.b-select-suggest .select2-search input','border-left-color','$content-border-3','','','.b-select-suggest'),(921262,'printshop','.b-select-suggest .select2-drop','border-left-color','$content-border-3','','','.b-select-suggest'),(921263,'printshop','.b-select-suggest .select2-drop-active','border-left-color','$content-border-3','','','.b-select-suggest'),(921264,'printshop','.w-socials > li','border-left-color','$content-border-3','','','.w-socials'),(921265,'printshop','.w-promo-code .holder','border-left-color','$content-border-3','','','.w-promo-code'),(921266,'printshop','.b-form input.required-error','border-left-color','$attention-border','','','.b-form'),(921267,'printshop','.checkbox input:checked + span','border-left-color','$checkbox-border-1','','',''),(921268,'printshop','.checkbox input + span','border-left-color','$checkbox-border-1','','',''),(921269,'printshop','.b-autocomplete .ui-autocomplete','border-left-color','$content-border-3','','','.b-autocomplete'),(921272,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-left-color','$switch-nc-border-1','3','','.b-switch'),(921273,'printshop','.b-upload-file .snapshot','border-left-color','$content-border-1','','','.b-upload-file'),(921274,'printshop','.w-socials > li','border-left-color','$content-border-3','','','.w-socials'),(921275,'printshop','.w-promo-code .holder','border-left-color','$content-border-3','','','.w-promo-code'),(921276,'printshop','.b-upload-files .upload-files','border-left-color','$content-border-3','','','.b-upload-files'),(921277,'printshop','.b-upload-file .upload-file-template','border-left-color','$content-border-3','','','.b-upload-file'),(921278,'printshop','.w-promo-code .holder','border-left-color','$content-border-3','','','.w-promo-code'),(921279,'printshop','.w-cart-products .checkout-attention-message','border-left-color','$attention-border','','','.w-cart-products'),(921280,'printshop','.w-cart-listing .item .gift-wrap label','border-left-color','$content-border-3','','','.w-cart-listing'),(921281,'printshop','.w-cart-listing .item','border-left-color','$content-border-3','5342','','.w-cart-listing'),(921283,'printshop','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-3','','','.b-dropdown'),(921284,'printshop','.w-cart-products .checkout-attention-message','border-left-color','$attention-border','','','.w-cart-products'),(921285,'printshop','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-3','','','.b-dropdown'),(921286,'printshop','.w-cart-compare .product-block td:nth-child(1)','border-left-color','$content-border-3','','','.w-cart-compare'),(921287,'printshop','.b-data-table table.dataTable.no-footer','border-left-color','$content-border-3','','','.b-data-table'),(921288,'printshop','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-left-color','$image-popup-border-1','','','.b-product-images'),(921289,'printshop','.b-trade-approval .steps-bar li ~ li a','border-left-color','$content-border-1','','','.b-trade-approval'),(921290,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-color','$content-border-3','','','.b-trade-approval'),(921291,'printshop','.w-account-personal-catalog .list-switcher a','border-left-color','$content-border-3','2','','.w-account-personal-catalog'),(921292,'printshop','.w-catalog-compare .compare .checkbox input:checked + span','border-left-color','$content-bg-1','','','.w-catalog-compare'),(921293,'printshop','.w-catalog-compare .cross-box .different-all > div','border-left-color','$content-border-3','2','','.w-catalog-compare'),(921295,'printshop','.w-filters .filter-widget','border-left-color','$content-border-3','','','.w-filters'),(921296,'printshop','.w-quote .cart-content','border-left-color','$content-border-3','','','.w-quote'),(921297,'printshop','.b-product-images .additional-images .active img','border-left-color','$image-popup-border-2','','','.b-product-images'),(921298,'printshop','.b-product-images .additional-images img','border-left-color','$image-popup-border-1','','','.b-product-images'),(921299,'printshop','.w-sample .cart-content','border-left-color','$content-border-3','','','.w-sample'),(921300,'printshop','.w-product-video .item img, .w-product-video .item video','border-left-color','$content-border-1','','','.w-product-video'),(921301,'printshop','.w-product-video .item.active img, .w-product-video .item.active video','border-left-color','$warning-border','','','.w-product-video'),(921302,'printshop','.w-cart-order-reference .btn','border-left-color','$highlight-box-border-1','','','.w-cart-order-reference'),(921303,'printshop','.w-cart-gift-certificate .btn','border-left-color','$highlight-box-border-1','','','.w-cart-gift-certificate'),(921305,'printshop','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-left-color','$highlight-box-border-2','','','.b-pagination'),(921306,'printshop','.b-pagination .pagination .next-pages','border-left-color','$content-border-3','','','.b-pagination'),(921307,'printshop','.b-pagination .pagination .page-number','border-left-color','$content-border-3','','','.b-pagination'),(921308,'printshop','.b-pagination .pagination .prev-pages','border-left-color','$content-border-3','','','.b-pagination'),(921309,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-left-color','$content-border-3','','','.b-pagination'),(921310,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-left-color','$content-border-3','','','.b-pagination'),(921311,'printshop','.b-pagination .pagination span','border-left-color','$highlight-box-border-2','2','','.b-pagination'),(921312,'printshop','.w-tabs .tab-li','border-left-color','$tab-nav-border-2','2','','.w-tabs'),(921313,'printshop','.w-product-multi-inventory .radio-attributes .option-item','border-left-color','$content-border-3','','','.w-product-multi-inventory'),(921314,'printshop','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-left-color','$highlight-box-border-1','','','.w-product-multi-inventory'),(921315,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-left-color','$content-border-3','','','.w-account-personal-catalog'),(921316,'printshop','.w-account-personal-catalog .list-row-action ul','border-left-color','$content-border-3','','','.w-account-personal-catalog'),(921317,'printshop','.b-products-listing .products-listing .radio-attributes .option','border-left-color','$content-border-3','','','.b-products-listing'),(921318,'printshop','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-left-color','$highlight-box-border-1','','','.b-products-listing'),(921319,'printshop','.w-product-attributes .radio-attributes .option-item','border-left-color','$content-border-3','','','.w-product-attributes'),(921320,'printshop','.w-product-attributes .radio-attributes input:checked + .option-item','border-left-color','$highlight-box-border-1','','','.w-product-attributes'),(921321,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-left-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(921322,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-left-color','$attention-border','','','.w-questionnaire-widgets-questionnaire'),(921323,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-left-color','$message-border','','','.w-questionnaire-widgets-questionnaire'),(921324,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-left-color','$attention-border','1','','.w-questionnaire-widgets-questionnaire'),(921325,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-left-color','$message-border','1','','.w-questionnaire-widgets-questionnaire'),(921326,'printshop','.w-product-groups .radioBox label .containerBlock','border-left-color','$content-border-3','','','.w-product-groups'),(921327,'printshop','.w-product-groups .radioBox label .containerBlock.selected','border-left-color','$highlight-box-border-2','','','.w-product-groups'),(921328,'printshop','.w-product-groups .radioBox label input:checked + .containerBlock','border-left-color','$highlight-box-border-2','','','.w-product-groups'),(921329,'printshop','.w-delivery-location-location-list .deliveryList li a','border-left-color','$content-border-1','','','.w-delivery-location-location-list'),(921330,'printshop','.w-delivery-location-location-list .deliveryList li a','border-left-color','$highlight-box-border-1','1','','.w-delivery-location-location-list'),(921331,'printshop','.w-sale-category .sale-holder','border-left-color','$content-border-3','','','.w-sale-category'),(921332,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-left-color','$content-border-3','','','.w-product-properties-icons'),(921333,'printshop','.w-product-designer-designer .prodDesignerType label','border-left-color','$content-border-1','','','.w-product-designer-designer'),(921334,'printshop','.b-products-listing .productGroup label a','border-left-color','$highlight-box-border-1','','','.b-products-listing'),(921335,'printshop','.w-support-system-listing .support-head','border-left-color','$content-border-1','','','.w-support-system-listing'),(921336,'printshop','.w-support-system-listing .product_icon','border-left-color','$content-border-1','','','.w-support-system-listing'),(921337,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border-left-color','$attention-border','','','.w-predefined-promotion'),(921338,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-left-color','$attention-border','','','.w-predefined-promotion'),(921339,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-left-color','$attention-border','','','.w-predefined-promotion'),(921340,'printshop','.w-predefined-promotion .promo-salemaker .discount','border-left-color','$warning-border','','','.w-predefined-promotion'),(921341,'printshop','.w-supplier-purchase-supplier-products .item','border-left-color','$content-border-1','','','.w-supplier-purchase-supplier-products'),(921343,'printshop','.btn-1','border-left-color','$btn-border-2','','',''),(921344,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','border-left-color','$content-border-3','','','.w-filters'),(921345,'printshop','.b-quantity .qty-box','border-left-color','$content-border-3','','','.b-quantity'),(921346,'printshop','.w-product-model ','border-left-color','$content-border-3','','','.w-product-model'),(921347,'printshop','.w-checkout-billing-address .same-address','border-left-color','$content-border-3','','','.w-checkout-billing-address'),(921348,'printshop','.btn-3','border-left-color','$btn-border-4','','',''),(921349,'printshop','.middleBanner .btn-1','border-left-color','$additional-banner-border-2','','','.middleBanner'),(921350,'printshop','.bottomBanner .btn-1','border-left-color','$additional-banner-border-2','','','.bottomBanner'),(921351,'printshop','.w-product-personal-catalog-button .btn','border-left-color','$highlight-box-border-2','','','.w-product-personal-catalog-button'),(921352,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-left-color','$highlight-box-border-2','','','.b-products-listing'),(921353,'printshop','.topBanner .content .btn','border-left-color','$main-banner-border-1','','','.topBanner'),(921354,'printshop','.topBanner .ourPick','border-left-color','transparent','3','','.topBanner'),(921355,'printshop','.topBanner .ourPick .top','border-left-color','$main-banner-bg-1','','','.topBanner'),(921356,'printshop','.topBanner .ourPick','border-left-color','transparent','5347,3','','.topBanner'),(921357,'printshop','.topBanner .ourPick','border-left-color','transparent','5363,3','','.topBanner'),(921358,'printshop','.topBanner .ourPick','border-left-color','$main-banner-bg-1','4','','.topBanner'),(921359,'printshop','.p-quote-checkout-index .input-wrapper','border-left-color','$content-border-3','','','.p-quote-checkout-index'),(921362,'printshop','.account-samples .orders-table .item','border-left-color','$content-border-3','5342','','.account-samples'),(921363,'printshop','.catalog-product-wrap .pn-image','border-left-color','$content-border-3','3','','.catalog-product-wrap'),(921364,'printshop','.shopping-cart-index .btn-3','border-left-color','$highlight-box-border-1','','','.shopping-cart-index'),(921365,'printshop','.checkout-index-wrap .input-wrapper','border-left-color','$content-border-3','','','.checkout-index-wrap'),(921366,'printshop','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-color','$highlight-box-border-1','','','.b-multi-page-checkout'),(921367,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-color','$content-border-3','','','.b-multi-page-checkout'),(921368,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-color','$content-border-3','','','.b-multi-page-checkout'),(921369,'printshop','.w-catalog-paging ','border-left-color','#CCCCCC','2','','.w-catalog-paging'),(921370,'printshop','.w-catalog-paging .next','border-left-color','#CCCCCC','','','.w-catalog-paging'),(921371,'printshop','.w-catalog-paging .next-pages','border-left-color','#CCCCCC','','','.w-catalog-paging'),(921372,'printshop','.w-catalog-paging .page-number','border-left-color','#CCCCCC','','','.w-catalog-paging'),(921373,'printshop','.w-catalog-paging .prev','border-left-color','#CCCCCC','','','.w-catalog-paging'),(921374,'printshop','.w-catalog-paging .prev-pages','border-left-color','#CCCCCC','','','.w-catalog-paging'),(921375,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-color','#CCCCCC','','','.w-catalog-paging'),(921376,'printshop','.w-sale .sale-holder','border-left-color','$content-border-3','','','.w-sale'),(921377,'printshop','.b-data-table table.dataTable.no-footer','border-left-color_important','important','','','.b-data-table'),(921378,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(921379,'printshop','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(921380,'printshop','.w-promotions .prom-multi-discount .promo-range','border-left-width','1','','','.w-promotions'),(921381,'printshop','.w-cart-compare .attributes-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(921384,'printshop','.testimonials .review','border-left-width','10','3','',''),(921385,'printshop','.w-promotions .promo-salemaker .discount','border-left-width','1','','','.w-promotions'),(921386,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-width','1','','','.w-promotions'),(921387,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border-left-width','1','','','.w-promotions'),(921388,'printshop','.b-messages .content_management_attach button','border-left-width','1','','','.b-messages'),(921389,'printshop','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-width','2','','','.b-messages'),(921390,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-left-width','1','','',''),(921391,'printshop','.w-product-reviews .reviews-list .review','border-left-width','10','3','','.w-product-reviews'),(921392,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(921393,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border-left-width','2','3','','.b-form'),(921394,'printshop','.b-info-popup .info-popup div','border-left-width','1','3','','.b-info-popup'),(921395,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-left-width','2','3','','.b-switch'),(921396,'printshop','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(921397,'printshop','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(921398,'printshop','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-left-width','1','','','.b-bottom'),(921399,'printshop','.w-socials > li','border-left-width','1','','','.w-socials'),(921401,'printshop','.w-cart-compare .cart-cell > div','border-left-width','1','','','.w-cart-compare'),(921402,'printshop','.b-info-popup .info-popup div','border-left-width','1','','','.b-info-popup'),(921403,'printshop','.w-tabs > .block','border-left-width','1','','','.w-tabs'),(921404,'printshop','.w-socials > li','border-left-width','1','','','.w-socials'),(921405,'printshop','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(921406,'printshop','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(921407,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-left-width','4','','','.b-switch'),(921408,'printshop','.w-filters .ui-slider-handle','border-left-width','0','','','.w-filters'),(921409,'printshop','.w-filters .ui-slider','border-left-width','0','','','.w-filters'),(921410,'printshop','.w-socials > li','border-left-width','1','','','.w-socials'),(921411,'printshop','.w-reviews .review','border-left-width','12','3','','.w-reviews'),(921413,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-left-width','3','','','.b-switch'),(921414,'printshop','.w-reviews-content .review','border-left-width','12','3','','.w-reviews-content'),(921415,'printshop','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(921416,'printshop','.w-socials > li','border-left-width','1','','','.w-socials'),(921417,'printshop','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(921418,'printshop','.b-select-suggest .select2-container .select2-choice','border-left-width','1','','','.b-select-suggest'),(921419,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-left-width','2','4','','.b-switch'),(921421,'printshop','.b-form .required-error','border-left-width','1','','','.b-form'),(921422,'printshop','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(921423,'printshop','textarea','border-left-width','1','','',''),(921424,'printshop','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(921425,'printshop','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-left-width','1','','','.b-bottom'),(921426,'printshop','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(921427,'printshop','.w-cart-compare .product-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(921428,'printshop','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(921429,'printshop','.b-bottom .popup-box','border-left-width','1','','','.b-bottom'),(921430,'printshop','.w-product-customers-activity .customers-activity','border-left-width','1','','','.w-product-customers-activity'),(921431,'printshop','.w-cart-compare .price-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(921432,'printshop','.w-socials > li','border-left-width','1','','','.w-socials'),(921433,'printshop','.w-socials > li','border-left-width','1','','','.w-socials'),(921434,'printshop','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(921435,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(921436,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-width','1','','','.b-select-suggest'),(921437,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(921438,'printshop','.b-select-suggest .select2-container-multi .select2-choices','border-left-width','1','','','.b-select-suggest'),(921439,'printshop','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-width','1','','','.b-select-suggest'),(921440,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','border-left-width','0','','','.b-select-suggest'),(921441,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-width','1','','','.b-select-suggest'),(921442,'printshop','.b-select-suggest .select2-search input','border-left-width','1','','','.b-select-suggest'),(921443,'printshop','.b-select-suggest .select2-drop-active','border-left-width','1','','','.b-select-suggest'),(921444,'printshop','.b-select-suggest .select2-drop','border-left-width','1','','','.b-select-suggest'),(921445,'printshop','.b-upload-file .upload-file-template','border-left-width','1','','','.b-upload-file'),(921446,'printshop','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(921447,'printshop','.checkbox input:checked + span','border-left-width','1','','',''),(921448,'printshop','.checkbox input + span','border-left-width','1','','',''),(921449,'printshop','.b-autocomplete .ui-autocomplete','border-left-width','1','','','.b-autocomplete'),(921452,'printshop','.w-checkout-shipping-choice label:first-child span','border-left-width','2','','','.w-checkout-shipping-choice'),(921453,'printshop','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(921454,'printshop','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(921455,'printshop','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(921456,'printshop','.w-cart-listing .item .gift-wrap label','border-left-width','1','','','.w-cart-listing'),(921457,'printshop','.w-cart-listing .item','border-left-width','1','5342','','.w-cart-listing'),(921459,'printshop','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(921460,'printshop','.w-filters .ui-slider-range','border-left-width','0','','','.w-filters'),(921461,'printshop','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(921462,'printshop','.b-upload-files .upload-files','border-left-width','1','','','.b-upload-files'),(921463,'printshop','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-width','1','','','.b-compare'),(921464,'printshop','.b-upload-file .snapshot','border-left-width','1','','','.b-upload-file'),(921465,'printshop','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-left-width','2','','','.b-product-images'),(921466,'printshop','.b-trade-approval .steps-bar li ~ li a','border-left-width','1','','','.b-trade-approval'),(921467,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-width','2','','','.b-trade-approval'),(921468,'printshop','.w-account-personal-catalog .list-switcher a','border-left-width','1','2','','.w-account-personal-catalog'),(921469,'printshop','.w-catalog-compare .compare .checkbox input:checked + span','border-left-width','1','','','.w-catalog-compare'),(921470,'printshop','.w-catalog-compare .cross-box .different-all > div','border-left-width','1','2','','.w-catalog-compare'),(921471,'printshop','.b-slick .slick-vertical .slick-slide','border-left-width','1','','','.b-slick'),(921472,'printshop','.w-filters .filter-widget','border-left-width','1','','','.w-filters'),(921473,'printshop','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-left-width','0','','','.w-filters'),(921474,'printshop','.w-quote .cart-content','border-left-width','1','','','.w-quote'),(921475,'printshop','.b-product-images .additional-images .active img','border-left-width','2','','','.b-product-images'),(921476,'printshop','.b-product-images .additional-images img','border-left-width','2','','','.b-product-images'),(921477,'printshop','.w-sample .cart-content','border-left-width','1','','','.w-sample'),(921478,'printshop','.w-product-video .item img, .w-product-video .item video','border-left-width','2','','','.w-product-video'),(921479,'printshop','.w-product-video .item.active img, .w-product-video .item.active video','border-left-width','2','','','.w-product-video'),(921480,'printshop','.w-cart-order-reference .btn','border-left-width','2','','','.w-cart-order-reference'),(921481,'printshop','.w-cart-gift-certificate .btn','border-left-width','2','','','.w-cart-gift-certificate'),(921483,'printshop','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-left-width','1','','','.b-pagination'),(921484,'printshop','.b-pagination .pagination .next-pages','border-left-width','1','','','.b-pagination'),(921485,'printshop','.b-pagination .pagination .page-number','border-left-width','1','','','.b-pagination'),(921486,'printshop','.b-pagination .pagination .prev-pages','border-left-width','1','','','.b-pagination'),(921487,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-left-width','1','','','.b-pagination'),(921488,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-left-width','1','','','.b-pagination'),(921489,'printshop','.b-pagination .pagination span','border-left-width','1','2','','.b-pagination'),(921490,'printshop','.w-tabs .tab-li','border-left-width','1','2','','.w-tabs'),(921491,'printshop','.w-product-multi-inventory .radio-attributes .option-item','border-left-width','2','','','.w-product-multi-inventory'),(921492,'printshop','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-left-width','2','','','.w-product-multi-inventory'),(921493,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-left-width','1','','','.w-account-personal-catalog'),(921494,'printshop','.w-account-personal-catalog .list-row-action ul','border-left-width','1','','','.w-account-personal-catalog'),(921495,'printshop','.b-products-listing .products-listing .radio-attributes .option','border-left-width','2','','','.b-products-listing'),(921496,'printshop','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-left-width','2','','','.b-products-listing'),(921497,'printshop','.w-product-attributes .radio-attributes .option-item','border-left-width','2','','','.w-product-attributes'),(921498,'printshop','.w-product-attributes .radio-attributes input:checked + .option-item','border-left-width','2','','','.w-product-attributes'),(921499,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-left-width','2','','','.w-questionnaire-widgets-questionnaire'),(921500,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-left-width','2','','','.w-questionnaire-widgets-questionnaire'),(921501,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-left-width','2','','','.w-questionnaire-widgets-questionnaire'),(921502,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-left-width','2','1','','.w-questionnaire-widgets-questionnaire'),(921503,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-left-width','2','1','','.w-questionnaire-widgets-questionnaire'),(921504,'printshop','.w-product-groups .radioBox label .containerBlock','border-left-width','2','','','.w-product-groups'),(921505,'printshop','.w-product-groups .radioBox label .containerBlock.selected','border-left-width','2','','','.w-product-groups'),(921506,'printshop','.w-product-groups .radioBox label input:checked + .containerBlock','border-left-width','2','','','.w-product-groups'),(921507,'printshop','.w-delivery-location-location-list .deliveryList li a','border-left-width','2','','','.w-delivery-location-location-list'),(921508,'printshop','.w-delivery-location-location-list .deliveryList li a','border-left-width','2','1','','.w-delivery-location-location-list'),(921509,'printshop','.w-sale-category .sale-holder','border-left-width','2','','','.w-sale-category'),(921510,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-left-width','1','','','.w-product-properties-icons'),(921511,'printshop','.w-product-designer-designer .prodDesignerType label','border-left-width','1','','','.w-product-designer-designer'),(921512,'printshop','.b-products-listing .productGroup label a','border-left-width','1','','','.b-products-listing'),(921513,'printshop','.w-support-system-listing .support-head','border-left-width','1','','','.w-support-system-listing'),(921514,'printshop','.w-support-system-listing .product_icon','border-left-width','1','','','.w-support-system-listing'),(921515,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border-left-width','1','','','.w-predefined-promotion'),(921516,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-left-width','1','','','.w-predefined-promotion'),(921517,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-left-width','1','','','.w-predefined-promotion'),(921518,'printshop','.w-predefined-promotion .promo-salemaker .discount','border-left-width','1','','','.w-predefined-promotion'),(921519,'printshop','.w-supplier-purchase-supplier-products .item','border-left-width','1','','','.w-supplier-purchase-supplier-products'),(921521,'printshop','.btn-1','border-left-width','2','','',''),(921522,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','border-left-width','1','','','.w-filters'),(921523,'printshop','.b-quantity .qty-box','border-left-width','2','','','.b-quantity'),(921524,'printshop','.w-product-model ','border-left-width','1','','','.w-product-model'),(921525,'printshop','.w-checkout-billing-address .same-address','border-left-width','1','','','.w-checkout-billing-address'),(921526,'printshop','.btn-3','border-left-width','2','','',''),(921527,'printshop','.middleBanner .btn-1','border-left-width','1','','','.middleBanner'),(921528,'printshop','.bottomBanner .btn-1','border-left-width','1','','','.bottomBanner'),(921529,'printshop','.w-product-personal-catalog-button .btn','border-left-width','2','','','.w-product-personal-catalog-button'),(921530,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-left-width','2','','','.b-products-listing'),(921531,'printshop','.topBanner .content .btn','border-left-width','1','','','.topBanner'),(921532,'printshop','.topBanner .ourPick','border-left-width','14','3','','.topBanner'),(921533,'printshop','.topBanner .ourPick','border-left-width','4','4','','.topBanner'),(921534,'printshop','.topBanner .ourPick .top','border-left-width','1','','','.topBanner'),(921535,'printshop','.topBanner .ourPick','border-left-width','10','5347,3','','.topBanner'),(921536,'printshop','.topBanner .ourPick','border-left-width','4','5347,4','','.topBanner'),(921537,'printshop','.topBanner .ourPick','border-left-width','5','5363,3','','.topBanner'),(921538,'printshop','.topBanner .ourPick','border-left-width','4','5363,4','','.topBanner'),(921539,'printshop','.p-quote-checkout-index .input-wrapper','border-left-width','2','','','.p-quote-checkout-index'),(921542,'printshop','.account-samples .orders-table .item','border-left-width','1','5342','','.account-samples'),(921543,'printshop','.catalog-product-wrap .next-product','border-left-width','1','','','.catalog-product-wrap'),(921544,'printshop','.catalog-product-wrap .pn-image','border-left-width','2','3','','.catalog-product-wrap'),(921545,'printshop','.shopping-cart-index .btn-3','border-left-width','2','','','.shopping-cart-index'),(921546,'printshop','.checkout-index-wrap .input-wrapper','border-left-width','2','','','.checkout-index-wrap'),(921547,'printshop','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(921548,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(921549,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-width','1','','','.b-multi-page-checkout'),(921550,'printshop','.w-catalog-paging ','border-left-width','1','2','','.w-catalog-paging'),(921551,'printshop','.w-catalog-paging .next','border-left-width','1','','','.w-catalog-paging'),(921552,'printshop','.w-catalog-paging .next-pages','border-left-width','1','','','.w-catalog-paging'),(921553,'printshop','.w-catalog-paging .page-number','border-left-width','1','','','.w-catalog-paging'),(921554,'printshop','.w-catalog-paging .prev','border-left-width','1','','','.w-catalog-paging'),(921555,'printshop','.w-catalog-paging .prev-pages','border-left-width','1','','','.w-catalog-paging'),(921556,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-width','1','','','.w-catalog-paging'),(921557,'printshop','.w-sale .sale-holder','border-left-width','2','','','.w-sale'),(921558,'printshop','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-3','','','.b-dropdown'),(921559,'printshop','.w-cart-products .checkout-attention-message','border-right-color','$attention-border','','','.w-cart-products'),(921560,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border-right-color','$checkbox-border-1','3','','.b-form'),(921561,'printshop','.w-promotions .prom-multi-discount .promo-range','border-right-color','$attention-border','','','.w-promotions'),(921562,'printshop','.w-cart-compare .attributes-block td','border-right-color','$content-border-3','','','.w-cart-compare'),(921564,'printshop','.testimonials .review','border-right-color','$transparent','3','',''),(921565,'printshop','.w-promotions .promo-salemaker .discount','border-right-color','$warning-border','','','.w-promotions'),(921566,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-color','$attention-border','','','.w-promotions'),(921567,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border-right-color','$attention-border','','','.w-promotions'),(921568,'printshop','.w-cart-compare .cart-cell > div','border-right-color','$content-border-3','','','.w-cart-compare'),(921569,'printshop','.w-cart-compare .price-block td','border-right-color','$content-border-3','','','.w-cart-compare'),(921570,'printshop','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-right-color','$content-border-3','','','.b-bottom'),(921571,'printshop','.b-messages .content_management_attach button','border-right-color','$highlight-box-border-1','','','.b-messages'),(921572,'printshop','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-color','$content-border-3','','','.b-messages'),(921573,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-right-color','$content-border-1','','',''),(921574,'printshop','.w-cart-products .checkout-attention-message','border-right-color','$attention-border','','','.w-cart-products'),(921575,'printshop','.w-socials > li','border-right-color','$content-border-3','','','.w-socials'),(921576,'printshop','.b-upload-file .upload-file-template','border-right-color','$content-border-3','','','.b-upload-file'),(921577,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-right-color','$switch-nc-border-1','','','.b-switch'),(921578,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(921579,'printshop','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-3','','','.b-dropdown'),(921580,'printshop','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-color','$content-border-1','','','.b-compare'),(921581,'printshop','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-3','','','.b-dropdown'),(921582,'printshop','.w-cart-products .checkout-attention-message','border-right-color','$attention-border','','','.w-cart-products'),(921583,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-color','$content-border-3','','','.b-select-suggest'),(921584,'printshop','.w-checkout-shipping-choice label:last-child span','border-right-color','$highlight-box-border-1','','','.w-checkout-shipping-choice'),(921585,'printshop','.w-socials > li','border-right-color','$content-border-3','','','.w-socials'),(921586,'printshop','.b-info-popup .info-popup div','border-right-color','$content-border-3','','','.b-info-popup'),(921587,'printshop','.w-cart-compare .product-block td','border-right-color','$content-border-3','','','.w-cart-compare'),(921588,'printshop','.w-promo-code .holder','border-right-color','$content-border-3','','','.w-promo-code'),(921589,'printshop','.w-reviews .review','border-right-color','$transparent','3','','.w-reviews'),(921590,'printshop','.w-tabs > .block','border-right-color','$tab-content-border-1','','','.w-tabs'),(921591,'printshop','.w-socials > li','border-right-color','$content-border-3','','','.w-socials'),(921592,'printshop','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-3','','','.b-dropdown'),(921593,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-right-color','$switch-handle-bg-3','','','.b-switch'),(921594,'printshop','.w-socials > li','border-right-color','$content-border-3','','','.w-socials'),(921595,'printshop','.w-promo-code .holder','border-right-color','$content-border-3','','','.w-promo-code'),(921596,'printshop','.w-socials > li','border-right-color','$content-border-3','','','.w-socials'),(921597,'printshop','.w-reviews-content .review','border-right-color','$transparent','3','','.w-reviews-content'),(921598,'printshop','.b-select-suggest .select2-container .select2-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(921599,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-right-color','$switch-nc-border-1','4','','.b-switch'),(921601,'printshop','.w-cart-products .checkout-attention-message','border-right-color','$attention-border','','','.w-cart-products'),(921602,'printshop','.w-socials > li','border-right-color','$content-border-3','','','.w-socials'),(921603,'printshop','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-right-color','$content-bg-1','','','.b-bottom'),(921604,'printshop','textarea','border-right-color','$content-border-1','','',''),(921605,'printshop','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-3','','','.b-dropdown'),(921606,'printshop','.w-promo-code .holder','border-right-color','$content-border-3','','','.w-promo-code'),(921607,'printshop','.b-bottom .popup-box','border-right-color','$content-border-3','','','.b-bottom'),(921608,'printshop','.w-product-customers-activity .customers-activity','border-right-color','$content-border-3','','','.w-product-customers-activity'),(921609,'printshop','.w-product-reviews .reviews-list .review','border-right-color','$transparent','3','','.w-product-reviews'),(921610,'printshop','.w-cart-products .checkout-attention-message','border-right-color','$attention-border','','','.w-cart-products'),(921611,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-color','$content-border-3','','','.b-select-suggest'),(921612,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-color','$content-border-3','','','.b-select-suggest'),(921613,'printshop','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-color','$content-border-3','','','.b-select-suggest'),(921614,'printshop','.b-select-suggest .select2-container-multi .select2-choices','border-right-color','$content-border-3','','','.b-select-suggest'),(921615,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-color','$content-border-3','','','.b-select-suggest'),(921616,'printshop','.b-select-suggest .select2-search input','border-right-color','$content-border-3','','','.b-select-suggest'),(921617,'printshop','.b-select-suggest .select2-drop-active','border-right-color','$content-border-3','','','.b-select-suggest'),(921618,'printshop','.b-select-suggest .select2-drop','border-right-color','$content-border-3','','','.b-select-suggest'),(921619,'printshop','.w-promo-code .holder','border-right-color','$content-border-3','','','.w-promo-code'),(921620,'printshop','.b-form input.required-error','border-right-color','$attention-border','','','.b-form'),(921621,'printshop','.checkbox input:checked + span','border-right-color','$checkbox-border-1','','',''),(921622,'printshop','.checkbox input + span','border-right-color','$checkbox-border-1','','',''),(921623,'printshop','.b-autocomplete .ui-autocomplete','border-right-color','$content-border-3','','','.b-autocomplete'),(921626,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-right-color','$switch-nc-border-1','3','','.b-switch'),(921627,'printshop','.b-upload-file .snapshot','border-right-color','$content-border-1','','','.b-upload-file'),(921628,'printshop','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-3','','','.b-dropdown'),(921629,'printshop','.b-upload-files .upload-files','border-right-color','$content-border-3','','','.b-upload-files'),(921630,'printshop','.b-form .required-error','border-right-color','$attention-border','','','.b-form'),(921631,'printshop','.w-promo-code .holder','border-right-color','$content-border-3','','','.w-promo-code'),(921632,'printshop','.w-cart-products .checkout-attention-message','border-right-color','$attention-border','','','.w-cart-products'),(921633,'printshop','.w-cart-listing .item .gift-wrap label','border-right-color','$content-border-3','','','.w-cart-listing'),(921634,'printshop','.w-cart-listing .item','border-right-color','$content-border-3','5342','','.w-cart-listing'),(921635,'printshop','.w-promo-code .holder','border-right-color','$content-border-3','','','.w-promo-code'),(921637,'printshop','.b-data-table table.dataTable.no-footer','border-right-color','$content-border-3','','','.b-data-table'),(921638,'printshop','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-right-color','$image-popup-border-1','','','.b-product-images'),(921639,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-color','$content-border-3','','','.b-trade-approval'),(921640,'printshop','.w-account-personal-catalog .list-switcher a','border-right-color','$content-border-3','2','','.w-account-personal-catalog'),(921641,'printshop','.w-catalog-compare .compare .checkbox input:checked + span','border-right-color','$content-bg-1','','','.w-catalog-compare'),(921642,'printshop','.w-catalog-compare .cross-box .different-all > div','border-right-color','$content-border-3','2','','.w-catalog-compare'),(921643,'printshop','.w-catalog-compare td:first-child','border-right-color','$content-border-3','','','.w-catalog-compare'),(921645,'printshop','.w-filters .filter-widget','border-right-color','$content-border-3','','','.w-filters'),(921646,'printshop','.w-quote .cart-content','border-right-color','$content-border-3','','','.w-quote'),(921647,'printshop','.b-product-images .additional-images .active img','border-right-color','$image-popup-border-2','','','.b-product-images'),(921648,'printshop','.b-product-images .additional-images img','border-right-color','$image-popup-border-1','','','.b-product-images'),(921649,'printshop','.w-sample .cart-box-link','border-right-color','$highlight-box-border-1','4','','.w-sample'),(921650,'printshop','.w-sample .cart-content','border-right-color','$content-border-3','','','.w-sample'),(921651,'printshop','.w-product-video .item img, .w-product-video .item video','border-right-color','$content-border-1','','','.w-product-video'),(921652,'printshop','.w-product-video .item.active img, .w-product-video .item.active video','border-right-color','$warning-border','','','.w-product-video'),(921653,'printshop','.w-cart-order-reference .btn','border-right-color','$highlight-box-border-1','','','.w-cart-order-reference'),(921654,'printshop','.w-cart-gift-certificate .btn','border-right-color','$highlight-box-border-1','','','.w-cart-gift-certificate'),(921656,'printshop','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-right-color','$highlight-box-border-2','','','.b-pagination'),(921657,'printshop','.b-pagination .pagination .next-pages','border-right-color','$content-border-3','','','.b-pagination'),(921658,'printshop','.b-pagination .pagination .page-number','border-right-color','$content-border-3','','','.b-pagination'),(921659,'printshop','.b-pagination .pagination .prev-pages','border-right-color','$content-border-3','','','.b-pagination'),(921660,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-right-color','$content-border-3','','','.b-pagination'),(921661,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-right-color','$content-border-3','','','.b-pagination'),(921662,'printshop','.b-pagination .pagination span','border-right-color','$highlight-box-border-2','2','','.b-pagination'),(921663,'printshop','.w-tabs .tab-li','border-right-color','$tab-nav-border-2','2','','.w-tabs'),(921664,'printshop','.w-product-multi-inventory .radio-attributes .option-item','border-right-color','$content-border-3','','','.w-product-multi-inventory'),(921665,'printshop','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-right-color','$highlight-box-border-1','','','.w-product-multi-inventory'),(921666,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-right-color','$content-border-3','','','.w-account-personal-catalog'),(921667,'printshop','.w-account-personal-catalog .list-row-action ul','border-right-color','$content-border-3','','','.w-account-personal-catalog'),(921668,'printshop','.b-products-listing .products-listing .radio-attributes .option','border-right-color','$content-border-3','','','.b-products-listing'),(921669,'printshop','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-right-color','$highlight-box-border-1','','','.b-products-listing'),(921670,'printshop','.w-product-attributes .radio-attributes .option-item','border-right-color','$content-border-3','','','.w-product-attributes'),(921671,'printshop','.w-product-attributes .radio-attributes input:checked + .option-item','border-right-color','$highlight-box-border-1','','','.w-product-attributes'),(921672,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-right-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(921673,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-right-color','$attention-border','','','.w-questionnaire-widgets-questionnaire'),(921674,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-right-color','$message-border','','','.w-questionnaire-widgets-questionnaire'),(921675,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-right-color','$attention-border','1','','.w-questionnaire-widgets-questionnaire'),(921676,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-right-color','$message-border','1','','.w-questionnaire-widgets-questionnaire'),(921677,'printshop','.w-product-groups .radioBox label .containerBlock','border-right-color','$content-border-3','','','.w-product-groups'),(921678,'printshop','.w-product-groups .radioBox label .containerBlock.selected','border-right-color','$highlight-box-border-2','','','.w-product-groups'),(921679,'printshop','.w-product-groups .radioBox label input:checked + .containerBlock','border-right-color','$highlight-box-border-2','','','.w-product-groups'),(921680,'printshop','.w-delivery-location-location-list .deliveryList li a','border-right-color','$content-border-1','','','.w-delivery-location-location-list'),(921681,'printshop','.w-delivery-location-location-list .deliveryList li a','border-right-color','$highlight-box-border-1','1','','.w-delivery-location-location-list'),(921682,'printshop','.w-sale-category .sale-holder','border-right-color','$content-border-3','','','.w-sale-category'),(921683,'printshop','.w-product-designer-designer .prodDesignerType label','border-right-color','$content-border-1','','','.w-product-designer-designer'),(921684,'printshop','.b-products-listing .productGroup label a','border-right-color','$highlight-box-border-1','','','.b-products-listing'),(921685,'printshop','.w-support-system-listing .support-head','border-right-color','$content-border-1','','','.w-support-system-listing'),(921686,'printshop','.w-support-system-listing .product_icon','border-right-color','$content-border-1','','','.w-support-system-listing'),(921687,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border-right-color','$attention-border','','','.w-predefined-promotion'),(921688,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-right-color','$attention-border','','','.w-predefined-promotion'),(921689,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-right-color','$attention-border','','','.w-predefined-promotion'),(921690,'printshop','.w-predefined-promotion .promo-salemaker .discount','border-right-color','$warning-border','','','.w-predefined-promotion'),(921691,'printshop','.w-supplier-purchase-supplier-products .item','border-right-color','$content-border-1','','','.w-supplier-purchase-supplier-products'),(921692,'printshop','.btn-1','border-right-color','$btn-border-2','','',''),(921693,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','border-right-color','$content-border-3','','','.w-filters'),(921694,'printshop','.b-quantity .qty-box','border-right-color','$content-border-3','','','.b-quantity'),(921695,'printshop','.w-product-model ','border-right-color','$content-border-3','','','.w-product-model'),(921696,'printshop','.w-checkout-billing-address .same-address','border-right-color','$content-border-3','','','.w-checkout-billing-address'),(921697,'printshop','.btn-3','border-right-color','$btn-border-4','','',''),(921698,'printshop','.middleBanner .btn-1','border-right-color','$additional-banner-border-2','','','.middleBanner'),(921699,'printshop','.bottomBanner .btn-1','border-right-color','$additional-banner-border-2','','','.bottomBanner'),(921700,'printshop','.w-product-personal-catalog-button .btn','border-right-color','$highlight-box-border-2','','','.w-product-personal-catalog-button'),(921701,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-right-color','$highlight-box-border-2','','','.b-products-listing'),(921702,'printshop','.topBanner .content .btn','border-right-color','$main-banner-border-1','','','.topBanner'),(921703,'printshop','.topBanner .ourPick','border-right-color','transparent','4','','.topBanner'),(921704,'printshop','.topBanner .ourPick .top','border-right-color','$main-banner-bg-1','','','.topBanner'),(921705,'printshop','.topBanner .ourPick','border-right-color','transparent','5347,4','','.topBanner'),(921706,'printshop','.topBanner .ourPick','border-right-color','transparent','5363,4','','.topBanner'),(921707,'printshop','.topBanner .ourPick','border-right-color','$main-banner-bg-1','3','','.topBanner'),(921708,'printshop','.p-quote-checkout-index .input-wrapper','border-right-color','$content-border-3','','','.p-quote-checkout-index'),(921711,'printshop','.account-samples .orders-table .item','border-right-color','$content-border-3','5342','','.account-samples'),(921712,'printshop','.catalog-product-wrap .pn-image','border-right-color','$content-border-3','3','','.catalog-product-wrap'),(921713,'printshop','.shopping-cart-index .btn-3','border-right-color','$highlight-box-border-1','','','.shopping-cart-index'),(921714,'printshop','.checkout-index-wrap .input-wrapper','border-right-color','$content-border-3','','','.checkout-index-wrap'),(921715,'printshop','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-color','$highlight-box-border-1','','','.b-multi-page-checkout'),(921716,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-color','$content-border-3','','','.b-multi-page-checkout'),(921717,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-color','$content-border-3','','','.b-multi-page-checkout'),(921719,'printshop','.w-catalog-paging ','border-right-color','#CCCCCC','2','','.w-catalog-paging'),(921720,'printshop','.w-catalog-paging .next','border-right-color','#CCCCCC','','','.w-catalog-paging'),(921721,'printshop','.w-catalog-paging .next-pages','border-right-color','#CCCCCC','','','.w-catalog-paging'),(921722,'printshop','.w-catalog-paging .page-number','border-right-color','#CCCCCC','','','.w-catalog-paging'),(921723,'printshop','.w-catalog-paging .prev','border-right-color','#CCCCCC','','','.w-catalog-paging'),(921724,'printshop','.w-catalog-paging .prev-pages','border-right-color','#CCCCCC','','','.w-catalog-paging'),(921725,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-color','#CCCCCC','','','.w-catalog-paging'),(921726,'printshop','.w-sale .sale-holder','border-right-color','$content-border-3','','','.w-sale'),(921727,'printshop','.b-data-table table.dataTable.no-footer','border-right-color_important','important','','','.b-data-table'),(921728,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(921729,'printshop','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(921730,'printshop','.w-promotions .prom-multi-discount .promo-range','border-right-width','1','','','.w-promotions'),(921731,'printshop','.w-cart-compare .attributes-block td','border-right-width','1','','','.w-cart-compare'),(921733,'printshop','.testimonials .review','border-right-width','10','3','',''),(921734,'printshop','.w-promotions .promo-salemaker .discount','border-right-width','1','','','.w-promotions'),(921735,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-width','1','','','.w-promotions'),(921736,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border-right-width','1','','','.w-promotions'),(921737,'printshop','.w-cart-compare .cart-cell > div','border-right-width','1','','','.w-cart-compare'),(921738,'printshop','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-right-width','1','','','.b-bottom'),(921739,'printshop','.b-messages .content_management_attach button','border-right-width','1','','','.b-messages'),(921740,'printshop','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-width','2','','','.b-messages'),(921741,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-right-width','1','','',''),(921742,'printshop','.w-socials > li','border-right-width','1','','','.w-socials'),(921743,'printshop','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(921744,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(921745,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border-right-width','2','3','','.b-form'),(921746,'printshop','.w-socials > li','border-right-width','1','','','.w-socials'),(921747,'printshop','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(921748,'printshop','.w-socials > li','border-right-width','1','','','.w-socials'),(921751,'printshop','.b-info-popup .info-popup div','border-right-width','1','','','.b-info-popup'),(921752,'printshop','.w-checkout-shipping-choice label:last-child span','border-right-width','2','','','.w-checkout-shipping-choice'),(921753,'printshop','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(921754,'printshop','.w-tabs > .block','border-right-width','1','','','.w-tabs'),(921755,'printshop','.w-socials > li','border-right-width','1','','','.w-socials'),(921756,'printshop','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(921757,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-right-width','4','','','.b-switch'),(921758,'printshop','.w-filters .ui-slider-handle','border-right-width','0','','','.w-filters'),(921759,'printshop','.w-filters .ui-slider','border-right-width','0','','','.w-filters'),(921760,'printshop','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(921761,'printshop','.w-socials > li','border-right-width','1','','','.w-socials'),(921762,'printshop','.w-reviews .review','border-right-width','12','3','','.w-reviews'),(921763,'printshop','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(921764,'printshop','.w-product-reviews .reviews-list .review','border-right-width','10','3','','.w-product-reviews'),(921765,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-right-width','3','','','.b-switch'),(921766,'printshop','.w-reviews-content .review','border-right-width','12','3','','.w-reviews-content'),(921767,'printshop','.w-socials > li','border-right-width','1','','','.w-socials'),(921768,'printshop','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(921769,'printshop','.b-select-suggest .select2-container .select2-choice','border-right-width','1','','','.b-select-suggest'),(921770,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-right-width','2','4','','.b-switch'),(921772,'printshop','.w-cart-compare .product-block td','border-right-width','1','','','.w-cart-compare'),(921773,'printshop','.b-form .required-error','border-right-width','1','','','.b-form'),(921774,'printshop','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(921775,'printshop','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(921776,'printshop','textarea','border-right-width','1','','',''),(921777,'printshop','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-right-width','1','','','.b-bottom'),(921778,'printshop','.b-bottom .popup-box','border-right-width','1','','','.b-bottom'),(921779,'printshop','.w-product-customers-activity .customers-activity','border-right-width','1','','','.w-product-customers-activity'),(921780,'printshop','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(921781,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(921782,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-width','1','','','.b-select-suggest'),(921783,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(921784,'printshop','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-width','1','','','.b-select-suggest'),(921785,'printshop','.b-select-suggest .select2-container-multi .select2-choices','border-right-width','1','','','.b-select-suggest'),(921786,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-width','1','','','.b-select-suggest'),(921787,'printshop','.b-select-suggest .select2-search input','border-right-width','1','','','.b-select-suggest'),(921788,'printshop','.b-select-suggest .select2-drop','border-right-width','1','','','.b-select-suggest'),(921789,'printshop','.b-select-suggest .select2-drop-active','border-right-width','1','','','.b-select-suggest'),(921790,'printshop','.w-cart-compare .price-block td','border-right-width','1','','','.w-cart-compare'),(921791,'printshop','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-width','1','','','.b-compare'),(921792,'printshop','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(921793,'printshop','.checkbox input:checked + span','border-right-width','1','','',''),(921794,'printshop','.checkbox input + span','border-right-width','1','','',''),(921795,'printshop','.b-autocomplete .ui-autocomplete','border-right-width','1','','','.b-autocomplete'),(921798,'printshop','.b-upload-file .upload-file-template','border-right-width','1','','','.b-upload-file'),(921799,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-right-width','2','3','','.b-switch'),(921800,'printshop','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(921801,'printshop','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(921802,'printshop','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(921803,'printshop','.w-cart-listing .item .gift-wrap label','border-right-width','1','','','.w-cart-listing'),(921804,'printshop','.w-cart-listing .item','border-right-width','1','5342','','.w-cart-listing'),(921806,'printshop','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(921807,'printshop','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(921808,'printshop','.w-filters .ui-slider-range','border-right-width','0','','','.w-filters'),(921809,'printshop','.b-upload-files .upload-files','border-right-width','1','','','.b-upload-files'),(921810,'printshop','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(921811,'printshop','.b-upload-file .snapshot','border-right-width','1','','','.b-upload-file'),(921812,'printshop','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-right-width','2','','','.b-product-images'),(921813,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-width','2','','','.b-trade-approval'),(921814,'printshop','.w-account-personal-catalog .list-switcher a','border-right-width','1','2','','.w-account-personal-catalog'),(921815,'printshop','.w-catalog-compare .compare .checkbox input:checked + span','border-right-width','1','','','.w-catalog-compare'),(921816,'printshop','.w-catalog-compare td:first-child','border-right-width','1','','','.w-catalog-compare'),(921817,'printshop','.w-catalog-compare .cross-box .different-all > div','border-right-width','1','2','','.w-catalog-compare'),(921818,'printshop','.b-slick .slick-vertical .slick-slide','border-right-width','1','','','.b-slick'),(921819,'printshop','.w-filters .filter-widget','border-right-width','1','','','.w-filters'),(921820,'printshop','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-right-width','0','','','.w-filters'),(921821,'printshop','.w-quote .cart-content','border-right-width','1','','','.w-quote'),(921822,'printshop','.b-product-images .additional-images .active img','border-right-width','2','','','.b-product-images'),(921823,'printshop','.b-product-images .additional-images img','border-right-width','2','','','.b-product-images'),(921824,'printshop','.w-sample .cart-box-link','border-right-width','1','4','','.w-sample'),(921825,'printshop','.w-sample .cart-content','border-right-width','1','','','.w-sample'),(921826,'printshop','.w-product-video .item img, .w-product-video .item video','border-right-width','2','','','.w-product-video'),(921827,'printshop','.w-product-video .item.active img, .w-product-video .item.active video','border-right-width','2','','','.w-product-video'),(921828,'printshop','.w-cart-order-reference .btn','border-right-width','2','','','.w-cart-order-reference'),(921829,'printshop','.w-cart-gift-certificate .btn','border-right-width','2','','','.w-cart-gift-certificate'),(921831,'printshop','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-right-width','1','','','.b-pagination'),(921832,'printshop','.b-pagination .pagination .next-pages','border-right-width','1','','','.b-pagination'),(921833,'printshop','.b-pagination .pagination .page-number','border-right-width','1','','','.b-pagination'),(921834,'printshop','.b-pagination .pagination .prev-pages','border-right-width','1','','','.b-pagination'),(921835,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-right-width','1','','','.b-pagination'),(921836,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-right-width','1','','','.b-pagination'),(921837,'printshop','.b-pagination .pagination span','border-right-width','1','2','','.b-pagination'),(921838,'printshop','.w-tabs .tab-li','border-right-width','1','2','','.w-tabs'),(921839,'printshop','.w-product-multi-inventory .radio-attributes .option-item','border-right-width','2','','','.w-product-multi-inventory'),(921840,'printshop','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-right-width','2','','','.w-product-multi-inventory'),(921841,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-right-width','1','','','.w-account-personal-catalog'),(921842,'printshop','.w-account-personal-catalog .list-row-action ul','border-right-width','1','','','.w-account-personal-catalog'),(921843,'printshop','.b-products-listing .products-listing .radio-attributes .option','border-right-width','2','','','.b-products-listing'),(921844,'printshop','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-right-width','2','','','.b-products-listing'),(921845,'printshop','.w-product-attributes .radio-attributes .option-item','border-right-width','2','','','.w-product-attributes'),(921846,'printshop','.w-product-attributes .radio-attributes input:checked + .option-item','border-right-width','2','','','.w-product-attributes'),(921847,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-right-width','2','','','.w-questionnaire-widgets-questionnaire'),(921848,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-right-width','2','','','.w-questionnaire-widgets-questionnaire'),(921849,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-right-width','2','','','.w-questionnaire-widgets-questionnaire'),(921850,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-right-width','2','1','','.w-questionnaire-widgets-questionnaire'),(921851,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-right-width','2','1','','.w-questionnaire-widgets-questionnaire'),(921852,'printshop','.w-product-groups .radioBox label .containerBlock','border-right-width','2','','','.w-product-groups'),(921853,'printshop','.w-product-groups .radioBox label .containerBlock.selected','border-right-width','2','','','.w-product-groups'),(921854,'printshop','.w-product-groups .radioBox label input:checked + .containerBlock','border-right-width','2','','','.w-product-groups'),(921855,'printshop','.w-delivery-location-location-list .deliveryList li a','border-right-width','2','','','.w-delivery-location-location-list'),(921856,'printshop','.w-delivery-location-location-list .deliveryList li a','border-right-width','2','1','','.w-delivery-location-location-list'),(921857,'printshop','.w-sale-category .sale-holder','border-right-width','2','','','.w-sale-category'),(921858,'printshop','.w-product-designer-designer .prodDesignerType label','border-right-width','1','','','.w-product-designer-designer'),(921859,'printshop','.b-products-listing .productGroup label a','border-right-width','1','','','.b-products-listing'),(921860,'printshop','.w-support-system-listing .support-head','border-right-width','1','','','.w-support-system-listing'),(921861,'printshop','.w-support-system-listing .product_icon','border-right-width','1','','','.w-support-system-listing'),(921862,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border-right-width','1','','','.w-predefined-promotion'),(921863,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-right-width','1','','','.w-predefined-promotion'),(921864,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-right-width','1','','','.w-predefined-promotion'),(921865,'printshop','.w-predefined-promotion .promo-salemaker .discount','border-right-width','1','','','.w-predefined-promotion'),(921866,'printshop','.w-supplier-purchase-supplier-products .item','border-right-width','1','','','.w-supplier-purchase-supplier-products'),(921867,'printshop','.btn-1','border-right-width','2','','',''),(921868,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','border-right-width','1','','','.w-filters'),(921869,'printshop','.b-quantity .qty-box','border-right-width','2','','','.b-quantity'),(921870,'printshop','.w-product-model ','border-right-width','1','','','.w-product-model'),(921871,'printshop','.w-checkout-billing-address .same-address','border-right-width','1','','','.w-checkout-billing-address'),(921872,'printshop','.btn-3','border-right-width','2','','',''),(921873,'printshop','.middleBanner .btn-1','border-right-width','1','','','.middleBanner'),(921874,'printshop','.bottomBanner .btn-1','border-right-width','1','','','.bottomBanner'),(921875,'printshop','.w-product-personal-catalog-button .btn','border-right-width','2','','','.w-product-personal-catalog-button'),(921876,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-right-width','2','','','.b-products-listing'),(921877,'printshop','.topBanner .content .btn','border-right-width','1','','','.topBanner'),(921878,'printshop','.topBanner .ourPick','border-right-width','4','3','','.topBanner'),(921879,'printshop','.topBanner .ourPick','border-right-width','14','4','','.topBanner'),(921880,'printshop','.topBanner .ourPick .top','border-right-width','1','','','.topBanner'),(921881,'printshop','.topBanner .ourPick','border-right-width','4','5347,3','','.topBanner'),(921882,'printshop','.topBanner .ourPick','border-right-width','10','5347,4','','.topBanner'),(921883,'printshop','.topBanner .ourPick','border-right-width','4','5363,3','','.topBanner'),(921884,'printshop','.topBanner .ourPick','border-right-width','5','5363,4','','.topBanner'),(921885,'printshop','.p-quote-checkout-index .input-wrapper','border-right-width','2','','','.p-quote-checkout-index'),(921888,'printshop','.account-samples .orders-table .item','border-right-width','1','5342','','.account-samples'),(921889,'printshop','.catalog-product-wrap .pn-image','border-right-width','2','3','','.catalog-product-wrap'),(921890,'printshop','.catalog-product-wrap .prev-product','border-right-width','1','','','.catalog-product-wrap'),(921891,'printshop','.shopping-cart-index .btn-3','border-right-width','2','','','.shopping-cart-index'),(921892,'printshop','.checkout-index-wrap .input-wrapper','border-right-width','2','','','.checkout-index-wrap'),(921893,'printshop','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(921894,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(921895,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-width','1','','','.b-multi-page-checkout'),(921897,'printshop','.w-catalog-paging ','border-right-width','1','2','','.w-catalog-paging'),(921898,'printshop','.w-catalog-paging .next','border-right-width','1','','','.w-catalog-paging'),(921899,'printshop','.w-catalog-paging .next-pages','border-right-width','1','','','.w-catalog-paging'),(921900,'printshop','.w-catalog-paging .page-number','border-right-width','1','','','.w-catalog-paging'),(921901,'printshop','.w-catalog-paging .prev','border-right-width','1','','','.w-catalog-paging'),(921902,'printshop','.w-catalog-paging .prev-pages','border-right-width','1','','','.w-catalog-paging'),(921903,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-width','1','','','.w-catalog-paging'),(921904,'printshop','.w-sale .sale-holder','border-right-width','2','','','.w-sale'),(921905,'printshop','.b-select-suggest .select2-drop-active','border-top','none','','','.b-select-suggest'),(921906,'printshop','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','border-top','none','','','.order-summary'),(921907,'printshop','.order-summary .price-row.ot_gv + .price-row, .order-summary .price-row.ot_coupon + .price-row, .order-summary .price-row.ot_bonus_points + .price-row','border-top','none','','','.order-summary'),(921910,'printshop','.account-samples .orders-table','border-top','none','','','.account-samples'),(921911,'printshop','.catalog-product-wrap .pn-image','border-top','none','5342','','.catalog-product-wrap'),(921912,'printshop','.w-communication-new-topic td','border-top-color','$content-border-3','','','.w-communication-new-topic'),(921913,'printshop','.b-email .model','border-top-color','$content-border-3','','','.b-email'),(921914,'printshop','.order-summary .price-row + .price-row','border-top-color','$content-border-3','','','.order-summary'),(921915,'printshop','.b-social-login .social-login-text-2','border-top-color','$content-border-3','4','','.b-social-login'),(921916,'printshop','.b-email .totals-table','border-top-color','$content-border-3','','','.b-email'),(921917,'printshop','.w-promotions .prom-multi-discount .promo-range','border-top-color','$attention-border','','','.w-promotions'),(921918,'printshop','.w-socials > li','border-top-color','$content-border-3','','','.w-socials'),(921919,'printshop','.w-cart-compare .attributes-block td','border-top-color','$content-border-3','','','.w-cart-compare'),(921921,'printshop','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-3','','','.b-dropdown'),(921922,'printshop','.b-email .price','border-top-color','$content-border-3','','','.b-email'),(921923,'printshop','.testimonials .review','border-top-color','$content-border-1','3','',''),(921924,'printshop','.w-promotions .promo-salemaker .discount','border-top-color','$warning-border','','','.w-promotions'),(921925,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-color','$attention-border','','','.w-promotions'),(921926,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border-top-color','$attention-border','','','.w-promotions'),(921927,'printshop','.w-cart-compare .cart-cell > div','border-top-color','$content-border-3','','','.w-cart-compare'),(921928,'printshop','.w-cart-products .checkout-attention-message','border-top-color','$attention-border','','','.w-cart-products'),(921929,'printshop','.b-upload-file .upload-file-template','border-top-color','$content-border-3','','','.b-upload-file'),(921930,'printshop','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-top-color','$content-border-3','','','.b-bottom'),(921931,'printshop','.b-messages .messMenuButtonTop','border-top-color','$content-border-3','','','.b-messages'),(921932,'printshop','.b-messages .msv_btn','border-top-color','$content-border-3','','','.b-messages'),(921933,'printshop','.b-messages .email-heading','border-top-color','$content-border-3','','','.b-messages'),(921934,'printshop','.b-messages .dataTable','border-top-color','$content-border-3','','','.b-messages'),(921935,'printshop','.b-messages .messages-menu li + li','border-top-color','$content-border-3','','','.b-messages'),(921936,'printshop','.b-messages .content_management_attach button','border-top-color','$highlight-box-border-1','','','.b-messages'),(921937,'printshop','.b-messages .content_management_attach','border-top-color','$content-border-3','','','.b-messages'),(921938,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-top-color','$content-border-1','','',''),(921939,'printshop','.b-social-login .social-login-text-2','border-top-color','$content-border-3','4','','.b-social-login'),(921940,'printshop','.b-email .name','border-top-color','$content-border-3','','','.b-email'),(921941,'printshop','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-3','','','.b-dropdown'),(921942,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-color','$switch-nc-border-1','','','.b-switch'),(921943,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(921944,'printshop','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-3','','','.b-table'),(921945,'printshop','.b-social-login .social-login-text-2','border-top-color','$content-border-3','3','','.b-social-login'),(921946,'printshop','.b-info div + .info','border-top-color','$content-border-3','','','.b-info'),(921947,'printshop','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-color','$content-border-1','','','.b-compare'),(921948,'printshop','.w-cart-products .checkout-attention-message','border-top-color','$attention-border','','','.w-cart-products'),(921949,'printshop','.w-promo-code .holder','border-top-color','$content-border-3','','','.w-promo-code'),(921950,'printshop','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-3','','','.b-tracking-numbers'),(921951,'printshop','.b-email .price','border-top-color','$content-border-3','','','.b-email'),(921952,'printshop','.b-email .model','border-top-color','$content-border-3','','','.b-email'),(921953,'printshop','.w-checkout-shipping-choice span','border-top-color','$highlight-box-border-1','','','.w-checkout-shipping-choice'),(921954,'printshop','.w-socials > li','border-top-color','$content-border-3','','','.w-socials'),(921955,'printshop','.b-social-login .social-login-text-2','border-top-color','$content-border-3','4','','.b-social-login'),(921956,'printshop','.b-info-popup .info-popup div','border-top-color','$content-border-3','','','.b-info-popup'),(921957,'printshop','.w-socials > li','border-top-color','$content-border-3','','','.w-socials'),(921958,'printshop','.b-info div + .info','border-top-color','$content-border-3','','','.b-info'),(921959,'printshop','.b-email .price','border-top-color','$content-border-3','','','.b-email'),(921960,'printshop','.b-email .name','border-top-color','$content-border-3','','','.b-email'),(921961,'printshop','.b-email .totals-table','border-top-color','$content-border-3','','','.b-email'),(921962,'printshop','.b-email .image','border-top-color','$content-border-3','','','.b-email'),(921964,'printshop','.w-socials > li','border-top-color','$content-border-3','','','.w-socials'),(921966,'printshop','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-3','','','.b-dropdown'),(921967,'printshop','.totals-line','border-top-color','$content-border-1','','',''),(921968,'printshop','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-3','','','.b-tracking-numbers'),(921969,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-color','$switch-handle-bg-3','','','.b-switch'),(921970,'printshop','.b-info div + .info','border-top-color','$content-border-3','','','.b-info'),(921971,'printshop','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-color','$content-border-3','','','.b-messages'),(921972,'printshop','.b-email .model','border-top-color','$content-border-3','','','.b-email'),(921973,'printshop','.w-reviews .review','border-top-color','$transparent','3','','.w-reviews'),(921974,'printshop','.b-email .price','border-top-color','$content-border-3','','','.b-email'),(921975,'printshop','.w-reviews-content .review','border-top-color','$transparent','3','','.w-reviews-content'),(921977,'printshop','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-3','','','.b-tracking-numbers'),(921978,'printshop','.b-email .name','border-top-color','$content-border-3','','','.b-email'),(921979,'printshop','.b-email .qty','border-top-color','$content-border-3','','','.b-email'),(921980,'printshop','.w-socials > li','border-top-color','$content-border-3','','','.w-socials'),(921981,'printshop','.b-email .image','border-top-color','$content-border-3','','','.b-email'),(921982,'printshop','.b-email .totals-table','border-top-color','$content-border-3','','','.b-email'),(921983,'printshop','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-3','','','.b-tracking-numbers'),(921984,'printshop','.b-email .image','border-top-color','$content-border-3','','','.b-email'),(921985,'printshop','.b-email .name','border-top-color','$content-border-3','','','.b-email'),(921986,'printshop','.b-email .qty','border-top-color','$content-border-3','','','.b-email'),(921987,'printshop','.b-email .model','border-top-color','$content-border-3','','','.b-email'),(921988,'printshop','.b-email .price','border-top-color','$content-border-3','','','.b-email'),(921989,'printshop','.w-checkout-shipping .sub-item + .sub-item','border-top-color','$content-border-3','','','.w-checkout-shipping'),(921990,'printshop','.b-form .required-error','border-top-color','$attention-border','','','.b-form'),(921991,'printshop','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-3','','','.b-dropdown'),(921992,'printshop','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-3','','','.b-table'),(921993,'printshop','.w-promo-code .holder','border-top-color','$content-border-3','','','.w-promo-code'),(921994,'printshop','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-3','','','.b-tracking-numbers'),(921995,'printshop','.b-select-suggest .select2-container .select2-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(921997,'printshop','.b-social-login .social-login-text-2','border-top-color','$content-border-3','4','','.b-social-login'),(921998,'printshop','.b-social-login .social-login-text-2','border-top-color','$content-border-3','3','','.b-social-login'),(921999,'printshop','textarea','border-top-color','$content-border-1','','',''),(922000,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-color','$switch-nc-border-1','4','','.b-switch'),(922001,'printshop','.b-social-login .social-login-text-2','border-top-color','$content-border-3','4','','.b-social-login'),(922002,'printshop','.b-social-login .social-login-text-2','border-top-color','$content-border-3','3','','.b-social-login'),(922004,'printshop','.b-info div + .info','border-top-color','$content-border-3','','','.b-info'),(922005,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border-top-color','$checkbox-border-1','3','','.b-form'),(922006,'printshop','.w-cart-products .checkout-attention-message','border-top-color','$attention-border','','','.w-cart-products'),(922007,'printshop','.w-cart-products .checkout-attention-message','border-top-color','$attention-border','','','.w-cart-products'),(922008,'printshop','.b-social-login .social-login-text-2','border-top-color','$content-border-3','3','','.b-social-login'),(922009,'printshop','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-3','','','.b-dropdown'),(922010,'printshop','.b-email .name','border-top-color','$content-border-3','','','.b-email'),(922011,'printshop','.b-email .qty','border-top-color','$content-border-3','','','.b-email'),(922012,'printshop','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-top-color','$content-bg-1','','','.b-bottom'),(922014,'printshop','.w-promo-code .holder','border-top-color','$content-border-3','','','.w-promo-code'),(922015,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-color','$content-border-3','','','.b-select-suggest'),(922016,'printshop','.b-email .totals-table','border-top-color','$content-border-3','','','.b-email'),(922017,'printshop','.b-email .image','border-top-color','$content-border-3','','','.b-email'),(922018,'printshop','.b-email .qty','border-top-color','$content-border-3','','','.b-email'),(922019,'printshop','.w-cart-compare .product-block td','border-top-color','$content-border-3','','','.w-cart-compare'),(922020,'printshop','.b-bottom .popup-box','border-top-color','$content-border-3','','','.b-bottom'),(922021,'printshop','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-3','','','.b-dropdown'),(922022,'printshop','.b-email .model','border-top-color','$content-border-3','','','.b-email'),(922023,'printshop','.b-info div + .info','border-top-color','$content-border-3','','','.b-info'),(922024,'printshop','.w-product-customers-activity .customers-activity','border-top-color','$content-border-3','','','.w-product-customers-activity'),(922025,'printshop','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-3','','','.b-table'),(922026,'printshop','.b-email .model','border-top-color','$content-border-3','','','.b-email'),(922027,'printshop','.b-social-login .social-login-text-2','border-top-color','$content-border-3','3','','.b-social-login'),(922028,'printshop','.w-cart-compare .price-block td','border-top-color','$content-border-3','','','.w-cart-compare'),(922029,'printshop','.w-promo-code .holder','border-top-color','$content-border-3','','','.w-promo-code'),(922030,'printshop','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-3','','','.b-table'),(922031,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-color','$content-border-3','','','.b-select-suggest'),(922032,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-color','$content-border-3','','','.b-select-suggest'),(922033,'printshop','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-color','$content-border-3','','','.b-select-suggest'),(922034,'printshop','.b-select-suggest .select2-container-multi .select2-choices','border-top-color','$content-border-3','','','.b-select-suggest'),(922035,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-color','$content-border-3','','','.b-select-suggest'),(922037,'printshop','.b-select-suggest .select2-search input','border-top-color','$content-border-3','','','.b-select-suggest'),(922038,'printshop','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-color','$content-border-3','','','.b-select-suggest'),(922039,'printshop','.b-select-suggest .select2-drop.select2-drop-above','border-top-color','$content-border-3','','','.b-select-suggest'),(922040,'printshop','.b-select-suggest .select2-drop-active','border-top-color','$content-border-3','','','.b-select-suggest'),(922041,'printshop','.b-select-suggest .select2-drop','border-top-color','$content-border-3','','','.b-select-suggest'),(922042,'printshop','.b-select-suggest .select2-drop-auto-width','border-top-color','$content-border-3','','','.b-select-suggest'),(922044,'printshop','.w-promo-code .holder','border-top-color','$content-border-3','','','.w-promo-code'),(922045,'printshop','.b-form input.required-error','border-top-color','$attention-border','','','.b-form'),(922046,'printshop','.w-communication-post .communication-post','border-top-color','$content-border-3','','','.w-communication-post'),(922047,'printshop','.checkbox input:checked + span','border-top-color','$checkbox-border-1','','',''),(922048,'printshop','.checkbox input + span','border-top-color','$checkbox-border-1','','',''),(922049,'printshop','.b-autocomplete .ui-autocomplete','border-top-color','$content-border-3','','','.b-autocomplete'),(922052,'printshop','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-3','','','.b-table'),(922053,'printshop','.b-info-popup .info-popup div','border-top-color','$content-border-3','3','','.b-info-popup'),(922054,'printshop','.w-socials > li','border-top-color','$content-border-3','','','.w-socials'),(922055,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-color','$switch-nc-border-1','3','','.b-switch'),(922056,'printshop','.b-email .qty','border-top-color','$content-border-3','','','.b-email'),(922057,'printshop','.b-email .totals-table','border-top-color','$content-border-3','','','.b-email'),(922058,'printshop','.b-email .name','border-top-color','$content-border-3','','','.b-email'),(922059,'printshop','.w-product-reviews .reviews-list .review','border-top-color','$content-border-3','3','','.w-product-reviews'),(922060,'printshop','.b-email .price','border-top-color','$content-border-3','','','.b-email'),(922061,'printshop','.b-email .image','border-top-color','$content-border-3','','','.b-email'),(922062,'printshop','.w-promo-code .holder','border-top-color','$content-border-3','','','.w-promo-code'),(922063,'printshop','.b-email .image','border-top-color','$content-border-3','','','.b-email'),(922064,'printshop','.w-cart-products .checkout-attention-message','border-top-color','$attention-border','','','.w-cart-products'),(922065,'printshop','.w-cart-listing .item .gift-wrap label','border-top-color','$content-border-3','','','.w-cart-listing'),(922066,'printshop','.w-cart-listing .item','border-top-color','$content-border-3','5342','','.w-cart-listing'),(922068,'printshop','.view-all','border-top-color','$content-border-1','3','',''),(922069,'printshop','.w-cart-products .checkout-attention-message','border-top-color','$attention-border','','','.w-cart-products'),(922070,'printshop','.b-social-login .social-login-text-2','border-top-color','$content-border-3','4','','.b-social-login'),(922071,'printshop','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-3','','','.b-tracking-numbers'),(922072,'printshop','.b-upload-files .added-file','border-top-color','$content-border-3','','','.b-upload-files'),(922073,'printshop','.b-data-table table.dataTable.no-footer','border-top-color','$content-border-3','','','.b-data-table'),(922074,'printshop','.b-data-table table.dataTable tbody td','border-top-color','$content-border-3','','','.b-data-table'),(922075,'printshop','.b-upload-files .upload-files','border-top-color','$content-border-3','','','.b-upload-files'),(922076,'printshop','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-3','','','.b-table'),(922077,'printshop','.b-social-login .social-login-text-2','border-top-color','$content-border-3','3','','.b-social-login'),(922078,'printshop','.b-info div + .info','border-top-color','$content-border-3','','','.b-info'),(922079,'printshop','.b-email .totals-table','border-top-color','$content-border-3','','','.b-email'),(922080,'printshop','.b-email .qty','border-top-color','$content-border-3','','','.b-email'),(922081,'printshop','.b-upload-file .snapshot','border-top-color','$content-border-1','','','.b-upload-file'),(922082,'printshop','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-top-color','$image-popup-border-1','','','.b-product-images'),(922083,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-color','$content-border-3','','','.b-trade-approval'),(922084,'printshop','.w-account-personal-catalog .list-switcher a','border-top-color','$highlight-box-border-2','2','','.w-account-personal-catalog'),(922085,'printshop','.w-account-subscription .subscription-variant + .subscription-variant','border-top-color','$content-border-1','','','.w-account-subscription'),(922086,'printshop','.w-catalog-compare .compare .checkbox input:checked + span','border-top-color','$content-bg-1','','','.w-catalog-compare'),(922087,'printshop','.w-catalog-compare .cross-box .different-all > div','border-top-color','$highlight-box-border-1','2','','.w-catalog-compare'),(922088,'printshop','.w-delivery-day .left-text-left','border-top-color','$content-border-3','','','.w-delivery-day'),(922089,'printshop','.w-delivery-day .left-text-right','border-top-color','$content-border-3','','','.w-delivery-day'),(922091,'printshop','.w-filters .filter-widget','border-top-color','$content-border-3','','','.w-filters'),(922092,'printshop','.w-quote .cart-content','border-top-color','$content-border-3','','','.w-quote'),(922093,'printshop','.b-product-images .additional-images .active img','border-top-color','$image-popup-border-2','','','.b-product-images'),(922094,'printshop','.b-product-images .additional-images img','border-top-color','$image-popup-border-1','','','.b-product-images'),(922095,'printshop','.w-product-sale-ends .left-text-left','border-top-color','$content-border-1','','','.w-product-sale-ends'),(922096,'printshop','.w-product-sale-ends .left-text-right','border-top-color','$content-border-1','','','.w-product-sale-ends'),(922097,'printshop','.w-files-catalog-widgets-files-list .item + .item','border-top-color','$content-border-1','','','.w-files-catalog-widgets-files-list'),(922098,'printshop','.w-sample .cart-content','border-top-color','$content-border-3','','','.w-sample'),(922099,'printshop','.w-product-video .item img, .w-product-video .item video','border-top-color','$content-border-1','','','.w-product-video'),(922100,'printshop','.w-product-video .item.active img, .w-product-video .item.active video','border-top-color','$warning-border','','','.w-product-video'),(922101,'printshop','.w-cart-order-reference .btn','border-top-color','$highlight-box-border-1','','','.w-cart-order-reference'),(922102,'printshop','.w-cart-gift-certificate .btn','border-top-color','$highlight-box-border-1','','','.w-cart-gift-certificate'),(922103,'printshop','.w-product-bundle .bundle_item:nth-child(3) ~ .bundle_item','border-top-color','$content-border-3','','','.w-product-bundle'),(922104,'printshop','.w-product-bundle .bundle-total-price','border-top-color','$content-border-3','','','.w-product-bundle'),(922105,'printshop','.w-product-bundle .bundle_item:nth-child(2) ~ .bundle_item','border-top-color','$content-border-3','5342','','.w-product-bundle'),(922106,'printshop','.w-product-bundle .bundle_item:nth-child(1) ~ .bundle_item','border-top-color','$content-border-3','5333','','.w-product-bundle'),(922107,'printshop','.w-product-in-bundles .bundle-total-price','border-top-color','$content-border-3','','','.w-product-in-bundles'),(922108,'printshop','.w-product-in-bundles .bundle_item:nth-child(3) ~ .bundle_item','border-top-color','$content-border-3','','','.w-product-in-bundles'),(922109,'printshop','.w-product-in-bundles .bundle_item:nth-child(2) ~ .bundle_item','border-top-color','$content-border-3','5342','','.w-product-in-bundles'),(922110,'printshop','.w-product-in-bundles .bundle_item:nth-child(1) ~ .bundle_item','border-top-color','$content-border-3','5333','','.w-product-in-bundles'),(922112,'printshop','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-top-color','$highlight-box-border-2','','','.b-pagination'),(922113,'printshop','.b-pagination .pagination .next-pages','border-top-color','$content-border-3','','','.b-pagination'),(922114,'printshop','.b-pagination .pagination .page-number','border-top-color','$content-border-3','','','.b-pagination'),(922115,'printshop','.b-pagination .pagination .prev-pages','border-top-color','$content-border-3','','','.b-pagination'),(922116,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-top-color','$content-border-3','','','.b-pagination'),(922117,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-top-color','$content-border-3','','','.b-pagination'),(922118,'printshop','.b-pagination .pagination span','border-top-color','$highlight-box-border-2','2','','.b-pagination'),(922119,'printshop','.w-tabs .tab-li','border-top-color','$tab-nav-border-1','2','','.w-tabs'),(922121,'printshop','.w-product-multi-inventory .radio-attributes .option-item','border-top-color','$content-border-3','','','.w-product-multi-inventory'),(922122,'printshop','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-top-color','$highlight-box-border-1','','','.w-product-multi-inventory'),(922123,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-top-color','$content-border-3','','','.w-account-personal-catalog'),(922124,'printshop','.w-account-personal-catalog .list-row-action ul','border-top-color','$content-border-3','','','.w-account-personal-catalog'),(922125,'printshop','.b-products-listing .products-listing .radio-attributes .option','border-top-color','$content-border-3','','','.b-products-listing'),(922126,'printshop','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-top-color','$highlight-box-border-1','','','.b-products-listing'),(922127,'printshop','.w-product-collection .choose-products','border-top-color','$content-border-3','','','.w-product-collection'),(922128,'printshop','.w-product-attributes .radio-attributes .option-item','border-top-color','$content-border-3','','','.w-product-attributes'),(922129,'printshop','.w-product-attributes .radio-attributes input:checked + .option-item','border-top-color','$highlight-box-border-1','','','.w-product-attributes'),(922130,'printshop','.w-questionnaire-widgets-questionnaire .question + .question','border-top-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(922131,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(922132,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-top-color','$attention-border','','','.w-questionnaire-widgets-questionnaire'),(922133,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-top-color','$message-border','','','.w-questionnaire-widgets-questionnaire'),(922134,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-top-color','$attention-border','1','','.w-questionnaire-widgets-questionnaire'),(922135,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-top-color','$message-border','1','','.w-questionnaire-widgets-questionnaire'),(922136,'printshop','.w-product-groups .radioBox label .containerBlock','border-top-color','$content-border-3','','','.w-product-groups'),(922137,'printshop','.w-product-groups .radioBox label .containerBlock.selected','border-top-color','$highlight-box-border-2','','','.w-product-groups'),(922138,'printshop','.w-product-groups .radioBox label input:checked + .containerBlock','border-top-color','$highlight-box-border-2','','','.w-product-groups'),(922139,'printshop','.w-product-custom-bundle .choose-products','border-top-color','$content-border-3','','','.w-product-custom-bundle'),(922140,'printshop','.w-product-custom-bundle .right-area .price','border-top-color','$content-border-1','5342','','.w-product-custom-bundle'),(922141,'printshop','.w-delivery-location-location-list .deliveryList li a','border-top-color','$content-border-1','','','.w-delivery-location-location-list'),(922142,'printshop','.w-delivery-location-location-list .deliveryList li a','border-top-color','$highlight-box-border-1','1','','.w-delivery-location-location-list'),(922143,'printshop','.w-sale-category .left-text-left','border-top-color','$content-border-3','','','.w-sale-category'),(922144,'printshop','.w-sale-category .left-text-right','border-top-color','$content-border-3','','','.w-sale-category'),(922145,'printshop','.w-sale-category .sale-holder','border-top-color','$content-border-3','','','.w-sale-category'),(922146,'printshop','.w-delivery-location-list-by-page .item','border-top-color','$content-border-1','','','.w-delivery-location-list-by-page'),(922147,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-top-color','$content-border-3','','','.w-product-properties-icons'),(922148,'printshop','.w-delivery-location-cross-pages .item','border-top-color','$content-border-1','','','.w-delivery-location-cross-pages'),(922149,'printshop','.w-product-designer-designer .prodDesignerType label','border-top-color','$content-border-1','','','.w-product-designer-designer'),(922150,'printshop','.w-press-reviews-widgets-press-reviews .press-reviews-button','border-top-color','$content-border-3','','','.w-press-reviews-widgets-press-reviews'),(922151,'printshop','.b-products-listing .productGroup label a','border-top-color','$highlight-box-border-1','','','.b-products-listing'),(922152,'printshop','.w-support-system-listing .support-head','border-top-color','$content-border-1','','','.w-support-system-listing'),(922153,'printshop','.w-support-system-listing .product_icon','border-top-color','$content-border-1','','','.w-support-system-listing'),(922154,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-color','$attention-border','','','.w-predefined-promotion'),(922155,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-color','$attention-border','','','.w-predefined-promotion'),(922156,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-color','$attention-border','','','.w-predefined-promotion'),(922157,'printshop','.w-predefined-promotion .promo-salemaker .discount','border-top-color','$warning-border','','','.w-predefined-promotion'),(922158,'printshop','.w-supplier-purchase-supplier-products .item','border-top-color','$content-border-1','','','.w-supplier-purchase-supplier-products'),(922160,'printshop','.btn-1','border-top-color','$btn-border-2','','',''),(922161,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','border-top-color','$content-border-3','','','.w-filters'),(922162,'printshop','.b-quantity .qty-box','border-top-color','$content-border-3','','','.b-quantity'),(922163,'printshop','.w-product-model ','border-top-color','$content-border-3','','','.w-product-model'),(922164,'printshop','.w-checkout-billing-address .same-address','border-top-color','$content-border-3','','','.w-checkout-billing-address'),(922165,'printshop','.btn-3','border-top-color','$btn-border-4','','',''),(922166,'printshop','.b-table-list .table-list td','border-top-color','$content-border-3','','','.b-table-list'),(922167,'printshop','.middleBanner .btn-1','border-top-color','$additional-banner-border-2','','','.middleBanner'),(922168,'printshop','.bottomBanner .btn-1','border-top-color','$additional-banner-border-2','','','.bottomBanner'),(922169,'printshop','.w-product-quantity-discounts .item','border-top-color','$content-border-3','','','.w-product-quantity-discounts'),(922170,'printshop','.w-product-personal-catalog-button .btn','border-top-color','$highlight-box-border-2','','','.w-product-personal-catalog-button'),(922171,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-top-color','$highlight-box-border-2','','','.b-products-listing'),(922172,'printshop','.b-products-listing .products-listing.list-productlisting .item','border-top-color','$content-border-3','','','.b-products-listing'),(922173,'printshop','.topBanner .content .btn','border-top-color','$main-banner-border-1','','','.topBanner'),(922174,'printshop','.topBanner .ourPick .top','border-top-color','$main-banner-bg-1','','','.topBanner'),(922175,'printshop','.topBanner .ourPick','border-top-color','$main-banner-bg-1','4','','.topBanner'),(922176,'printshop','.topBanner .ourPick','border-top-color','$main-banner-bg-1','3','','.topBanner'),(922177,'printshop','.p-quote-checkout-index .input-wrapper','border-top-color','$content-border-3','','','.p-quote-checkout-index'),(922180,'printshop','.account-samples .orders-table .item','border-top-color','$content-border-3','5342','','.account-samples'),(922181,'printshop','.catalog-product-wrap .pn-image','border-top-color','$content-border-3','3','','.catalog-product-wrap'),(922182,'printshop','.shopping-cart-index .btn-3','border-top-color','$highlight-box-border-1','','','.shopping-cart-index'),(922183,'printshop','.checkout-index-wrap .input-wrapper','border-top-color','$content-border-3','','','.checkout-index-wrap'),(922184,'printshop','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-color','$highlight-box-border-1','','','.b-multi-page-checkout'),(922185,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-color','$content-border-3','','','.b-multi-page-checkout'),(922186,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-color','$content-border-3','','','.b-multi-page-checkout'),(922188,'printshop','.w-catalog-paging ','border-top-color','#CCCCCC','2','','.w-catalog-paging'),(922189,'printshop','.w-catalog-paging .next','border-top-color','#CCCCCC','','','.w-catalog-paging'),(922190,'printshop','.w-catalog-paging .next-pages','border-top-color','#CCCCCC','','','.w-catalog-paging'),(922191,'printshop','.w-catalog-paging .page-number','border-top-color','#CCCCCC','','','.w-catalog-paging'),(922192,'printshop','.w-catalog-paging .prev','border-top-color','#CCCCCC','','','.w-catalog-paging'),(922193,'printshop','.w-catalog-paging .prev-pages','border-top-color','#CCCCCC','','','.w-catalog-paging'),(922194,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-color','#CCCCCC','','','.w-catalog-paging'),(922196,'printshop','.w-sale .left-text-left','border-top-color','$content-border-3','','','.w-sale'),(922197,'printshop','.w-sale .left-text-right','border-top-color','$content-border-3','','','.w-sale'),(922198,'printshop','.w-sale .sale-holder','border-top-color','$content-border-3','','','.w-sale'),(922199,'printshop','.b-data-table table.dataTable.no-footer','border-top-color_important','important','','','.b-data-table'),(922200,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-top-left-radius','0','4','','.b-switch'),(922201,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.p-quick-order-index'),(922202,'printshop','.w-promotions .prom-multi-discount .promo-range','border-top-left-radius','12','','','.w-promotions'),(922203,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.p-quick-order-index'),(922204,'printshop','.w-promotions .promo-salemaker .discount','border-top-left-radius','12','','','.w-promotions'),(922205,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-left-radius','12','','','.w-promotions'),(922206,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border-top-left-radius','12','','','.w-promotions'),(922207,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-left-radius','5','','','.b-messages'),(922208,'printshop','.b-fancybox .fancybox-close','border-top-left-radius','50','','','.b-fancybox'),(922209,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-left-radius','25','','','.b-switch'),(922210,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-top-left-radius','0','3','','.b-switch'),(922211,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-left-radius','15','3','','.b-switch'),(922212,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(922213,'printshop','.b-switch .bootstrap-switch','border-top-left-radius','14','','','.b-switch'),(922214,'printshop','.b-switch .candlestick-wrapper .candlestick-bg','border-top-left-radius','15','','','.b-switch'),(922215,'printshop','.w-checkout-shipping-choice label:first-child span','border-top-left-radius','16','','','.w-checkout-shipping-choice'),(922216,'printshop','.w-checkout-shipping-choice label:last-child span','border-top-left-radius','0','','','.w-checkout-shipping-choice'),(922217,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-left-radius','25','','','.b-switch'),(922218,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border-top-left-radius','50','3','','.b-form'),(922219,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-top-left-radius','50','3','','.b-switch'),(922220,'printshop','.b-fancybox .fancybox-title-float-wrap .child','border-top-left-radius','15','','','.b-fancybox'),(922221,'printshop','.b-fancybox .fancybox-skin','border-top-left-radius','4','','','.b-fancybox'),(922222,'printshop','.w-personal-gift-status-bar .progress-bar','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(922223,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-left-radius','15','4','','.b-switch'),(922224,'printshop','.w-personal-gift-status-bar .progress-bar-content','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(922225,'printshop','.b-fancybox .fancybox-nav span','border-top-left-radius','50','','','.b-fancybox'),(922226,'printshop','.w-product-customers-activity .close','border-top-left-radius','50','','','.w-product-customers-activity'),(922227,'printshop','.w-product-customers-activity .customers-activity','border-top-left-radius','10','','','.w-product-customers-activity'),(922228,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.b-data-table'),(922229,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.b-data-table'),(922230,'printshop','.b-products-listing .promos-info .promo-name','border-top-left-radius','0','','','.b-products-listing'),(922231,'printshop','.b-upload-file .snapshot','border-top-left-radius','50','','','.b-upload-file'),(922232,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(922233,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-top-left-radius','0','','','.b-product-images'),(922234,'printshop','.b-trade-approval .steps-bar','border-top-left-radius','18','','','.b-trade-approval'),(922235,'printshop','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-left-radius','3','','','.w-delivery-day'),(922236,'printshop','.w-delivery-day .left-count','border-top-left-radius','3','','','.w-delivery-day'),(922238,'printshop','.menu-header .burger-icon','border-top-left-radius','50','5342','','.menu-header'),(922239,'printshop','.w-quote .cart-box-link','border-top-left-radius','50','3','','.w-quote'),(922240,'printshop','.w-product-sale-ends .left-count','border-top-left-radius','3','','','.w-product-sale-ends'),(922241,'printshop','.w-product-sale-ends .left-count-days','border-top-left-radius','3','','','.w-product-sale-ends'),(922242,'printshop','.w-product-sale-ends .left-count-hours','border-top-left-radius','3','','','.w-product-sale-ends'),(922243,'printshop','.w-sample .cart-box-link','border-top-left-radius','50','3','','.w-sample'),(922244,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-left-radius','50','','','.w-questionnaire-widgets-questionnaire'),(922245,'printshop','.w-sale-category .badge','border-top-left-radius','50','','','.w-sale-category'),(922246,'printshop','.w-sale-category .left-count','border-top-left-radius','3','','','.w-sale-category'),(922247,'printshop','.w-sale-category .left-count-days','border-top-left-radius','3','','','.w-sale-category'),(922248,'printshop','.w-sale-category .left-count-hours','border-top-left-radius','3','','','.w-sale-category'),(922249,'printshop','.b-products-listing .productGroup label a','border-top-left-radius','3','','','.b-products-listing'),(922250,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-left-radius','12','','','.w-predefined-promotion'),(922251,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-left-radius','12','','','.w-predefined-promotion'),(922252,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-left-radius','12','','','.w-predefined-promotion'),(922253,'printshop','.w-predefined-promotion .promo-salemaker .discount','border-top-left-radius','12','','','.w-predefined-promotion'),(922255,'printshop','.btn','border-top-left-radius','5','','',''),(922256,'printshop','.btn-1','border-top-left-radius','5','','',''),(922257,'printshop','.btn-2','border-top-left-radius','5','','',''),(922258,'printshop','.w-catalog-listing-look .b2b','border-top-left-radius','5','','','.w-catalog-listing-look'),(922259,'printshop','.w-catalog-listing-look .grid','border-top-left-radius','5','','','.w-catalog-listing-look'),(922260,'printshop','.w-catalog-listing-look .list','border-top-left-radius','5','','','.w-catalog-listing-look'),(922261,'printshop','.btn-3','border-top-left-radius','5','','',''),(922262,'printshop','.middleBanner .btn-1','border-top-left-radius','3','','','.middleBanner'),(922263,'printshop','.bottomBanner .btn-1','border-top-left-radius','3','','','.bottomBanner'),(922264,'printshop','.topBanner .content .btn','border-top-left-radius','3','','','.topBanner'),(922265,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','border-top-left-radius','5','','','.p-quote-checkout-index'),(922267,'printshop','.catalog-product-wrap .pn-image','border-top-left-radius','50','3','','.catalog-product-wrap'),(922268,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','border-top-left-radius','5','','','.checkout-index-wrap'),(922269,'printshop','.b-slick .slick-dots li','border-top-left-radius','50','3','','.b-slick'),(922270,'printshop','.success-page .w-cart-listing .qty','border-top-left-radius','50','','','.success-page'),(922271,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-left-radius','50','','','.b-multi-page-checkout'),(922272,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-left-radius','50','3','','.b-multi-page-checkout'),(922273,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-left-radius','0','','','.w-catalog-paging'),(922274,'printshop','.w-sale .badge','border-top-left-radius','50','','','.w-sale'),(922275,'printshop','.w-sale .left-count','border-top-left-radius','3','','','.w-sale'),(922276,'printshop','.w-sale .left-count-days','border-top-left-radius','3','','','.w-sale'),(922277,'printshop','.w-sale .left-count-hours','border-top-left-radius','3','','','.w-sale'),(922278,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-top-right-radius','0','4','','.b-switch'),(922279,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.p-quick-order-index'),(922280,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.p-quick-order-index'),(922281,'printshop','.w-promotions .prom-multi-discount .promo-range','border-top-right-radius','12','','','.w-promotions'),(922282,'printshop','.w-promotions .promo-salemaker .discount','border-top-right-radius','12','','','.w-promotions'),(922283,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-right-radius','12','','','.w-promotions'),(922284,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border-top-right-radius','12','','','.w-promotions'),(922285,'printshop','.b-upload-file .snapshot','border-top-right-radius','50','','','.b-upload-file'),(922286,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-right-radius','5','','','.b-messages'),(922287,'printshop','.w-personal-gift-status-bar .progress-bar','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(922288,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border-top-right-radius','50','3','','.b-form'),(922289,'printshop','.b-fancybox .fancybox-close','border-top-right-radius','50','','','.b-fancybox'),(922290,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-right-radius','25','','','.b-switch'),(922291,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-top-right-radius','0','3','','.b-switch'),(922292,'printshop','.b-switch .bootstrap-switch','border-top-right-radius','14','','','.b-switch'),(922293,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-right-radius','15','3','','.b-switch'),(922294,'printshop','.b-switch .candlestick-wrapper .candlestick-bg','border-top-right-radius','15','','','.b-switch'),(922295,'printshop','.w-checkout-shipping-choice label:last-child span','border-top-right-radius','16','','','.w-checkout-shipping-choice'),(922296,'printshop','.w-checkout-shipping-choice label:first-child span','border-top-right-radius','0','','','.w-checkout-shipping-choice'),(922297,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-right-radius','25','','','.b-switch'),(922298,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-top-right-radius','50','3','','.b-switch'),(922299,'printshop','.b-fancybox .fancybox-title-float-wrap .child','border-top-right-radius','15','','','.b-fancybox'),(922300,'printshop','.b-fancybox .fancybox-skin','border-top-right-radius','4','','','.b-fancybox'),(922301,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-right-radius','15','4','','.b-switch'),(922302,'printshop','.b-fancybox .fancybox-nav span','border-top-right-radius','50','','','.b-fancybox'),(922303,'printshop','.w-product-customers-activity .close','border-top-right-radius','50','','','.w-product-customers-activity'),(922304,'printshop','.w-product-customers-activity .customers-activity','border-top-right-radius','10','','','.w-product-customers-activity'),(922305,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.b-data-table'),(922306,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.b-data-table'),(922307,'printshop','.b-products-listing .promos-info .promo-name','border-top-right-radius','8','','','.b-products-listing'),(922308,'printshop','.w-personal-gift-status-bar .progress-bar-content','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(922309,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(922310,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(922311,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-top-right-radius','0','','','.b-product-images'),(922312,'printshop','.b-trade-approval .steps-bar','border-top-right-radius','18','','','.b-trade-approval'),(922313,'printshop','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-right-radius','3','','','.w-delivery-day'),(922314,'printshop','.w-delivery-day .left-count','border-top-right-radius','3','','','.w-delivery-day'),(922316,'printshop','.menu-header .burger-icon','border-top-right-radius','50','5342','','.menu-header'),(922317,'printshop','.w-quote .cart-box-link','border-top-right-radius','50','3','','.w-quote'),(922318,'printshop','.w-product-sale-ends .left-count','border-top-right-radius','3','','','.w-product-sale-ends'),(922319,'printshop','.w-product-sale-ends .left-count-days','border-top-right-radius','3','','','.w-product-sale-ends'),(922320,'printshop','.w-product-sale-ends .left-count-hours','border-top-right-radius','3','','','.w-product-sale-ends'),(922321,'printshop','.w-sample .cart-box-link','border-top-right-radius','50','3','','.w-sample'),(922322,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-right-radius','50','','','.w-questionnaire-widgets-questionnaire'),(922323,'printshop','.w-sale-category .badge','border-top-right-radius','50','','','.w-sale-category'),(922324,'printshop','.w-sale-category .left-count','border-top-right-radius','3','','','.w-sale-category'),(922325,'printshop','.w-sale-category .left-count-days','border-top-right-radius','3','','','.w-sale-category'),(922326,'printshop','.w-sale-category .left-count-hours','border-top-right-radius','3','','','.w-sale-category'),(922327,'printshop','.b-products-listing .productGroup label a','border-top-right-radius','3','','','.b-products-listing'),(922328,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-right-radius','12','','','.w-predefined-promotion'),(922329,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-right-radius','12','','','.w-predefined-promotion'),(922330,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-right-radius','12','','','.w-predefined-promotion'),(922331,'printshop','.w-predefined-promotion .promo-salemaker .discount','border-top-right-radius','12','','','.w-predefined-promotion'),(922333,'printshop','.btn','border-top-right-radius','5','','',''),(922334,'printshop','.btn-1','border-top-right-radius','5','','',''),(922335,'printshop','.btn-2','border-top-right-radius','5','','',''),(922336,'printshop','.w-catalog-listing-look .b2b','border-top-right-radius','5','','','.w-catalog-listing-look'),(922337,'printshop','.w-catalog-listing-look .grid','border-top-right-radius','5','','','.w-catalog-listing-look'),(922338,'printshop','.w-catalog-listing-look .list','border-top-right-radius','5','','','.w-catalog-listing-look'),(922339,'printshop','.btn-3','border-top-right-radius','5','','',''),(922340,'printshop','.middleBanner .btn-1','border-top-right-radius','3','','','.middleBanner'),(922341,'printshop','.bottomBanner .btn-1','border-top-right-radius','3','','','.bottomBanner'),(922342,'printshop','.topBanner .content .btn','border-top-right-radius','3','','','.topBanner'),(922343,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','border-top-right-radius','5','','','.p-quote-checkout-index'),(922345,'printshop','.catalog-product-wrap .pn-image','border-top-right-radius','50','3','','.catalog-product-wrap'),(922346,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','border-top-right-radius','5','','','.checkout-index-wrap'),(922347,'printshop','.b-slick .slick-dots li','border-top-right-radius','50','3','','.b-slick'),(922348,'printshop','.success-page .w-cart-listing .qty','border-top-right-radius','50','','','.success-page'),(922349,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-right-radius','50','','','.b-multi-page-checkout'),(922350,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-right-radius','50','3','','.b-multi-page-checkout'),(922351,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-right-radius','0','','','.w-catalog-paging'),(922352,'printshop','.w-sale .badge','border-top-right-radius','50','','','.w-sale'),(922353,'printshop','.w-sale .left-count','border-top-right-radius','3','','','.w-sale'),(922354,'printshop','.w-sale .left-count-days','border-top-right-radius','3','','','.w-sale'),(922355,'printshop','.w-sale .left-count-hours','border-top-right-radius','3','','','.w-sale'),(922356,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(922357,'printshop','.w-communication-new-topic td','border-top-width','1','','','.w-communication-new-topic'),(922358,'printshop','.b-info div + .info','border-top-width','1','','','.b-info'),(922359,'printshop','.w-promotions .prom-multi-discount .promo-range','border-top-width','1','','','.w-promotions'),(922362,'printshop','.w-cart-compare .attributes-block td','border-top-width','1','','','.w-cart-compare'),(922364,'printshop','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(922365,'printshop','.b-email .qty','border-top-width','1','','','.b-email'),(922366,'printshop','.b-email .name','border-top-width','1','','','.b-email'),(922367,'printshop','.b-email .totals-table','border-top-width','1','','','.b-email'),(922368,'printshop','.testimonials .review','border-top-width','7','3','',''),(922369,'printshop','.w-promotions .promo-salemaker .discount','border-top-width','1','','','.w-promotions'),(922370,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-width','1','','','.w-promotions'),(922371,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border-top-width','1','','','.w-promotions'),(922372,'printshop','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(922373,'printshop','.b-messages .messMenuButtonTop','border-top-width','1','','','.b-messages'),(922374,'printshop','.b-messages .msv_btn','border-top-width','1','','','.b-messages'),(922375,'printshop','.b-messages .email-heading','border-top-width','1','','','.b-messages'),(922376,'printshop','.b-messages .dataTable','border-top-width','1','','','.b-messages'),(922377,'printshop','.b-messages .messages-menu li + li','border-top-width','1','','','.b-messages'),(922378,'printshop','.b-messages .content_management_attach button','border-top-width','1','','','.b-messages'),(922379,'printshop','.b-messages .content_management_attach','border-top-width','1','','','.b-messages'),(922380,'printshop','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-width','2','','','.b-messages'),(922381,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-top-width','1','','',''),(922382,'printshop','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(922383,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border-top-width','2','3','','.b-form'),(922384,'printshop','.w-socials > li','border-top-width','1','','','.w-socials'),(922385,'printshop','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(922386,'printshop','.b-email .price','border-top-width','1','','','.b-email'),(922387,'printshop','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(922388,'printshop','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(922389,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(922390,'printshop','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(922391,'printshop','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(922392,'printshop','.b-info div + .info','border-top-width','1','','','.b-info'),(922393,'printshop','.b-email .model','border-top-width','1','','','.b-email'),(922394,'printshop','.b-info div + .info','border-top-width','1','','','.b-info'),(922395,'printshop','.b-email .model','border-top-width','1','','','.b-email'),(922396,'printshop','.b-email .price','border-top-width','1','','','.b-email'),(922397,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-width','2','3','','.b-switch'),(922398,'printshop','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(922399,'printshop','.w-filters .ui-slider','border-top-width','0','','','.w-filters'),(922400,'printshop','.w-filters .ui-slider-handle','border-top-width','0','','','.w-filters'),(922401,'printshop','.b-email .name','border-top-width','1','','','.b-email'),(922402,'printshop','.b-email .qty','border-top-width','1','','','.b-email'),(922403,'printshop','.b-email .totals-table','border-top-width','1','','','.b-email'),(922404,'printshop','.w-checkout-shipping-choice span','border-top-width','2','','','.w-checkout-shipping-choice'),(922405,'printshop','.w-socials > li','border-top-width','1','','','.w-socials'),(922407,'printshop','.w-cart-compare .product-block td','border-top-width','1','','','.w-cart-compare'),(922408,'printshop','.b-info-popup .info-popup div','border-top-width','1','','','.b-info-popup'),(922409,'printshop','.b-email .qty','border-top-width','1','','','.b-email'),(922410,'printshop','.w-socials > li','border-top-width','1','','','.w-socials'),(922411,'printshop','.b-bottom .popup-buttons','border-top-width','1','','','.b-bottom'),(922412,'printshop','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(922413,'printshop','.totals-line','border-top-width','1','','',''),(922414,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-width','4','','','.b-switch'),(922415,'printshop','.b-email .name','border-top-width','1','','','.b-email'),(922416,'printshop','.b-email .totals-table','border-top-width','1','','','.b-email'),(922417,'printshop','.b-email .name','border-top-width','1','','','.b-email'),(922418,'printshop','.order-summary .price-row + .price-row','border-top-width','1','','','.order-summary'),(922419,'printshop','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(922421,'printshop','.w-reviews .review','border-top-width','8','3','','.w-reviews'),(922423,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-width','3','','','.b-switch'),(922424,'printshop','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(922425,'printshop','.b-email .image','border-top-width','1','','','.b-email'),(922426,'printshop','.b-email .image','border-top-width','1','','','.b-email'),(922427,'printshop','.b-email .model','border-top-width','1','','','.b-email'),(922428,'printshop','.w-socials > li','border-top-width','1','','','.w-socials'),(922429,'printshop','.b-email .image','border-top-width','1','','','.b-email'),(922430,'printshop','.b-email .price','border-top-width','1','','','.b-email'),(922431,'printshop','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(922432,'printshop','.b-email .name','border-top-width','1','','','.b-email'),(922433,'printshop','.b-email .qty','border-top-width','1','','','.b-email'),(922434,'printshop','.b-email .model','border-top-width','1','','','.b-email'),(922435,'printshop','.b-email .totals-table','border-top-width','1','','','.b-email'),(922436,'printshop','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(922437,'printshop','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(922438,'printshop','.b-form .shipping-method .item + .item','border-top-width','1','','','.b-form'),(922439,'printshop','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(922440,'printshop','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(922441,'printshop','.b-select-suggest .select2-container .select2-choice','border-top-width','1','','','.b-select-suggest'),(922442,'printshop','.view-all','border-top-width','1','3','',''),(922443,'printshop','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(922444,'printshop','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(922445,'printshop','textarea','border-top-width','1','','',''),(922446,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-width','2','4','','.b-switch'),(922447,'printshop','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(922448,'printshop','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(922450,'printshop','.w-cart-compare .cart-cell > div','border-top-width','1','','','.w-cart-compare'),(922452,'printshop','.b-info div + .info','border-top-width','1','','','.b-info'),(922453,'printshop','.b-form .form-buttons','border-top-width','1','','','.b-form'),(922454,'printshop','.b-form .required-error','border-top-width','1','','','.b-form'),(922455,'printshop','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(922456,'printshop','.b-info div + .info','border-top-width','1','','','.b-info'),(922457,'printshop','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(922458,'printshop','.b-email .totals-table','border-top-width','1','','','.b-email'),(922460,'printshop','.b-email .model','border-top-width','1','','','.b-email'),(922461,'printshop','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-top-width','1','','','.b-bottom'),(922462,'printshop','.b-email .model','border-top-width','1','','','.b-email'),(922463,'printshop','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(922464,'printshop','.b-upload-files .upload-files','border-top-width','1','','','.b-upload-files'),(922465,'printshop','.b-upload-files .added-file','border-top-width','1','','','.b-upload-files'),(922466,'printshop','.b-bottom .popup-box','border-top-width','1','','','.b-bottom'),(922467,'printshop','.b-email .image','border-top-width','1','','','.b-email'),(922468,'printshop','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(922469,'printshop','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(922470,'printshop','.w-product-customers-activity .customers-activity','border-top-width','1','','','.w-product-customers-activity'),(922471,'printshop','.b-form .privacy-row','border-top-width','1','','','.b-form'),(922472,'printshop','.w-reviews-content .review','border-top-width','8','3','','.w-reviews-content'),(922473,'printshop','.w-cart-compare .price-block td','border-top-width','1','','','.w-cart-compare'),(922474,'printshop','.w-socials > li','border-top-width','1','','','.w-socials'),(922475,'printshop','.w-product-reviews .reviews-list .review','border-top-width','7','3','','.w-product-reviews'),(922476,'printshop','.b-upload-file .upload-file-template','border-top-width','1','','','.b-upload-file'),(922477,'printshop','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(922478,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(922479,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-width','1','','','.b-select-suggest'),(922480,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(922481,'printshop','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-width','1','','','.b-select-suggest'),(922482,'printshop','.b-select-suggest .select2-container-multi .select2-choices','border-top-width','1','','','.b-select-suggest'),(922483,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-width','1','','','.b-select-suggest'),(922484,'printshop','.b-select-suggest .select2-search input','border-top-width','1','','','.b-select-suggest'),(922485,'printshop','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-width','1','','','.b-select-suggest'),(922486,'printshop','.b-select-suggest .select2-drop.select2-drop-above','border-top-width','1','','','.b-select-suggest'),(922487,'printshop','.b-select-suggest .select2-drop-active','border-top-width','1','','','.b-select-suggest'),(922488,'printshop','.b-select-suggest .select2-drop-auto-width','border-top-width','1','','','.b-select-suggest'),(922489,'printshop','.w-socials > li','border-top-width','1','','','.w-socials'),(922490,'printshop','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(922492,'printshop','.b-form .payment-method .item + .item','border-top-width','1','','','.b-form'),(922493,'printshop','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(922494,'printshop','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(922496,'printshop','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-top-width','1','','','.b-bottom'),(922497,'printshop','.w-communication-post .communication-post','border-top-width','1','','','.w-communication-post'),(922498,'printshop','.checkbox input:checked + span','border-top-width','1','','',''),(922499,'printshop','.checkbox input + span','border-top-width','1','','',''),(922500,'printshop','.b-autocomplete .ui-autocomplete','border-top-width','1','','','.b-autocomplete'),(922503,'printshop','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(922504,'printshop','.b-info-popup .info-popup div','border-top-width','1','3','','.b-info-popup'),(922505,'printshop','.b-info div + .info','border-top-width','1','','','.b-info'),(922506,'printshop','.b-email .price','border-top-width','1','','','.b-email'),(922507,'printshop','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(922508,'printshop','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(922509,'printshop','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(922510,'printshop','.b-email .image','border-top-width','1','','','.b-email'),(922511,'printshop','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(922512,'printshop','.b-email .price','border-top-width','1','','','.b-email'),(922513,'printshop','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(922515,'printshop','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(922516,'printshop','.w-checkout-shipping .sub-item + .sub-item','border-top-width','1','','','.w-checkout-shipping'),(922517,'printshop','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(922518,'printshop','.w-cart-listing .item .gift-wrap label','border-top-width','1','','','.w-cart-listing'),(922519,'printshop','.w-cart-listing .item','border-top-width','1','5342','','.w-cart-listing'),(922521,'printshop','.b-email .image','border-top-width','1','','','.b-email'),(922522,'printshop','.b-email .price','border-top-width','1','','','.b-email'),(922523,'printshop','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(922524,'printshop','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(922525,'printshop','.w-filters .ui-slider-range','border-top-width','0','','','.w-filters'),(922526,'printshop','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(922527,'printshop','.b-email .qty','border-top-width','1','','','.b-email'),(922528,'printshop','.b-email .name','border-top-width','1','','','.b-email'),(922529,'printshop','.b-data-table table.dataTable tbody td','border-top-width','1','','','.b-data-table'),(922530,'printshop','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-width','1','','','.b-compare'),(922531,'printshop','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(922532,'printshop','.b-email .totals-table','border-top-width','1','','','.b-email'),(922533,'printshop','.b-email .qty','border-top-width','1','','','.b-email'),(922534,'printshop','.b-upload-file .snapshot','border-top-width','1','','','.b-upload-file'),(922535,'printshop','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-top-width','2','','','.b-product-images'),(922536,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-width','2','','','.b-trade-approval'),(922537,'printshop','.w-account-personal-catalog .list-switcher a','border-top-width','3','2','','.w-account-personal-catalog'),(922538,'printshop','.w-account-subscription .subscription-variant + .subscription-variant','border-top-width','1','','','.w-account-subscription'),(922539,'printshop','.w-catalog-compare .compare .checkbox input:checked + span','border-top-width','1','','','.w-catalog-compare'),(922540,'printshop','.w-catalog-compare .cross-box .different-all > div','border-top-width','3','2','','.w-catalog-compare'),(922541,'printshop','.w-delivery-day .left-text-left','border-top-width','2','','','.w-delivery-day'),(922542,'printshop','.w-delivery-day .left-text-right','border-top-width','2','','','.w-delivery-day'),(922543,'printshop','.b-slick .slick-vertical .slick-slide','border-top-width','1','','','.b-slick'),(922544,'printshop','.w-filters .filter-widget','border-top-width','1','','','.w-filters'),(922545,'printshop','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-top-width','0','','','.w-filters'),(922546,'printshop','.b-products-listing .products-listing.list-rows .item:first-of-type .BlockBox.item-holder','border-top-width','0','','','.b-products-listing'),(922547,'printshop','.w-quote .cart-content','border-top-width','1','','','.w-quote'),(922548,'printshop','.b-product-images .additional-images .active img','border-top-width','2','','','.b-product-images'),(922549,'printshop','.b-product-images .additional-images img','border-top-width','2','','','.b-product-images'),(922550,'printshop','.w-product-sale-ends .left-text-left','border-top-width','2','','','.w-product-sale-ends'),(922551,'printshop','.w-product-sale-ends .left-text-right','border-top-width','2','','','.w-product-sale-ends'),(922552,'printshop','.w-files-catalog-widgets-files-list .item + .item','border-top-width','1','','','.w-files-catalog-widgets-files-list'),(922553,'printshop','.w-sample .cart-content','border-top-width','1','','','.w-sample'),(922554,'printshop','.w-product-video .item img, .w-product-video .item video','border-top-width','2','','','.w-product-video'),(922555,'printshop','.w-product-video .item.active img, .w-product-video .item.active video','border-top-width','2','','','.w-product-video'),(922556,'printshop','.w-cart-order-reference .btn','border-top-width','2','','','.w-cart-order-reference'),(922557,'printshop','.w-cart-gift-certificate .btn','border-top-width','2','','','.w-cart-gift-certificate'),(922558,'printshop','.w-product-bundle .bundle_item:nth-child(3) ~ .bundle_item','border-top-width','1','','','.w-product-bundle'),(922559,'printshop','.w-product-bundle .bundle-total-price','border-top-width','1','','','.w-product-bundle'),(922560,'printshop','.w-product-bundle .bundle_item:nth-child(2) ~ .bundle_item','border-top-width','1','5342','','.w-product-bundle'),(922561,'printshop','.w-product-bundle .bundle_item:nth-child(1) ~ .bundle_item','border-top-width','1','5333','','.w-product-bundle'),(922562,'printshop','.w-product-in-bundles .bundle-total-price','border-top-width','1','','','.w-product-in-bundles'),(922563,'printshop','.w-product-in-bundles .bundle_item:nth-child(3) ~ .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(922564,'printshop','.w-product-in-bundles .bundle_item:nth-child(2) ~ .bundle_item','border-top-width','1','5342','','.w-product-in-bundles'),(922565,'printshop','.w-product-in-bundles .bundle_item:nth-child(1) ~ .bundle_item','border-top-width','1','5333','','.w-product-in-bundles'),(922567,'printshop','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-top-width','1','','','.b-pagination'),(922568,'printshop','.b-pagination .pagination .next-pages','border-top-width','1','','','.b-pagination'),(922569,'printshop','.b-pagination .pagination .page-number','border-top-width','1','','','.b-pagination'),(922570,'printshop','.b-pagination .pagination .prev-pages','border-top-width','1','','','.b-pagination'),(922571,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-top-width','1','','','.b-pagination'),(922572,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-top-width','1','','','.b-pagination'),(922573,'printshop','.b-pagination .pagination span','border-top-width','1','2','','.b-pagination'),(922574,'printshop','.w-tabs .tab-li','border-top-width','3','2','','.w-tabs'),(922576,'printshop','.w-product-multi-inventory .radio-attributes .option-item','border-top-width','2','','','.w-product-multi-inventory'),(922577,'printshop','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-top-width','2','','','.w-product-multi-inventory'),(922578,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-top-width','1','','','.w-account-personal-catalog'),(922579,'printshop','.w-account-personal-catalog .list-row-action ul','border-top-width','1','','','.w-account-personal-catalog'),(922580,'printshop','.b-products-listing .products-listing .radio-attributes .option','border-top-width','2','','','.b-products-listing'),(922581,'printshop','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-top-width','2','','','.b-products-listing'),(922582,'printshop','.w-product-collection .choose-products','border-top-width','1','','','.w-product-collection'),(922583,'printshop','.w-product-attributes .radio-attributes .option-item','border-top-width','2','','','.w-product-attributes'),(922584,'printshop','.w-product-attributes .radio-attributes input:checked + .option-item','border-top-width','2','','','.w-product-attributes'),(922585,'printshop','.w-questionnaire-widgets-questionnaire .question + .question','border-top-width','1','','','.w-questionnaire-widgets-questionnaire'),(922586,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-width','2','','','.w-questionnaire-widgets-questionnaire'),(922587,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-top-width','2','','','.w-questionnaire-widgets-questionnaire'),(922588,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-top-width','2','','','.w-questionnaire-widgets-questionnaire'),(922589,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-top-width','2','1','','.w-questionnaire-widgets-questionnaire'),(922590,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-top-width','2','1','','.w-questionnaire-widgets-questionnaire'),(922591,'printshop','.w-product-groups .radioBox label .containerBlock','border-top-width','2','','','.w-product-groups'),(922592,'printshop','.w-product-groups .radioBox label .containerBlock.selected','border-top-width','2','','','.w-product-groups'),(922593,'printshop','.w-product-groups .radioBox label input:checked + .containerBlock','border-top-width','2','','','.w-product-groups'),(922594,'printshop','.w-product-custom-bundle .choose-products','border-top-width','1','','','.w-product-custom-bundle'),(922595,'printshop','.w-product-custom-bundle .right-area .price','border-top-width','1','5342','','.w-product-custom-bundle'),(922596,'printshop','.w-delivery-location-location-list .deliveryList li a','border-top-width','2','','','.w-delivery-location-location-list'),(922597,'printshop','.w-delivery-location-location-list .deliveryList li a','border-top-width','2','1','','.w-delivery-location-location-list'),(922598,'printshop','.w-sale-category .left-text-left','border-top-width','2','','','.w-sale-category'),(922599,'printshop','.w-sale-category .left-text-right','border-top-width','2','','','.w-sale-category'),(922600,'printshop','.w-sale-category .sale-holder','border-top-width','2','','','.w-sale-category'),(922601,'printshop','.w-delivery-location-list-by-page .item','border-top-width','1','','','.w-delivery-location-list-by-page'),(922602,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-top-width','1','','','.w-product-properties-icons'),(922603,'printshop','.w-delivery-location-cross-pages .item','border-top-width','1','','','.w-delivery-location-cross-pages'),(922604,'printshop','.w-product-designer-designer .prodDesignerType label','border-top-width','1','','','.w-product-designer-designer'),(922605,'printshop','.w-press-reviews-widgets-press-reviews .press-reviews-button','border-top-width','1','','','.w-press-reviews-widgets-press-reviews'),(922606,'printshop','.b-products-listing .productGroup label a','border-top-width','1','','','.b-products-listing'),(922607,'printshop','.w-support-system-listing .support-head','border-top-width','1','','','.w-support-system-listing'),(922608,'printshop','.w-support-system-listing .product_icon','border-top-width','1','','','.w-support-system-listing'),(922609,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-width','1','','','.w-predefined-promotion'),(922610,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-width','1','','','.w-predefined-promotion'),(922611,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-width','1','','','.w-predefined-promotion'),(922612,'printshop','.w-predefined-promotion .promo-salemaker .discount','border-top-width','1','','','.w-predefined-promotion'),(922613,'printshop','.w-supplier-purchase-supplier-products .item','border-top-width','1','','','.w-supplier-purchase-supplier-products'),(922615,'printshop','.btn-1','border-top-width','2','','',''),(922616,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','border-top-width','1','','','.w-filters'),(922617,'printshop','.b-quantity .qty-box','border-top-width','2','','','.b-quantity'),(922618,'printshop','.w-product-model ','border-top-width','1','','','.w-product-model'),(922619,'printshop','.w-checkout-billing-address .same-address','border-top-width','1','','','.w-checkout-billing-address'),(922620,'printshop','.btn-3','border-top-width','2','','',''),(922621,'printshop','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(922622,'printshop','.middleBanner .btn-1','border-top-width','1','','','.middleBanner'),(922623,'printshop','.bottomBanner .btn-1','border-top-width','1','','','.bottomBanner'),(922624,'printshop','.w-product-quantity-discounts .item','border-top-width','1','','','.w-product-quantity-discounts'),(922625,'printshop','.w-product-personal-catalog-button .btn','border-top-width','2','','','.w-product-personal-catalog-button'),(922626,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-top-width','2','','','.b-products-listing'),(922627,'printshop','.b-products-listing .products-listing.list-productlisting .item','border-top-width','1','','','.b-products-listing'),(922628,'printshop','.topBanner .content .btn','border-top-width','1','','','.topBanner'),(922629,'printshop','.topBanner .ourPick','border-top-width','23','3','','.topBanner'),(922630,'printshop','.topBanner .ourPick','border-top-width','23','4','','.topBanner'),(922631,'printshop','.topBanner .ourPick .top','border-top-width','1','','','.topBanner'),(922632,'printshop','.topBanner .ourPick','border-top-width','15','5347,3','','.topBanner'),(922633,'printshop','.topBanner .ourPick','border-top-width','15','5347,4','','.topBanner'),(922634,'printshop','.topBanner .ourPick','border-top-width','10','5363,3','','.topBanner'),(922635,'printshop','.topBanner .ourPick','border-top-width','10','5363,4','','.topBanner'),(922636,'printshop','.p-quote-checkout-index .input-wrapper','border-top-width','2','','','.p-quote-checkout-index'),(922644,'printshop','.account-samples .orders-table .item','border-top-width','1','5342','','.account-samples'),(922645,'printshop','.account-samples .orders-table .td-alignright','border-top-width','1','5342','','.account-samples'),(922646,'printshop','.catalog-product-wrap .pn-image','border-top-width','2','3','','.catalog-product-wrap'),(922647,'printshop','.catalog-product-wrap .pn-image','border-top-width','1','','','.catalog-product-wrap'),(922648,'printshop','.catalog-product-wrap .pn-name','border-top-width','1','','','.catalog-product-wrap'),(922649,'printshop','.catalog-product-wrap .prev-next-product','border-top-width','1','','','.catalog-product-wrap'),(922650,'printshop','.shopping-cart-index .btn-3','border-top-width','2','','','.shopping-cart-index'),(922651,'printshop','.checkout-index-wrap .input-wrapper','border-top-width','2','','','.checkout-index-wrap'),(922652,'printshop','.index-wrap .w-new-products .products-listing.list-productlisting .item:nth-child(1), .index-wrap .w-new-products .products-listing.list-productlisting .item:nth-child(2)','border-top-width','0','','','.index-wrap'),(922653,'printshop','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(922654,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-content','border-top-width','1','','','.b-multi-page-checkout'),(922655,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(922656,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-width','1','','','.b-multi-page-checkout'),(922658,'printshop','.w-catalog-paging ','border-top-width','1','2','','.w-catalog-paging'),(922659,'printshop','.w-catalog-paging .next','border-top-width','1','','','.w-catalog-paging'),(922660,'printshop','.w-catalog-paging .next-pages','border-top-width','1','','','.w-catalog-paging'),(922661,'printshop','.w-catalog-paging .page-number','border-top-width','1','','','.w-catalog-paging'),(922662,'printshop','.w-catalog-paging .prev','border-top-width','1','','','.w-catalog-paging'),(922663,'printshop','.w-catalog-paging .prev-pages','border-top-width','1','','','.w-catalog-paging'),(922664,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-width','1','','','.w-catalog-paging'),(922666,'printshop','.w-sale .left-text-left','border-top-width','2','','','.w-sale'),(922667,'printshop','.w-sale .left-text-right','border-top-width','2','','','.w-sale'),(922668,'printshop','.w-sale .sale-holder','border-top-width','2','','','.w-sale'),(922669,'printshop','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item:last-of-type','border_bottom_width_measure','','','','.w-promotions-widgets-promotion-icons-desc'),(922670,'printshop','.b-autocomplete .ui-autocomplete li','border_important','important','','','.b-autocomplete'),(922671,'printshop','.b-data-table table.dataTable thead td','border_important','important','','','.b-data-table'),(922672,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','border_important','important','','','.w-rma-returns-history'),(922673,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_1_measure','px','4','','.b-switch'),(922674,'printshop','.w-personal-gift-status-bar .progress-bar-content','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(922675,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.p-quick-order-index'),(922676,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.p-quick-order-index'),(922677,'printshop','.w-promotions .prom-multi-discount .promo-range','border_radius_1_measure','px','','','.w-promotions'),(922678,'printshop','.w-promotions .promo-salemaker .discount','border_radius_1_measure','px','','','.w-promotions'),(922679,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_1_measure','px','','','.w-promotions'),(922680,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_1_measure','px','','','.w-promotions'),(922681,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_1_measure','px','','','.b-messages'),(922682,'printshop','.b-fancybox .fancybox-close','border_radius_1_measure','%','','','.b-fancybox'),(922683,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_1_measure','px','','','.b-switch'),(922684,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_1_measure','px','3','','.b-switch'),(922685,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_1_measure','px','3','','.b-switch'),(922686,'printshop','.b-switch .bootstrap-switch','border_radius_1_measure','px','','','.b-switch'),(922687,'printshop','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_1_measure','px','','','.b-switch'),(922688,'printshop','.w-checkout-shipping-choice label:last-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(922689,'printshop','.w-checkout-shipping-choice label:first-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(922690,'printshop','.w-personal-gift-status-bar .progress-bar','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(922691,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_1_measure','px','','','.b-switch'),(922692,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_1_measure','%','3','','.b-switch'),(922693,'printshop','.b-fancybox .fancybox-title-float-wrap .child','border_radius_1_measure','px','','','.b-fancybox'),(922694,'printshop','.b-fancybox .fancybox-skin','border_radius_1_measure','px','','','.b-fancybox'),(922695,'printshop','.b-fancybox .fancybox-nav span','border_radius_1_measure','%','','','.b-fancybox'),(922696,'printshop','.w-product-customers-activity .close','border_radius_1_measure','%','','','.w-product-customers-activity'),(922697,'printshop','.w-product-customers-activity .customers-activity','border_radius_1_measure','px','','','.w-product-customers-activity'),(922698,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_1_measure','px','4','','.b-switch'),(922699,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.b-data-table'),(922700,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.b-data-table'),(922701,'printshop','.b-products-listing .promos-info .promo-name','border_radius_1_measure','px','','','.b-products-listing'),(922702,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(922703,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_1_measure','%','3','','.b-form'),(922704,'printshop','.b-upload-file .snapshot','border_radius_1_measure','%','','','.b-upload-file'),(922705,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(922706,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_1_measure','px','','','.b-product-images'),(922707,'printshop','.b-trade-approval .steps-bar','border_radius_1_measure','px','','','.b-trade-approval'),(922708,'printshop','.w-delivery-day .left-count','border_radius_1_measure','px','','','.w-delivery-day'),(922709,'printshop','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_1_measure','px','','','.w-delivery-day'),(922711,'printshop','.menu-header .burger-icon','border_radius_1_measure','%','5342','','.menu-header'),(922712,'printshop','.w-quote .cart-box-link','border_radius_1_measure','%','3','','.w-quote'),(922713,'printshop','.w-product-sale-ends .left-count','border_radius_1_measure','px','','','.w-product-sale-ends'),(922714,'printshop','.w-product-sale-ends .left-count-days','border_radius_1_measure','px','','','.w-product-sale-ends'),(922715,'printshop','.w-product-sale-ends .left-count-hours','border_radius_1_measure','px','','','.w-product-sale-ends'),(922716,'printshop','.w-sample .cart-box-link','border_radius_1_measure','%','3','','.w-sample'),(922717,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_1_measure','%','','','.w-questionnaire-widgets-questionnaire'),(922718,'printshop','.w-sale-category .badge','border_radius_1_measure','%','','','.w-sale-category'),(922719,'printshop','.w-sale-category .left-count','border_radius_1_measure','px','','','.w-sale-category'),(922720,'printshop','.w-sale-category .left-count-days','border_radius_1_measure','px','','','.w-sale-category'),(922721,'printshop','.w-sale-category .left-count-hours','border_radius_1_measure','px','','','.w-sale-category'),(922722,'printshop','.b-products-listing .productGroup label a','border_radius_1_measure','px','','','.b-products-listing'),(922723,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_1_measure','px','','','.w-predefined-promotion'),(922724,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_1_measure','px','','','.w-predefined-promotion'),(922725,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_1_measure','px','','','.w-predefined-promotion'),(922726,'printshop','.w-predefined-promotion .promo-salemaker .discount','border_radius_1_measure','px','','','.w-predefined-promotion'),(922728,'printshop','.btn','border_radius_1_measure','px','','',''),(922729,'printshop','.btn-1','border_radius_1_measure','px','','',''),(922730,'printshop','.btn-2','border_radius_1_measure','px','','',''),(922731,'printshop','.w-catalog-listing-look .b2b','border_radius_1_measure','px','','','.w-catalog-listing-look'),(922732,'printshop','.w-catalog-listing-look .grid','border_radius_1_measure','px','','','.w-catalog-listing-look'),(922733,'printshop','.w-catalog-listing-look .list','border_radius_1_measure','px','','','.w-catalog-listing-look'),(922734,'printshop','.btn-3','border_radius_1_measure','px','','',''),(922735,'printshop','.middleBanner .btn-1','border_radius_1_measure','px','','','.middleBanner'),(922736,'printshop','.bottomBanner .btn-1','border_radius_1_measure','px','','','.bottomBanner'),(922737,'printshop','.topBanner .content .btn','border_radius_1_measure','px','','','.topBanner'),(922738,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','border_radius_1_measure','px','','','.p-quote-checkout-index'),(922740,'printshop','.catalog-product-wrap .pn-image','border_radius_1_measure','%','3','','.catalog-product-wrap'),(922741,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','border_radius_1_measure','px','','','.checkout-index-wrap'),(922742,'printshop','.b-slick .slick-dots li','border_radius_1_measure','%','3','','.b-slick'),(922743,'printshop','.success-page .w-cart-listing .qty','border_radius_1_measure','%','','','.success-page'),(922744,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_1_measure','%','','','.b-multi-page-checkout'),(922745,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_1_measure','%','3','','.b-multi-page-checkout'),(922746,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_1_measure','px','','','.w-catalog-paging'),(922747,'printshop','.w-sale .badge','border_radius_1_measure','%','','','.w-sale'),(922748,'printshop','.w-sale .left-count','border_radius_1_measure','px','','','.w-sale'),(922749,'printshop','.w-sale .left-count-days','border_radius_1_measure','px','','','.w-sale'),(922750,'printshop','.w-sale .left-count-hours','border_radius_1_measure','px','','','.w-sale'),(922751,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_2_measure','px','4','','.b-switch'),(922752,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_2_measure','px','','','.b-switch'),(922753,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.p-quick-order-index'),(922754,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.p-quick-order-index'),(922755,'printshop','.w-promotions .prom-multi-discount .promo-range','border_radius_2_measure','px','','','.w-promotions'),(922756,'printshop','.w-promotions .promo-salemaker .discount','border_radius_2_measure','px','','','.w-promotions'),(922757,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_2_measure','px','','','.w-promotions'),(922758,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_2_measure','px','','','.w-promotions'),(922759,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_2_measure','px','4','','.b-switch'),(922760,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_2_measure','px','','','.b-messages'),(922761,'printshop','.b-fancybox .fancybox-close','border_radius_2_measure','%','','','.b-fancybox'),(922762,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_2_measure','px','','','.b-switch'),(922763,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_2_measure','px','3','','.b-switch'),(922764,'printshop','.b-switch .bootstrap-switch','border_radius_2_measure','px','','','.b-switch'),(922765,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_2_measure','px','3','','.b-switch'),(922766,'printshop','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_2_measure','px','','','.b-switch'),(922767,'printshop','.w-checkout-shipping-choice label:last-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(922768,'printshop','.w-checkout-shipping-choice label:first-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(922769,'printshop','.w-personal-gift-status-bar .progress-bar-content','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(922770,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_2_measure','%','3','','.b-switch'),(922771,'printshop','.b-fancybox .fancybox-title-float-wrap .child','border_radius_2_measure','px','','','.b-fancybox'),(922772,'printshop','.b-fancybox .fancybox-skin','border_radius_2_measure','px','','','.b-fancybox'),(922773,'printshop','.b-upload-file .snapshot','border_radius_2_measure','%','','','.b-upload-file'),(922774,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_2_measure','%','3','','.b-form'),(922775,'printshop','.b-fancybox .fancybox-nav span','border_radius_2_measure','%','','','.b-fancybox'),(922776,'printshop','.w-product-customers-activity .close','border_radius_2_measure','%','','','.w-product-customers-activity'),(922777,'printshop','.w-product-customers-activity .customers-activity','border_radius_2_measure','px','','','.w-product-customers-activity'),(922778,'printshop','.w-personal-gift-status-bar .progress-bar','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(922779,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.b-data-table'),(922780,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.b-data-table'),(922781,'printshop','.b-products-listing .promos-info .promo-name','border_radius_2_measure','px','','','.b-products-listing'),(922782,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(922783,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(922784,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_2_measure','px','','','.b-product-images'),(922785,'printshop','.b-trade-approval .steps-bar','border_radius_2_measure','px','','','.b-trade-approval'),(922786,'printshop','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_2_measure','px','','','.w-delivery-day'),(922787,'printshop','.w-delivery-day .left-count','border_radius_2_measure','px','','','.w-delivery-day'),(922789,'printshop','.menu-header .burger-icon','border_radius_2_measure','%','5342','','.menu-header'),(922790,'printshop','.w-quote .cart-box-link','border_radius_2_measure','%','3','','.w-quote'),(922791,'printshop','.w-product-sale-ends .left-count','border_radius_2_measure','px','','','.w-product-sale-ends'),(922792,'printshop','.w-product-sale-ends .left-count-days','border_radius_2_measure','px','','','.w-product-sale-ends'),(922793,'printshop','.w-product-sale-ends .left-count-hours','border_radius_2_measure','px','','','.w-product-sale-ends'),(922794,'printshop','.w-sample .cart-box-link','border_radius_2_measure','%','3','','.w-sample'),(922795,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_2_measure','%','','','.w-questionnaire-widgets-questionnaire'),(922796,'printshop','.w-sale-category .badge','border_radius_2_measure','%','','','.w-sale-category'),(922797,'printshop','.w-sale-category .left-count','border_radius_2_measure','px','','','.w-sale-category'),(922798,'printshop','.w-sale-category .left-count-days','border_radius_2_measure','px','','','.w-sale-category'),(922799,'printshop','.w-sale-category .left-count-hours','border_radius_2_measure','px','','','.w-sale-category'),(922800,'printshop','.b-products-listing .productGroup label a','border_radius_2_measure','px','','','.b-products-listing'),(922801,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_2_measure','px','','','.w-predefined-promotion'),(922802,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_2_measure','px','','','.w-predefined-promotion'),(922803,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_2_measure','px','','','.w-predefined-promotion'),(922804,'printshop','.w-predefined-promotion .promo-salemaker .discount','border_radius_2_measure','px','','','.w-predefined-promotion'),(922806,'printshop','.btn','border_radius_2_measure','px','','',''),(922807,'printshop','.btn-1','border_radius_2_measure','px','','',''),(922808,'printshop','.btn-2','border_radius_2_measure','px','','',''),(922809,'printshop','.w-catalog-listing-look .b2b','border_radius_2_measure','px','','','.w-catalog-listing-look'),(922810,'printshop','.w-catalog-listing-look .grid','border_radius_2_measure','px','','','.w-catalog-listing-look'),(922811,'printshop','.w-catalog-listing-look .list','border_radius_2_measure','px','','','.w-catalog-listing-look'),(922812,'printshop','.btn-3','border_radius_2_measure','px','','',''),(922813,'printshop','.middleBanner .btn-1','border_radius_2_measure','px','','','.middleBanner'),(922814,'printshop','.bottomBanner .btn-1','border_radius_2_measure','px','','','.bottomBanner'),(922815,'printshop','.topBanner .content .btn','border_radius_2_measure','px','','','.topBanner'),(922816,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','border_radius_2_measure','px','','','.p-quote-checkout-index'),(922818,'printshop','.catalog-product-wrap .pn-image','border_radius_2_measure','%','3','','.catalog-product-wrap'),(922819,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','border_radius_2_measure','px','','','.checkout-index-wrap'),(922820,'printshop','.b-slick .slick-dots li','border_radius_2_measure','%','3','','.b-slick'),(922821,'printshop','.success-page .w-cart-listing .qty','border_radius_2_measure','%','','','.success-page'),(922822,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_2_measure','%','','','.b-multi-page-checkout'),(922823,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_2_measure','%','3','','.b-multi-page-checkout'),(922824,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_2_measure','px','','','.w-catalog-paging'),(922825,'printshop','.w-sale .badge','border_radius_2_measure','%','','','.w-sale'),(922826,'printshop','.w-sale .left-count','border_radius_2_measure','px','','','.w-sale'),(922827,'printshop','.w-sale .left-count-days','border_radius_2_measure','px','','','.w-sale'),(922828,'printshop','.w-sale .left-count-hours','border_radius_2_measure','px','','','.w-sale'),(922829,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_3_measure','px','4','','.b-switch'),(922830,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_3_measure','px','4','','.b-switch'),(922831,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.p-quick-order-index'),(922832,'printshop','.w-promotions .prom-multi-discount .promo-range','border_radius_3_measure','px','','','.w-promotions'),(922833,'printshop','.w-promotions .promo-salemaker .discount','border_radius_3_measure','px','','','.w-promotions'),(922834,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_3_measure','px','','','.w-promotions'),(922835,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_3_measure','px','','','.w-promotions'),(922836,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_3_measure','px','','','.b-messages'),(922837,'printshop','.b-fancybox .fancybox-close','border_radius_3_measure','%','','','.b-fancybox'),(922838,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_3_measure','px','','','.b-switch'),(922839,'printshop','.w-personal-gift-status-bar .progress-bar-content','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(922840,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_3_measure','px','3','','.b-switch'),(922841,'printshop','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_3_measure','px','','','.b-switch'),(922842,'printshop','.w-personal-gift-status-bar .progress-bar','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(922843,'printshop','.w-checkout-shipping-choice label:last-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(922844,'printshop','.w-checkout-shipping-choice label:first-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(922845,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_3_measure','%','3','','.b-form'),(922846,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_3_measure','px','3','','.b-switch'),(922847,'printshop','.b-fancybox .fancybox-title-float-wrap .child','border_radius_3_measure','px','','','.b-fancybox'),(922848,'printshop','.b-fancybox .fancybox-skin','border_radius_3_measure','px','','','.b-fancybox'),(922849,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_3_measure','%','3','','.b-switch'),(922850,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.p-quick-order-index'),(922851,'printshop','.b-fancybox .fancybox-nav span','border_radius_3_measure','%','','','.b-fancybox'),(922852,'printshop','.w-product-customers-activity .close','border_radius_3_measure','%','','','.w-product-customers-activity'),(922853,'printshop','.w-product-customers-activity .customers-activity','border_radius_3_measure','px','','','.w-product-customers-activity'),(922854,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(922855,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.b-data-table'),(922856,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.b-data-table'),(922857,'printshop','.b-products-listing .promos-info .promo-name','border_radius_3_measure','px','','','.b-products-listing'),(922858,'printshop','.b-upload-file .snapshot','border_radius_3_measure','%','','','.b-upload-file'),(922859,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(922860,'printshop','.b-switch .bootstrap-switch','border_radius_3_measure','px','','','.b-switch'),(922861,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_3_measure','px','','','.b-switch'),(922862,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_3_measure','px','','','.b-product-images'),(922863,'printshop','.b-trade-approval .steps-bar','border_radius_3_measure','px','','','.b-trade-approval'),(922864,'printshop','.w-delivery-day .left-count','border_radius_3_measure','px','','','.w-delivery-day'),(922865,'printshop','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_3_measure','px','','','.w-delivery-day'),(922867,'printshop','.menu-header .burger-icon','border_radius_3_measure','%','5342','','.menu-header'),(922868,'printshop','.w-quote .cart-box-link','border_radius_3_measure','%','3','','.w-quote'),(922869,'printshop','.w-product-sale-ends .left-count','border_radius_3_measure','px','','','.w-product-sale-ends'),(922870,'printshop','.w-product-sale-ends .left-count-days','border_radius_3_measure','px','','','.w-product-sale-ends'),(922871,'printshop','.w-product-sale-ends .left-count-hours','border_radius_3_measure','px','','','.w-product-sale-ends'),(922872,'printshop','.w-sample .cart-box-link','border_radius_3_measure','%','3','','.w-sample'),(922873,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_3_measure','%','','','.w-questionnaire-widgets-questionnaire'),(922874,'printshop','.w-sale-category .badge','border_radius_3_measure','%','','','.w-sale-category'),(922875,'printshop','.w-sale-category .left-count','border_radius_3_measure','px','','','.w-sale-category'),(922876,'printshop','.w-sale-category .left-count-days','border_radius_3_measure','px','','','.w-sale-category'),(922877,'printshop','.w-sale-category .left-count-hours','border_radius_3_measure','px','','','.w-sale-category'),(922878,'printshop','.b-products-listing .productGroup label a','border_radius_3_measure','px','','','.b-products-listing'),(922879,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_3_measure','px','','','.w-predefined-promotion'),(922880,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_3_measure','px','','','.w-predefined-promotion'),(922881,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_3_measure','px','','','.w-predefined-promotion'),(922882,'printshop','.w-predefined-promotion .promo-salemaker .discount','border_radius_3_measure','px','','','.w-predefined-promotion'),(922884,'printshop','.btn','border_radius_3_measure','px','','',''),(922885,'printshop','.btn-1','border_radius_3_measure','px','','',''),(922886,'printshop','.btn-2','border_radius_3_measure','px','','',''),(922887,'printshop','.w-catalog-listing-look .b2b','border_radius_3_measure','px','','','.w-catalog-listing-look'),(922888,'printshop','.w-catalog-listing-look .grid','border_radius_3_measure','px','','','.w-catalog-listing-look'),(922889,'printshop','.w-catalog-listing-look .list','border_radius_3_measure','px','','','.w-catalog-listing-look'),(922890,'printshop','.btn-3','border_radius_3_measure','px','','',''),(922891,'printshop','.middleBanner .btn-1','border_radius_3_measure','px','','','.middleBanner'),(922892,'printshop','.bottomBanner .btn-1','border_radius_3_measure','px','','','.bottomBanner'),(922893,'printshop','.topBanner .content .btn','border_radius_3_measure','px','','','.topBanner'),(922894,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','border_radius_3_measure','px','','','.p-quote-checkout-index'),(922896,'printshop','.catalog-product-wrap .pn-image','border_radius_3_measure','%','3','','.catalog-product-wrap'),(922897,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','border_radius_3_measure','px','','','.checkout-index-wrap'),(922898,'printshop','.b-slick .slick-dots li','border_radius_3_measure','%','3','','.b-slick'),(922899,'printshop','.success-page .w-cart-listing .qty','border_radius_3_measure','%','','','.success-page'),(922900,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_3_measure','%','','','.b-multi-page-checkout'),(922901,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_3_measure','%','3','','.b-multi-page-checkout'),(922902,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_3_measure','px','','','.w-catalog-paging'),(922903,'printshop','.w-sale .badge','border_radius_3_measure','%','','','.w-sale'),(922904,'printshop','.w-sale .left-count','border_radius_3_measure','px','','','.w-sale'),(922905,'printshop','.w-sale .left-count-days','border_radius_3_measure','px','','','.w-sale'),(922906,'printshop','.w-sale .left-count-hours','border_radius_3_measure','px','','','.w-sale'),(922907,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_4_measure','px','4','','.b-switch'),(922908,'printshop','.b-upload-file .snapshot','border_radius_4_measure','%','','','.b-upload-file'),(922909,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.p-quick-order-index'),(922910,'printshop','.w-promotions .prom-multi-discount .promo-range','border_radius_4_measure','px','','','.w-promotions'),(922911,'printshop','.w-promotions .promo-salemaker .discount','border_radius_4_measure','px','','','.w-promotions'),(922912,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_4_measure','px','','','.w-promotions'),(922913,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.p-quick-order-index'),(922914,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_4_measure','px','','','.w-promotions'),(922915,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_4_measure','px','','','.b-messages'),(922916,'printshop','.b-fancybox .fancybox-close','border_radius_4_measure','%','','','.b-fancybox'),(922917,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_4_measure','px','','','.b-switch'),(922918,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_4_measure','px','3','','.b-switch'),(922919,'printshop','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_4_measure','px','','','.b-switch'),(922920,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(922921,'printshop','.w-checkout-shipping-choice label:last-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(922922,'printshop','.w-checkout-shipping-choice label:first-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(922923,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_4_measure','px','4','','.b-switch'),(922924,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_4_measure','px','3','','.b-switch'),(922925,'printshop','.b-fancybox .fancybox-title-float-wrap .child','border_radius_4_measure','px','','','.b-fancybox'),(922926,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_4_measure','%','3','','.b-form'),(922927,'printshop','.w-personal-gift-status-bar .progress-bar-content','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(922928,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_4_measure','%','3','','.b-switch'),(922929,'printshop','.w-personal-gift-status-bar .progress-bar','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(922930,'printshop','.b-fancybox .fancybox-nav span','border_radius_4_measure','%','','','.b-fancybox'),(922931,'printshop','.w-product-customers-activity .customers-activity','border_radius_4_measure','px','','','.w-product-customers-activity'),(922932,'printshop','.w-product-customers-activity .close','border_radius_4_measure','%','','','.w-product-customers-activity'),(922933,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(922934,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.b-data-table'),(922935,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.b-data-table'),(922936,'printshop','.b-products-listing .promos-info .promo-name','border_radius_4_measure','px','','','.b-products-listing'),(922937,'printshop','.b-fancybox .fancybox-skin','border_radius_4_measure','px','','','.b-fancybox'),(922938,'printshop','.b-switch .bootstrap-switch','border_radius_4_measure','px','','','.b-switch'),(922939,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_4_measure','px','','','.b-switch'),(922940,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_4_measure','px','','','.b-product-images'),(922941,'printshop','.b-trade-approval .steps-bar','border_radius_4_measure','px','','','.b-trade-approval'),(922942,'printshop','.w-delivery-day .left-count','border_radius_4_measure','px','','','.w-delivery-day'),(922943,'printshop','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_4_measure','px','','','.w-delivery-day'),(922945,'printshop','.menu-header .burger-icon','border_radius_4_measure','%','5342','','.menu-header'),(922946,'printshop','.w-quote .cart-box-link','border_radius_4_measure','%','3','','.w-quote'),(922947,'printshop','.w-product-sale-ends .left-count','border_radius_4_measure','px','','','.w-product-sale-ends'),(922948,'printshop','.w-product-sale-ends .left-count-days','border_radius_4_measure','px','','','.w-product-sale-ends'),(922949,'printshop','.w-product-sale-ends .left-count-hours','border_radius_4_measure','px','','','.w-product-sale-ends'),(922950,'printshop','.w-sample .cart-box-link','border_radius_4_measure','%','3','','.w-sample'),(922951,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_4_measure','%','','','.w-questionnaire-widgets-questionnaire'),(922952,'printshop','.w-sale-category .badge','border_radius_4_measure','%','','','.w-sale-category'),(922953,'printshop','.w-sale-category .left-count','border_radius_4_measure','px','','','.w-sale-category'),(922954,'printshop','.w-sale-category .left-count-days','border_radius_4_measure','px','','','.w-sale-category'),(922955,'printshop','.w-sale-category .left-count-hours','border_radius_4_measure','px','','','.w-sale-category'),(922956,'printshop','.b-products-listing .productGroup label a','border_radius_4_measure','px','','','.b-products-listing'),(922957,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_4_measure','px','','','.w-predefined-promotion'),(922958,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_4_measure','px','','','.w-predefined-promotion'),(922959,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_4_measure','px','','','.w-predefined-promotion'),(922960,'printshop','.w-predefined-promotion .promo-salemaker .discount','border_radius_4_measure','px','','','.w-predefined-promotion'),(922962,'printshop','.btn','border_radius_4_measure','px','','',''),(922963,'printshop','.btn-1','border_radius_4_measure','px','','',''),(922964,'printshop','.btn-2','border_radius_4_measure','px','','',''),(922965,'printshop','.w-catalog-listing-look .b2b','border_radius_4_measure','px','','','.w-catalog-listing-look'),(922966,'printshop','.w-catalog-listing-look .grid','border_radius_4_measure','px','','','.w-catalog-listing-look'),(922967,'printshop','.w-catalog-listing-look .list','border_radius_4_measure','px','','','.w-catalog-listing-look'),(922968,'printshop','.btn-3','border_radius_4_measure','px','','',''),(922969,'printshop','.middleBanner .btn-1','border_radius_4_measure','px','','','.middleBanner'),(922970,'printshop','.bottomBanner .btn-1','border_radius_4_measure','px','','','.bottomBanner'),(922971,'printshop','.topBanner .content .btn','border_radius_4_measure','px','','','.topBanner'),(922972,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','border_radius_4_measure','px','','','.p-quote-checkout-index'),(922974,'printshop','.catalog-product-wrap .pn-image','border_radius_4_measure','%','3','','.catalog-product-wrap'),(922975,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','border_radius_4_measure','px','','','.checkout-index-wrap'),(922976,'printshop','.b-slick .slick-dots li','border_radius_4_measure','%','3','','.b-slick'),(922977,'printshop','.success-page .w-cart-listing .qty','border_radius_4_measure','%','','','.success-page'),(922978,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_4_measure','%','','','.b-multi-page-checkout'),(922979,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_4_measure','%','3','','.b-multi-page-checkout'),(922980,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_4_measure','px','','','.w-catalog-paging'),(922981,'printshop','.w-sale .badge','border_radius_4_measure','%','','','.w-sale'),(922982,'printshop','.w-sale .left-count','border_radius_4_measure','px','','','.w-sale'),(922983,'printshop','.w-sale .left-count-days','border_radius_4_measure','px','','','.w-sale'),(922984,'printshop','.w-sale .left-count-hours','border_radius_4_measure','px','','','.w-sale'),(922985,'printshop','.testimonials .review','bottom','-13','3','',''),(922986,'printshop','.w-checkout-shipping-choice input:checked + span:before','bottom','-7','','','.w-checkout-shipping-choice'),(922987,'printshop','.b-fancybox .fancybox-title-over-wrap','bottom','0','','','.b-fancybox'),(922988,'printshop','.b-info-popup .info-popup.top-left div','bottom','30','','','.b-info-popup'),(922989,'printshop','.b-info-popup .info-popup.top-left div','bottom','-11','3','','.b-info-popup'),(922990,'printshop','.b-upload-file .snapshot','bottom','5','','','.b-upload-file'),(922991,'printshop','.w-product-reviews .reviews-list .review','bottom','-13','3','','.w-product-reviews'),(922992,'printshop','.b-fancybox .fancybox-overlay-fixed','bottom','0','','','.b-fancybox'),(922993,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','bottom','0','','','.b-switch'),(922994,'printshop','.w-product-customers-activity .customers-activity','bottom','0','','','.w-product-customers-activity'),(922995,'printshop','.w-product-customers-activity .customers-activity.closed','bottom','-1000','','','.w-product-customers-activity'),(922996,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','bottom','0','','','.b-switch'),(922997,'printshop','.w-catalog-b2b-add-button ','bottom','0','','','.w-catalog-b2b-add-button'),(922998,'printshop','.b-fancybox .fancybox-title-float-wrap','bottom','0','','','.b-fancybox'),(922999,'printshop','.p-quick-order-index .all-scroll-div','bottom','0','','','.p-quick-order-index'),(923000,'printshop','.w-cart-listing .item .remove','bottom','0','5342','','.w-cart-listing'),(923001,'printshop','.b-product-images .mp-shadow, .b-product-images .media-popup','bottom','0','','','.b-product-images'),(923002,'printshop','.b-slick .slick-vertical button.slick-next','bottom','0','','','.b-slick'),(923003,'printshop','.b-slick .slick-vertical button.slick-prev','bottom','auto','','','.b-slick'),(923004,'printshop','.w-compare ','bottom','0','','','.w-compare'),(923005,'printshop','.w-compare .remove','bottom','10','','','.w-compare'),(923012,'printshop','.account-samples .orders-table .order-total','bottom','45','5342','','.account-samples'),(923013,'printshop','.account-samples .orders-table .status-name','bottom','7','5342','','.account-samples'),(923014,'printshop','.account-samples .orders-table .td-alignright','bottom','0','5342','','.account-samples'),(923015,'printshop','.w-banner .image-text-banner.bottom-center .text-banner','bottom','0','','','.w-banner'),(923016,'printshop','.w-banner .image-text-banner.bottom-left .text-banner','bottom','0','','','.w-banner'),(923017,'printshop','.w-banner .image-text-banner.bottom-right .text-banner','bottom','0','','','.w-banner'),(923018,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(923020,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(923021,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(923023,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(923024,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(923025,'printshop','.b-fancybox .fancybox-opened .fancybox-skin','box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(923028,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','box-shadow','none','','','.w-contact-contacts'),(923029,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','box-shadow','0 0 4px rgba(75,75,75,0.5)','3','','.b-switch'),(923032,'printshop','.w-catalog-compare .compare-fix-bar.fix-bar-fix','box-shadow','0 10px 10px -10px #cccccc','','','.w-catalog-compare'),(923034,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-step','box-shadow','0 2px 9px 0 rgba(0, 0, 0, 0.2)','2','','.b-multi-page-checkout'),(923036,'printshop','.b-fancybox .filter-listing-loader','box-sizing','content-box','','','.b-fancybox'),(923037,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','box-sizing','border-box','','','.b-switch'),(923038,'printshop','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','box-sizing','border-box','','','.b-select-suggest'),(923039,'printshop','.b-slick .slick-slider','box-sizing','border-box','','','.b-slick'),(923040,'printshop','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(923041,'printshop','.w-support-system-listing .support-head','box-sizing','border-box','','','.w-support-system-listing'),(923042,'printshop','.b-info-popup .info-popup div','box_shadow_blur','10','','','.b-info-popup'),(923043,'printshop','.w-product-customers-activity .customers-activity','box_shadow_blur','20','','','.w-product-customers-activity'),(923044,'printshop','.b-datepicker .datepicker-dropdown','box_shadow_blur','10','','','.b-datepicker'),(923045,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur','5','','','.w-image-maps'),(923046,'printshop','.w-compare ','box_shadow_blur','20','','','.w-compare'),(923047,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_blur','10','','','.w-product-properties-icons'),(923048,'printshop','.b-info-popup .info-popup div','box_shadow_blur_measure','px','','','.b-info-popup'),(923049,'printshop','.b-datepicker .datepicker-dropdown','box_shadow_blur_measure','px','','','.b-datepicker'),(923050,'printshop','.w-product-customers-activity .customers-activity','box_shadow_blur_measure','px','','','.w-product-customers-activity'),(923051,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur_measure','px','','','.w-image-maps'),(923052,'printshop','.w-compare ','box_shadow_blur_measure','px','','','.w-compare'),(923053,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_blur_measure','px','','','.w-product-properties-icons'),(923054,'printshop','.b-info-popup .info-popup div','box_shadow_color','#ccc','','','.b-info-popup'),(923055,'printshop','.b-datepicker .datepicker-dropdown','box_shadow_color','#ccc','','','.b-datepicker'),(923056,'printshop','.w-product-customers-activity .customers-activity','box_shadow_color','#eee','','','.w-product-customers-activity'),(923057,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_color','#ccc','','','.w-image-maps'),(923058,'printshop','.w-compare ','box_shadow_color','#cccc','','','.w-compare'),(923059,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_color','#bdbdbd','','','.w-product-properties-icons'),(923060,'printshop','.b-info-popup .info-popup div','box_shadow_left','0','','','.b-info-popup'),(923061,'printshop','.b-datepicker .datepicker-dropdown','box_shadow_left','0','','','.b-datepicker'),(923062,'printshop','.w-product-customers-activity .customers-activity','box_shadow_left','0','','','.w-product-customers-activity'),(923063,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left','0','','','.w-image-maps'),(923064,'printshop','.w-compare ','box_shadow_left','0','','','.w-compare'),(923065,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_left','1','','','.w-product-properties-icons'),(923066,'printshop','.b-info-popup .info-popup div','box_shadow_left_measure','','','','.b-info-popup'),(923067,'printshop','.b-datepicker .datepicker-dropdown','box_shadow_left_measure','','','','.b-datepicker'),(923068,'printshop','.w-product-customers-activity .customers-activity','box_shadow_left_measure','','','','.w-product-customers-activity'),(923069,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left_measure','','','','.w-image-maps'),(923070,'printshop','.w-compare ','box_shadow_left_measure','','','','.w-compare'),(923071,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_left_measure','px','','','.w-product-properties-icons'),(923072,'printshop','.b-info-popup .info-popup div','box_shadow_top','0','','','.b-info-popup'),(923073,'printshop','.w-product-customers-activity .customers-activity','box_shadow_top','0','','','.w-product-customers-activity'),(923074,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top','0','','','.w-image-maps'),(923075,'printshop','.b-datepicker .datepicker-dropdown','box_shadow_top','0','','','.b-datepicker'),(923076,'printshop','.w-compare ','box_shadow_top','0','','','.w-compare'),(923077,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_top','1','','','.w-product-properties-icons'),(923078,'printshop','.b-info-popup .info-popup div','box_shadow_top_measure','','','','.b-info-popup'),(923079,'printshop','.w-product-customers-activity .customers-activity','box_shadow_top_measure','','','','.w-product-customers-activity'),(923080,'printshop','.b-datepicker .datepicker-dropdown','box_shadow_top_measure','','','','.b-datepicker'),(923081,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top_measure','','','','.w-image-maps'),(923082,'printshop','.w-compare ','box_shadow_top_measure','','','','.w-compare'),(923083,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_top_measure','px','','','.w-product-properties-icons'),(923084,'printshop','.b-form .addresses .address-item:nth-child(2n + 1)','clear','left','','','.b-form'),(923085,'printshop','.w-checkout-billing-address .btn-cancel','clear','both','','','.w-checkout-billing-address'),(923086,'printshop','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(923088,'printshop','.b-form .col-full','clear','both','','','.b-form'),(923089,'printshop','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(923092,'printshop','.w-promotions .prom-multi-discount','clear','both','4','','.w-promotions'),(923093,'printshop','.w-product-available-in-warehouses .content','clear','both','4','','.w-product-available-in-warehouses'),(923094,'printshop','.b-products-listing .products-listing .mix-attributes','clear','bpth','4','','.b-products-listing'),(923095,'printshop','.w-cart-compare .product .name','clear','right','','','.w-cart-compare'),(923096,'printshop','.b-messages .dataTables_wrapper > .top','clear','both','4','','.b-messages'),(923097,'printshop','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(923098,'printshop','.b-messages .dataTables_wrapper > .bottom','clear','both','4','','.b-messages'),(923099,'printshop','.b-form .columns','clear','both','4','','.b-form'),(923100,'printshop','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(923101,'printshop','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(923102,'printshop','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(923103,'printshop','.w-login-block .buttons','clear','none','','','.w-login-block'),(923104,'printshop','.w-login-block .cols','clear','both','4','','.w-login-block'),(923105,'printshop','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(923106,'printshop','.w-login-block .guest','clear','right','','','.w-login-block'),(923107,'printshop','.w-menu-horizontal li','clear','none','','','.w-menu-horizontal'),(923108,'printshop','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(923109,'printshop','.b-form .col-left','clear','left','','','.b-form'),(923110,'printshop','.buttons','clear','both','','',''),(923111,'printshop','.buttons','clear','both','4','',''),(923112,'printshop','.w-cart-give-away .ga_column:nth-child(2n + 1)','clear','both','','','.w-cart-give-away'),(923113,'printshop','.w-top-categories .categories','clear','both','4','','.w-top-categories'),(923114,'printshop','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(923115,'printshop','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(923116,'printshop','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(923117,'printshop','.w-checkout-billing-address .addresses','clear','both','4','','.w-checkout-billing-address'),(923118,'printshop','.w-cart-listing .right-area','clear','both','5342','','.w-cart-listing'),(923119,'printshop','.w-checkout-shipping-address .addresses','clear','both','4','','.w-checkout-shipping-address'),(923120,'printshop','.w-checkout-shipping-address .btn-cancel','clear','both','','','.w-checkout-shipping-address'),(923121,'printshop','.w-top-categories .item:nth-child(4n + 1)','clear','both','','','.w-top-categories'),(923122,'printshop','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(923123,'printshop','.b-form .newsletter-row','clear','both','4','','.b-form'),(923124,'printshop','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(923125,'printshop','.w-login-block .cols','clear','both','4','','.w-login-block'),(923126,'printshop','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(923127,'printshop','.w-login-block .guest','clear','right','','','.w-login-block'),(923128,'printshop','.w-login-block .guest','clear','right','','','.w-login-block'),(923129,'printshop','.w-list-b2b .attributes','clear','both','4','','.w-list-b2b'),(923131,'printshop','.w-cart-shipping-estimator .item .row: after','clear','both','','','.w-cart-shipping-estimator'),(923132,'printshop','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(923133,'printshop','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(923134,'printshop','.w-login-block .guest','clear','right','','','.w-login-block'),(923135,'printshop','.w-login-block .buttons','clear','none','','','.w-login-block'),(923136,'printshop','.w-login-block .cols','clear','both','4','','.w-login-block'),(923137,'printshop','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(923138,'printshop','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(923139,'printshop','.b-form .col-right','clear','right','','','.b-form'),(923140,'printshop','.w-cart-compare .product','clear','both','4','','.w-cart-compare'),(923141,'printshop','.w-login-block .buttons','clear','none','','','.w-login-block'),(923142,'printshop','.b-bottom .cart-options .option-item:nth-child(2n + 1)','clear','both','','','.b-bottom'),(923143,'printshop','.b-bottom .cart-options .heading-4','clear','both','','','.b-bottom'),(923144,'printshop','.b-bottom .cart-options .cart-item:nth-child(2n + 1)','clear','both','','','.b-bottom'),(923145,'printshop','.b-bottom .cart-options .options','clear','both','','','.b-bottom'),(923146,'printshop','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(923147,'printshop','.w-login-block .guest','clear','right','','','.w-login-block'),(923148,'printshop','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(923149,'printshop','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-billing-address'),(923150,'printshop','.b-form .center-buttons','clear','both','','','.b-form'),(923151,'printshop','.w-list-b2b .mix-attributes','clear','both','','','.w-list-b2b'),(923152,'printshop','.w-cart-shipping-estimator .address-item .lastname','clear','both','4','','.w-cart-shipping-estimator'),(923153,'printshop','.w-login-block .buttons','clear','none','','','.w-login-block'),(923154,'printshop','.w-cart-compare .product .image','clear','both','','','.w-cart-compare'),(923155,'printshop','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(923156,'printshop','.w-login-block .cols','clear','both','4','','.w-login-block'),(923157,'printshop','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(923158,'printshop','.w-product-reviews .reviews-list','clear','right','','','.w-product-reviews'),(923159,'printshop','.w-cart-compare .buttons','clear','none','','','.w-cart-compare'),(923160,'printshop','.w-menu-big li','clear','none','','','.w-menu-big'),(923161,'printshop','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(923162,'printshop','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(923163,'printshop','.w-login-block .cols','clear','both','4','','.w-login-block'),(923164,'printshop','.w-login-block .guest','clear','right','','','.w-login-block'),(923165,'printshop','.w-login-block .buttons','clear','none','','','.w-login-block'),(923166,'printshop','.b-products-listing .BlockBox','clear','both','4','','.b-products-listing'),(923167,'printshop','.b-products-listing .products-listing','clear','both','4','','.b-products-listing'),(923169,'printshop','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(923170,'printshop','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(923171,'printshop','.w-categories .categories','clear','both','4','','.w-categories'),(923172,'printshop','.b-form .password-forgotten-link','clear','both','','','.b-form'),(923173,'printshop','.b-form .requiredM','clear','both','','','.b-form'),(923174,'printshop','.w-login-block .cols','clear','both','4','','.w-login-block'),(923175,'printshop','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(923176,'printshop','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-shipping-address'),(923177,'printshop','.w-categories .item:nth-child(4n + 1)','clear','both','','','.w-categories'),(923178,'printshop','.w-cart-give-away .ga_name','clear','both','4','','.w-cart-give-away'),(923179,'printshop','.b-form .login_btns','clear','both','','','.b-form'),(923180,'printshop','.w-login-block .buttons','clear','none','','','.w-login-block'),(923181,'printshop','.w-filters .fsl_handle','clear','both','4','','.w-filters'),(923182,'printshop','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(923183,'printshop','.w-cart-shipping-estimator .shipping-estimator','clear','both','4','','.w-cart-shipping-estimator'),(923184,'printshop','.b-form .col-right + .col-left','clear','both','','','.b-form'),(923185,'printshop','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(923186,'printshop','.w-cart-shipping-estimator .item .row','clear','both','','','.w-cart-shipping-estimator'),(923187,'printshop','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(923188,'printshop','.b-form .columns .col-2:nth-child(2n + 1)','clear','left','','','.b-form'),(923189,'printshop','.b-trade-approval .col-right','clear','right','','','.b-trade-approval'),(923190,'printshop','.b-trade-approval .col-left','clear','left','','','.b-trade-approval'),(923191,'printshop','.b-trade-approval .center-buttons','clear','both','','','.b-trade-approval'),(923192,'printshop','.b-trade-approval .columns','clear','both','4','','.b-trade-approval'),(923193,'printshop','.w-catalog-compare .BlockBox','clear','both','','','.w-catalog-compare'),(923194,'printshop','.b-slick .slick-slide','clear','none','','','.b-slick'),(923195,'printshop','.b-slick .slick-track','clear','both','4','','.b-slick'),(923196,'printshop','.w-quote a.item','clear','both','4','','.w-quote'),(923197,'printshop','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(923198,'printshop','.w-product-bonus-points > div','clear','both','4','','.w-product-bonus-points'),(923199,'printshop','.w-compare .compare-button','clear','both','','','.w-compare'),(923200,'printshop','.w-sample a.item','clear','both','4','','.w-sample'),(923201,'printshop','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(923202,'printshop','.b-products-listing .products-listing .radio-attributes','clear','both','4','','.b-products-listing'),(923203,'printshop','.b-pagination .pagination','clear','both','4','','.b-pagination'),(923204,'printshop','.w-product-multi-inventory .select-box:nth-child(2n+1)','clear','both','','','.w-product-multi-inventory'),(923205,'printshop','.w-product-multi-inventory .select-box:last-of-type:after','clear','both','','','.w-product-multi-inventory'),(923206,'printshop','.w-product-multi-inventory .radio-attributes','clear','both','','','.w-product-multi-inventory'),(923207,'printshop','.w-product-multi-inventory #product-attributes','clear','both','4','','.w-product-multi-inventory'),(923208,'printshop','.w-product-multi-inventory .radio-attributes','clear','both','4','','.w-product-multi-inventory'),(923209,'printshop','.w-product-quantity-discounts .quantity-discounts','clear','both','4','','.w-product-quantity-discounts'),(923210,'printshop','.b-products-listing .products-listing .radio-attributes','clear','both','','','.b-products-listing'),(923211,'printshop','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(923212,'printshop','.w-product-attributes #product-attributes','clear','both','4','','.w-product-attributes'),(923213,'printshop','.w-product-attributes .radio-attributes','clear','both','','','.w-product-attributes'),(923214,'printshop','.w-product-attributes .radio-attributes','clear','both','4','','.w-product-attributes'),(923215,'printshop','.w-product-attributes .select-box:last-of-type:after','clear','both','','','.w-product-attributes'),(923216,'printshop','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(923217,'printshop','.w-product-groups .prop-group-swatch','clear','both','4','','.w-product-groups'),(923218,'printshop','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(923219,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list'),(923220,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list-block'),(923221,'printshop','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(923222,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li:nth-child(2n+1)','clear','both','5333','','.w-catalog-pages-category-pages-last-list'),(923223,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li:nth-child(2n+1)','clear','both','5333','','.w-catalog-pages-category-pages-last-list-block'),(923224,'printshop','.w-delivery-location-featured-list .deliveryList ul','clear','both','4','','.w-delivery-location-featured-list'),(923225,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list-by-catalog'),(923226,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(923227,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li:nth-child(2n+1)','clear','both','5333','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(923228,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li:nth-child(2n+1)','clear','both','5333','','.w-catalog-pages-category-pages-last-list-by-catalog'),(923229,'printshop','.w-delivery-location-list-by-page .page-list','clear','both','4','','.w-delivery-location-list-by-page'),(923230,'printshop','.w-delivery-location-top-location-list .deliveryList','clear','both','4','','.w-delivery-location-top-location-list'),(923231,'printshop','.w-delivery-location-list-by-page .item:nth-child(3n+1)','clear','left','','','.w-delivery-location-list-by-page'),(923232,'printshop','.w-delivery-location-list-by-page .item:nth-child(3n+1)','clear','none','5342','','.w-delivery-location-list-by-page'),(923233,'printshop','.w-delivery-location-list-by-page .item:nth-child(2n+1)','clear','left','5342','','.w-delivery-location-list-by-page'),(923234,'printshop','.w-delivery-location-cross-pages .item:nth-child(3n+1)','clear','left','','','.w-delivery-location-cross-pages'),(923235,'printshop','.w-delivery-location-cross-pages .page-list','clear','both','4','','.w-delivery-location-cross-pages'),(923236,'printshop','.w-delivery-location-cross-pages .item:nth-child(2n+1)','clear','left','5342','','.w-delivery-location-cross-pages'),(923237,'printshop','.w-delivery-location-cross-pages .item:nth-child(3n+1)','clear','none','5342','','.w-delivery-location-cross-pages'),(923238,'printshop','.w-catalog-delivery-locations .item:nth-child(2n+1)','clear','left','','','.w-catalog-delivery-locations'),(923239,'printshop','.delivery-options-popup','clear','both','4','',''),(923240,'printshop','.w-gift-wrap-message-checkout .gift_message-comment-box','clear','both','','','.w-gift-wrap-message-checkout'),(923241,'printshop','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(923242,'printshop','.w-product-configurator .pc_attr','clear','both','5333','','.w-product-configurator'),(923243,'printshop','.w-product-configurator .pc_qty','clear','both','5333','','.w-product-configurator'),(923244,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-list'),(923245,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li:nth-child(2n+1)','clear','both','5333','','.w-catalog-pages-category-pages-list'),(923246,'printshop','.w-predefined-promotion .prom-multi-discount','clear','both','4','','.w-predefined-promotion'),(923247,'printshop','.w-neighbour-checkout .neighbour-box','clear','both','4','','.w-neighbour-checkout'),(923248,'printshop','.w-cart-shipping-estimator .left-area','clear','both','5363,4','','.w-cart-shipping-estimator'),(923249,'printshop','.account-address-book .address_book_row','clear','both','','','.account-address-book'),(923251,'printshop','.b-form .addresses','clear','both','4','','.b-form'),(923252,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-content','clear','both','4','','.b-multi-page-checkout'),(923253,'printshop','.w-social-links ','clear','both','','','.w-social-links'),(923254,'printshop','.w-menu-horizontal li','clear_important','important','','','.w-menu-horizontal'),(923255,'printshop','.w-menu-big li','clear_important','important','','','.w-menu-big'),(923256,'printshop','.b-slick .slick-slide','clear_important','important','','','.b-slick'),(923257,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip','rect(0 0 0 0)','','','.b-select-suggest'),(923258,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip_important','important','','','.b-select-suggest'),(923259,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-on i','color','$switch-off-color-2','','','.b-switch'),(923260,'printshop','.b-info .info a','color','$content-color-1','','','.b-info'),(923261,'printshop','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(923262,'printshop','.b-rating .glyphicon','color','$fade-color-2','','','.b-rating'),(923263,'printshop','.w-product-promotions .promotion-data-2 .save','color','$hileght-color-5','','','.w-product-promotions'),(923264,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(923265,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','$content-color-1','','','.p-quick-order-index'),(923266,'printshop','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .specials_category .promo-conditions','color','$hileght-color-4','3','','.w-promotions'),(923267,'printshop','.w-promotions .promo-salemaker .content a','color','$content-color-1','','','.w-promotions'),(923268,'printshop','.w-promotions .promo-cart-discount .item a','color','$content-color-1','','','.w-promotions'),(923269,'printshop','.w-promotions .prom-multi-discount .promo-range','color','$hileght-color-3','','','.w-promotions'),(923270,'printshop','.w-personal-gift-status-bar .end-label','color','$content-color-1','','','.w-personal-gift-status-bar'),(923271,'printshop','.p-sample-checkout-success .page-success .text-3','color','$hileght-color-3','','','.p-sample-checkout-success'),(923272,'printshop','.p-quote-checkout-success .page-success .text-3','color','$hileght-color-3','','','.p-quote-checkout-success'),(923273,'printshop','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(923274,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(923275,'printshop','.testimonials .reviews-list .date','color','$fade-color-1','','',''),(923276,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-2','3','','.w-contact-contacts'),(923277,'printshop','.w-promotions .prom-multi-discount .promo-range, .w-promotions .prom-multi-discount > .heading','color','$hileght-color-3','3','','.w-promotions'),(923278,'printshop','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','color','$content-color-1','','','.w-promotions'),(923279,'printshop','.w-promotions .cart_discount .promo-date','color','$hileght-color-2','3','','.w-promotions'),(923280,'printshop','.w-promotions .multidiscount .promo-date, .w-promotions .multidiscount .heading-3','color','$hileght-color-3','','','.w-promotions'),(923281,'printshop','.w-promotions .cart_discount .heading-3','color','$hileght-color-2','','','.w-promotions'),(923282,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','$content-color-1','','','.p-quick-order-index'),(923283,'printshop','.w-promotions .specials_category .promo-salemaker .content a, .w-promotions .specials_category .promo-date','color','$hileght-color-4','3','','.w-promotions'),(923284,'printshop','.w-promotions .specials_category .heading-3','color','$hileght-color-4','','','.w-promotions'),(923285,'printshop','.w-promotions .promo-salemaker .discount','color','$hileght-color-4','','','.w-promotions'),(923286,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','color','$hileght-color-3','','','.w-promotions'),(923287,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','color','$hileght-color-3','','','.w-promotions'),(923288,'printshop','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','color','$hileght-color-2','3','','.w-promotions'),(923289,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','color','$content-color-1','','','.b-warehouses-popup'),(923290,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','color','$hileght-color-3','','','.b-warehouses-popup'),(923291,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','color','$hileght-color-5','','','.b-warehouses-popup'),(923292,'printshop','.b-warehouses-popup a.warehouses-popup-link','color','$content-color-1','','','.b-warehouses-popup'),(923293,'printshop','.p-quote-checkout-success .page-success .text-3','color','$hileght-color-3','','','.p-quote-checkout-success'),(923294,'printshop','.b-bottom .closeable-heading','color','$content-color-1','3','','.b-bottom'),(923295,'printshop','.b-messages .messMenuButton span','color','$content-color-1','','','.b-messages'),(923296,'printshop','.b-messages .messages-menu li a','color','$content-color-1','','','.b-messages'),(923297,'printshop','.b-messages .content_management_attach','color','$content-color-1','','','.b-messages'),(923298,'printshop','.b-messages .content_management_attach button','color','$content-color-1','','','.b-messages'),(923299,'printshop','.b-messages .select2-search-choice-close','color','$fade-color-1','3','','.b-messages'),(923301,'printshop','.w-socials .post_item > div.tw_post_item','color','$hileght-color-1','3','','.w-socials'),(923302,'printshop','.w-promo-code .holder','color','$hileght-color-3','3','','.w-promo-code'),(923303,'printshop','.w-product-promotions .promotion-full-price-discount','color','$hileght-color-3','','','.w-product-promotions'),(923304,'printshop','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(923305,'printshop','.b-info .info','color','$hileght-color-3','','','.b-info'),(923307,'printshop','.p-payer-order-confirmation .discount-ico','color','$content-color-1','3','','.p-payer-order-confirmation'),(923308,'printshop','.p-payer-order-pay .discount-ico','color','$content-color-1','3','','.p-payer-order-pay'),(923309,'printshop','.b-form .inputRequirement','color','$attention-color','','','.b-form'),(923310,'printshop','.b-fancybox .fancybox-close','color','$fancybox-color-1','','','.b-fancybox'),(923311,'printshop','.b-email-editor .special-price','color','$hileght-color-3','','','.b-email-editor'),(923312,'printshop','.p-quote-checkout-success .page-success .text-3','color','$hileght-color-3','','','.p-quote-checkout-success'),(923313,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','$content-color-1','1','','.p-quick-order-index'),(923314,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-remove','color','$hileght-color-3','','','.w-upload-customer-id-upload-customer-id-form'),(923315,'printshop','.w-menu-horizontal a','color','inherit','','','.w-menu-horizontal'),(923316,'printshop','.order-summary .price-row.ot_bonus_points .title','color','$hileght-color-5','3','','.order-summary'),(923317,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-2','3','','.w-contact-contacts'),(923318,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','color','$checkbox-color-1','3','','.b-form'),(923319,'printshop','.b-info .info a','color','$content-color-1','','','.b-info'),(923320,'printshop','.b-info .info-plus','color','$hileght-color-5','','','.b-info'),(923321,'printshop','.w-coupons-and-vauchers-checkout #credit_modules_message','color','$hileght-color-5','','','.w-coupons-and-vauchers-checkout'),(923322,'printshop','.b-fancybox .fancybox-title-outside-wrap','color','$fancybox-color-1','','','.b-fancybox'),(923323,'printshop','.b-fancybox .fancybox-title-over-wrap','color','$fancybox-color-1','','','.b-fancybox'),(923324,'printshop','.b-email-editor .special-price','color','$hileght-color-3','','','.b-email-editor'),(923325,'printshop','.b-info .info','color','$hileght-color-3','','','.b-info'),(923326,'printshop','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(923327,'printshop','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(923328,'printshop','.btn-1','color','$btn-color-2','','',''),(923329,'printshop','.price .specials','color','$price-special-1','','',''),(923331,'printshop','.w-socials .post_item > div.tw_post_item','color','$hileght-color-1','3','','.w-socials'),(923332,'printshop','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(923333,'printshop','.w-product-promotions .promotion-data-2 .save','color','$hileght-color-5','','','.w-product-promotions'),(923334,'printshop','.w-filters .input-checkbox:checked + .checkbox-span:before','color','$hileght-color-1','','','.w-filters'),(923335,'printshop','.w-cart-compare .product .name a','color','$content-color-1','','','.w-cart-compare'),(923336,'printshop','.b-info .info a','color','$content-color-1','','','.b-info'),(923337,'printshop','.w-reviews .date','color','$fade-color-2','','','.w-reviews'),(923338,'printshop','.w-checkout-shipping-choice span','color','$content-color-1','','','.w-checkout-shipping-choice'),(923339,'printshop','.w-socials .post_item > div.insta_post_item','color','$hileght-color-3','3','','.w-socials'),(923340,'printshop','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(923341,'printshop','.w-socials .post_item > div.tw_post_item','color','$hileght-color-1','3','','.w-socials'),(923342,'printshop','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(923344,'printshop','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(923345,'printshop','.b-rating .glyphicon.coloron ~ .glyphicon-star','color','$content-color-1','','','.b-rating'),(923346,'printshop','.w-image-maps .default-links .item .description','color','$content-color-1','','','.w-image-maps'),(923347,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-2','3','','.w-contact-contacts'),(923348,'printshop','.price .special','color','$price-special-1','','',''),(923349,'printshop','.w-reviews-content .date','color','$fade-color-2','','','.w-reviews-content'),(923350,'printshop','.b-delete-account .delete-box .delete-message','color','$hileght-color-3','','','.b-delete-account'),(923351,'printshop','.b-info .info','color','$hileght-color-3','','','.b-info'),(923352,'printshop','.b-form .radio-button input[type=\"radio\"]:checked + span:before','color','$checkbox-color-1','','','.b-form'),(923353,'printshop','.w-multi-cart-actions .cart-actions .dropdown-toggle','color','$fade-color-1','3','','.w-multi-cart-actions'),(923356,'printshop','.w-tabs .tab-a','color','$tab-nav-color-1','2','','.w-tabs'),(923357,'printshop','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(923358,'printshop','.w-socials .post_item > div.tw_post_item','color','$hileght-color-1','3','','.w-socials'),(923359,'printshop','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(923360,'printshop','.w-socials .post_item > div.insta_post_item','color','$hileght-color-3','3','','.w-socials'),(923361,'printshop','.bell-ico .heading-2','color','$content-color-1','3','','.bell-ico'),(923362,'printshop','.w-tabs a.tab-a','color','$content-color-1','','','.w-tabs'),(923363,'printshop','.w-tabs .tab-li:hover a.tab-a','color','$content-color-1','','','.w-tabs'),(923364,'printshop','.w-cart-credit-amount #credit_modules_message.error','color','$hileght-color-3','','','.w-cart-credit-amount'),(923365,'printshop','.w-cart-credit-amount #credit_modules_message','color','$hileght-color-5','','','.w-cart-credit-amount'),(923366,'printshop','.w-cart-listing .attention_mark','color','$hileght-color-3','','','.w-cart-listing'),(923367,'printshop','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(923368,'printshop','.w-product-promotions .promotion-full-price-discount','color','$hileght-color-3','','','.w-product-promotions'),(923369,'printshop','.w-product-promotions .promotion-data-2 .save','color','$hileght-color-5','','','.w-product-promotions'),(923370,'printshop','.w-personal-gift-status-bar .start-label','color','$content-color-1','','','.w-personal-gift-status-bar'),(923371,'printshop','.p-quote-checkout-success .page-success .text-3','color','$hileght-color-3','','','.p-quote-checkout-success'),(923372,'printshop','a.btn-2','color','$btn-color-3','','',''),(923373,'printshop','.btn-2','color','$btn-color-3','','',''),(923374,'printshop','.heading-4 .edit, h4 .edit','color','$link-color-1','','',''),(923375,'printshop','.w-cart-compare .delete-cart','color','$content-color-1','3','','.w-cart-compare'),(923376,'printshop','.w-cart-compare .cart-name a','color','$content-color-1','','','.w-cart-compare'),(923377,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','color','$switch-on-color-1','','','.b-switch'),(923378,'printshop','.p-sample-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-sample-checkout-success'),(923379,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-2','3','','.w-contact-contacts'),(923380,'printshop','.w-top-categories .categories h2','color','inherit','','','.w-top-categories'),(923381,'printshop','.out-stock','color','$attention-color','','',''),(923382,'printshop','.transit','color','$hileght-color-2','','',''),(923383,'printshop','.in-stock','color','$color-10','','',''),(923384,'printshop','.heading-3 .edit, h3 .edit','color','$link-color-1','','',''),(923385,'printshop','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(923386,'printshop','.b-bottom .header-error','color','$hileght-color-3','','','.b-bottom'),(923387,'printshop','.w-socials .post_item > div.insta_post_item','color','$hileght-color-3','3','','.w-socials'),(923388,'printshop','.savings-ico .heading-2','color','$hileght-color-5','3','','.savings-ico'),(923389,'printshop','.w-promo-code .holder','color','$hileght-color-3','3','','.w-promo-code'),(923391,'printshop','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(923392,'printshop','.testimonials .date','color','$fade-color-1','','',''),(923393,'printshop','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(923394,'printshop','.b-fancybox .fancybox-title-float-wrap .child','color','$fancybox-color-1','','','.b-fancybox'),(923395,'printshop','.w-reviews-content .product-name a','color','$content-color-1','','','.w-reviews-content'),(923396,'printshop','.b-fancybox .fancybox-skin','color','$fancybox-color-1','','','.b-fancybox'),(923397,'printshop','.w-product-promotions .promotion-full-price-discount','color','$hileght-color-3','','','.w-product-promotions'),(923398,'printshop','.w-product-promotions .promotion-data-2 .save','color','$hileght-color-5','','','.w-product-promotions'),(923399,'printshop','.w-socials .post_item > div.insta_post_item','color','$hileght-color-3','3','','.w-socials'),(923400,'printshop','.w-socials .post_item > div.tw_post_item','color','$hileght-color-1','3','','.w-socials'),(923401,'printshop','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(923402,'printshop','.b-info .info-plus','color','$hileght-color-5','','','.b-info'),(923403,'printshop','.main-content a','color','$link-color-1','','',''),(923404,'printshop','.btn','color','$btn-color-1','','',''),(923407,'printshop','.message.success','color','$message-color','','',''),(923408,'printshop','.b-form .required-message','color','$attention-color','','','.b-form'),(923409,'printshop','.b-email-editor .special-price','color','$hileght-color-3','','','.b-email-editor'),(923410,'printshop','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(923411,'printshop','.w-promo-code .holder','color','$hileght-color-3','3','','.w-promo-code'),(923412,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(923413,'printshop','.w-reviews .heading-3','color','$content-color-1','3','','.w-reviews'),(923414,'printshop','.w-reviews .product-name a','color','$content-color-1','','','.w-reviews'),(923415,'printshop','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','color','$content-color-1','','','.b-select-suggest'),(923416,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span:before','color','$checkbox-color-1','','','.b-form'),(923417,'printshop','.b-info .info a','color','$content-color-1','','','.b-info'),(923418,'printshop','.b-info .info','color','$hileght-color-3','','','.b-info'),(923419,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','color','$switch-off-color-2','','','.b-switch'),(923420,'printshop','a','color','inherit','','',''),(923422,'printshop','a.btn','color','$btn-color-1','','',''),(923424,'printshop','.b-form .checkbox-style:checked + .checkbox-span:before','color','$checkbox-color-1','','','.b-form'),(923425,'printshop','.btn-del','color','$attention-color','4','',''),(923426,'printshop','.b-form .required','color','$attention-color','','','.b-form'),(923427,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(923428,'printshop','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(923430,'printshop','.b-rating .glyphicon-star.coloron','color','$content-color-1','3','','.b-rating'),(923431,'printshop','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(923432,'printshop','.b-pass-strength span.good-pass','color','$hileght-color-5','','','.b-pass-strength'),(923433,'printshop','.b-pass-strength span.strong-pass, .b-pass-strength span.pass-match','color','$hileght-color-5','','','.b-pass-strength'),(923434,'printshop','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(923435,'printshop','.b-info .info','color','$hileght-color-3','','','.b-info'),(923436,'printshop','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(923439,'printshop','.w-promo-code .holder','color','$hileght-color-3','3','','.w-promo-code'),(923440,'printshop','.w-product-promotions .promotion-data-2 .save','color','$hileght-color-5','','','.w-product-promotions'),(923441,'printshop','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(923443,'printshop','.b-info .info-plus','color','$hileght-color-5','','','.b-info'),(923444,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(923445,'printshop','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(923446,'printshop','.b-bottom .pop-up-close','color','$fade-color-1','1','','.b-bottom'),(923447,'printshop','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','color','$fade-color-1','3','','.order-summary'),(923448,'printshop','.order-summary .price-row.ot_gv .title','color','$hileght-color-5','3','','.order-summary'),(923449,'printshop','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','color','$hileght-color-5','','','.b-products-listing'),(923450,'printshop','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','color','$hileght-color-5','','','.b-products-listing'),(923451,'printshop','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(923453,'printshop','.b-email-editor .special-price','color','$hileght-color-3','','','.b-email-editor'),(923454,'printshop','.b-info .info a','color','$content-color-1','','','.b-info'),(923455,'printshop','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(923456,'printshop','.b-info .info-plus','color','$hileght-color-5','','','.b-info'),(923457,'printshop','.b-info .info','color','$hileght-color-3','','','.b-info'),(923458,'printshop','.b-form .privacy-row a','color','$content-color-1','','','.b-form'),(923461,'printshop','.p-quote-checkout-success .page-success .text-3','color','$hileght-color-3','','','.p-quote-checkout-success'),(923462,'printshop','.w-product-promotions .promotion-full-price-discount','color','$hileght-color-3','','','.w-product-promotions'),(923463,'printshop','.w-image-maps .categories-items .item .description','color','$content-color-1','','','.w-image-maps'),(923464,'printshop','.w-checkout-shipping-choice input:checked + span','color','$highlight-box-color-1','','','.w-checkout-shipping-choice'),(923465,'printshop','.w-socials .post_item > div.insta_post_item','color','$hileght-color-3','3','','.w-socials'),(923466,'printshop','.w-tabs .accordion-heading','color','$content-color-1','2','','.w-tabs'),(923467,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on i, .b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-off i','color','$switch-on-color-1','','','.b-switch'),(923468,'printshop','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(923469,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','color','$content-color-1','','','.b-select-suggest'),(923470,'printshop','.b-select-suggest .select2-default','color','$fade-color-1','','','.b-select-suggest'),(923471,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','color','$content-color-1','','','.b-select-suggest'),(923472,'printshop','.b-select-suggest .select2-results .select2-highlighted ul','color','$content-color-1','','','.b-select-suggest'),(923473,'printshop','.b-select-suggest .select2-results .select2-highlighted','color','$content-color-1','','','.b-select-suggest'),(923474,'printshop','.b-select-suggest .select2-drop','color','$content-color-1','','','.b-select-suggest'),(923476,'printshop','.w-socials .post_item > div.insta_post_item','color','$hileght-color-3','3','','.w-socials'),(923477,'printshop','.w-menu-big a','color','inherit','','','.w-menu-big'),(923479,'printshop','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(923481,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','$content-color-1','','','.b-data-table'),(923482,'printshop','.b-products-listing .products-listing .bonus-points span:first-child','color','$content-color-1','','','.b-products-listing'),(923483,'printshop','.b-products-listing .products-listing .bonus-points-price','color','$content-color-1','3','','.b-products-listing'),(923484,'printshop','.b-products-listing .products-listing .bonus-points-cost','color','$content-color-1','3','','.b-products-listing'),(923485,'printshop','.w-catalog-b2b-add-button ','color','$highlight-box-color-1','','','.w-catalog-b2b-add-button'),(923489,'printshop','.w-promo-code .holder','color','$hileght-color-3','3','','.w-promo-code'),(923490,'printshop','.b-upload-file .snapshot','color','$fade-color-1','','','.b-upload-file'),(923491,'printshop','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(923492,'printshop','.b-info .info-plus','color','$hileght-color-5','','','.b-info'),(923493,'printshop','.b-info .info a','color','$content-color-1','','','.b-info'),(923494,'printshop','.w-top-categories h2.name','color','$content-color-1','','','.w-top-categories'),(923496,'printshop','.w-coupons-and-vauchers-checkout #credit_modules_message.error','color','$hileght-color-3','','','.w-coupons-and-vauchers-checkout'),(923497,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-2','3','','.w-contact-contacts'),(923498,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','color','$content-color-1','','','.w-communication-new-topic'),(923499,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','color','$content-color-1','','','.w-communication-new-topic'),(923500,'printshop','.btn-3','color','$btn-color-4','','',''),(923501,'printshop','.order-summary .price-row.ot_coupon .title','color','$hileght-color-5','3','','.order-summary'),(923502,'printshop','.w-product-promotions .promotion-full-price-discount','color','$hileght-color-3','','','.w-product-promotions'),(923503,'printshop','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(923504,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','color','inherit','','','.w-contact-contacts'),(923505,'printshop','.w-cart-compare .product-actions .dropdown-toggle','color','$fade-color-1','','','.w-cart-compare'),(923506,'printshop','.w-promo-code .holder','color','$hileght-color-3','3','','.w-promo-code'),(923507,'printshop','.b-info .info-plus','color','$hileght-color-5','','','.b-info'),(923508,'printshop','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(923509,'printshop','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(923510,'printshop','.w-catalog-listing-look .grid','color','$content-color-1','','','.w-catalog-listing-look'),(923511,'printshop','.w-catalog-listing-look .b2b','color','$highlight-box-color-2','2','','.w-catalog-listing-look'),(923512,'printshop','.w-catalog-listing-look .b2b','color','$content-color-1','','','.w-catalog-listing-look'),(923513,'printshop','.w-catalog-listing-look .list','color','$content-color-1','','','.w-catalog-listing-look'),(923514,'printshop','.w-catalog-listing-look .grid','color','$highlight-box-color-2','2','','.w-catalog-listing-look'),(923515,'printshop','.w-catalog-listing-look .list','color','$highlight-box-color-2','2','','.w-catalog-listing-look'),(923516,'printshop','.checkbox input:checked + span:before','color','$checkbox-color-1','','',''),(923517,'printshop','.p-quick-order-index .all-scroll-div','color','$highlight-box-color-1','','','.p-quick-order-index'),(923518,'printshop','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','color','$fade-color-1','','','.w-cart-listing'),(923519,'printshop','.w-cart-listing .actions a','color','$fade-color-1','','','.w-cart-listing'),(923520,'printshop','.w-cart-listing .points-redeem','color','$hileght-color-5','','','.w-cart-listing'),(923521,'printshop','.w-cart-listing .remove-btn','color','$fade-color-1','','','.w-cart-listing'),(923522,'printshop','.w-cart-discount-coupon #credit_modules_message.error','color','$hileght-color-3','','','.w-cart-discount-coupon'),(923523,'printshop','.w-cart-discount-coupon #credit_modules_message','color','$hileght-color-5','','','.w-cart-discount-coupon'),(923524,'printshop','.b-email-editor .special-price','color','$hileght-color-3','','','.b-email-editor'),(923525,'printshop','.w-image-maps .float-items .item .description','color','$content-color-1','','','.w-image-maps'),(923526,'printshop','.b-fancybox .fancybox-nav span','color','$fancybox-color-1','','','.b-fancybox'),(923527,'printshop','.b-email-editor .special-price','color','$hileght-color-3','','','.b-email-editor'),(923528,'printshop','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(923529,'printshop','.w-socials .post_item > div.tw_post_item','color','$hileght-color-1','3','','.w-socials'),(923530,'printshop','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(923531,'printshop','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(923532,'printshop','.w-product-promotions .promotion-full-price-discount','color','$hileght-color-3','','','.w-product-promotions'),(923533,'printshop','.w-product-promotions .promotion-data-2 .save','color','$hileght-color-5','','','.w-product-promotions'),(923534,'printshop','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(923535,'printshop','.w-filters .open','color','$hileght-color-1','3','','.w-filters'),(923536,'printshop','.w-filters .head-filter-widget','color','$highlight-box-color-1','5342','','.w-filters'),(923537,'printshop','.w-filters .view_more','color','$content-color-1','','','.w-filters'),(923538,'printshop','.p-quote-checkout-success .page-success .text-3','color','$hileght-color-3','','','.p-quote-checkout-success'),(923539,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','color','$fade-color-2','3','','.w-contact-contacts'),(923540,'printshop','.b-bottom .pop-up-close','color','$fade-color-1','','','.b-bottom'),(923541,'printshop','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(923542,'printshop','.b-pass-strength span.bad-pass','color','$hileght-color-4','','','.b-pass-strength'),(923543,'printshop','.w-product-reviews .reviews-list .date','color','$fade-color-1','','','.w-product-reviews'),(923544,'printshop','.b-upload-files .remove-file','color','$hileght-color-3','3','','.b-upload-files'),(923545,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','$content-color-1','1','','.b-data-table'),(923546,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','$content-color-1','','','.b-data-table'),(923548,'printshop','a.btn-3','color','$btn-color-4','','',''),(923549,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.off .candlestick-off','color','$switch-handle-bg-3','4','','.b-switch'),(923550,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.on .candlestick-on','color','$switch-handle-bg-3','4','','.b-switch'),(923551,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.default .candlestick-nc','color','$switch-handle-bg-3','4','','.b-switch'),(923552,'printshop','.b-pass-strength .short-pass, .b-pass-strength .pass-strength, .b-pass-strength .pass-no-match','color','$hileght-color-3','','','.b-pass-strength'),(923553,'printshop','.b-form .message.error','color','$attention-color','','','.b-form'),(923554,'printshop','a.btn-1','color','$btn-color-2','','',''),(923555,'printshop','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','color','$fade-color-2','','','.w-filters'),(923556,'printshop','.b-product-images .media-popup .mp-close','color','$image-popup-color-2','','','.b-product-images'),(923557,'printshop','.b-product-images .media-popup .mp-close','color','$image-popup-color-1','1','','.b-product-images'),(923558,'printshop','.b-product-images .media-popup .slick-dots li','color','$image-popup-color-2','','','.b-product-images'),(923559,'printshop','.b-product-images .media-popup .slick-dots li.slick-active','color','$image-popup-color-1','','','.b-product-images'),(923560,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','color','$image-popup-color-2','','','.b-product-images'),(923561,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','color','$image-popup-color-1','1','','.b-product-images'),(923562,'printshop','.b-personal-catalog-popup #personal_catalog_popup .show-all-lists','color','$content-color-1','','','.b-personal-catalog-popup'),(923563,'printshop','.b-trade-approval .steps-bar li.current a','color','$highlight-box-color-1','','','.b-trade-approval'),(923564,'printshop','.b-trade-approval .middle-form label','color','$content-color-1','','','.b-trade-approval'),(923565,'printshop','.w-account-personal-catalog .list-switcher a','color','$hileght-color-1','2','','.w-account-personal-catalog'),(923566,'printshop','.w-catalog-compare .checkbox input:checked + span:before','color','$fade-color-1','','','.w-catalog-compare'),(923567,'printshop','.w-catalog-compare span.btn-preloader','color','$content-color-1','3','','.w-catalog-compare'),(923568,'printshop','.w-catalog-compare .cross-box .different-all > div','color','$content-color-1','2','','.w-catalog-compare'),(923569,'printshop','.w-catalog-compare .cross-box .return','color','$content-color-1','','','.w-catalog-compare'),(923570,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','color','$content-color-1','3','','.w-catalog-compare'),(923571,'printshop','.w-delivery-day .ends','color','$hileght-color-3','','','.w-delivery-day'),(923572,'printshop','.w-delivery-day .left-count-days-text, .w-delivery-day .left-count-hours-text, .w-delivery-day .left-count-minutes-text, .w-delivery-day .left-count-seconds-text','color','$highlight-box-color-1','','','.w-delivery-day'),(923576,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','color','$content-color-1','','','.b-slick'),(923577,'printshop','.menu-header .burger-icon','color','$highlight-box-color-4','5342','','.menu-header'),(923578,'printshop','.menu-header .burger-icon','color','$content-color-1','5342,3','','.menu-header'),(923579,'printshop','.price .old','color','$price-old-1','','',''),(923580,'printshop','.w-subscribers .btn-submit','color','$highlight-box-color-4','','','.w-subscribers'),(923581,'printshop','.w-quote .cart-box-link','color','$highlight-box-color-4','3','','.w-quote'),(923582,'printshop','.w-quote .multicart .count','color','$fade-color-1','','','.w-quote'),(923583,'printshop','.w-quote .multicart .item.current-multi-cart .switch-cart','color','$content-color-1','3','','.w-quote'),(923584,'printshop','.w-quote .multicart .switch-cart','color','$fade-color-2','','','.w-quote'),(923585,'printshop','.w-quote .multicart a.switch-cart','color','$hileght-color-3','1','','.w-quote'),(923588,'printshop','.b-quantity .qty-box .bigger','color','$content-color-1','','','.b-quantity'),(923589,'printshop','.b-quantity .qty-box .smaller','color','$content-color-1','','','.b-quantity'),(923590,'printshop','.rating-0, .rating-1, .rating-2, .rating-3, .rating-4, .rating-5','color','$hileght-color-2','','',''),(923591,'printshop','.w-product-sale-ends .ends','color','$hileght-color-3','','','.w-product-sale-ends'),(923592,'printshop','.w-product-sale-ends .left-count-days-text','color','$content-color-1','','','.w-product-sale-ends'),(923593,'printshop','.w-product-sale-ends .left-count-hours-text','color','$content-color-1','','','.w-product-sale-ends'),(923594,'printshop','.w-product-quantity .qty_packs .price_1','color','$fade-color-2','4','','.w-product-quantity'),(923595,'printshop','.w-product-bonus-points > div > div','color','$content-color-1','','','.w-product-bonus-points'),(923596,'printshop','.warrantyProduct div','color','$content-color-1','','','.warrantyProduct'),(923597,'printshop','.w-files-catalog-widgets-files-catalog .name a','color','$highlight-box-color-1','','','.w-files-catalog-widgets-files-catalog'),(923598,'printshop','.w-files-catalog-widgets-files-list .file','color','$content-color-1','3','','.w-files-catalog-widgets-files-list'),(923599,'printshop','.w-sample .cart-box-link','color','$highlight-box-color-4','3','','.w-sample'),(923600,'printshop','.w-sample .cart-content','color','$content-color-1','','','.w-sample'),(923601,'printshop','.w-sample .multicart .count','color','$fade-color-1','','','.w-sample'),(923602,'printshop','.w-sample .multicart .item.current-multi-cart .switch-cart','color','$content-color-1','3','','.w-sample'),(923603,'printshop','.w-sample .multicart .switch-cart','color','$fade-color-2','','','.w-sample'),(923604,'printshop','.w-sample .multicart a.switch-cart','color','$hileght-color-3','1','','.w-sample'),(923605,'printshop','.w-cart-gift-certificate .gift-certificate .heading-4','color','$content-color-1','3','','.w-cart-gift-certificate'),(923607,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','color','inherit','','','.b-products-listing'),(923608,'printshop','.b-pagination .pagination span','color','$highlight-box-border-2','2','','.b-pagination'),(923609,'printshop','.b-products-listing .products-listing.list-rows .stock','color','$hileght-color-5','','','.b-products-listing'),(923610,'printshop','.b-products-listing .products-listing.list-b2b .stock','color','$hileght-color-5','','','.b-products-listing'),(923611,'printshop','.w-product-collection .save','color','$hileght-color-5','','','.w-product-collection'),(923612,'printshop','.w-product-collection .right-area .separate-text, .w-product-collection .right-area .separate','color','$fade-color-1','','','.w-product-collection'),(923613,'printshop','.w-product-collection .together','color','$content-color-1','','','.w-product-collection'),(923614,'printshop','.price .special-promote','color','$price-special-2','','',''),(923615,'printshop','.w-product-in-bundles .bundle_price .old','color','$fade-color-1','','','.w-product-in-bundles'),(923616,'printshop','.w-product-in-bundles .bundle_price .specials','color','$hileght-color-3','','','.w-product-in-bundles'),(923617,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','color','$fade-color-2','','','.w-questionnaire-widgets-questionnaire'),(923618,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','color','$hileght-color-3','','','.w-questionnaire-widgets-questionnaire'),(923619,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','color','$hileght-color-5','','','.w-questionnaire-widgets-questionnaire'),(923620,'printshop','.w-product-groups .radioBox label input:checked + div .val1','color','$hileght-color-1','','','.w-product-groups'),(923621,'printshop','.w-product-groups .val1','color','$content-color-1','','','.w-product-groups'),(923622,'printshop','.w-product-groups .val2','color','$content-color-1','','','.w-product-groups'),(923623,'printshop','.w-product-custom-bundle .save','color','$hileght-color-5','','','.w-product-custom-bundle'),(923624,'printshop','.w-product-custom-bundle .right-area .separate','color','$hileght-color-3','','','.w-product-custom-bundle'),(923625,'printshop','.w-delivery-location-location-list .deliveryList li a','color','$content-color-1','1','','.w-delivery-location-location-list'),(923626,'printshop','.w-sale-category .badge','color','$highlight-box-color-1','','','.w-sale-category'),(923627,'printshop','.w-sale-category .ends','color','$hileght-color-3','','','.w-sale-category'),(923628,'printshop','.w-sale-category .left-count-days-text','color','$highlight-box-color-1','','','.w-sale-category'),(923629,'printshop','.w-sale-category .left-count-hours-text','color','$highlight-box-color-1','','','.w-sale-category'),(923630,'printshop','.w-sale-category .special-price','color','$hileght-color-3','','','.w-sale-category'),(923631,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','color','$content-color-1','','','.w-product-properties-icons'),(923632,'printshop','.w-product-properties-icons .hover-box-content','color','$transparent','','','.w-product-properties-icons'),(923633,'printshop','.w-delivery-location-product-categories .name','color','$highlight-box-color-4','','','.w-delivery-location-product-categories'),(923634,'printshop','.w-product-designer-designer .grnamebox .title-sortable','color','$highlight-box-color-4','','','.w-product-designer-designer'),(923635,'printshop','.w-product-designer-designer .prodDesignerType label','color','$content-color-1','','','.w-product-designer-designer'),(923636,'printshop','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','color','$hileght-color-1','','','.w-press-reviews-widgets-press-reviews-small'),(923637,'printshop','.w-press-reviews-widgets-press-reviews .date','color','$fade-color-1','','','.w-press-reviews-widgets-press-reviews'),(923638,'printshop','.w-press-reviews-widgets-press-reviews .full-review a','color','$hileght-color-1','','','.w-press-reviews-widgets-press-reviews'),(923639,'printshop','.w-press-reviews-widgets-press-reviews-list .date-added','color','$fade-color-2','','','.w-press-reviews-widgets-press-reviews-list'),(923640,'printshop','.w-press-reviews-widgets-press-reviews-list .out-link a','color','$hileght-color-1','','','.w-press-reviews-widgets-press-reviews-list'),(923641,'printshop','.b-products-listing .productGroup label a','color','$content-color-1','','','.b-products-listing'),(923642,'printshop','.w-gift-wrap-message-checkout .error','color','$hileght-color-3','','','.w-gift-wrap-message-checkout'),(923643,'printshop','.w-support-system-listing .support-head','color','$hileght-color-1','','','.w-support-system-listing'),(923644,'printshop','.w-rma-returns-history .column .title','color','$highlight-box-color-1','','','.w-rma-returns-history'),(923645,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','color','$transparent','','','.w-rma-returns-history'),(923646,'printshop','.w-rma-returns-history .icons .excel','color','$hileght-color-5','3','','.w-rma-returns-history'),(923647,'printshop','.w-rma-returns-history .icons .print','color','$content-color-1','','','.w-rma-returns-history'),(923648,'printshop','.w-rma-returns-history .linkButton','color','$hileght-color-1','','','.w-rma-returns-history'),(923649,'printshop','.w-rma-returns-history .linkButton','color','$content-color-1','1','','.w-rma-returns-history'),(923650,'printshop','.w-rma-returns-history thead tr','color','$highlight-box-color-1','','','.w-rma-returns-history'),(923651,'printshop','.w-rma-returns-history thead tr td','color','$highlight-box-color-1','','','.w-rma-returns-history'),(923652,'printshop','.b-products-listing .promos-info .promo-name-span','color','$highlight-box-color-2','','','.b-products-listing'),(923653,'printshop','.w-predefined-promotion .cart_discount .heading-3','color','$hileght-color-2','','','.w-predefined-promotion'),(923654,'printshop','.w-predefined-promotion .cart_discount .promo-date','color','$hileght-color-2','3','','.w-predefined-promotion'),(923655,'printshop','.w-predefined-promotion .multidiscount .promo-date, .w-predefined-promotion .multidiscount .heading-3','color','$hileght-color-3','','','.w-predefined-promotion'),(923656,'printshop','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','color','$content-color-1','','','.w-predefined-promotion'),(923657,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','color','$hileght-color-3','','','.w-predefined-promotion'),(923658,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range, .w-predefined-promotion .prom-multi-discount > .heading','color','$hileght-color-3','3','','.w-predefined-promotion'),(923659,'printshop','.w-predefined-promotion .promo-cart-discount .item a','color','$content-color-1','','','.w-predefined-promotion'),(923660,'printshop','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','color','$hileght-color-2','3','','.w-predefined-promotion'),(923661,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','color','$hileght-color-3','','','.w-predefined-promotion'),(923662,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','color','$hileght-color-3','','','.w-predefined-promotion'),(923663,'printshop','.w-predefined-promotion .promo-salemaker .content a','color','$content-color-1','','','.w-predefined-promotion'),(923664,'printshop','.w-predefined-promotion .promo-salemaker .discount','color','$hileght-color-4','','','.w-predefined-promotion'),(923665,'printshop','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .specials_category .promo-conditions','color','$hileght-color-4','3','','.w-predefined-promotion'),(923666,'printshop','.w-predefined-promotion .specials_category .heading-3','color','$hileght-color-4','','','.w-predefined-promotion'),(923667,'printshop','.w-predefined-promotion .specials_category .promo-salemaker .content a, .w-predefined-promotion .specials_category .promo-date','color','$hileght-color-4','3','','.w-predefined-promotion'),(923668,'printshop','.w-supplier-purchase-supplier-products .active .select_item > div:before','color','$hileght-color-5','','','.w-supplier-purchase-supplier-products'),(923669,'printshop','body','color','$content-color-1','','',''),(923673,'printshop','.w-categories h2.name','color','$content-color-1','','','.w-categories'),(923674,'printshop','.b-quantity .qty-box input[type=\"text\"]','color','$content-color-1','','','.b-quantity'),(923675,'printshop','.w-product-groups .radioBox label .containerBlock.selected .val1','color','$hileght-color-1','','','.w-product-groups'),(923676,'printshop','.w-cart-listing .name a','color','$hileght-color-1','','','.w-cart-listing'),(923677,'printshop','.p-wedding-registry-view h1','color','$hileght-color-3','3','','.p-wedding-registry-view'),(923678,'printshop','.p-wedding-registry-view h1','color','$hileght-color-3','4','','.p-wedding-registry-view'),(923679,'printshop','.lowestPricedBox .title','color','$content-color-1','','','.lowestPricedBox'),(923680,'printshop','.lowestPricedBox .descr','color','$content-color-1','','','.lowestPricedBox'),(923681,'printshop','.doubleBanner .descr','color','$additional-banner-color-1','','','.doubleBanner'),(923682,'printshop','.doubleBanner .title','color','$additional-banner-color-1','','','.doubleBanner'),(923683,'printshop','.doubleBanner .descr','color','$additional-banner-color-1','5347','','.doubleBanner'),(923684,'printshop','.doubleBanner .title','color','$additional-banner-color-1','5347','','.doubleBanner'),(923685,'printshop','.middleBanner .btn-1','color','$additional-banner-color-2','','','.middleBanner'),(923686,'printshop','.bottomDoubleBanner .title','color','$additional-banner-color-1','','','.bottomDoubleBanner'),(923687,'printshop','.bottomDoubleBanner .title','color','$additional-banner-color-1','5347','','.bottomDoubleBanner'),(923688,'printshop','.bottomBanner .btn-1','color','$additional-banner-color-2','','','.bottomBanner'),(923689,'printshop','.bottomBanner .wrapper','color','$additional-banner-color-2','','','.bottomBanner'),(923691,'printshop','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','color','$content-color-1','3','','.b-menu-burger_icon'),(923692,'printshop','.w-product-personal-catalog-button .btn','color','$hileght-color-1','','','.w-product-personal-catalog-button'),(923693,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','color','$hileght-color-1','','','.b-products-listing'),(923694,'printshop','.topBanner .content','color','$main-banner-color-1','','','.topBanner'),(923695,'printshop','.topBanner .content .btn','color','$main-banner-color-1','','','.topBanner'),(923696,'printshop','.topBanner .ourPick .bottom','color','$main-banner-color-3','','','.topBanner'),(923697,'printshop','.topBanner .ourPick .top','color','$main-banner-color-2','','','.topBanner'),(923698,'printshop','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','color','$content-color-1','','','.w-promotions-widgets-promotion-icons-desc'),(923699,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','color','$highlight-box-color-2','','','.p-quote-checkout-index'),(923700,'printshop','.p-quote-checkout-index .edit-address-popup .edit-ab','color','$content-color-1','','','.p-quote-checkout-index'),(923701,'printshop','.account-address-book .leftMes div','color','$hileght-color-3','','','.account-address-book'),(923702,'printshop','.account-address-book .leftMes ul','color','$hileght-color-3','','','.account-address-book'),(923703,'printshop','.account-address-book .rightMes ul','color','$hileght-color-3','','','.account-address-book'),(923723,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','color','$content-color-1','3','','.account-order-pay'),(923724,'printshop','.account-order-pay .not_fully_paid_td','color','$hileght-color-3','','','.account-order-pay'),(923725,'printshop','.account-samples .moduleRowDue td','color','$fade-color-2','','','.account-samples'),(923726,'printshop','.account-samples .not_fully_paid_td','color','$hileght-color-3','','','.account-samples'),(923727,'printshop','.account-samples .view_link','color','$content-color-1','','','.account-samples'),(923728,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','color','$content-color-1','3','','.account-sample-info'),(923729,'printshop','.account-sample-info .not_fully_paid_td','color','$hileght-color-3','','','.account-sample-info'),(923730,'printshop','.catalog-product-wrap .pn-direction','color','$content-color-1','','','.catalog-product-wrap'),(923731,'printshop','.catalog-product-wrap .pn-image','color','$fade-color-2','3','','.catalog-product-wrap'),(923732,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','color','$highlight-box-color-2','','','.checkout-index-wrap'),(923733,'printshop','.checkout-index-wrap .edit-address-popup .edit-ab','color','$content-color-1','','','.checkout-index-wrap'),(923734,'printshop','.checkout-order-confirmation .discount-ico','color','$content-color-1','3','','.checkout-order-confirmation'),(923735,'printshop','.checkout-success-wrap .page-success .text-1','color','$content-color-1','3','','.checkout-success-wrap'),(923736,'printshop','.checkout-success-wrap .page-success .text-3','color','$hileght-color-3','','','.checkout-success-wrap'),(923737,'printshop','.b-info .danger-message','color','$attention-color','','','.b-info'),(923738,'printshop','.b-info .info-message','color','$message-color','','','.b-info'),(923739,'printshop','.b-info .success-message','color','$message-color','','','.b-info'),(923740,'printshop','.b-info .warning-message','color','$warning-color','','','.b-info'),(923741,'printshop','.success-page .check-ico-block','color','$hileght-color-1','3','','.success-page'),(923742,'printshop','.success-page .comment-ico','color','$hileght-color-1','3','','.success-page'),(923743,'printshop','.success-page .discount-ico','color','$hileght-color-1','3','','.success-page'),(923744,'printshop','.success-page .order-ico','color','$hileght-color-1','3','','.success-page'),(923745,'printshop','.success-page .page-success .text-1','color','$hileght-color-1','3','','.success-page'),(923746,'printshop','.success-page .page-success .text-3','color','$attention-color','','','.success-page'),(923747,'printshop','.success-page .pay-ico','color','$hileght-color-1','3','','.success-page'),(923748,'printshop','.success-page .prod-ico','color','$hileght-color-1','3','','.success-page'),(923749,'printshop','.success-page .ship-ico','color','$hileght-color-1','3','','.success-page'),(923750,'printshop','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading','color','$content-color-1','','','.b-multi-page-checkout'),(923751,'printshop','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','color','$highlight-box-color-1','','','.b-multi-page-checkout'),(923752,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading','color','$fade-color-2','','','.b-multi-page-checkout'),(923753,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','$highlight-box-color-2','3','','.b-multi-page-checkout'),(923754,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','$content-color-1','','','.b-multi-page-checkout'),(923755,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','$content-color-1','','','.b-multi-page-checkout'),(923756,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','$content-color-1','4','','.b-multi-page-checkout'),(923757,'printshop','.success-page .w-cart-listing .qty','color','$highlight-box-color-2','','','.success-page'),(923758,'printshop','.middleBanner div.banner-text-holder','color','$additional-banner-color-2','','','.middleBanner'),(923765,'printshop','.footer-menu .level-2 > li','color','$footer-menu-color-1','3','','.footer-menu'),(923766,'printshop','.footer-menu li > a, .footer-menu .no-link','color','$footer-menu-color-1','','','.footer-menu'),(923767,'printshop','.footer-menu .level-1 > li','color','$footer-menu-color-1','5342,3','','.footer-menu'),(923768,'printshop','.w-bestsellers .counter','color','$best-sellers-color-1','','','.w-bestsellers'),(923769,'printshop','.w-bestsellers .heading-3','color','$best-sellers-color-1','3','','.w-bestsellers'),(923770,'printshop','.w-bestsellers .item','color','$best-sellers-color-1','3','','.w-bestsellers'),(923771,'printshop','.w-bestsellers .item:first-child .counter','color','$best-sellers-color-2','','','.w-bestsellers'),(923772,'printshop','.testimonials .review','color','$content-color-2','','',''),(923773,'printshop','.w-catalog-paging ','color','$highlight-box-color-2','2','','.w-catalog-paging'),(923775,'printshop','.w-sale .badge','color','$highlight-box-color-1','','','.w-sale'),(923776,'printshop','.w-sale .ends','color','$hileght-color-3','','','.w-sale'),(923777,'printshop','.w-sale .left-count-days-text','color','$highlight-box-color-1','','','.w-sale'),(923778,'printshop','.w-sale .left-count-hours-text','color','$highlight-box-color-1','','','.w-sale'),(923779,'printshop','.w-sale .special-price','color','$hileght-color-3','','','.w-sale'),(923780,'printshop','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','color','$highlight-box-color-4','','','.b-cookie-notice'),(923781,'printshop','.w-product-properties-filters-widgets-chosen-filters .item','color','$highlight-box-color-4','','','.w-product-properties-filters-widgets-chosen-filters'),(923782,'printshop','.w-product-sale-ends .left-count','color','$highlight-box-color-4','','','.w-product-sale-ends'),(923783,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.p-quick-order-index'),(923784,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.p-quick-order-index'),(923785,'printshop','a.btn-2','color_important','important','','',''),(923786,'printshop','a.btn-3','color_important','important','','',''),(923787,'printshop','a.btn','color_important','important','','',''),(923788,'printshop','.b-select-suggest .select2-default','color_important','important','','','.b-select-suggest'),(923789,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.b-data-table'),(923790,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.b-data-table'),(923791,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','color_important','important','','','.w-rma-returns-history'),(923792,'printshop','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','content','\\f003','3','','.w-checkout-contact-information'),(923793,'printshop','.heading-4 .edit, h4 .edit','content','\\e917','4','',''),(923794,'printshop','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(923795,'printshop','.message.success','content','\\e918','3','',''),(923797,'printshop','.p-quick-order-index .paginate_button.next','content','\\f105','3','','.p-quick-order-index'),(923798,'printshop','.p-quick-order-index .paginate_button.previous','content','\\f104','3','','.p-quick-order-index'),(923799,'printshop','.w-promotions .prom-multi-discount .promo-range .promo-prod-qty','content',',','4','','.w-promotions'),(923800,'printshop','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','content','\\_','3','','.w-promotions'),(923801,'printshop','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(923802,'printshop','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(923803,'printshop','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(923806,'printshop','.p-sample-checkout-success .page-success','content','\\_','0,3','','.p-sample-checkout-success'),(923807,'printshop','.p-sample-checkout-success .page-success .text-1','content','\\e916','3','','.p-sample-checkout-success'),(923808,'printshop','.w-promotions .prom-multi-discount','content','\\_','4','','.w-promotions'),(923809,'printshop','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(923810,'printshop','.testimonials .review','content','\\_','3','',''),(923811,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(923812,'printshop','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(923813,'printshop','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(923814,'printshop','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(923815,'printshop','.w-promotions .prom-multi-discount > .heading','content','\\_','3','','.w-promotions'),(923816,'printshop','.w-promotions .nextdiscount .heading','content','\\f07a','3','','.w-promotions'),(923817,'printshop','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','content','\\_','3','','.w-promotions'),(923818,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','content','\\f041','3','','.b-warehouses-popup'),(923819,'printshop','.b-warehouses-popup .warehouses-popup-link','content','\\f041','3','','.b-warehouses-popup'),(923820,'printshop','.b-preloader .preloader','content','\\f110','3','','.b-preloader'),(923821,'printshop','.w-product-available-in-warehouses .content','content','\\_','4','','.w-product-available-in-warehouses'),(923822,'printshop','.b-products-listing .products-listing .mix-attributes','content','\\_','4','','.b-products-listing'),(923824,'printshop','.order-summary .price-row.ot_gv .title','content','\\e99f','3','','.order-summary'),(923825,'printshop','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(923826,'printshop','.b-messages .messBtnMenuUnread','content','\\f097','3','','.b-messages'),(923827,'printshop','.b-messages .messBtnMenuDelete','content','\\e913','3','','.b-messages'),(923828,'printshop','.b-messages span.starred::before','content','\\e90e','','','.b-messages'),(923829,'printshop','.b-messages .dataTables_wrapper > .top','content','\\_','4','','.b-messages'),(923830,'printshop','.b-messages .messBtnMenuStarred','content','\\e90e','3','','.b-messages'),(923831,'printshop','.b-messages .icon-circle-with-cross::before','content','×','','','.b-messages'),(923833,'printshop','.b-messages .dataTables_wrapper > .bottom','content','\\_','4','','.b-messages'),(923835,'printshop','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(923836,'printshop','.b-info .info','content','\\e918','3','','.b-info'),(923837,'printshop','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(923838,'printshop','.p-payer-order-confirmation .ship-ico','content','\\e66d','3','','.p-payer-order-confirmation'),(923839,'printshop','.p-payer-order-confirmation .pay-ico','content','\\e6cd','3','','.p-payer-order-confirmation'),(923840,'printshop','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(923841,'printshop','.p-payer-order-confirmation .discount-ico','content','\\e95e','3','','.p-payer-order-confirmation'),(923842,'printshop','.p-payer-order-confirmation .comment-ico','content','\\e644','3','','.p-payer-order-confirmation'),(923843,'printshop','.p-payer-order-pay .ship-ico','content','\\e66d','3','','.p-payer-order-pay'),(923844,'printshop','.p-payer-order-pay .pay-ico','content','\\e6cd','3','','.p-payer-order-pay'),(923845,'printshop','.p-payer-order-pay .discount-ico','content','\\e95e','3','','.p-payer-order-pay'),(923846,'printshop','.p-payer-order-pay .comment-ico','content','\\e644','3','','.p-payer-order-pay'),(923847,'printshop','.b-fancybox .fancybox-close','content','\\f00d','3','','.b-fancybox'),(923848,'printshop','.b-messages .select2-search-choice-close','content','\\e913','3','','.b-messages'),(923849,'printshop','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','content','\\f095','3','','.w-checkout-contact-information'),(923850,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','content','ttr(data-content','4','','.b-switch'),(923851,'printshop','.b-rating .glyphicon-chevron-left','content','\\f104','3','','.b-rating'),(923852,'printshop','.w-product-reviews .reviews-list .review','content','\\_','3','','.w-product-reviews'),(923853,'printshop','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(923854,'printshop','.bell-ico .heading-2','content','\\e9a7','3','','.bell-ico'),(923855,'printshop','.b-rating .glyphicon-chevron-right','content','\\f105','3','','.b-rating'),(923856,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-remove','content','\\f1f8','3','','.w-upload-customer-id-upload-customer-id-form'),(923857,'printshop','.b-info .info','content','\\e918','3','','.b-info'),(923858,'printshop','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(923859,'printshop','.w-coupons-and-vauchers-checkout .btn-remove','content','\\e913','3','','.w-coupons-and-vauchers-checkout'),(923860,'printshop','.w-login-block .cols','content','\\_','4','','.w-login-block'),(923861,'printshop','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(923863,'printshop','.order-summary .price-row.ot_bonus_points .title','content','\\e9a9','3','','.order-summary'),(923864,'printshop','.b-info .info','content','\\e918','3','','.b-info'),(923865,'printshop','.b-bottom .closeable-heading','content','\\e622','3','','.b-bottom'),(923866,'printshop','.b-bottom .closeable-heading.closed','content','\\e61a','3','','.b-bottom'),(923867,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','content','\\f00c','3','','.b-form'),(923868,'printshop','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(923869,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','content',' ','3','','.b-switch'),(923870,'printshop','.w-social-links .stumbleupon','content','\\f1a4','3','','.w-social-links'),(923871,'printshop','.buttons','content','\\_','4','',''),(923872,'printshop','.out-stock-icon','content','\\f10c','3','',''),(923873,'printshop','.in-stock-icon','content','\\f00c','3','',''),(923874,'printshop','.transit-icon','content','\\f133','3','',''),(923877,'printshop','.w-cart-compare .atr-col','content','\\f070','3','','.w-cart-compare'),(923878,'printshop','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(923879,'printshop','.b-rating .glyphicon-chevron-up','content','\\f106','3','','.b-rating'),(923881,'printshop','.b-upload-file .upload-file-wrap .upload-remove','content','\\e913','3','','.b-upload-file'),(923883,'printshop','.b-bottom .footerTitle','content','\\f067','5333,4','','.b-bottom'),(923884,'printshop','.closeable-heading','content','\\f067','3','',''),(923885,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow b','content','\\25be','3','','.b-select-suggest'),(923887,'printshop','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(923888,'printshop','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(923889,'printshop','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(923890,'printshop','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(923891,'printshop','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(923893,'printshop','.w-top-categories .categories','content','\\_','4','','.w-top-categories'),(923894,'printshop','.w-checkout-billing-address .addresses','content','\\_','4','','.w-checkout-billing-address'),(923896,'printshop','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(923897,'printshop','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(923898,'printshop','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(923900,'printshop','.view-all .btn','content','\\f054','4','',''),(923901,'printshop','.view-all','content','\\_','3','',''),(923902,'printshop','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(923903,'printshop','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(923904,'printshop','.b-form .newsletter-row','content','\\_','4','','.b-form'),(923905,'printshop','.b-info .info','content','\\e918','3','','.b-info'),(923906,'printshop','.w-checkout-shipping-address .addresses','content','\\_','4','','.w-checkout-shipping-address'),(923907,'printshop','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(923908,'printshop','.w-quote .cart-box-link','content','\\e90d','3','','.w-quote'),(923909,'printshop','.w-multi-cart-actions .cart-actions .dropdown-toggle','content','\\f013','3','','.w-multi-cart-actions'),(923911,'printshop','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(923912,'printshop','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(923913,'printshop','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(923914,'printshop','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(923915,'printshop','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(923916,'printshop','.btn-edit','content','\\e917','3','',''),(923917,'printshop','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(923918,'printshop','.w-login-block .cols','content','\\_','4','','.w-login-block'),(923919,'printshop','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(923920,'printshop','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(923921,'printshop','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(923922,'printshop','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(923923,'printshop','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(923924,'printshop','.b-rating .glyphicon-time','content','\\f017','3','','.b-rating'),(923925,'printshop','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(923927,'printshop','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(923928,'printshop','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(923929,'printshop','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(923930,'printshop','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(923933,'printshop','.w-checkout-shipping-choice input:checked + span:before','content','\\_','','','.w-checkout-shipping-choice'),(923934,'printshop','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(923935,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(923936,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(923937,'printshop','.w-filters .input-checkbox:checked + .checkbox-span:before','content','\\e64d','','','.w-filters'),(923938,'printshop','.heading-3 .edit, h3 .edit','content','\\e917','4','',''),(923939,'printshop','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(923940,'printshop','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(923941,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','content','ttr(data-content','4','','.b-switch'),(923942,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','content',' ','3','','.b-switch'),(923943,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','content','ttr(data-content','4','','.b-switch'),(923944,'printshop','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(923945,'printshop','.w-cart-bonus-points .btn-remove','content','\\e913','3','','.w-cart-bonus-points'),(923946,'printshop','.savings-ico .heading-2','content','\\e95e','3','','.savings-ico'),(923947,'printshop','.w-cart-compare .product-actions .dropdown-toggle','content','\\f013','3','','.w-cart-compare'),(923949,'printshop','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(923951,'printshop','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(923952,'printshop','.w-reviews .review','content','\\_','3','','.w-reviews'),(923953,'printshop','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(923954,'printshop','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(923955,'printshop','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(923956,'printshop','.js-stock-icon','content','\\f00c','3','',''),(923957,'printshop','.testimonials .heading-3','content','\\e908','3','',''),(923958,'printshop','.b-switch .candlestick-wrapper .fa-check','content','\\f00c','3','','.b-switch'),(923959,'printshop','.b-switch .candlestick-wrapper .fa-times','content','\\f00d','3','','.b-switch'),(923960,'printshop','.b-fancybox .fancybox-prev span','content','\\e900','3','','.b-fancybox'),(923961,'printshop','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(923962,'printshop','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(923963,'printshop','.w-list-b2b .attributes','content','\\_','4','','.w-list-b2b'),(923964,'printshop','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(923965,'printshop','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(923966,'printshop','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(923967,'printshop','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(923968,'printshop','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(923969,'printshop','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(923970,'printshop','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(923971,'printshop','.b-info .info','content','\\e918','3','','.b-info'),(923972,'printshop','.w-reviews .heading-3','content','\\e908','3','','.w-reviews'),(923973,'printshop','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(923974,'printshop','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(923975,'printshop','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(923976,'printshop','.w-social-links .instagram','content','\\f16d','3','','.w-social-links'),(923977,'printshop','.w-social-links .linkedin','content','\\f0e1','3','','.w-social-links'),(923978,'printshop','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(923979,'printshop','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(923980,'printshop','.w-login-block .cols','content','\\_','4','','.w-login-block'),(923981,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span:before','content','\\f1db','','','.b-form'),(923982,'printshop','.b-info .info','content','\\e918','3','','.b-info'),(923983,'printshop','.w-cart-compare .product','content','\\_','4','','.w-cart-compare'),(923984,'printshop','.btn-del','content','\\f1f8','4','',''),(923985,'printshop','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(923986,'printshop','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(923988,'printshop','.w-checkout-bonus-points .btn-remove','content','\\e913','3','','.w-checkout-bonus-points'),(923989,'printshop','.b-rating .glyphicon-star.coloron','content','\\f005','3','','.b-rating'),(923990,'printshop','.w-cart-compare .delete-cart','content','\\2573','3','','.w-cart-compare'),(923991,'printshop','.w-cart-shipping-estimator .shipping-estimator','content','\\_','4','','.w-cart-shipping-estimator'),(923992,'printshop','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(923993,'printshop','.b-form .checkbox-style:checked + .checkbox-span:before','content','\\f058','','','.b-form'),(923994,'printshop','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(923995,'printshop','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(923996,'printshop','.w-cart-credit-amount .btn-remove','content','\\e913','3','','.w-cart-credit-amount'),(923998,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(923999,'printshop','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(924000,'printshop','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(924002,'printshop','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(924003,'printshop','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(924004,'printshop','.b-info-popup .info-popup','content','\\e918','3','','.b-info-popup'),(924005,'printshop','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(924006,'printshop','.b-upload-file .snapshot','content','\\f030','3','','.b-upload-file'),(924007,'printshop','.b-form .columns','content','\\_','4','','.b-form'),(924008,'printshop','.b-bottom .footerTitle','content','\\f068','5333,2,4','','.b-bottom'),(924009,'printshop','.b-bottom .pop-up-close','content','\\f00d','3','','.b-bottom'),(924010,'printshop','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','content','\\f004','','','.b-products-listing'),(924011,'printshop','.w-cart-shipping-estimator .address-item .lastname','content','\\_','4','','.w-cart-shipping-estimator'),(924012,'printshop','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','content','\\f08a','','','.b-products-listing'),(924013,'printshop','.b-upload-files .remove-file','content','\\f014','3','','.b-upload-files'),(924014,'printshop','.w-reviews-content .review','content','\\_','3','','.w-reviews-content'),(924015,'printshop','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(924016,'printshop','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(924017,'printshop','.w-social-links .facebook','content','\\f09a','3','','.w-social-links'),(924018,'printshop','.b-fancybox .fancybox-next span','content','\\e901','3','','.b-fancybox'),(924019,'printshop','.w-product-customers-activity .close','content','\\2715','3','','.w-product-customers-activity'),(924020,'printshop','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(924021,'printshop','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(924022,'printshop','.w-categories .categories','content','\\_','4','','.w-categories'),(924023,'printshop','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(924024,'printshop','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(924025,'printshop','.w-login-block .cols','content','\\_','4','','.w-login-block'),(924026,'printshop','.w-contact-contacts .contacts-icons .phone','content','\\e907','3','','.w-contact-contacts'),(924027,'printshop','.w-contact-contacts .contacts-icons .email','content','\\e923','3','','.w-contact-contacts'),(924028,'printshop','.w-cart-shipping-estimator .item .row: after','content','\\_','','','.w-cart-shipping-estimator'),(924031,'printshop','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(924032,'printshop','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(924033,'printshop','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(924036,'printshop','.w-social-links .pinterest','content','\\f0d2','3','','.w-social-links'),(924037,'printshop','.w-social-links .google-plus','content','\\f2b3','3','','.w-social-links'),(924038,'printshop','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(924039,'printshop','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(924040,'printshop','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(924041,'printshop','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(924044,'printshop','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(924045,'printshop','.b-rating .glyphicon-chevron-down','content','\\f107','3','','.b-rating'),(924046,'printshop','.w-social-links .twitter','content','\\f099','3','','.w-social-links'),(924047,'printshop','.w-checkout-create-account .account-benefits strong','content','\\e918','3','','.w-checkout-create-account'),(924048,'printshop','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(924049,'printshop','.w-contact-contacts .contacts-icons .hours','content','\\e98d','3','','.w-contact-contacts'),(924051,'printshop','.b-products-listing .products-listing .bonus-points-cost','content','\\f219','3','','.b-products-listing'),(924052,'printshop','.b-products-listing .products-listing .bonus-points-price','content','\\f219','3','','.b-products-listing'),(924053,'printshop','.b-products-listing .BlockBox','content','\\_','4','','.b-products-listing'),(924054,'printshop','.b-products-listing .btn-preloader','content','\\f110','3','','.b-products-listing'),(924055,'printshop','.b-products-listing .hover-box-content','content','\\_','3','','.b-products-listing'),(924056,'printshop','.b-products-listing .loader','content','\\f110','4','','.b-products-listing'),(924057,'printshop','.b-products-listing .products-listing','content','\\_','4','','.b-products-listing'),(924058,'printshop','.b-products-listing .loader','content','\\_','3','','.b-products-listing'),(924059,'printshop','.b-products-listing .products-listing .qty-input.hidden','content','\\_','3','','.b-products-listing'),(924060,'printshop','.checkbox input:not(checked) + span:before','content','\\_','','',''),(924063,'printshop','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(924064,'printshop','.b-rating .glyphicon-star','content','\\f006','3','','.b-rating'),(924065,'printshop','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(924066,'printshop','.b-form .hide-box','content','\\_','3','','.b-form'),(924067,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','content','\\_','3','','.b-switch'),(924068,'printshop','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','content','\\f10b','3','','.w-checkout-contact-information'),(924069,'printshop','.b-info-popup .info-popup div','content','\\_','3','','.b-info-popup'),(924070,'printshop','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(924071,'printshop','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(924072,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(924073,'printshop','.order-summary .price-row.ot_coupon .title','content','%','3','','.order-summary'),(924074,'printshop','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(924075,'printshop','.b-form .eye-password.eye-password-showed','content','\\f070','3','','.b-form'),(924076,'printshop','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(924077,'printshop','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(924078,'printshop','.w-login-block .cols','content','\\_','4','','.w-login-block'),(924080,'printshop','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','content','\\e913','3','','.order-summary'),(924081,'printshop','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(924082,'printshop','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(924083,'printshop','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(924084,'printshop','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(924085,'printshop','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(924086,'printshop','.w-product-cross-sell .buy-all-checker','content','\\f14a','3','','.w-product-cross-sell'),(924087,'printshop','.w-catalog-listing-look .b2b','content','\\f0c9','3','','.w-catalog-listing-look'),(924088,'printshop','.w-catalog-listing-look .grid','content','\\f009','3','','.w-catalog-listing-look'),(924089,'printshop','.checkbox input:checked + span:before','content','\\f00c','','',''),(924090,'printshop','.w-cart-listing .multi-product-copy','content','\\e922','3','','.w-cart-listing'),(924091,'printshop','.w-cart-listing .multi-product-delete','content','\\e913','3','','.w-cart-listing'),(924092,'printshop','.w-cart-listing .multi-product-move','content','\\e975','3','','.w-cart-listing'),(924093,'printshop','.w-cart-listing .points-redeem','content','\\f219','3','','.w-cart-listing'),(924094,'printshop','.w-cart-listing .item .gift-wrap .value','content',')','4','','.w-cart-listing'),(924095,'printshop','.w-cart-listing .item .gift-wrap .value','content','(','3','','.w-cart-listing'),(924096,'printshop','.w-cart-listing .remove-btn','content','\\e605','3','','.w-cart-listing'),(924097,'printshop','.w-cart-give-away .ga_name','content','\\_','4','','.w-cart-give-away'),(924101,'printshop','.w-cart-discount-coupon .btn-remove','content','\\e913','3','','.w-cart-discount-coupon'),(924102,'printshop','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(924103,'printshop','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(924104,'printshop','.b-compare .clear_all','content','\\f00d','4','','.b-compare'),(924105,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','content','\\_','3','','.w-contact-contacts'),(924106,'printshop','.w-filters .open','content','\\e622','3','','.w-filters'),(924108,'printshop','.w-checkout-credit-amount .btn-remove','content','\\e913','3','','.w-checkout-credit-amount'),(924109,'printshop','.w-filters .fsl_handle','content','\\_','4','','.w-filters'),(924110,'printshop','.w-filters .view_more','content','\\f061','4','','.w-filters'),(924111,'printshop','.w-filters span.close','content','\\e61a','3','','.w-filters'),(924112,'printshop','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(924113,'printshop','.w-catalog-listing-look .list','content','\\f00b','3','','.w-catalog-listing-look'),(924114,'printshop','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(924115,'printshop','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(924116,'printshop','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(924117,'printshop','.w-login-block .cols','content','\\_','4','','.w-login-block'),(924118,'printshop','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(924122,'printshop','.b-rating .glyphicon-calendar','content','\\f073','3','','.b-rating'),(924123,'printshop','.w-filters .mobileCollapse','content','\\f056','2,4','','.w-filters'),(924124,'printshop','.w-filters .mobileCollapse','content','\\f055','4','','.w-filters'),(924125,'printshop','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','content','\\e6e8','','','.w-filters'),(924126,'printshop','.b-product-images .media-popup .mp-close','content','\\f00d','3','','.b-product-images'),(924127,'printshop','.b-product-images .media-popup .slick-dots li','content','\\2022','3','','.b-product-images'),(924128,'printshop','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','content','\\e68e','3','','.b-menu-burger_icon'),(924129,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(924130,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(924131,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(924132,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(924133,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(924134,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(924135,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(924136,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(924137,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(924138,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(924139,'printshop','.b-trade-approval .columns','content','\\_','4','','.b-trade-approval'),(924140,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','content','\\e90d','3','','.w-catalog-compare'),(924141,'printshop','.w-catalog-compare td span + span','content','| ','3','','.w-catalog-compare'),(924142,'printshop','.w-catalog-compare .checkbox input:checked + span:before','content','\\f014','','','.w-catalog-compare'),(924144,'printshop','.tripleBanner .w-html_box','content','\\_','3','','.tripleBanner'),(924145,'printshop','.b-slick .slick-track, .b-slick .slick-track:after','content','\\_','3','','.b-slick'),(924146,'printshop','.b-slick .slick-vertical button.slick-next','content','\\f078','3','','.b-slick'),(924147,'printshop','.b-slick .slick-vertical button.slick-prev','content','\\f077','3','','.b-slick'),(924148,'printshop','.b-slick button.slick-next','content','\\f054','3','','.b-slick'),(924149,'printshop','.b-slick button.slick-prev','content','\\f053','3','','.b-slick'),(924150,'printshop','.w-breadcrumb .breadcrumb-li + .breadcrumb-li','content','/','3','','.w-breadcrumb'),(924151,'printshop','.w-quote .multicart .count','content','(','3','','.w-quote'),(924152,'printshop','.w-quote .multicart .count','content',')','4','','.w-quote'),(924153,'printshop','.w-quote .multicart .item.current-multi-cart .switch-cart','content','\\f058','3','','.w-quote'),(924154,'printshop','.w-quote .multicart .switch-cart','content','\\f111','3','','.w-quote'),(924155,'printshop','.w-quote .qty','content','\\274c','4','','.w-quote'),(924156,'printshop','.w-quote a.item','content','\\_','4','','.w-quote'),(924157,'printshop','.b-quantity .qty-box .bigger','content','\\e61a','3','','.b-quantity'),(924158,'printshop','.b-quantity .qty-box .smaller','content','\\e622','3','','.b-quantity'),(924159,'printshop','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(924160,'printshop','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(924161,'printshop','.w-product-bonus-points > div','content','\\_','4','','.w-product-bonus-points'),(924162,'printshop','.w-product-bonus-points > div > div','content','\\f219','3','','.w-product-bonus-points'),(924163,'printshop','.warrantyProduct .warranty','content','\\_','3','','.warrantyProduct'),(924164,'printshop','.warrantyProduct .delivery','content','\\_','3','','.warrantyProduct'),(924165,'printshop','.w-compare .remove','content','\\f014','3','','.w-compare'),(924166,'printshop','.w-files-catalog-widgets-files-list .file','content','\\f1c1','3','','.w-files-catalog-widgets-files-list'),(924167,'printshop','.w-sample .cart-box-link','content','\\_','4','','.w-sample'),(924168,'printshop','.w-sample .cart-box-link','content','\\e90d','3','','.w-sample'),(924169,'printshop','.w-sample .multicart .count','content','(','3','','.w-sample'),(924170,'printshop','.w-sample .multicart .count','content',')','4','','.w-sample'),(924171,'printshop','.w-sample .multicart .item.current-multi-cart .switch-cart','content','\\f058','3','','.w-sample'),(924172,'printshop','.w-sample .multicart .switch-cart','content','\\f111','3','','.w-sample'),(924173,'printshop','.w-sample .qty','content','\\f00d ','4','','.w-sample'),(924174,'printshop','.w-sample a.item','content','\\_','4','','.w-sample'),(924175,'printshop','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(924176,'printshop','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(924178,'printshop','.b-products-listing .products-listing .radio-attributes','content','\\_','4','','.b-products-listing'),(924179,'printshop','.b-pagination .pagination','content','\\_','4','','.b-pagination'),(924180,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','content','\\f105','3','','.b-pagination'),(924181,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','content','\\f104','3','','.b-pagination'),(924182,'printshop','.w-product-multi-inventory .select-box:last-of-type:after','content','\\_','','','.w-product-multi-inventory'),(924183,'printshop','.w-product-properties-filters-widgets-chosen-filters .remove','content','\\2716','3','','.w-product-properties-filters-widgets-chosen-filters'),(924184,'printshop','.w-product-multi-inventory #product-attributes','content','\\_','4','','.w-product-multi-inventory'),(924185,'printshop','.p-sample-checkout-index .order-summary .heading-2','content','\\_','3','','.p-sample-checkout-index'),(924186,'printshop','.p-sample-checkout-index .order-summary .heading-2','content','\\_','4','','.p-sample-checkout-index'),(924187,'printshop','.w-product-multi-inventory .radio-attributes','content','\\_','4','','.w-product-multi-inventory'),(924188,'printshop','.w-account-personal-catalog .list-row-action ul','content','\\f107','4','','.w-account-personal-catalog'),(924189,'printshop','.w-product-quantity-discounts .quantity-discounts','content','\\_','4','','.w-product-quantity-discounts'),(924190,'printshop','.w-product-attributes #product-attributes','content','\\_','4','','.w-product-attributes'),(924191,'printshop','.w-product-attributes .radio-attributes','content','\\_','4','','.w-product-attributes'),(924192,'printshop','.w-product-attributes .select-box:last-of-type:after','content','\\_','','','.w-product-attributes'),(924193,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','content','\\2714','3','','.w-questionnaire-widgets-questionnaire'),(924194,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','content','\\2718','3','','.w-questionnaire-widgets-questionnaire'),(924195,'printshop','.w-product-groups .prop-group-swatch','content','\\_','4','','.w-product-groups'),(924196,'printshop','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','content','\\e90d','3','','.w-product-custom-bundle'),(924197,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list'),(924198,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list-block'),(924199,'printshop','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(924200,'printshop','.w-delivery-location-featured-list .deliveryList ul','content','\\_','4','','.w-delivery-location-featured-list'),(924201,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list-by-catalog'),(924202,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(924203,'printshop','.w-delivery-location-list-by-page .page-list','content','\\_','4','','.w-delivery-location-list-by-page'),(924204,'printshop','.w-delivery-location-top-location-list .deliveryList','content','\\_','4','','.w-delivery-location-top-location-list'),(924205,'printshop','.w-delivery-location-cross-pages .page-list','content','\\_','4','','.w-delivery-location-cross-pages'),(924206,'printshop','.delivery-options-popup','content','\\_','4','',''),(924207,'printshop','.w-support-system-filter .dd3-content .collapse_span','content','\\f056','3','','.w-support-system-filter'),(924208,'printshop','.w-support-system-filter .dd3-content .collapse_span.clouse','content','\\f055','3','','.w-support-system-filter'),(924209,'printshop','.w-communication-post .btn.refresh','content','\\21bb','3','','.w-communication-post'),(924210,'printshop','.w-rma-returns-history .icons .excel','content','\\f1c3','3','','.w-rma-returns-history'),(924211,'printshop','.w-rma-returns-history .icons .print','content','\\f02f','3','','.w-rma-returns-history'),(924212,'printshop','.w-rma-returns-history .linkButton','content','\\f105','4','','.w-rma-returns-history'),(924213,'printshop','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(924214,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-list'),(924215,'printshop','.w-predefined-promotion .nextdiscount .heading','content','\\f07a','3','','.w-predefined-promotion'),(924216,'printshop','.w-predefined-promotion .prom-multi-discount','content','\\_','4','','.w-predefined-promotion'),(924217,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range .promo-prod-qty','content',',','4','','.w-predefined-promotion'),(924218,'printshop','.w-predefined-promotion .prom-multi-discount > .heading','content','\\_','3','','.w-predefined-promotion'),(924219,'printshop','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','content','\\_','3','','.w-predefined-promotion'),(924220,'printshop','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','content','\\_','3','','.w-predefined-promotion'),(924221,'printshop','.w-supplier-purchase-supplier-products .active .select_item > div:before','content','\\f00c','','','.w-supplier-purchase-supplier-products'),(924225,'printshop','.heading-1','content','\\_','4','',''),(924226,'printshop','h1','content','\\_','4','',''),(924227,'printshop','.tripleLine .text-banner-2 > div a','content','\\e628','4','','.tripleLine'),(924228,'printshop','.cartTitle >div','content','\\_','4','','.cartTitle'),(924229,'printshop','.p-wedding-registry-view h1','content','\\f004','3','','.p-wedding-registry-view'),(924230,'printshop','.p-wedding-registry-view h1','content','\\f004','4','','.p-wedding-registry-view'),(924231,'printshop','.middleBanner .btn-1','content','\\e628','4','','.middleBanner'),(924232,'printshop','.bottomBanner .btn-1','content','\\e628','4','','.bottomBanner'),(924233,'printshop','.bottomBanner .icon-box > div','content','\\_','3','','.bottomBanner'),(924235,'printshop','.w-neighbour-checkout .neighbour-box','content','\\_','4','','.w-neighbour-checkout'),(924236,'printshop','.topBanner .content .btn','content','\\e628','4','','.topBanner'),(924237,'printshop','.topBanner .ourPick','content','\\_','3','','.topBanner'),(924238,'printshop','.topBanner .ourPick','content','\\_','4','','.topBanner'),(924239,'printshop','.topBanner .ourPick','content','\\_','5347,4','','.topBanner'),(924240,'printshop','.tripleLine .banner-text-holder > div a','content','\\e628','4','','.tripleLine'),(924241,'printshop','.order-summary .icon','content','\\f068','','','.order-summary'),(924242,'printshop','.order-summary .icon','content','\\e61a','3','','.order-summary'),(924243,'printshop','.order-summary .icon.opened','content','\\e622','3','','.order-summary'),(924244,'printshop','.w-cart-discount-coupon .title','content','\\e64b','4','','.w-cart-discount-coupon'),(924245,'printshop','.w-cart-discount-coupon .title.opened','content','\\e648','4','','.w-cart-discount-coupon'),(924246,'printshop','.w-cart-shipping-estimator .left-area','content','\\_','5363,4','','.w-cart-shipping-estimator'),(924247,'printshop','.w-cart-checkout-btn .with-card','content','\\f283','4','','.w-cart-checkout-btn'),(924248,'printshop','.p-quote-checkout-index .comment-ico','content','\\e644','3','','.p-quote-checkout-index'),(924249,'printshop','.p-quote-checkout-index .pay-ico','content','\\e6cd','3','','.p-quote-checkout-index'),(924250,'printshop','.p-quote-checkout-index .ship-ico','content','\\e66d','3','','.p-quote-checkout-index'),(924270,'printshop','.account-order-pay .historyInfoColumn h2.title-delivery-address, .account-order-pay .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-order-pay'),(924271,'printshop','.account-order-pay .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-order-pay'),(924272,'printshop','.account-order-pay .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-order-pay'),(924273,'printshop','.account-samples .view_link','content','\\e901','4','','.account-samples'),(924274,'printshop','.account-sample-info .historyInfoColumn h2.title-delivery-address, .account-sample-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-sample-info'),(924275,'printshop','.account-sample-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-sample-info'),(924276,'printshop','.account-sample-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-sample-info'),(924277,'printshop','.catalog-product-wrap .next-product .pn-image','content','\\f054','3','','.catalog-product-wrap'),(924278,'printshop','.catalog-product-wrap .prev-product .pn-image','content','\\f053','3','','.catalog-product-wrap'),(924279,'printshop','.shopping-cart-index .gift-code .heading-4','content','\\f068','2,4','','.shopping-cart-index'),(924280,'printshop','.shopping-cart-index .gift-code .heading-4','content','\\f067','4','','.shopping-cart-index'),(924281,'printshop','.checkout-index-wrap .comment-ico','content','\\e644','3','','.checkout-index-wrap'),(924282,'printshop','.checkout-index-wrap .pay-ico','content','\\e6cd','3','','.checkout-index-wrap'),(924283,'printshop','.checkout-index-wrap .ship-ico','content','\\e66d','3','','.checkout-index-wrap'),(924284,'printshop','.checkout-order-confirmation .comment-ico','content','\\e644','3','','.checkout-order-confirmation'),(924285,'printshop','.checkout-order-confirmation .discount-ico','content','\\e95e','3','','.checkout-order-confirmation'),(924286,'printshop','.checkout-order-confirmation .pay-ico','content','\\e6cd','3','','.checkout-order-confirmation'),(924287,'printshop','.checkout-order-confirmation .ship-ico','content','\\e66d','3','','.checkout-order-confirmation'),(924288,'printshop','.checkout-success-wrap .page-success','content','\\_','3','','.checkout-success-wrap'),(924289,'printshop','.checkout-success-wrap .page-success .text-1','content','\\e64d','3','','.checkout-success-wrap'),(924290,'printshop','.index-wrap .heading-2','content','\\_','4','','.index-wrap'),(924291,'printshop','.index-wrap h2','content','\\_','4','','.index-wrap'),(924292,'printshop','.b-form .addresses','content','\\_','4','','.b-form'),(924293,'printshop','.b-form .eye-password','content','\\f06e','3','','.b-form'),(924294,'printshop','.b-slick .slick-dots li','content','\\_','3','','.b-slick'),(924296,'printshop','.success-page .check-ico-block','content','\\e916','3','','.success-page'),(924297,'printshop','.success-page .comment-ico','content','\\e99d','3','','.success-page'),(924298,'printshop','.success-page .discount-ico','content','\\e95e','3','','.success-page'),(924299,'printshop','.success-page .order-ico','content','\\e922','3','','.success-page'),(924300,'printshop','.success-page .page-success','content','\\_','3','','.success-page'),(924301,'printshop','.success-page .page-success .text-1','content','\\e916','3','','.success-page'),(924302,'printshop','.success-page .pay-ico','content','\\e99e','3','','.success-page'),(924303,'printshop','.success-page .prod-ico','content','\\e99b','3','','.success-page'),(924304,'printshop','.success-page .ship-ico','content','\\e94e','3','','.success-page'),(924305,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-content','content','\\_','4','','.b-multi-page-checkout'),(924306,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','content','\\f00c','3','','.b-multi-page-checkout'),(924307,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','content','\\e917','4','','.b-multi-page-checkout'),(924311,'printshop','.footer-menu .level-2 > li','content','\\2022','3','','.footer-menu'),(924312,'printshop','.footer-menu .level-2 > li.component-item','content','\\_','3','','.footer-menu'),(924313,'printshop','.footer-menu .level-1 > li','content','\\e61a','5342,3','','.footer-menu'),(924314,'printshop','.footer-menu .level-1 > li.vis-show','content','\\e622','5342,3','','.footer-menu'),(924315,'printshop','.w-bestsellers .heading-3','content','\\e903','3','','.w-bestsellers'),(924316,'printshop','.w-bestsellers .item','content','\\e90b','3','','.w-bestsellers'),(924317,'printshop','.w-bestsellers .item:first-child:before','content','\\e90c','','','.w-bestsellers'),(924318,'printshop','.w-catalog-paging .next','content','\\f105','3','','.w-catalog-paging'),(924319,'printshop','.w-catalog-paging .prev','content','\\f104','3','','.w-catalog-paging'),(924323,'printshop','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(924324,'printshop','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(924325,'printshop','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(924326,'printshop','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(924327,'printshop','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(924328,'printshop','.b-rating .glyphicon-chevron-left','content_important','important','3','','.b-rating'),(924329,'printshop','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(924330,'printshop','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(924331,'printshop','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(924332,'printshop','.b-rating .glyphicon-chevron-right','content_important','important','3','','.b-rating'),(924333,'printshop','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(924334,'printshop','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(924335,'printshop','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(924336,'printshop','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(924337,'printshop','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(924338,'printshop','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(924339,'printshop','.b-rating .glyphicon-chevron-up','content_important','important','3','','.b-rating'),(924340,'printshop','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(924341,'printshop','.w-contact-contacts .contacts-icons .phone','content_important','important','3','','.w-contact-contacts'),(924342,'printshop','.w-contact-contacts .contacts-icons .hours','content_important','important','3','','.w-contact-contacts'),(924343,'printshop','.b-rating .glyphicon-chevron-down','content_important','important','3','','.b-rating'),(924344,'printshop','.b-rating .glyphicon-calendar','content_important','important','3','','.b-rating'),(924345,'printshop','.b-rating .glyphicon-time','content_important','important','3','','.b-rating'),(924346,'printshop','.w-contact-contacts .contacts-icons .email','content_important','important','3','','.w-contact-contacts'),(924347,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor','default','','','.b-switch'),(924348,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','cursor','pointer','','','.b-switch'),(924349,'printshop','.p-quick-order-index .filters .clear','cursor','pointer','','','.p-quick-order-index'),(924350,'printshop','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','cursor','pointer','3','','.order-summary'),(924351,'printshop','.b-messages .messMenuButton span','cursor','pointer','','','.b-messages'),(924352,'printshop','.b-fancybox #fancybox-loading','cursor','pointer','','','.b-fancybox'),(924353,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file','cursor','pointer','','','.w-upload-customer-id-upload-customer-id-form'),(924354,'printshop','.b-switch .bootstrap-switch','cursor','pointer','','','.b-switch'),(924355,'printshop','.w-coupons-and-vauchers-checkout .btn-remove','cursor','pointer','','','.w-coupons-and-vauchers-checkout'),(924356,'printshop','.b-autocomplete .ui-autocomplete li','cursor','pointer','','','.b-autocomplete'),(924358,'printshop','.w-filters .open, .w-filters .close','cursor','pointer','','','.w-filters'),(924359,'printshop','.w-checkout-shipping-choice span','cursor','pointer','','','.w-checkout-shipping-choice'),(924360,'printshop','.w-cart-compare .atr-col','cursor','pointer','','','.w-cart-compare'),(924361,'printshop','.w-tabs .tab-a','cursor','pointer','','','.w-tabs'),(924362,'printshop','.w-tabs .tab-a','cursor','default','2','','.w-tabs'),(924363,'printshop','.disabled-area','cursor','not-allowed','','',''),(924364,'printshop','.disabled-area *','cursor','not-allowed','','',''),(924366,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','cursor','pointer','3','','.b-form'),(924367,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','cursor','pointer','','','.b-switch'),(924368,'printshop','.w-cart-bonus-points .btn-remove','cursor','pointer','','','.w-cart-bonus-points'),(924369,'printshop','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','','','.b-select-suggest'),(924370,'printshop','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','1','','.b-select-suggest'),(924371,'printshop','.b-switch .candlestick-wrapper .candlestick-bg.grab:not(.candlestick-disabled ) .candlestick-toggle','cursor','grab','','','.b-switch'),(924372,'printshop','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled','cursor','not-allowed','','','.b-switch'),(924373,'printshop','.b-fancybox .fancybox-close','cursor','pointer','','','.b-fancybox'),(924374,'printshop','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','cursor','default','','','.b-select-suggest'),(924375,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor','default','','','.b-switch'),(924376,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor','default','','','.b-switch'),(924377,'printshop','.w-checkout-bonus-points .btn-remove','cursor','pointer','','','.w-checkout-bonus-points'),(924378,'printshop','.w-checkout-credit-amount .btn-remove','cursor','pointer','','','.w-checkout-credit-amount'),(924379,'printshop','.b-upload-file .snapshot','cursor','pointer','','','.b-upload-file'),(924380,'printshop','.b-form .item-radio label','cursor','pointer','','','.b-form'),(924381,'printshop','.b-bottom .footerTitle','cursor','pointer','5333','','.b-bottom'),(924382,'printshop','.b-products-listing .products-listing .wishlistButton .checkbox','cursor','pointer','','','.b-products-listing'),(924383,'printshop','.w-cart-credit-amount .btn-remove','cursor','pointer','','','.w-cart-credit-amount'),(924384,'printshop','.w-product-customers-activity .close','cursor','pointer','','','.w-product-customers-activity'),(924385,'printshop','.b-form .item-radio.active label','cursor','default','','','.b-form'),(924386,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor','default','','','.b-switch'),(924387,'printshop','.b-fancybox .fancybox-nav','cursor','pointer','','','.b-fancybox'),(924389,'printshop','.closeable-event','cursor','pointer','','',''),(924390,'printshop','.b-form .addresses.address-main .address-item label','cursor','default','','','.b-form'),(924391,'printshop','.w-checkout-shipping-choice input:checked + span','cursor','default','','','.w-checkout-shipping-choice'),(924392,'printshop','.w-tabs .accordion-heading','cursor','default','2','','.w-tabs'),(924393,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','cursor','default','','','.b-select-suggest'),(924394,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-chosen','cursor','default','','','.b-select-suggest'),(924395,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','cursor','default','','','.b-select-suggest'),(924396,'printshop','.b-select-suggest .select2-container-multi .select2-choices','cursor','text','','','.b-select-suggest'),(924397,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','cursor','default','','','.b-select-suggest'),(924398,'printshop','.b-select-suggest .select2-results .select2-disabled','cursor','default','','','.b-select-suggest'),(924399,'printshop','.b-select-suggest .select2-results .select2-result-label','cursor','pointer','','','.b-select-suggest'),(924402,'printshop','.b-form .eye-password','cursor','pointer','','','.b-form'),(924403,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','cursor','pointer','','','.w-communication-new-topic'),(924404,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','cursor','pointer','','','.w-communication-new-topic'),(924405,'printshop','.w-filters .ui-slider-handle','cursor','pointer','','','.w-filters'),(924406,'printshop','.w-cart-discount-coupon .btn-remove','cursor','pointer','','','.w-cart-discount-coupon'),(924407,'printshop','.b-fancybox .fancybox-nav span','cursor','pointer','','','.b-fancybox'),(924408,'printshop','.w-tabs .accordion-heading','cursor','pointer','','','.w-tabs'),(924409,'printshop','.w-filters .filter-box-content ul li.view_items','cursor','pointer','','','.w-filters'),(924410,'printshop','.b-bottom .pop-up-close','cursor','pointer','','','.b-bottom'),(924411,'printshop','.b-upload-files .remove-file','cursor','pointer','','','.b-upload-files'),(924413,'printshop','.w-menu-big .show-all','cursor','pointer','','','.w-menu-big'),(924414,'printshop','.b-form .addresses .address-item label','cursor','pointer','','','.b-form'),(924415,'printshop','.w-filters .mobileCollapse','cursor','pointer','4','','.w-filters'),(924416,'printshop','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','cursor','pointer','','','.b-product-images'),(924417,'printshop','.b-product-images .media-popup .mp-close','cursor','pointer','','','.b-product-images'),(924418,'printshop','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','cursor','pointer','','','.b-product-images'),(924419,'printshop','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','cursor','pointer','','','.b-menu-burger_icon'),(924420,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(924421,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(924422,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(924423,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(924424,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(924425,'printshop','.w-account-personal-catalog .list-switcher a','cursor','pointer','','','.w-account-personal-catalog'),(924426,'printshop','.w-account-personal-catalog .list-switcher a','cursor','default','2','','.w-account-personal-catalog'),(924427,'printshop','.w-catalog-compare .compare label','cursor','pointer','','','.w-catalog-compare'),(924428,'printshop','.w-catalog-compare .cross-box .different-all > div','cursor','pointer','','','.w-catalog-compare'),(924429,'printshop','.w-catalog-compare .cross-box .different-all > div','cursor','default','2','','.w-catalog-compare'),(924430,'printshop','.w-catalog-compare .cross-box .return','cursor','pointer','','','.w-catalog-compare'),(924431,'printshop','.b-slick button.slick-disabled','cursor','default','','','.b-slick'),(924432,'printshop','.w-subscribers .btn-submit','cursor','pointer','','','.w-subscribers'),(924433,'printshop','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(924434,'printshop','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(924435,'printshop','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(924436,'printshop','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(924437,'printshop','.w-compare .clear-compare-button','cursor','pointer','','','.w-compare'),(924438,'printshop','.w-compare .remove','cursor','pointer','','','.w-compare'),(924439,'printshop','.w-product-video .item img, .w-product-video .item video','cursor','pointer','','','.w-product-video'),(924440,'printshop','.w-product-properties-filters-widgets-chosen-filters .remove','cursor','pointer','','','.w-product-properties-filters-widgets-chosen-filters'),(924441,'printshop','.w-product-multi-inventory .radio-attributes input:checked + .option-item','cursor','default','','','.w-product-multi-inventory'),(924442,'printshop','.w-product-multi-inventory .radio-attributes .option-item','cursor','pointer','','','.w-product-multi-inventory'),(924443,'printshop','.b-products-listing .products-listing .radio-attributes .option','cursor','pointer','','','.b-products-listing'),(924444,'printshop','.b-products-listing .products-listing .radio-attributes input:checked + .option','cursor','default','','','.b-products-listing'),(924445,'printshop','.w-product-attributes .radio-attributes .option-item','cursor','pointer','','','.w-product-attributes'),(924446,'printshop','.w-product-attributes .radio-attributes input:checked + .option-item','cursor','default','','','.w-product-attributes'),(924447,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','cursor','pointer','','','.w-questionnaire-widgets-questionnaire'),(924448,'printshop','.w-product-designer-designer .prodDesignerType label','cursor','pointer','','','.w-product-designer-designer'),(924449,'printshop','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','cursor','pointer','','','.w-press-reviews-widgets-press-reviews-small'),(924450,'printshop','.w-support-system-filter .dd3-content .collapse_span','cursor','pointer','3','','.w-support-system-filter'),(924451,'printshop','.w-support-system-listing .pm-head-2','cursor','pointer','','','.w-support-system-listing'),(924452,'printshop','.order-summary .icon','cursor','pointer','','','.order-summary'),(924453,'printshop','.w-cart-discount-coupon .title','cursor','pointer','','','.w-cart-discount-coupon'),(924456,'printshop','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-order-pay'),(924457,'printshop','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-order-pay'),(924458,'printshop','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-sample-info'),(924459,'printshop','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-sample-info'),(924460,'printshop','.shopping-cart-index .gift-code .heading-4','cursor','pointer','5333','','.shopping-cart-index'),(924461,'printshop','.b-slick .slick-dots li','cursor','pointer','','','.b-slick'),(924463,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','cursor','pointer','','','.b-multi-page-checkout'),(924465,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor_important','important','','','.b-switch'),(924466,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor_important','important','','','.b-switch'),(924467,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor_important','important','','','.b-switch'),(924468,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor_important','important','','','.b-switch'),(924469,'printshop','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(924470,'printshop','.b-switch .bootstrap-switch','direction','ltr','','','.b-switch'),(924471,'printshop','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(924472,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(924473,'printshop','.b-info .info','display','inline-block','3','','.b-info'),(924474,'printshop','.message.success','display','inline-block','3','',''),(924475,'printshop','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(924478,'printshop','.w-filters .mobileCollapse','display','inline-block','5342','','.w-filters'),(924479,'printshop','.p-quick-order-index ul.token-input-list','display','inline-block','','','.p-quick-order-index'),(924480,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.p-quick-order-index'),(924481,'printshop','.w-promotions .promo-salemaker .content a.name','display','block','','','.w-promotions'),(924482,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.p-quick-order-index'),(924483,'printshop','.w-promotions .prom-multi-discount .promo-range > div','display','inline-block','','','.w-promotions'),(924484,'printshop','.w-promotions .promo-salemaker','display','flex','','','.w-promotions'),(924485,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','display','inline-block','','','.w-promotions'),(924486,'printshop','.w-promotions .promo-date > div','display','inline-block','','','.w-promotions'),(924487,'printshop','.w-promotions .promo-cart-discount','display','flex','','','.w-promotions'),(924496,'printshop','.p-sample-checkout-success .page-success .text-1','display','block','3','','.p-sample-checkout-success'),(924497,'printshop','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(924498,'printshop','.w-promotions .prom-multi-discount','display','block','4','','.w-promotions'),(924499,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(924500,'printshop','.testimonials .review','display','block','3','',''),(924501,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(924502,'printshop','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(924503,'printshop','.w-categories .image','display','block','','','.w-categories'),(924504,'printshop','.w-promotions .prom-multi-discount .promo-range','display','inline-block','','','.w-promotions'),(924505,'printshop','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','display','block','','','.w-promotions'),(924506,'printshop','.w-promotions .prom-multi-discount .products','display','grid','','','.w-promotions'),(924507,'printshop','.w-promotions .prom-multi-discount .list','display','grid','','','.w-promotions'),(924508,'printshop','.w-promotions .nextdiscount .promo-for-each','display','inline-block','','','.w-promotions'),(924509,'printshop','.w-promotions .nextdiscount .item-holder','display','flex','','','.w-promotions'),(924510,'printshop','.w-promotions .nextdiscount .content','display','grid','','','.w-promotions'),(924511,'printshop','.w-promotions .heading-3','display','inline-block','','','.w-promotions'),(924512,'printshop','.w-promotions .icon','display','inline-block','','','.w-promotions'),(924513,'printshop','.w-promotions .promo-salemaker .discount','display','inline-block','','','.w-promotions'),(924514,'printshop','.w-promotions .promo-salemaker .content','display','flex','','','.w-promotions'),(924515,'printshop','.w-promotions .promo-content > .personalgift','display','none','','','.w-promotions'),(924516,'printshop','.w-promotions .promo-cart-discount .slave','display','flex','','','.w-promotions'),(924517,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','display','inline-block','','','.w-promotions'),(924518,'printshop','.w-promotions .promo-cart-discount .item a','display','block','','','.w-promotions'),(924519,'printshop','.w-promotions .promo-cart-discount .content','display','flex','','','.w-promotions'),(924520,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','display','inline-block','','','.b-warehouses-popup'),(924521,'printshop','.w-product-available-in-warehouses .content','display','block','4','','.w-product-available-in-warehouses'),(924522,'printshop','.b-preloader .preloader','display','inline-block','3','','.b-preloader'),(924523,'printshop','.w-product-available-in-warehouses .warehouse-item','display','inline-block','','','.w-product-available-in-warehouses'),(924524,'printshop','.b-products-listing .products-listing .mix-attributes','display','block','4','','.b-products-listing'),(924525,'printshop','.b-products-listing .products-listing .attribute-qty-blocks','display','flex','','','.b-products-listing'),(924527,'printshop','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(924528,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(924529,'printshop','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(924531,'printshop','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(924532,'printshop','.b-messages .messBtnMenuDelete','display','inline-block','3','','.b-messages'),(924533,'printshop','.b-messages .messMenuButton span','display','inline-block','','','.b-messages'),(924534,'printshop','.b-messages .msv_to_cc div span','display','inline-block','','','.b-messages'),(924535,'printshop','.b-messages span.starred::before','display','inline-block','','','.b-messages'),(924536,'printshop','.b-messages .dataTables_wrapper > .top','display','block','4','','.b-messages'),(924537,'printshop','.b-messages .messBtnMenuStarred','display','inline-block','3','','.b-messages'),(924538,'printshop','.b-messages .messBtnMenuUnread','display','inline-block','3','','.b-messages'),(924539,'printshop','.b-messages .messages-menu li a','display','block','','','.b-messages'),(924540,'printshop','.b-messages .content_management_attach button','display','inline-block','','','.b-messages'),(924541,'printshop','.b-messages .email-line','display','flex','','','.b-messages'),(924542,'printshop','.b-messages .dataTables_wrapper > .bottom','display','block','4','','.b-messages'),(924543,'printshop','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(924544,'printshop','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(924545,'printshop','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(924546,'printshop','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(924547,'printshop','.order-summary .price-row.ot_gv .title','display','inline-block','3','','.order-summary'),(924548,'printshop','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(924549,'printshop','.w-sitemap-delivery-location > ul > li > ul','display','flex','','','.w-sitemap-delivery-location'),(924550,'printshop','.w-checkout-terms .required-message-wrap','display','inline-block','','','.w-checkout-terms'),(924551,'printshop','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(924552,'printshop','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(924553,'printshop','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(924554,'printshop','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(924555,'printshop','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(924556,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','display','inline-block','','','.b-switch'),(924557,'printshop','.w-product-reviews .reviews-list .review','display','block','3','','.w-product-reviews'),(924558,'printshop','.b-info-popup .info-popup','display','inline-block','','','.b-info-popup'),(924559,'printshop','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(924560,'printshop','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(924561,'printshop','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(924562,'printshop','.p-quick-order-index .quick-order-total','display','flex','','','.p-quick-order-index'),(924563,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-details ~ div','display','none','','','.w-upload-customer-id-upload-customer-id-form'),(924564,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','display','flex','','','.w-upload-customer-id-upload-customer-id-form'),(924565,'printshop','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(924566,'printshop','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(924567,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(924568,'printshop','.w-checkout-bonus-points .btn-remove','display','inline-block','','','.w-checkout-bonus-points'),(924569,'printshop','.w-login-block .cols','display','block','4','','.w-login-block'),(924570,'printshop','.w-login-block .label','display','block','','','.w-login-block'),(924571,'printshop','.w-menu-horizontal li','display','inline-block','','','.w-menu-horizontal'),(924572,'printshop','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','display','inline-block','','','.w-menu-horizontal'),(924573,'printshop','.w-menu-horizontal li li a, .w-menu-horizontal li li .no-link','display','block','','','.w-menu-horizontal'),(924574,'printshop','.w-tabs .tab-navigation','display','table','','','.w-tabs'),(924575,'printshop','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(924576,'printshop','.b-form .payment-method .item-radio label','display','block','','','.b-form'),(924577,'printshop','.w-quote .cart-box-link','display','flex','','','.w-quote'),(924578,'printshop','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(924581,'printshop','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(924582,'printshop','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(924583,'printshop','.w-promo-code .promo-text-2','display','none','5342','','.w-promo-code'),(924584,'printshop','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(924585,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(924586,'printshop','.b-switch .bootstrap-switch','display','inline-block','','','.b-switch'),(924587,'printshop','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(924588,'printshop','.w-social-links .name, .w-social-links .image','display','none','','','.w-social-links'),(924590,'printshop','.buttons','display','block','4','',''),(924591,'printshop','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(924592,'printshop','.w-login-block .label','display','block','','','.w-login-block'),(924593,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(924594,'printshop','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(924596,'printshop','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(924597,'printshop','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(924598,'printshop','.w-login-block .cols','display','block','4','','.w-login-block'),(924601,'printshop','.w-filters .input-checkbox:checked + .checkbox-span','display','inline-block','','','.w-filters'),(924602,'printshop','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(924603,'printshop','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(924604,'printshop','.b-switch .candlestick-wrapper','display','inline-block','','','.b-switch'),(924605,'printshop','.w-catalog-listing-look .listing-look-title','display','inline-block','','','.w-catalog-listing-look'),(924606,'printshop','.b-bottom .footerTitle ~ div','display','none','5333','','.b-bottom'),(924607,'printshop','.b-info .info','display','inline-block','3','','.b-info'),(924608,'printshop','.w-checkout-billing-address .genders-title > div','display','inline-block','','','.w-checkout-billing-address'),(924609,'printshop','.b-select-suggest .select2-display-none','display','none','','','.b-select-suggest'),(924610,'printshop','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(924611,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','3','','.b-select-suggest'),(924614,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','display','none','','','.b-select-suggest'),(924615,'printshop','.w-checkout-shipping-choice span','display','flex','','','.w-checkout-shipping-choice'),(924617,'printshop','.w-menu-big li a, .w-menu-big li .no-link','display','inline-block','','','.w-menu-big'),(924618,'printshop','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(924619,'printshop','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(924620,'printshop','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(924621,'printshop','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(924622,'printshop','.w-cart-compare .product','display','block','4','','.w-cart-compare'),(924623,'printshop','.w-top-categories .categories','display','block','4','','.w-top-categories'),(924624,'printshop','.w-top-categories .categories','display','flex','','','.w-top-categories'),(924625,'printshop','.b-info-popup .info-popup div','display','none','','','.b-info-popup'),(924626,'printshop','.w-checkout-billing-address .addresses','display','block','4','','.w-checkout-billing-address'),(924627,'printshop','.w-promo-code .promo-text-2','display','none','5342','','.w-promo-code'),(924628,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(924630,'printshop','.w-image-maps .default-links .item .description','display','block','','','.w-image-maps'),(924631,'printshop','.w-image-maps .float-items .item','display','block','1','','.w-image-maps'),(924632,'printshop','.w-image-maps .default-links .item .title','display','block','','','.w-image-maps'),(924633,'printshop','.b-upload-file .upload-file-template','display','inline-block','','','.b-upload-file'),(924634,'printshop','.b-info .info','display','inline-block','3','','.b-info'),(924635,'printshop','.w-checkout-shipping-address .addresses','display','block','4','','.w-checkout-shipping-address'),(924636,'printshop','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(924637,'printshop','.w-quote .cart-box-link','display','inline-block','3','','.w-quote'),(924638,'printshop','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(924639,'printshop','.w-multi-cart-actions .cart-actions .dropdown-toggle','display','inline-block','','','.w-multi-cart-actions'),(924640,'printshop','.w-top-categories .item','display','inline-block','','','.w-top-categories'),(924642,'printshop','.w-tabs .tab-a','display','block','','','.w-tabs'),(924643,'printshop','.w-tabs > .block > .box .heading-2, .w-tabs > .block > .box .heading-3, .w-tabs > .block > .box .heading-4','display','none','','','.w-tabs'),(924644,'printshop','.w-tabs .tab-li','display','table-cell','','','.w-tabs'),(924645,'printshop','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(924647,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(924648,'printshop','.p-wedding-registry-search .search-form','display','flex','','','.p-wedding-registry-search'),(924651,'printshop','.b-form .payment-method .item-radio label span','display','block','','','.b-form'),(924652,'printshop','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(924653,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','display','block','3','','.b-switch'),(924654,'printshop','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(924655,'printshop','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(924656,'printshop','.w-login-block .cols','display','block','4','','.w-login-block'),(924657,'printshop','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(924658,'printshop','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(924659,'printshop','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(924660,'printshop','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(924661,'printshop','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(924662,'printshop','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(924663,'printshop','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(924664,'printshop','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(924665,'printshop','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(924666,'printshop','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(924667,'printshop','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(924668,'printshop','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(924669,'printshop','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(924670,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','display','inline-block','','','.b-switch'),(924671,'printshop','.w-login-block .label','display','block','','','.w-login-block'),(924673,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(924674,'printshop','.w-filters .filter-widget-horizontal .content-filter-widget','display','table','','','.w-filters'),(924675,'printshop','.w-filters .filter-widget-horizontal .filter-box','display','table-cell','','','.w-filters'),(924676,'printshop','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(924677,'printshop','.b-products-listing .products-listing .bonus-points','display','flex','','','.b-products-listing'),(924678,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','display','inline-block','','','.b-switch'),(924679,'printshop','.w-checkout-shipping-address .genders-title label','display','inline-block','','','.w-checkout-shipping-address'),(924680,'printshop','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(924681,'printshop','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','display','inline-block','3','','.w-checkout-contact-information'),(924682,'printshop','.order-summary .price-row','display','none','','','.order-summary'),(924683,'printshop','.w-cart-bonus-points .btn-remove','display','inline-block','','','.w-cart-bonus-points'),(924684,'printshop','.w-cart-listing .points-earn','display','inline-block','','','.w-cart-listing'),(924685,'printshop','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(924687,'printshop','.w-multi-cart-actions .cart-actions','display','inline-block','','','.w-multi-cart-actions'),(924688,'printshop','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(924689,'printshop','.b-select-suggest .select2-container.select2-allowclear .select2-choice abbr','display','inline-block','','','.b-select-suggest'),(924690,'printshop','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(924691,'printshop','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(924693,'printshop','.w-reviews .item','display','grid','','','.w-reviews'),(924694,'printshop','.w-promo-code .holder','display','block','4','','.w-promo-code'),(924695,'printshop','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(924696,'printshop','.w-image-maps .default-links .item','display','block','1','','.w-image-maps'),(924698,'printshop','.w-checkout-shipping-choice input:checked + span:before','display','block','','','.w-checkout-shipping-choice'),(924700,'printshop','.w-checkout-create-account .columns .col-2:nth-child(2n)','display','none','5342','','.w-checkout-create-account'),(924701,'printshop','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(924702,'printshop','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(924703,'printshop','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(924704,'printshop','.w-top-categories .image','display','block','','','.w-top-categories'),(924705,'printshop','.w-cart-compare .delete-cart','display','inline-block','','','.w-cart-compare'),(924706,'printshop','.b-fancybox .fancybox-overlay','display','none','','','.b-fancybox'),(924707,'printshop','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(924708,'printshop','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(924709,'printshop','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(924710,'printshop','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(924711,'printshop','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(924712,'printshop','.w-list-b2b .attributes','display','block','4','','.w-list-b2b'),(924713,'printshop','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(924720,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(924721,'printshop','.b-form .columns','display','block','4','','.b-form'),(924722,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(924723,'printshop','.w-promo-code .holder','display','block','4','','.w-promo-code'),(924724,'printshop','.w-catalog-sorting .sorting','display','flex','','','.w-catalog-sorting'),(924725,'printshop','.w-promo-code .promo-text-2','display','none','5342','','.w-promo-code'),(924726,'printshop','.b-info .info','display','inline-block','3','','.b-info'),(924727,'printshop','.b-select-suggest .select2-container .select2-choice abbr','display','none','','','.b-select-suggest'),(924728,'printshop','.b-select-suggest .select2-container .select2-choice > .select2-chosen','display','block','','','.b-select-suggest'),(924729,'printshop','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(924730,'printshop','.b-select-suggest .select2-container .select2-choice','display','block','','','.b-select-suggest'),(924731,'printshop','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','display','list-item','','','.b-select-suggest'),(924732,'printshop','.b-select-suggest .select2-container','display','inline-block','','','.b-select-suggest'),(924733,'printshop','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(924734,'printshop','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(924735,'printshop','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(924736,'printshop','.w-checkout-shipping .sub-item','display','block','','','.w-checkout-shipping'),(924737,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','display','inline-block','','','.b-switch'),(924738,'printshop','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(924739,'printshop','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(924740,'printshop','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(924742,'printshop','.w-login-block .label','display','block','','','.w-login-block'),(924743,'printshop','.w-login-block .cols','display','block','4','','.w-login-block'),(924744,'printshop','.w-cart-shipping-estimator .item .row: after','display','block','','','.w-cart-shipping-estimator'),(924745,'printshop','.w-categories h2.name','display','block','','','.w-categories'),(924746,'printshop','.b-info .info','display','inline-block','3','','.b-info'),(924748,'printshop','.w-cart-compare .js-cart_totals_container b','display','block','','','.w-cart-compare'),(924749,'printshop','.b-form .middle-form .col-gender label','display','inline-block','','','.b-form'),(924750,'printshop','.b-form .login-cols','display','flex','','','.b-form'),(924751,'printshop','.b-form .payment-method .sub-item span','display','block','','','.b-form'),(924752,'printshop','.b-form .checkbox-style:checked + .checkbox-span','display','inline-block','','','.b-form'),(924753,'printshop','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(924756,'printshop','.w-cart-shipping-estimator .shipping-estimator','display','block','4','','.w-cart-shipping-estimator'),(924757,'printshop','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(924758,'printshop','.b-fancybox .fancybox-title-float-wrap .child','display','inline-block','','','.b-fancybox'),(924759,'printshop','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(924760,'printshop','.w-checkout-credit-amount .btn-remove','display','inline-block','','','.w-checkout-credit-amount'),(924761,'printshop','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(924762,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(924763,'printshop','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(924764,'printshop','.price .old','display','inline-block','','',''),(924765,'printshop','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(924766,'printshop','.w-checkout-billing-address .genders-title label','display','inline-block','','','.w-checkout-billing-address'),(924767,'printshop','.w-top-categories h2.name','display','block','','','.w-top-categories'),(924768,'printshop','.w-promo-code .holder','display','block','4','','.w-promo-code'),(924769,'printshop','.w-image-maps .categories-items .item .description','display','block','','','.w-image-maps'),(924770,'printshop','.w-image-maps .categories-items .item .title','display','block','','','.w-image-maps'),(924771,'printshop','.w-quote .no-text','display','none','5342','','.w-quote'),(924772,'printshop','.b-info-popup .info-popup','display','inline-block','3','','.b-info-popup'),(924773,'printshop','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(924774,'printshop','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(924775,'printshop','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(924776,'printshop','.b-upload-files .attach-active-holder','display','block','','','.b-upload-files'),(924777,'printshop','.b-compare .compare_select_items','display','inline-block','','','.b-compare'),(924778,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display','inline-block','','','.b-switch'),(924779,'printshop','.b-form .middle-form label','display','block','','','.b-form'),(924780,'printshop','.b-form .form-inputs label > span','display','inline-block','','','.b-form'),(924781,'printshop','.w-checkout-shipping-address .edit-ab','display','inline-block','','','.w-checkout-shipping-address'),(924782,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(924783,'printshop','.w-cart-shipping-estimator .address-item .lastname','display','block','4','','.w-cart-shipping-estimator'),(924786,'printshop','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(924787,'printshop','.w-promo-code .promo-text-2','display','none','5342','','.w-promo-code'),(924788,'printshop','.b-datepicker .picker-switch','display','none','','','.b-datepicker'),(924789,'printshop','.b-info .info','display','inline-block','3','','.b-info'),(924790,'printshop','.w-personal-gift-status-bar .timeline','display','flex','','','.w-personal-gift-status-bar'),(924791,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','display','block','','','.b-switch'),(924792,'printshop','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','display','inline-block','3','','.w-checkout-contact-information'),(924793,'printshop','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','display','inline-block','3','','.w-checkout-contact-information'),(924794,'printshop','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(924795,'printshop','.w-checkout-shipping-address .genders-title > div','display','inline-block','','','.w-checkout-shipping-address'),(924796,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span','display','inline-block','','','.b-form'),(924797,'printshop','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(924799,'printshop','.w-categories .categories','display','block','4','','.w-categories'),(924800,'printshop','.w-promo-code .holder','display','block','4','','.w-promo-code'),(924802,'printshop','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(924803,'printshop','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(924804,'printshop','.w-menu-big .hide-more.hide-more-disable, .w-menu-big .hide-more.hide-more-disable ~ li:not(.show-all)','display','block','','','.w-menu-big'),(924806,'printshop','.w-image-maps .categories-items .item','display','block','1','','.w-image-maps'),(924807,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(924808,'printshop','.w-checkout-billing-address .edit-ab','display','inline-block','','','.w-checkout-billing-address'),(924809,'printshop','.w-checkout-billing-address .addresses .address-item label','display','block','','','.w-checkout-billing-address'),(924810,'printshop','.w-checkout-shipping-choice #shippingchoice-choice','display','flex','','','.w-checkout-shipping-choice'),(924811,'printshop','.w-checkout-shipping-choice input','display','none','','','.w-checkout-shipping-choice'),(924812,'printshop','.w-cart-give-away h2','display','none','','','.w-cart-give-away'),(924813,'printshop','.w-promo-code .promo-text-2','display','none','5342','','.w-promo-code'),(924815,'printshop','.b-pass-strength .pass-strength','display','block','','','.b-pass-strength'),(924816,'printshop','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(924817,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display','inline-block','','','.b-switch'),(924818,'printshop','.w-quote .strong','display','block','','','.w-quote'),(924819,'printshop','.w-cart-up-sell h3','display','none','','','.w-cart-up-sell'),(924820,'printshop','.w-cart-compare .product-actions .dropdown-toggle','display','none','4','','.w-cart-compare'),(924821,'printshop','.b-select-suggest .select2-results li','display','list-item','','','.b-select-suggest'),(924822,'printshop','.b-select-suggest .select2-search-choice-close','display','block','','','.b-select-suggest'),(924823,'printshop','.b-select-suggest .select2-container.select2-container-disabled .select2-choice abbr','display','none','','','.b-select-suggest'),(924824,'printshop','.b-select-suggest .select2-more-results','display','list-item','','','.b-select-suggest'),(924825,'printshop','.b-select-suggest .select2-results .select2-selected','display','none','','','.b-select-suggest'),(924826,'printshop','.b-select-suggest .select2-results .select2-disabled','display','list-item','','','.b-select-suggest'),(924827,'printshop','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','display','list-item','','','.b-select-suggest'),(924828,'printshop','.w-menu-big .hide-more, .w-menu-big .hide-more ~ li:not(.show-all)','display','none','','','.w-menu-big'),(924829,'printshop','.w-checkout-shipping-address .change-ab','display','inline-block','','','.w-checkout-shipping-address'),(924830,'printshop','.w-checkout-shipping-address .addresses .address-item label','display','block','','','.w-checkout-shipping-address'),(924831,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','','','.b-select-suggest'),(924832,'printshop','.b-select-suggest .select2-search','display','inline-block','','','.b-select-suggest'),(924833,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow','display','inline-block','','','.b-select-suggest'),(924834,'printshop','.w-neighbour-checkout .text','display','inline-block','','','.w-neighbour-checkout'),(924836,'printshop','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(924837,'printshop','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(924838,'printshop','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(924839,'printshop','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(924841,'printshop','.w-menu-big > ul > li:hover > ul','display','block','','','.w-menu-big'),(924842,'printshop','.w-menu-big li li a, .w-menu-big li li .no-link','display','block','','','.w-menu-big'),(924844,'printshop','.w-menu-big li li li','display','block','','','.w-menu-big'),(924850,'printshop','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(924851,'printshop','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(924852,'printshop','.w-menu-horizontal ul li:hover > ul','display','block','','','.w-menu-horizontal'),(924853,'printshop','.w-menu-big li','display','inline-block','','','.w-menu-big'),(924855,'printshop','.w-cart-listing .points-redeem','display','inline-block','','','.w-cart-listing'),(924856,'printshop','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(924857,'printshop','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(924858,'printshop','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(924859,'printshop','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(924860,'printshop','.w-promo-code .holder','display','block','4','','.w-promo-code'),(924861,'printshop','.w-login-block .label','display','block','','','.w-login-block'),(924862,'printshop','.w-categories .item','display','inline-block','','','.w-categories'),(924863,'printshop','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(924864,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.b-data-table'),(924865,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.b-data-table'),(924867,'printshop','.w-communication-post .communication-post-author','display','flex','','','.w-communication-post'),(924868,'printshop','.b-products-listing .products-listing .compare label','display','inline','','','.b-products-listing'),(924869,'printshop','.b-products-listing .products-listing .compare','display','block','','','.b-products-listing'),(924870,'printshop','.b-products-listing .BlockBox','display','block','4','','.b-products-listing'),(924871,'printshop','.b-products-listing .btn-preloader','display','inline-block','3','','.b-products-listing'),(924872,'printshop','.b-products-listing .hide','display','none','','','.b-products-listing'),(924873,'printshop','.b-products-listing .hover-box-content','display','none','','','.b-products-listing'),(924874,'printshop','.b-products-listing .hover-box:hover .hover-box-content','display','block','','','.b-products-listing'),(924875,'printshop','.b-products-listing .loader','display','inline-block','4','','.b-products-listing'),(924876,'printshop','.b-products-listing .products-listing .attribute-qty-block','display','flex','','','.b-products-listing'),(924877,'printshop','.b-products-listing .products-listing','display','block','4','','.b-products-listing'),(924878,'printshop','.w-catalog-b2b-add-button ','display','none','','','.w-catalog-b2b-add-button'),(924879,'printshop','.b-products-listing .products-listing .item','display','inline-block','','','.b-products-listing'),(924880,'printshop','.b-products-listing .products-listing.align-left .item','display','block','','','.b-products-listing'),(924881,'printshop','.b-products-listing .products-listing.align-right .item','display','block','','','.b-products-listing'),(924882,'printshop','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','display','block','','','.b-products-listing'),(924883,'printshop','.b-products-listing .show-ofstock-products .headerStock','display','inline-block','','','.b-products-listing'),(924884,'printshop','.checkbox input','display','none','','',''),(924885,'printshop','.checkbox input + span','display','inline-block','','',''),(924892,'printshop','.b-rating .glyphicon','display','inline-block','','','.b-rating'),(924893,'printshop','.b-form .newsletter-row','display','block','4','','.b-form'),(924894,'printshop','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','display','block','','','.b-fancybox'),(924895,'printshop','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(924896,'printshop','.w-cart-credit-amount .btn-remove','display','inline-block','','','.w-cart-credit-amount'),(924898,'printshop','.w-login-block .label','display','block','','','.w-login-block'),(924899,'printshop','.w-coupons-and-vauchers-checkout .btn-remove','display','inline-block','','','.w-coupons-and-vauchers-checkout'),(924900,'printshop','.order-summary .price-row.ot_coupon .title','display','inline-block','3','','.order-summary'),(924901,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(924902,'printshop','.b-form .eye-password-wrap','display','block','','','.b-form'),(924903,'printshop','.w-taxable form','display','flex','','','.w-taxable'),(924904,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','display','inline-block','','',''),(924905,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','','','.w-communication-new-topic'),(924906,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','3','','.w-communication-new-topic'),(924907,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','display','inline-block','','','.w-communication-new-topic'),(924908,'printshop','.w-communication-new-topic .middle-form .col-2 label > span','display','block','','','.w-communication-new-topic'),(924909,'printshop','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(924910,'printshop','.w-login-block .cols','display','block','4','','.w-login-block'),(924912,'printshop','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(924913,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(924914,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(924915,'printshop','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','display','inline-block','','','.b-form'),(924916,'printshop','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(924917,'printshop','.w-promo-code .holder','display','block','4','','.w-promo-code'),(924918,'printshop','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(924919,'printshop','.w-menu-horizontal ul ul','display','none','','','.w-menu-horizontal'),(924920,'printshop','.w-menu-horizontal ul ul li','display','block','','','.w-menu-horizontal'),(924921,'printshop','.w-catalog-listing-look .grid','display','inline-block','','','.w-catalog-listing-look'),(924922,'printshop','.w-catalog-listing-look .b2b','display','inline-block','','','.w-catalog-listing-look'),(924923,'printshop','.w-catalog-listing-look .list','display','inline-block','','','.w-catalog-listing-look'),(924924,'printshop','.w-catalog-items-on-page .items-on-page','display','flex','','','.w-catalog-items-on-page'),(924925,'printshop','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(924926,'printshop','.w-cart-listing .item .attributes > div','display','table-row','','','.w-cart-listing'),(924927,'printshop','.w-cart-listing .item .attributes span','display','table-cell','','','.w-cart-listing'),(924928,'printshop','.w-cart-listing .item .attributes','display','table','','','.w-cart-listing'),(924929,'printshop','.w-cart-listing .item .attributes strong','display','table-cell','','','.w-cart-listing'),(924930,'printshop','.w-cart-listing .item .gift-wrap label','display','flex','','','.w-cart-listing'),(924931,'printshop','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','display','block','','','.w-cart-listing'),(924932,'printshop','.w-cart-listing .headings','display','none','5342','','.w-cart-listing'),(924933,'printshop','.w-cart-listing .item .price *','display','inline-block','5342','','.w-cart-listing'),(924934,'printshop','.w-cart-give-away .ga_name','display','block','4','','.w-cart-give-away'),(924935,'printshop','.w-cart-discount-coupon .btn-remove','display','inline-block','','','.w-cart-discount-coupon'),(924948,'printshop','.w-image-maps .float-items .item .title','display','block','','','.w-image-maps'),(924949,'printshop','.w-image-maps .float-items .item .description','display','block','','','.w-image-maps'),(924950,'printshop','.w-image-maps .products-items .item-holder','display','block','1','','.w-image-maps'),(924951,'printshop','.w-image-maps .svg-wrap','display','inline-block','','','.w-image-maps'),(924952,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','display','none','','','.w-image-maps'),(924953,'printshop','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','display','inline-block','','','.b-compare'),(924954,'printshop','.p-wedding-registry-search #searchform-status','display','flex','','','.p-wedding-registry-search'),(924955,'printshop','.w-tabs .accordion-heading','display','block','','','.w-tabs'),(924956,'printshop','.w-cart-shipping-estimator .item .row','display','block','','','.w-cart-shipping-estimator'),(924959,'printshop','.w-login-block .cols','display','block','4','','.w-login-block'),(924961,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','display','inline','','','.w-contact-contacts'),(924962,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','display','inline-block','3','','.w-contact-contacts'),(924963,'printshop','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','display','inline-block','','','.w-contact-contacts'),(924964,'printshop','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(924966,'printshop','.order-summary .price-row.ot_bonus_points .title','display','inline-block','3','','.order-summary'),(924967,'printshop','.w-cart-shipping-estimator .shipping-estimator .heading-2','display','none','','','.w-cart-shipping-estimator'),(924968,'printshop','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(924971,'printshop','.w-reviews-content .item','display','grid','','','.w-reviews-content'),(924972,'printshop','.b-info-popup .info-popup:hover div','display','block','','','.b-info-popup'),(924973,'printshop','.w-filters .content-filter-widget','display','none','5342','','.w-filters'),(924974,'printshop','.w-filters .fsl_handle','display','block','4','','.w-filters'),(924975,'printshop','.w-filters .filter-box-content ul li.view_items','display','block','','','.w-filters'),(924977,'printshop','.w-promo-code .promo-text-2','display','none','5342','','.w-promo-code'),(924978,'printshop','.w-taxable select','display','inline-block','','','.w-taxable'),(924979,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-container','display','inline-block','','','.b-switch'),(924980,'printshop','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(924985,'printshop','.w-menu-big > ul > li > ul','display','none','','','.w-menu-big'),(924986,'printshop','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(924987,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','display','inline','','','.b-h-inline'),(924988,'printshop','.w-quote .no-text','display','inline-block','','','.w-quote'),(924989,'printshop','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(924991,'printshop','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(924992,'printshop','.w-filters .mobileCollapse','display','none','','','.w-filters'),(924993,'printshop','.w-filters .input-checkbox:not(checked) + .checkbox-span','display','inline-block','','','.w-filters'),(924994,'printshop','.b-product-images .media-popup .mp-big-images .item','display','flex','','','.b-product-images'),(924995,'printshop','.b-product-images .media-popup .mp-big-images .item + .item:not(.slick-slide)','display','none','','','.b-product-images'),(924996,'printshop','.b-product-images .media-popup .mp-small-images .item','display','inline-block','','','.b-product-images'),(924997,'printshop','.b-product-images .media-popup .mp-small-images img','display','inline-block','','','.b-product-images'),(924998,'printshop','.b-product-images .media-popup .slick-dots button','display','none','','','.b-product-images'),(924999,'printshop','.b-product-images .media-popup .slick-dots li','display','inline-block','','','.b-product-images'),(925000,'printshop','.b-menu-burger_icon .menu-style[data-burger_icon] .menu-content','display','none','','','.b-menu-burger_icon'),(925001,'printshop','.b-menu-burger_icon .bi-opened .menu-style[data-burger_icon] .menu-content','display','block','','','.b-menu-burger_icon'),(925002,'printshop','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','display','block','','','.b-menu-burger_icon'),(925003,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','display','block','','','.b-menu-lev_display-slide'),(925004,'printshop','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','display','block','','','.b-menu-lev_display-slide'),(925005,'printshop','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','display','block','','','.b-menu-lev_display-slide'),(925006,'printshop','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','display','block','','','.b-menu-lev_display-slide'),(925007,'printshop','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','display','block','','','.b-menu-lev_display-slide'),(925008,'printshop','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(925009,'printshop','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(925010,'printshop','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(925011,'printshop','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(925012,'printshop','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(925013,'printshop','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(925014,'printshop','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(925015,'printshop','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(925016,'printshop','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(925017,'printshop','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(925018,'printshop','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(925019,'printshop','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(925020,'printshop','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-2','display','none','','','.b-menu-lev_vis'),(925021,'printshop','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(925022,'printshop','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-3','display','none','','','.b-menu-lev_vis'),(925023,'printshop','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(925024,'printshop','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-4','display','none','','','.b-menu-lev_vis'),(925025,'printshop','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(925026,'printshop','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-5','display','none','','','.b-menu-lev_vis'),(925027,'printshop','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(925028,'printshop','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-6','display','none','','','.b-menu-lev_vis'),(925029,'printshop','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(925030,'printshop','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(925031,'printshop','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-2','display','none','','','.b-menu-lev_vis'),(925032,'printshop','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(925033,'printshop','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-3','display','none','','','.b-menu-lev_vis'),(925034,'printshop','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(925035,'printshop','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-4','display','none','','','.b-menu-lev_vis'),(925036,'printshop','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(925037,'printshop','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-5','display','none','','','.b-menu-lev_vis'),(925038,'printshop','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(925039,'printshop','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-6','display','none','','','.b-menu-lev_vis'),(925040,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(925041,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(925042,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-3','display','none','','','.b-menu-lev_vis-click_icon'),(925043,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(925044,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-4','display','none','','','.b-menu-lev_vis-click_icon'),(925045,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(925046,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-5','display','none','','','.b-menu-lev_vis-click_icon'),(925047,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(925048,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-6','display','none','','','.b-menu-lev_vis-click_icon'),(925049,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display','block','','','.b-menu-open_from-left'),(925050,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul','display','flex','','','.b-menu-position'),(925051,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(925052,'printshop','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display','none','','','.b-menu-style'),(925053,'printshop','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display','none','','','.b-menu-style'),(925054,'printshop','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display','none','','','.b-menu-style'),(925055,'printshop','.b-trade-approval .steps-bar','display','table','','','.b-trade-approval'),(925056,'printshop','.b-trade-approval .steps-bar li','display','table-cell','','','.b-trade-approval'),(925057,'printshop','.b-trade-approval .steps-bar li a','display','block','','','.b-trade-approval'),(925058,'printshop','.b-trade-approval .middle-form label','display','block','','','.b-trade-approval'),(925059,'printshop','.b-trade-approval .columns','display','block','4','','.b-trade-approval'),(925060,'printshop','.w-account-personal-catalog .list-switcher','display','flex','','','.w-account-personal-catalog'),(925061,'printshop','.w-account-subscription .send-email','display','block','','','.w-account-subscription'),(925062,'printshop','.w-account-subscription .subscription-variant','display','flex','','','.w-account-subscription'),(925063,'printshop','.w-catalog-additional-images li','display','inline-block','','','.w-catalog-additional-images'),(925064,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','display','inline-block','3','','.w-catalog-compare'),(925065,'printshop','.w-catalog-compare td span','display','inline','','','.w-catalog-compare'),(925066,'printshop','.w-catalog-compare .product-listing','display','flex','','','.w-catalog-compare'),(925067,'printshop','.w-catalog-compare .promos-info','display','none','','','.w-catalog-compare'),(925068,'printshop','.w-catalog-compare .item .compare a','display','none','','','.w-catalog-compare'),(925069,'printshop','.w-catalog-compare .cross-box .different-all','display','flex','','','.w-catalog-compare'),(925070,'printshop','.w-catalog-compare .cross-box','display','flex','','','.w-catalog-compare'),(925071,'printshop','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','display','block','','','.w-delivery-day'),(925072,'printshop','.w-delivery-day .time-left','display','flex','','','.w-delivery-day'),(925073,'printshop','.w-delivery-day .left-count','display','block','','','.w-delivery-day'),(925074,'printshop','.w-delivery-day .left-text-left','display','block','','','.w-delivery-day'),(925075,'printshop','.w-delivery-day .left-text-right','display','block','','','.w-delivery-day'),(925076,'printshop','.w-product-images .img-holder','display','flex','','','.w-product-images'),(925077,'printshop','.w-product-images .additional-vertical','display','flex','','','.w-product-images'),(925078,'printshop','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','display','inline-block','','','.b-cookie-notice'),(925080,'printshop','.lowestPricedBox .w-banner .banner','display','flex','','','.lowestPricedBox'),(925081,'printshop','.tripleBanner .w-html_box','display','inline-block','3','','.tripleBanner'),(925082,'printshop','.b-products-listing .products-listing .item picture','display','block','','','.b-products-listing'),(925083,'printshop','.shopByCollectionBox .w-banner .banner','display','flex','','','.shopByCollectionBox'),(925084,'printshop','.preFooter .w-banner .single_banner','display','inline-block','','','.preFooter'),(925085,'printshop','.b-slick .slick-slide','display','none','','','.b-slick'),(925086,'printshop','.b-slick .slick-arrow.slick-hidden','display','none','','','.b-slick'),(925087,'printshop','.b-slick .slick-initialized .slick-slide','display','block','','','.b-slick'),(925088,'printshop','.b-slick .slick-list','display','block','','','.b-slick'),(925089,'printshop','.b-slick .slick-slide img','display','block','','','.b-slick'),(925090,'printshop','.b-slick .slick-slide.slick-loading img','display','none','','','.b-slick'),(925091,'printshop','.b-slick .slick-slider','display','block','','','.b-slick'),(925092,'printshop','.b-slick .slick-track','display','block','','','.b-slick'),(925093,'printshop','.b-slick .slick-track, .b-slick .slick-track:after','display','table','3','','.b-slick'),(925094,'printshop','.b-slick .slick-vertical .slick-slide','display','block','','','.b-slick'),(925100,'printshop','.menu-header .burger-icon','display','inline-block','5342','','.menu-header'),(925101,'printshop','.tripleBanner ','display','flex','','','.tripleBanner'),(925102,'printshop','.b-products-listing .save-price-box','display','none','','','.b-products-listing'),(925103,'printshop','.b-products-listing .products-listing .compare input + span','display','block','','','.b-products-listing'),(925104,'printshop','.b-products-listing .products-listing .item:hover .item-nav','display','block','','','.b-products-listing'),(925105,'printshop','.LeftCategories .level-2','display','none','','','.LeftCategories'),(925106,'printshop','.LeftCategories .w-menu-simple ul li a','display','block','','','.LeftCategories'),(925107,'printshop','.b-products-listing .products-listing.slick-slider .item-nav','display','none','','','.b-products-listing'),(925108,'printshop','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','display','none','4','','.b-products-listing'),(925109,'printshop','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(925110,'printshop','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(925111,'printshop','.w-subscribers .sb_ta','display','flex','','','.w-subscribers'),(925112,'printshop','.w-subscribers .btn-submit','display','block','','','.w-subscribers'),(925113,'printshop','.w-quote .multicart .current-text','display','block','','','.w-quote'),(925114,'printshop','.w-quote .multicart .item','display','block','','','.w-quote'),(925115,'printshop','.w-quote .multicart .name','display','block','','','.w-quote'),(925116,'printshop','.w-quote .multicart .sub-total-row','display','block','','','.w-quote'),(925117,'printshop','.w-quote .multicart .title','display','inline-block','','','.w-quote'),(925118,'printshop','.w-quote .name','display','block','','','.w-quote'),(925119,'printshop','.w-quote .price','display','block','','','.w-quote'),(925120,'printshop','.w-quote a.item','display','block','4','','.w-quote'),(925121,'printshop','.w-quote a.item','display','block','','','.w-quote'),(925122,'printshop','.w-quote .cart-box-link','display','none','5342,4','','.w-quote'),(925123,'printshop','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(925124,'printshop','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(925125,'printshop','.b-products-listing .rating, .b-products-listing .ratingCounts','display','inline-block','','','.b-products-listing'),(925126,'printshop','.rating, .ratingCounts','display','inline-block','','',''),(925127,'printshop','.b-products-listing .promos-info .promo-item','display','flex','','','.b-products-listing'),(925128,'printshop','.w-product-sale-ends .left-count','display','block','','','.w-product-sale-ends'),(925129,'printshop','.w-product-sale-ends .left-count-days','display','block','','','.w-product-sale-ends'),(925130,'printshop','.w-product-sale-ends .left-count-hours','display','block','','','.w-product-sale-ends'),(925131,'printshop','.w-product-sale-ends .left-text-left','display','block','','','.w-product-sale-ends'),(925132,'printshop','.w-product-sale-ends .left-text-right','display','block','','','.w-product-sale-ends'),(925133,'printshop','.w-product-quantity .product-quantity-label','display','none','','','.w-product-quantity'),(925134,'printshop','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(925135,'printshop','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(925136,'printshop','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(925137,'printshop','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(925138,'printshop','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(925139,'printshop','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(925140,'printshop','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(925141,'printshop','.w-product-bonus-points > div','display','block','4','','.w-product-bonus-points'),(925142,'printshop','.warrantyProduct .warranty','display','inline-block','3','','.warrantyProduct'),(925143,'printshop','.warrantyProduct .delivery','display','inline-block','3','','.warrantyProduct'),(925144,'printshop','.w-compare .compare-button','display','block','','','.w-compare'),(925145,'printshop','.w-files-catalog-widgets-files-catalog ','display','flex','','','.w-files-catalog-widgets-files-catalog'),(925146,'printshop','.w-files-catalog-widgets-files-catalog .image','display','flex','','','.w-files-catalog-widgets-files-catalog'),(925147,'printshop','.w-files-catalog-widgets-files-catalog .item','display','flex','','','.w-files-catalog-widgets-files-catalog'),(925148,'printshop','.w-files-catalog-widgets-files-catalog picture','display','inline-block','','','.w-files-catalog-widgets-files-catalog'),(925149,'printshop','.w-sample .cart-box-link','display','inline-block','4','','.w-sample'),(925150,'printshop','.w-sample .cart-box-link','display','flex','','','.w-sample'),(925151,'printshop','.w-sample .cart-box-link','display','inline-block','3','','.w-sample'),(925152,'printshop','.w-sample .cart-box-link .strong','display','none','','','.w-sample'),(925153,'printshop','.w-sample .multicart .current-text','display','block','','','.w-sample'),(925154,'printshop','.w-sample .multicart .item','display','block','','','.w-sample'),(925155,'printshop','.w-sample .multicart .name','display','block','','','.w-sample'),(925156,'printshop','.w-sample .multicart .sub-total-row','display','block','','','.w-sample'),(925157,'printshop','.w-sample .multicart .title','display','inline-block','','','.w-sample'),(925158,'printshop','.w-sample .name','display','block','','','.w-sample'),(925159,'printshop','.w-sample .no-text','display','inline-block','','','.w-sample'),(925160,'printshop','.w-sample .price','display','block','','','.w-sample'),(925161,'printshop','.w-sample .strong','display','block','','','.w-sample'),(925162,'printshop','.w-sample a.item','display','block','4','','.w-sample'),(925163,'printshop','.w-sample a.item','display','block','','','.w-sample'),(925164,'printshop','.w-sample .cart-box-link','display','none','5342,4','','.w-sample'),(925165,'printshop','.w-sample .no-text','display','none','5342','','.w-sample'),(925166,'printshop','.w-quote .cart-box.hover-box .cart-content','display','none','','','.w-quote'),(925167,'printshop','.w-quote .cart-box.hover-box:hover .cart-content','display','block','','','.w-quote'),(925168,'printshop','.w-sample .cart-box .cart-content','display','none','','','.w-sample'),(925169,'printshop','.w-sample .cart-box:hover .cart-content','display','block','','','.w-sample'),(925170,'printshop','.w-filters-simple .filter-row','display','flex','','','.w-filters-simple'),(925171,'printshop','.w-filters-simple .integrate-price-holder > div','display','inline-block','','','.w-filters-simple'),(925172,'printshop','.w-cart-discount-coupon .inp','display','none','','','.w-cart-discount-coupon'),(925173,'printshop','.w-cart-sub-total .price-row','display','flex','','','.w-cart-sub-total'),(925174,'printshop','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(925175,'printshop','.w-cart-gift-certificate .input-apple','display','flex','','','.w-cart-gift-certificate'),(925176,'printshop','.w-cart-order-reference .input-apple','display','flex','','','.w-cart-order-reference'),(925177,'printshop','.w-product-attributes .radio-attributes > span','display','block','','','.w-product-attributes'),(925178,'printshop','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(925179,'printshop','.w-product-bundle .bundle-products','display','flex','','','.w-product-bundle'),(925180,'printshop','.w-product-bundle .bundle-total-price .title, .w-product-bundle .bundle-total-price .price','display','inline-block','','','.w-product-bundle'),(925181,'printshop','.w-product-in-bundles .bundle-products','display','flex','','','.w-product-in-bundles'),(925182,'printshop','.w-product-in-bundles .bundle-total-price .title, .w-product-in-bundles .bundle-total-price .price','display','inline-block','','','.w-product-in-bundles'),(925183,'printshop','.w-product-quantity-discounts .count','display','inline-block','','','.w-product-quantity-discounts'),(925184,'printshop','.b-bottom .cart-options .buttons','display','block','','','.b-bottom'),(925185,'printshop','.w-catalog-additional-images picture','display','flex','','','.w-catalog-additional-images'),(925186,'printshop','.w-sample-products .price','display','none','','','.w-sample-products'),(925189,'printshop','.b-products-listing .products-listing .radio-attributes','display','block','4','','.b-products-listing'),(925190,'printshop','.b-pagination .pagination','display','block','4','','.b-pagination'),(925191,'printshop','.b-pagination .pagination .next-pages','display','inline-block','','','.b-pagination'),(925192,'printshop','.b-pagination .pagination .page-number','display','inline-block','','','.b-pagination'),(925193,'printshop','.b-pagination .pagination .paging','display','inline-block','','','.b-pagination'),(925194,'printshop','.b-pagination .pagination .prev-pages','display','inline-block','','','.b-pagination'),(925195,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','display','inline-block','','','.b-pagination'),(925196,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','display','inline-block','','','.b-pagination'),(925197,'printshop','.b-pagination .pagination span','display','inline-block','2','','.b-pagination'),(925198,'printshop','.b-pagination ul.pagination li','display','inline-block','','','.b-pagination'),(925199,'printshop','.w-product-multi-inventory .select-box:last-of-type:after','display','block','','','.w-product-multi-inventory'),(925200,'printshop','.w-product-properties-filters-widgets-chosen-filters .item','display','inline-block','','','.w-product-properties-filters-widgets-chosen-filters'),(925201,'printshop','.w-product-multi-inventory .radio-attributes > label','display','block','','','.w-product-multi-inventory'),(925202,'printshop','.w-cart-listing .no-price .price','display','none','','','.w-cart-listing'),(925203,'printshop','.w-product-multi-inventory #product-attributes','display','block','4','','.w-product-multi-inventory'),(925204,'printshop','.p-sample-checkout-index .heading-2','display','none','3','','.p-sample-checkout-index'),(925205,'printshop','.p-sample-checkout-index .heading-2','display','none','4','','.p-sample-checkout-index'),(925206,'printshop','.p-sample-checkout-index .order-summary .heading-2','display','inline-block','3','','.p-sample-checkout-index'),(925207,'printshop','.p-sample-checkout-index .order-summary .heading-2','display','inline-block','4','','.p-sample-checkout-index'),(925210,'printshop','.w-product-multi-inventory .radio-attributes > span','display','block','','','.w-product-multi-inventory'),(925211,'printshop','.w-quote-products .cart-listing .price','display','none','','','.w-quote-products'),(925212,'printshop','.w-product-multi-inventory .radio-attributes .option-item','display','inline-block','','','.w-product-multi-inventory'),(925213,'printshop','.w-product-multi-inventory .radio-attributes > label input','display','none','','','.w-product-multi-inventory'),(925214,'printshop','.w-product-multi-inventory .radio-attributes','display','block','4','','.w-product-multi-inventory'),(925215,'printshop','.w-account-personal-catalog .headings','display','none','','','.w-account-personal-catalog'),(925216,'printshop','.w-account-personal-catalog .list-row-action','display','flex','','','.w-account-personal-catalog'),(925217,'printshop','.w-account-personal-catalog .list-row-action a','display','block','','','.w-account-personal-catalog'),(925218,'printshop','.w-product-quantity-discounts .quantity-discounts','display','block','4','','.w-product-quantity-discounts'),(925219,'printshop','h1, .heading-1','display','none','5342,3','',''),(925220,'printshop','h1, .heading-1','display','none','5342,4','',''),(925221,'printshop','.w-account-personal-catalog .buy-box','display','flex','5333','','.w-account-personal-catalog'),(925222,'printshop','.w-filters .handle_tit','display','block','5347','','.w-filters'),(925223,'printshop','.b-products-listing .products-listing .radio-attributes .option','display','inline-block','','','.b-products-listing'),(925224,'printshop','.b-products-listing .products-listing .radio-attributes > label','display','block','','','.b-products-listing'),(925225,'printshop','.b-products-listing .products-listing .radio-attributes > label input','display','none','','','.b-products-listing'),(925226,'printshop','.b-products-listing .products-listing .radio-attributes > span','display','block','','','.b-products-listing'),(925227,'printshop','.b-products-listing .products-listing .radio-attributes .item-title','display','block','','','.b-products-listing'),(925228,'printshop','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(925229,'printshop','.w-product-collection .together','display','block','','','.w-product-collection'),(925230,'printshop','.price .special-promote','display','block','','',''),(925231,'printshop','.w-product-attributes #product-attributes','display','block','4','','.w-product-attributes'),(925232,'printshop','.w-product-attributes .radio-attributes','display','block','4','','.w-product-attributes'),(925233,'printshop','.w-product-attributes .radio-attributes .option-item','display','inline-block','','','.w-product-attributes'),(925234,'printshop','.w-product-attributes .radio-attributes > label','display','block','','','.w-product-attributes'),(925235,'printshop','.w-product-attributes .radio-attributes > label input','display','none','','','.w-product-attributes'),(925236,'printshop','.w-product-attributes .select-box:last-of-type:after','display','block','','','.w-product-attributes'),(925237,'printshop','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(925238,'printshop','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(925239,'printshop','.w-product-properties li','display','table-cell','','','.w-product-properties'),(925240,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','display','block','','','.w-questionnaire-widgets-questionnaire'),(925241,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no label','display','inline','','','.w-questionnaire-widgets-questionnaire'),(925242,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no','display','flex','','','.w-questionnaire-widgets-questionnaire'),(925243,'printshop','.w-product-groups .property-category-heading','display','none','','','.w-product-groups'),(925244,'printshop','.w-product-groups .radioBox label','display','block','','','.w-product-groups'),(925245,'printshop','.w-product-groups .radioBox label .containerBlock','display','block','','','.w-product-groups'),(925246,'printshop','.w-product-groups .prop-group-swatch','display','block','4','','.w-product-groups'),(925247,'printshop','.b-products-listing .mix-attributes .mult-qty-input .qty-box','display','block','','','.b-products-listing'),(925248,'printshop','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(925249,'printshop','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(925250,'printshop','.w-product-custom-bundle .right-area .separate-text','display','block','','','.w-product-custom-bundle'),(925251,'printshop','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','display','inline-block','3','','.w-product-custom-bundle'),(925252,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list'),(925253,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list-block'),(925254,'printshop','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(925255,'printshop','.w-delivery-location-location-list .deliveryListParrent a','display','inline-block','','','.w-delivery-location-location-list'),(925256,'printshop','.w-delivery-location-location-list .deliveryList li a','display','block','','','.w-delivery-location-location-list'),(925257,'printshop','.w-delivery-location-featured-list .deliveryList ul','display','block','4','','.w-delivery-location-featured-list'),(925258,'printshop','.w-sale-category .btn','display','block','','','.w-sale-category'),(925259,'printshop','.w-sale-category .left-count','display','block','','','.w-sale-category'),(925260,'printshop','.w-sale-category .left-count-days','display','block','','','.w-sale-category'),(925261,'printshop','.w-sale-category .left-count-hours','display','block','','','.w-sale-category'),(925262,'printshop','.w-sale-category .left-text-left','display','block','','','.w-sale-category'),(925263,'printshop','.w-sale-category .left-text-right','display','block','','','.w-sale-category'),(925264,'printshop','.w-sale-category .special-price','display','block','','','.w-sale-category'),(925265,'printshop','.w-sale-category .special-price-text','display','none','','','.w-sale-category'),(925266,'printshop','.w-sale-category .text','display','block','','','.w-sale-category'),(925267,'printshop','.w-success-download table td','display','block','5363','','.w-success-download'),(925268,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list-by-catalog'),(925269,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(925270,'printshop','.w-delivery-location-list-by-page .page-list','display','block','4','','.w-delivery-location-list-by-page'),(925271,'printshop','.w-delivery-location-top-location-list .deliveryList','display','block','4','','.w-delivery-location-top-location-list'),(925272,'printshop','.w-product-properties-icons ','display','flex','','','.w-product-properties-icons'),(925273,'printshop','.w-product-properties-icons .hover-box-content','display','inline-block','','','.w-product-properties-icons'),(925274,'printshop','.w-product-properties-icons .hover-box','display','block','','','.w-product-properties-icons'),(925275,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','display','inline-block','','','.w-product-properties-icons'),(925276,'printshop','.w-delivery-location-cross-pages .page-list','display','block','4','','.w-delivery-location-cross-pages'),(925277,'printshop','.w-cart-listing .price br','display','none','','','.w-cart-listing'),(925278,'printshop','.w-delivery-location-product-categories .categories','display','flex','','','.w-delivery-location-product-categories'),(925279,'printshop','.w-delivery-location-product-categories .item.category-link','display','block','','','.w-delivery-location-product-categories'),(925280,'printshop','.delivery-options-popup','display','block','4','',''),(925281,'printshop','.w-product-bonus-points .bonus-points-cost','display','inline-block','','','.w-product-bonus-points'),(925282,'printshop','.w-product-designer-designer .groupNamePrDes','display','none','','','.w-product-designer-designer'),(925283,'printshop','.w-product-designer-designer .grnamebox .title-sortable','display','block','','','.w-product-designer-designer'),(925284,'printshop','.w-product-designer-designer .prodDesignerType','display','flex','','','.w-product-designer-designer'),(925285,'printshop','.w-press-reviews-widgets-press-reviews .image a','display','block','','','.w-press-reviews-widgets-press-reviews'),(925286,'printshop','.w-press-reviews-widgets-press-reviews .item','display','block','','','.w-press-reviews-widgets-press-reviews'),(925287,'printshop','.w-press-reviews-widgets-press-reviews .review-box','display','flex','','','.w-press-reviews-widgets-press-reviews'),(925288,'printshop','.w-press-reviews-widgets-press-reviews .title a','display','block','','','.w-press-reviews-widgets-press-reviews'),(925289,'printshop','.w-press-reviews-widgets-press-reviews-list .item','display','flex','','','.w-press-reviews-widgets-press-reviews-list'),(925290,'printshop','.w-press-reviews-widgets-press-reviews-list .review-box','display','flex','','','.w-press-reviews-widgets-press-reviews-list'),(925291,'printshop','.b-products-listing .productGroup label','display','inline-block','','','.b-products-listing'),(925292,'printshop','.b-products-listing .productGroup label a','display','block','','','.b-products-listing'),(925293,'printshop','.w-gift-wrap-message-checkout .max-counter, .w-gift-wrap-message-checkout .max-words','display','inline-block','','','.w-gift-wrap-message-checkout'),(925294,'printshop','.w-communication-post .btn.refresh input','display','none','','','.w-communication-post'),(925295,'printshop','.w-rma-returns-history .column','display','flex','','','.w-rma-returns-history'),(925296,'printshop','.w-rma-returns-history .column .fromTo','display','flex','','','.w-rma-returns-history'),(925297,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','display','inline-block','','','.w-rma-returns-history'),(925298,'printshop','.w-rma-returns-history .filterMessages','display','flex','','','.w-rma-returns-history'),(925299,'printshop','.w-rma-returns-history .fromTo label','display','inline-block','','','.w-rma-returns-history'),(925300,'printshop','.w-rma-returns-history .fromTo label >span','display','block','','','.w-rma-returns-history'),(925301,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul','display','flex','','','.b-menu-position'),(925302,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(925303,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul','display','flex','','','.b-menu-position'),(925304,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(925305,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul','display','flex','','','.b-menu-position'),(925306,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(925307,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > ul','display','none','','','.b-menu-lev_vis-click_icon'),(925308,'printshop','.w-show-inactive-show-inactive .out_stock_wrap','display','flex','','','.w-show-inactive-show-inactive'),(925309,'printshop','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(925310,'printshop','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(925311,'printshop','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(925312,'printshop','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(925313,'printshop','.w-product-configurator .item-content','display','block','5333','','.w-product-configurator'),(925314,'printshop','.w-product-configurator .item-content > div','display','block','5333','','.w-product-configurator'),(925315,'printshop','.w-product-configurator .pc-item label','display','block','','','.w-product-configurator'),(925316,'printshop','.b-products-listing .products-listing .bonus-points-cost','display','inline-block','','','.b-products-listing'),(925317,'printshop','.b-products-listing .promo-icon','display','inline-block','','','.b-products-listing'),(925318,'printshop','.b-products-listing .promos-info .promo-name','display','inline-block','','','.b-products-listing'),(925319,'printshop','.b-products-listing .promos-info .promo-name-span','display','block','','','.b-products-listing'),(925320,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-list'),(925321,'printshop','.w-predefined-promotion .heading-3','display','inline-block','','','.w-predefined-promotion'),(925322,'printshop','.w-predefined-promotion .icon','display','inline-block','','','.w-predefined-promotion'),(925323,'printshop','.w-predefined-promotion .nextdiscount .content','display','grid','','','.w-predefined-promotion'),(925324,'printshop','.w-predefined-promotion .nextdiscount .item-holder','display','flex','','','.w-predefined-promotion'),(925325,'printshop','.w-predefined-promotion .nextdiscount .promo-for-each','display','inline-block','','','.w-predefined-promotion'),(925326,'printshop','.w-predefined-promotion .prom-multi-discount','display','block','4','','.w-predefined-promotion'),(925327,'printshop','.w-predefined-promotion .prom-multi-discount .list','display','grid','','','.w-predefined-promotion'),(925328,'printshop','.w-predefined-promotion .prom-multi-discount .products','display','grid','','','.w-predefined-promotion'),(925329,'printshop','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','display','block','','','.w-predefined-promotion'),(925330,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','display','inline-block','','','.w-predefined-promotion'),(925331,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range > div','display','inline-block','','','.w-predefined-promotion'),(925332,'printshop','.w-predefined-promotion .promo-cart-discount','display','flex','','','.w-predefined-promotion'),(925333,'printshop','.w-predefined-promotion .promo-cart-discount .content','display','flex','','','.w-predefined-promotion'),(925334,'printshop','.w-predefined-promotion .promo-cart-discount .item a','display','block','','','.w-predefined-promotion'),(925335,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','display','inline-block','','','.w-predefined-promotion'),(925336,'printshop','.w-predefined-promotion .promo-cart-discount .slave','display','flex','','','.w-predefined-promotion'),(925337,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','display','inline-block','','','.w-predefined-promotion'),(925338,'printshop','.w-predefined-promotion .promo-content > .personalgift','display','none','','','.w-predefined-promotion'),(925339,'printshop','.w-predefined-promotion .promo-date > div','display','inline-block','','','.w-predefined-promotion'),(925340,'printshop','.w-predefined-promotion .promo-salemaker','display','flex','','','.w-predefined-promotion'),(925341,'printshop','.w-predefined-promotion .promo-salemaker .content','display','flex','','','.w-predefined-promotion'),(925342,'printshop','.w-predefined-promotion .promo-salemaker .content a.name','display','block','','','.w-predefined-promotion'),(925343,'printshop','.w-predefined-promotion .promo-salemaker .discount','display','inline-block','','','.w-predefined-promotion'),(925344,'printshop','.w-supplier-purchase-supplier-products .item','display','flex','','','.w-supplier-purchase-supplier-products'),(925345,'printshop','.w-supplier-purchase-supplier-products .qty_col','display','flex','','','.w-supplier-purchase-supplier-products'),(925352,'printshop','.heading-1','display','block','4','',''),(925353,'printshop','h1','display','block','4','',''),(925354,'printshop','.w-categories .categories','display','flex','','','.w-categories'),(925355,'printshop','.w-product-name h1','display','none','4','','.w-product-name'),(925356,'printshop','.b-quantity .qty-box','display','inline-block','','','.b-quantity'),(925357,'printshop','.w-cart-listing .headings','display','none','','','.w-cart-listing'),(925358,'printshop','.w-cart-listing .item','display','grid','','','.w-cart-listing'),(925359,'printshop','.w-cart-listing .name a','display','inline-block','','','.w-cart-listing'),(925360,'printshop','.w-cart-listing .remove-btn','display','inline-block','3','','.w-cart-listing'),(925361,'printshop','.w-cart-listing .remove-btn span','display','inline-block','','','.w-cart-listing'),(925362,'printshop','.tripleLine .banner','display','flex','','','.tripleLine'),(925363,'printshop','.cartTitle >div','display','block','4','','.cartTitle'),(925365,'printshop','.bottomBanner .icon-box','display','flex','','','.bottomBanner'),(925366,'printshop','.bottomBanner .icon-box > div','display','block','3','','.bottomBanner'),(925368,'printshop','.b-menu-open_from-top .menu-style[data-open_from=\"top\"] .menu-content','display','block','','','.b-menu-open_from-top'),(925369,'printshop','.doubleBanner .descr','display','none','5363','','.doubleBanner'),(925370,'printshop','.middleBanner .descr','display','none','5333','','.middleBanner'),(925371,'printshop','.bottomBanner .descr','display','none','5342','','.bottomBanner'),(925372,'printshop','.bottomBanner .icon-box','display','none','5333','','.bottomBanner'),(925373,'printshop','.tripleLine .text-banner-2 > div br','display','none','5363','','.tripleLine'),(925374,'printshop','.w-neighbour-checkout .neighbour-box','display','block','4','','.w-neighbour-checkout'),(925375,'printshop','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(925376,'printshop','.p-payer-order-pay .heading-2.prod-ico','display','none','3','','.p-payer-order-pay'),(925377,'printshop','.p-payer-order-pay .heading-2.prod-ico','display','none','4','','.p-payer-order-pay'),(925378,'printshop','.p-payer-order-pay .price-row','display','flex','','','.p-payer-order-pay'),(925379,'printshop','.p-payer-order-confirmation .heading-2.prod-ico','display','none','3','','.p-payer-order-confirmation'),(925380,'printshop','.p-payer-order-confirmation .heading-2.prod-ico','display','none','4','','.p-payer-order-confirmation'),(925381,'printshop','.p-payer-order-confirmation .price-row','display','flex','','','.p-payer-order-confirmation'),(925382,'printshop','.tripleLine ','display','none','5363','','.tripleLine'),(925383,'printshop','.w-catalog-listing-look ','display','none','5342','','.w-catalog-listing-look'),(925384,'printshop','.w-product-quantity .qty-input label','display','none','','','.w-product-quantity'),(925385,'printshop','.b-products-listing .products-listing .compare input + span','display','inline-block','5342','','.b-products-listing'),(925386,'printshop','.w-cart-listing .remove-btn','display','block','','','.w-cart-listing'),(925387,'printshop','.topBanner .ourPick','display','inline-block','','','.topBanner'),(925388,'printshop','.topBanner .ourPick > span','display','block','','','.topBanner'),(925389,'printshop','.topBanner .content .btn','display','none','5363,4','','.topBanner'),(925390,'printshop','.topBanner .content','display','table-cell','','','.topBanner'),(925391,'printshop','.topBanner .banner-text-holder','display','table','','','.topBanner'),(925392,'printshop','.w-promotions-widgets-promotion-icons-desc .w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','display','flex','','','.w-promotions-widgets-promotion-icons-desc'),(925393,'printshop','.tripleLine .banner-text-holder > div br','display','none','5363','','.tripleLine'),(925394,'printshop','.tripleLine .banner-holder','display','flex','','','.tripleLine'),(925395,'printshop','.order-summary .checkout-cart-listing.main-listing','display','none','','','.order-summary'),(925396,'printshop','.order-summary .icon','display','block','','','.order-summary'),(925397,'printshop','.order-summary .price-box .price-row.total','display','flex','','','.order-summary'),(925398,'printshop','.order-summary .price-row','display','flex','2','','.order-summary'),(925399,'printshop','.order-summary .top-totals .price-box .price-row.total','display','none','','','.order-summary'),(925400,'printshop','.order-summary .top-totals .price-row','display','flex','2','','.order-summary'),(925401,'printshop','.order-summary .w-cart-listing .item .points','display','none','','','.order-summary'),(925402,'printshop','.order-summary .w-cart-listing .item > div.image','display','none','','','.order-summary'),(925403,'printshop','.w-cart-listing .item div.price small','display','block','','','.w-cart-listing'),(925404,'printshop','.w-cart-discount-coupon .title','display','inline-block','4','','.w-cart-discount-coupon'),(925405,'printshop','.w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp','display','flex','','','.w-cart-discount-coupon'),(925406,'printshop','.w-cart-shipping-estimator .left-area','display','block','5363,4','','.w-cart-shipping-estimator'),(925407,'printshop','.w-cart-shipping-estimator .left-area .col-right > span:nth-child(1)','display','none','5363','','.w-cart-shipping-estimator'),(925408,'printshop','.w-cart-shipping-estimator .left-area .col-right > span:nth-child(1) + br','display','none','5363','','.w-cart-shipping-estimator'),(925409,'printshop','.w-cart-checkout-btn .with-card','display','inline-block','4','','.w-cart-checkout-btn'),(925410,'printshop','.w-checkout-continue-btn .button-hide','display','none','','','.w-checkout-continue-btn'),(925411,'printshop','.w-checkout-continue-btn .or-text','display','none','','','.w-checkout-continue-btn'),(925412,'printshop','.p-quote-checkout-index .edit-address-popup .address-item > label','display','block','','','.p-quote-checkout-index'),(925413,'printshop','.p-quote-checkout-index .edit-address-popup .addresses','display','flex','','','.p-quote-checkout-index'),(925414,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons','display','flex','','','.p-quote-checkout-index'),(925415,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons','display','none','4','','.p-quote-checkout-index'),(925416,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','display','inline-block','','','.p-quote-checkout-index'),(925417,'printshop','.p-quote-checkout-index .edit-address-popup .addresses.address-edit-holder','display','block','','','.p-quote-checkout-index'),(925418,'printshop','.p-quote-checkout-index .order-summary .icon','display','none','','','.p-quote-checkout-index'),(925456,'printshop','.account-order-pay .history_attr','display','table','','','.account-order-pay'),(925457,'printshop','.account-order-pay .history_attr div','display','table-row','','','.account-order-pay'),(925458,'printshop','.account-order-pay .history_attr div strong, .account-order-pay .history_attr div span','display','table-cell','','','.account-order-pay'),(925459,'printshop','.account-samples .orders-table .hidden','display','none','','','.account-samples'),(925460,'printshop','.account-samples .short-date','display','none','','','.account-samples'),(925461,'printshop','.account-samples .view_link','display','inline-block','4','','.account-samples'),(925462,'printshop','.account-samples .orders-table .headings','display','none','5342','','.account-samples'),(925463,'printshop','.account-samples .orders-table .hidden','display','inline-block','5342','','.account-samples'),(925464,'printshop','.account-samples .orders-table .item','display','block','5342','','.account-samples'),(925465,'printshop','.account-samples .orders-table .item td','display','block','5342','','.account-samples'),(925466,'printshop','.account-samples .orders-table td.name','display','none','5342','','.account-samples'),(925467,'printshop','.account-samples .orders-table, .account-samples .orders-table tbody','display','block','5342','','.account-samples'),(925468,'printshop','.account-sample-info .history_attr','display','table','','','.account-sample-info'),(925469,'printshop','.account-sample-info .history_attr div','display','table-row','','','.account-sample-info'),(925470,'printshop','.account-sample-info .history_attr div strong, .account-sample-info .history_attr div span','display','table-cell','','','.account-sample-info'),(925471,'printshop','.account-sample-info .popup-tracking-number a','display','block','','','.account-sample-info'),(925472,'printshop','.account-sample-info .popup-tracking-number-link','display','block','','','.account-sample-info'),(925473,'printshop','.catalog-product-wrap .pn-image','display','inline-block','3','','.catalog-product-wrap'),(925474,'printshop','.catalog-product-wrap .pn-price','display','none','','','.catalog-product-wrap'),(925475,'printshop','.catalog-product-wrap .prev-next-product','display','none','','','.catalog-product-wrap'),(925476,'printshop','.catalog-product-wrap .prev-next-product > span','display','block','','','.catalog-product-wrap'),(925477,'printshop','.catalog-product-wrap .pn-image img','display','none','5342','','.catalog-product-wrap'),(925478,'printshop','.catalog-product-wrap .pn-name','display','none','5342','','.catalog-product-wrap'),(925479,'printshop','.shopping-cart-index .cart-popup .gift-wrap','display','none','','','.shopping-cart-index'),(925480,'printshop','.shopping-cart-index .order-summary .bottom-totals .icon','display','none','','','.shopping-cart-index'),(925481,'printshop','.shopping-cart-index .order-summary .bottom-totals .price-box .price-row.total','display','flex','','','.shopping-cart-index'),(925482,'printshop','.shopping-cart-index .order-summary .bottom-totals .price-row','display','none','2','','.shopping-cart-index'),(925483,'printshop','.shopping-cart-index .gift-code .heading-4 ~ *','display','none','5333','','.shopping-cart-index'),(925484,'printshop','.checkout-index-wrap .edit-address-popup .address-item > label','display','block','','','.checkout-index-wrap'),(925485,'printshop','.checkout-index-wrap .edit-address-popup .addresses','display','flex','','','.checkout-index-wrap'),(925486,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons','display','flex','','','.checkout-index-wrap'),(925487,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons','display','none','4','','.checkout-index-wrap'),(925488,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','display','inline-block','','','.checkout-index-wrap'),(925489,'printshop','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','display','block','','','.checkout-index-wrap'),(925490,'printshop','.checkout-index-wrap .hiding-box .checkout-cart-listing.summary-listing','display','none','','','.checkout-index-wrap'),(925491,'printshop','.checkout-order-confirmation .heading-2.prod-ico','display','none','3','','.checkout-order-confirmation'),(925492,'printshop','.checkout-order-confirmation .heading-2.prod-ico','display','none','4','','.checkout-order-confirmation'),(925493,'printshop','.checkout-order-confirmation .price-row','display','flex','','','.checkout-order-confirmation'),(925494,'printshop','.checkout-success-wrap .page-success .text-1','display','block','3','','.checkout-success-wrap'),(925495,'printshop','.checkout-success-wrap .w-success-continue-btn','display','block','5363','','.checkout-success-wrap'),(925496,'printshop','.checkout-success-wrap .w-success-print-btn','display','block','5363','','.checkout-success-wrap'),(925497,'printshop','.index-wrap .heading-2','display','block','4','','.index-wrap'),(925498,'printshop','.index-wrap h2','display','block','4','','.index-wrap'),(925499,'printshop','.b-form .middle-form form','display','flex','','','.b-form'),(925500,'printshop','.b-form .addresses','display','block','4','','.b-form'),(925501,'printshop','.b-form .columns','display','flex','','','.b-form'),(925502,'printshop','.b-slick .slick-dots','display','flex','','','.b-slick'),(925503,'printshop','.b-slick .slick-dots li','display','block','3','','.b-slick'),(925504,'printshop','.b-slick .slick-dots button','display','none','','','.b-slick'),(925505,'printshop','.hide-page','display','flex','','',''),(925508,'printshop','.success-page .check-ico-block','display','block','3','','.success-page'),(925509,'printshop','.success-page .order_totals .price-row','display','flex','','','.success-page'),(925510,'printshop','.success-page .page-success .text-1','display','inline-block','3','','.success-page'),(925511,'printshop','.success-page .price-row','display','flex','','','.success-page'),(925512,'printshop','.w-checkout-totals .price-row','display','flex','','','.w-checkout-totals'),(925513,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-content','display','block','4','','.b-multi-page-checkout'),(925514,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','display','inline-block','','','.b-multi-page-checkout'),(925515,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .edit','display','none','','','.b-multi-page-checkout'),(925516,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading > .block','display','inline-block','','','.b-multi-page-checkout'),(925517,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','display','inline-block','3','','.b-multi-page-checkout'),(925518,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .count','display','none','','','.b-multi-page-checkout'),(925519,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','block','','','.b-multi-page-checkout'),(925520,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','inline-block','4','','.b-multi-page-checkout'),(925521,'printshop','.b-form .formWrapBox','display','flex','','','.b-form'),(925523,'printshop','.doubleBanner .w-banner .banner-holder','display','flex','','','.doubleBanner'),(925524,'printshop','.bottomDoubleBanner .w-banner .banner-holder','display','flex','','','.bottomDoubleBanner'),(925525,'printshop','.w-checkout-totals div.price-row','display','none','','','.w-checkout-totals'),(925526,'printshop','.w-checkout-totals div.price-row','display','flex','2','','.w-checkout-totals'),(925527,'printshop','.b-form .addresses .address-item .edit-ab','display','block','','','.b-form'),(925528,'printshop','.b-form .ui-helper-hidden-accessible','display','none','','','.b-form'),(925529,'printshop','.w-login-register .middle-form form','display','flex','','','.w-login-register'),(925530,'printshop','.w-login-returning .middle-form form','display','flex','','','.w-login-returning'),(925531,'printshop','.w-product-reviews .middle-form form','display','flex','','','.w-product-reviews'),(925534,'printshop','.footer-menu .level-1','display','flex','','','.footer-menu'),(925535,'printshop','.footer-menu .level-1 > li > a, .footer-menu .level-1 > li > .no-link','display','block','','','.footer-menu'),(925536,'printshop','.footer-menu .level-1 > li > .no-link','display','block','5342','','.footer-menu'),(925537,'printshop','.w-bestsellers .counter','display','inline-block','','','.w-bestsellers'),(925538,'printshop','.payment-method-tf label','display','block','','','.payment-method-tf'),(925539,'printshop','.w-account-customer-additional-field .field-type-checkbox label','display','inline-block','','','.w-account-customer-additional-field'),(925540,'printshop','.w-account-customer-additional-field .field-type-text','display','flex','','','.w-account-customer-additional-field'),(925541,'printshop','.w-banner .banner-item','display','grid','','','.w-banner'),(925542,'printshop','.w-banner .banner-text','display','flex','','','.w-banner'),(925543,'printshop','.w-banner .carousel-text','display','flex','','','.w-banner'),(925544,'printshop','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','display','table','','','.w-banner'),(925545,'printshop','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','display','table-cell','','','.w-banner'),(925546,'printshop','.w-banner .sliderItems a + a, .w-banner .sliderItems a + img, .w-banner .sliderItems img + a, .w-banner .sliderItems img + img','display','none','','','.w-banner'),(925547,'printshop','.w-catalog-paging ','display','inline-block','2','','.w-catalog-paging'),(925548,'printshop','.w-catalog-paging .next','display','inline-block','','','.w-catalog-paging'),(925549,'printshop','.w-catalog-paging .next-pages','display','inline-block','','','.w-catalog-paging'),(925550,'printshop','.w-catalog-paging .page-number','display','inline-block','','','.w-catalog-paging'),(925551,'printshop','.w-catalog-paging .paging','display','inline-block','','','.w-catalog-paging'),(925552,'printshop','.w-catalog-paging .paging-holder','display','inline-block','','','.w-catalog-paging'),(925553,'printshop','.w-catalog-paging .paging-item','display','inline-block','','','.w-catalog-paging'),(925554,'printshop','.w-catalog-paging .prev','display','inline-block','','','.w-catalog-paging'),(925555,'printshop','.w-catalog-paging .prev-pages','display','inline-block','','','.w-catalog-paging'),(925557,'printshop','.w-sale .btn','display','block','','','.w-sale'),(925558,'printshop','.w-sale .left-count','display','block','','','.w-sale'),(925559,'printshop','.w-sale .left-count-days','display','block','','','.w-sale'),(925560,'printshop','.w-sale .left-count-hours','display','block','','','.w-sale'),(925561,'printshop','.w-sale .left-text-left','display','block','','','.w-sale'),(925562,'printshop','.w-sale .left-text-right','display','block','','','.w-sale'),(925563,'printshop','.w-sale .special-price','display','block','','','.w-sale'),(925564,'printshop','.w-sale .special-price-text','display','none','','','.w-sale'),(925565,'printshop','.w-sale .text','display','block','','','.w-sale'),(925566,'printshop','.w-social-links a','display','inline-block','','','.w-social-links'),(925567,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display_important','important','','','.b-switch'),(925568,'printshop','.w-menu-horizontal ul ul li','display_important','important','','','.w-menu-horizontal'),(925569,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display_important','important','','','.b-switch'),(925572,'printshop','.w-filters .filter-box-content ul li.view_items','display_important','important','','','.w-filters'),(925573,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display_important','important','','','.b-menu-open_from-left'),(925574,'printshop','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display_important','important','','','.b-menu-style'),(925575,'printshop','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display_important','important','','','.b-menu-style'),(925576,'printshop','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display_important','important','','','.b-menu-style'),(925577,'printshop','.b-products-listing .products-listing.slick-slider .item-nav','display_important','important','','','.b-products-listing'),(925578,'printshop','.w-quote .cart-box.hover-box:hover .cart-content','display_important','important','','','.w-quote'),(925579,'printshop','.w-sample .cart-box:hover .cart-content','display_important','important','','','.w-sample'),(925580,'printshop','.w-cart-listing .remove-btn span','display_important','important','','','.w-cart-listing'),(925581,'printshop','.b-menu-open_from-top .menu-style[data-open_from=\"top\"] .menu-content','display_important','important','','','.b-menu-open_from-top'),(925582,'printshop','.order-summary .icon','display_important','important','','','.order-summary'),(925583,'printshop','.p-quote-checkout-index .order-summary .icon','display_important','important','','','.p-quote-checkout-index'),(925584,'printshop','.catalog-product-wrap .pn-price','display_important','important','','','.catalog-product-wrap'),(925585,'printshop','.catalog-product-wrap .pn-name','display_important','important','5342','','.catalog-product-wrap'),(925586,'printshop','.shopping-cart-index .order-summary .bottom-totals .icon','display_important','important','','','.shopping-cart-index'),(925587,'printshop','.checkout-success-wrap .w-success-continue-btn','display_important','important','5363','','.checkout-success-wrap'),(925588,'printshop','.checkout-success-wrap .w-success-print-btn','display_important','important','5363','','.checkout-success-wrap'),(925589,'printshop','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','fill','rgba(255, 255, 255, 0)','','','.w-image-maps'),(925590,'printshop','.w-image-maps polygon:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(925591,'printshop','.w-image-maps rect:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(925592,'printshop','.w-image-maps circle:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(925593,'printshop','.w-image-maps rect.no-items, .w-image-maps circle.no-items, .w-image-maps polygon.no-items','fill','rgba(150, 150, 150, 0.7)','','','.w-image-maps'),(925594,'printshop','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','filter','alpha(opacity=0)','','','.b-switch'),(925595,'printshop','.b-select-suggest .select2-container .select2-choice','filter','progid','','','.b-select-suggest'),(925596,'printshop','.b-select-suggest .select2-container.select2-drop-above .select2-choice','filter','progid','','','.b-select-suggest'),(925597,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','filter','alpha(opacity=50)','','','.b-switch'),(925598,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','filter','alpha(opacity=50)','','','.b-switch'),(925599,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','filter','progid','','','.b-select-suggest'),(925600,'printshop','.b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choice, .b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choices','filter','progid','','','.b-select-suggest'),(925601,'printshop','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','filter','none','','','.b-select-suggest'),(925602,'printshop','.b-select-suggest .select2-dropdown-open .select2-choice','filter','progid','','','.b-select-suggest'),(925603,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow','filter','progid','','','.b-select-suggest'),(925604,'printshop','.b-select-suggest .select2-drop-mask','filter','alpha(opacity=0)','','','.b-select-suggest'),(925605,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','filter','alpha(opacity=50)','','','.b-switch'),(925606,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-basis','0','','','.b-menu-position'),(925607,'printshop','.w-promotions .promo-cart-discount .slave','flex-direction','column','','','.w-promotions'),(925608,'printshop','.w-catalog-compare .cross-box','flex-direction','column','','','.w-catalog-compare'),(925609,'printshop','.tripleBanner ','flex-direction','column','5342','','.tripleBanner'),(925610,'printshop','.w-files-catalog-widgets-files-catalog .item','flex-direction','column','','','.w-files-catalog-widgets-files-catalog'),(925611,'printshop','.b-products-listing .products-listing .attribute-qty-block','flex-direction','column','','','.b-products-listing'),(925612,'printshop','.w-product-designer-designer .prodDesignerType','flex-direction','row','','','.w-product-designer-designer'),(925613,'printshop','.w-press-reviews-widgets-press-reviews-list .item','flex-direction','column','','','.w-press-reviews-widgets-press-reviews-list'),(925614,'printshop','.w-rma-returns-history .column','flex-direction','column','','','.w-rma-returns-history'),(925615,'printshop','.w-rma-returns-history .filterMessages','flex-direction','column','','screen and (max-width: 768px)','.w-rma-returns-history'),(925616,'printshop','.w-predefined-promotion .promo-cart-discount .slave','flex-direction','column','','','.w-predefined-promotion'),(925617,'printshop','.tripleLine .banner','flex-direction','column','5363','','.tripleLine'),(925618,'printshop','.w-account-personal-catalog .buy-box','flex-direction','column','5363','','.w-account-personal-catalog'),(925619,'printshop','.tripleLine .banner-holder','flex-direction','column','5363','','.tripleLine'),(925621,'printshop','.doubleBanner .w-banner .banner-holder','flex-direction','column','5363','','.doubleBanner'),(925622,'printshop','.bottomDoubleBanner .w-banner .banner-holder','flex-direction','column','5363','','.bottomDoubleBanner'),(925623,'printshop','.footer-menu .level-1','flex-direction','row','','','.footer-menu'),(925624,'printshop','.footer-menu .level-1','flex-direction','column','5333','','.footer-menu'),(925625,'printshop','.p-wedding-registry-search .search-form > div','flex-grow','2','','','.p-wedding-registry-search'),(925626,'printshop','.b-messages .email-line > div','flex-grow','1','','','.b-messages'),(925627,'printshop','.w-promotions .prom-multi-discount .promo-product, .w-promotions .prom-multi-discount .promo-category-item','flex-grow','1','','','.w-promotions'),(925628,'printshop','.p-wedding-registry-search #searchform-status label','flex-grow','1','','','.p-wedding-registry-search'),(925629,'printshop','.w-cart-listing .item .gift-wrap .value','flex-grow','1','','','.w-cart-listing'),(925630,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-grow','1','','','.b-menu-position'),(925631,'printshop','.w-account-personal-catalog .list-switcher a','flex-grow','1','','','.w-account-personal-catalog'),(925632,'printshop','.w-account-subscription .title','flex-grow','1','','','.w-account-subscription'),(925633,'printshop','.w-catalog-compare .product-listing > div','flex-grow','1','','','.w-catalog-compare'),(925634,'printshop','.w-delivery-day .time-left > span','flex-grow','1','','','.w-delivery-day'),(925635,'printshop','.w-files-catalog-widgets-files-catalog .image','flex-grow','1','','','.w-files-catalog-widgets-files-catalog'),(925636,'printshop','.w-filters-simple .system-1','flex-grow','1','','','.w-filters-simple'),(925637,'printshop','.w-predefined-promotion .prom-multi-discount .promo-product, .w-predefined-promotion .prom-multi-discount .promo-category-item','flex-grow','1','','','.w-predefined-promotion'),(925639,'printshop','.footer-menu .level-1 > li','flex-grow','1','','','.footer-menu'),(925640,'printshop','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-grow','1','','','.w-account-customer-additional-field'),(925641,'printshop','.w-account-customer-additional-field .field-type-text label','flex-grow','1','','','.w-account-customer-additional-field'),(925642,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','flex-shrink','0','','','.w-upload-customer-id-upload-customer-id-form'),(925643,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-shrink','1','','','.b-menu-position'),(925644,'printshop','.w-catalog-compare .cross-box','flex-shrink','0','','','.w-catalog-compare'),(925645,'printshop','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-shrink','0','','','.w-account-customer-additional-field'),(925646,'printshop','.w-account-customer-additional-field .field-type-text label','flex-shrink','0','','','.w-account-customer-additional-field'),(925647,'printshop','.w-promotions .promo-cart-discount .content','flex-wrap','wrap','','','.w-promotions'),(925648,'printshop','.w-promotions .promo-salemaker .content','flex-wrap','wrap','','','.w-promotions'),(925649,'printshop','.b-products-listing .products-listing .attribute-qty-blocks','flex-wrap','wrap','','','.b-products-listing'),(925650,'printshop','.w-top-categories .categories','flex-wrap','wrap','','','.w-top-categories'),(925651,'printshop','.w-files-catalog-widgets-files-catalog ','flex-wrap','wrap','','','.w-files-catalog-widgets-files-catalog'),(925652,'printshop','.w-product-bundle .bundle-products','flex-wrap','wrap','','','.w-product-bundle'),(925653,'printshop','.w-product-in-bundles .bundle-products','flex-wrap','wrap','','','.w-product-in-bundles'),(925655,'printshop','.w-product-properties-icons ','flex-wrap','wrap','','','.w-product-properties-icons'),(925656,'printshop','.w-delivery-location-product-categories .categories','flex-wrap','wrap','','','.w-delivery-location-product-categories'),(925657,'printshop','.w-product-designer-designer .prodDesignerType','flex-wrap','wrap','','','.w-product-designer-designer'),(925658,'printshop','.w-press-reviews-widgets-press-reviews .sub-box','flex-wrap','wrap','','','.w-press-reviews-widgets-press-reviews'),(925659,'printshop','.w-press-reviews-widgets-press-reviews-list .review-box > *','flex-wrap','wrap','','','.w-press-reviews-widgets-press-reviews-list'),(925660,'printshop','.w-press-reviews-widgets-press-reviews-list .review-box','flex-wrap','wrap','5363','','.w-press-reviews-widgets-press-reviews-list'),(925661,'printshop','.w-predefined-promotion .promo-cart-discount .content','flex-wrap','wrap','','','.w-predefined-promotion'),(925662,'printshop','.w-predefined-promotion .promo-salemaker .content','flex-wrap','wrap','','','.w-predefined-promotion'),(925663,'printshop','.w-categories .categories','flex-wrap','wrap','','','.w-categories'),(925664,'printshop','.p-quote-checkout-index .edit-address-popup .addresses','flex-wrap','wrap','','','.p-quote-checkout-index'),(925665,'printshop','.checkout-index-wrap .edit-address-popup .addresses','flex-wrap','wrap','','','.checkout-index-wrap'),(925666,'printshop','.b-form .middle-form form','flex-wrap','wrap','','','.b-form'),(925667,'printshop','.b-form .columns','flex-wrap','wrap','','','.b-form'),(925668,'printshop','.b-form .formWrapBox','flex-wrap','wrap','','','.b-form'),(925669,'printshop','.heading-4 .right-text, h4 .right-text','float','right','','',''),(925670,'printshop','.w-checkout-billing-address .btn-cancel','float','left','','','.w-checkout-billing-address'),(925671,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(925672,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(925674,'printshop','.w-socials .post_item_img','float','left','','','.w-socials'),(925677,'printshop','.w-brands .brands-listing > div','float','left','','','.w-brands'),(925678,'printshop','.w-cart-shipping-estimator .left-area','float','left','','','.w-cart-shipping-estimator'),(925679,'printshop','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(925680,'printshop','.b-messages .msv_btn .btn','float','right','','','.b-messages'),(925681,'printshop','.b-messages .messages-menu li span','float','right','','','.b-messages'),(925682,'printshop','.w-checkout-shipping-address .btn-cancel','float','left','','','.w-checkout-shipping-address'),(925683,'printshop','.w-login-block .guest','float','right','','','.w-login-block'),(925684,'printshop','.b-compare .col-two label, .b-compare .col-two select','float','left','','','.b-compare'),(925685,'printshop','.b-info .info','float','left','3','','.b-info'),(925686,'printshop','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(925687,'printshop','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(925688,'printshop','.w-login-block .guest','float','right','','','.w-login-block'),(925689,'printshop','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(925690,'printshop','.w-login-block .returning','float','left','','','.w-login-block'),(925691,'printshop','.w-login-block .new','float','right','','','.w-login-block'),(925692,'printshop','.w-menu-horizontal li','float','none','','','.w-menu-horizontal'),(925693,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(925694,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(925695,'printshop','.b-info .info','float','left','3','','.b-info'),(925696,'printshop','.b-bottom .closeable-heading','float','right','3','','.b-bottom'),(925697,'printshop','.b-form .col-3','float','left','','','.b-form'),(925698,'printshop','.w-checkout-contact-information .btn-save','float','right','','','.w-checkout-contact-information'),(925699,'printshop','.b-form .terms-login .bootstrap-switch','float','right','','','.b-form'),(925700,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(925703,'printshop','.buttons .right-buttons','float','right','','',''),(925704,'printshop','.buttons .left-buttons','float','left','','',''),(925705,'printshop','.w-login-block .returning','float','left','','','.w-login-block'),(925706,'printshop','.w-brands .brands-listing > div','float','left','','','.w-brands'),(925707,'printshop','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(925708,'printshop','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(925710,'printshop','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(925711,'printshop','.message.success','float','left','3','',''),(925712,'printshop','.w-socials > li','float','left','','','.w-socials'),(925713,'printshop','.w-socials .post_item_img','float','left','','','.w-socials'),(925714,'printshop','.w-checkout-billing-address .add-ab','float','left','','','.w-checkout-billing-address'),(925715,'printshop','.w-cart-listing .right-area','float','none','5342','','.w-cart-listing'),(925716,'printshop','.w-checkout-shipping-address .add-ab','float','left','','','.w-checkout-shipping-address'),(925717,'printshop','.w-socials > li','float','left','','','.w-socials'),(925718,'printshop','.w-socials .post_item_img','float','left','','','.w-socials'),(925719,'printshop','.w-socials > li','float','left','','','.w-socials'),(925720,'printshop','.b-info .info','float','left','3','','.b-info'),(925721,'printshop','.b-form .addresses .address-item input[type=\"radio\"]','float','left','','','.b-form'),(925722,'printshop','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(925723,'printshop','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(925724,'printshop','.w-socials > li','float','left','','','.w-socials'),(925725,'printshop','.heading-4 .edit, h4 .edit','float','right','','',''),(925726,'printshop','.w-login-block .returning','float','left','','','.w-login-block'),(925728,'printshop','.b-info-popup .password-info .info-popup','float','right','','','.b-info-popup'),(925729,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(925730,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(925731,'printshop','.heading-3 .right-text, h3 .right-text','float','right','','',''),(925732,'printshop','.heading-3 .edit, h3 .edit','float','right','','',''),(925733,'printshop','.b-info .info','float','left','3','','.b-info'),(925734,'printshop','.w-socials .post_item_img','float','left','','','.w-socials'),(925736,'printshop','.w-checkout-billing-address .addresses .address-item','float','left','','','.w-checkout-billing-address'),(925737,'printshop','.w-list-b2b .select-attributes','float','left','','','.w-list-b2b'),(925738,'printshop','.w-socials .post_item_img','float','left','','','.w-socials'),(925739,'printshop','.edit-link','float','right','','',''),(925742,'printshop','.w-socials > li','float','left','','','.w-socials'),(925743,'printshop','.b-info .info','float','left','3','','.b-info'),(925744,'printshop','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(925745,'printshop','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(925746,'printshop','.w-promo-code .btn','float','right','','','.w-promo-code'),(925747,'printshop','.b-form .shipping-method .cost','float','right','','','.b-form'),(925748,'printshop','.b-form .shipping-method .input','float','left','','','.b-form'),(925749,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(925750,'printshop','.b-sub-totals .historyTotal table','float','right','','','.b-sub-totals'),(925751,'printshop','.b-info .info','float','left','3','','.b-info'),(925752,'printshop','.w-login-block .returning','float','left','','','.w-login-block'),(925753,'printshop','.w-login-block .guest','float','right','','','.w-login-block'),(925754,'printshop','.w-login-block .new','float','right','','','.w-login-block'),(925755,'printshop','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(925756,'printshop','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(925757,'printshop','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(925758,'printshop','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(925759,'printshop','.b-form .col-right','float','right','','','.b-form'),(925760,'printshop','.b-form .payment-method .item-radio input','float','left','','','.b-form'),(925761,'printshop','.w-cart-listing .actions > div','float','left','','','.w-cart-listing'),(925762,'printshop','.w-login-block .guest','float','right','','','.w-login-block'),(925763,'printshop','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(925764,'printshop','.w-login-block .new','float','right','','','.w-login-block'),(925766,'printshop','.w-brands .brands-listing > div','float','left','','','.w-brands'),(925768,'printshop','.w-cart-shipping-estimator .right-area','float','right','','','.w-cart-shipping-estimator'),(925769,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(925770,'printshop','.w-cart-give-away .ga_attributes > div','float','left','','','.w-cart-give-away'),(925771,'printshop','.b-bottom .cart-options .option-item','float','left','','','.b-bottom'),(925772,'printshop','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(925773,'printshop','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(925774,'printshop','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(925775,'printshop','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(925776,'printshop','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(925777,'printshop','.w-list-b2b .select-attributes:nth-child(2n)','float','right','','','.w-list-b2b'),(925778,'printshop','.b-upload-files .remove-file','float','right','','','.b-upload-files'),(925779,'printshop','.w-login-block .new','float','right','','','.w-login-block'),(925780,'printshop','.w-cart-compare .product .image','float','left','','','.w-cart-compare'),(925781,'printshop','.b-form .col-left','float','left','','','.b-form'),(925782,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(925783,'printshop','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(925784,'printshop','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(925785,'printshop','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(925786,'printshop','.b-form .addresses .address-item','float','left','','','.b-form'),(925787,'printshop','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(925788,'printshop','.w-socials > li','float','left','','','.w-socials'),(925789,'printshop','.w-cart-give-away .ga_column','float','left','','','.w-cart-give-away'),(925790,'printshop','.b-select-suggest .select2-container-multi .select2-choices li','float','left','','','.b-select-suggest'),(925791,'printshop','.w-neighbour-checkout .bootstrap-switch','float','right','','','.w-neighbour-checkout'),(925792,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','float','left','3','','.b-warehouses-popup'),(925793,'printshop','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(925799,'printshop','.w-menu-horizontal .box','float','none','','','.w-menu-horizontal'),(925801,'printshop','.w-login-block .new','float','right','','','.w-login-block'),(925802,'printshop','.w-login-block .guest','float','right','','','.w-login-block'),(925803,'printshop','.w-brands .brands-listing > div','float','left','','','.w-brands'),(925805,'printshop','.w-login-block .guest','float','right','','','.w-login-block'),(925807,'printshop','.w-menu-big li','float','none','','','.w-menu-big'),(925808,'printshop','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(925809,'printshop','.w-promo-code .btn','float','right','','','.w-promo-code'),(925810,'printshop','.w-login-block .new','float','right','','','.w-login-block'),(925811,'printshop','.w-account-addresses-list .address-fields input[type=\"radio\"]','float','left','','','.w-account-addresses-list'),(925812,'printshop','.w-account-addresses-list .addsess-suggestion-item','float','left','','','.w-account-addresses-list'),(925813,'printshop','.b-products-listing .products-listing .bonus-points-price','float','left','3','','.b-products-listing'),(925814,'printshop','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','float','right','','','.b-products-listing'),(925815,'printshop','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','float','right','','','.b-products-listing'),(925816,'printshop','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','float','right','','','.b-products-listing'),(925817,'printshop','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','float','right','','','.b-products-listing'),(925818,'printshop','.b-products-listing .BlockBox.type-7 > .col, .b-products-listing .BlockBox.type-8 > .col, .b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col','float','left','','','.b-products-listing'),(925819,'printshop','.b-products-listing .BlockBox.type-2 > .col, .b-products-listing .BlockBox.type-3 > .col, .b-products-listing .BlockBox.type-4 > .col, .b-products-listing .BlockBox.type-5 > .col, .b-products-listing .BlockBox.type-6 > .col','float','left','','','.b-products-listing'),(925820,'printshop','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','float','right','','','.b-products-listing'),(925821,'printshop','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','float','right','','','.b-products-listing'),(925822,'printshop','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','float','right','','','.b-products-listing'),(925823,'printshop','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','float','right','','','.b-products-listing'),(925824,'printshop','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','float','right','','','.b-products-listing'),(925825,'printshop','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','float','right','','','.b-products-listing'),(925826,'printshop','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','float','right','','','.b-products-listing'),(925827,'printshop','.b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col, .b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockB','float','left','','','.b-products-listing'),(925828,'printshop','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','float','right','','','.b-products-listing'),(925829,'printshop','.b-products-listing .products-listing .item','float','none','','','.b-products-listing'),(925830,'printshop','.b-products-listing .products-listing.align-left .item','float','left','','','.b-products-listing'),(925831,'printshop','.b-products-listing .products-listing.align-right .item','float','right','','','.b-products-listing'),(925832,'printshop','.b-products-listing .wedding-registry-count','float','right','','','.b-products-listing'),(925833,'printshop','.w-checkout-gdpr .candlestick-wrapper','float','right','','','.w-checkout-gdpr'),(925834,'printshop','.b-compare .compare-box-btn','float','right','','','.b-compare'),(925835,'printshop','.w-cart-give-away .ga_img','float','left','','','.w-cart-give-away'),(925836,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(925837,'printshop','.w-cart-compare .product-actions','float','right','','','.w-cart-compare'),(925838,'printshop','.w-socials .post_item_img','float','left','','','.w-socials'),(925839,'printshop','.w-promo-code .btn','float','right','','','.w-promo-code'),(925841,'printshop','.w-login-block .returning','float','left','','','.w-login-block'),(925842,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(925843,'printshop','.w-checkout-create-account .newsletter-switcher .bootstrap-switch','float','right','','','.w-checkout-create-account'),(925844,'printshop','.w-checkout-shipping-address .addresses .address-item','float','left','','','.w-checkout-shipping-address'),(925845,'printshop','.w-checkout-create-account .create-account-switcher','float','right','','','.w-checkout-create-account'),(925846,'printshop','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(925847,'printshop','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(925848,'printshop','.w-login-block .returning','float','left','','','.w-login-block'),(925850,'printshop','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(925851,'printshop','.w-promo-code .btn','float','right','','','.w-promo-code'),(925852,'printshop','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(925853,'printshop','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(925854,'printshop','.b-form .columns .col-2','float','left','','','.b-form'),(925855,'printshop','.w-product-cross-sell .buy-all-checker','float','left','','','.w-product-cross-sell'),(925856,'printshop','.w-cart-listing .item > div','float','left','','','.w-cart-listing'),(925857,'printshop','.w-cart-listing .points-redeem','float','left','3','','.w-cart-listing'),(925858,'printshop','.w-cart-listing .right-area','float','left','','','.w-cart-listing'),(925859,'printshop','.w-cart-listing .item .qty','float','right','5342','','.w-cart-listing'),(925860,'printshop','.w-cart-listing .links','float','left','','','.w-cart-listing'),(925861,'printshop','.w-cart-give-away .ga_price .checkBoxWrap','float','right','','','.w-cart-give-away'),(925864,'printshop','.w-brands .brands-listing > div','float','left','','','.w-brands'),(925865,'printshop','.order-summary .btn-2','float','none','5342','','.order-summary'),(925866,'printshop','.w-promo-code .btn','float','right','','','.w-promo-code'),(925870,'printshop','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(925871,'printshop','.w-checkout-billing-address .bootstrap-switch','float','right','','','.w-checkout-billing-address'),(925872,'printshop','.w-brands .brands-listing > div','float','left','','','.w-brands'),(925875,'printshop','.b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockBox.type-14 > .col, .b-products-listing .BlockBox.type-15 > .col, .b-products-listing .BlockBox.type-16 > .col','float','left','','','.b-products-listing'),(925876,'printshop','.w-product-reviews .write-review-button','float','right','','','.w-product-reviews'),(925877,'printshop','.w-promo-code .btn','float','right','','','.w-promo-code'),(925878,'printshop','.w-filters .handle-to','float','right','','','.w-filters'),(925879,'printshop','.w-filters .handle-from','float','left','','','.w-filters'),(925880,'printshop','.w-cart-compare .js-cart_totals_container','float','left','','','.w-cart-compare'),(925881,'printshop','.w-cart-compare .buttons','float','right','','','.w-cart-compare'),(925882,'printshop','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(925883,'printshop','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(925887,'printshop','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(925888,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(925889,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(925890,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(925891,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(925892,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(925893,'printshop','.b-trade-approval .col-right','float','right','','','.b-trade-approval'),(925894,'printshop','.b-trade-approval .col-left','float','left','','','.b-trade-approval'),(925895,'printshop','.b-trade-approval .col-3','float','left','','','.b-trade-approval'),(925896,'printshop','.w-catalog-compare .compare label','float','right','','','.w-catalog-compare'),(925897,'printshop','.w-catalog-compare .buyButton','float','right','','','.w-catalog-compare'),(925898,'printshop','.w-delivery-day .left-count','float','left','','','.w-delivery-day'),(925899,'printshop','.w-delivery-day .left-text-left','float','left','','','.w-delivery-day'),(925900,'printshop','.w-delivery-day .left-text-right','float','left','','','.w-delivery-day'),(925902,'printshop','.b-products-listing .products-listing.list-productlisting .stock','float','none','','','.b-products-listing'),(925903,'printshop','.b-slick .slick-slide','float','left','','','.b-slick'),(925904,'printshop','.b-slick [dir=\'rtl\'] .slick-slide','float','right','','','.b-slick'),(925905,'printshop','.b-products-listing .item-nav > div','float','left','','','.b-products-listing'),(925906,'printshop','.w-quote .image','float','left','','','.w-quote'),(925907,'printshop','.w-quote .sub-total','float','right','','','.w-quote'),(925908,'printshop','.w-quote .sub-total-text','float','left','','','.w-quote'),(925909,'printshop','.b-quantity .qty-input label','float','left','','','.b-quantity'),(925910,'printshop','.w-product-sale-ends .left-count','float','left','','','.w-product-sale-ends'),(925911,'printshop','.w-product-sale-ends .left-text-left','float','left','','','.w-product-sale-ends'),(925912,'printshop','.w-product-sale-ends .left-text-right','float','left','','','.w-product-sale-ends'),(925913,'printshop','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(925914,'printshop','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(925915,'printshop','.w-product-bonus-points > div > div','float','left','','','.w-product-bonus-points'),(925916,'printshop','.w-compare .compare-list-buttons','float','right','','','.w-compare'),(925917,'printshop','.w-compare .clear-compare-button','float','right','','','.w-compare'),(925918,'printshop','.w-compare .image','float','left','','','.w-compare'),(925919,'printshop','.w-files-catalog-widgets-files-list .file','float','left','3','','.w-files-catalog-widgets-files-list'),(925920,'printshop','.w-sample .image','float','left','','','.w-sample'),(925921,'printshop','.w-sample .sub-total','float','right','','','.w-sample'),(925922,'printshop','.w-sample .sub-total-text','float','left','','','.w-sample'),(925923,'printshop','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(925924,'printshop','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(925925,'printshop','.w-product-bundle .bundle_qty','float','left','','','.w-product-bundle'),(925926,'printshop','.w-product-bundle .bundle_price','float','right','','','.w-product-bundle'),(925927,'printshop','.w-product-in-bundles .attributes-item','float','left','','','.w-product-in-bundles'),(925928,'printshop','.w-product-in-bundles .bundle_qty','float','left','','','.w-product-in-bundles'),(925929,'printshop','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(925930,'printshop','.w-cart-listing .item div.price','float','left','5342','','.w-cart-listing'),(925931,'printshop','.b-pagination .pagination .left-area','float','left','','','.b-pagination'),(925932,'printshop','.b-pagination .pagination .right-area','float','right','','','.b-pagination'),(925933,'printshop','.w-product-quantity-discounts .item','float','left','','','.w-product-quantity-discounts'),(925934,'printshop','.w-product-quantity-discounts .item','float','none','5342','','.w-product-quantity-discounts'),(925935,'printshop','.w-product-multi-inventory .select-box:nth-child(2n)','float','left','','','.w-product-multi-inventory'),(925936,'printshop','.w-product-multi-inventory .select-box:nth-child(2n+1)','float','left','','','.w-product-multi-inventory'),(925937,'printshop','.w-product-multi-inventory .radio-attributes > label','float','left','','','.w-product-multi-inventory'),(925938,'printshop','.b-products-listing .products-listing .radio-attributes > label','float','left','','','.b-products-listing'),(925939,'printshop','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(925940,'printshop','.w-product-collection .current-product','float','left','','','.w-product-collection'),(925941,'printshop','.w-product-collection .right-area','float','left','','','.w-product-collection'),(925942,'printshop','.w-product-collection .current-product, .w-product-collection .chosen-products','float','none','5342','','.w-product-collection'),(925943,'printshop','.w-product-collection .right-area','float','none','5342','','.w-product-collection'),(925944,'printshop','.w-product-attributes .radio-attributes > label','float','left','','','.w-product-attributes'),(925945,'printshop','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(925946,'printshop','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(925947,'printshop','.w-product-groups .radioBox label','float','left','','','.w-product-groups'),(925948,'printshop','.w-product-groups .radioBox label .containerBlock img','float','left','','','.w-product-groups'),(925949,'printshop','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img','float','none','','','.w-product-groups'),(925950,'printshop','.b-products-listing .products-listing .attribute-color','float','left','','','.b-products-listing'),(925951,'printshop','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(925952,'printshop','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(925953,'printshop','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(925954,'printshop','.w-product-custom-bundle .chosen-products','float','none','5342','','.w-product-custom-bundle'),(925955,'printshop','.w-product-custom-bundle .right-area','float','none','5342','','.w-product-custom-bundle'),(925956,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','float','left','','','.w-catalog-pages-category-pages-last-list'),(925957,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','float','left','','','.w-catalog-pages-category-pages-last-list-block'),(925958,'printshop','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(925959,'printshop','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(925960,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li','float','left','','','.w-delivery-location-featured-list'),(925961,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li','float','none','5363','','.w-delivery-location-featured-list'),(925962,'printshop','.w-sale-category .holder-1','float','right','','','.w-sale-category'),(925963,'printshop','.w-sale-category .holder-2','float','left','','','.w-sale-category'),(925964,'printshop','.w-sale-category .image','float','left','','','.w-sale-category'),(925965,'printshop','.w-sale-category .left-count','float','left','','','.w-sale-category'),(925966,'printshop','.w-sale-category .left-text-left','float','left','','','.w-sale-category'),(925967,'printshop','.w-sale-category .left-text-right','float','left','','','.w-sale-category'),(925968,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','float','left','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(925969,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','float','left','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(925970,'printshop','.w-delivery-location-list-by-page .item','float','left','','','.w-delivery-location-list-by-page'),(925971,'printshop','.w-delivery-location-cross-pages .item','float','left','','','.w-delivery-location-cross-pages'),(925972,'printshop','.w-catalog-delivery-locations .item','float','left','','','.w-catalog-delivery-locations'),(925973,'printshop','.w-catalog-delivery-locations .item','float','none','5333','','.w-catalog-delivery-locations'),(925974,'printshop','.w-product-designer-designer .prodDesignerType label','float','left','','','.w-product-designer-designer'),(925975,'printshop','.w-product-designer-designer .prodDesignerType','float','none','','','.w-product-designer-designer'),(925976,'printshop','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','float','right','','','.w-press-reviews-widgets-press-reviews-small'),(925977,'printshop','.w-gift-wrap-message-checkout .text','float','left','','','.w-gift-wrap-message-checkout'),(925978,'printshop','.w-support-system-filter .filter-categories','float','none','','','.w-support-system-filter'),(925979,'printshop','.w-support-system-filter .dd3-content .collapse_span','float','right','','','.w-support-system-filter'),(925980,'printshop','.w-support-system-listing .product_icon','float','left','','','.w-support-system-listing'),(925981,'printshop','.w-rma-returns-history .topRow .icons','float','right','','','.w-rma-returns-history'),(925982,'printshop','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(925983,'printshop','.w-product-configurator .item-content > div','float','left','5333','','.w-product-configurator'),(925984,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','float','left','','','.w-catalog-pages-category-pages-list'),(925985,'printshop','.w-product-reviews .write-review-button','float','none','5363','','.w-product-reviews'),(925986,'printshop','.w-compare .compare-list-buttons','float','none','5342','','.w-compare'),(925987,'printshop','.w-cart-shipping-estimator .left-area','float','none','5363','','.w-cart-shipping-estimator'),(925988,'printshop','.w-cart-shipping-estimator .right-area','float','none','5363','','.w-cart-shipping-estimator'),(925989,'printshop','.p-quote-checkout-index .dob-hide > div','float','right','','','.p-quote-checkout-index'),(925990,'printshop','.p-quote-checkout-index .dob-hide label','float','left','','','.p-quote-checkout-index'),(925991,'printshop','.account-address-book .address_book h2 strong','float','left','','','.account-address-book'),(925992,'printshop','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','float','left','','','.account-address-book'),(925993,'printshop','.account-address-book .button1','float','right','','','.account-address-book'),(925994,'printshop','.account-address-book .button2','float','left','','','.account-address-book'),(925995,'printshop','.account-address-book .address_book_row .column','float','none','5333','','.account-address-book'),(925996,'printshop','.account-address-book .address_book_row .column + .column','float','none','5333','','.account-address-book'),(925997,'printshop','.account-address-book .topInfo > div','float','none','5333','','.account-address-book'),(925998,'printshop','.account-address-book .topInfo > div + div','float','none','5333','','.account-address-book'),(926008,'printshop','.account-order-pay .history_info > div','float','left','','','.account-order-pay'),(926009,'printshop','.account-sample-info .history_info > div','float','left','','','.account-sample-info'),(926010,'printshop','.checkout-index-wrap .dob-hide > div','float','right','','','.checkout-index-wrap'),(926011,'printshop','.checkout-index-wrap .dob-hide label','float','left','','','.checkout-index-wrap'),(926012,'printshop','.b-form .add-ab','float','right','','','.b-form'),(926013,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','float','right','','','.b-multi-page-checkout'),(926015,'printshop','.footer-menu .level-2 > li','float','left','3','','.footer-menu'),(926016,'printshop','.w-sale .holder-1','float','right','','','.w-sale'),(926017,'printshop','.w-sale .holder-2','float','left','','','.w-sale'),(926018,'printshop','.w-sale .image','float','left','','','.w-sale'),(926019,'printshop','.w-sale .left-count','float','left','','','.w-sale'),(926020,'printshop','.w-sale .left-text-left','float','left','','','.w-sale'),(926021,'printshop','.w-sale .left-text-right','float','left','','','.w-sale'),(926022,'printshop','.b-slick .slick-slide','float_important','important','','','.b-slick'),(926023,'printshop','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-family','$font-1','','','.w-communication-new-topic'),(926024,'printshop','.b-upload-file .snapshot','font-family','$font-icons-1','3','','.b-upload-file'),(926025,'printshop','.heading-4 .edit, h4 .edit','font-family','trueloaded','4','',''),(926026,'printshop','.message.success','font-family','trueloaded','3','',''),(926027,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(926028,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(926029,'printshop','.b-form .checkbox-style:checked + .checkbox-span:before','font-family','$font-icons-1','','','.b-form'),(926030,'printshop','.p-quick-order-index .paginate_button.previous','font-family','$font-icons-1','3','','.p-quick-order-index'),(926031,'printshop','.p-quick-order-index .paginate_button.next','font-family','$font-icons-1','3','','.p-quick-order-index'),(926032,'printshop','.w-cart-compare .cart-name a','font-family','$font-1','','','.w-cart-compare'),(926033,'printshop','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(926035,'printshop','.p-sample-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-sample-checkout-success'),(926036,'printshop','.p-sample-checkout-success .page-success .text-1, .p-sample-checkout-success .page-success .text-2, .p-sample-checkout-success .page-success .text-3','font-family','$font-1','','','.p-sample-checkout-success'),(926037,'printshop','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(926038,'printshop','.testimonials .heading-3','font-family','trueloaded','3','',''),(926039,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(926040,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(926041,'printshop','.w-promotions .nextdiscount .heading','font-family','$font-icons-1','3','','.w-promotions'),(926042,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','font-family','$font-icons-1','3','','.b-warehouses-popup'),(926043,'printshop','.b-warehouses-popup .warehouses-popup-link','font-family','$font-icons-1','3','','.b-warehouses-popup'),(926044,'printshop','.b-preloader .preloader','font-family','$font-icons-1','3','','.b-preloader'),(926045,'printshop','.w-social-links a','font-family','$font-icons-1','','','.w-social-links'),(926046,'printshop','.b-bottom .closeable-heading','font-family','$font-icons-3','3','','.b-bottom'),(926047,'printshop','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(926048,'printshop','.b-messages .messBtnMenuUnread','font-family','$font-icons-1','3','','.b-messages'),(926049,'printshop','.b-messages .messBtnMenuDelete','font-family','trueloaded','3','','.b-messages'),(926050,'printshop','.b-messages span.starred::before','font-family','trueloaded','','','.b-messages'),(926051,'printshop','.b-messages .messBtnMenuStarred','font-family','trueloaded','3','','.b-messages'),(926052,'printshop','.b-messages .content_management_attach span','font-family','$font-1','','','.b-messages'),(926053,'printshop','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(926054,'printshop','.p-payer-order-confirmation .ship-ico','font-family','$font-icons-3','3','','.p-payer-order-confirmation'),(926055,'printshop','.p-payer-order-confirmation .pay-ico','font-family','$font-icons-3','3','','.p-payer-order-confirmation'),(926056,'printshop','.p-payer-order-confirmation .discount-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(926057,'printshop','.p-payer-order-confirmation .comment-ico','font-family','$font-icons-3','3','','.p-payer-order-confirmation'),(926058,'printshop','.p-payer-order-pay .ship-ico','font-family','$font-icons-3','3','','.p-payer-order-pay'),(926059,'printshop','.p-payer-order-pay .pay-ico','font-family','$font-icons-3','3','','.p-payer-order-pay'),(926060,'printshop','.p-payer-order-pay .discount-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(926061,'printshop','.p-payer-order-pay .comment-ico','font-family','$font-icons-3','3','','.p-payer-order-pay'),(926062,'printshop','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(926063,'printshop','.b-info .info strong','font-family','$font-1','','','.b-info'),(926064,'printshop','.b-fancybox .fancybox-close','font-family','FontAwesome','3','','.b-fancybox'),(926065,'printshop','.b-messages .select2-search-choice-close','font-family','trueloaded','3','','.b-messages'),(926067,'printshop','.bell-ico .heading-2','font-family','trueloaded','3','','.bell-ico'),(926068,'printshop','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(926069,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-family','$font-icons-1','3','','.w-upload-customer-id-upload-customer-id-form'),(926070,'printshop','.w-coupons-and-vauchers-checkout .btn-remove','font-family','trueloaded','3','','.w-coupons-and-vauchers-checkout'),(926071,'printshop','.w-filters .open','font-family','$font-icons-3','3','','.w-filters'),(926072,'printshop','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(926073,'printshop','.b-fancybox .fancybox-nav span','font-family','trueloaded','','','.b-fancybox'),(926075,'printshop','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','font-family','$font-icons-1','3','','.w-checkout-contact-information'),(926076,'printshop','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(926077,'printshop','.view-all .btn','font-family','$font-icons-1','4','',''),(926078,'printshop','.w-catalog-listing-look .list','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(926079,'printshop','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(926082,'printshop','.w-cart-compare .price-cell','font-family','$font-1','','','.w-cart-compare'),(926083,'printshop','.b-bottom .footerTitle','font-family','$font-icons-1','5333,4','','.b-bottom'),(926085,'printshop','.b-rating .glyphicon-star','font-family','$font-icons-1','3','','.b-rating'),(926087,'printshop','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(926089,'printshop','.w-cart-compare .product-actions .dropdown-toggle','font-family','$font-icons-1','3','','.w-cart-compare'),(926090,'printshop','.w-cart-compare .atr-col','font-family','$font-icons-1','3','','.w-cart-compare'),(926092,'printshop','.b-rating .glyphicon','font-family','$font-icons-1','','','.b-rating'),(926093,'printshop','.order-summary .price-row.ot_gv .title','font-family','trueloaded','3','','.order-summary'),(926094,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(926095,'printshop','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(926096,'printshop','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(926097,'printshop','.b-info .info','font-family','trueloaded','3','','.b-info'),(926098,'printshop','.w-multi-cart-actions .cart-actions .dropdown-toggle','font-family','$font-icons-1','3','','.w-multi-cart-actions'),(926099,'printshop','.w-top-categories h2.name','font-family','$font-1','','','.w-top-categories'),(926102,'printshop','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(926103,'printshop','.btn-edit','font-family','trueloaded','3','',''),(926104,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(926105,'printshop','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(926106,'printshop','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(926107,'printshop','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(926109,'printshop','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(926110,'printshop','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(926111,'printshop','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(926112,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(926113,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(926114,'printshop','.w-filters .input-checkbox:checked + .checkbox-span:before','font-family','$font-icons-3','','','.w-filters'),(926115,'printshop','.in-stock-icon','font-family','$font-icons-1','3','',''),(926116,'printshop','.out-stock-icon','font-family','$font-icons-1','3','',''),(926117,'printshop','.transit-icon','font-family','$font-icons-1','3','',''),(926118,'printshop','.heading-3 .edit, h3 .edit','font-family','trueloaded','4','',''),(926119,'printshop','.b-info .info','font-family','trueloaded','3','','.b-info'),(926120,'printshop','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(926121,'printshop','.w-checkout-create-account .account-benefits strong','font-family','trueloaded','3','','.w-checkout-create-account'),(926122,'printshop','.b-info .info strong','font-family','$font-1','','','.b-info'),(926123,'printshop','.savings-ico .heading-2','font-family','trueloaded','3','','.savings-ico'),(926124,'printshop','.w-cart-bonus-points .btn-remove','font-family','trueloaded','3','','.w-cart-bonus-points'),(926127,'printshop','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(926128,'printshop','.js-stock-icon','font-family','$font-icons-1','3','',''),(926129,'printshop','.b-switch .candlestick-wrapper .fa-check','font-family','FontAwesome','3','','.b-switch'),(926130,'printshop','.b-switch .candlestick-wrapper .fa-times','font-family','FontAwesome','3','','.b-switch'),(926131,'printshop','.b-info .info strong','font-family','$font-1','','','.b-info'),(926132,'printshop','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(926133,'printshop','.w-top-categories .categories h2','font-family','inherit','','','.w-top-categories'),(926134,'printshop','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(926135,'printshop','.b-upload-file .upload-file-wrap .upload-remove','font-family','trueloaded','3','','.b-upload-file'),(926136,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-family','$font-icons-1','','','.b-form'),(926137,'printshop','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(926138,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(926139,'printshop','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(926140,'printshop','.w-reviews .heading-3','font-family','trueloaded','3','','.w-reviews'),(926141,'printshop','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(926142,'printshop','.b-info .info','font-family','trueloaded','3','','.b-info'),(926143,'printshop','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(926144,'printshop','.b-info .info strong','font-family','$font-1','','','.b-info'),(926145,'printshop','.btn-del','font-family','$font-icons-1','4','',''),(926146,'printshop','.b-rating .glyphicon-star.coloron','font-family','$font-icons-1','3','','.b-rating'),(926148,'printshop','.w-cart-credit-amount .btn-remove','font-family','trueloaded','3','','.w-cart-credit-amount'),(926150,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(926151,'printshop','.closeable-heading','font-family','$font-icons-1','3','',''),(926152,'printshop','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(926153,'printshop','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(926154,'printshop','.b-bottom .pop-up-close','font-family','$font-icons-1','3','','.b-bottom'),(926155,'printshop','.b-info-popup .info-popup','font-family','trueloaded','3','','.b-info-popup'),(926156,'printshop','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-family','$font-icons-1','','','.b-products-listing'),(926157,'printshop','.b-upload-files .remove-file','font-family','$font-icons-1','3','','.b-upload-files'),(926160,'printshop','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(926162,'printshop','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(926163,'printshop','.b-info .info','font-family','trueloaded','3','','.b-info'),(926164,'printshop','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(926166,'printshop','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(926168,'printshop','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(926170,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-family','$font-1','','','.b-select-suggest'),(926171,'printshop','.b-select-suggest .select2-search input','font-family','$font-1','','','.b-select-suggest'),(926176,'printshop','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(926179,'printshop','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(926181,'printshop','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(926182,'printshop','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(926183,'printshop','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(926184,'printshop','.b-products-listing .products-listing .bonus-points-price','font-family','$font-icons-1','3','','.b-products-listing'),(926185,'printshop','.b-products-listing .products-listing .bonus-points-cost','font-family','$font-icons-1','3','','.b-products-listing'),(926186,'printshop','.b-products-listing .btn-preloader','font-family','$font-icons-1','3','','.b-products-listing'),(926187,'printshop','.b-products-listing .loader','font-family','$font-icons-1','4','','.b-products-listing'),(926189,'printshop','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(926190,'printshop','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(926191,'printshop','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(926192,'printshop','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','font-family','$font-icons-1','3','','.w-checkout-contact-information'),(926193,'printshop','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(926196,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','font-family','trueloaded','3','','.w-contact-contacts'),(926197,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-family','inherit','','','.w-contact-contacts'),(926198,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-family','inherit','','',''),(926199,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-family','inherit','','','.b-h-inline'),(926201,'printshop','.b-info .info strong','font-family','$font-1','','','.b-info'),(926202,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','font-family','$font-icons-1','3','','.b-form'),(926203,'printshop','.b-info .info','font-family','trueloaded','3','','.b-info'),(926204,'printshop','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','font-family','$font-icons-1','3','','.w-checkout-contact-information'),(926205,'printshop','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(926206,'printshop','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(926208,'printshop','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(926209,'printshop','.b-info .info','font-family','trueloaded','3','','.b-info'),(926210,'printshop','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','font-family','trueloaded','3','','.order-summary'),(926211,'printshop','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(926212,'printshop','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(926213,'printshop','.w-product-cross-sell .buy-all-checker','font-family','$font-icons-1','3','','.w-product-cross-sell'),(926214,'printshop','.w-catalog-listing-look .b2b','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(926215,'printshop','.w-catalog-listing-look .grid','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(926216,'printshop','.checkbox input:checked + span:before','font-family','$font-icons-1','','',''),(926217,'printshop','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-family','trueloaded','3','','.w-cart-listing'),(926218,'printshop','.w-cart-listing .points-redeem','font-family','$font-1','','','.w-cart-listing'),(926219,'printshop','.w-cart-listing .points-redeem','font-family','$font-icons-1','3','','.w-cart-listing'),(926220,'printshop','.w-cart-listing .remove-btn','font-family','$font-icons-3','3','','.w-cart-listing'),(926221,'printshop','.w-cart-give-away .ga_qty','font-family','$font-1','','','.w-cart-give-away'),(926222,'printshop','.w-cart-discount-coupon .btn-remove','font-family','trueloaded','3','','.w-cart-discount-coupon'),(926225,'printshop','.b-compare .clear_all','font-family','$font-icons-1','4','','.b-compare'),(926226,'printshop','.order-summary .price-row.ot_bonus_points .title','font-family','trueloaded','3','','.order-summary'),(926227,'printshop','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(926228,'printshop','.w-checkout-credit-amount .btn-remove','font-family','trueloaded','3','','.w-checkout-credit-amount'),(926229,'printshop','.w-product-wishlist-button .btn','font-family','$font-1','','','.w-product-wishlist-button'),(926230,'printshop','.w-filters .view_more','font-family','$font-icons-1','4','','.w-filters'),(926231,'printshop','.w-filters span.close','font-family','$font-icons-3','3','','.w-filters'),(926232,'printshop','.w-quote .cart-box-link','font-family','trueloaded','3','','.w-quote'),(926233,'printshop','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(926234,'printshop','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(926235,'printshop','.b-info .info strong','font-family','$font-1','','','.b-info'),(926236,'printshop','body','font-family','$font-1','','',''),(926237,'printshop','.w-checkout-bonus-points .btn-remove','font-family','trueloaded','3','','.w-checkout-bonus-points'),(926238,'printshop','.b-data-table table.dataTable thead td','font-family','$font-1','','','.b-data-table'),(926241,'printshop','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(926243,'printshop','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(926245,'printshop','.w-filters .mobileCollapse','font-family','$font-icons-1','4','','.w-filters'),(926246,'printshop','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-family','$font-icons-3','','','.w-filters'),(926247,'printshop','.b-product-images .media-popup .mp-close','font-family','$font-icons-1','3','','.b-product-images'),(926248,'printshop','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','font-family','$font-icons-3','3','','.b-menu-burger_icon'),(926249,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-family','trueloaded','3','','.w-catalog-compare'),(926251,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','font-family','$font-icons-1','3','','.b-slick'),(926252,'printshop','.w-subscribers .btn-submit','font-family','$font-1','','','.w-subscribers'),(926253,'printshop','.w-quote .multicart .switch-cart','font-family','$font-icons-1','3','','.w-quote'),(926254,'printshop','.w-quote .multicart .title','font-family','$font-1','','','.w-quote'),(926256,'printshop','.w-product-bonus-points > div > div','font-family','$font-icons-1','3','','.w-product-bonus-points'),(926257,'printshop','.w-compare .remove','font-family','$font-icons-1','3','','.w-compare'),(926258,'printshop','.w-files-catalog-widgets-files-list .file','font-family','$font-icons-1','3','','.w-files-catalog-widgets-files-list'),(926259,'printshop','.w-sample .cart-box-link','font-family','trueloaded','3','','.w-sample'),(926260,'printshop','.w-sample .multicart .switch-cart','font-family','$font-icons-1','3','','.w-sample'),(926261,'printshop','.w-sample .multicart .title','font-family','$font-1','','','.w-sample'),(926262,'printshop','.w-sample .qty','font-family','$font-icons-1','4','','.w-sample'),(926263,'printshop','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','trueloaded','3','','.w-cart-gift-certificate'),(926264,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','font-family','inherit','','','.b-products-listing'),(926265,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','font-family','$font-icons-1','3','','.b-pagination'),(926266,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','font-family','$font-icons-1','3','','.b-pagination'),(926267,'printshop','.w-account-personal-catalog .list-row-action ul','font-family','$font-icons-1','4','','.w-account-personal-catalog'),(926268,'printshop','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','font-family','$font-2','3','','.w-product-custom-bundle'),(926269,'printshop','.w-delivery-location-location-list .deliveryListParrent','font-family','$font-1','','','.w-delivery-location-location-list'),(926270,'printshop','.w-support-system-filter .dd3-content .collapse_span','font-family','$font-icons-1','3','','.w-support-system-filter'),(926271,'printshop','.w-rma-returns-history .column .title','font-family','inherit','','','.w-rma-returns-history'),(926272,'printshop','.w-predefined-promotion .nextdiscount .heading','font-family','$font-icons-1','3','','.w-predefined-promotion'),(926273,'printshop','.w-supplier-purchase-supplier-products .active .select_item > div:before','font-family','$font-icons-1','','','.w-supplier-purchase-supplier-products'),(926275,'printshop','.b-quantity .qty-box .bigger','font-family','$font-icons-3','','','.b-quantity'),(926276,'printshop','.b-quantity .qty-box .smaller','font-family','$font-icons-3','','','.b-quantity'),(926277,'printshop','html, button, input, select, textarea','font-family','$font-1','','',''),(926278,'printshop','.tripleLine .text-banner-2 > div a','font-family','$font-icons-3','4','','.tripleLine'),(926279,'printshop','.b-table-list .table-list th','font-family','$font-1','','','.b-table-list'),(926280,'printshop','.p-wedding-registry-view h1','font-family','$font-icons-1','3','','.p-wedding-registry-view'),(926281,'printshop','.p-wedding-registry-view h1','font-family','$font-icons-1','4','','.p-wedding-registry-view'),(926282,'printshop','.middleBanner .btn-1','font-family','$font-icons-3','4','','.middleBanner'),(926283,'printshop','.bottomBanner .btn-1','font-family','$font-icons-3','4','','.bottomBanner'),(926285,'printshop','.topBanner .content .btn','font-family','$font-icons-3','4','','.topBanner'),(926286,'printshop','.tripleLine .banner-text-holder > div a','font-family','$font-icons-3','4','','.tripleLine'),(926287,'printshop','.order-summary .icon','font-family','$font-icons-3','3','','.order-summary'),(926288,'printshop','.w-cart-discount-coupon .title','font-family','$font-icons-3','4','','.w-cart-discount-coupon'),(926289,'printshop','.w-cart-checkout-btn .with-card','font-family','$font-icons-1','4','','.w-cart-checkout-btn'),(926290,'printshop','.p-quote-checkout-index .comment-ico','font-family','$font-icons-3','3','','.p-quote-checkout-index'),(926291,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','font-family','$font-1','','','.p-quote-checkout-index'),(926292,'printshop','.p-quote-checkout-index .pay-ico','font-family','$font-icons-3','3','','.p-quote-checkout-index'),(926293,'printshop','.p-quote-checkout-index .ship-ico','font-family','$font-icons-3','3','','.p-quote-checkout-index'),(926297,'printshop','.account-address-book .leftMes div','font-family','$font-1','','','.account-address-book'),(926308,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-family','trueloaded','3','','.account-order-pay'),(926309,'printshop','.account-samples .orders-table th','font-family','$font-1','','','.account-samples'),(926310,'printshop','.account-samples .view_link','font-family','trueloaded','4','','.account-samples'),(926311,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-family','trueloaded','3','','.account-sample-info'),(926312,'printshop','.catalog-product-wrap .pn-direction','font-family','$font-1','','','.catalog-product-wrap'),(926313,'printshop','.catalog-product-wrap .pn-image','font-family','$font-icons-1','3','','.catalog-product-wrap'),(926314,'printshop','.shopping-cart-index .gift-code .heading-4','font-family','$font-icons-1','4','','.shopping-cart-index'),(926315,'printshop','.checkout-index-wrap .comment-ico','font-family','$font-icons-3','3','','.checkout-index-wrap'),(926316,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','font-family','$font-1','','','.checkout-index-wrap'),(926317,'printshop','.checkout-index-wrap .pay-ico','font-family','$font-icons-3','3','','.checkout-index-wrap'),(926318,'printshop','.checkout-index-wrap .ship-ico','font-family','$font-icons-3','3','','.checkout-index-wrap'),(926319,'printshop','.checkout-order-confirmation .comment-ico','font-family','$font-icons-3','3','','.checkout-order-confirmation'),(926320,'printshop','.checkout-order-confirmation .discount-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(926321,'printshop','.checkout-order-confirmation .pay-ico','font-family','$font-icons-3','3','','.checkout-order-confirmation'),(926322,'printshop','.checkout-order-confirmation .ship-ico','font-family','$font-icons-3','3','','.checkout-order-confirmation'),(926323,'printshop','.checkout-success-wrap .page-success .text-1','font-family','$font-icons-3','3','','.checkout-success-wrap'),(926324,'printshop','.checkout-success-wrap .page-success .text-1, .checkout-success-wrap .page-success .text-2, .checkout-success-wrap .page-success .text-3','font-family','$font-1','','','.checkout-success-wrap'),(926325,'printshop','.b-form .eye-password','font-family','$font-icons-1','3','','.b-form'),(926328,'printshop','.success-page .check-ico-block','font-family','trueloaded','3','','.success-page'),(926329,'printshop','.success-page .comment-ico','font-family','trueloaded','3','','.success-page'),(926330,'printshop','.success-page .discount-ico','font-family','trueloaded','3','','.success-page'),(926331,'printshop','.success-page .order-ico','font-family','trueloaded','3','','.success-page'),(926332,'printshop','.success-page .page-success .text-1','font-family','trueloaded','3','','.success-page'),(926333,'printshop','.success-page .page-success .text-1, .success-page .page-success .text-2, .success-page .page-success .text-3','font-family','$font-1','','','.success-page'),(926334,'printshop','.success-page .pay-ico','font-family','trueloaded','3','','.success-page'),(926335,'printshop','.success-page .prod-ico','font-family','trueloaded','3','','.success-page'),(926336,'printshop','.success-page .ship-ico','font-family','trueloaded','3','','.success-page'),(926337,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-family','$font-1','','','.b-multi-page-checkout'),(926338,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-family','$font-icons-1','3','','.b-multi-page-checkout'),(926339,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-family','trueloaded','4','','.b-multi-page-checkout'),(926343,'printshop','.footer-menu .level-1 > li','font-family','$font-icons-3','5342,3','','.footer-menu'),(926344,'printshop','.w-bestsellers .heading-3','font-family','trueloaded','3','','.w-bestsellers'),(926345,'printshop','.w-bestsellers .item','font-family','trueloaded','3','','.w-bestsellers'),(926346,'printshop','.w-catalog-paging .next','font-family','FontAwesome','3','','.w-catalog-paging'),(926347,'printshop','.w-catalog-paging .prev','font-family','FontAwesome','3','','.w-catalog-paging'),(926350,'printshop','.b-rating .glyphicon','font-family_important','important','','','.b-rating'),(926351,'printshop','.w-communication-new-topic td.date-purchased','font-size','14','','','.w-communication-new-topic'),(926352,'printshop','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-size','14','','','.w-communication-new-topic'),(926353,'printshop','.b-email .price','font-size','14','','','.b-email'),(926354,'printshop','.heading-4 .right-text, h4 .right-text','font-size','16','','',''),(926355,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(926356,'printshop','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(926357,'printshop','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(926358,'printshop','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(926360,'printshop','.b-form .middle-form label','font-size','16','','','.b-form'),(926361,'printshop','.b-email-editor .price','font-size','18','','','.b-email-editor'),(926362,'printshop','.p-quick-order-index .paginate_button.previous','font-size','20','3','','.p-quick-order-index'),(926363,'printshop','.b-email .qty','font-size','14','','','.b-email'),(926364,'printshop','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','font-size','13','','','.p-quick-order-index'),(926365,'printshop','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-size','14','','','.p-quick-order-index'),(926366,'printshop','.p-quick-order-index .paginate_button.next','font-size','20','3','','.p-quick-order-index'),(926367,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.next','font-size','0','','','.p-quick-order-index'),(926368,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.previous','font-size','0','','','.p-quick-order-index'),(926369,'printshop','.w-promotions .promo-item','font-size','24','','','.w-promotions'),(926371,'printshop','.w-promotions .prom-multi-discount .promo-range','font-size','13','','','.w-promotions'),(926373,'printshop','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(926375,'printshop','.w-cart-compare .attributes-label','font-size','14','','','.w-cart-compare'),(926377,'printshop','.w-personal-gift-status-bar .end-label','font-size','14','','','.w-personal-gift-status-bar'),(926378,'printshop','.p-sample-checkout-success .page-success .text-1','font-size','60','','','.p-sample-checkout-success'),(926379,'printshop','.p-sample-checkout-success .page-success .text-3','font-size','27','','','.p-sample-checkout-success'),(926380,'printshop','.p-sample-checkout-success .page-success .text-2','font-size','34','','','.p-sample-checkout-success'),(926381,'printshop','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(926382,'printshop','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(926383,'printshop','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(926384,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(926385,'printshop','.w-promotions .prom-multi-discount .heading','font-size','26','','','.w-promotions'),(926386,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(926387,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(926388,'printshop','.b-email .heading-name','font-size','14','','','.b-email'),(926389,'printshop','.testimonials .reviews-list span','font-size','22','','',''),(926390,'printshop','.testimonials .rating','font-size','22','','',''),(926391,'printshop','.testimonials .reviews-list .date','font-size','14','','',''),(926392,'printshop','.testimonials .date','font-size','14','','',''),(926393,'printshop','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','font-size','14','','','.w-promotions'),(926394,'printshop','.w-promotions .prom-multi-discount .promo-group','font-size','16','','','.w-promotions'),(926395,'printshop','.w-promotions .nextdiscount .heading','font-size','26','','','.w-promotions'),(926396,'printshop','.w-promotions .nextdiscount .heading','font-size','18','3','','.w-promotions'),(926397,'printshop','.w-promotions .nextdiscount .promo-for-each','font-size','14','','','.w-promotions'),(926398,'printshop','.w-promotions .nextdiscount .item-holder .name','font-size','14','','','.w-promotions'),(926399,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.p-quick-order-index'),(926400,'printshop','.w-promotions .heading-3','font-size','48','','','.w-promotions'),(926401,'printshop','.w-promotions .promo-salemaker .discount','font-size','13','','','.w-promotions'),(926402,'printshop','.w-promotions .promo-salemaker .content a','font-size','14','','','.w-promotions'),(926403,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','font-size','16','','','.w-promotions'),(926404,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','font-size','13','','','.w-promotions'),(926405,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-name','font-size','16','','','.b-warehouses-popup'),(926406,'printshop','.w-promotions .promo-cart-discount .item a','font-size','14','','','.w-promotions'),(926407,'printshop','.b-warehouses-popup a.warehouses-popup-link','font-size','14','','','.b-warehouses-popup'),(926408,'printshop','.b-warehouses-popup .warehouses-popup .heading','font-size','18','','','.b-warehouses-popup'),(926409,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','font-size','14','','','.b-warehouses-popup'),(926410,'printshop','.b-preloader .preloader','font-size','40','3','','.b-preloader'),(926412,'printshop','.w-cart-compare .dropdown li','font-size','14','','','.w-cart-compare'),(926413,'printshop','.w-cart-compare .attributes-cell','font-size','14','','','.w-cart-compare'),(926414,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(926415,'printshop','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(926416,'printshop','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','font-size','12','3','','.order-summary'),(926417,'printshop','.b-compare .compare-head','font-size','22','','','.b-compare'),(926418,'printshop','.b-bottom .closeable-heading','font-size','20','3','','.b-bottom'),(926419,'printshop','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(926420,'printshop','.b-messages .messBtnMenuDelete','font-size','22','3','','.b-messages'),(926421,'printshop','.b-messages .content-messages .heading-2','font-size','26','','','.b-messages'),(926422,'printshop','.b-messages span.starred::before','font-size','16','','','.b-messages'),(926423,'printshop','.b-messages .messBtnMenuStarred','font-size','22','3','','.b-messages'),(926424,'printshop','.b-messages .messBtnMenuUnread','font-size','22','3','','.b-messages'),(926425,'printshop','.b-messages .messMenuButton span','font-size','14','','','.b-messages'),(926426,'printshop','.b-messages .content_management_attach','font-size','14','','','.b-messages'),(926427,'printshop','.b-messages .content_management_attach span','font-size','16','','','.b-messages'),(926428,'printshop','.b-messages .content_management_attach button','font-size','14','','','.b-messages'),(926429,'printshop','.b-messages .select2-search-choice-close','font-size','11','3','','.b-messages'),(926430,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','font-size','14','','',''),(926431,'printshop','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(926432,'printshop','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(926433,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(926434,'printshop','.b-info .info strong','font-size','18','','','.b-info'),(926436,'printshop','.b-data-table table.dataTable thead td','font-size','16','','','.b-data-table'),(926437,'printshop','.p-payer-order-confirmation .discount-ico','font-size','30','3','','.p-payer-order-confirmation'),(926438,'printshop','.p-payer-order-pay .discount-ico','font-size','30','3','','.p-payer-order-pay'),(926439,'printshop','.w-checkout-terms .terms-box','font-size','13','','','.w-checkout-terms'),(926440,'printshop','.w-cart-cart-tabs .w-tabs .tab-a','font-size','18','5333','','.w-cart-cart-tabs'),(926441,'printshop','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(926442,'printshop','.order-summary .price-box .title','font-size','15','','','.order-summary'),(926443,'printshop','.b-email .heading-qty','font-size','14','','','.b-email'),(926444,'printshop','.b-email .model','font-size','14','','','.b-email'),(926445,'printshop','.b-email .heading-name','font-size','14','','','.b-email'),(926446,'printshop','.p-quote-checkout-success .page-success .text-2','font-size','30','5333','','.p-quote-checkout-success'),(926447,'printshop','.b-page-name .page-name','font-size','20','','','.b-page-name'),(926448,'printshop','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(926449,'printshop','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(926450,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','font-size','10','','','.b-switch'),(926451,'printshop','.p-quick-order-index .value','font-size','20','','','.p-quick-order-index'),(926452,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-size','20','','','.w-upload-customer-id-upload-customer-id-form'),(926453,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-template','font-size','18','','','.w-upload-customer-id-upload-customer-id-form'),(926454,'printshop','.b-switch .bootstrap-switch','font-size','16','','','.b-switch'),(926455,'printshop','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(926456,'printshop','.b-info .info strong','font-size','18','','','.b-info'),(926457,'printshop','.b-email .qty','font-size','14','','','.b-email'),(926458,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(926459,'printshop','.w-coupons-and-vauchers-checkout .btn-remove','font-size','12','','','.w-coupons-and-vauchers-checkout'),(926460,'printshop','.w-checkout-bonus-points .btn-remove','font-size','12','','','.w-checkout-bonus-points'),(926461,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','font-size','7','','','.b-switch'),(926463,'printshop','.b-form .required-message','font-size','14','','','.b-form'),(926464,'printshop','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(926465,'printshop','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(926468,'printshop','.b-email-editor .price','font-size','18','','','.b-email-editor'),(926469,'printshop','.b-info-popup .info-popup div','font-size','14','','','.b-info-popup'),(926470,'printshop','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-size','24','','','.w-multi-cart-cart-switcher'),(926471,'printshop','.p-quote-checkout-success .page-success .text-2','font-size','30','5333','','.p-quote-checkout-success'),(926472,'printshop','.w-promo-code .holder','font-size','30','5363,3','','.w-promo-code'),(926473,'printshop','.no-found','font-size','1.4','','',''),(926474,'printshop','.price','font-size','30','','',''),(926476,'printshop','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(926477,'printshop','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(926478,'printshop','.w-filters .input-checkbox:checked + .checkbox-span:before','font-size','22','','','.w-filters'),(926479,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','font-size','14','','','.b-switch'),(926480,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','font-size','14','','','.b-switch'),(926481,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(926482,'printshop','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(926483,'printshop','.b-email .heading-model','font-size','14','','','.b-email'),(926484,'printshop','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(926485,'printshop','.b-info .info','font-size','30','3','','.b-info'),(926486,'printshop','.b-email .totals-label','font-size','18','','','.b-email'),(926487,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-size','18','','','.b-form'),(926488,'printshop','.w-reviews-content .rating','font-size','18','','','.w-reviews-content'),(926489,'printshop','.w-reviews-content .date','font-size','13','','','.w-reviews-content'),(926490,'printshop','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(926491,'printshop','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(926492,'printshop','.w-reviews .date','font-size','13','','','.w-reviews'),(926493,'printshop','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(926495,'printshop','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(926496,'printshop','h1','font-size','24','5342','',''),(926497,'printshop','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(926498,'printshop','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(926499,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(926500,'printshop','.bell-ico .heading-2','font-size','32','3','','.bell-ico'),(926501,'printshop','.w-personal-gift-status-bar .end-date','font-size','14','','','.w-personal-gift-status-bar'),(926502,'printshop','.w-cart-compare .price-cell','font-size','18','','','.w-cart-compare'),(926503,'printshop','.w-cart-compare .price-label','font-size','14','','','.w-cart-compare'),(926504,'printshop','.w-checkout-create-account .account-benefits','font-size','0.8','','','.w-checkout-create-account'),(926505,'printshop','.w-cart-listing .price','font-size','18','','','.w-cart-listing'),(926506,'printshop','.w-cart-compare .js-cart_totals_container b','font-size','16','','','.w-cart-compare'),(926507,'printshop','.p-quote-checkout-success .page-success .text-2','font-size','30','5333','','.p-quote-checkout-success'),(926508,'printshop','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(926509,'printshop','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(926510,'printshop','.view-all .btn','font-size','0.8','4','',''),(926511,'printshop','.btn-1','font-size','16','','',''),(926512,'printshop','.b-form .privacy-row','font-size','16','','','.b-form'),(926513,'printshop','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(926514,'printshop','.b-email .name','font-size','14','','','.b-email'),(926518,'printshop','.w-tabs .tab-a','font-size','16','5342','','.w-tabs'),(926519,'printshop','.w-tabs .tab-a','font-size','26','','','.w-tabs'),(926520,'printshop','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(926522,'printshop','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(926523,'printshop','.btn-edit','font-size','0.8','3','',''),(926524,'printshop','.w-promo-code .holder','font-size','30','5363,3','','.w-promo-code'),(926525,'printshop','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(926526,'printshop','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(926527,'printshop','.w-personal-gift-status-bar .start-label','font-size','14','','','.w-personal-gift-status-bar'),(926528,'printshop','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(926529,'printshop','.heading-4 .edit, h4 .edit','font-size','16','','',''),(926530,'printshop','.heading-6, h6, .h-block h6','font-size','16','','',''),(926531,'printshop','.btn-2','font-size','16','','',''),(926533,'printshop','.w-cart-compare .cart-name a','font-size','17','','','.w-cart-compare'),(926534,'printshop','.w-cart-compare .delete-cart','font-size','12','','','.w-cart-compare'),(926535,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(926536,'printshop','.p-sample-checkout-success .page-success .text-2','font-size','30','5333','','.p-sample-checkout-success'),(926537,'printshop','.w-top-categories .categories h2','font-size','inherit','','','.w-top-categories'),(926538,'printshop','.out-stock','font-size','16','','',''),(926539,'printshop','.transit','font-size','14','','',''),(926540,'printshop','.in-stock','font-size','16','','',''),(926541,'printshop','.heading-3 .right-text, h3 .right-text','font-size','16','','',''),(926542,'printshop','.heading-3 .edit, h3 .edit','font-size','14','4','',''),(926543,'printshop','.heading-3 .edit, h3 .edit','font-size','16','','',''),(926544,'printshop','.heading-5, h5, .h-block h5','font-size','17','','',''),(926545,'printshop','.b-email .heading-model','font-size','14','','','.b-email'),(926546,'printshop','.b-email .heading-price','font-size','14','','','.b-email'),(926547,'printshop','.b-page-name .page-name','font-size','20','','','.b-page-name'),(926548,'printshop','.b-info .info','font-size','30','3','','.b-info'),(926549,'printshop','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(926550,'printshop','.w-cart-credit-amount .text','font-size','14','','','.w-cart-credit-amount'),(926551,'printshop','.w-cart-bonus-points .btn-remove','font-size','12','','','.w-cart-bonus-points'),(926552,'printshop','.w-cart-discount-coupon .text','font-size','14','','','.w-cart-discount-coupon'),(926553,'printshop','.order-summary .price-box .price-row.total','font-size','22','','','.order-summary'),(926554,'printshop','.order-summary .price','font-size','15','','','.order-summary'),(926555,'printshop','.savings-ico .heading-2','font-size','32','3','','.savings-ico'),(926556,'printshop','.w-cart-bonus-points .text','font-size','14','','','.w-cart-bonus-points'),(926557,'printshop','.b-email .model','font-size','14','','','.b-email'),(926558,'printshop','.b-email .name','font-size','14','','','.b-email'),(926560,'printshop','.testimonials .heading-3','font-size','37','3','',''),(926561,'printshop','.js-stock','font-size','16','','',''),(926562,'printshop','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(926563,'printshop','.w-checkout-shipping-choice span','font-size','14','5363','','.w-checkout-shipping-choice'),(926564,'printshop','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(926565,'printshop','.w-product-reviews .reviews-list .date','font-size','14','','','.w-product-reviews'),(926566,'printshop','.b-email-editor .price','font-size','18','','','.b-email-editor'),(926567,'printshop','.b-email .model','font-size','14','','','.b-email'),(926569,'printshop','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(926570,'printshop','.heading-4, h4, .h-block h4','font-size','18','','',''),(926571,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(926572,'printshop','.b-email .price','font-size','14','','','.b-email'),(926574,'printshop','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(926575,'printshop','.b-email .name','font-size','14','','','.b-email'),(926576,'printshop','.btn','font-size','16','','',''),(926577,'printshop','.b-email .heading-model','font-size','14','','','.b-email'),(926578,'printshop','.b-email .price','font-size','14','','','.b-email'),(926579,'printshop','.b-email .heading-qty','font-size','14','','','.b-email'),(926585,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(926586,'printshop','.b-email .qty','font-size','14','','','.b-email'),(926587,'printshop','.b-email .heading-qty','font-size','14','','','.b-email'),(926588,'printshop','.b-email .heading-name','font-size','14','','','.b-email'),(926589,'printshop','.b-email .heading-price','font-size','14','','','.b-email'),(926590,'printshop','.b-email .totals-label','font-size','18','','','.b-email'),(926591,'printshop','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(926593,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(926595,'printshop','.b-info .info','font-size','30','3','','.b-info'),(926596,'printshop','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(926597,'printshop','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(926598,'printshop','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(926599,'printshop','.w-promo-code .holder','font-size','30','5363,3','','.w-promo-code'),(926600,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(926601,'printshop','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(926602,'printshop','.message.success','font-size','30','3','',''),(926603,'printshop','.w-reviews .heading-3','font-size','37','3','','.w-reviews'),(926604,'printshop','.b-sub-totals .historyTotal table td','font-size','18','','','.b-sub-totals'),(926605,'printshop','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(926606,'printshop','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(926607,'printshop','.b-info .info','font-size','30','3','','.b-info'),(926608,'printshop','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(926609,'printshop','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(926610,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','40','5333','','.p-quote-checkout-success'),(926612,'printshop','.b-info .info strong','font-size','18','','','.b-info'),(926613,'printshop','.b-form .checkbox-style:checked + .checkbox-span:before','font-size','18','','','.b-form'),(926615,'printshop','.w-social-links a','font-size','30','5333','','.w-social-links'),(926616,'printshop','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(926617,'printshop','.b-info .info strong','font-size','18','','','.b-info'),(926618,'printshop','.b-email .name','font-size','14','','','.b-email'),(926619,'printshop','.b-email .heading-qty','font-size','14','','','.b-email'),(926620,'printshop','.p-quick-order-index .stock','font-size','12','','','.p-quick-order-index'),(926621,'printshop','.b-email .price','font-size','14','','','.b-email'),(926622,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','40','5333','','.p-quote-checkout-success'),(926623,'printshop','.w-cart-compare .js-cart_totals_container','font-size','14','','','.w-cart-compare'),(926624,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','40','5333','','.p-quote-checkout-success'),(926625,'printshop','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(926626,'printshop','.b-bottom .alert-message','font-size','18','','','.b-bottom'),(926627,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(926628,'printshop','.w-cart-compare .product .name a','font-size','14','','','.w-cart-compare'),(926629,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(926630,'printshop','.b-email .totals-label','font-size','18','','','.b-email'),(926631,'printshop','.w-checkout-credit-amount .btn-remove','font-size','12','','','.w-checkout-credit-amount'),(926633,'printshop','.b-info-popup .info-popup','font-size','20','3','','.b-info-popup'),(926634,'printshop','.b-info .info','font-size','30','3','','.b-info'),(926635,'printshop','.b-email .name','font-size','14','','','.b-email'),(926636,'printshop','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(926637,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','40','5333','','.p-quote-checkout-success'),(926638,'printshop','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(926639,'printshop','.b-info .info strong','font-size','18','','','.b-info'),(926640,'printshop','.b-email .price','font-size','14','','','.b-email'),(926641,'printshop','.b-email .heading-model','font-size','14','','','.b-email'),(926642,'printshop','.b-email .heading-name','font-size','14','','','.b-email'),(926643,'printshop','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(926644,'printshop','.b-email .heading-price','font-size','14','','','.b-email'),(926645,'printshop','.b-email .model','font-size','14','','','.b-email'),(926646,'printshop','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(926647,'printshop','.order-summary .price-row.ot_coupon .title','font-size','18','3','','.order-summary'),(926648,'printshop','.w-cart-shipping-estimator .address-item','font-size','14','','','.w-cart-shipping-estimator'),(926649,'printshop','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','font-size','20','','','.b-products-listing'),(926650,'printshop','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-size','20','','','.b-products-listing'),(926651,'printshop','.b-products-listing .products-listing .attribute-qty-block','font-size','14','','','.b-products-listing'),(926652,'printshop','.w-cart-credit-amount .btn-remove','font-size','12','','','.w-cart-credit-amount'),(926653,'printshop','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(926654,'printshop','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(926655,'printshop','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(926657,'printshop','.p-quick-order-index .in-stock, .p-quick-order-index .out-stock','font-size','12','','','.p-quick-order-index'),(926658,'printshop','.b-email .heading-price','font-size','14','','','.b-email'),(926659,'printshop','.b-email .name','font-size','14','','','.b-email'),(926660,'printshop','.b-email .heading-name','font-size','14','','','.b-email'),(926661,'printshop','.b-form .middle-form .middle-rating span','font-size','26','','','.b-form'),(926662,'printshop','.b-info .info','font-size','30','3','','.b-info'),(926664,'printshop','.w-product-customers-activity .customers-activity','font-size','16','','','.w-product-customers-activity'),(926665,'printshop','.w-product-available-in-warehouses .heading','font-size','18','','','.w-product-available-in-warehouses'),(926666,'printshop','.b-bottom .confirm-popup .confirm-text','font-size','20','','','.b-bottom'),(926667,'printshop','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(926668,'printshop','.b-email .qty','font-size','14','','','.b-email'),(926669,'printshop','.b-page-name .page-name','font-size','20','','','.b-page-name'),(926673,'printshop','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(926674,'printshop','.p-sample-checkout-success .page-success .text-1','font-size','80','3','','.p-sample-checkout-success'),(926675,'printshop','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-size','22','','','.order-summary'),(926677,'printshop','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(926678,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(926679,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(926680,'printshop','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(926681,'printshop','.w-menu-horizontal .menu-ico','font-size','23','','','.w-menu-horizontal'),(926682,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(926683,'printshop','.w-promo-code .holder','font-size','30','5363,3','','.w-promo-code'),(926684,'printshop','.w-categories h2.name','font-size','20','','','.w-categories'),(926685,'printshop','.w-cart-checkout-btn a','font-size','17','5333','','.w-cart-checkout-btn'),(926686,'printshop','.price .old','font-size','0.6','','',''),(926687,'printshop','.w-cart-compare .product-actions .dropdown-toggle','font-size','18','3','','.w-cart-compare'),(926688,'printshop','.w-social-links a','font-size','24','','','.w-social-links'),(926689,'printshop','.b-fancybox .fancybox-close','font-size','26','','','.b-fancybox'),(926690,'printshop','.b-select-suggest .select2-search-choice-close','font-size','1','','','.b-select-suggest'),(926691,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-size','100','','','.b-select-suggest'),(926692,'printshop','.b-select-suggest .select2-search input','font-size','1','','','.b-select-suggest'),(926693,'printshop','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(926694,'printshop','.p-sample-checkout-success .page-success .text-1','font-size','40','5333','','.p-sample-checkout-success'),(926695,'printshop','.w-cart-compare .product-actions','font-size','12','','','.w-cart-compare'),(926696,'printshop','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(926697,'printshop','.w-personal-gift-status-bar .inform','font-size','14','','','.w-personal-gift-status-bar'),(926698,'printshop','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(926699,'printshop','.w-quote-products .empty','font-size','24','','','.w-quote-products'),(926700,'printshop','.b-bottom .footerTitle','font-size','24','','','.b-bottom'),(926701,'printshop','.w-account-addresses-list .addsess-suggestion-item','font-size','14','','','.w-account-addresses-list'),(926702,'printshop','.w-communication-post .communication-post-date','font-size','14','','','.w-communication-post'),(926703,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.b-data-table'),(926704,'printshop','.w-communication-post .communication-post-attach','font-size','14','','','.w-communication-post'),(926705,'printshop','.b-products-listing .products-listing .bonusPoints','font-size','13','','','.b-products-listing'),(926706,'printshop','.b-products-listing .products-listing .model','font-size','14','','','.b-products-listing'),(926707,'printshop','.b-products-listing .btn-preloader','font-size','24','3','','.b-products-listing'),(926708,'printshop','.b-products-listing .loader','font-size','30','4','','.b-products-listing'),(926709,'printshop','.b-products-listing .promos-info .promo-name','font-size','14','','','.b-products-listing'),(926710,'printshop','.b-products-listing .wedding-registry-count','font-size','14','','','.b-products-listing'),(926712,'printshop','.w-quote .cart-box-link','font-size','30','3','','.w-quote'),(926713,'printshop','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(926714,'printshop','.p-quote-checkout-success .page-success .text-2','font-size','30','5333','','.p-quote-checkout-success'),(926715,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','40','5333','','.p-quote-checkout-success'),(926716,'printshop','.b-email-editor .price','font-size','18','','','.b-email-editor'),(926717,'printshop','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(926718,'printshop','.b-form .cart-popup .price','font-size','18','','','.b-form'),(926719,'printshop','.b-email-editor .price','font-size','18','','','.b-email-editor'),(926720,'printshop','.b-email .heading-model','font-size','14','','','.b-email'),(926721,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','40','5333','','.p-quote-checkout-success'),(926723,'printshop','.w-top-categories h2.name','font-size','18','','','.w-top-categories'),(926724,'printshop','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(926725,'printshop','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(926726,'printshop','.w-product-reviews .reviews-list span','font-size','22','','','.w-product-reviews'),(926727,'printshop','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(926728,'printshop','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(926729,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-size','inherit','','',''),(926730,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-size','inherit','','','.b-h-inline'),(926731,'printshop','h1, .heading-1','font-size','50','','',''),(926732,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','font-size','31','','','.w-communication-new-topic'),(926733,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','font-size','31','','','.w-communication-new-topic'),(926734,'printshop','.b-page-name .page-name','font-size','20','','','.b-page-name'),(926735,'printshop','.b-email .heading-price','font-size','14','','','.b-email'),(926736,'printshop','.b-email .totals-label','font-size','18','','','.b-email'),(926737,'printshop','.b-email .price','font-size','14','','','.b-email'),(926738,'printshop','.b-email .heading-name','font-size','14','','','.b-email'),(926739,'printshop','.b-bottom .popup-heading','font-size','16','','','.b-bottom'),(926740,'printshop','.w-promo-code .holder','font-size','30','5363,3','','.w-promo-code'),(926741,'printshop','.p-quote-checkout-success .page-success .text-2','font-size','30','5333','','.p-quote-checkout-success'),(926742,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(926743,'printshop','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(926744,'printshop','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(926745,'printshop','.b-email .model','font-size','14','','','.b-email'),(926746,'printshop','.w-cart-compare .atr-col','font-size','20','3','','.w-cart-compare'),(926747,'printshop','.w-quote .cart-box-link','font-size','25','5342,3','','.w-quote'),(926748,'printshop','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(926749,'printshop','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(926750,'printshop','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(926751,'printshop','.b-email .qty','font-size','14','','','.b-email'),(926752,'printshop','.b-email .model','font-size','14','','','.b-email'),(926753,'printshop','.b-email .totals-label','font-size','18','','','.b-email'),(926754,'printshop','.checkbox input:checked + span:before','font-size','18','','',''),(926755,'printshop','.p-quick-order-index .dataTables_info','font-size','14','','','.p-quick-order-index'),(926756,'printshop','.w-cart-listing .item .gift-wrap label','font-size','14','','','.w-cart-listing'),(926757,'printshop','.w-cart-listing .item .attributes','font-size','14','','','.w-cart-listing'),(926758,'printshop','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-size','12','','','.w-cart-listing'),(926759,'printshop','.w-cart-listing .points-earn','font-size','12','','','.w-cart-listing'),(926760,'printshop','.w-cart-listing .points-redeem','font-size','14','','','.w-cart-listing'),(926761,'printshop','.w-cart-listing .points-redeem','font-size','14','3','','.w-cart-listing'),(926762,'printshop','.w-cart-listing .remove-btn','font-size','16','','','.w-cart-listing'),(926763,'printshop','.w-cart-give-away .ga_name','font-size','16','','','.w-cart-give-away'),(926764,'printshop','.w-cart-give-away .ga_qty','font-size','20','','','.w-cart-give-away'),(926765,'printshop','.w-cart-give-away .ga_qty','font-size','17','5333','','.w-cart-give-away'),(926766,'printshop','.w-cart-discount-coupon .btn-remove','font-size','12','','','.w-cart-discount-coupon'),(926770,'printshop','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(926771,'printshop','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(926772,'printshop','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(926773,'printshop','.b-upload-file .snapshot','font-size','18','','','.b-upload-file'),(926774,'printshop','.b-fancybox .fancybox-nav span','font-size','34','','','.b-fancybox'),(926775,'printshop','.b-email-editor .price','font-size','18','','','.b-email-editor'),(926776,'printshop','.b-email .heading-qty','font-size','14','','','.b-email'),(926777,'printshop','.w-promo-code .holder','font-size','30','5363,3','','.w-promo-code'),(926779,'printshop','.w-tabs .accordion-heading','font-size','24','','','.w-tabs'),(926780,'printshop','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(926781,'printshop','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(926782,'printshop','.b-compare .clear_all','font-size','16','4','','.b-compare'),(926783,'printshop','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(926784,'printshop','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(926785,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-size','inherit','','','.w-contact-contacts'),(926787,'printshop','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(926788,'printshop','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(926789,'printshop','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(926790,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(926791,'printshop','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(926792,'printshop','.w-checkout-create-account .account-benefits strong','font-size','18','3','','.w-checkout-create-account'),(926793,'printshop','.w-filters .head-filter-widget > span','font-size','18','5342','','.w-filters'),(926794,'printshop','.w-filters .head-filter-widget','font-size','21','5347','','.w-filters'),(926795,'printshop','.w-filters .filter-box-head','font-size','20','','','.w-filters'),(926796,'printshop','.w-filters .view_more','font-size','16','4','','.w-filters'),(926798,'printshop','.b-bottom .pop-up-close','font-size','25','','','.b-bottom'),(926799,'printshop','.w-filters .head-filter-widget','font-size','24','','','.w-filters'),(926800,'printshop','.order-summary .price-row.ot_bonus_points .title','font-size','12','3','','.order-summary'),(926801,'printshop','.b-form #payment_method .title','font-size','16','','','.b-form'),(926802,'printshop','.p-quote-checkout-success .page-success .text-2','font-size','30','5333','','.p-quote-checkout-success'),(926803,'printshop','.b-email .heading-model','font-size','14','','','.b-email'),(926804,'printshop','.b-email .heading-qty','font-size','14','','','.b-email'),(926805,'printshop','.b-page-name .page-name','font-size','20','','','.b-page-name'),(926806,'printshop','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(926807,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(926808,'printshop','.heading-3, h3, .h-block h3','font-size','20','','',''),(926809,'printshop','.heading-2, h2, .h-block h2','font-size','24','','',''),(926810,'printshop','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(926811,'printshop','.btn-3','font-size','16','','',''),(926812,'printshop','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(926813,'printshop','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(926814,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','font-size','20','','','.b-switch'),(926815,'printshop','.b-page-name .page-name','font-size','20','','','.b-page-name'),(926816,'printshop','.b-info .info strong','font-size','18','','','.b-info'),(926817,'printshop','.b-form .middle-form label.slim','font-size','14','','','.b-form'),(926818,'printshop','.b-email .heading-price','font-size','14','','','.b-email'),(926819,'printshop','.b-select-suggest .select2-container .select2-choice abbr','font-size','1','','','.b-select-suggest'),(926820,'printshop','.b-email .qty','font-size','14','','','.b-email'),(926821,'printshop','.b-email .totals-label','font-size','18','','','.b-email'),(926822,'printshop','.w-filters .mobileCollapse','font-size','20','4','','.w-filters'),(926823,'printshop','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-size','22','','','.w-filters'),(926824,'printshop','.b-product-images .media-popup .mp-close','font-size','50','','','.b-product-images'),(926825,'printshop','.b-product-images .media-popup .slick-dots li','font-size','30','','','.b-product-images'),(926826,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','font-size','50','3','','.b-product-images'),(926827,'printshop','.w-product-name h1','font-size','36','','','.w-product-name'),(926828,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(926829,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(926830,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(926831,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(926832,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(926833,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(926834,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(926835,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(926836,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(926837,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev63_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(926838,'printshop','.b-trade-approval .middle-form label','font-size','16','','','.b-trade-approval'),(926839,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','font-size','14','','','.b-trade-approval'),(926840,'printshop','.w-account-personal-catalog .list-switcher a','font-size','20','','','.w-account-personal-catalog'),(926841,'printshop','.w-catalog-compare .checkbox input:checked + span:before','font-size','24','','','.w-catalog-compare'),(926842,'printshop','.w-catalog-compare .model','font-size','14','','','.w-catalog-compare'),(926843,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-size','26','3','','.w-catalog-compare'),(926844,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','font-size','0','','','.w-catalog-compare'),(926845,'printshop','.w-catalog-compare .item .compare','font-size','0','','','.w-catalog-compare'),(926846,'printshop','.w-catalog-compare .cross-box .different-all > div','font-size','15','','','.w-catalog-compare'),(926847,'printshop','.w-catalog-compare .name','font-size','12','','','.w-catalog-compare'),(926848,'printshop','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-size','40','','','.w-delivery-day'),(926849,'printshop','.w-delivery-day .ends','font-size','26','','','.w-delivery-day'),(926850,'printshop','.w-delivery-day .left-text-left','font-size','24','','','.w-delivery-day'),(926851,'printshop','.w-delivery-day .left-text-right','font-size','24','','','.w-delivery-day'),(926852,'printshop','.w-delivery-day .title','font-size','18','','','.w-delivery-day'),(926855,'printshop','.tripleBanner .w-html_box > div:nth-child(1)','font-size','18','','','.tripleBanner'),(926856,'printshop','.tripleBanner .w-html_box > div:nth-child(2)','font-size','20','','','.tripleBanner'),(926857,'printshop','.b-products-listing .products-listing .name a','font-size','24','','','.b-products-listing'),(926858,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','0','','','.b-slick'),(926859,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','20','3','','.b-slick'),(926862,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','font-size','16','','','.b-products-listing'),(926863,'printshop','.w-cart-listing .headings .head','font-size','14','','','.w-cart-listing'),(926864,'printshop','.LeftCategories .w-menu-simple ul li a','font-size','18','','','.LeftCategories'),(926865,'printshop','.w-subscribers .btn-submit','font-size','16','','','.w-subscribers'),(926866,'printshop','.w-quote .buttons .btn','font-size','14','','','.w-quote'),(926867,'printshop','.w-quote .cart-box-link','font-size','18','','','.w-quote'),(926868,'printshop','.w-quote .cart-total','font-size','1.2','','','.w-quote'),(926869,'printshop','.w-quote .multicart .count','font-size','14','','','.w-quote'),(926870,'printshop','.w-quote .qty','font-size','0.6','4','','.w-quote'),(926871,'printshop','.w-quote .sub-total-row','font-size','18','','','.w-quote'),(926873,'printshop','.w-product-personal-catalog-button .btn','font-size','16','','','.w-product-personal-catalog-button'),(926874,'printshop','.b-quantity .qty-box .bigger','font-size','18','','','.b-quantity'),(926875,'printshop','.b-quantity .qty-box .smaller','font-size','18','','','.b-quantity'),(926876,'printshop','.rating, .ratingCounts','font-size','14','','',''),(926877,'printshop','.w-product-sale-ends .ends','font-size','24','','','.w-product-sale-ends'),(926878,'printshop','.w-product-sale-ends .left-count-days','font-size','30','','','.w-product-sale-ends'),(926879,'printshop','.w-product-sale-ends .left-count-hours','font-size','30','','','.w-product-sale-ends'),(926880,'printshop','.w-product-sale-ends .left-text-left','font-size','24','','','.w-product-sale-ends'),(926881,'printshop','.w-product-sale-ends .left-text-right','font-size','24','','','.w-product-sale-ends'),(926882,'printshop','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(926883,'printshop','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(926884,'printshop','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(926885,'printshop','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(926886,'printshop','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(926887,'printshop','.w-product-bonus-points > div','font-size','14','','','.w-product-bonus-points'),(926888,'printshop','.warrantyProduct .title','font-size','18','','','.warrantyProduct'),(926889,'printshop','.warrantyProduct .seeDetails a','font-size','14','','','.warrantyProduct'),(926890,'printshop','.w-compare .price','font-size','18','','','.w-compare'),(926891,'printshop','.w-compare .name','font-size','14','','','.w-compare'),(926892,'printshop','.w-compare .clear-compare-button','font-size','14','','','.w-compare'),(926893,'printshop','.w-files-catalog-widgets-files-catalog .name','font-size','16','','','.w-files-catalog-widgets-files-catalog'),(926894,'printshop','.w-files-catalog-widgets-files-list .name','font-size','18','','','.w-files-catalog-widgets-files-list'),(926895,'printshop','.w-sample .buttons .btn','font-size','14','','','.w-sample'),(926896,'printshop','.w-sample .cart-box-link','font-size','18','','','.w-sample'),(926897,'printshop','.w-sample .cart-box-link','font-size','30','3','','.w-sample'),(926898,'printshop','.w-sample .cart-total','font-size','1.2','','','.w-sample'),(926899,'printshop','.w-sample .multicart .count','font-size','14','','','.w-sample'),(926900,'printshop','.w-sample .qty','font-size','0.7','4','','.w-sample'),(926901,'printshop','.w-sample .sub-total-row','font-size','18','','','.w-sample'),(926902,'printshop','.w-sample .cart-box-link','font-size','25','5342,3','','.w-sample'),(926903,'printshop','.w-filters-simple .integrate-price-holder','font-size','20','','','.w-filters-simple'),(926904,'printshop','.w-filters-simple .integrate-price','font-size','30','','','.w-filters-simple'),(926905,'printshop','.w-cart-discount-coupon .title','font-size','20','','','.w-cart-discount-coupon'),(926906,'printshop','.w-cart-sub-total .title','font-size','24','','','.w-cart-sub-total'),(926907,'printshop','.w-cart-sub-total .price','font-size','24','','','.w-cart-sub-total'),(926908,'printshop','.w-cart-bonus-points .title','font-size','20','','','.w-cart-bonus-points'),(926909,'printshop','.shipping-ico .heading-3','font-size','24','','','.shipping-ico'),(926910,'printshop','.w-cart-up-sell .products-listing .price','font-size','18','','','.w-cart-up-sell'),(926911,'printshop','.w-cart-up-sell .products-listing .name a','font-size','16','','','.w-cart-up-sell'),(926912,'printshop','.w-cart-gift-certificate .heading-4','font-size','20','','','.w-cart-gift-certificate'),(926913,'printshop','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(926914,'printshop','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(926915,'printshop','.w-cart-order-reference .heading-4','font-size','20','','','.w-cart-order-reference'),(926916,'printshop','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(926917,'printshop','.w-product-bundle .bundle_price .old','font-size','0.8','','','.w-product-bundle'),(926918,'printshop','.w-product-in-bundles .bundle_price .old','font-size','0.6','','','.w-product-in-bundles'),(926919,'printshop','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(926920,'printshop','.w-product-quantity-discounts .count','font-size','18','','','.w-product-quantity-discounts'),(926922,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','font-size','inherit','','','.b-products-listing'),(926923,'printshop','.b-pagination .pagination .next a, .b-pagination .pagination .next span','font-size','0','','','.b-pagination'),(926924,'printshop','.b-pagination .pagination .prev a, .b-pagination .pagination .prev span','font-size','0','','','.b-pagination'),(926925,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','font-size','20','3','','.b-pagination'),(926926,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','font-size','20','3','','.b-pagination'),(926927,'printshop','.w-catalog-compare .price','font-size','20','','','.w-catalog-compare'),(926928,'printshop','.w-catalog-compare .out-stock','font-size','12','','','.w-catalog-compare'),(926929,'printshop','.w-product-quantity-discounts .item .price','font-size','24','5347','','.w-product-quantity-discounts'),(926930,'printshop','.w-product-properties-filters-widgets-chosen-filters .remove','font-size','0','','','.w-product-properties-filters-widgets-chosen-filters'),(926931,'printshop','.w-product-properties-filters-widgets-chosen-filters .remove','font-size','20','3','','.w-product-properties-filters-widgets-chosen-filters'),(926932,'printshop','.w-product-multi-inventory .radio-attributes > span','font-size','18','','','.w-product-multi-inventory'),(926933,'printshop','.w-product-sale-ends .left-text-right, .w-product-sale-ends .left-text-left','font-size','18','5347','','.w-product-sale-ends'),(926934,'printshop','.w-product-sale-ends .left-count-days, .w-product-sale-ends .left-count-hours','font-size','24','5347','','.w-product-sale-ends'),(926935,'printshop','.w-product-sale-ends .ends','font-size','21','5347','','.w-product-sale-ends'),(926936,'printshop','.heading-2, h2, .h-block h2','font-size','21','5342','',''),(926937,'printshop','.heading-3, h3, .h-block h3','font-size','19','5342','',''),(926938,'printshop','.heading-4, h4, .h-block h4','font-size','17','5342','',''),(926939,'printshop','.w-product-name h1','font-size','24','5342','','.w-product-name'),(926940,'printshop','.b-products-listing .products-listing.list-rows .stock','font-size','14','','','.b-products-listing'),(926941,'printshop','.b-products-listing .products-listing.list-b2b .stock','font-size','14','','','.b-products-listing'),(926942,'printshop','.b-products-listing .products-listing .radio-attributes > span','font-size','18','','','.b-products-listing'),(926943,'printshop','.b-products-listing .products-listing .radio-attributes .option','font-size','14','','','.b-products-listing'),(926944,'printshop','.w-product-collection .stock > span','font-size','14','','','.w-product-collection'),(926945,'printshop','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(926946,'printshop','.w-product-collection .right-area .separate-text, .w-product-collection .right-area .separate','font-size','16','','','.w-product-collection'),(926947,'printshop','.w-product-collection .together','font-size','16','','','.w-product-collection'),(926948,'printshop','.w-product-collection .right-area .btn','font-size','18','','','.w-product-collection'),(926949,'printshop','.price .special-promote','font-size','16','','',''),(926950,'printshop','.w-breadcrumb .catalog-breadcrumb','font-size','14','5333','','.w-breadcrumb'),(926951,'printshop','.w-product-attributes .radio-attributes > span','font-size','18','','','.w-product-attributes'),(926952,'printshop','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(926953,'printshop','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(926954,'printshop','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(926955,'printshop','.w-product-properties li','font-size','14','','','.w-product-properties'),(926956,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','font-size','0','','','.w-questionnaire-widgets-questionnaire'),(926957,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','font-size','30','3','','.w-questionnaire-widgets-questionnaire'),(926958,'printshop','.w-product-groups .radioBoxHead','font-size','18','','','.w-product-groups'),(926959,'printshop','.w-product-groups .val1','font-size','16','','','.w-product-groups'),(926960,'printshop','.w-product-groups .val2','font-size','16','','','.w-product-groups'),(926961,'printshop','.w-product-groups .radioBox label .containerBlock img + .name + .val2','font-size','16','','','.w-product-groups'),(926962,'printshop','.b-products-listing .mix-attributes .attribute-qty-block > span','font-size','13','','','.b-products-listing'),(926963,'printshop','.w-product-custom-bundle .heading-3','font-size','16','','','.w-product-custom-bundle'),(926964,'printshop','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(926965,'printshop','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(926966,'printshop','.w-product-custom-bundle .right-area .separate-text','font-size','16','','','.w-product-custom-bundle'),(926967,'printshop','.w-product-custom-bundle .right-area .separate','font-size','36','','','.w-product-custom-bundle'),(926968,'printshop','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','font-size','24','','','.w-product-custom-bundle'),(926969,'printshop','.w-delivery-location-top-location-list .deliveryName','font-size','18','','','.w-delivery-location-top-location-list'),(926970,'printshop','.w-delivery-location-location-list .deliveryName','font-size','18','','','.w-delivery-location-location-list'),(926971,'printshop','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(926972,'printshop','.w-delivery-location-location-list .deliveryListParrent a','font-size','24','','','.w-delivery-location-location-list'),(926973,'printshop','.w-delivery-location-location-list .deliveryListParrent a','font-size','18','5342','','.w-delivery-location-location-list'),(926974,'printshop','.w-delivery-location-location-list .deliveryList li','font-size','14','5342','','.w-delivery-location-location-list'),(926975,'printshop','.w-delivery-location-featured-list .deliveryName','font-size','18','','','.w-delivery-location-featured-list'),(926976,'printshop','.btn-2','font-size','16','5333','',''),(926977,'printshop','.w-sale-category .badge','font-size','20','','','.w-sale-category'),(926978,'printshop','.w-sale-category .ends','font-size','26','','','.w-sale-category'),(926979,'printshop','.w-sale-category .left-count-days','font-size','40','','','.w-sale-category'),(926980,'printshop','.w-sale-category .left-count-hours','font-size','40','','','.w-sale-category'),(926981,'printshop','.w-sale-category .left-text-left','font-size','24','','','.w-sale-category'),(926982,'printshop','.w-sale-category .left-text-right','font-size','24','','','.w-sale-category'),(926983,'printshop','.w-sale-category .name','font-size','20','','','.w-sale-category'),(926984,'printshop','.w-sale-category .old','font-size','45','','','.w-sale-category'),(926985,'printshop','.w-sale-category .percents','font-size','30','','','.w-sale-category'),(926986,'printshop','.w-sale-category .special-price','font-size','70','','','.w-sale-category'),(926987,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-name','font-size','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(926988,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-name','font-size','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(926989,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description + div','font-size','18','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(926990,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description + div','font-size','18','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(926991,'printshop','.w-delivery-location-list-by-page .name','font-size','18','','','.w-delivery-location-list-by-page'),(926992,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','font-size','14','','','.w-product-properties-icons'),(926993,'printshop','.w-delivery-location-cross-pages .name','font-size','18','','','.w-delivery-location-cross-pages'),(926994,'printshop','.w-cart-credit-amount .amount-title','font-size','20','','','.w-cart-credit-amount'),(926995,'printshop','.w-catalog-delivery-locations .name','font-size','18','','','.w-catalog-delivery-locations'),(926996,'printshop','.w-product-bonus-points .bonus-points-cost','font-size','16','','','.w-product-bonus-points'),(926997,'printshop','.w-product-bonus-points .bonus-points-cost','font-size','14','5363','','.w-product-bonus-points'),(926998,'printshop','.w-product-designer-designer .grnamebox .title-sortable','font-size','16','','','.w-product-designer-designer'),(926999,'printshop','.w-product-designer-designer .prodDesignerType label','font-size','14','','','.w-product-designer-designer'),(927000,'printshop','.w-press-reviews-widgets-press-reviews .date','font-size','13','','','.w-press-reviews-widgets-press-reviews'),(927001,'printshop','.w-press-reviews-widgets-press-reviews .heading-3','font-size','30','','','.w-press-reviews-widgets-press-reviews'),(927002,'printshop','.w-press-reviews-widgets-press-reviews .rating','font-size','18','','','.w-press-reviews-widgets-press-reviews'),(927003,'printshop','.w-press-reviews-widgets-press-reviews-list .product-name','font-size','20','','','.w-press-reviews-widgets-press-reviews-list'),(927004,'printshop','.b-products-listing .productGroup label a','font-size','12','','','.b-products-listing'),(927005,'printshop','.w-support-system-filter .filter_cats.level-0 > li > a','font-size','18','','','.w-support-system-filter'),(927006,'printshop','.w-communication-post .btn.refresh','font-size','30','','','.w-communication-post'),(927007,'printshop','.w-rma-returns-history .btn','font-size','13','','','.w-rma-returns-history'),(927008,'printshop','.w-rma-returns-history .column .title','font-size','14','','','.w-rma-returns-history'),(927009,'printshop','.w-rma-returns-history .fromTo label >span','font-size','12','','','.w-rma-returns-history'),(927010,'printshop','.w-rma-returns-history .icons .excel','font-size','20','3','','.w-rma-returns-history'),(927011,'printshop','.w-rma-returns-history .icons .print','font-size','20','3','','.w-rma-returns-history'),(927012,'printshop','.w-rma-returns-history .icons a','font-size','0','','','.w-rma-returns-history'),(927013,'printshop','.w-rma-returns-history .sorting_1','font-size','13','','','.w-rma-returns-history'),(927014,'printshop','.w-rma-returns-history .tableTitle','font-size','18','','','.w-rma-returns-history'),(927015,'printshop','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(927016,'printshop','.b-products-listing .products-listing .bonus-points-cost','font-size','13','','','.b-products-listing'),(927017,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-name','font-size','20','','','.w-catalog-pages-category-pages-list'),(927018,'printshop','.w-predefined-promotion .heading-3','font-size','48','','','.w-predefined-promotion'),(927019,'printshop','.w-predefined-promotion .nextdiscount .heading','font-size','18','3','','.w-predefined-promotion'),(927020,'printshop','.w-predefined-promotion .nextdiscount .heading','font-size','26','','','.w-predefined-promotion'),(927021,'printshop','.w-predefined-promotion .nextdiscount .item-holder .name','font-size','14','','','.w-predefined-promotion'),(927022,'printshop','.w-predefined-promotion .nextdiscount .promo-for-each','font-size','14','','','.w-predefined-promotion'),(927023,'printshop','.w-predefined-promotion .prom-multi-discount .heading','font-size','26','','','.w-predefined-promotion'),(927024,'printshop','.w-predefined-promotion .prom-multi-discount .promo-group','font-size','16','','','.w-predefined-promotion'),(927025,'printshop','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','font-size','14','','','.w-predefined-promotion'),(927026,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','font-size','13','','','.w-predefined-promotion'),(927027,'printshop','.w-predefined-promotion .promo-cart-discount .item a','font-size','14','','','.w-predefined-promotion'),(927028,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','font-size','13','','','.w-predefined-promotion'),(927029,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','font-size','16','','','.w-predefined-promotion'),(927030,'printshop','.w-predefined-promotion .promo-item','font-size','24','','','.w-predefined-promotion'),(927031,'printshop','.w-predefined-promotion .promo-salemaker .content a','font-size','14','','','.w-predefined-promotion'),(927032,'printshop','.w-predefined-promotion .promo-salemaker .discount','font-size','13','','','.w-predefined-promotion'),(927033,'printshop','.w-supplier-purchase-supplier-products .active .select_item > div:before','font-size','20','','','.w-supplier-purchase-supplier-products'),(927042,'printshop','.b-quantity .qty-box input[type=\"text\"]','font-size','16','','','.b-quantity'),(927043,'printshop','.w-product-model ','font-size','18','','','.w-product-model'),(927044,'printshop','.w-product-quantity-discounts .price','font-size','21','','','.w-product-quantity-discounts'),(927045,'printshop','.popup-box h1','font-size','36','','',''),(927046,'printshop','.w-cart-listing .name a','font-size','16','','','.w-cart-listing'),(927047,'printshop','.w-cart-listing .remove-btn span','font-size','12','','','.w-cart-listing'),(927048,'printshop','.tripleLine .text-banner-2 > div','font-size','24','','','.tripleLine'),(927049,'printshop','.tripleLine .text-banner-2 > div a','font-size','16','','','.tripleLine'),(927050,'printshop','.cartTitle span','font-size','50','','','.cartTitle'),(927051,'printshop','.b-select-suggest .select2-container .select2-choice','font-size','14','','','.b-select-suggest'),(927052,'printshop','.p-wedding-registry-view h1','font-size','22','3','','.p-wedding-registry-view'),(927053,'printshop','.p-wedding-registry-view h1','font-size','22','4','','.p-wedding-registry-view'),(927054,'printshop','.lowestPricedBox .title','font-size','48','','','.lowestPricedBox'),(927055,'printshop','.lowestPricedBox .descr','font-size','28','','','.lowestPricedBox'),(927056,'printshop','.lowestPricedBox .btn-2','font-size','23','','','.lowestPricedBox'),(927057,'printshop','.doubleBanner .btn-2','font-size','23','','','.doubleBanner'),(927058,'printshop','.doubleBanner .descr','font-size','28','','','.doubleBanner'),(927059,'printshop','.doubleBanner .title','font-size','48','','','.doubleBanner'),(927060,'printshop','.doubleBanner .btn-2','font-size','16','5347','','.doubleBanner'),(927061,'printshop','.doubleBanner .descr','font-size','1.8','5347','','.doubleBanner'),(927062,'printshop','.doubleBanner .title','font-size','2.6','5347','','.doubleBanner'),(927063,'printshop','.middleBanner .title','font-size','50','','','.middleBanner'),(927064,'printshop','.middleBanner .descr','font-size','30','','','.middleBanner'),(927065,'printshop','.middleBanner .btn-1','font-size','24','','','.middleBanner'),(927066,'printshop','.bottomDoubleBanner .btn-2','font-size','23','','','.bottomDoubleBanner'),(927067,'printshop','.bottomDoubleBanner .title','font-size','36','','','.bottomDoubleBanner'),(927068,'printshop','.bottomDoubleBanner .btn-2','font-size','16','5347','','.bottomDoubleBanner'),(927069,'printshop','.bottomDoubleBanner .title','font-size','3.6','5347','','.bottomDoubleBanner'),(927070,'printshop','.bottomBanner .title','font-size','50','','','.bottomBanner'),(927071,'printshop','.bottomBanner .descr','font-size','30','','','.bottomBanner'),(927072,'printshop','.bottomBanner .btn-1','font-size','24','','','.bottomBanner'),(927073,'printshop','.bottomBanner .icon-box > div','font-size','24','','','.bottomBanner'),(927076,'printshop','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','font-size','30','3','','.b-menu-burger_icon'),(927078,'printshop','.doubleBanner .title','font-size','21','5363','','.doubleBanner'),(927079,'printshop','.middleBanner .descr','font-size','1.8','5347','','.middleBanner'),(927080,'printshop','.middleBanner .title','font-size','2.8','5347','','.middleBanner'),(927081,'printshop','.middleBanner .btn-1','font-size','16','5342','','.middleBanner'),(927082,'printshop','.middleBanner .title','font-size','3','5342','','.middleBanner'),(927083,'printshop','.middleBanner .descr','font-size','1.8','5342','','.middleBanner'),(927084,'printshop','.b-products-listing .products-listing .name a','font-size','18','5342','','.b-products-listing'),(927085,'printshop','.bottomBanner .title','font-size','3.6','5347','','.bottomBanner'),(927086,'printshop','.bottomBanner .descr','font-size','2','5347','','.bottomBanner'),(927087,'printshop','.bottomBanner .btn-1','font-size','16','5347','','.bottomBanner'),(927088,'printshop','.bottomBanner .icon-box > div','font-size','18','5347','','.bottomBanner'),(927089,'printshop','.bottomBanner .title','font-size','4','5363','','.bottomBanner'),(927090,'printshop','.bottomDoubleBanner .title','font-size','21','5363','','.bottomDoubleBanner'),(927091,'printshop','.tripleLine .text-banner-2 > div','font-size','18','5333','','.tripleLine'),(927092,'printshop','.tripleLine .text-banner-2 > div a','font-size','14','5333','','.tripleLine'),(927093,'printshop','.w-cart-cart-tabs .w-tabs .tab-a','font-size','14','5363','','.w-cart-cart-tabs'),(927094,'printshop','.cartTitle span','font-size','36','5347','','.cartTitle'),(927095,'printshop','.w-cart-bonus-points .title','font-size','16','5333','','.w-cart-bonus-points'),(927096,'printshop','.w-cart-credit-amount .amount-title','font-size','16','5333','','.w-cart-credit-amount'),(927097,'printshop','.w-cart-discount-coupon .title','font-size','16','5333','','.w-cart-discount-coupon'),(927098,'printshop','.w-cart-sub-total .title, .w-cart-sub-total .price','font-size','21','5333','','.w-cart-sub-total'),(927099,'printshop','.b-products-listing .products-listing .name a','font-size','18','5347','','.b-products-listing'),(927100,'printshop','.b-products-listing .products-listing.list-productlisting .price','font-size','24','5347','','.b-products-listing'),(927101,'printshop','.cartTitle span','font-size','24','5333','','.cartTitle'),(927102,'printshop','.w-account-personal-catalog .list-switcher a','font-size','16','5363','','.w-account-personal-catalog'),(927103,'printshop','.b-sub-totals .historyTotal table td','font-size','16','5363','','.b-sub-totals'),(927104,'printshop','.b-sub-totals .historyTotal table tr:last-child td','font-size','18','5363','','.b-sub-totals'),(927105,'printshop','.p-payer-order-pay .heading-2','font-size','24','','','.p-payer-order-pay'),(927106,'printshop','.p-payer-order-pay .order-summary .heading-2','font-size','24','','','.p-payer-order-pay'),(927107,'printshop','.p-payer-order-pay .price-box','font-size','16','','','.p-payer-order-pay'),(927108,'printshop','.p-payer-order-pay .price-box .price','font-size','16','','','.p-payer-order-pay'),(927109,'printshop','.p-payer-order-pay .price-box .price-row.total','font-size','22','','','.p-payer-order-pay'),(927110,'printshop','.p-payer-order-pay .heading-2','font-size','24','5333','','.p-payer-order-pay'),(927111,'printshop','.p-payer-order-confirmation .heading-2','font-size','24','','','.p-payer-order-confirmation'),(927112,'printshop','.p-payer-order-confirmation .order-summary .heading-2','font-size','24','','','.p-payer-order-confirmation'),(927113,'printshop','.p-payer-order-confirmation .price-box','font-size','16','','','.p-payer-order-confirmation'),(927114,'printshop','.p-payer-order-confirmation .price-box .price','font-size','16','','','.p-payer-order-confirmation'),(927115,'printshop','.p-payer-order-confirmation .price-box .price-row.total','font-size','22','','','.p-payer-order-confirmation'),(927116,'printshop','.p-payer-order-confirmation .heading-2','font-size','24','5333','','.p-payer-order-confirmation'),(927117,'printshop','.w-product-bundle .bundle-total-price','font-size','24','','','.w-product-bundle'),(927118,'printshop','.w-product-quantity-discounts .item .price','font-size','18','5363','','.w-product-quantity-discounts'),(927119,'printshop','.w-product-bundle .price','font-size','24','','','.w-product-bundle'),(927120,'printshop','.popup-box h1','font-size','24','5333','',''),(927121,'printshop','.topBanner .content .btn','font-size','1.25','','','.topBanner'),(927122,'printshop','.topBanner .descr','font-size','1.77','','','.topBanner'),(927123,'printshop','.topBanner .ourPick .bottom','font-size','1.35','','','.topBanner'),(927124,'printshop','.topBanner .ourPick .top','font-size','1.25','','','.topBanner'),(927125,'printshop','.topBanner .title','font-size','3.15','','','.topBanner'),(927126,'printshop','.topBanner .content .btn','font-size','16','5342','','.topBanner'),(927127,'printshop','.topBanner .descr','font-size','2.865','5333','','.topBanner'),(927128,'printshop','.topBanner .ourPick .bottom','font-size','2.604','5333','','.topBanner'),(927129,'printshop','.topBanner .ourPick .top','font-size','2.344','5333','','.topBanner'),(927130,'printshop','.topBanner .title','font-size','5.469','5333','','.topBanner'),(927131,'printshop','.topBanner .content .btn','font-size','14','5363','','.topBanner'),(927132,'printshop','.bottomBanner .btn-1','font-size','14','5363','','.bottomBanner'),(927133,'printshop','.middleBanner .title','font-size','4','5333','','.middleBanner'),(927134,'printshop','.middleBanner .btn-1','font-size','14','5363','','.middleBanner'),(927135,'printshop','.tripleLine .banner-text-holder > div','font-size','24','','','.tripleLine'),(927136,'printshop','.tripleLine .banner-text-holder > div a','font-size','16','','','.tripleLine'),(927137,'printshop','.tripleLine .banner-text-holder > div','font-size','18','5333','','.tripleLine'),(927138,'printshop','.tripleLine .banner-text-holder > div a','font-size','14','5333','','.tripleLine'),(927139,'printshop','.order-summary .icon','font-size','18','3','','.order-summary'),(927140,'printshop','.order-summary .w-cart-listing .price','font-size','16','','','.order-summary'),(927141,'printshop','.w-cart-discount-coupon .title','font-size','21','4','','.w-cart-discount-coupon'),(927142,'printshop','.w-cart-discount-coupon .title','font-size','18','5333,4','','.w-cart-discount-coupon'),(927143,'printshop','.w-cart-checkout-btn .with-card','font-size','18','4','','.w-cart-checkout-btn'),(927144,'printshop','.p-quote-checkout-index .closeable-heading','font-size','30','3','','.p-quote-checkout-index'),(927145,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','font-size','16','','','.p-quote-checkout-index'),(927146,'printshop','.p-quote-checkout-index .heading-2','font-size','36','','','.p-quote-checkout-index'),(927147,'printshop','.p-quote-checkout-index .order-summary .heading-2','font-size','24','','','.p-quote-checkout-index'),(927148,'printshop','.p-quote-checkout-index .closeable-heading','font-size','24','5333,3','','.p-quote-checkout-index'),(927149,'printshop','.p-quote-checkout-index .heading-2','font-size','24','5333','','.p-quote-checkout-index'),(927154,'printshop','.account-address-book .address_book .btn-edit, .account-address-book .address_book .btn-delete','font-size','16','4','','.account-address-book'),(927155,'printshop','.account-address-book .address_book h2','font-size','18','','','.account-address-book'),(927156,'printshop','.account-address-book .leftMes div','font-size','18','','','.account-address-book'),(927186,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-size','18','','','.account-order-pay'),(927187,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-size','22','3','','.account-order-pay'),(927188,'printshop','.account-order-pay .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-order-pay'),(927189,'printshop','.account-order-pay .history_attr','font-size','14','','','.account-order-pay'),(927190,'printshop','.account-order-pay .not_fully_paid_td','font-size','30','','','.account-order-pay'),(927191,'printshop','.account-samples .not_fully_paid_td','font-size','30','','','.account-samples'),(927192,'printshop','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','font-size','16','','','.account-samples'),(927193,'printshop','.account-samples .order_history_table h2','font-size','24','','','.account-samples'),(927194,'printshop','.account-samples .order_history_table th','font-size','16','','','.account-samples'),(927195,'printshop','.account-samples .view_link','font-size','18','4','','.account-samples'),(927196,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-size','18','','','.account-sample-info'),(927197,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-size','22','3','','.account-sample-info'),(927198,'printshop','.account-sample-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-sample-info'),(927199,'printshop','.account-sample-info .history_attr','font-size','14','','','.account-sample-info'),(927200,'printshop','.account-sample-info .not_fully_paid_td','font-size','30','','','.account-sample-info'),(927201,'printshop','.account-sample-info .popup-tracking-number-link','font-size','18','','','.account-sample-info'),(927202,'printshop','.account-sample-info .trackings-nambers-label','font-size','20','','','.account-sample-info'),(927203,'printshop','.catalog-product-wrap .pn-direction','font-size','14','','','.catalog-product-wrap'),(927204,'printshop','.catalog-product-wrap .pn-image','font-size','14','3','','.catalog-product-wrap'),(927205,'printshop','.catalog-product-wrap .pn-name','font-size','14','','','.catalog-product-wrap'),(927206,'printshop','.catalog-product-wrap .w-product-price .price','font-size','24','','','.catalog-product-wrap'),(927207,'printshop','.catalog-product-wrap .pn-direction','font-size','10','5342','','.catalog-product-wrap'),(927208,'printshop','.shopping-cart-index .cart-page .empty','font-size','24','','','.shopping-cart-index'),(927209,'printshop','.shopping-cart-index .gift-code .heading-4','font-size','20','5333','','.shopping-cart-index'),(927210,'printshop','.checkout-index-wrap .closeable-heading','font-size','30','3','','.checkout-index-wrap'),(927211,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','font-size','16','','','.checkout-index-wrap'),(927212,'printshop','.checkout-index-wrap .heading-2','font-size','36','','','.checkout-index-wrap'),(927213,'printshop','.checkout-index-wrap .order-summary .heading-2','font-size','24','','','.checkout-index-wrap'),(927214,'printshop','.checkout-index-wrap .closeable-heading','font-size','24','5333,3','','.checkout-index-wrap'),(927215,'printshop','.checkout-index-wrap .heading-2','font-size','24','5333','','.checkout-index-wrap'),(927216,'printshop','.checkout-order-confirmation .discount-ico','font-size','30','3','','.checkout-order-confirmation'),(927217,'printshop','.checkout-order-confirmation .heading-2','font-size','24','','','.checkout-order-confirmation'),(927218,'printshop','.checkout-order-confirmation .order-summary .heading-2','font-size','24','','','.checkout-order-confirmation'),(927219,'printshop','.checkout-order-confirmation .price-box','font-size','16','','','.checkout-order-confirmation'),(927220,'printshop','.checkout-order-confirmation .price-box .price','font-size','16','','','.checkout-order-confirmation'),(927221,'printshop','.checkout-order-confirmation .price-box .price-row.total','font-size','22','','','.checkout-order-confirmation'),(927222,'printshop','.checkout-order-confirmation .heading-2','font-size','24','5333','','.checkout-order-confirmation'),(927223,'printshop','.checkout-success-wrap .page-success .text-1','font-size','80','3','','.checkout-success-wrap'),(927224,'printshop','.checkout-success-wrap .page-success .text-1','font-size','60','','','.checkout-success-wrap'),(927225,'printshop','.checkout-success-wrap .page-success .text-2','font-size','34','','','.checkout-success-wrap'),(927226,'printshop','.checkout-success-wrap .page-success .text-3','font-size','27','','','.checkout-success-wrap'),(927227,'printshop','.checkout-success-wrap .page-success .text-1','font-size','40','5333','','.checkout-success-wrap'),(927228,'printshop','.checkout-success-wrap .page-success .text-2','font-size','30','5333','','.checkout-success-wrap'),(927229,'printshop','.checkout-success-wrap .page-success .text-1','font-size','36','5363','','.checkout-success-wrap'),(927230,'printshop','.checkout-success-wrap .page-success .text-1','font-size','60','5363,3','','.checkout-success-wrap'),(927231,'printshop','.checkout-success-wrap .page-success .text-2','font-size','21','5363','','.checkout-success-wrap'),(927232,'printshop','.checkout-success-wrap .page-success .text-3','font-size','16','5363','','.checkout-success-wrap'),(927233,'printshop','.checkout-login-wrap .password-forgotten-link','font-size','14','','','.checkout-login-wrap'),(927234,'printshop','.index-wrap h2, .index-wrap .heading-2','font-size','50','','','.index-wrap'),(927235,'printshop','.index-wrap h2, .index-wrap .heading-2','font-size','36','5347','','.index-wrap'),(927236,'printshop','.index-wrap h2, .index-wrap .heading-2','font-size','24','5333','','.index-wrap'),(927238,'printshop','.success-page .check-ico-block','font-size','60','3','','.success-page'),(927239,'printshop','.success-page .comment-ico','font-size','30','3','','.success-page'),(927240,'printshop','.success-page .discount-ico','font-size','30','3','','.success-page'),(927241,'printshop','.success-page .order-ico','font-size','36','3','','.success-page'),(927242,'printshop','.success-page .order_totals .price','font-size','18','','','.success-page'),(927243,'printshop','.success-page .page-success .text-1','font-size','30','','','.success-page'),(927244,'printshop','.success-page .page-success .text-1','font-size','36','3','','.success-page'),(927245,'printshop','.success-page .page-success .text-1','font-size','40','5333','','.success-page'),(927246,'printshop','.success-page .page-success .text-2','font-size','24','','','.success-page'),(927247,'printshop','.success-page .page-success .text-2','font-size','30','5333','','.success-page'),(927248,'printshop','.success-page .page-success .text-3','font-size','20','','','.success-page'),(927249,'printshop','.success-page .pay-ico','font-size','30','3','','.success-page'),(927250,'printshop','.success-page .price-box','font-size','16','','','.success-page'),(927251,'printshop','.success-page .price-box .price','font-size','16','','','.success-page'),(927252,'printshop','.success-page .price-box .price-row.total','font-size','22','','','.success-page'),(927253,'printshop','.success-page .price-row.total .price b','font-size','22','','','.success-page'),(927254,'printshop','.success-page .prod-ico','font-size','30','3','','.success-page'),(927255,'printshop','.success-page .ship-ico','font-size','30','3','','.success-page'),(927256,'printshop','.success-page .w-cart-listing .history_attr','font-size','13','','','.success-page'),(927257,'printshop','.success-page .w-cart-listing .name a','font-size','14','','','.success-page'),(927258,'printshop','.success-page .w-cart-listing .price','font-size','16','','','.success-page'),(927259,'printshop','.success-page .w-cart-listing .qty','font-size','14','','','.success-page'),(927260,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-size','24','','','.b-multi-page-checkout'),(927261,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-size','0.7','4','','.b-multi-page-checkout'),(927265,'printshop','.footer-menu .level-1 > li > a, .footer-menu .level-1 > li > .no-link','font-size','18','','','.footer-menu'),(927266,'printshop','.footer-menu .level-1 > li','font-size','25','5342,3','','.footer-menu'),(927267,'printshop','.w-bestsellers .heading-3','font-size','50','3','','.w-bestsellers'),(927268,'printshop','.w-bestsellers .item','font-size','32','3','','.w-bestsellers'),(927269,'printshop','.w-catalog-paging .next','font-size','20','3','','.w-catalog-paging'),(927270,'printshop','.w-catalog-paging .prev','font-size','20','3','','.w-catalog-paging'),(927275,'printshop','.w-sale .badge','font-size','20','','','.w-sale'),(927276,'printshop','.w-sale .ends','font-size','26','','','.w-sale'),(927277,'printshop','.w-sale .left-count-days','font-size','40','','','.w-sale'),(927278,'printshop','.w-sale .left-count-hours','font-size','40','','','.w-sale'),(927279,'printshop','.w-sale .left-text-left','font-size','24','','','.w-sale'),(927280,'printshop','.w-sale .left-text-right','font-size','24','','','.w-sale'),(927281,'printshop','.w-sale .name','font-size','20','','','.w-sale'),(927282,'printshop','.w-sale .old','font-size','45','','','.w-sale'),(927283,'printshop','.w-sale .percents','font-size','30','','','.w-sale'),(927284,'printshop','.w-sale .special-price','font-size','70','','','.w-sale'),(927286,'printshop','.b-rating .glyphicon','font-style','normal','','','.b-rating'),(927287,'printshop','.b-switch .candlestick-wrapper .fa-times','font-style','normal','3','','.b-switch'),(927288,'printshop','.b-switch .candlestick-wrapper .fa-check','font-style','normal','3','','.b-switch'),(927289,'printshop','.b-select-suggest .select2-results li em','font-style','normal','','','.b-select-suggest'),(927290,'printshop','.heading-4 .right-text, h4 .right-text','font-weight','400','','',''),(927291,'printshop','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(927292,'printshop','.b-info .info strong','font-weight','400','','','.b-info'),(927293,'printshop','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(927294,'printshop','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(927295,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','font-weight','600','','','.b-switch'),(927296,'printshop','.w-multi-cart-cart-switcher .dropdown-menu a','font-weight','500','','','.w-multi-cart-cart-switcher'),(927297,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(927298,'printshop','.p-quick-order-index .filters label','font-weight','700','','','.p-quick-order-index'),(927299,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.p-quick-order-index'),(927300,'printshop','.w-promotions .prom-multi-discount .promo-range .value','font-weight','bold','','','.w-promotions'),(927301,'printshop','.w-promotions .promo-date','font-weight','500','','','.w-promotions'),(927302,'printshop','.w-personal-gift-status-bar .end-label','font-weight','bold','','','.w-personal-gift-status-bar'),(927303,'printshop','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(927304,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(927305,'printshop','.testimonials .reviews-list span','font-weight','400','','',''),(927306,'printshop','.testimonials .rating','font-weight','400','','',''),(927307,'printshop','.testimonials .name','font-weight','700','','',''),(927308,'printshop','.testimonials .heading-3','font-weight','400','3','',''),(927309,'printshop','.testimonials .reviews-list .name','font-weight','700','','',''),(927310,'printshop','.w-promotions .prom-multi-discount .heading','font-weight','300','','','.w-promotions'),(927311,'printshop','.w-promotions .heading-3','font-weight','bold','','','.w-promotions'),(927312,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.p-quick-order-index'),(927313,'printshop','.w-promotions .promo-salemaker .promo-manufacturers .heading','font-weight','300','','','.w-promotions'),(927314,'printshop','.w-promotions .promo-salemaker .promo-conditions','font-weight','300','','','.w-promotions'),(927315,'printshop','.w-promotions .promo-salemaker .discount .value','font-weight','700','','','.w-promotions'),(927316,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder .value','font-weight','bold','','','.w-promotions'),(927317,'printshop','.w-promotions .promo-cart-discount .slave .heading','font-weight','300','','','.w-promotions'),(927318,'printshop','.w-promotions .promo-cart-discount .promo-min-qty .value','font-weight','bold','','','.w-promotions'),(927319,'printshop','.w-promotions .promo-cart-discount .master .heading','font-weight','300','','','.w-promotions'),(927320,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','font-weight','bold','','','.b-warehouses-popup'),(927321,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-name','font-weight','bold','','','.b-warehouses-popup'),(927322,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','font-weight','bold','','','.b-warehouses-popup'),(927323,'printshop','.b-warehouses-popup .warehouses-popup .heading','font-weight','bold','','','.b-warehouses-popup'),(927324,'printshop','.b-warehouses-popup a.warehouses-popup-link','font-weight','bold','','','.b-warehouses-popup'),(927325,'printshop','.w-product-available-in-warehouses .warehouse-name','font-weight','bold','','','.w-product-available-in-warehouses'),(927326,'printshop','.w-checkout-create-account .account-benefits strong','font-weight','normal','','','.w-checkout-create-account'),(927327,'printshop','.w-cart-listing .name a','font-weight','700','','','.w-cart-listing'),(927328,'printshop','.b-messages .messBtnMenuDelete','font-weight','normal','3','','.b-messages'),(927329,'printshop','.b-messages span.starred::before','font-weight','normal','','','.b-messages'),(927330,'printshop','.b-messages .messBtnMenuStarred','font-weight','normal','3','','.b-messages'),(927331,'printshop','.b-messages .messMenuButton span','font-weight','600','','','.b-messages'),(927332,'printshop','.b-messages .messBtnMenuUnread','font-weight','normal','3','','.b-messages'),(927333,'printshop','.b-messages .messages-menu li a','font-weight','bold','2','','.b-messages'),(927334,'printshop','.b-messages .content_management_attach','font-weight','600','','','.b-messages'),(927335,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','font-weight','600','','','.b-messages'),(927336,'printshop','.w-reviews .author','font-weight','bold','','','.w-reviews'),(927337,'printshop','.order-summary .price-box .price-row.total','font-weight','600','','','.order-summary'),(927338,'printshop','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(927339,'printshop','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(927340,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','font-weight','bold','4','','.b-switch'),(927341,'printshop','.b-rating .glyphicon','font-weight','400','','','.b-rating'),(927342,'printshop','.p-quick-order-index .value','font-weight','bold','','','.p-quick-order-index'),(927343,'printshop','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(927344,'printshop','.b-table .table .headings td','font-weight','600','','','.b-table'),(927345,'printshop','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(927346,'printshop','.b-info .info strong','font-weight','400','','','.b-info'),(927347,'printshop','.b-form .shipping-method .cost','font-weight','500','','','.b-form'),(927348,'printshop','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-weight','600','','','.p-quick-order-index'),(927349,'printshop','.btn-1','font-weight','500','','',''),(927350,'printshop','.w-checkout-totals .ot_code_ot_subtotal','font-weight','bold','','','.w-checkout-totals'),(927351,'printshop','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(927352,'printshop','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(927353,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(927354,'printshop','.b-bottom .popup-heading','font-weight','bold','','','.b-bottom'),(927355,'printshop','.b-form .middle-form label.slim','font-weight','400','','','.b-form'),(927356,'printshop','.w-checkout-shipping-choice span','font-weight','600','','','.w-checkout-shipping-choice'),(927357,'printshop','.btn-3','font-weight','500','','',''),(927358,'printshop','.w-reviews-content .author','font-weight','bold','','','.w-reviews-content'),(927359,'printshop','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(927360,'printshop','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(927361,'printshop','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(927362,'printshop','.w-cart-compare .js-cart_totals_container b','font-weight','600','','','.w-cart-compare'),(927363,'printshop','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(927364,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(927365,'printshop','.w-image-maps .default-links .item .title','font-weight','700','','','.w-image-maps'),(927366,'printshop','.heading-4 .edit, h4 .edit','font-weight','400','','',''),(927367,'printshop','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(927368,'printshop','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(927369,'printshop','.w-multi-cart-cart-switcher .cart-label','font-weight','500','','','.w-multi-cart-cart-switcher'),(927370,'printshop','.w-multi-cart-actions .cart-actions','font-weight','600','','','.w-multi-cart-actions'),(927371,'printshop','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(927372,'printshop','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(927373,'printshop','.w-personal-gift-status-bar .end-date b','font-weight','bold','','','.w-personal-gift-status-bar'),(927374,'printshop','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(927375,'printshop','.btn-2','font-weight','500','','',''),(927376,'printshop','.heading-5, h5, .h-block h5','font-weight','600','','',''),(927377,'printshop','.w-cart-compare .cart-name a','font-weight','600','','','.w-cart-compare'),(927378,'printshop','.w-product-reviews .reviews-list span','font-weight','400','','','.w-product-reviews'),(927379,'printshop','.b-table .table .headings td','font-weight','600','','','.b-table'),(927380,'printshop','.w-delayed-despatch-checkout .heading','font-weight','500','','','.w-delayed-despatch-checkout'),(927381,'printshop','.w-top-categories .categories h2','font-weight','inherit','','','.w-top-categories'),(927382,'printshop','.transit','font-weight','700','','',''),(927383,'printshop','.out-stock','font-weight','500','','',''),(927384,'printshop','.in-stock','font-weight','500','','',''),(927385,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','font-weight','bold','4','','.b-switch'),(927386,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','font-weight','bold','4','','.b-switch'),(927387,'printshop','.b-delete-account .delete-box .delete-message','font-weight','normal','','','.b-delete-account'),(927388,'printshop','.w-checkout-shipping-address .genders-title > div','font-weight','bold','','','.w-checkout-shipping-address'),(927389,'printshop','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(927390,'printshop','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(927391,'printshop','.w-checkout-billing-address .btn-cancel','font-weight','500','','','.w-checkout-billing-address'),(927392,'printshop','.js-stock','font-weight','500','','',''),(927393,'printshop','.b-form #payment_method .title','font-weight','500','','','.b-form'),(927394,'printshop','.b-fancybox .fancybox-title-float-wrap .child','font-weight','bold','','','.b-fancybox'),(927395,'printshop','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(927396,'printshop','.w-reviews-content .product-name a','font-weight','bold','','','.w-reviews-content'),(927397,'printshop','.w-product-reviews .reviews-list .name','font-weight','700','','','.w-product-reviews'),(927398,'printshop','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(927399,'printshop','.b-table .table .headings td','font-weight','600','','','.b-table'),(927400,'printshop','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(927401,'printshop','.btn','font-weight','500','','',''),(927402,'printshop','.w-personal-gift-status-bar .inform b','font-weight','bold','','','.w-personal-gift-status-bar'),(927403,'printshop','.b-table .table .headings td','font-weight','600','','','.b-table'),(927404,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(927405,'printshop','.w-reviews .heading-3','font-weight','400','3','','.w-reviews'),(927406,'printshop','.w-reviews .product-name a','font-weight','bold','','','.w-reviews'),(927407,'printshop','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(927408,'printshop','.w-checkout-billing-address .genders-title > div','font-weight','bold','','','.w-checkout-billing-address'),(927409,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','font-weight','600','','','.b-switch'),(927410,'printshop','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(927411,'printshop','.w-cart-compare .atr-col','font-weight','600','','','.w-cart-compare'),(927412,'printshop','.b-info .info strong','font-weight','400','','','.b-info'),(927413,'printshop','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(927414,'printshop','.b-bottom .alert-message','font-weight','bold','','','.b-bottom'),(927415,'printshop','.w-image-maps .categories-items .item .title','font-weight','700','','','.w-image-maps'),(927416,'printshop','.w-neighbour-checkout .text','font-weight','bold','','','.w-neighbour-checkout'),(927417,'printshop','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-weight','600','','','.order-summary'),(927418,'printshop','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(927419,'printshop','.b-info .info strong','font-weight','400','','','.b-info'),(927420,'printshop','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(927421,'printshop','.w-cart-compare .atr-col','font-weight','normal','3','','.w-cart-compare'),(927422,'printshop','.b-info .info strong','font-weight','400','','','.b-info'),(927423,'printshop','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(927424,'printshop','.w-product-available-in-warehouses .heading','font-weight','bold','','','.w-product-available-in-warehouses'),(927425,'printshop','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(927426,'printshop','.p-quick-order-index .dataTables_info','font-weight','500','','','.p-quick-order-index'),(927427,'printshop','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(927428,'printshop','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(927429,'printshop','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(927430,'printshop','.w-checkout-bonus-points .title','font-weight','bold','','','.w-checkout-bonus-points'),(927431,'printshop','.w-coupons-and-vauchers-checkout .title','font-weight','bold','','','.w-coupons-and-vauchers-checkout'),(927432,'printshop','.w-checkout-credit-amount .amount-title','font-weight','bold','','','.w-checkout-credit-amount'),(927433,'printshop','.b-pass-strength .pass-strength span','font-weight','bold','','','.b-pass-strength'),(927434,'printshop','.b-table .table .headings td','font-weight','600','','','.b-table'),(927435,'printshop','.w-quote .strong','font-weight','400','','','.w-quote'),(927436,'printshop','.b-select-suggest .select2-results li.select2-result-with-children > .select2-result-label','font-weight','bold','','','.b-select-suggest'),(927437,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','font-weight','bold','','','.b-warehouses-popup'),(927438,'printshop','.b-table .table .headings td','font-weight','600','','','.b-table'),(927439,'printshop','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(927440,'printshop','.w-quote-products .empty','font-weight','700','','','.w-quote-products'),(927441,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.b-data-table'),(927442,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.b-data-table'),(927443,'printshop','.w-communication-post .communication-post-author-name','font-weight','bold','','','.w-communication-post'),(927444,'printshop','.b-products-listing .products-listing .bonus-points span:first-child','font-weight','bold','','','.b-products-listing'),(927445,'printshop','.b-products-listing .promos-info .promo-name','font-weight','500','','','.b-products-listing'),(927446,'printshop','.b-products-listing .wedding-registry-count','font-weight','bold','','','.b-products-listing'),(927449,'printshop','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(927450,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-weight','inherit','','',''),(927451,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-weight','inherit','','','.b-h-inline'),(927452,'printshop','h1, .heading-1','font-weight','300','','',''),(927453,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','font-weight','inherit','','','.w-contact-contacts'),(927454,'printshop','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(927455,'printshop','.b-form .shipping-method .title','font-weight','500','','','.b-form'),(927456,'printshop','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(927457,'printshop','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(927458,'printshop','.w-cart-listing .item .gift-wrap label','font-weight','700','','','.w-cart-listing'),(927459,'printshop','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-weight','600','','','.w-cart-listing'),(927460,'printshop','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-weight','normal','3','','.w-cart-listing'),(927461,'printshop','.w-cart-give-away .ga_price','font-weight','700','','','.w-cart-give-away'),(927466,'printshop','.w-image-maps .float-items .item .title','font-weight','700','','','.w-image-maps'),(927467,'printshop','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(927468,'printshop','.b-form .address-item .firstname, .b-form .address-item .lastname','font-weight','500','','','.b-form'),(927471,'printshop','.w-checkout-contact-information .contact-info-buttons a','font-weight','500','','','.w-checkout-contact-information'),(927472,'printshop','.w-checkout-shipping-address .change-ab','font-weight','500','','','.w-checkout-shipping-address'),(927473,'printshop','.w-checkout-billing-address .edit-ab','font-weight','500','','','.w-checkout-billing-address'),(927474,'printshop','.w-checkout-billing-address .add-ab','font-weight','500','','','.w-checkout-billing-address'),(927475,'printshop','.w-filters .view_more','font-weight','400','4','','.w-filters'),(927476,'printshop','.b-bottom .footerTitle','font-weight','700','','','.b-bottom'),(927477,'printshop','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(927478,'printshop','.heading-2, h2, .h-block h2','font-weight','300','','',''),(927479,'printshop','.b-data-table table.dataTable thead td','font-weight','700','','','.b-data-table'),(927480,'printshop','.heading-6, h6, .h-block h6','font-weight','600','','',''),(927481,'printshop','.b-info .info strong','font-weight','400','','','.b-info'),(927482,'printshop','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(927483,'printshop','.order-summary .price-row.ot_coupon .title','font-weight','bold','3','','.order-summary'),(927484,'printshop','.w-personal-gift-status-bar .start-label','font-weight','bold','','','.w-personal-gift-status-bar'),(927485,'printshop','.b-personal-catalog-popup #personal_catalog_popup','font-weight','normal','','','.b-personal-catalog-popup'),(927486,'printshop','.b-trade-approval .middle-form label','font-weight','600','','','.b-trade-approval'),(927487,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-weight','normal','3','','.w-catalog-compare'),(927488,'printshop','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-weight','600','','','.w-delivery-day'),(927489,'printshop','.w-delivery-day .ends-date','font-weight','600','','','.w-delivery-day'),(927490,'printshop','.w-delivery-day .title','font-weight','bold','','','.w-delivery-day'),(927491,'printshop','.w-delivery-day .left-text-left','font-weight','600','','','.w-delivery-day'),(927492,'printshop','.w-delivery-day .left-text-right','font-weight','600','','','.w-delivery-day'),(927496,'printshop','.tripleBanner .w-html_box > div:nth-child(2)','font-weight','700','','','.tripleBanner'),(927497,'printshop','.b-products-listing .products-listing.list-productlisting .price','font-weight','400','','','.b-products-listing'),(927498,'printshop','.w-cart-listing .item div.price','font-weight','bold','','','.w-cart-listing'),(927499,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','font-weight','400','','','.b-products-listing'),(927500,'printshop','.w-filters .head-filter-widget','font-weight','400','','','.w-filters'),(927501,'printshop','.w-subscribers .btn-submit','font-weight','600','','','.w-subscribers'),(927502,'printshop','.w-quote .cart-box-link','font-weight','bold','','','.w-quote'),(927503,'printshop','.w-quote .cart-box-link','font-weight','normal','3','','.w-quote'),(927504,'printshop','.w-quote .cart-total','font-weight','600','','','.w-quote'),(927505,'printshop','.w-quote .multicart .title','font-weight','600','','','.w-quote'),(927506,'printshop','.w-quote .price','font-weight','600','','','.w-quote'),(927507,'printshop','.w-quote .sub-total-row','font-weight','600','','','.w-quote'),(927508,'printshop','.w-product-sale-ends .ends-date','font-weight','600','','','.w-product-sale-ends'),(927509,'printshop','.w-product-sale-ends .left-count-days','font-weight','600','','','.w-product-sale-ends'),(927510,'printshop','.w-product-sale-ends .left-count-hours','font-weight','600','','','.w-product-sale-ends'),(927511,'printshop','.w-product-sale-ends .left-text-left','font-weight','600','','','.w-product-sale-ends'),(927512,'printshop','.w-product-sale-ends .left-text-right','font-weight','600','','','.w-product-sale-ends'),(927513,'printshop','.w-tabs .tab-a','font-weight','300','','','.w-tabs'),(927514,'printshop','.warrantyProduct .title','font-weight','700','','','.warrantyProduct'),(927515,'printshop','.w-files-catalog-widgets-files-catalog .name','font-weight','600','','','.w-files-catalog-widgets-files-catalog'),(927516,'printshop','.w-files-catalog-widgets-files-list .name','font-weight','600','','','.w-files-catalog-widgets-files-list'),(927517,'printshop','.w-sample .cart-box-link','font-weight','bold','','','.w-sample'),(927518,'printshop','.w-sample .cart-box-link','font-weight','normal','3','','.w-sample'),(927519,'printshop','.w-sample .cart-total','font-weight','600','','','.w-sample'),(927520,'printshop','.w-sample .multicart .title','font-weight','600','','','.w-sample'),(927521,'printshop','.w-sample .price','font-weight','600','','','.w-sample'),(927522,'printshop','.w-sample .strong','font-weight','400','','','.w-sample'),(927523,'printshop','.w-sample .sub-total-row','font-weight','600','','','.w-sample'),(927524,'printshop','.w-filters-simple .integrate-price','font-weight','bold','','','.w-filters-simple'),(927525,'printshop','.w-cart-sub-total .title','font-weight','500','','','.w-cart-sub-total'),(927526,'printshop','.w-cart-sub-total .price','font-weight','500','','','.w-cart-sub-total'),(927527,'printshop','.w-cart-gift-certificate .heading-4','font-weight','700','','','.w-cart-gift-certificate'),(927528,'printshop','.w-cart-order-reference .heading-4','font-weight','700','','','.w-cart-order-reference'),(927529,'printshop','.w-product-attributes .radio-attributes > span','font-weight','700','','','.w-product-attributes'),(927530,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','font-weight','inherit','','','.b-products-listing'),(927531,'printshop','.b-pagination .pagination .active a, .b-pagination .pagination .active span','font-weight','bold','','','.b-pagination'),(927532,'printshop','.b-pagination .pagination span','font-weight','700','2','','.b-pagination'),(927533,'printshop','.w-product-multi-inventory .radio-attributes > span','font-weight','700','','','.w-product-multi-inventory'),(927534,'printshop','.w-product-multi-inventory .radio-attributes .option-item','font-weight','700','','','.w-product-multi-inventory'),(927535,'printshop','.b-products-listing .products-listing.list-rows .stock','font-weight','700','','','.b-products-listing'),(927536,'printshop','.b-products-listing .products-listing.list-b2b .stock','font-weight','700','','','.b-products-listing'),(927537,'printshop','.b-products-listing .products-listing .radio-attributes .option','font-weight','700','','','.b-products-listing'),(927538,'printshop','.b-products-listing .products-listing .radio-attributes > span','font-weight','700','','','.b-products-listing'),(927539,'printshop','.b-products-listing .products-listing .attributes .item-title','font-weight','700','','','.b-products-listing'),(927540,'printshop','.w-product-collection .stock > span','font-weight','700','','','.w-product-collection'),(927541,'printshop','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(927542,'printshop','.w-product-collection .title','font-weight','500','','','.w-product-collection'),(927543,'printshop','.w-product-collection .together','font-weight','500','','','.w-product-collection'),(927544,'printshop','.w-product-attributes .radio-attributes .option-item','font-weight','700','','','.w-product-attributes'),(927545,'printshop','.w-product-in-bundles .bundle_name','font-weight','500','','','.w-product-in-bundles'),(927546,'printshop','.w-product-groups .radioBoxHead','font-weight','400','','','.w-product-groups'),(927547,'printshop','.w-product-groups .val1','font-weight','500','','','.w-product-groups'),(927548,'printshop','.w-product-groups .radioBox label .containerBlock img + .name + .val2','font-weight','700','','','.w-product-groups'),(927549,'printshop','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(927550,'printshop','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','font-weight','400','3','','.w-product-custom-bundle'),(927551,'printshop','.w-delivery-location-top-location-list .deliveryName','font-weight','700','','','.w-delivery-location-top-location-list'),(927552,'printshop','.w-delivery-location-location-list .deliveryName','font-weight','700','','','.w-delivery-location-location-list'),(927553,'printshop','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(927554,'printshop','.w-delivery-location-location-list .deliveryList li','font-weight','600','','','.w-delivery-location-location-list'),(927555,'printshop','.w-delivery-location-featured-list .deliveryName','font-weight','700','','','.w-delivery-location-featured-list'),(927556,'printshop','.w-sale-category .ends-date','font-weight','600','','','.w-sale-category'),(927557,'printshop','.w-sale-category .left-count-days','font-weight','600','','','.w-sale-category'),(927558,'printshop','.w-sale-category .left-count-hours','font-weight','600','','','.w-sale-category'),(927559,'printshop','.w-sale-category .left-text-left','font-weight','600','','','.w-sale-category'),(927560,'printshop','.w-sale-category .left-text-right','font-weight','600','','','.w-sale-category'),(927561,'printshop','.w-sale-category .name','font-weight','bold','','','.w-sale-category'),(927562,'printshop','.w-sale-category .special-price','font-weight','600','','','.w-sale-category'),(927563,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description + div','font-weight','700','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(927564,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description + div','font-weight','700','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(927565,'printshop','.w-delivery-location-list-by-page .name','font-weight','700','','','.w-delivery-location-list-by-page'),(927566,'printshop','.w-delivery-location-cross-pages .name','font-weight','700','','','.w-delivery-location-cross-pages'),(927567,'printshop','.w-catalog-delivery-locations .name','font-weight','700','','','.w-catalog-delivery-locations'),(927568,'printshop','.w-product-designer-designer .grnamebox .title-sortable','font-weight','700','','','.w-product-designer-designer'),(927569,'printshop','.w-press-reviews-widgets-press-reviews .author','font-weight','bold','','','.w-press-reviews-widgets-press-reviews'),(927570,'printshop','.w-press-reviews-widgets-press-reviews .title a','font-weight','bold','','','.w-press-reviews-widgets-press-reviews'),(927571,'printshop','.w-press-reviews-widgets-press-reviews-list .product-name','font-weight','600','','','.w-press-reviews-widgets-press-reviews-list'),(927572,'printshop','.w-press-reviews-widgets-press-reviews-list .short-description','font-weight','700','','','.w-press-reviews-widgets-press-reviews-list'),(927573,'printshop','.w-support-system-filter .filter_cats.level-0 > li > a','font-weight','700','','','.w-support-system-filter'),(927574,'printshop','.w-rma-returns-history .column .title','font-weight','normal','','','.w-rma-returns-history'),(927575,'printshop','.w-predefined-promotion .heading-3','font-weight','bold','','','.w-predefined-promotion'),(927576,'printshop','.w-predefined-promotion .prom-multi-discount .heading','font-weight','300','','','.w-predefined-promotion'),(927577,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range .value','font-weight','bold','','','.w-predefined-promotion'),(927578,'printshop','.w-predefined-promotion .promo-cart-discount .master .heading','font-weight','300','','','.w-predefined-promotion'),(927579,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty .value','font-weight','bold','','','.w-predefined-promotion'),(927580,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder .value','font-weight','bold','','','.w-predefined-promotion'),(927581,'printshop','.w-predefined-promotion .promo-cart-discount .slave .heading','font-weight','300','','','.w-predefined-promotion'),(927582,'printshop','.w-predefined-promotion .promo-date','font-weight','500','','','.w-predefined-promotion'),(927583,'printshop','.w-predefined-promotion .promo-salemaker .discount .value','font-weight','700','','','.w-predefined-promotion'),(927584,'printshop','.w-predefined-promotion .promo-salemaker .promo-conditions','font-weight','300','','','.w-predefined-promotion'),(927585,'printshop','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading','font-weight','300','','','.w-predefined-promotion'),(927588,'printshop','.w-categories h2.name','font-weight','500','','','.w-categories'),(927589,'printshop','.w-product-model strong','font-weight','400','','','.w-product-model'),(927590,'printshop','.tripleLine .text-banner-2 > div','font-weight','300','','','.tripleLine'),(927591,'printshop','.tripleLine .text-banner-2 > div a','font-weight','300','','','.tripleLine'),(927592,'printshop','.cartTitle span','font-weight','300','','','.cartTitle'),(927593,'printshop','.heading-4, h4, .h-block h4','font-weight','500','','',''),(927597,'printshop','.lowestPricedBox .title','font-weight','300','','','.lowestPricedBox'),(927598,'printshop','.lowestPricedBox .descr','font-weight','300','','','.lowestPricedBox'),(927599,'printshop','.doubleBanner .descr','font-weight','300','','','.doubleBanner'),(927600,'printshop','.doubleBanner .title','font-weight','300','','','.doubleBanner'),(927601,'printshop','.doubleBanner .descr','font-weight','300','5347','','.doubleBanner'),(927602,'printshop','.doubleBanner .title','font-weight','300','5347','','.doubleBanner'),(927603,'printshop','.middleBanner .title','font-weight','300','','','.middleBanner'),(927604,'printshop','.middleBanner .descr','font-weight','300','','','.middleBanner'),(927605,'printshop','.middleBanner .btn-1','font-weight','300','','','.middleBanner'),(927606,'printshop','.bottomDoubleBanner .title','font-weight','300','','','.bottomDoubleBanner'),(927607,'printshop','.bottomDoubleBanner .title','font-weight','300','5347','','.bottomDoubleBanner'),(927608,'printshop','.bottomBanner .title','font-weight','300','','','.bottomBanner'),(927609,'printshop','.bottomBanner .descr','font-weight','300','','','.bottomBanner'),(927610,'printshop','.bottomBanner .btn-1','font-weight','300','','','.bottomBanner'),(927611,'printshop','.bottomBanner .icon-box > div','font-weight','300','','','.bottomBanner'),(927612,'printshop','.w-delayed-despatch-checkout-confirm .heading','font-weight','500','','','.w-delayed-despatch-checkout-confirm'),(927613,'printshop','h1','font-weight','500','5342','',''),(927614,'printshop','.topBanner .content .btn','font-weight','300','','','.topBanner'),(927615,'printshop','.topBanner .title','font-weight','300','','','.topBanner'),(927616,'printshop','.tripleLine .banner-text-holder > div','font-weight','300','','','.tripleLine'),(927617,'printshop','.tripleLine .banner-text-holder > div a','font-weight','300','','','.tripleLine'),(927618,'printshop','.order-summary .icon','font-weight','600','3','','.order-summary'),(927619,'printshop','.w-cart-discount-coupon .title','font-weight','400','4','','.w-cart-discount-coupon'),(927620,'printshop','.w-cart-checkout-btn .with-card','font-weight','400','4','','.w-cart-checkout-btn'),(927621,'printshop','.p-quote-checkout-index .cardinfo-label','font-weight','bold','','','.p-quote-checkout-index'),(927622,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','font-weight','500','','','.p-quote-checkout-index'),(927623,'printshop','.p-quote-checkout-index .edit-address-popup .edit-ab','font-weight','500','','','.p-quote-checkout-index'),(927624,'printshop','.account-address-book .address_book h2','font-weight','normal','','','.account-address-book'),(927638,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-weight','normal','3','','.account-order-pay'),(927639,'printshop','.account-order-pay .not_fully_paid_td','font-weight','700','','','.account-order-pay'),(927640,'printshop','.account-samples .not_fully_paid_td','font-weight','700','','','.account-samples'),(927641,'printshop','.account-samples .order_history_table h2','font-weight','normal','','','.account-samples'),(927642,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-weight','normal','3','','.account-sample-info'),(927643,'printshop','.account-sample-info .not_fully_paid_td','font-weight','700','','','.account-sample-info'),(927644,'printshop','.account-sample-info .popup-tracking-number-link','font-weight','600','','','.account-sample-info'),(927645,'printshop','.account-sample-info .trackings-nambers-label','font-weight','600','','','.account-sample-info'),(927646,'printshop','.catalog-product-wrap .pn-direction','font-weight','600','','','.catalog-product-wrap'),(927647,'printshop','.shopping-cart-index .cart-page .empty','font-weight','700','','','.shopping-cart-index'),(927648,'printshop','.checkout-index-wrap .cardinfo-label','font-weight','bold','','','.checkout-index-wrap'),(927649,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','font-weight','500','','','.checkout-index-wrap'),(927650,'printshop','.checkout-index-wrap .edit-address-popup .edit-ab','font-weight','500','','','.checkout-index-wrap'),(927651,'printshop','.success-page .price-box .price-row.total','font-weight','500','','','.success-page'),(927652,'printshop','.success-page .price-row.total .price b','font-weight','500','','','.success-page'),(927653,'printshop','.success-page .w-cart-listing .name a','font-weight','500','','','.success-page'),(927654,'printshop','.success-page .w-cart-listing .price','font-weight','normal','','','.success-page'),(927655,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-weight','normal','3','','.b-multi-page-checkout'),(927656,'printshop','.b-form .addresses .address-item .edit-ab','font-weight','bold','','','.b-form'),(927657,'printshop','.b-sub-totals .historyTotal table tr.ot_total td','font-weight','bold','','','.b-sub-totals'),(927660,'printshop','.footer-menu .level-1 > li > a, .footer-menu .level-1 > li > .no-link','font-weight','300','','','.footer-menu'),(927661,'printshop','.footer-menu .level-1 > li','font-weight','normal','5342,3','','.footer-menu'),(927662,'printshop','.w-bestsellers .counter','font-weight','600','','','.w-bestsellers'),(927663,'printshop','.w-bestsellers .heading-3','font-weight','400','3','','.w-bestsellers'),(927664,'printshop','.w-catalog-paging ','font-weight','700','2','','.w-catalog-paging'),(927667,'printshop','.w-sale .ends-date','font-weight','600','','','.w-sale'),(927668,'printshop','.w-sale .left-count-days','font-weight','600','','','.w-sale'),(927669,'printshop','.w-sale .left-count-hours','font-weight','600','','','.w-sale'),(927670,'printshop','.w-sale .left-text-left','font-weight','600','','','.w-sale'),(927671,'printshop','.w-sale .left-text-right','font-weight','600','','','.w-sale'),(927672,'printshop','.w-sale .name','font-weight','bold','','','.w-sale'),(927673,'printshop','.w-sale .special-price','font-weight','600','','','.w-sale'),(927674,'printshop','.no-found','font_size_measure','em','','',''),(927675,'printshop','.w-checkout-create-account .account-benefits','font_size_measure','em','','','.w-checkout-create-account'),(927676,'printshop','.view-all .btn','font_size_measure','em','4','',''),(927677,'printshop','.price .old','font_size_measure','em','','',''),(927678,'printshop','.btn-edit','font_size_measure','em','3','',''),(927679,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font_size_measure','%','','','.b-select-suggest'),(927680,'printshop','.b-select-suggest .select2-search input','font_size_measure','em','','','.b-select-suggest'),(927682,'printshop','.w-quote .cart-total','font_size_measure','em','','','.w-quote'),(927683,'printshop','.w-quote .qty','font_size_measure','em','4','','.w-quote'),(927685,'printshop','.w-sample .cart-total','font_size_measure','em','','','.w-sample'),(927686,'printshop','.w-sample .qty','font_size_measure','em','4','','.w-sample'),(927687,'printshop','.w-product-bundle .bundle_price .old','font_size_measure','em','','','.w-product-bundle'),(927688,'printshop','.w-product-in-bundles .bundle_price .old','font_size_measure','em','','','.w-product-in-bundles'),(927689,'printshop','.doubleBanner .descr','font_size_measure','vw','5347','','.doubleBanner'),(927690,'printshop','.doubleBanner .title','font_size_measure','vw','5347','','.doubleBanner'),(927691,'printshop','.middleBanner .descr','font_size_measure','vw','5347','','.middleBanner'),(927692,'printshop','.middleBanner .title','font_size_measure','vw','5347','','.middleBanner'),(927693,'printshop','.middleBanner .title','font_size_measure','vw','5342','','.middleBanner'),(927694,'printshop','.middleBanner .descr','font_size_measure','vw','5342','','.middleBanner'),(927695,'printshop','.bottomBanner .title','font_size_measure','vw','5347','','.bottomBanner'),(927696,'printshop','.bottomBanner .descr','font_size_measure','vw','5347','','.bottomBanner'),(927697,'printshop','.bottomBanner .title','font_size_measure','vw','5363','','.bottomBanner'),(927698,'printshop','.bottomDoubleBanner .title','font_size_measure','vw','5347','','.bottomDoubleBanner'),(927699,'printshop','.topBanner .content .btn','font_size_measure','vw','','','.topBanner'),(927700,'printshop','.topBanner .descr','font_size_measure','vw','','','.topBanner'),(927701,'printshop','.topBanner .ourPick .bottom','font_size_measure','vw','','','.topBanner'),(927702,'printshop','.topBanner .ourPick .top','font_size_measure','vw','','','.topBanner'),(927703,'printshop','.topBanner .title','font_size_measure','vw','','','.topBanner'),(927704,'printshop','.topBanner .descr','font_size_measure','vw','5333','','.topBanner'),(927705,'printshop','.topBanner .ourPick .bottom','font_size_measure','vw','5333','','.topBanner'),(927706,'printshop','.topBanner .ourPick .top','font_size_measure','vw','5333','','.topBanner'),(927707,'printshop','.topBanner .title','font_size_measure','vw','5333','','.topBanner'),(927708,'printshop','.middleBanner .title','font_size_measure','vw','5333','','.middleBanner'),(927709,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font_size_measure','em','4','','.b-multi-page-checkout'),(927710,'printshop','.w-promotions .prom-multi-discount .list','grid-auto-flow','dense','','','.w-promotions'),(927711,'printshop','.w-predefined-promotion .prom-multi-discount .list','grid-auto-flow','dense','','','.w-predefined-promotion'),(927712,'printshop','.w-promotions .prom-multi-discount .promo-group-4','grid-column','span 4','','','.w-promotions'),(927713,'printshop','.w-promotions .prom-multi-discount .promo-group-2','grid-column','span 2','','','.w-promotions'),(927714,'printshop','.w-promotions .prom-multi-discount .promo-group-3','grid-column','span 3','','','.w-promotions'),(927715,'printshop','.w-cart-listing .points','grid-column','2 / 5','5333','','.w-cart-listing'),(927716,'printshop','.w-cart-listing .item .gift-wrap','grid-column','3 / 4','5333','','.w-cart-listing'),(927717,'printshop','.w-cart-listing .name','grid-column','2 / 4','5333','','.w-cart-listing'),(927718,'printshop','.w-cart-listing .price','grid-column','3 / 5','5333','','.w-cart-listing'),(927719,'printshop','.w-reviews .author','grid-column','2/4','','','.w-reviews'),(927720,'printshop','.w-cart-listing .promos-info','grid-column','1 / 2','5333','','.w-cart-listing'),(927721,'printshop','.w-reviews-content .rating','grid-column','2','','','.w-reviews-content'),(927722,'printshop','.w-reviews-content .date','grid-column','3','','','.w-reviews-content'),(927723,'printshop','.w-reviews-content .review','grid-column','2/4','','','.w-reviews-content'),(927724,'printshop','.w-reviews .date','grid-column','3','','','.w-reviews'),(927725,'printshop','.w-reviews-content .author','grid-column','2/4','','','.w-reviews-content'),(927726,'printshop','.w-reviews .product-name','grid-column','2/4','','','.w-reviews'),(927727,'printshop','.w-reviews .product-image','grid-column','1','','','.w-reviews'),(927728,'printshop','.w-reviews .rating','grid-column','2','','','.w-reviews'),(927729,'printshop','.w-reviews .review','grid-column','2/4','','','.w-reviews'),(927730,'printshop','.w-reviews-content .product-image','grid-column','1','','','.w-reviews-content'),(927731,'printshop','.w-cart-listing .promos-info','grid-column','2 / 3','','','.w-cart-listing'),(927732,'printshop','.w-cart-listing .qty','grid-column','3 / 3','','','.w-cart-listing'),(927733,'printshop','.w-cart-listing .price','grid-column','4 / 4','','','.w-cart-listing'),(927734,'printshop','.w-cart-listing .name','grid-column','2 / 3','','','.w-cart-listing'),(927735,'printshop','.w-cart-listing .image','grid-column','1 / 1','','','.w-cart-listing'),(927736,'printshop','.w-cart-listing .points','grid-column','4 / 4','','','.w-cart-listing'),(927737,'printshop','.w-cart-listing .item .gift-wrap','grid-column','4 / 6','','','.w-cart-listing'),(927738,'printshop','.w-cart-listing .actions','grid-column','2 / 4','','','.w-cart-listing'),(927739,'printshop','.w-cart-listing .no-price .qty','grid-column','4 / 6','','','.w-cart-listing'),(927740,'printshop','.w-reviews-content .product-name','grid-column','2/4','','','.w-reviews-content'),(927741,'printshop','.w-cart-listing .image','grid-column','1 / 2','5333','','.w-cart-listing'),(927742,'printshop','.w-cart-listing .remove','grid-column','3 / 3','','','.w-cart-listing'),(927743,'printshop','.w-cart-listing .item > div.actions','grid-column','1 / 4','5333','','.w-cart-listing'),(927744,'printshop','.w-cart-listing .no-price .qty','grid-column','2/4','5342','','.w-cart-listing'),(927745,'printshop','.w-sample-products .w-cart-listing .item .qty','grid-column','2 / 4','5333','','.w-sample-products'),(927746,'printshop','.w-quote-products .cart-listing .qty','grid-column','4 / 4','','','.w-quote-products'),(927747,'printshop','.w-account-personal-catalog .check-box','grid-column','5 / 5','','','.w-account-personal-catalog'),(927748,'printshop','.w-account-personal-catalog .list-row-action','grid-column','2 / 5','','','.w-account-personal-catalog'),(927749,'printshop','.w-account-personal-catalog .image','grid-column','1 / 1','','','.w-account-personal-catalog'),(927750,'printshop','.w-account-personal-catalog .name','grid-column','2 / 4','','','.w-account-personal-catalog'),(927751,'printshop','.w-account-personal-catalog .buy-box','grid-column','5 / 6','','','.w-account-personal-catalog'),(927752,'printshop','.w-account-personal-catalog .qty-input','grid-column','4 / 5','','','.w-account-personal-catalog'),(927753,'printshop','.w-account-personal-catalog .w-cart-listing .item .remove','grid-column','1 / 2','5342','','.w-account-personal-catalog'),(927754,'printshop','.w-account-personal-catalog .price','grid-column','2 / 3','5333','','.w-account-personal-catalog'),(927755,'printshop','.w-account-personal-catalog .remove','grid-column','1 / 2','5333','','.w-account-personal-catalog'),(927756,'printshop','.w-account-personal-catalog .list-row-action','grid-column','2 / 5','5333','','.w-account-personal-catalog'),(927757,'printshop','.w-account-personal-catalog .image','grid-column','1 / 1','5333','','.w-account-personal-catalog'),(927758,'printshop','.w-account-personal-catalog .name','grid-column','3 / 4','5333','','.w-account-personal-catalog'),(927759,'printshop','.w-account-personal-catalog .buy-box','grid-column','2 / 5','5333','','.w-account-personal-catalog'),(927760,'printshop','.w-account-personal-catalog .qty-input','grid-column','3 / 4','5333','','.w-account-personal-catalog'),(927761,'printshop','.w-press-reviews-widgets-press-reviews .author','grid-column','2/4','','','.w-press-reviews-widgets-press-reviews'),(927762,'printshop','.w-press-reviews-widgets-press-reviews .date','grid-column','3','','','.w-press-reviews-widgets-press-reviews'),(927763,'printshop','.w-press-reviews-widgets-press-reviews .image','grid-column','1','','','.w-press-reviews-widgets-press-reviews'),(927764,'printshop','.w-press-reviews-widgets-press-reviews .rating','grid-column','2','','','.w-press-reviews-widgets-press-reviews'),(927765,'printshop','.w-press-reviews-widgets-press-reviews .review','grid-column','2/4','','','.w-press-reviews-widgets-press-reviews'),(927766,'printshop','.w-press-reviews-widgets-press-reviews .title','grid-column','2/4','','','.w-press-reviews-widgets-press-reviews'),(927767,'printshop','.w-press-reviews-widgets-press-reviews .author','grid-column','1/2','5333','','.w-press-reviews-widgets-press-reviews'),(927768,'printshop','.w-press-reviews-widgets-press-reviews .date','grid-column','1/2','5333','','.w-press-reviews-widgets-press-reviews'),(927769,'printshop','.w-press-reviews-widgets-press-reviews .image','grid-column','1/2','5333','','.w-press-reviews-widgets-press-reviews'),(927770,'printshop','.w-press-reviews-widgets-press-reviews .rating','grid-column','1/2','5333','','.w-press-reviews-widgets-press-reviews'),(927771,'printshop','.w-press-reviews-widgets-press-reviews .review','grid-column','1/2','5333','','.w-press-reviews-widgets-press-reviews'),(927772,'printshop','.w-press-reviews-widgets-press-reviews .title','grid-column','1/2','5333','','.w-press-reviews-widgets-press-reviews'),(927773,'printshop','.w-predefined-promotion .prom-multi-discount .promo-group-2','grid-column','span 2','','','.w-predefined-promotion'),(927774,'printshop','.w-predefined-promotion .prom-multi-discount .promo-group-3','grid-column','span 3','','','.w-predefined-promotion'),(927775,'printshop','.w-predefined-promotion .prom-multi-discount .promo-group-4','grid-column','span 4','','','.w-predefined-promotion'),(927776,'printshop','.w-cart-listing .remove','grid-column','1 / 2','5333','','.w-cart-listing'),(927777,'printshop','.w-cart-listing .item .qty','grid-column','1 / 3','5333','','.w-cart-listing'),(927778,'printshop','.w-account-personal-catalog .w-cart-listing .remove','grid-column','1 / 1','','','.w-account-personal-catalog'),(927779,'printshop','.w-account-personal-catalog .w-cart-listing .price','grid-column','4 / 5','','','.w-account-personal-catalog'),(927780,'printshop','.w-account-personal-catalog .check-box','grid-column','1 / 1','5333','','.w-account-personal-catalog'),(927781,'printshop','.w-account-personal-catalog .buy-box','grid-column','1 / 5','5363','','.w-account-personal-catalog'),(927782,'printshop','.w-account-personal-catalog .check-box','grid-column','1 / 1','5363','','.w-account-personal-catalog'),(927783,'printshop','.w-account-personal-catalog .qty-input','grid-column','1 / 3','5363','','.w-account-personal-catalog'),(927784,'printshop','.w-account-personal-catalog .w-cart-listing .price','grid-column','3 / 5','5363','','.w-account-personal-catalog'),(927785,'printshop','.order-summary .w-cart-listing .item .name','grid-column','1/2','','','.order-summary'),(927786,'printshop','.order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price','grid-column','3/4','','','.order-summary'),(927787,'printshop','.order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty','grid-column','2/3','','','.order-summary'),(927788,'printshop','.order-summary .w-cart-listing.type-2 .image','grid-column','1 / 3','','','.order-summary'),(927789,'printshop','.w-quote-products .w-cart-listing .remove','grid-column','3 / 3','','','.w-quote-products'),(927790,'printshop','.w-quote-products .w-cart-listing .item .qty','grid-column','2 / 6','5342','','.w-quote-products'),(927791,'printshop','.w-quote-products .w-cart-listing .name','grid-column','2 / 6','5342','','.w-quote-products'),(927792,'printshop','.w-quote-products .w-cart-listing .remove','grid-column','1 / 2','5342','','.w-quote-products'),(927793,'printshop','.success-page .w-cart-listing .image','grid-column','1','','','.success-page'),(927794,'printshop','.success-page .w-cart-listing .name','grid-column','2','','','.success-page'),(927795,'printshop','.success-page .w-cart-listing .price','grid-column','3','','','.success-page'),(927796,'printshop','.success-page .w-cart-listing .qty','grid-column','1','','','.success-page'),(927797,'printshop','.success-page .w-cart-listing .sub-product .image','grid-column','1','','','.success-page'),(927798,'printshop','.w-banner .banner-image','grid-column','1','','','.w-banner'),(927799,'printshop','.w-banner .banner-text','grid-column','1','','','.w-banner'),(927800,'printshop','.w-promotions .content','grid-column-end','3','','','.w-promotions'),(927801,'printshop','.w-predefined-promotion .content','grid-column-end','3','','','.w-predefined-promotion'),(927802,'printshop','.w-promotions .heading','grid-column-start','1','','','.w-promotions'),(927803,'printshop','.w-promotions .condition','grid-column-start','2','','','.w-promotions'),(927804,'printshop','.w-promotions .content','grid-column-start','1','','','.w-promotions'),(927805,'printshop','.w-predefined-promotion .condition','grid-column-start','2','','','.w-predefined-promotion'),(927806,'printshop','.w-predefined-promotion .content','grid-column-start','1','','','.w-predefined-promotion'),(927807,'printshop','.w-predefined-promotion .heading','grid-column-start','1','','','.w-predefined-promotion'),(927808,'printshop','.w-account-personal-catalog .remove','grid-column_important','important','5333','','.w-account-personal-catalog'),(927809,'printshop','.w-promotions .prom-multi-discount .products','grid-gap','4px','','','.w-promotions'),(927810,'printshop','.w-promotions .prom-multi-discount .list','grid-gap','20px','','','.w-promotions'),(927811,'printshop','.w-promotions .nextdiscount .content','grid-gap','3px','','','.w-promotions'),(927812,'printshop','.w-predefined-promotion .nextdiscount .content','grid-gap','3px','','','.w-predefined-promotion'),(927813,'printshop','.w-predefined-promotion .prom-multi-discount .list','grid-gap','20px','','','.w-predefined-promotion'),(927814,'printshop','.w-predefined-promotion .prom-multi-discount .products','grid-gap','4px','','','.w-predefined-promotion'),(927815,'printshop','.w-cart-listing .name','grid-row','1 / 2','5333','','.w-cart-listing'),(927816,'printshop','.w-cart-listing .promos-info','grid-row','1 / 5','5333','','.w-cart-listing'),(927817,'printshop','.w-cart-listing .price','grid-row','3 / 3','5333','','.w-cart-listing'),(927818,'printshop','.w-reviews-content .product-name','grid-row','2','','','.w-reviews-content'),(927819,'printshop','.w-reviews-content .date','grid-row','1','','','.w-reviews-content'),(927820,'printshop','.w-reviews .author','grid-row','4','','','.w-reviews'),(927821,'printshop','.w-reviews .date','grid-row','1','','','.w-reviews'),(927822,'printshop','.w-reviews-content .author','grid-row','4','','','.w-reviews-content'),(927823,'printshop','.w-reviews-content .review','grid-row','3','','','.w-reviews-content'),(927824,'printshop','.w-reviews .product-image','grid-row','1/6','','','.w-reviews'),(927825,'printshop','.w-reviews .product-name','grid-row','2','','','.w-reviews'),(927826,'printshop','.w-reviews .rating','grid-row','1','','','.w-reviews'),(927827,'printshop','.w-reviews .review','grid-row','3','','','.w-reviews'),(927828,'printshop','.w-reviews-content .rating','grid-row','1','','','.w-reviews-content'),(927829,'printshop','.w-reviews-content .product-image','grid-row','1/6','','','.w-reviews-content'),(927830,'printshop','.w-cart-listing .remove','grid-row','1 / 6','','','.w-cart-listing'),(927831,'printshop','.w-cart-listing .promos-info','grid-row','1 / 6','','','.w-cart-listing'),(927832,'printshop','.w-cart-listing .image','grid-row','1 / 6','','','.w-cart-listing'),(927833,'printshop','.w-cart-listing .name','grid-row','1 / 3','','','.w-cart-listing'),(927834,'printshop','.w-cart-listing .price','grid-row','1 / 2','','','.w-cart-listing'),(927835,'printshop','.w-cart-listing .actions','grid-row','5 / 6','','','.w-cart-listing'),(927836,'printshop','.w-cart-listing .qty','grid-row','1 / 2','','','.w-cart-listing'),(927837,'printshop','.w-cart-listing .image','grid-row','1 / 1','5333','','.w-cart-listing'),(927838,'printshop','.w-cart-listing .points','grid-row','2 / 3','5333','','.w-cart-listing'),(927839,'printshop','.w-cart-listing .item .remove','grid-row','2/3','5342','','.w-cart-listing'),(927840,'printshop','.w-cart-listing .item > div.actions','grid-row','4 / 4','5333','','.w-cart-listing'),(927841,'printshop','.w-cart-listing .no-price .qty','grid-row','2/3','5342','','.w-cart-listing'),(927842,'printshop','.w-sample-products .w-cart-listing .item .qty','grid-row','2 / 3','5333','','.w-sample-products'),(927843,'printshop','.w-account-personal-catalog .check-box','grid-row','1 / 2','','','.w-account-personal-catalog'),(927844,'printshop','.w-account-personal-catalog .list-row-action','grid-row','3 / 4','','','.w-account-personal-catalog'),(927845,'printshop','.w-account-personal-catalog .image','grid-row','1 / 3','','','.w-account-personal-catalog'),(927846,'printshop','.w-account-personal-catalog .name','grid-row','1 / 3','','','.w-account-personal-catalog'),(927847,'printshop','.w-account-personal-catalog .buy-box','grid-row','1 / 4','','','.w-account-personal-catalog'),(927848,'printshop','.w-account-personal-catalog .qty-input','grid-row','2 / 2','','','.w-account-personal-catalog'),(927849,'printshop','.w-account-personal-catalog .w-cart-listing .item .remove','grid-row','3 / 4','5342','','.w-account-personal-catalog'),(927850,'printshop','.w-account-personal-catalog .price','grid-row','2 / 3','5333','','.w-account-personal-catalog'),(927851,'printshop','.w-account-personal-catalog .remove','grid-row','4 / 5','5333','','.w-account-personal-catalog'),(927852,'printshop','.w-account-personal-catalog .list-row-action','grid-row','4 / 5','5333','','.w-account-personal-catalog'),(927853,'printshop','.w-account-personal-catalog .image','grid-row','1 / 2','5333','','.w-account-personal-catalog'),(927854,'printshop','.w-account-personal-catalog .name','grid-row','1 / 2','5333','','.w-account-personal-catalog'),(927855,'printshop','.w-account-personal-catalog .buy-box','grid-row','3 / 4','5333','','.w-account-personal-catalog'),(927856,'printshop','.w-account-personal-catalog .qty-input','grid-row','2 / 3','5333','','.w-account-personal-catalog'),(927857,'printshop','.w-press-reviews-widgets-press-reviews .author','grid-row','4','','','.w-press-reviews-widgets-press-reviews'),(927858,'printshop','.w-press-reviews-widgets-press-reviews .date','grid-row','1','','','.w-press-reviews-widgets-press-reviews'),(927859,'printshop','.w-press-reviews-widgets-press-reviews .image','grid-row','1/6','','','.w-press-reviews-widgets-press-reviews'),(927860,'printshop','.w-press-reviews-widgets-press-reviews .rating','grid-row','1','','','.w-press-reviews-widgets-press-reviews'),(927861,'printshop','.w-press-reviews-widgets-press-reviews .review','grid-row','3','','','.w-press-reviews-widgets-press-reviews'),(927862,'printshop','.w-press-reviews-widgets-press-reviews .title','grid-row','2','','','.w-press-reviews-widgets-press-reviews'),(927863,'printshop','.w-press-reviews-widgets-press-reviews .author','grid-row','6/7','5333','','.w-press-reviews-widgets-press-reviews'),(927864,'printshop','.w-press-reviews-widgets-press-reviews .date','grid-row','2/3','5333','','.w-press-reviews-widgets-press-reviews'),(927865,'printshop','.w-press-reviews-widgets-press-reviews .image','grid-row','1/2','5333','','.w-press-reviews-widgets-press-reviews'),(927866,'printshop','.w-press-reviews-widgets-press-reviews .rating','grid-row','3/4','5333','','.w-press-reviews-widgets-press-reviews'),(927867,'printshop','.w-press-reviews-widgets-press-reviews .review','grid-row','5/6','5333','','.w-press-reviews-widgets-press-reviews'),(927868,'printshop','.w-press-reviews-widgets-press-reviews .title','grid-row','4/5','5333','','.w-press-reviews-widgets-press-reviews'),(927869,'printshop','.w-cart-listing .item .qty','grid-row','3 / 3','5333','','.w-cart-listing'),(927870,'printshop','.w-account-personal-catalog .w-cart-listing .remove','grid-row','3 / 3','','','.w-account-personal-catalog'),(927871,'printshop','.w-account-personal-catalog .w-cart-listing .price','grid-row','1 / 1','','','.w-account-personal-catalog'),(927872,'printshop','.w-account-personal-catalog .check-box','grid-row','2 / 2','5333','','.w-account-personal-catalog'),(927873,'printshop','.w-account-personal-catalog .check-box','grid-row','1 / 1','5363','','.w-account-personal-catalog'),(927874,'printshop','.w-account-personal-catalog .qty-input','grid-row','2 / 3','5363','','.w-account-personal-catalog'),(927875,'printshop','.w-account-personal-catalog .w-cart-listing .price','grid-row','2 / 2','5363','','.w-account-personal-catalog'),(927876,'printshop','.order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price','grid-row','1/2','','','.order-summary'),(927877,'printshop','.order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty','grid-row','1/2','','','.order-summary'),(927878,'printshop','.w-quote-products .w-cart-listing .image','grid-row','1 / 1','5342','','.w-quote-products'),(927879,'printshop','.w-quote-products .w-cart-listing .item .qty','grid-row','2 / 2','5342','','.w-quote-products'),(927880,'printshop','.w-quote-products .w-cart-listing .remove','grid-row','2 / 2','5342','','.w-quote-products'),(927881,'printshop','.success-page .w-cart-listing .item > div','grid-row','1','','','.success-page'),(927882,'printshop','.w-banner .banner-image','grid-row','1','','','.w-banner'),(927883,'printshop','.w-banner .banner-item.text-bottom-text .banner-text','grid-row','2','','','.w-banner'),(927884,'printshop','.w-banner .banner-text','grid-row','1','','','.w-banner'),(927885,'printshop','.w-promotions .content','grid-row-start','2','','','.w-promotions'),(927886,'printshop','.w-promotions .condition','grid-row-start','1','','','.w-promotions'),(927887,'printshop','.w-promotions .heading','grid-row-start','1','','','.w-promotions'),(927888,'printshop','.w-predefined-promotion .condition','grid-row-start','1','','','.w-predefined-promotion'),(927889,'printshop','.w-predefined-promotion .content','grid-row-start','2','','','.w-predefined-promotion'),(927890,'printshop','.w-predefined-promotion .heading','grid-row-start','1','','','.w-predefined-promotion'),(927891,'printshop','.w-account-personal-catalog .remove','grid-row_important','important','5333','','.w-account-personal-catalog'),(927892,'printshop','.w-promotions .prom-multi-discount .list','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(927893,'printshop','.w-promotions .prom-multi-discount .promo-group-4 .products','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(927894,'printshop','.w-promotions .prom-multi-discount .promo-group-3 .products','grid-template-columns','1fr 1fr 1fr','','','.w-promotions'),(927895,'printshop','.w-promotions .prom-multi-discount .products','grid-template-columns','1fr','','','.w-promotions'),(927896,'printshop','.w-promotions .prom-multi-discount .promo-group-2 .products','grid-template-columns','1fr 1fr','','','.w-promotions'),(927897,'printshop','.w-promotions .nextdiscount .content','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(927898,'printshop','.w-reviews-content .item','grid-template-columns','170px 1fr 1fr','','','.w-reviews-content'),(927899,'printshop','.w-reviews .item','grid-template-columns','140px 1fr 1fr','','','.w-reviews'),(927900,'printshop','.w-cart-listing .item','grid-template-columns','80px 1fr 150px 130px','5342','','.w-cart-listing'),(927901,'printshop','.w-cart-listing .item','grid-template-columns','80px 70px 1fr','5333','','.w-cart-listing'),(927902,'printshop','.w-sample-products .w-cart-listing .item, .w-sample-products .w-cart-listing .headings','grid-template-columns','50px 120px 1fr 150px','','','.w-sample-products'),(927903,'printshop','.w-sample-products .w-cart-listing .item, .w-sample-products .w-cart-listing .headings','grid-template-columns','80px 70px 1fr','5333','','.w-sample-products'),(927904,'printshop','.w-account-personal-catalog .w-cart-listing .item','grid-template-columns','80px 120px 1fr 150px 200px','5342','','.w-account-personal-catalog'),(927905,'printshop','.w-account-personal-catalog .w-cart-listing .item','grid-template-columns','80px 1fr','5333','','.w-account-personal-catalog'),(927906,'printshop','.w-press-reviews-widgets-press-reviews .item','grid-template-columns','170px 1fr 1fr','','','.w-press-reviews-widgets-press-reviews'),(927907,'printshop','.w-press-reviews-widgets-press-reviews .item','grid-template-columns','1fr','5333','','.w-press-reviews-widgets-press-reviews'),(927908,'printshop','.w-predefined-promotion .nextdiscount .content','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-predefined-promotion'),(927909,'printshop','.w-predefined-promotion .prom-multi-discount .list','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-predefined-promotion'),(927910,'printshop','.w-predefined-promotion .prom-multi-discount .products','grid-template-columns','1fr','','','.w-predefined-promotion'),(927911,'printshop','.w-predefined-promotion .prom-multi-discount .promo-group-2 .products','grid-template-columns','1fr 1fr','','','.w-predefined-promotion'),(927912,'printshop','.w-predefined-promotion .prom-multi-discount .promo-group-3 .products','grid-template-columns','1fr 1fr 1fr','','','.w-predefined-promotion'),(927913,'printshop','.w-predefined-promotion .prom-multi-discount .promo-group-4 .products','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-predefined-promotion'),(927914,'printshop','.w-cart-listing .headings','grid-template-columns','120px 1fr 150px 200px','','','.w-cart-listing'),(927915,'printshop','.w-cart-listing .item','grid-template-columns','120px 1fr 200px 150px','','','.w-cart-listing'),(927916,'printshop','.order-summary .w-cart-listing .headings','grid-template-columns','3fr 1fr 1fr','','','.order-summary'),(927917,'printshop','.order-summary .w-cart-listing .item','grid-template-columns','3fr 1fr 1fr','','','.order-summary'),(927918,'printshop','.success-page .w-cart-listing .item','grid-template-columns','80px 1fr 100px','','','.success-page'),(927919,'printshop','.w-cart-listing .item','grid-template-rows','1fr','5333','','.w-cart-listing'),(927920,'printshop','.w-cart-listing .item','grid-template-rows','53px 1fr','','','.w-cart-listing'),(927921,'printshop','.checkout-index-wrap .w-cart-listing .multi-cart .item','grid-template-rows','1fr','','','.checkout-index-wrap'),(927922,'printshop','.success-page .w-cart-listing .item','grid-template-rows','1fr','','','.success-page'),(927923,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','height','28','','','.b-switch'),(927924,'printshop','.w-product-promotions select','height','29','','','.w-product-promotions'),(927925,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','height','20','3','','.b-switch'),(927926,'printshop','.b-email-editor img','height','auto','','','.b-email-editor'),(927927,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.p-quick-order-index'),(927928,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.p-quick-order-index'),(927929,'printshop','.w-product-images-additional .item-div','height','80','5363','','.w-product-images-additional'),(927930,'printshop','.w-promotions .prom-multi-discount .products','height','calc(100% - 25px)','','','.w-promotions'),(927931,'printshop','.w-promotions .prom-multi-discount .image img','height','auto','','','.w-promotions'),(927932,'printshop','.w-promotions .promo-salemaker .image img','height','auto','','','.w-promotions'),(927933,'printshop','.w-promotions .promo-cart-discount .image img','height','auto','','','.w-promotions'),(927934,'printshop','.b-preloader .preloader','height','40','3','','.b-preloader'),(927935,'printshop','.b-preloader .preloader','height','100','','','.b-preloader'),(927936,'printshop','.b-messages .select2-container-multi input.select2-input','height','31','','','.b-messages'),(927937,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','height','35','','',''),(927938,'printshop','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(927939,'printshop','.w-product-promotions select','height','29','','','.w-product-promotions'),(927940,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','height','15','3','','.b-switch'),(927941,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','height','15','','','.b-switch'),(927942,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','height','15','','','.b-switch'),(927943,'printshop','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(927944,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','height','15','','','.b-switch'),(927945,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','height','30','4','','.b-switch'),(927946,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg','height','15','','','.b-switch'),(927947,'printshop','.b-fancybox #fancybox-loading div','height','44','','','.b-fancybox'),(927948,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','height','60','','','.b-switch'),(927949,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height','100','3','','.b-switch'),(927950,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-toggle','height','40','','','.b-switch'),(927951,'printshop','.w-checkout-shipping-choice input:checked + span:before','height','10','','','.w-checkout-shipping-choice'),(927952,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','height','150','','','.w-upload-customer-id-upload-customer-id-form'),(927953,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file','height','100','','','.w-upload-customer-id-upload-customer-id-form'),(927954,'printshop','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(927955,'printshop','.b-switch .bootstrap-switch','height','28','','','.b-switch'),(927956,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','height','10','3','','.b-switch'),(927957,'printshop','.w-personal-gift-status-bar .progress-bar','height','8','','','.w-personal-gift-status-bar'),(927958,'printshop','.w-filters .input-checkbox:checked + .checkbox-span','height','24','','','.w-filters'),(927959,'printshop','.b-info-popup .info-popup div','height','20','3','','.b-info-popup'),(927960,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','height','10','','','.b-switch'),(927961,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','height','10','','','.b-switch'),(927962,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','height','15','4','','.b-switch'),(927963,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-toggle','height','15','','','.b-switch'),(927964,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg','height','10','','','.b-switch'),(927965,'printshop','.b-form .hide-billing-address','height','100','','','.b-form'),(927966,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','height','16','3','','.b-switch'),(927967,'printshop','.b-select-suggest .select2-container .select2-choice abbr','height','12','','','.b-select-suggest'),(927968,'printshop','.w-filters .ui-slider-handle','height','18','','','.w-filters'),(927969,'printshop','.w-filters .ui-slider','height','6','','','.w-filters'),(927970,'printshop','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(927971,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','height','16','','','.b-switch'),(927972,'printshop','.b-switch .candlestick-wrapper','height','auto','','','.b-switch'),(927973,'printshop','.b-switch .candlestick-wrapper .candlestick-bg','height','28','','','.b-switch'),(927974,'printshop','.w-product-images-additional .item','height','80','5363','','.w-product-images-additional'),(927975,'printshop','.b-bottom .cart-options .cart-item input[type=\"text\"]','height','33','','','.b-bottom'),(927976,'printshop','.b-select-suggest .select2-measure-scrollbar','height','100','','','.b-select-suggest'),(927977,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','height','30','3','','.b-form'),(927978,'printshop','.b-fancybox .fancybox-close','height','40','','','.b-fancybox'),(927979,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height','1','','','.b-select-suggest'),(927980,'printshop','.w-product-images-additional .item','height','80','5363','','.w-product-images-additional'),(927981,'printshop','.w-product-images-additional .item-div','height','80','5363','','.w-product-images-additional'),(927982,'printshop','.w-product-images-additional .item-div','height','80','5363','','.w-product-images-additional'),(927983,'printshop','.b-email-editor img','height','auto','','','.b-email-editor'),(927984,'printshop','.w-product-images-additional .item-div','height','80','5363','','.w-product-images-additional'),(927985,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','height','20','','','.b-switch'),(927986,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span','height','18','','','.b-form'),(927987,'printshop','.w-product-promotions select','height','29','','','.w-product-promotions'),(927988,'printshop','.w-product-promotions select','height','29','','','.w-product-promotions'),(927989,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height','60','','','.b-switch'),(927990,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','height','56','','','.b-switch'),(927991,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height','100','4','','.b-switch'),(927992,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','','','.b-switch'),(927993,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height','60','','','.b-switch'),(927994,'printshop','.b-email-editor img','height','auto','','','.b-email-editor'),(927995,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','height','100','','','.b-switch'),(927996,'printshop','.b-switch .candlestick-wrapper.candlestick-contents','height','56','','','.b-switch'),(927997,'printshop','.w-product-promotions select','height','29','','','.w-product-promotions'),(927998,'printshop','.b-fancybox .fancybox-nav','height','100','','','.b-fancybox'),(927999,'printshop','.b-select-suggest .select2-container .select2-choice','height','35','','','.b-select-suggest'),(928000,'printshop','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(928001,'printshop','.w-personal-gift-status-bar .progress-bar-content','height','8','','','.w-personal-gift-status-bar'),(928002,'printshop','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(928003,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','height','20','3','','.b-switch'),(928004,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','4','','.b-switch'),(928005,'printshop','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(928006,'printshop','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(928007,'printshop','.b-email-editor img','height','auto','','','.b-email-editor'),(928008,'printshop','.w-product-images-additional .item-div','height','80','5363','','.w-product-images-additional'),(928009,'printshop','.b-autocomplete .ui-autocomplete','height','300','','','.b-autocomplete'),(928010,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','','','.b-switch'),(928011,'printshop','.b-form .checkbox-style:checked + .checkbox-span','height','18','','','.b-form'),(928012,'printshop','.b-info-popup .info-popup','height','2','','','.b-info-popup'),(928013,'printshop','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(928014,'printshop','.w-product-customers-activity .close','height','30','','','.w-product-customers-activity'),(928015,'printshop','.b-email-editor img','height','auto','','','.b-email-editor'),(928016,'printshop','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(928017,'printshop','.w-menu-horizontal .menu-ico','height','54','','','.w-menu-horizontal'),(928018,'printshop','.w-product-images-additional .item','height','80','5363','','.w-product-images-additional'),(928019,'printshop','.w-product-images-additional .item-div','height','80','5363','','.w-product-images-additional'),(928020,'printshop','.w-product-images-additional .item','height','80','5363','','.w-product-images-additional'),(928021,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','height','16','','','.b-switch'),(928022,'printshop','.b-select-suggest .select2-search-choice-close','height','13','','','.b-select-suggest'),(928023,'printshop','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','height','25','','','.b-datepicker'),(928024,'printshop','.b-select-suggest .select2-search input','height','auto','','','.b-select-suggest'),(928025,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height','100','','','.b-select-suggest'),(928026,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow','height','100','','','.b-select-suggest'),(928027,'printshop','.b-select-suggest .select2-drop-mask','height','auto','','','.b-select-suggest'),(928028,'printshop','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(928029,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.b-data-table'),(928030,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.b-data-table'),(928031,'printshop','.b-products-listing .btn-preloader','height','24','3','','.b-products-listing'),(928032,'printshop','.b-products-listing .hover-box-content','height','20','3','','.b-products-listing'),(928033,'printshop','.b-products-listing .loader','height','30','4','','.b-products-listing'),(928034,'printshop','.b-products-listing .loader','height','100','3','','.b-products-listing'),(928035,'printshop','.b-products-listing .products-listing .qty-input.hidden','height','100','3','','.b-products-listing'),(928036,'printshop','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','height','auto','','','.b-products-listing'),(928037,'printshop','.checkbox input + span','height','24','','',''),(928038,'printshop','.checkbox input:not(checked) + span:before','height','22','','',''),(928039,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','height','20','3','','.b-switch'),(928040,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','height','10','4','','.b-switch'),(928041,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-toggle','height','10','','','.b-switch'),(928042,'printshop','.b-email-editor img','height','auto','','','.b-email-editor'),(928043,'printshop','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height','100','','','.b-fancybox'),(928044,'printshop','.w-product-promotions select','height','29','','','.w-product-promotions'),(928045,'printshop','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(928046,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','height','36','','','.w-communication-new-topic'),(928047,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','height','36','','','.w-communication-new-topic'),(928048,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','height','30','','','.w-communication-new-topic'),(928049,'printshop','.w-communication-new-topic #communication_group_holder select','height','35','','','.w-communication-new-topic'),(928050,'printshop','.w-catalog-listing-look .grid','height','35','','','.w-catalog-listing-look'),(928051,'printshop','.w-catalog-listing-look .b2b','height','35','','','.w-catalog-listing-look'),(928052,'printshop','.w-catalog-listing-look .list','height','35','','','.w-catalog-listing-look'),(928053,'printshop','.w-cart-listing .item .remove','height','45','5342','','.w-cart-listing'),(928054,'printshop','.b-upload-file .snapshot','height','38','','','.b-upload-file'),(928055,'printshop','.w-image-maps .svg-wrap svg','height','100','','','.w-image-maps'),(928056,'printshop','.b-fancybox .fancybox-nav span','height','40','','','.b-fancybox'),(928057,'printshop','.b-upload-file .upload-file-template','height','150','','','.b-upload-file'),(928058,'printshop','.w-filters .ui-slider-range','height','6','','','.w-filters'),(928059,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','height','10','','','.b-switch'),(928060,'printshop','.b-bottom .pop-up-close','height','31','','','.b-bottom'),(928061,'printshop','.w-product-images-additional .item','height','80','5363','','.w-product-images-additional'),(928062,'printshop','.w-product-images-additional .item','height','80','5363','','.w-product-images-additional'),(928063,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg','height','30','','','.b-switch'),(928064,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','height','30','','','.b-switch'),(928065,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','height','30','','','.b-switch'),(928066,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','height','30','3','','.b-switch'),(928067,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','height','30','','','.b-switch'),(928068,'printshop','.w-filters .input-checkbox:not(checked) + .checkbox-span','height','24','','','.w-filters'),(928069,'printshop','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','height','auto','','','.b-product-images'),(928070,'printshop','.b-product-images .media-popup .mp-big-images','height','calc(100vh - 150px)','','','.b-product-images'),(928071,'printshop','.b-product-images .media-popup .mp-big-images .item','height','calc(100vh - 150px)','','','.b-product-images'),(928072,'printshop','.b-product-images .media-popup .mp-close','height','100','','','.b-product-images'),(928073,'printshop','.b-product-images .media-popup .mp-content','height','100','','','.b-product-images'),(928074,'printshop','.b-product-images .media-popup .mp-small-images','height','100','','','.b-product-images'),(928075,'printshop','.b-product-images .media-popup .mp-small-images .item','height','100','','','.b-product-images'),(928076,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','height','100','','','.b-product-images'),(928077,'printshop','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','height','30','','','.b-menu-burger_icon'),(928078,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(928079,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(928080,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(928081,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(928082,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(928083,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height','100','','','.b-menu-open_from-left'),(928084,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(928085,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','height','35','','','.b-trade-approval'),(928086,'printshop','.w-account-subscription .info-popup','height','15','','','.w-account-subscription'),(928087,'printshop','.w-catalog-compare span.btn-preloader','height','24','','','.w-catalog-compare'),(928092,'printshop','.tripleBanner .w-html_box','height','100','3','','.tripleBanner'),(928093,'printshop','.b-slick .slick-slide','height','100','','','.b-slick'),(928094,'printshop','.b-slick .slick-vertical .slick-slide','height','auto','','','.b-slick'),(928095,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','height','40','','','.b-slick'),(928096,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','height','50','5342','','.b-slick'),(928099,'printshop','.menu-header .burger-icon','height','40','5342','','.menu-header'),(928100,'printshop','.tripleBanner > .block > .box','height','100','','','.tripleBanner'),(928101,'printshop','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','height','18','','','.w-filters'),(928102,'printshop','.w-quote .cart-box-link','height','48','3','','.w-quote'),(928103,'printshop','.w-quote .cart-box-link','height','40','5342,3','','.w-quote'),(928104,'printshop','.w-product-images .additional-vertical','height','400','','','.w-product-images'),(928105,'printshop','.w-product-images .img-holder','height','100','','','.w-product-images'),(928106,'printshop','.b-quantity .qty-box .bigger','height','32','','','.b-quantity'),(928107,'printshop','.b-quantity .qty-box .smaller','height','32','','','.b-quantity'),(928108,'printshop','.warrantyProduct .warranty','height','32','3','','.warrantyProduct'),(928109,'printshop','.warrantyProduct .delivery','height','30','3','','.warrantyProduct'),(928110,'printshop','.w-sample .cart-box-link','height','10','4','','.w-sample'),(928111,'printshop','.w-sample .cart-box-link','height','48','3','','.w-sample'),(928112,'printshop','.w-sample .cart-box-link','height','40','5342,3','','.w-sample'),(928113,'printshop','.w-catalog-additional-images img','height','auto','','','.w-catalog-additional-images'),(928114,'printshop','.w-catalog-additional-images picture','height','150','','','.w-catalog-additional-images'),(928115,'printshop','.b-pagination .pagination .next-pages','height','30','','','.b-pagination'),(928116,'printshop','.b-pagination .pagination .page-number','height','30','','','.b-pagination'),(928117,'printshop','.b-pagination .pagination .prev-pages','height','30','','','.b-pagination'),(928118,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','height','30','','','.b-pagination');
INSERT INTO `themes_styles` VALUES (928119,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','height','30','','','.b-pagination'),(928120,'printshop','.b-pagination .pagination span','height','30','2','','.b-pagination'),(928121,'printshop','.p-sample-checkout-index .order-summary .heading-2','height','1','3','','.p-sample-checkout-index'),(928122,'printshop','.p-sample-checkout-index .order-summary .heading-2','height','1','4','','.p-sample-checkout-index'),(928124,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','height','36','','','.w-account-personal-catalog'),(928125,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','height','40','','','.w-questionnaire-widgets-questionnaire'),(928126,'printshop','.w-sale-category .badge','height','80','','','.w-sale-category'),(928127,'printshop','.w-product-designer-designer .prodDesignerType label','height','78','','','.w-product-designer-designer'),(928128,'printshop','.w-product-designer-designer .productDesignerBox input','height','100','','','.w-product-designer-designer'),(928129,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','height','35','','','.w-rma-returns-history'),(928130,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(928131,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(928132,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(928133,'printshop','.w-predefined-promotion .prom-multi-discount .image img','height','auto','','','.w-predefined-promotion'),(928134,'printshop','.w-predefined-promotion .prom-multi-discount .products','height','calc(100% - 25px)','','','.w-predefined-promotion'),(928135,'printshop','.w-predefined-promotion .promo-cart-discount .image img','height','auto','','','.w-predefined-promotion'),(928136,'printshop','.w-predefined-promotion .promo-salemaker .image img','height','auto','','','.w-predefined-promotion'),(928138,'printshop','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','height','auto','','','.b-menu-lev_vis'),(928139,'printshop','.heading-1','height','1','4','',''),(928140,'printshop','h1','height','1','4','',''),(928141,'printshop','.b-quantity .qty-box input[type=\"text\"]','height','32','','','.b-quantity'),(928142,'printshop','.tripleLine picture[id] > img, .tripleLine picture[style] > img','height','auto','','','.tripleLine'),(928143,'printshop','.cartTitle >div','height','1','4','','.cartTitle'),(928144,'printshop','.topBanner .w-banner .banner-item .banner-text','height','100','','','.topBanner'),(928145,'printshop','.topBanner .w-banner .text-middle-left .banner-text','height','auto','5333','','.topBanner'),(928146,'printshop','.topBanner .content','height','100','','','.topBanner'),(928147,'printshop','.topBanner .banner-text-holder','height','100','','','.topBanner'),(928148,'printshop','.order-summary .icon','height','30','','','.order-summary'),(928149,'printshop','.p-quote-checkout-index .input-wrapper','height','35','','','.p-quote-checkout-index'),(928154,'printshop','.account-samples .orders-table .td-alignright','height','45','5342','','.account-samples'),(928155,'printshop','.catalog-product-wrap .pn-image','height','24','3','','.catalog-product-wrap'),(928156,'printshop','.checkout-index-wrap .input-wrapper','height','35','','','.checkout-index-wrap'),(928157,'printshop','.index-wrap .heading-2','height','1','4','','.index-wrap'),(928158,'printshop','.index-wrap h2','height','1','4','','.index-wrap'),(928159,'printshop','.b-slick .slick-dots li','height','10','3','','.b-slick'),(928160,'printshop','.fake-input','height','0','','',''),(928161,'printshop','.hide-page','height','100','','',''),(928162,'printshop','.success-page .w-cart-listing .qty','height','24','','','.success-page'),(928163,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-content','height','auto','','','.b-multi-page-checkout'),(928164,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','height','33','','','.b-multi-page-checkout'),(928165,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','height','35','3','','.b-multi-page-checkout'),(928166,'printshop','.w-bestsellers .counter','height','32','','','.w-bestsellers'),(928167,'printshop','.w-bestsellers .item','height','32','3','','.w-bestsellers'),(928168,'printshop','.w-banner .carousel-text','height','100','','','.w-banner'),(928169,'printshop','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height','100','','','.w-banner'),(928170,'printshop','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height','100','','','.w-banner'),(928171,'printshop','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height','100','','','.w-banner'),(928172,'printshop','.w-catalog-paging ','height','30','2','','.w-catalog-paging'),(928173,'printshop','.w-catalog-paging .next','height','30','','','.w-catalog-paging'),(928174,'printshop','.w-catalog-paging .next-pages','height','30','','','.w-catalog-paging'),(928175,'printshop','.w-catalog-paging .page-number','height','30','','','.w-catalog-paging'),(928176,'printshop','.w-catalog-paging .paging-holder','height','30','','','.w-catalog-paging'),(928177,'printshop','.w-catalog-paging .prev','height','30','','','.w-catalog-paging'),(928178,'printshop','.w-catalog-paging .prev-pages','height','30','','','.w-catalog-paging'),(928179,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height','30','','','.w-catalog-paging'),(928183,'printshop','.w-sale .badge','height','80','','','.w-sale'),(928184,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height_important','important','','','.b-select-suggest'),(928185,'printshop','.b-select-suggest .select2-search input','height_important','important','','','.b-select-suggest'),(928186,'printshop','.menu-header .burger-icon','height_important','important','5342','','.menu-header'),(928187,'printshop','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','height_important','important','','','.b-menu-lev_vis'),(928188,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-content','height_important','important','','','.b-multi-page-checkout'),(928189,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height_important','important','','','.w-catalog-paging'),(928190,'printshop','.b-preloader .preloader','height_measure','%','','','.b-preloader'),(928191,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height_measure','%','3','','.b-switch'),(928192,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file','height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(928193,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height_measure','%','4','','.b-switch'),(928194,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','height_measure','%','','','.b-switch'),(928195,'printshop','.b-fancybox .fancybox-nav','height_measure','%','','','.b-fancybox'),(928196,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height_measure','%','','','.b-select-suggest'),(928197,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow','height_measure','%','','','.b-select-suggest'),(928198,'printshop','.b-products-listing .loader','height_measure','%','3','','.b-products-listing'),(928199,'printshop','.b-products-listing .products-listing .qty-input.hidden','height_measure','%','3','','.b-products-listing'),(928200,'printshop','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height_measure','%','','','.b-fancybox'),(928201,'printshop','.b-form .hide-billing-address','height_measure','%','','','.b-form'),(928202,'printshop','.w-image-maps .svg-wrap svg','height_measure','%','','','.w-image-maps'),(928203,'printshop','.b-product-images .media-popup .mp-content','height_measure','vh','','','.b-product-images'),(928204,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height_measure','vh','','','.b-menu-open_from-left'),(928205,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(928206,'printshop','.tripleBanner .w-html_box','height_measure','%','3','','.tripleBanner'),(928207,'printshop','.b-slick .slick-slide','height_measure','%','','','.b-slick'),(928208,'printshop','.tripleBanner > .block > .box','height_measure','%','','','.tripleBanner'),(928209,'printshop','.w-catalog-listing-look .b2b','height_measure','x','','','.w-catalog-listing-look'),(928210,'printshop','.w-product-images .img-holder','height_measure','%','','','.w-product-images'),(928211,'printshop','.w-product-designer-designer .productDesignerBox input','height_measure','%','','','.w-product-designer-designer'),(928212,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(928213,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(928214,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(928215,'printshop','.topBanner .w-banner .banner-item .banner-text','height_measure','%','','','.topBanner'),(928216,'printshop','.topBanner .content','height_measure','%','','','.topBanner'),(928217,'printshop','.topBanner .banner-text-holder','height_measure','%','','','.topBanner'),(928219,'printshop','.hide-page','height_measure','%','','',''),(928220,'printshop','.w-banner .carousel-text','height_measure','%','','','.w-banner'),(928221,'printshop','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height_measure','%','','','.w-banner'),(928222,'printshop','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height_measure','%','','','.w-banner'),(928223,'printshop','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height_measure','%','','','.w-banner'),(928224,'printshop','.w-promotions .promo-cart-discount .content','justify-content','center','','','.w-promotions'),(928225,'printshop','.w-promotions .prom-multi-discount .products','justify-content','space-between','','','.w-promotions'),(928226,'printshop','.w-promotions .promo-salemaker .content','justify-content','center','','','.w-promotions'),(928227,'printshop','.b-products-listing .products-listing .attribute-qty-blocks','justify-content','space-between','','','.b-products-listing'),(928228,'printshop','.p-quick-order-index .quick-order-total','justify-content','space-between','','','.p-quick-order-index'),(928229,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(928230,'printshop','.w-personal-gift-status-bar .timeline','justify-content','center','','','.w-personal-gift-status-bar'),(928231,'printshop','.w-checkout-shipping-choice span','justify-content','center','','','.w-checkout-shipping-choice'),(928232,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(928233,'printshop','.order-summary .price-row','justify-content','space-between','','','.order-summary'),(928234,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(928235,'printshop','.w-communication-post .communication-post-author','justify-content','space-between','','','.w-communication-post'),(928236,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(928237,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(928238,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(928239,'printshop','.b-product-images .media-popup .mp-big-images .item','justify-content','center','','','.b-product-images'),(928240,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(928241,'printshop','.w-catalog-compare .cross-box','justify-content','flex-end','','','.w-catalog-compare'),(928242,'printshop','.w-product-images .img-holder','justify-content','center','','','.w-product-images'),(928243,'printshop','.w-files-catalog-widgets-files-catalog ','justify-content','space-between','','','.w-files-catalog-widgets-files-catalog'),(928244,'printshop','.w-files-catalog-widgets-files-catalog .image','justify-content','center','','','.w-files-catalog-widgets-files-catalog'),(928245,'printshop','.w-product-bundle .bundle-products','justify-content','space-between','','','.w-product-bundle'),(928246,'printshop','.w-product-in-bundles .bundle-products','justify-content','space-between','','','.w-product-in-bundles'),(928248,'printshop','.w-delivery-location-product-categories .categories','justify-content','center','','','.w-delivery-location-product-categories'),(928249,'printshop','.w-press-reviews-widgets-press-reviews .review-box','justify-content','center','','','.w-press-reviews-widgets-press-reviews'),(928250,'printshop','.w-press-reviews-widgets-press-reviews-list .review-box','justify-content','center','','','.w-press-reviews-widgets-press-reviews-list'),(928251,'printshop','.w-rma-returns-history .column','justify-content','space-between','','','.w-rma-returns-history'),(928252,'printshop','.w-rma-returns-history .filterMessages','justify-content','space-between','','','.w-rma-returns-history'),(928253,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul','justify-content','flex-start','','','.b-menu-position'),(928254,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(928255,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul','justify-content','center','','','.b-menu-position'),(928256,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(928257,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul','justify-content','flex-end','','','.b-menu-position'),(928258,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(928259,'printshop','.w-predefined-promotion .prom-multi-discount .products','justify-content','space-between','','','.w-predefined-promotion'),(928260,'printshop','.w-predefined-promotion .promo-cart-discount .content','justify-content','center','','','.w-predefined-promotion'),(928261,'printshop','.w-predefined-promotion .promo-salemaker .content','justify-content','center','','','.w-predefined-promotion'),(928262,'printshop','.w-supplier-purchase-supplier-products .item','justify-content','space-between','','','.w-supplier-purchase-supplier-products'),(928264,'printshop','.bottomBanner .icon-box','justify-content','center','5347','','.bottomBanner'),(928265,'printshop','.p-payer-order-pay .price-row','justify-content','space-between','','','.p-payer-order-pay'),(928266,'printshop','.p-payer-order-confirmation .price-row','justify-content','space-between','','','.p-payer-order-confirmation'),(928267,'printshop','.w-categories .categories','justify-content','center','','','.w-categories'),(928268,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons','justify-content','space-between','','','.p-quote-checkout-index'),(928269,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons','justify-content','space-between','','','.checkout-index-wrap'),(928270,'printshop','.checkout-order-confirmation .price-row','justify-content','space-between','','','.checkout-order-confirmation'),(928271,'printshop','.b-form .columns','justify-content','space-between','','','.b-form'),(928272,'printshop','.b-slick .slick-dots','justify-content','center','','','.b-slick'),(928273,'printshop','.hide-page','justify-content','center','','',''),(928274,'printshop','.success-page .order_totals .price-row','justify-content','space-between','','','.success-page'),(928275,'printshop','.success-page .price-row','justify-content','space-between','','','.success-page'),(928276,'printshop','.w-checkout-totals .price-row','justify-content','space-between','','','.w-checkout-totals'),(928277,'printshop','.b-form .formWrapBox','justify-content','space-between','','','.b-form'),(928278,'printshop','.tripleLine .banner','justify-content','space-around','','','.tripleLine'),(928279,'printshop','.w-login-register .middle-form form','justify-content','space-between','','','.w-login-register'),(928280,'printshop','.w-login-returning .middle-form form','justify-content','space-between','','','.w-login-returning'),(928281,'printshop','.w-product-reviews .middle-form form','justify-content','space-between','','','.w-product-reviews'),(928283,'printshop','.w-banner .banner-item.text-bottom-center .banner-text','justify-content','center','','','.w-banner'),(928284,'printshop','.w-banner .banner-item.text-bottom-left .banner-text','justify-content','start','','','.w-banner'),(928285,'printshop','.w-banner .banner-item.text-bottom-right .banner-text','justify-content','end','','','.w-banner'),(928286,'printshop','.w-banner .banner-item.text-middle-center .banner-text','justify-content','center','','','.w-banner'),(928287,'printshop','.w-banner .banner-item.text-middle-left .banner-text','justify-content','start','','','.w-banner'),(928288,'printshop','.w-banner .banner-item.text-middle-right .banner-text','justify-content','end','','','.w-banner'),(928289,'printshop','.w-banner .banner-item.text-top-center .banner-text','justify-content','center','','','.w-banner'),(928290,'printshop','.w-banner .banner-item.text-top-left .banner-text','justify-content','start','','','.w-banner'),(928291,'printshop','.w-banner .banner-item.text-top-right .banner-text','justify-content','end','','','.w-banner'),(928292,'printshop','.w-banner .carousel .bottom-center','justify-content','center','','','.w-banner'),(928293,'printshop','.w-banner .carousel .bottom-left','justify-content','flex-start','','','.w-banner'),(928294,'printshop','.w-banner .carousel .bottom-right','justify-content','flex-end','','','.w-banner'),(928295,'printshop','.w-banner .carousel .middle-center','justify-content','center','','','.w-banner'),(928296,'printshop','.w-banner .carousel .middle-left','justify-content','flex-start','','','.w-banner'),(928297,'printshop','.w-banner .carousel .middle-right','justify-content','flex-end','','','.w-banner'),(928298,'printshop','.w-banner .carousel .top-center','justify-content','center','','','.w-banner'),(928299,'printshop','.w-banner .carousel .top-left','justify-content','flex-start','','','.w-banner'),(928300,'printshop','.w-banner .carousel .top-right','justify-content','flex-end','','','.w-banner'),(928301,'printshop','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(928302,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','left','2','3','','.b-switch'),(928303,'printshop','.w-promo-code .holder','left','12','5363,3','','.w-promo-code'),(928304,'printshop','.p-quick-order-index .all-scroll-div','left','0','','','.p-quick-order-index'),(928305,'printshop','.w-promo-code .holder','left','20','3','','.w-promo-code'),(928306,'printshop','.testimonials .heading-3','left','0','3','',''),(928307,'printshop','.testimonials .review','left','10','3','',''),(928308,'printshop','.b-preloader .preloader','left','calc(50% - 20px)','3','','.b-preloader'),(928309,'printshop','.b-preloader .preloader','left','0','','','.b-preloader'),(928310,'printshop','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(928311,'printshop','.w-checkout-terms .required-message','left','0','','','.w-checkout-terms'),(928312,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','left','15','','','.b-switch'),(928313,'printshop','.b-fancybox #fancybox-loading','left','50','','','.b-fancybox'),(928314,'printshop','.b-fancybox .fancybox-wrap','left','0','','','.b-fancybox'),(928315,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','left','100','','','.b-switch'),(928316,'printshop','.w-promo-code .holder','left','20','3','','.w-promo-code'),(928317,'printshop','.w-checkout-shipping-choice input:checked + span:before','left','50','','','.w-checkout-shipping-choice'),(928318,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(928319,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-details','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(928320,'printshop','.b-info-popup .info-popup div','left','-11','3','','.b-info-popup'),(928321,'printshop','.b-fancybox .fancybox-title-over-wrap','left','0','','','.b-fancybox'),(928322,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','left','10','','','.b-switch'),(928323,'printshop','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(928324,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','left','20','','','.b-switch'),(928325,'printshop','.w-cart-compare .dropdown .dropdown-menu','left','auto','','','.w-cart-compare'),(928326,'printshop','.b-select-suggest .select2-measure-scrollbar','left','-10000','','','.b-select-suggest'),(928327,'printshop','.b-fancybox .fancybox-tmp','left','-99999','','','.b-fancybox'),(928329,'printshop','.b-info-popup .info-popup.top-left div','left','auto','','','.b-info-popup'),(928330,'printshop','.b-info-popup .info-popup.top-left div','left','auto','3','','.b-info-popup'),(928331,'printshop','.w-promo-code .holder','left','12','5363,3','','.w-promo-code'),(928332,'printshop','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(928333,'printshop','.w-promo-code .holder','left','20','3','','.w-promo-code'),(928334,'printshop','.view-all','left','0','3','',''),(928336,'printshop','.b-fancybox .fancybox-overlay','left','0','','','.b-fancybox'),(928338,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left','25','','','.b-switch'),(928339,'printshop','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(928340,'printshop','.w-multi-cart-actions .dropdown .dropdown-menu','left','0','','','.w-multi-cart-actions'),(928341,'printshop','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','left','0','','','.b-switch'),(928343,'printshop','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(928344,'printshop','.b-select-suggest .select2-drop-mask','left','0','','','.b-select-suggest'),(928345,'printshop','.w-reviews .review','left','15','3','','.w-reviews'),(928347,'printshop','.b-fancybox .fancybox-prev','left','0','','','.b-fancybox'),(928348,'printshop','.b-fancybox .fancybox-prev span','left','10','','','.b-fancybox'),(928350,'printshop','.w-promo-code .holder','left','12','5363,3','','.w-promo-code'),(928351,'printshop','.w-promo-code .holder','left','20','3','','.w-promo-code'),(928352,'printshop','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(928353,'printshop','.w-reviews .heading-3','left','0','3','','.w-reviews'),(928354,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','left','2','3','','.b-switch'),(928355,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left','4','3','','.b-switch'),(928356,'printshop','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(928357,'printshop','.w-reviews-content .review','left','15','3','','.w-reviews-content'),(928358,'printshop','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(928359,'printshop','.w-promo-code .holder','left','12','5363,3','','.w-promo-code'),(928360,'printshop','.b-form .radio-button input[type=\"radio\"].no','left','-100','','','.b-form'),(928362,'printshop','.w-checkout-billing-address .addresses .address-item label input','left','0','','','.w-checkout-billing-address'),(928363,'printshop','.w-promo-code .holder','left','12','5363,3','','.w-promo-code'),(928364,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','left','0','','','.b-switch'),(928365,'printshop','.b-select-suggest .select2-container-multi .select2-search-choice-close','left','3','','','.b-select-suggest'),(928366,'printshop','.w-menu-horizontal > ul > li > ul','left','0','','','.w-menu-horizontal'),(928367,'printshop','.w-checkout-shipping-address .addresses .address-item label input','left','0','','','.w-checkout-shipping-address'),(928369,'printshop','.w-image-maps .svg-wrap svg','left','0','','','.w-image-maps'),(928370,'printshop','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(928371,'printshop','.b-products-listing .products-listing .promos-info','left','0','','','.b-products-listing'),(928372,'printshop','.b-products-listing .hover-box-content','left','0','','','.b-products-listing'),(928373,'printshop','.b-products-listing .hover-box-content','left','20','3','','.b-products-listing'),(928374,'printshop','.b-products-listing .loader','left','calc(50% - 15px)','4','','.b-products-listing'),(928375,'printshop','.b-products-listing .loader','left','0','3','','.b-products-listing'),(928376,'printshop','.w-catalog-b2b-add-button ','left','0','','','.w-catalog-b2b-add-button'),(928377,'printshop','.b-products-listing .products-listing .qty-input.hidden','left','0','3','','.b-products-listing'),(928378,'printshop','.b-products-listing .promo','left','0','','','.b-products-listing'),(928379,'printshop','.checkbox input','left','-20','','',''),(928381,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left','0','','','.b-select-suggest'),(928382,'printshop','.w-promo-code .holder','left','20','3','','.w-promo-code'),(928383,'printshop','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(928384,'printshop','.w-promo-code .holder','left','20','3','','.w-promo-code'),(928385,'printshop','.w-promo-code .holder','left','12','5363,3','','.w-promo-code'),(928386,'printshop','.w-cart-listing .item .remove','left','0','5342','','.w-cart-listing'),(928387,'printshop','.w-cart-listing .remove-btn','left','10','5342','','.w-cart-listing'),(928389,'printshop','.b-info-popup .info-popup div','left','40','','','.b-info-popup'),(928390,'printshop','.w-product-reviews .reviews-list .review','left','10','3','','.w-product-reviews'),(928391,'printshop','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(928392,'printshop','.b-form .hide-billing-address','left','0','','','.b-form'),(928393,'printshop','.w-menu-big > ul > li > ul','left','0','','','.w-menu-big'),(928394,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','left','40','','','.b-switch'),(928395,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','left','0','','','.w-image-maps'),(928396,'printshop','.b-product-images .mp-shadow, .b-product-images .media-popup','left','0','','','.b-product-images'),(928397,'printshop','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','left','0','','','.b-menu-lev_display-down'),(928398,'printshop','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','left','0','','','.b-menu-lev_display-down'),(928399,'printshop','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','left','0','','','.b-menu-lev_display-down'),(928400,'printshop','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','left','0','','','.b-menu-lev_display-down'),(928401,'printshop','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','left','0','','','.b-menu-lev_display-down'),(928402,'printshop','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left','100','','','.b-menu-lev_display-lra'),(928403,'printshop','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left','100','','','.b-menu-lev_display-lra'),(928404,'printshop','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left','100','','','.b-menu-lev_display-lra'),(928405,'printshop','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left','100','','','.b-menu-lev_display-lra'),(928406,'printshop','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left','100','','','.b-menu-lev_display-lra'),(928407,'printshop','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','left','auto','','','.b-menu-lev_display-lra'),(928408,'printshop','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','left','auto','','','.b-menu-lev_display-lra'),(928409,'printshop','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','left','auto','','','.b-menu-lev_display-lra'),(928410,'printshop','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','left','auto','','','.b-menu-lev_display-lra'),(928411,'printshop','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','left','auto','','','.b-menu-lev_display-lra'),(928412,'printshop','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left','100','','','.b-menu-lev_display-right'),(928413,'printshop','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left','100','','','.b-menu-lev_display-right'),(928414,'printshop','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left','100','','','.b-menu-lev_display-right'),(928415,'printshop','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left','100','','','.b-menu-lev_display-right'),(928416,'printshop','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left','100','','','.b-menu-lev_display-right'),(928417,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left','100','','','.b-menu-lev_display-slide'),(928418,'printshop','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left','100','','','.b-menu-lev_display-slide'),(928419,'printshop','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left','100','','','.b-menu-lev_display-slide'),(928420,'printshop','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left','100','','','.b-menu-lev_display-slide'),(928421,'printshop','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left','100','','','.b-menu-lev_display-slide'),(928422,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left','-110','','','.b-menu-open_from-left'),(928423,'printshop','.b-menu-open_from-left .bi-opened .menu-style[data-open_from=\"left\"] .menu-content','left','0','','','.b-menu-open_from-left'),(928424,'printshop','.tripleBanner .w-html_box','left','0','3','','.tripleBanner'),(928425,'printshop','.b-slick .slick-track','left','0','','','.b-slick'),(928426,'printshop','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left','50','','','.b-slick'),(928427,'printshop','.b-slick button.slick-next','left','auto','','','.b-slick'),(928428,'printshop','.b-slick button.slick-prev','left','0','','','.b-slick'),(928429,'printshop','.header','left','0','5342','',''),(928430,'printshop','.w-quote .multicart .switch-cart','left','15','','','.w-quote'),(928431,'printshop','.warrantyProduct .warranty','left','0','3','','.warrantyProduct'),(928432,'printshop','.warrantyProduct .delivery','left','0','3','','.warrantyProduct'),(928433,'printshop','.w-compare ','left','0','','','.w-compare'),(928434,'printshop','.w-sample .multicart .switch-cart','left','15','','','.w-sample'),(928435,'printshop','.p-sample-checkout-index .order-summary .heading-2','left','-14','3','','.p-sample-checkout-index'),(928436,'printshop','.w-account-personal-catalog .w-cart-listing .remove-btn','left','0','5342','','.w-account-personal-catalog'),(928437,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input','left','-50','','','.w-questionnaire-widgets-questionnaire'),(928438,'printshop','.w-sale-category .badge','left','10','','','.w-sale-category'),(928439,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content:before','left','25','','','.w-product-properties-icons'),(928440,'printshop','.w-product-bonus-points > div > div','left','0','3','','.w-product-bonus-points'),(928441,'printshop','.w-product-designer-designer .productDesignerBox input','left','0','','','.w-product-designer-designer'),(928442,'printshop','.w-product-configurator .pc-item label input','left','0','','','.w-product-configurator'),(928443,'printshop','.b-products-listing .products-listing .bonus-points-cost','left','10','3','','.b-products-listing'),(928445,'printshop','.p-wedding-registry-view h1','left','-10','3','','.p-wedding-registry-view'),(928446,'printshop','.b-menu-open_from-top .bi-opened .menu-style[data-open_from=\"top\"] .menu-content','left','0','','','.b-menu-open_from-top'),(928447,'printshop','.b-menu-open_from-top .menu-style[data-open_from=\"top\"] .menu-content','left','0','','','.b-menu-open_from-top'),(928448,'printshop','.topBanner .ourPick','left','-18','3','','.topBanner'),(928449,'printshop','.topBanner .ourPick','left','-14','5347,3','','.topBanner'),(928450,'printshop','.topBanner .ourPick','left','-9','5363,3','','.topBanner'),(928451,'printshop','.topBanner .w-banner .text-middle-left .banner-text','left','5','','','.topBanner'),(928452,'printshop','.topBanner .w-banner .text-middle-left .banner-text','left','2','5342','','.topBanner'),(928453,'printshop','.topBanner .w-banner .text-middle-left .banner-text','left','0','5333','','.topBanner'),(928455,'printshop','.account-address-book .buttonBox .info','left','-6','3','','.account-address-book'),(928469,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','left','1','3','','.account-order-pay'),(928470,'printshop','.account-order-pay .historyInfoColumn h2.title-delivery-address, .account-order-pay .historyInfoColumn h2.title-billing-address','left','10','3','','.account-order-pay'),(928471,'printshop','.account-order-pay .historyInfoColumn h2.title-payment','left','10','3','','.account-order-pay'),(928472,'printshop','.account-order-pay .not_fully_paid_td','left','15','','','.account-order-pay'),(928473,'printshop','.account-samples .not_fully_paid_td','left','15','','','.account-samples'),(928474,'printshop','.account-samples .orders-table .status-name','left','0','5342','','.account-samples'),(928475,'printshop','.account-samples .orders-table .td-alignright','left','0','5342','','.account-samples'),(928476,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','left','1','3','','.account-sample-info'),(928477,'printshop','.account-sample-info .historyInfoColumn h2.title-delivery-address, .account-sample-info .historyInfoColumn h2.title-billing-address','left','10','3','','.account-sample-info'),(928478,'printshop','.account-sample-info .historyInfoColumn h2.title-payment','left','10','3','','.account-sample-info'),(928479,'printshop','.account-sample-info .not_fully_paid_td','left','15','','','.account-sample-info'),(928480,'printshop','.catalog-product-wrap .prev-product','left','0','','','.catalog-product-wrap'),(928481,'printshop','.catalog-product-wrap .prev-product .pn-image','left','20','3','','.catalog-product-wrap'),(928482,'printshop','.catalog-product-wrap button.slick-prev','left','-10','','','.catalog-product-wrap'),(928483,'printshop','.b-form .addresses .address-item input[type=\"radio\"]','left','0','','','.b-form'),(928484,'printshop','.hide-page','left','0','','',''),(928485,'printshop','.success-page .w-cart-listing .qty','left','60','','','.success-page'),(928488,'printshop','.w-bestsellers .heading-3','left','0','3','','.w-bestsellers'),(928489,'printshop','.w-banner .banner img + img','left','0','','','.w-banner'),(928490,'printshop','.w-banner .carousel-text','left','0','','','.w-banner'),(928491,'printshop','.w-banner .image-text-banner.bottom-left .text-banner','left','0','','','.w-banner'),(928492,'printshop','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','left','0','','','.w-banner'),(928493,'printshop','.w-banner .image-text-banner.top-left .text-banner','left','0','','','.w-banner'),(928495,'printshop','.w-sale .badge','left','10','','','.w-sale'),(928496,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left_important','important','','','.b-select-suggest'),(928497,'printshop','.b-form .radio-button input[type=\"radio\"].no','left_measure','vw','','','.b-form'),(928498,'printshop','.b-fancybox #fancybox-loading','left_measure','%','','','.b-fancybox'),(928499,'printshop','.w-checkout-shipping-choice input:checked + span:before','left_measure','%','','','.w-checkout-shipping-choice'),(928500,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left_measure','%','','','.b-switch'),(928501,'printshop','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left_measure','%','','','.b-menu-lev_display-lra'),(928502,'printshop','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left_measure','%','','','.b-menu-lev_display-lra'),(928503,'printshop','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left_measure','%','','','.b-menu-lev_display-lra'),(928504,'printshop','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left_measure','%','','','.b-menu-lev_display-lra'),(928505,'printshop','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left_measure','%','','','.b-menu-lev_display-lra'),(928506,'printshop','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left_measure','%','','','.b-menu-lev_display-right'),(928507,'printshop','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left_measure','%','','','.b-menu-lev_display-right'),(928508,'printshop','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left_measure','%','','','.b-menu-lev_display-right'),(928509,'printshop','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left_measure','%','','','.b-menu-lev_display-right'),(928510,'printshop','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left_measure','%','','','.b-menu-lev_display-right'),(928511,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left_measure','vw','','','.b-menu-lev_display-slide'),(928512,'printshop','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left_measure','vw','','','.b-menu-lev_display-slide'),(928513,'printshop','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left_measure','vw','','','.b-menu-lev_display-slide'),(928514,'printshop','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left_measure','vw','','','.b-menu-lev_display-slide'),(928515,'printshop','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left_measure','vw','','','.b-menu-lev_display-slide'),(928516,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left_measure','vw','','','.b-menu-open_from-left'),(928517,'printshop','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left_measure','%','','','.b-slick'),(928518,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content:before','left_measure','%','','','.w-product-properties-icons'),(928519,'printshop','.topBanner .w-banner .text-middle-left .banner-text','left_measure','%','','','.topBanner'),(928520,'printshop','.topBanner .w-banner .text-middle-left .banner-text','left_measure','%','5342','','.topBanner'),(928522,'printshop','.rating-0, .rating-1, .rating-2, .rating-3, .rating-4, .rating-5','letter-spacing','2px','','',''),(928523,'printshop','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','line-height','1.2','','','.w-communication-new-topic'),(928524,'printshop','.b-info-popup .info-popup div','line-height','30','3','','.b-info-popup'),(928525,'printshop','.b-form .shipping-method .sub-title','line-height','1.3','','','.b-form'),(928526,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','line-height','12','','','.b-switch'),(928527,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line-height','30','','','.b-switch'),(928528,'printshop','.message.success','line-height','1','3','',''),(928529,'printshop','.heading-4 .edit, h4 .edit','line-height','20','','',''),(928530,'printshop','.w-socials .post_item > div','line-height','19','','','.w-socials'),(928531,'printshop','.p-quick-order-index .paginate_button.previous','line-height','26','3','','.p-quick-order-index'),(928532,'printshop','.p-quick-order-index .paginate_button.next','line-height','26','3','','.p-quick-order-index'),(928533,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.p-quick-order-index'),(928534,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.p-quick-order-index'),(928536,'printshop','.w-promotions .prom-multi-discount .promo-range','line-height','23','','','.w-promotions'),(928537,'printshop','.w-quote .cart-box-link','line-height','40','5342,3','','.w-quote'),(928539,'printshop','.testimonials .heading-3','line-height','1','3','',''),(928540,'printshop','.w-promotions .heading-3','line-height','1','','','.w-promotions'),(928541,'printshop','.w-promotions .promo-salemaker .discount','line-height','23','','','.w-promotions'),(928542,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','line-height','23','','','.w-promotions'),(928543,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','line-height','23','','','.w-promotions'),(928544,'printshop','.b-preloader .preloader','line-height','40','3','','.b-preloader'),(928545,'printshop','.w-cart-compare .attributes-cell','line-height','22','','','.w-cart-compare'),(928547,'printshop','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(928548,'printshop','.b-bottom .closeable-heading','line-height','45','3','','.b-bottom'),(928549,'printshop','.b-messages .messBtnMenuDelete','line-height','10','3','','.b-messages'),(928550,'printshop','.b-messages span.starred::before','line-height','10','','','.b-messages'),(928551,'printshop','.b-messages .messBtnMenuStarred','line-height','10','3','','.b-messages'),(928552,'printshop','.b-messages .messBtnMenuUnread','line-height','10','3','','.b-messages'),(928553,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line-height','14','','','.b-messages'),(928554,'printshop','.w-quote .cart-box-link','line-height','48','3','','.w-quote'),(928555,'printshop','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(928556,'printshop','.w-socials .post_item > div','line-height','19','','','.w-socials'),(928557,'printshop','.p-payer-order-confirmation .discount-ico','line-height','20','3','','.p-payer-order-confirmation'),(928558,'printshop','.p-payer-order-pay .discount-ico','line-height','20','3','','.p-payer-order-pay'),(928559,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','line-height','15','','','.b-switch'),(928560,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','line-height','15','','','.b-switch'),(928561,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','line-height','15','','','.b-switch'),(928562,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','line-height','56','4','','.b-switch'),(928563,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','line-height','16','','','.b-switch'),(928564,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','line-height','10','','','.b-switch'),(928565,'printshop','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','line-height','1.2','','','.p-quick-order-index'),(928566,'printshop','.b-info .info','line-height','1','3','','.b-info'),(928567,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','line-height','15','','','.b-switch'),(928568,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','line-height','10','','','.b-switch'),(928569,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','line-height','10','','','.b-switch'),(928570,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','line-height','12','','','.b-switch'),(928571,'printshop','.bell-ico .heading-2','line-height','10','3','','.bell-ico'),(928572,'printshop','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(928574,'printshop','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(928575,'printshop','.w-cart-compare .compare-table','line-height','1.3','','','.w-cart-compare'),(928576,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line-height','18','','','.b-form'),(928577,'printshop','.w-checkout-shipping-choice span','line-height','19','','','.w-checkout-shipping-choice'),(928578,'printshop','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(928579,'printshop','.w-socials .post_item > div','line-height','19','','','.w-socials'),(928580,'printshop','.b-info-popup .info-popup div','line-height','1.7','','','.b-info-popup'),(928581,'printshop','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(928582,'printshop','.w-checkout-shipping-address .addresses .address-item label','line-height','1.3','','','.w-checkout-shipping-address'),(928584,'printshop','.w-socials .post_item > div','line-height','19','','','.w-socials'),(928585,'printshop','.b-info .info','line-height','1','3','','.b-info'),(928586,'printshop','.b-info-popup .info-popup','line-height','2','','','.b-info-popup'),(928588,'printshop','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(928589,'printshop','.btn-2','line-height','20','','',''),(928590,'printshop','.w-cart-compare .delete-cart','line-height','1','','','.w-cart-compare'),(928592,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span','line-height','22','','','.b-form'),(928593,'printshop','.w-filters .input-checkbox:checked + .checkbox-span:before','line-height','22','','','.w-filters'),(928594,'printshop','.heading-3 .right-text, h3 .right-text','line-height','20','','',''),(928595,'printshop','.heading-3 .edit, h3 .edit','line-height','20','','',''),(928596,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','line-height','56','4','','.b-switch'),(928597,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','line-height','56','4','','.b-switch'),(928599,'printshop','.savings-ico .heading-2','line-height','10','3','','.savings-ico'),(928600,'printshop','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(928601,'printshop','.b-fancybox .fancybox-title-float-wrap .child','line-height','24','','','.b-fancybox'),(928602,'printshop','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(928603,'printshop','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(928604,'printshop','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(928605,'printshop','.w-socials .post_item > div','line-height','19','','','.w-socials'),(928606,'printshop','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(928607,'printshop','.btn','line-height','20','','',''),(928608,'printshop','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(928610,'printshop','.b-info .info','line-height','1','3','','.b-info'),(928611,'printshop','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(928612,'printshop','.w-reviews .heading-3','line-height','1','3','','.w-reviews'),(928613,'printshop','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(928614,'printshop','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(928615,'printshop','.p-quick-order-index .stock','line-height','1.2','','','.p-quick-order-index'),(928616,'printshop','.b-info .info','line-height','1','3','','.b-info'),(928617,'printshop','.b-form .checkbox-style:checked + .checkbox-span:before','line-height','18','','','.b-form'),(928618,'printshop','.w-cart-listing .links','line-height','35','','','.w-cart-listing'),(928619,'printshop','.price .old','line-height','0.6','','',''),(928620,'printshop','.w-cart-compare .price-cell','line-height','22','','','.w-cart-compare'),(928621,'printshop','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(928622,'printshop','.b-info .info','line-height','1','3','','.b-info'),(928623,'printshop','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(928624,'printshop','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(928625,'printshop','.w-multi-cart-cart-switcher .cart-label','line-height','20','','','.w-multi-cart-cart-switcher'),(928626,'printshop','.b-bottom .pop-up-close','line-height','25','','','.b-bottom'),(928627,'printshop','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(928628,'printshop','.b-fancybox .fancybox-close','line-height','40','','','.b-fancybox'),(928629,'printshop','.b-form .form-inputs div.required-message','line-height','1.3','','','.b-form'),(928630,'printshop','.b-info .info','line-height','1','3','','.b-info'),(928631,'printshop','.w-product-customers-activity .close','line-height','32','','','.w-product-customers-activity'),(928632,'printshop','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(928633,'printshop','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(928634,'printshop','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(928635,'printshop','.w-checkout-billing-address .addresses .address-item label','line-height','1.3','','','.w-checkout-billing-address'),(928637,'printshop','.w-cart-compare .cart-name a','line-height','1.2','','','.w-cart-compare'),(928638,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line-height','13','','','.b-select-suggest'),(928639,'printshop','.b-switch .bootstrap-switch','line-height','28','','','.b-switch'),(928640,'printshop','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(928641,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.b-data-table'),(928642,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.b-data-table'),(928643,'printshop','.b-products-listing .products-listing .name a','line-height','1.5','','','.b-products-listing'),(928644,'printshop','.b-products-listing .btn-preloader','line-height','24','3','','.b-products-listing'),(928645,'printshop','.b-products-listing .loader','line-height','30','4','','.b-products-listing'),(928646,'printshop','.checkbox input:not(checked) + span:before','line-height','24','','',''),(928649,'printshop','.b-select-suggest .select2-container .select2-choice','line-height','26','','','.b-select-suggest'),(928650,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','line-height','10','','','.b-switch'),(928651,'printshop','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(928652,'printshop','.w-socials .post_item > div','line-height','19','','','.w-socials'),(928653,'printshop','.order-summary .price-row.ot_coupon .title','line-height','22','3','','.order-summary'),(928654,'printshop','.heading-4 .right-text, h4 .right-text','line-height','20','','',''),(928655,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','40','','','.w-communication-new-topic'),(928656,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','35','3','','.w-communication-new-topic'),(928657,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line-height','36','','','.w-communication-new-topic'),(928658,'printshop','.btn-3','line-height','20','','',''),(928659,'printshop','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(928660,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','line-height','30','3','','.b-form'),(928661,'printshop','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(928662,'printshop','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(928663,'printshop','.w-menu-horizontal .menu-ico','line-height','54','','','.w-menu-horizontal'),(928664,'printshop','.w-catalog-listing-look .grid','line-height','35','','','.w-catalog-listing-look'),(928665,'printshop','.w-catalog-listing-look .b2b','line-height','35','','','.w-catalog-listing-look'),(928666,'printshop','.w-catalog-listing-look .list','line-height','35','','','.w-catalog-listing-look'),(928667,'printshop','.w-cart-listing .item .attributes','line-height','1.7','','','.w-cart-listing'),(928668,'printshop','.w-cart-listing .points-earn','line-height','1','','','.w-cart-listing'),(928669,'printshop','.w-cart-listing .points-redeem','line-height','1','','','.w-cart-listing'),(928670,'printshop','.w-cart-listing .remove-btn','line-height','30','','','.w-cart-listing'),(928671,'printshop','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(928672,'printshop','.b-fancybox .fancybox-nav span','line-height','40','','','.b-fancybox'),(928673,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','line-height','30','','','.b-switch'),(928674,'printshop','.w-checkout-create-account .account-benefits strong','line-height','16','3','','.w-checkout-create-account'),(928675,'printshop','.w-cart-compare .js-cart_totals_container','line-height','1.2','','','.w-cart-compare'),(928676,'printshop','.btn-1','line-height','20','','',''),(928677,'printshop','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(928678,'printshop','.b-products-listing .products-listing .btn-preloader','line-height','8','','','.b-products-listing'),(928679,'printshop','.price .special','line-height','0.8','','',''),(928680,'printshop','.b-data-table table.dataTable thead td','line-height','1.5','','','.b-data-table'),(928681,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','line-height','30','','','.b-switch'),(928682,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','line-height','30','','','.b-switch'),(928683,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','line-height','30','','','.b-switch'),(928684,'printshop','.w-filters .input-checkbox:not(checked) + .checkbox-span','line-height','22','','','.w-filters'),(928685,'printshop','.b-upload-file .snapshot','line-height','38','','','.b-upload-file'),(928686,'printshop','.b-product-images .media-popup .mp-close','line-height','100','','','.b-product-images'),(928687,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','line-height','100','','','.b-product-images'),(928688,'printshop','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line-height','30','','','.b-menu-burger_icon'),(928689,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(928690,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(928691,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(928692,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(928693,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(928694,'printshop','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','line-height','1.3','','','.b-trade-approval'),(928695,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line-height','24','3','','.w-catalog-compare'),(928696,'printshop','.w-catalog-compare td','line-height','1.5','','','.w-catalog-compare'),(928697,'printshop','.w-catalog-compare span.btn-preloader','line-height','24','3','','.w-catalog-compare'),(928698,'printshop','.w-delivery-day .ends','line-height','1','','','.w-delivery-day'),(928700,'printshop','.tripleBanner .w-html_box','line-height','1.25','','','.tripleBanner'),(928701,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','40','','','.b-slick'),(928702,'printshop','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line-height','36','','','.b-slick'),(928703,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','48','5342','','.b-slick'),(928706,'printshop','.menu-header .burger-icon','line-height','40','5342','','.menu-header'),(928707,'printshop','.menu-header .burger-icon','line-height','40','5342,3','','.menu-header'),(928708,'printshop','.w-subscribers .btn-submit','line-height','24','','','.w-subscribers'),(928709,'printshop','.b-quantity .qty-box .bigger','line-height','32','','','.b-quantity'),(928710,'printshop','.b-quantity .qty-box .smaller','line-height','32','','','.b-quantity'),(928711,'printshop','.w-product-sale-ends .ends','line-height','1','','','.w-product-sale-ends'),(928712,'printshop','.warrantyProduct .title','line-height','1.2','','','.warrantyProduct'),(928713,'printshop','.warrantyProduct .seeDetails','line-height','1.2','','','.warrantyProduct'),(928714,'printshop','.w-sample .cart-box-link','line-height','48','3','','.w-sample'),(928715,'printshop','.w-sample .cart-box-link','line-height','40','5342,3','','.w-sample'),(928716,'printshop','.w-cart-bonus-points .title','line-height','1','','','.w-cart-bonus-points'),(928717,'printshop','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(928719,'printshop','.b-pagination .pagination .next-pages','line-height','30','','','.b-pagination'),(928720,'printshop','.b-pagination .pagination .page-number','line-height','30','','','.b-pagination'),(928721,'printshop','.b-pagination .pagination .prev-pages','line-height','30','','','.b-pagination'),(928722,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','line-height','30','','','.b-pagination'),(928723,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','line-height','26','3','','.b-pagination'),(928724,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','line-height','30','','','.b-pagination'),(928725,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','line-height','26','3','','.b-pagination'),(928726,'printshop','.b-pagination .pagination span','line-height','30','2','','.b-pagination'),(928727,'printshop','.w-product-properties-filters-widgets-chosen-filters .remove','line-height','10','3','','.w-product-properties-filters-widgets-chosen-filters'),(928728,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','line-height','36','','','.w-questionnaire-widgets-questionnaire'),(928729,'printshop','.w-product-custom-bundle .right-area .price','line-height','1.2','','','.w-product-custom-bundle'),(928730,'printshop','.b-products-listing .products-listing.list-productlisting .attribute-qty-block > span','line-height','1.15','','','.b-products-listing'),(928731,'printshop','.w-delivery-location-location-list .deliveryListParrent a','line-height','1.5','','','.w-delivery-location-location-list'),(928732,'printshop','.w-sale-category .badge','line-height','27','','','.w-sale-category'),(928733,'printshop','.w-sale-category .ends','line-height','1','','','.w-sale-category'),(928734,'printshop','.w-sale-category .name','line-height','1.2','','','.w-sale-category'),(928735,'printshop','.w-sale-category .old','line-height','0.8','','','.w-sale-category'),(928736,'printshop','.w-sale-category .special-price','line-height','0.8','','','.w-sale-category'),(928737,'printshop','.w-product-bonus-points .bonus-points-cost','line-height','1.2','','','.w-product-bonus-points'),(928738,'printshop','.b-products-listing .productGroup label a','line-height','1','','','.b-products-listing'),(928739,'printshop','.w-rma-returns-history .column .title','line-height','16','','','.w-rma-returns-history'),(928740,'printshop','.w-rma-returns-history tbody tr td','line-height','1.3','','','.w-rma-returns-history'),(928741,'printshop','.w-rma-returns-history thead tr td','line-height','1.3','','','.w-rma-returns-history'),(928742,'printshop','.b-products-listing .products-listing .bonus-points-cost','line-height','1.2','','','.b-products-listing'),(928743,'printshop','.w-predefined-promotion .heading-3','line-height','1','','','.w-predefined-promotion'),(928744,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','line-height','23','','','.w-predefined-promotion'),(928745,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','line-height','23','','','.w-predefined-promotion'),(928746,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','line-height','23','','','.w-predefined-promotion'),(928747,'printshop','.w-predefined-promotion .promo-salemaker .discount','line-height','23','','','.w-predefined-promotion'),(928748,'printshop','.w-supplier-purchase-supplier-products .active .select_item > div','line-height','28','','','.w-supplier-purchase-supplier-products'),(928751,'printshop','.w-product-model ','line-height','1','','','.w-product-model'),(928752,'printshop','.w-cart-listing .name a','line-height','1.5','','','.w-cart-listing'),(928753,'printshop','.tripleLine .text-banner-2 > div','line-height','1.3','','','.tripleLine'),(928754,'printshop','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(928755,'printshop','.lowestPricedBox .btn-2','line-height','24','','','.lowestPricedBox'),(928756,'printshop','.doubleBanner .btn-2','line-height','24','','','.doubleBanner'),(928757,'printshop','.doubleBanner .btn-2','line-height','20','5347','','.doubleBanner'),(928758,'printshop','.doubleBanner .title','line-height','1.2','','','.doubleBanner'),(928759,'printshop','.middleBanner .title','line-height','1.2','','','.middleBanner'),(928760,'printshop','.middleBanner .descr','line-height','1.2','','','.middleBanner'),(928761,'printshop','.bottomDoubleBanner .btn-2','line-height','24','','','.bottomDoubleBanner'),(928762,'printshop','.bottomDoubleBanner .title','line-height','1.2','','','.bottomDoubleBanner'),(928763,'printshop','.bottomDoubleBanner .btn-2','line-height','20','5347','','.bottomDoubleBanner'),(928764,'printshop','.bottomBanner .title','line-height','1.2','','','.bottomBanner'),(928768,'printshop','.b-bottom .closeable-heading','line-height','40','5333,3','','.b-bottom'),(928769,'printshop','.topBanner .descr','line-height','1.3','','','.topBanner'),(928770,'printshop','.topBanner .ourPick .bottom','line-height','1.47','','','.topBanner'),(928771,'printshop','.topBanner .ourPick .top','line-height','1.33','','','.topBanner'),(928772,'printshop','.tripleLine .banner-text-holder > div','line-height','1.3','','','.tripleLine'),(928773,'printshop','.order-summary .icon','line-height','30','','','.order-summary'),(928774,'printshop','.w-cart-listing .item div.price small','line-height','1','','','.w-cart-listing'),(928775,'printshop','.w-cart-discount-coupon .title','line-height','0.75','4','','.w-cart-discount-coupon'),(928776,'printshop','.p-quote-checkout-index .closeable-heading','line-height','55','3','','.p-quote-checkout-index'),(928777,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','line-height','20','','','.p-quote-checkout-index'),(928778,'printshop','.p-quote-checkout-index .closeable-heading','line-height','40','5333,3','','.p-quote-checkout-index'),(928790,'printshop','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','line-height','20','','','.account-samples'),(928791,'printshop','.account-samples .order_history_table th','line-height','16','','','.account-samples'),(928792,'printshop','.account-samples .view_link','line-height','17','4','','.account-samples'),(928793,'printshop','.account-samples .orders-table .td-alignright','line-height','35','5342','','.account-samples'),(928794,'printshop','.catalog-product-wrap .pn-direction','line-height','1.2','','','.catalog-product-wrap'),(928795,'printshop','.catalog-product-wrap .pn-image','line-height','24','3','','.catalog-product-wrap'),(928796,'printshop','.checkout-index-wrap .closeable-heading','line-height','55','3','','.checkout-index-wrap'),(928797,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','line-height','20','','','.checkout-index-wrap'),(928798,'printshop','.checkout-index-wrap .closeable-heading','line-height','40','5333,3','','.checkout-index-wrap'),(928799,'printshop','.checkout-order-confirmation .discount-ico','line-height','20','3','','.checkout-order-confirmation'),(928800,'printshop','.success-page .comment-ico','line-height','20','3','','.success-page'),(928801,'printshop','.success-page .discount-ico','line-height','20','3','','.success-page'),(928802,'printshop','.success-page .order-ico','line-height','20','3','','.success-page'),(928803,'printshop','.success-page .page-success .text-1','line-height','20','3','','.success-page'),(928804,'printshop','.success-page .pay-ico','line-height','20','3','','.success-page'),(928805,'printshop','.success-page .prod-ico','line-height','20','3','','.success-page'),(928806,'printshop','.success-page .ship-ico','line-height','20','3','','.success-page'),(928807,'printshop','.success-page .w-cart-listing .qty','line-height','26','','','.success-page'),(928808,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line-height','31','','','.b-multi-page-checkout'),(928809,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line-height','35','3','','.b-multi-page-checkout'),(928811,'printshop','.footer-menu .level-1 > li','line-height','14','5342,3','','.footer-menu'),(928812,'printshop','.w-bestsellers .counter','line-height','34','','','.w-bestsellers'),(928813,'printshop','.w-bestsellers .heading-3','line-height','1','3','','.w-bestsellers'),(928814,'printshop','.w-bestsellers .item','line-height','33','3','','.w-bestsellers'),(928815,'printshop','.w-catalog-paging ','line-height','30','2','','.w-catalog-paging'),(928816,'printshop','.w-catalog-paging .next','line-height','30','','','.w-catalog-paging'),(928817,'printshop','.w-catalog-paging .next','line-height','26','3','','.w-catalog-paging'),(928818,'printshop','.w-catalog-paging .next-pages','line-height','30','','','.w-catalog-paging'),(928819,'printshop','.w-catalog-paging .page-number','line-height','30','','','.w-catalog-paging'),(928820,'printshop','.w-catalog-paging .prev','line-height','30','','','.w-catalog-paging'),(928821,'printshop','.w-catalog-paging .prev','line-height','26','3','','.w-catalog-paging'),(928822,'printshop','.w-catalog-paging .prev-pages','line-height','30','','','.w-catalog-paging'),(928823,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line-height','30','','','.w-catalog-paging'),(928827,'printshop','.w-sale .badge','line-height','27','','','.w-sale'),(928828,'printshop','.w-sale .ends','line-height','1','','','.w-sale'),(928829,'printshop','.w-sale .name','line-height','1.2','','','.w-sale'),(928830,'printshop','.w-sale .old','line-height','0.8','','','.w-sale'),(928831,'printshop','.w-sale .special-price','line-height','0.8','','','.w-sale'),(928832,'printshop','.w-social-links a','line-height','1','','','.w-social-links'),(928833,'printshop','.b-info-popup .info-popup div','line_height_measure','px','3','','.b-info-popup'),(928834,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(928835,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line_height_measure','px','','','.b-switch'),(928836,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','line_height_measure','px','3','','.b-form'),(928837,'printshop','.heading-4 .edit, h4 .edit','line_height_measure','px','','',''),(928838,'printshop','.p-quick-order-index .paginate_button.next','line_height_measure','px','3','','.p-quick-order-index'),(928839,'printshop','.p-quick-order-index .paginate_button.previous','line_height_measure','px','3','','.p-quick-order-index'),(928840,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.p-quick-order-index'),(928841,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.p-quick-order-index'),(928842,'printshop','.w-promotions .prom-multi-discount .promo-range','line_height_measure','px','','','.w-promotions'),(928843,'printshop','.w-promotions .promo-salemaker .discount','line_height_measure','px','','','.w-promotions'),(928844,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','line_height_measure','px','','','.w-promotions'),(928845,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','line_height_measure','px','','','.w-promotions'),(928846,'printshop','.b-preloader .preloader','line_height_measure','px','3','','.b-preloader'),(928847,'printshop','.w-cart-compare .attributes-cell','line_height_measure','px','','','.w-cart-compare'),(928848,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-messages'),(928849,'printshop','.b-bottom .closeable-heading','line_height_measure','px','3','','.b-bottom'),(928850,'printshop','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(928851,'printshop','.b-messages .messBtnMenuDelete','line_height_measure','px','3','','.b-messages'),(928852,'printshop','.b-messages .messBtnMenuStarred','line_height_measure','px','3','','.b-messages'),(928853,'printshop','.b-messages span.starred::before','line_height_measure','px','','','.b-messages'),(928854,'printshop','.b-messages .messBtnMenuUnread','line_height_measure','px','3','','.b-messages'),(928855,'printshop','.p-payer-order-confirmation .discount-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(928856,'printshop','.p-payer-order-pay .discount-ico','line_height_measure','px','3','','.p-payer-order-pay'),(928857,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(928858,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(928859,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(928860,'printshop','.b-fancybox .fancybox-close','line_height_measure','px','','','.b-fancybox'),(928861,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','line_height_measure','px','4','','.b-switch'),(928862,'printshop','.b-info-popup .info-popup','line_height_measure','px','','','.b-info-popup'),(928863,'printshop','.bell-ico .heading-2','line_height_measure','px','3','','.bell-ico'),(928864,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(928865,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(928866,'printshop','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(928867,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(928868,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(928869,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(928870,'printshop','.b-switch .bootstrap-switch','line_height_measure','px','','','.b-switch'),(928871,'printshop','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(928872,'printshop','.w-checkout-shipping-choice span','line_height_measure','px','','','.w-checkout-shipping-choice'),(928873,'printshop','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(928874,'printshop','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(928875,'printshop','.b-form .checkbox-style:checked + .checkbox-span:before','line_height_measure','px','','','.b-form'),(928877,'printshop','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(928878,'printshop','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(928879,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span','line_height_measure','px','','','.b-form'),(928880,'printshop','.btn-2','line_height_measure','px','','',''),(928881,'printshop','.w-filters .input-checkbox:checked + .checkbox-span:before','line_height_measure','px','','','.w-filters'),(928882,'printshop','.heading-3 .right-text, h3 .right-text','line_height_measure','px','','',''),(928883,'printshop','.heading-3 .edit, h3 .edit','line_height_measure','px','','',''),(928884,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','line_height_measure','px','4','','.b-switch'),(928885,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','line_height_measure','px','4','','.b-switch'),(928887,'printshop','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(928888,'printshop','.savings-ico .heading-2','line_height_measure','px','3','','.savings-ico'),(928889,'printshop','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(928890,'printshop','.b-fancybox .fancybox-title-float-wrap .child','line_height_measure','px','','','.b-fancybox'),(928891,'printshop','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(928892,'printshop','.btn','line_height_measure','px','','',''),(928893,'printshop','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(928894,'printshop','.b-select-suggest .select2-container .select2-choice','line_height_measure','px','','','.b-select-suggest'),(928895,'printshop','.w-cart-listing .links','line_height_measure','px','','','.w-cart-listing'),(928896,'printshop','.b-bottom .pop-up-close','line_height_measure','px','','','.b-bottom'),(928897,'printshop','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(928898,'printshop','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(928899,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line_height_measure','px','','','.b-form'),(928900,'printshop','.w-product-customers-activity .close','line_height_measure','px','','','.w-product-customers-activity'),(928903,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(928904,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-select-suggest'),(928905,'printshop','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(928907,'printshop','.w-cart-compare .price-cell','line_height_measure','px','','','.w-cart-compare'),(928908,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.b-data-table'),(928909,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.b-data-table'),(928910,'printshop','.b-products-listing .btn-preloader','line_height_measure','px','3','','.b-products-listing'),(928911,'printshop','.b-products-listing .loader','line_height_measure','px','4','','.b-products-listing'),(928912,'printshop','.checkbox input:not(checked) + span:before','line_height_measure','px','','',''),(928914,'printshop','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(928915,'printshop','.w-quote .cart-box-link','line_height_measure','px','5342,3','','.w-quote'),(928916,'printshop','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(928917,'printshop','.order-summary .price-row.ot_coupon .title','line_height_measure','px','3','','.order-summary'),(928918,'printshop','.w-checkout-create-account .account-benefits strong','line_height_measure','px','3','','.w-checkout-create-account'),(928919,'printshop','.heading-4 .right-text, h4 .right-text','line_height_measure','px','','',''),(928920,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','','','.w-communication-new-topic'),(928921,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','3','','.w-communication-new-topic'),(928922,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line_height_measure','px','','','.w-communication-new-topic'),(928924,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(928925,'printshop','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(928926,'printshop','.w-menu-horizontal .menu-ico','line_height_measure','px','','','.w-menu-horizontal'),(928927,'printshop','.w-catalog-listing-look .grid','line_height_measure','px','','','.w-catalog-listing-look'),(928928,'printshop','.w-catalog-listing-look .b2b','line_height_measure','px','','','.w-catalog-listing-look'),(928929,'printshop','.w-catalog-listing-look .list','line_height_measure','px','','','.w-catalog-listing-look'),(928930,'printshop','.w-cart-listing .remove-btn','line_height_measure','px','','','.w-cart-listing'),(928931,'printshop','.b-fancybox .fancybox-nav span','line_height_measure','px','','','.b-fancybox'),(928932,'printshop','.w-multi-cart-cart-switcher .cart-label','line_height_measure','px','','','.w-multi-cart-cart-switcher'),(928933,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(928934,'printshop','.btn-1','line_height_measure','px','','',''),(928935,'printshop','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(928936,'printshop','.b-products-listing .products-listing .btn-preloader','line_height_measure','px','','','.b-products-listing'),(928937,'printshop','.btn-3','line_height_measure','px','','',''),(928938,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(928939,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(928940,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(928941,'printshop','.w-filters .input-checkbox:not(checked) + .checkbox-span','line_height_measure','px','','','.w-filters'),(928942,'printshop','.b-upload-file .snapshot','line_height_measure','px','','','.b-upload-file'),(928943,'printshop','.b-product-images .media-popup .mp-close','line_height_measure','px','','','.b-product-images'),(928944,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','line_height_measure','px','','','.b-product-images'),(928945,'printshop','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line_height_measure','px','','','.b-menu-burger_icon'),(928946,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(928947,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(928948,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(928949,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(928950,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(928951,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line_height_measure','px','3','','.w-catalog-compare'),(928952,'printshop','.w-catalog-compare span.btn-preloader','line_height_measure','px','3','','.w-catalog-compare'),(928956,'printshop','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line_height_measure','px','','','.b-slick'),(928957,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','','','.b-slick'),(928958,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','5342','','.b-slick'),(928961,'printshop','.menu-header .burger-icon','line_height_measure','px','5342','','.menu-header'),(928962,'printshop','.menu-header .burger-icon','line_height_measure','px','5342,3','','.menu-header'),(928963,'printshop','.w-subscribers .btn-submit','line_height_measure','px','','','.w-subscribers'),(928964,'printshop','.w-quote .cart-box-link','line_height_measure','px','3','','.w-quote'),(928965,'printshop','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(928966,'printshop','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(928967,'printshop','.w-sample .cart-box-link','line_height_measure','px','3','','.w-sample'),(928968,'printshop','.w-sample .cart-box-link','line_height_measure','px','5342,3','','.w-sample'),(928969,'printshop','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(928971,'printshop','.b-pagination .pagination .next-pages','line_height_measure','px','','','.b-pagination'),(928972,'printshop','.b-pagination .pagination .page-number','line_height_measure','px','','','.b-pagination'),(928973,'printshop','.b-pagination .pagination .prev-pages','line_height_measure','px','','','.b-pagination'),(928974,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','line_height_measure','px','','','.b-pagination'),(928975,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','line_height_measure','px','3','','.b-pagination'),(928976,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','line_height_measure','px','','','.b-pagination'),(928977,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','line_height_measure','px','3','','.b-pagination'),(928978,'printshop','.b-pagination .pagination span','line_height_measure','px','2','','.b-pagination'),(928979,'printshop','.w-product-properties-filters-widgets-chosen-filters .remove','line_height_measure','px','3','','.w-product-properties-filters-widgets-chosen-filters'),(928980,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','line_height_measure','px','','','.w-questionnaire-widgets-questionnaire'),(928981,'printshop','.w-sale-category .badge','line_height_measure','px','','','.w-sale-category'),(928982,'printshop','.w-rma-returns-history .column .title','line_height_measure','px','','','.w-rma-returns-history'),(928983,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','line_height_measure','px','','','.w-predefined-promotion'),(928984,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','line_height_measure','px','','','.w-predefined-promotion'),(928985,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','line_height_measure','px','','','.w-predefined-promotion'),(928986,'printshop','.w-predefined-promotion .promo-salemaker .discount','line_height_measure','px','','','.w-predefined-promotion'),(928987,'printshop','.w-supplier-purchase-supplier-products .active .select_item > div','line_height_measure','px','','','.w-supplier-purchase-supplier-products'),(928989,'printshop','.lowestPricedBox .btn-2','line_height_measure','px','','','.lowestPricedBox'),(928990,'printshop','.doubleBanner .btn-2','line_height_measure','px','','','.doubleBanner'),(928991,'printshop','.doubleBanner .btn-2','line_height_measure','px','5347','','.doubleBanner'),(928992,'printshop','.bottomDoubleBanner .btn-2','line_height_measure','px','','','.bottomDoubleBanner'),(928993,'printshop','.bottomDoubleBanner .btn-2','line_height_measure','px','5347','','.bottomDoubleBanner'),(928995,'printshop','.b-bottom .closeable-heading','line_height_measure','px','5333,3','','.b-bottom'),(928996,'printshop','.order-summary .icon','line_height_measure','px','','','.order-summary'),(928997,'printshop','.p-quote-checkout-index .closeable-heading','line_height_measure','px','3','','.p-quote-checkout-index'),(928998,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','line_height_measure','px','','','.p-quote-checkout-index'),(928999,'printshop','.p-quote-checkout-index .closeable-heading','line_height_measure','px','5333,3','','.p-quote-checkout-index'),(929011,'printshop','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','line_height_measure','px','','','.account-samples'),(929012,'printshop','.account-samples .order_history_table th','line_height_measure','px','','','.account-samples'),(929013,'printshop','.account-samples .view_link','line_height_measure','px','4','','.account-samples'),(929014,'printshop','.account-samples .orders-table .td-alignright','line_height_measure','px','5342','','.account-samples'),(929015,'printshop','.catalog-product-wrap .pn-image','line_height_measure','px','3','','.catalog-product-wrap'),(929016,'printshop','.checkout-index-wrap .closeable-heading','line_height_measure','px','3','','.checkout-index-wrap'),(929017,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','line_height_measure','px','','','.checkout-index-wrap'),(929018,'printshop','.checkout-index-wrap .closeable-heading','line_height_measure','px','5333,3','','.checkout-index-wrap'),(929019,'printshop','.checkout-order-confirmation .discount-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(929020,'printshop','.success-page .comment-ico','line_height_measure','px','3','','.success-page'),(929021,'printshop','.success-page .discount-ico','line_height_measure','px','3','','.success-page'),(929022,'printshop','.success-page .order-ico','line_height_measure','px','3','','.success-page'),(929023,'printshop','.success-page .page-success .text-1','line_height_measure','px','3','','.success-page'),(929024,'printshop','.success-page .pay-ico','line_height_measure','px','3','','.success-page'),(929025,'printshop','.success-page .prod-ico','line_height_measure','px','3','','.success-page'),(929026,'printshop','.success-page .ship-ico','line_height_measure','px','3','','.success-page'),(929027,'printshop','.success-page .w-cart-listing .qty','line_height_measure','px','','','.success-page'),(929028,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line_height_measure','px','','','.b-multi-page-checkout'),(929029,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line_height_measure','px','3','','.b-multi-page-checkout'),(929030,'printshop','.footer-menu .level-1 > li','line_height_measure','px','5342,3','','.footer-menu'),(929031,'printshop','.w-bestsellers .counter','line_height_measure','px','','','.w-bestsellers'),(929032,'printshop','.w-bestsellers .item','line_height_measure','px','3','','.w-bestsellers'),(929033,'printshop','.w-catalog-paging ','line_height_measure','px','2','','.w-catalog-paging'),(929034,'printshop','.w-catalog-paging .next','line_height_measure','px','','','.w-catalog-paging'),(929035,'printshop','.w-catalog-paging .next','line_height_measure','px','3','','.w-catalog-paging'),(929036,'printshop','.w-catalog-paging .next-pages','line_height_measure','px','','','.w-catalog-paging'),(929037,'printshop','.w-catalog-paging .page-number','line_height_measure','px','','','.w-catalog-paging'),(929038,'printshop','.w-catalog-paging .prev','line_height_measure','px','','','.w-catalog-paging'),(929039,'printshop','.w-catalog-paging .prev','line_height_measure','px','3','','.w-catalog-paging'),(929040,'printshop','.w-catalog-paging .prev-pages','line_height_measure','px','','','.w-catalog-paging'),(929041,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line_height_measure','px','','','.w-catalog-paging'),(929045,'printshop','.w-sale .badge','line_height_measure','px','','','.w-sale'),(929046,'printshop','.p-quick-order-index ul.token-input-list','list-style','none','','','.p-quick-order-index'),(929050,'printshop','.b-messages .messages-menu ul','list-style','none','','','.b-messages'),(929051,'printshop','.w-sitemap-delivery-location > ul > li > ul','list-style','none','','','.w-sitemap-delivery-location'),(929052,'printshop','.b-info .info ul','list-style','disc inside','','','.b-info'),(929053,'printshop','.w-sitemap-delivery-location > ul','list-style','none','','','.w-sitemap-delivery-location'),(929054,'printshop','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(929055,'printshop','.b-info .info ul','list-style','disc inside','','','.b-info'),(929056,'printshop','.w-filters .filter-ul-content','list-style','none','','','.w-filters'),(929057,'printshop','.w-menu-horizontal ul','list-style','none','','','.w-menu-horizontal'),(929058,'printshop','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(929059,'printshop','.b-info .info ul','list-style','disc inside','','','.b-info'),(929060,'printshop','.b-info .info ul','list-style','disc inside','','','.b-info'),(929061,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(929062,'printshop','.products-quick-index ul','list-style','none','','',''),(929063,'printshop','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(929064,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(929065,'printshop','.w-tabs .tab-navigation','list-style','none','','','.w-tabs'),(929066,'printshop','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(929067,'printshop','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(929068,'printshop','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(929069,'printshop','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(929070,'printshop','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(929071,'printshop','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(929072,'printshop','.b-info .info ul','list-style','disc inside','','','.b-info'),(929073,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(929074,'printshop','.b-autocomplete .ui-autocomplete','list-style','none','','','.b-autocomplete'),(929076,'printshop','.b-select-suggest .select2-container-multi .select2-choices li','list-style','none','','','.b-select-suggest'),(929077,'printshop','.b-select-suggest .select2-results li','list-style','none','','','.b-select-suggest'),(929078,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(929079,'printshop','.w-menu-big ul','list-style','none','','','.w-menu-big'),(929081,'printshop','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(929082,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(929083,'printshop','.products-quick-index .token-input-list','list-style','none','','',''),(929084,'printshop','.b-info .info ul','list-style','disc inside','','','.b-info'),(929085,'printshop','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(929086,'printshop','.products-quick-index ul.token-input-list','list-style','none','','',''),(929087,'printshop','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(929088,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(929089,'printshop','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','list-style','none','','','.b-menu-style'),(929090,'printshop','.w-catalog-additional-images ul, .w-catalog-additional-images li','list-style','none','','','.w-catalog-additional-images'),(929091,'printshop','.LeftCategories .w-menu-simple ul','list-style','none','','','.LeftCategories'),(929092,'printshop','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(929093,'printshop','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(929094,'printshop','.b-pagination ul.pagination','list-style','none','','','.b-pagination'),(929095,'printshop','.w-account-personal-catalog .list-row-action ul','list-style','none','','','.w-account-personal-catalog'),(929096,'printshop','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(929097,'printshop','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(929098,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list'),(929099,'printshop','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(929100,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list-block'),(929101,'printshop','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(929102,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li','list-style','none','','','.w-delivery-location-featured-list'),(929103,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(929104,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(929105,'printshop','.w-delivery-location-list-by-page .description ul','list-style','circle','','','.w-delivery-location-list-by-page'),(929106,'printshop','.w-delivery-location-cross-pages .description ul','list-style','circle','','','.w-delivery-location-cross-pages'),(929107,'printshop','.w-catalog-delivery-locations .description ul','list-style','circle','','','.w-catalog-delivery-locations'),(929108,'printshop','.w-support-system-filter .filter_cats','list-style','none','','','.w-support-system-filter'),(929109,'printshop','.w-product-configurator .pc-item','list-style','none','','','.w-product-configurator'),(929110,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-list'),(929111,'printshop','.account-address-book .leftMes ul','list-style','disc inside','','','.account-address-book'),(929112,'printshop','.account-address-book .rightMes ul','list-style','disc inside','','','.account-address-book'),(929117,'printshop','.b-slick .slick-dots','list-style','none','','','.b-slick'),(929118,'printshop','.w-delivery-location-featured-list .deliveryList ul','list-style-type','circle','','','.w-delivery-location-featured-list'),(929119,'printshop','.b-form .middle-form','margin','0 auto','','','.b-form'),(929120,'printshop','.b-messages .msv_btn .btn','margin','0px auto 0px','','','.b-messages'),(929121,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','margin','3px auto 3px','','','.b-select-suggest'),(929122,'printshop','.b-select-suggest .select2-results','margin','4px auto 4px','','','.b-select-suggest'),(929123,'printshop','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(929124,'printshop','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(929125,'printshop','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(929126,'printshop','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin','0px auto 10px','','','.b-form'),(929127,'printshop','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(929128,'printshop','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(929129,'printshop','.w-catalog-b2b-add-button .b2b-add-box-wrap','margin','0 auto','','','.w-catalog-b2b-add-button'),(929130,'printshop','.b-form .terms-login .bootstrap-switch','margin','9px auto 0px','','','.b-form'),(929131,'printshop','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin','0px auto 0px','','','.b-compare'),(929132,'printshop','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','margin','0 0 0 auto','','','.w-cart-listing'),(929133,'printshop','.b-compare .clear_all','margin','0px auto 0px','4','','.b-compare'),(929134,'printshop','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','margin','0px auto 0px','','','.b-compare'),(929135,'printshop','.b-compare .clear_all','margin','0px auto 0px','4','','.b-compare'),(929136,'printshop','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','margin','0 auto','','','.b-product-images'),(929137,'printshop','.b-trade-approval .middle-form','margin','0 auto','','','.b-trade-approval'),(929139,'printshop','.b-products-listing .products-listing .slick-slide img','margin','auto','','','.b-products-listing'),(929140,'printshop','.b-products-listing .products-listing .compare input + span','margin','auto','','','.b-products-listing'),(929141,'printshop','.w-product-quantity .qty_packs .price_1','margin','0px auto 0px','4','','.w-product-quantity'),(929142,'printshop','.p-quote-checkout-index .datepicker-inline','margin','0 auto','','','.p-quote-checkout-index'),(929143,'printshop','.p-sample-checkout-index .datepicker-inline','margin','0 auto','','','.p-sample-checkout-index'),(929144,'printshop','.b-slick .slick-slide img','margin','auto','','','.b-slick'),(929145,'printshop','.heading-1','margin','10px auto','4','',''),(929146,'printshop','h1','margin','10px auto','4','',''),(929147,'printshop','.cartTitle >div','margin','10px auto','4','','.cartTitle'),(929148,'printshop','.bottomBanner .icon-box > div','margin','auto','3','','.bottomBanner'),(929149,'printshop','.w-catalog-additional-images picture','margin','auto','','','.w-catalog-additional-images'),(929150,'printshop','.topBanner .content','margin','auto','5333','','.topBanner'),(929151,'printshop','.p-quote-checkout-index .edit-address-popup .addresses.address-edit-holder','margin','0 auto','','','.p-quote-checkout-index'),(929152,'printshop','.account-address-book .address_book .row-buttons a','margin','0px auto 0px','','','.account-address-book'),(929153,'printshop','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin','0px auto 15px','','','.account-address-book'),(929154,'printshop','.account-address-book .address_book_row h2 a','margin','0px auto 0px','','','.account-address-book'),(929155,'printshop','.account-address-book .buttonBox .info','margin','0px auto 0px','','','.account-address-book'),(929158,'printshop','.checkout-index-wrap .datepicker-inline','margin','0 auto','','','.checkout-index-wrap'),(929159,'printshop','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','margin','0 auto','','','.checkout-index-wrap'),(929160,'printshop','.index-wrap .heading-2','margin','10px auto','4','','.index-wrap'),(929161,'printshop','.index-wrap h2','margin','10px auto','4','','.index-wrap'),(929162,'printshop','.b-form .formWrapBox','margin','0 auto','','','.b-form'),(929163,'printshop','.w-communication-new-topic #communication_group_holder input, .w-communication-new-topic select','margin-bottom','0','','','.w-communication-new-topic'),(929164,'printshop','.w-checkout-billing-address .genders-title','margin-bottom','5','','','.w-checkout-billing-address'),(929165,'printshop','.b-form .col-full-margin','margin-bottom','10','','','.b-form'),(929167,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(929168,'printshop','.w-catalog-items-on-page select','margin-bottom','0','','','.w-catalog-items-on-page'),(929169,'printshop','.b-form .message.error','margin-bottom','10','','','.b-form'),(929170,'printshop','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-bottom','0','','','.b-fancybox'),(929171,'printshop','.p-quick-order-index .filters','margin-bottom','20','','','.p-quick-order-index'),(929172,'printshop','.w-promotions .promo-date','margin-bottom','10','','','.w-promotions'),(929173,'printshop','.w-promotions .promo-item','margin-bottom','30','','','.w-promotions'),(929174,'printshop','.w-socials > li','margin-bottom','10','','','.w-socials'),(929175,'printshop','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(929176,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(929180,'printshop','.w-promotions .prom-multi-discount .heading','margin-bottom','10','','','.w-promotions'),(929181,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(929182,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(929183,'printshop','.testimonials .reviews-list .name','margin-bottom','20','','',''),(929184,'printshop','.testimonials .heading-3','margin-bottom','10','','',''),(929185,'printshop','.testimonials .name','margin-bottom','20','','',''),(929186,'printshop','.b-products-listing .select-attributes','margin-bottom','10','','','.b-products-listing'),(929187,'printshop','.b-products-listing .select-attributes select','margin-bottom','0','','','.b-products-listing'),(929188,'printshop','.w-promotions .nextdiscount .promo-for-each','margin-bottom','10','','','.w-promotions'),(929189,'printshop','.w-promotions .nextdiscount .heading','margin-bottom','20','','','.w-promotions'),(929190,'printshop','.w-promotions .heading-3','margin-bottom','20','','','.w-promotions'),(929191,'printshop','.w-promotions .promo-salemaker .item','margin-bottom','2','','','.w-promotions'),(929192,'printshop','.w-promotions .promo-cart-discount .slave .item','margin-bottom','2','','','.w-promotions'),(929193,'printshop','.w-promotions .promo-cart-discount .master .item','margin-bottom','12','','','.w-promotions'),(929194,'printshop','.w-promotions .promo-cart-discount .master .heading','margin-bottom','10','','','.w-promotions'),(929195,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-bottom','20','','','.b-warehouses-popup'),(929196,'printshop','.b-warehouses-popup .warehouses-popup .heading','margin-bottom','20','','','.b-warehouses-popup'),(929197,'printshop','.w-info-content p','margin-bottom','10','','','.w-info-content'),(929199,'printshop','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(929200,'printshop','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(929201,'printshop','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(929203,'printshop','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(929204,'printshop','.w-top-categories .categories','margin-bottom','0','5333','','.w-top-categories'),(929205,'printshop','.b-messages .messages-menu ul','margin-bottom','0','','','.b-messages'),(929206,'printshop','.b-messages .messMenuButtonTop','margin-bottom','-39','','','.b-messages'),(929207,'printshop','.b-messages .dataTables_wrapper > .top','margin-bottom','8','','','.b-messages'),(929208,'printshop','.b-messages .messages-sidebar .heading-2','margin-bottom','20','','','.b-messages'),(929209,'printshop','.b-messages .messages-menu li','margin-bottom','0','','','.b-messages'),(929210,'printshop','.b-messages .messages-sidebar .btn-2','margin-bottom','20','','','.b-messages'),(929211,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-bottom','5','','','.b-messages'),(929212,'printshop','.w-sitemap-delivery-location > ul > li > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(929213,'printshop','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(929214,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(929215,'printshop','.b-form .middle-form .bootstrap-switch','margin-bottom','15','','','.b-form'),(929216,'printshop','.w-sitemap-delivery-location > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(929217,'printshop','.p-quick-order-index ul.token-input-list','margin-bottom','0','','','.p-quick-order-index'),(929218,'printshop','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(929219,'printshop','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(929220,'printshop','.b-info .info li','margin-bottom','0','','','.b-info'),(929221,'printshop','.b-info .info ul','margin-bottom','0','','','.b-info'),(929222,'printshop','.w-checkout-shipping-address .genders-title','margin-bottom','5','','','.w-checkout-shipping-address'),(929223,'printshop','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(929224,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(929225,'printshop','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(929226,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(929227,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','margin-bottom','20','','','.w-upload-customer-id-upload-customer-id-form'),(929228,'printshop','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(929229,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(929230,'printshop','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(929231,'printshop','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(929232,'printshop','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(929233,'printshop','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(929234,'printshop','.w-filters .filter-box-head','margin-bottom','15','','','.w-filters'),(929235,'printshop','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(929236,'printshop','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(929237,'printshop','.w-menu-horizontal li','margin-bottom','0','','','.w-menu-horizontal'),(929238,'printshop','.w-menu-horizontal ul','margin-bottom','0','','','.w-menu-horizontal'),(929239,'printshop','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(929240,'printshop','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(929241,'printshop','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(929242,'printshop','.b-delete-account .delete-box > div','margin-bottom','10','','','.b-delete-account'),(929243,'printshop','.w-info-content p','margin-bottom','10','','','.w-info-content'),(929244,'printshop','.w-filters .input-checkbox','margin-bottom','0','','','.w-filters'),(929245,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(929246,'printshop','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(929247,'printshop','.b-form .newsletter-row','margin-bottom','10','','','.b-form'),(929248,'printshop','.w-cart-give-away .ga_attributes > div','margin-bottom','1','','','.w-cart-give-away'),(929249,'printshop','.w-cart-checkout-btn + .w-image','margin-bottom','0','','','.w-cart-checkout-btn'),(929250,'printshop','.b-info .info li','margin-bottom','0','','','.b-info'),(929251,'printshop','.heading-6, h6, .h-block h6','margin-bottom','5','','',''),(929252,'printshop','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(929253,'printshop','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(929254,'printshop','.w-communication-post .text-container','margin-bottom','20','','','.w-communication-post'),(929255,'printshop','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(929256,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(929257,'printshop','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(929258,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(929259,'printshop','.b-info .info ul','margin-bottom','0','','','.b-info'),(929260,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(929261,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-bottom','0','','','.b-select-suggest'),(929262,'printshop','.b-form .password-forgotten-link','margin-bottom','0','','','.b-form'),(929263,'printshop','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(929264,'printshop','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(929265,'printshop','.w-socials > li','margin-bottom','10','','','.w-socials'),(929267,'printshop','.b-delete-account .delete-box span','margin-bottom','0','','','.b-delete-account'),(929268,'printshop','.w-socials > li','margin-bottom','10','','','.w-socials'),(929269,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(929270,'printshop','.w-image-maps .default-links .item .title','margin-bottom','10','','','.w-image-maps'),(929271,'printshop','.w-reviews .heading-3','margin-bottom','10','','','.w-reviews'),(929272,'printshop','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(929273,'printshop','.w-socials > li','margin-bottom','10','','','.w-socials'),(929274,'printshop','.b-info .info li','margin-bottom','0','','','.b-info'),(929275,'printshop','.w-checkout-shipping-address .addresses .address-item','margin-bottom','10','','','.w-checkout-shipping-address'),(929276,'printshop','.w-checkout-billing-address .same-address','margin-bottom','10','','','.w-checkout-billing-address'),(929277,'printshop','.b-form .required-message-wrap','margin-bottom','0','','','.b-form'),(929278,'printshop','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(929279,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(929280,'printshop','.w-tabs > .block','margin-bottom','20','','','.w-tabs'),(929281,'printshop','.w-cart-cart-tabs .w-tabs .tab-navigation','margin-bottom','5','','','.w-cart-cart-tabs'),(929282,'printshop','.w-tabs .tab-li','margin-bottom','0','','','.w-tabs'),(929283,'printshop','.w-socials > li','margin-bottom','10','','','.w-socials'),(929284,'printshop','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(929286,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(929287,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(929288,'printshop','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(929289,'printshop','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(929290,'printshop','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(929291,'printshop','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(929292,'printshop','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(929293,'printshop','.heading-5, h5, .h-block h5','margin-bottom','5','','',''),(929294,'printshop','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(929295,'printshop','.w-filters .filter-ul-content','margin-bottom','0','','','.w-filters'),(929296,'printshop','.heading-4, h4, .h-block h4','margin-bottom','5','','',''),(929297,'printshop','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(929298,'printshop','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(929299,'printshop','.b-info .info ul','margin-bottom','0','','','.b-info'),(929300,'printshop','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','margin-bottom','10','','','.b-form'),(929301,'printshop','.order-summary .price-box','margin-bottom','10','','','.order-summary'),(929302,'printshop','.b-form .addresses .address-item input[type=\"radio\"]','margin-bottom','0','','','.b-form'),(929303,'printshop','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(929304,'printshop','.w-image-maps .categories-items .item .title','margin-bottom','10','','','.w-image-maps'),(929305,'printshop','.b-select-suggest .select2-drop-mask','margin-bottom','0','','','.b-select-suggest'),(929306,'printshop','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(929307,'printshop','.w-top-categories .categories','margin-bottom','0','5347','','.w-top-categories'),(929308,'printshop','.products-quick-index ul','margin-bottom','0','','',''),(929309,'printshop','.w-checkout-gdpr .col-left','margin-bottom','20','5342','','.w-checkout-gdpr'),(929310,'printshop','.w-top-categories .categories h2','margin-bottom','0','','','.w-top-categories'),(929311,'printshop','.w-product-reviews .reviews-list .name','margin-bottom','20','','','.w-product-reviews'),(929312,'printshop','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(929313,'printshop','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(929314,'printshop','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(929315,'printshop','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(929316,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(929317,'printshop','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(929318,'printshop','.b-form .required-message','margin-bottom','0','','','.b-form'),(929319,'printshop','.w-socials .post_item_img','margin-bottom','0','','','.w-socials'),(929320,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(929321,'printshop','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(929322,'printshop','.w-product-quantity .qty_packs .price_1','margin-bottom','0','4','','.w-product-quantity'),(929323,'printshop','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(929324,'printshop','.w-reviews .reviews-list','margin-bottom','20','','','.w-reviews'),(929325,'printshop','.b-select-suggest .select2-container','margin-bottom','0','','','.b-select-suggest'),(929326,'printshop','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(929327,'printshop','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(929328,'printshop','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(929329,'printshop','.w-checkout-create-account .heading-2','margin-bottom','0','','','.w-checkout-create-account'),(929330,'printshop','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(929331,'printshop','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(929332,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(929333,'printshop','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(929334,'printshop','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(929335,'printshop','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(929336,'printshop','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(929337,'printshop','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(929338,'printshop','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(929339,'printshop','.b-form .col-full-padding','margin-bottom','10','','','.b-form'),(929340,'printshop','.b-info .info li','margin-bottom','0','','','.b-info'),(929341,'printshop','.b-info .info ul','margin-bottom','0','','','.b-info'),(929342,'printshop','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','margin-bottom','15','','','.b-form'),(929343,'printshop','.heading-3, h3, .h-block h3','margin-bottom','10','','',''),(929344,'printshop','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(929345,'printshop','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(929346,'printshop','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(929348,'printshop','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(929349,'printshop','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(929350,'printshop','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(929351,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(929352,'printshop','.b-form .form-inputs label > span','margin-bottom','1','','','.b-form'),(929353,'printshop','.b-autocomplete .ui-autocomplete','margin-bottom','0','','','.b-autocomplete'),(929354,'printshop','.b-bottom .cart-options .js-carts','margin-bottom','10','','','.b-bottom'),(929355,'printshop','.b-bottom .cart-options .option-item','margin-bottom','5','','','.b-bottom'),(929356,'printshop','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(929357,'printshop','.b-bottom .cart-options .cart-item','margin-bottom','5','','','.b-bottom'),(929359,'printshop','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(929360,'printshop','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(929361,'printshop','.b-select-suggest .select2-results .select2-result-label','margin-bottom','0','','','.b-select-suggest'),(929363,'printshop','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(929364,'printshop','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(929365,'printshop','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(929366,'printshop','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(929367,'printshop','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(929368,'printshop','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(929369,'printshop','.b-bottom .pop-up-content .buttons','margin-bottom','0','','','.b-bottom'),(929370,'printshop','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(929371,'printshop','.w-menu-big li','margin-bottom','0','','','.w-menu-big'),(929372,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(929373,'printshop','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(929374,'printshop','.b-fancybox .fancybox-error','margin-bottom','0','','','.b-fancybox'),(929375,'printshop','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(929376,'printshop','.w-cart-compare .product .image','margin-bottom','10','','','.w-cart-compare'),(929377,'printshop','.w-checkout-billing-address .addresses .address-item','margin-bottom','10','','','.w-checkout-billing-address'),(929378,'printshop','.b-bottom .confirm-popup .buttons .btn','margin-bottom','10','','','.b-bottom'),(929379,'printshop','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-bottom','0','','','.b-switch'),(929380,'printshop','.w-reviews-content .reviews-list','margin-bottom','20','','','.w-reviews-content'),(929381,'printshop','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(929382,'printshop','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(929383,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(929384,'printshop','.b-form #shipping-address .radio-buttons','margin-bottom','10','','','.b-form'),(929385,'printshop','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(929386,'printshop','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(929387,'printshop','.w-tabs .tab-navigation','margin-bottom','0','','','.w-tabs'),(929388,'printshop','.b-info .info ul','margin-bottom','0','','','.b-info'),(929389,'printshop','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(929390,'printshop','.w-social-links a','margin-bottom','0','','','.w-social-links'),(929391,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-bottom','1','','','.b-select-suggest'),(929392,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-bottom','0','','','.b-select-suggest'),(929393,'printshop','.b-select-suggest .select2-container-multi .select2-choices','margin-bottom','0','','','.b-select-suggest'),(929394,'printshop','.w-info-content p','margin-bottom','10','','','.w-info-content'),(929395,'printshop','.b-select-suggest .select2-results ul.select2-result-sub','margin-bottom','0','','','.b-select-suggest'),(929396,'printshop','.b-select-suggest .select2-search input','margin-bottom','0','','','.b-select-suggest'),(929397,'printshop','.b-select-suggest .select2-search','margin-bottom','0','','','.b-select-suggest'),(929398,'printshop','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(929402,'printshop','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(929404,'printshop','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(929405,'printshop','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(929406,'printshop','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(929407,'printshop','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(929408,'printshop','.order-summary .btn-2, .order-summary .btn-3','margin-bottom','15','','','.order-summary'),(929410,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(929411,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(929412,'printshop','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(929413,'printshop','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(929414,'printshop','.b-bottom .content-item','margin-bottom','20','','','.b-bottom'),(929415,'printshop','.b-form .middle-form .checkbox-holder','margin-bottom','15','','','.b-form'),(929416,'printshop','.w-communication-new-topic .privacy-row','margin-bottom','10','','','.w-communication-new-topic'),(929417,'printshop','.w-communication-post .communication-post-message','margin-bottom','20','','','.w-communication-post'),(929418,'printshop','.w-communication-post .communication-post','margin-bottom','5','','','.w-communication-post'),(929419,'printshop','.b-products-listing .products-listing .name','margin-bottom','5','','','.b-products-listing'),(929420,'printshop','.b-products-listing .products-listing .model','margin-bottom','5','','','.b-products-listing'),(929421,'printshop','.b-products-listing .products-listing .description','margin-bottom','30','','','.b-products-listing'),(929422,'printshop','.b-products-listing .products-listing .bonusPoints','margin-bottom','7','','','.b-products-listing'),(929423,'printshop','.b-products-listing .products-listing .description ul','margin-bottom','0','','','.b-products-listing'),(929424,'printshop','.b-products-listing .products-listing .mult-qty-input','margin-bottom','3','','','.b-products-listing'),(929425,'printshop','.b-products-listing .promos-info','margin-bottom','-30','','','.b-products-listing'),(929426,'printshop','.b-products-listing .wedding-registry-count','margin-bottom','10','','','.b-products-listing'),(929427,'printshop','.w-info-content p','margin-bottom','10','','','.w-info-content'),(929428,'printshop','.w-checkout-gdpr .privacy-row','margin-bottom','0','','','.w-checkout-gdpr'),(929429,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(929430,'printshop','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(929431,'printshop','.b-fancybox .fancybox-title-float-wrap','margin-bottom','-35','','','.b-fancybox'),(929432,'printshop','.w-socials > li','margin-bottom','10','','','.w-socials'),(929433,'printshop','.w-product-reviews .reviews-list','margin-bottom','10','','','.w-product-reviews'),(929434,'printshop','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(929436,'printshop','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(929437,'printshop','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(929438,'printshop','.w-info-content p','margin-bottom','10','','','.w-info-content'),(929439,'printshop','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(929440,'printshop','.w-taxable label','margin-bottom','0','','','.w-taxable'),(929441,'printshop','.w-taxable select','margin-bottom','0','','','.w-taxable'),(929442,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-bottom','0','','',''),(929443,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-bottom','0','','','.b-h-inline'),(929444,'printshop','h1, .heading-1','margin-bottom','18','','',''),(929445,'printshop','.w-communication-new-topic #rmaProductReturnButtonFilterHolder','margin-bottom','30','','','.w-communication-new-topic'),(929446,'printshop','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(929447,'printshop','.w-checkout-shipping-address #shippingchoice-choice','margin-bottom','10','','','.w-checkout-shipping-address'),(929448,'printshop','.b-info .info li','margin-bottom','0','','','.b-info'),(929449,'printshop','.w-product-reviews .write-review-button','margin-bottom','20','','','.w-product-reviews'),(929450,'printshop','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(929451,'printshop','.b-form .checkbox-style','margin-bottom','0','','','.b-form'),(929452,'printshop','.b-info .info ul','margin-bottom','0','','','.b-info'),(929453,'printshop','.products-quick-index .token-input-list','margin-bottom','0','','',''),(929454,'printshop','.products-quick-index ul.token-input-list','margin-bottom','0','','',''),(929455,'printshop','.w-cart-checkout-btn .or-text','margin-bottom','5','','','.w-cart-checkout-btn'),(929456,'printshop','.b-compare .col-two','margin-bottom','15','','','.b-compare'),(929457,'printshop','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(929458,'printshop','.w-cart-listing .item','margin-bottom','10','5342','','.w-cart-listing'),(929459,'printshop','.w-cart-give-away .ga_wrapper','margin-bottom','25','','','.w-cart-give-away'),(929461,'printshop','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(929462,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(929463,'printshop','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(929464,'printshop','.w-image-maps .float-items .item .title','margin-bottom','10','','','.w-image-maps'),(929465,'printshop','.w-info-content p','margin-bottom','10','','','.w-info-content'),(929466,'printshop','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-bottom','0','','','.b-fancybox'),(929467,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(929468,'printshop','.w-filters .ui-slider','margin-bottom','0','','','.w-filters'),(929469,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-bottom','0','','','.w-contact-contacts'),(929470,'printshop','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(929471,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(929472,'printshop','.w-catalog-sorting select','margin-bottom','0','','','.w-catalog-sorting'),(929473,'printshop','.b-info .info li','margin-bottom','0','','','.b-info'),(929474,'printshop','.b-form .radio-buttons','margin-bottom','10','','','.b-form'),(929475,'printshop','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(929476,'printshop','.heading-2, h2, .h-block h2','margin-bottom','10','','',''),(929477,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(929478,'printshop','.b-upload-files .upload-files','margin-bottom','20','','','.b-upload-files'),(929479,'printshop','.w-communication-new-topic .text-container','margin-bottom','20','','','.w-communication-new-topic'),(929480,'printshop','.b-form .addresses','margin-bottom','20','','','.b-form'),(929483,'printshop','.w-menu-big ul','margin-bottom','0','','','.w-menu-big'),(929484,'printshop','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(929485,'printshop','.b-product-images .media-popup .slick-dots','margin-bottom','0','','','.b-product-images'),(929486,'printshop','.b-product-images .media-popup .slick-dots li','margin-bottom','0','','','.b-product-images'),(929487,'printshop','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-bottom','0','','','.b-menu-style'),(929488,'printshop','.b-personal-catalog-popup #personal_catalog_popup .lists-message-box','margin-bottom','20','','','.b-personal-catalog-popup'),(929489,'printshop','.b-trade-approval .steps-bar','margin-bottom','25','','','.b-trade-approval'),(929490,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','margin-bottom','15','','','.b-trade-approval'),(929491,'printshop','.b-trade-approval .middle-form textarea','margin-bottom','15','','','.b-trade-approval'),(929492,'printshop','.w-account-personal-catalog .list-switcher','margin-bottom','20','','','.w-account-personal-catalog'),(929493,'printshop','.w-account-subscription .send-email','margin-bottom','20','','','.w-account-subscription'),(929494,'printshop','.w-account-subscription .subscription-list','margin-bottom','20','','','.w-account-subscription'),(929495,'printshop','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-bottom','0','','','.w-catalog-additional-images'),(929496,'printshop','.w-catalog-compare .cross-box .return','margin-bottom','30','','','.w-catalog-compare'),(929497,'printshop','.w-delivery-day .time-left','margin-bottom','30','','','.w-delivery-day'),(929498,'printshop','.w-delivery-day .ends','margin-bottom','20','','','.w-delivery-day'),(929499,'printshop','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-bottom','0','','','.b-cookie-notice'),(929500,'printshop','.lowestPricedBox .w-banner .banner','margin-bottom','0','','','.lowestPricedBox'),(929501,'printshop','.tripleBanner ','margin-bottom','0','','','.tripleBanner'),(929502,'printshop','.b-products-listing .products-listing.list-productlisting .price','margin-bottom','0','','','.b-products-listing'),(929503,'printshop','.shopByCollectionBox .w-banner .banner','margin-bottom','0','','','.shopByCollectionBox'),(929504,'printshop','.preFooter .w-banner .single_banner','margin-bottom','0','','','.preFooter'),(929505,'printshop','.b-slick .slick-list','margin-bottom','0','','','.b-slick'),(929506,'printshop','.LeftCategories .w-menu-simple ul','margin-bottom','0','','','.LeftCategories'),(929507,'printshop','.w-breadcrumb .breadcrumb-li','margin-bottom','0','','','.w-breadcrumb'),(929508,'printshop','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(929509,'printshop','.w-quote .multicart .name','margin-bottom','0','','','.w-quote'),(929510,'printshop','.b-products-listing .rating, .b-products-listing .ratingCounts','margin-bottom','5','','','.b-products-listing'),(929511,'printshop','.w-product-name h1','margin-bottom','5','','','.w-product-name'),(929512,'printshop','.w-product-sale-ends .ends','margin-bottom','20','','','.w-product-sale-ends'),(929513,'printshop','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(929514,'printshop','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(929515,'printshop','.w-compare .clear-compare-button','margin-bottom','15','','','.w-compare'),(929516,'printshop','.w-files-catalog-widgets-files-catalog ','margin-bottom','50','','','.w-files-catalog-widgets-files-catalog'),(929517,'printshop','.w-files-catalog-widgets-files-list .files','margin-bottom','50','','','.w-files-catalog-widgets-files-list'),(929518,'printshop','.w-files-catalog-widgets-files-list .name','margin-bottom','10','','','.w-files-catalog-widgets-files-list'),(929519,'printshop','.w-sample .multicart .name','margin-bottom','0','','','.w-sample'),(929520,'printshop','.w-filters-simple select','margin-bottom','0','','','.w-filters-simple'),(929521,'printshop','.w-cart-discount-coupon .title','margin-bottom','0','','','.w-cart-discount-coupon'),(929522,'printshop','.w-cart-sub-total ','margin-bottom','20','','','.w-cart-sub-total'),(929523,'printshop','.shipping-ico .heading-3','margin-bottom','10','','','.shipping-ico'),(929524,'printshop','.order-summary .heading-2','margin-bottom','0','','','.order-summary'),(929525,'printshop','.w-cart-gift-certificate .heading-4','margin-bottom','0','','','.w-cart-gift-certificate'),(929526,'printshop','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(929527,'printshop','.w-product-bundle .bundle-total-price','margin-bottom','20','','','.w-product-bundle'),(929528,'printshop','.w-product-in-bundles .bundle-total-price','margin-bottom','20','','','.w-product-in-bundles'),(929529,'printshop','.b-bottom .cart-options .buttons','margin-bottom','0','','','.b-bottom'),(929530,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-bottom','0','','','.b-products-listing'),(929531,'printshop','.b-pagination .pagination','margin-bottom','20','','','.b-pagination'),(929532,'printshop','.b-pagination ul.pagination','margin-bottom','0','','','.b-pagination'),(929533,'printshop','.w-catalog-compare .list-compareproduct .stock','margin-bottom','0','','','.w-catalog-compare'),(929534,'printshop','.w-product-quantity-discounts .item','margin-bottom','0','5342','','.w-product-quantity-discounts'),(929535,'printshop','.w-product-properties-filters-widgets-chosen-filters .item','margin-bottom','5','','','.w-product-properties-filters-widgets-chosen-filters'),(929536,'printshop','.w-product-multi-inventory .radio-attributes > span','margin-bottom','5','','','.w-product-multi-inventory'),(929537,'printshop','.w-product-multi-inventory .radio-attributes','margin-bottom','15','','','.w-product-multi-inventory'),(929538,'printshop','.w-account-personal-catalog .list-row-action ul','margin-bottom','-1','','','.w-account-personal-catalog'),(929539,'printshop','.w-account-personal-catalog .list-row-action li','margin-bottom','0','','','.w-account-personal-catalog'),(929540,'printshop','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','margin-bottom','10','','','.w-account-personal-catalog'),(929541,'printshop','.b-products-listing .products-listing .radio-attributes','margin-bottom','15','','','.b-products-listing'),(929542,'printshop','.b-products-listing .products-listing .radio-attributes > span','margin-bottom','5','','','.b-products-listing'),(929543,'printshop','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(929544,'printshop','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(929545,'printshop','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(929546,'printshop','.w-product-attributes .radio-attributes','margin-bottom','15','','','.w-product-attributes'),(929547,'printshop','.w-product-attributes .radio-attributes > span','margin-bottom','5','','','.w-product-attributes'),(929548,'printshop','.w-product-properties .property-ul','margin-bottom','0','','','.w-product-properties'),(929549,'printshop','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(929550,'printshop','.w-questionnaire-widgets-questionnaire .question','margin-bottom','20','','','.w-questionnaire-widgets-questionnaire'),(929551,'printshop','.w-questionnaire-widgets-questionnaire .description','margin-bottom','10','','','.w-questionnaire-widgets-questionnaire'),(929552,'printshop','.w-product-groups .radioBox label','margin-bottom','15','','','.w-product-groups'),(929553,'printshop','.w-product-groups .radioBoxHead','margin-bottom','5','','','.w-product-groups'),(929554,'printshop','.w-delivery-day .title','margin-bottom','10','','','.w-delivery-day'),(929555,'printshop','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(929556,'printshop','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(929557,'printshop','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(929558,'printshop','.b-products-listing .products-listing.list-productlisting .attribute-qty-block > span','margin-bottom','4','','','.b-products-listing'),(929559,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-bottom','0','','','.w-catalog-pages-category-pages-last-list'),(929560,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(929561,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-bottom','0','','','.w-catalog-pages-category-pages-last-list-block'),(929562,'printshop','.w-delivery-location-top-location-list .deliveryName','margin-bottom','10','','','.w-delivery-location-top-location-list'),(929563,'printshop','.w-delivery-location-location-list .deliveryName','margin-bottom','10','','','.w-delivery-location-location-list'),(929564,'printshop','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(929565,'printshop','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(929566,'printshop','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(929567,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','5333','','.w-delivery-location-top-location-list'),(929568,'printshop','.w-delivery-location-featured-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-featured-list'),(929569,'printshop','.w-delivery-location-location-list .deliveryListParrent a','margin-bottom','5','','','.w-delivery-location-location-list'),(929570,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li','margin-bottom','20','','','.w-delivery-location-featured-list'),(929571,'printshop','.w-sale-category .ends','margin-bottom','20','','','.w-sale-category'),(929572,'printshop','.w-sale-category .left','margin-bottom','30','','','.w-sale-category'),(929573,'printshop','.w-sale-category .name','margin-bottom','20','','','.w-sale-category'),(929574,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-img','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(929575,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-name','margin-bottom','10','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(929576,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(929577,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(929578,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-img','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(929579,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-name','margin-bottom','10','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(929580,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(929581,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(929582,'printshop','.w-delivery-location-list-by-page .description ul','margin-bottom','5','','','.w-delivery-location-list-by-page'),(929583,'printshop','.w-delivery-location-list-by-page .item','margin-bottom','20','','','.w-delivery-location-list-by-page'),(929584,'printshop','.w-delivery-location-list-by-page .item','margin-bottom','10','5363','','.w-delivery-location-list-by-page'),(929585,'printshop','.w-delivery-location-cross-pages .description ul','margin-bottom','5','','','.w-delivery-location-cross-pages'),(929586,'printshop','.w-delivery-location-cross-pages .item','margin-bottom','20','','','.w-delivery-location-cross-pages'),(929587,'printshop','.w-delivery-location-cross-pages .item','margin-bottom','10','5363','','.w-delivery-location-cross-pages'),(929588,'printshop','.w-cart-credit-amount ','margin-bottom','10','','','.w-cart-credit-amount'),(929589,'printshop','.w-catalog-delivery-locations .item','margin-bottom','20','','','.w-catalog-delivery-locations'),(929590,'printshop','.w-catalog-delivery-locations .description ul','margin-bottom','5','','','.w-catalog-delivery-locations'),(929591,'printshop','.w-catalog-delivery-locations .name','margin-bottom','10','','','.w-catalog-delivery-locations'),(929592,'printshop','.w-catalog-delivery-locations .item','margin-bottom','20','5333','','.w-catalog-delivery-locations'),(929593,'printshop','.w-product-designer-designer .grnamebox .title-sortable','margin-bottom','10','','','.w-product-designer-designer'),(929594,'printshop','.w-product-designer-designer .prodDesignerType label','margin-bottom','10','','','.w-product-designer-designer'),(929595,'printshop','.w-press-reviews-widgets-press-reviews-small ','margin-bottom','12','','','.w-press-reviews-widgets-press-reviews-small'),(929596,'printshop','.w-press-reviews-widgets-press-reviews ','margin-bottom','30','','','.w-press-reviews-widgets-press-reviews'),(929597,'printshop','.w-press-reviews-widgets-press-reviews .image','margin-bottom','15','','','.w-press-reviews-widgets-press-reviews'),(929598,'printshop','.w-press-reviews-widgets-press-reviews .reviews-list','margin-bottom','20','','','.w-press-reviews-widgets-press-reviews'),(929599,'printshop','.w-press-reviews-widgets-press-reviews .date','margin-bottom','10','5333','','.w-press-reviews-widgets-press-reviews'),(929600,'printshop','.w-press-reviews-widgets-press-reviews-list .image','margin-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(929601,'printshop','.w-press-reviews-widgets-press-reviews-list .item','margin-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(929602,'printshop','.w-press-reviews-widgets-press-reviews-list .product-name','margin-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(929603,'printshop','.b-products-listing .productGroup','margin-bottom','10','','','.b-products-listing'),(929604,'printshop','.w-gift-wrap-message-checkout .text','margin-bottom','20','','','.w-gift-wrap-message-checkout'),(929605,'printshop','.w-support-system-filter .filter_cats','margin-bottom','0','','','.w-support-system-filter'),(929606,'printshop','.w-support-system-listing .topic-products-listing .item','margin-bottom','30','','','.w-support-system-listing'),(929607,'printshop','.w-communication-post .buttons','margin-bottom','20','','','.w-communication-post'),(929608,'printshop','.w-rma-returns-history .content-messages .messages-table .top','margin-bottom','10','','','.w-rma-returns-history'),(929609,'printshop','.w-rma-returns-history .filterMessages','margin-bottom','0','','','.w-rma-returns-history'),(929610,'printshop','.w-rma-returns-history .column','margin-bottom','10','','screen and (max-width: 768px)','.w-rma-returns-history'),(929611,'printshop','.w-rma-returns-history .column .title','margin-bottom','5','','screen and (max-width: 768px)','.w-rma-returns-history'),(929612,'printshop','.w-rma-returns-history .column:last-child .title','margin-bottom','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(929613,'printshop','.w-product-designer-designer .productDesignerBox ul','margin-bottom','0','','','.w-product-designer-designer'),(929614,'printshop','.w-product-designer-designer .grnamebox','margin-bottom','10','','','.w-product-designer-designer'),(929615,'printshop','.w-product-configurator .pc-item','margin-bottom','0','','','.w-product-configurator'),(929616,'printshop','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(929617,'printshop','.w-product-configurator .pc_row','margin-bottom','10','','','.w-product-configurator'),(929618,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-bottom','0','','','.w-catalog-pages-category-pages-list'),(929619,'printshop','.w-predefined-promotion .heading-3','margin-bottom','20','','','.w-predefined-promotion'),(929620,'printshop','.w-predefined-promotion .nextdiscount .heading','margin-bottom','20','','','.w-predefined-promotion'),(929621,'printshop','.w-predefined-promotion .nextdiscount .promo-for-each','margin-bottom','10','','','.w-predefined-promotion'),(929622,'printshop','.w-predefined-promotion .prom-multi-discount .heading','margin-bottom','10','','','.w-predefined-promotion'),(929623,'printshop','.w-predefined-promotion .promo-cart-discount .master .heading','margin-bottom','10','','','.w-predefined-promotion'),(929624,'printshop','.w-predefined-promotion .promo-cart-discount .master .item','margin-bottom','12','','','.w-predefined-promotion'),(929625,'printshop','.w-predefined-promotion .promo-cart-discount .slave .item','margin-bottom','2','','','.w-predefined-promotion'),(929626,'printshop','.w-predefined-promotion .promo-date','margin-bottom','10','','','.w-predefined-promotion'),(929627,'printshop','.w-predefined-promotion .promo-item','margin-bottom','30','','','.w-predefined-promotion'),(929628,'printshop','.w-predefined-promotion .promo-salemaker .item','margin-bottom','2','','','.w-predefined-promotion'),(929629,'printshop','.w-supplier-purchase-supplier-products .item','margin-bottom','10','','','.w-supplier-purchase-supplier-products'),(929630,'printshop','.w-filters .filter-widget-horizontal .filter-box-head','margin-bottom','0','','','.w-filters'),(929631,'printshop','.w-product-model ','margin-bottom','12','','','.w-product-model'),(929632,'printshop','.tripleLine .single_banner','margin-bottom','10','','','.tripleLine'),(929633,'printshop','.cartTitle span','margin-bottom','18','','','.cartTitle'),(929634,'printshop','.lowestPricedBox .descr','margin-bottom','15','','','.lowestPricedBox'),(929635,'printshop','.doubleBanner .descr','margin-bottom','15','','','.doubleBanner'),(929636,'printshop','.doubleBanner .descr','margin-bottom','15','5347','','.doubleBanner'),(929637,'printshop','.pop-up-content .buttons .left-buttons','margin-bottom','15','5333','',''),(929638,'printshop','.b-products-listing .products-listing .description','margin-bottom','15','5347','','.b-products-listing'),(929639,'printshop','.b-bottom .confirm-popup .buttons .btn','margin-bottom','10','5333','','.b-bottom'),(929640,'printshop','.w-catalog-counts-items ','margin-bottom','10','5363','','.w-catalog-counts-items'),(929641,'printshop','.topBanner .content .btn','margin-bottom','15','','','.topBanner'),(929642,'printshop','.topBanner .ourPick','margin-bottom','15','','','.topBanner'),(929643,'printshop','.tripleLine .banner-image','margin-bottom','10','','','.tripleLine'),(929644,'printshop','.w-cart-discount-coupon .discount-box','margin-bottom','10','','','.w-cart-discount-coupon'),(929645,'printshop','.w-cart-shipping-estimator .left-area','margin-bottom','20','5363','','.w-cart-shipping-estimator'),(929646,'printshop','.p-quote-checkout-index .dob-hide','margin-bottom','-10','','','.p-quote-checkout-index'),(929647,'printshop','.p-quote-checkout-index .input-wrapper','margin-bottom','10','','','.p-quote-checkout-index'),(929648,'printshop','.account-address-book .address_book .row-buttons a','margin-bottom','0','','','.account-address-book'),(929649,'printshop','.account-address-book .address_book h1','margin-bottom','18','','','.account-address-book'),(929650,'printshop','.account-address-book .address_book h2','margin-bottom','15','','','.account-address-book'),(929651,'printshop','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-bottom','15','','','.account-address-book'),(929652,'printshop','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-bottom','10','','','.account-address-book'),(929653,'printshop','.account-address-book .address_book_row h2 a','margin-bottom','0','','','.account-address-book'),(929654,'printshop','.account-address-book .buttonBox .info','margin-bottom','0','','','.account-address-book'),(929655,'printshop','.account-address-book .address_book_row .column','margin-bottom','12','5333','','.account-address-book'),(929656,'printshop','.account-address-book .address_book_row .column + .column','margin-bottom','12','5333','','.account-address-book'),(929657,'printshop','.account-address-book .topInfo > div','margin-bottom','12','5333','','.account-address-book'),(929658,'printshop','.account-address-book .topInfo > div + div','margin-bottom','12','5333','','.account-address-book'),(929677,'printshop','.account-order-pay .buttons','margin-bottom','20','','','.account-order-pay'),(929678,'printshop','.account-order-pay .history_info','margin-bottom','20','','','.account-order-pay'),(929679,'printshop','.account-order-pay .history_info > div','margin-bottom','12','5342','','.account-order-pay'),(929680,'printshop','.account-password-wrap .buttonedit','margin-bottom','0','','','.account-password-wrap'),(929681,'printshop','.account-password-wrap .buttons','margin-bottom','20','','','.account-password-wrap'),(929682,'printshop','.account-samples .buttonBox','margin-bottom','15','','','.account-samples'),(929683,'printshop','.account-samples .order_history_table h2','margin-bottom','8','','','.account-samples'),(929684,'printshop','.account-samples .orders-table .item','margin-bottom','10','5342','','.account-samples'),(929685,'printshop','.account-sample-info .buttons','margin-bottom','20','','','.account-sample-info'),(929686,'printshop','.account-sample-info .history_info','margin-bottom','20','','','.account-sample-info'),(929687,'printshop','.account-sample-info .history_info > div','margin-bottom','12','5342','','.account-sample-info'),(929688,'printshop','.catalog-product-wrap .pn-direction','margin-bottom','15','','','.catalog-product-wrap'),(929689,'printshop','.catalog-product-wrap .rating, .catalog-product-wrap .ratingCounts','margin-bottom','0','','','.catalog-product-wrap'),(929690,'printshop','.shopping-cart-index .closeable-heading .heading-2','margin-bottom','0','','','.shopping-cart-index'),(929691,'printshop','.checkout-index-wrap .closeable-heading .heading-2','margin-bottom','0','','','.checkout-index-wrap'),(929692,'printshop','.checkout-index-wrap .dob-hide','margin-bottom','-10','','','.checkout-index-wrap'),(929693,'printshop','.checkout-index-wrap .input-wrapper','margin-bottom','10','','','.checkout-index-wrap'),(929694,'printshop','.checkout-success-wrap .w-success-print-btn','margin-bottom','15','5363','','.checkout-success-wrap'),(929695,'printshop','.b-form .columns','margin-bottom','10','','','.b-form'),(929696,'printshop','.b-slick .slick-dots li','margin-bottom','0','','','.b-slick'),(929697,'printshop','.success-page .order_totals','margin-bottom','30','','','.success-page'),(929698,'printshop','.success-page .page-success .text-1','margin-bottom','0','3','','.success-page'),(929699,'printshop','.success-page .w-order-products','margin-bottom','20','','','.success-page'),(929700,'printshop','.b-multi-page-checkout .multi-page-checkout .buttons','margin-bottom','0','','','.b-multi-page-checkout'),(929701,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-step','margin-bottom','5','','','.b-multi-page-checkout'),(929702,'printshop','.doubleBanner .w-banner .banner-holder','margin-bottom','0','','','.doubleBanner'),(929703,'printshop','.doubleBanner .w-banner .banner-item','margin-bottom','20','5363','','.doubleBanner'),(929704,'printshop','.bottomDoubleBanner .w-banner .banner-holder','margin-bottom','0','','','.bottomDoubleBanner'),(929705,'printshop','.bottomDoubleBanner .w-banner .banner-item','margin-bottom','20','5363','','.bottomDoubleBanner'),(929706,'printshop','.footer-menu .level-1 > li > a, .footer-menu .level-1 > li > .no-link','margin-bottom','10','','','.footer-menu'),(929707,'printshop','.footer-menu .level-2 > li','margin-bottom','5','','','.footer-menu'),(929708,'printshop','.footer-menu .level-1 > li > .no-link','margin-bottom','0','5342','','.footer-menu'),(929709,'printshop','.w-bestsellers .heading-3','margin-bottom','10','','','.w-bestsellers'),(929710,'printshop','.w-bestsellers .item','margin-bottom','12','','','.w-bestsellers'),(929711,'printshop','.payment-method-tf label','margin-bottom','10','','','.payment-method-tf'),(929712,'printshop','.accout-box ','margin-bottom','30','','','.accout-box'),(929713,'printshop','.accout-box select[data-type=\"vat_number\"]','margin-bottom','0','','','.accout-box'),(929714,'printshop','.w-account-customer-additional-field .field-type-checkbox','margin-bottom','10','','','.w-account-customer-additional-field'),(929715,'printshop','.w-account-customer-additional-field .field-type-text','margin-bottom','10','','','.w-account-customer-additional-field'),(929716,'printshop','.w-sale .ends','margin-bottom','20','','','.w-sale'),(929717,'printshop','.w-sale .left','margin-bottom','30','','','.w-sale'),(929718,'printshop','.w-sale .name','margin-bottom','20','','','.w-sale'),(929719,'printshop','.b-bottom .cart-options .buttons','margin-bottom_important','important','','','.b-bottom'),(929720,'printshop','.w-product-quantity-discounts .item','margin-bottom_important','important','5342','','.w-product-quantity-discounts'),(929721,'printshop','.heading-4 .edit, h4 .edit','margin-left','10','4','',''),(929722,'printshop','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(929723,'printshop','.message.success','margin-left','-40','3','',''),(929724,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(929726,'printshop','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(929727,'printshop','.w-catalog-items-on-page select','margin-left','10','','','.w-catalog-items-on-page'),(929729,'printshop','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-left','0','','','.b-fancybox'),(929730,'printshop','.p-quick-order-index ul.token-input-list','margin-left','5','','','.p-quick-order-index'),(929731,'printshop','.p-quick-order-index .filters .clear','margin-left','15','','','.p-quick-order-index'),(929732,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','margin-left','5','','','.p-quick-order-index'),(929733,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.p-quick-order-index'),(929734,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(929738,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(929739,'printshop','.w-promotions .promo-salemaker .item','margin-left','2','','','.w-promotions'),(929740,'printshop','.w-promotions .promo-cart-discount .slave .item','margin-left','2','','','.w-promotions'),(929741,'printshop','.w-promotions .promo-cart-discount .master .item','margin-left','12','','','.w-promotions'),(929742,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','-17','3','','.b-warehouses-popup'),(929743,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','0','','','.b-warehouses-popup'),(929745,'printshop','.b-form .password-forgotten-link','margin-left','0','','','.b-form'),(929746,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(929747,'printshop','.b-messages .messages-menu ul','margin-left','0','','','.b-messages'),(929748,'printshop','.b-messages .msv_content','margin-left','0','','','.b-messages'),(929749,'printshop','.b-messages .msv_history','margin-left','0','','','.b-messages'),(929750,'printshop','.b-messages .messages-menu li','margin-left','0','','','.b-messages'),(929751,'printshop','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(929752,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-left','5','','','.b-messages'),(929753,'printshop','.w-sitemap-delivery-location > ul > li > ul','margin-left','0','','','.w-sitemap-delivery-location'),(929754,'printshop','.w-sitemap-delivery-location > ul','margin-left','0','','','.w-sitemap-delivery-location'),(929755,'printshop','.b-fancybox #fancybox-loading','margin-left','-22','','','.b-fancybox'),(929756,'printshop','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(929758,'printshop','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(929759,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(929760,'printshop','.b-info .info','margin-left','-40','3','','.b-info'),(929761,'printshop','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(929762,'printshop','.w-coupons-and-vauchers-checkout .btn-remove','margin-left','-30','','','.w-coupons-and-vauchers-checkout'),(929763,'printshop','.w-checkout-bonus-points .btn-remove','margin-left','-30','','','.w-checkout-bonus-points'),(929764,'printshop','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(929765,'printshop','.w-menu-horizontal li','margin-left','0','','','.w-menu-horizontal'),(929766,'printshop','.w-filters .input-checkbox','margin-left','0','','','.w-filters'),(929767,'printshop','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(929768,'printshop','.b-info .info ul','margin-left','0','','','.b-info'),(929769,'printshop','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(929770,'printshop','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(929771,'printshop','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','margin-left','7','3','','.order-summary'),(929772,'printshop','.buttons .right-buttons .btn','margin-left','10','','',''),(929773,'printshop','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(929774,'printshop','.w-top-categories .categories','margin-left','0','5333','','.w-top-categories'),(929775,'printshop','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(929776,'printshop','.w-cart-checkout-btn + .w-image','margin-left','0','','','.w-cart-checkout-btn'),(929777,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(929778,'printshop','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(929779,'printshop','.b-form .col-3 + .col-3','margin-left','3','','','.b-form'),(929780,'printshop','.b-info .info','margin-left','-40','3','','.b-info'),(929781,'printshop','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(929782,'printshop','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(929783,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-left','0','','','.b-select-suggest'),(929784,'printshop','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(929785,'printshop','.w-socials > li','margin-left','10','','','.w-socials'),(929787,'printshop','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(929788,'printshop','.b-delete-account .delete-box span','margin-left','10','','','.b-delete-account'),(929789,'printshop','.w-socials > li','margin-left','10','','','.w-socials'),(929790,'printshop','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(929791,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(929792,'printshop','.w-catalog-listing-look .list','margin-left','5','','','.w-catalog-listing-look'),(929793,'printshop','.view-all .btn','margin-left','10','4','',''),(929794,'printshop','.w-socials > li','margin-left','10','','','.w-socials'),(929795,'printshop','.b-info .info li','margin-left','0','','','.b-info'),(929796,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(929797,'printshop','.w-tabs .tab-navigation','margin-left','0','','','.w-tabs'),(929798,'printshop','.w-tabs .tab-li','margin-left','0','','','.w-tabs'),(929799,'printshop','.w-socials > li','margin-left','10','','','.w-socials'),(929800,'printshop','.b-info .info','margin-left','-40','3','','.b-info'),(929801,'printshop','.b-info .info li','margin-left','0','','','.b-info'),(929802,'printshop','.b-info .info ul','margin-left','0','','','.b-info'),(929803,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(929804,'printshop','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(929805,'printshop','.w-cart-credit-amount .btn-remove','margin-left','-30','','','.w-cart-credit-amount'),(929806,'printshop','.heading-3 .right-text, h3 .right-text','margin-left','10','','',''),(929807,'printshop','.w-product-reviews .reviews-list','margin-left','0','','','.w-product-reviews'),(929808,'printshop','.b-products-listing .products-listing .bonus-points-price','margin-left','-20','3','','.b-products-listing'),(929810,'printshop','.w-filters .filter-ul-content','margin-left','0','','','.w-filters'),(929811,'printshop','.heading-3 .edit, h3 .edit','margin-left','10','4','',''),(929812,'printshop','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-shipping-address'),(929813,'printshop','.b-info .info ul','margin-left','0','','','.b-info'),(929814,'printshop','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(929815,'printshop','.w-cart-bonus-points .btn-remove','margin-left','-30','','','.w-cart-bonus-points'),(929816,'printshop','.b-select-suggest .select2-drop-mask','margin-left','0','','','.b-select-suggest'),(929817,'printshop','.w-checkout-shipping-choice input:checked + span:before','margin-left','-5','','','.w-checkout-shipping-choice'),(929818,'printshop','.products-quick-index ul','margin-left','0','','',''),(929819,'printshop','.w-top-categories .categories h2','margin-left','0','','','.w-top-categories'),(929820,'printshop','.b-form .checkbox-style','margin-left','0','','','.b-form'),(929821,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(929822,'printshop','.b-form .addresses .address-item input[type=\"radio\"]','margin-left','0','','','.b-form'),(929823,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(929824,'printshop','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(929825,'printshop','.b-form .columns .col-2:nth-child(2n)','margin-left','0','5363','','.b-form'),(929826,'printshop','.w-product-quantity .qty_packs .price_1','margin-left','15','4','','.w-product-quantity'),(929827,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(929828,'printshop','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(929829,'printshop','.b-select-suggest .select2-container','margin-left','0','','','.b-select-suggest'),(929830,'printshop','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(929831,'printshop','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(929832,'printshop','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(929833,'printshop','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(929834,'printshop','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(929835,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(929836,'printshop','.b-info .info','margin-left','-40','3','','.b-info'),(929837,'printshop','.b-info .info ul','margin-left','0','','','.b-info'),(929838,'printshop','.b-info .info li','margin-left','0','','','.b-info'),(929839,'printshop','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(929840,'printshop','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(929842,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(929844,'printshop','.w-checkout-credit-amount .btn-remove','margin-left','-30','','','.w-checkout-credit-amount'),(929845,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(929846,'printshop','.b-info .info','margin-left','-40','3','','.b-info'),(929847,'printshop','.b-autocomplete .ui-autocomplete','margin-left','0','','','.b-autocomplete'),(929848,'printshop','.w-top-categories .categories','margin-left','-10','5347','','.w-top-categories'),(929849,'printshop','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(929850,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(929852,'printshop','.b-select-suggest .select2-results .select2-result-label','margin-left','0','','','.b-select-suggest'),(929853,'printshop','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(929854,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(929855,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(929856,'printshop','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-billing-address'),(929857,'printshop','.b-bottom .pop-up-content .buttons','margin-left','0','','','.b-bottom'),(929858,'printshop','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(929860,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(929861,'printshop','.b-fancybox .fancybox-error','margin-left','0','','','.b-fancybox'),(929862,'printshop','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(929863,'printshop','.w-cart-compare .product .image','margin-left','0','','','.w-cart-compare'),(929864,'printshop','.b-info .info li','margin-left','0','','','.b-info'),(929865,'printshop','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(929866,'printshop','.b-bottom .confirm-popup .buttons .btn','margin-left','10','','','.b-bottom'),(929867,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(929868,'printshop','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-left','0','','','.b-switch'),(929869,'printshop','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(929870,'printshop','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(929871,'printshop','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(929872,'printshop','.w-cart-give-away .ga_attributes > div','margin-left','1','','','.w-cart-give-away'),(929873,'printshop','.w-cart-checkout-btn .or-text','margin-left','0','','','.w-cart-checkout-btn'),(929874,'printshop','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(929875,'printshop','.w-cart-give-away .ga_column','margin-left','2','','','.w-cart-give-away'),(929876,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(929877,'printshop','.w-social-links a','margin-left','5','','','.w-social-links'),(929878,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(929879,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-left','0','','','.b-select-suggest'),(929880,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-left','0','','','.b-select-suggest'),(929881,'printshop','.b-select-suggest .select2-container-multi .select2-choices','margin-left','0','','','.b-select-suggest'),(929882,'printshop','.b-select-suggest .select2-results ul.select2-result-sub','margin-left','0','','','.b-select-suggest'),(929883,'printshop','.b-select-suggest .select2-search input','margin-left','0','','','.b-select-suggest'),(929884,'printshop','.b-select-suggest .select2-search','margin-left','0','','','.b-select-suggest'),(929885,'printshop','.w-socials > li','margin-left','10','','','.w-socials'),(929888,'printshop','.w-menu-horizontal ul','margin-left','0','','','.w-menu-horizontal'),(929890,'printshop','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(929891,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.b-data-table'),(929892,'printshop','.w-catalog-b2b-add-button .add-b2b-products','margin-left','50','','','.w-catalog-b2b-add-button'),(929893,'printshop','.b-products-listing .products-listing .description ul','margin-left','0','','','.b-products-listing'),(929894,'printshop','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(929895,'printshop','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(929896,'printshop','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(929897,'printshop','.w-checkout-gdpr .privacy-row','margin-left','0','','','.w-checkout-gdpr'),(929898,'printshop','.w-checkout-gdpr .bootstrap-switch','margin-left','25','','','.w-checkout-gdpr'),(929899,'printshop','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(929900,'printshop','.b-info .info','margin-left','-40','3','','.b-info'),(929901,'printshop','.b-info .info li','margin-left','0','','','.b-info'),(929902,'printshop','.w-socials > li','margin-left','10','','','.w-socials'),(929903,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(929904,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(929905,'printshop','.w-taxable label','margin-left','5','','','.w-taxable'),(929906,'printshop','.w-taxable select','margin-left','5','','','.w-taxable'),(929907,'printshop','.heading-4 .right-text, h4 .right-text','margin-left','10','','',''),(929908,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-left','0','','',''),(929909,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-left','0','','','.b-h-inline'),(929910,'printshop','.b-info .info ul','margin-left','0','','','.b-info'),(929911,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(929912,'printshop','.products-quick-index ul.token-input-list','margin-left','0','','',''),(929913,'printshop','.b-form .required-message','margin-left','0','','','.b-form'),(929914,'printshop','.b-info .info li','margin-left','0','','','.b-info'),(929915,'printshop','.w-catalog-listing-look .b2b','margin-left','5','','','.w-catalog-listing-look'),(929916,'printshop','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(929917,'printshop','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(929918,'printshop','.w-cart-listing .points-redeem','margin-left','-25','3','','.w-cart-listing'),(929919,'printshop','.w-cart-listing .remove-btn','margin-left','0','5342','','.w-cart-listing'),(929920,'printshop','.w-cart-give-away .ga_column','margin-left','0','5333','','.w-cart-give-away'),(929921,'printshop','.w-cart-discount-coupon .btn-remove','margin-left','-30','','','.w-cart-discount-coupon'),(929922,'printshop','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(929924,'printshop','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-left','0','','','.b-fancybox'),(929925,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(929926,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(929927,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(929928,'printshop','.w-socials .post_item_img','margin-left','0','','','.w-socials'),(929929,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-left','0','','','.w-contact-contacts'),(929930,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(929931,'printshop','.w-filters .view_more','margin-left','5','4','','.w-filters'),(929932,'printshop','.products-quick-index .token-input-list','margin-left','0','','',''),(929933,'printshop','.b-info .info ul','margin-left','0','','','.b-info'),(929934,'printshop','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(929937,'printshop','.w-menu-big ul','margin-left','0','','','.w-menu-big'),(929938,'printshop','.w-menu-big li','margin-left','0','','','.w-menu-big'),(929940,'printshop','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(929941,'printshop','.b-form .required-message-wrap','margin-left','0','','','.b-form'),(929942,'printshop','.b-product-images .media-popup .slick-dots','margin-left','0','','','.b-product-images'),(929943,'printshop','.b-product-images .media-popup .slick-dots li','margin-left','5','','','.b-product-images'),(929944,'printshop','.b-product-images .media-popup button.slick-prev:active','margin-left','-3','','','.b-product-images'),(929945,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(929946,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(929947,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(929948,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(929949,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(929950,'printshop','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-left','0','','','.b-menu-style'),(929951,'printshop','.b-trade-approval .steps-bar','margin-left','0','','','.b-trade-approval'),(929952,'printshop','.b-trade-approval .col-3 + .col-3','margin-left','3','','','.b-trade-approval'),(929953,'printshop','.w-account-personal-catalog .list-switcher','margin-left','0','','','.w-account-personal-catalog'),(929954,'printshop','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-left','0','','','.w-catalog-additional-images'),(929955,'printshop','.w-delivery-day .left-count','margin-left','2','','','.w-delivery-day'),(929956,'printshop','.w-delivery-day .left-text-right','margin-left','2','','','.w-delivery-day'),(929957,'printshop','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-left','0','','','.b-cookie-notice'),(929958,'printshop','.lowestPricedBox .w-banner .banner','margin-left','-15','','','.lowestPricedBox'),(929959,'printshop','.tripleBanner ','margin-left','-15','','','.tripleBanner'),(929960,'printshop','.shopByCollectionBox .w-banner .banner','margin-left','-15','','','.shopByCollectionBox'),(929961,'printshop','.preFooter .w-banner .single_banner','margin-left','2','','','.preFooter'),(929962,'printshop','.b-slick .slick-list','margin-left','0','','','.b-slick'),(929963,'printshop','.b-slick .slick-track','margin-left','auto','','','.b-slick'),(929964,'printshop','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-left','-20','','','.b-slick'),(929965,'printshop','.LeftCategories .w-menu-simple ul','margin-left','0','','','.LeftCategories'),(929966,'printshop','.w-breadcrumb .breadcrumb-li','margin-left','0','','','.w-breadcrumb'),(929967,'printshop','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(929968,'printshop','.w-quote .image','margin-left','-90','','','.w-quote'),(929969,'printshop','.w-quote .multicart .name','margin-left','-10','','','.w-quote'),(929970,'printshop','.w-product-sale-ends .left-count','margin-left','2','','','.w-product-sale-ends'),(929971,'printshop','.w-product-sale-ends .left-text-right','margin-left','2','','','.w-product-sale-ends'),(929972,'printshop','.w-compare .image','margin-left','-80','','','.w-compare'),(929973,'printshop','.w-files-catalog-widgets-files-list .file','margin-left','-20','3','','.w-files-catalog-widgets-files-list'),(929974,'printshop','.w-files-catalog-widgets-files-list .files','margin-left','10','','','.w-files-catalog-widgets-files-list'),(929975,'printshop','.w-sample .image','margin-left','-90','','','.w-sample'),(929976,'printshop','.w-sample .multicart .name','margin-left','-10','','','.w-sample'),(929977,'printshop','.w-cart-sub-total ','margin-left','0','','','.w-cart-sub-total'),(929978,'printshop','.shipping-ico .heading-3','margin-left','0','','','.shipping-ico'),(929979,'printshop','.order-summary .heading-2','margin-left','0','','','.order-summary'),(929980,'printshop','.w-cart-gift-certificate .heading-4','margin-left','0','','','.w-cart-gift-certificate'),(929981,'printshop','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(929982,'printshop','.w-cart-order-reference .input-apple button','margin-left','10','','','.w-cart-order-reference'),(929983,'printshop','.w-cart-gift-certificate .btn','margin-left','10','','','.w-cart-gift-certificate'),(929984,'printshop','.b-bottom .cart-options .buttons','margin-left','0','','','.b-bottom'),(929985,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-left','0','','','.b-products-listing'),(929986,'printshop','.b-pagination .pagination .next-pages','margin-left','5','','','.b-pagination'),(929987,'printshop','.b-pagination .pagination .page-number','margin-left','5','','','.b-pagination'),(929988,'printshop','.b-pagination .pagination .prev-pages','margin-left','5','','','.b-pagination'),(929989,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','margin-left','5','','','.b-pagination'),(929990,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','margin-left','5','','','.b-pagination'),(929991,'printshop','.b-pagination .pagination span','margin-left','5','2','','.b-pagination'),(929992,'printshop','.b-pagination ul.pagination','margin-left','0','','','.b-pagination'),(929993,'printshop','.w-product-quantity-discounts .item:nth-child(2n)','margin-left','2','','','.w-product-quantity-discounts'),(929994,'printshop','.w-product-quantity-discounts .item','margin-left','0','5342','','.w-product-quantity-discounts'),(929995,'printshop','.w-product-multi-inventory .select-box:nth-child(2n)','margin-left','4','','','.w-product-multi-inventory'),(929996,'printshop','.w-product-properties-filters-widgets-chosen-filters .item','margin-left','0','','','.w-product-properties-filters-widgets-chosen-filters'),(929997,'printshop','.w-product-properties-filters-widgets-chosen-filters .remove','margin-left','5','','','.w-product-properties-filters-widgets-chosen-filters'),(929998,'printshop','.p-sample-checkout-index .order-summary .heading-2','margin-left','-100','3','','.p-sample-checkout-index'),(929999,'printshop','.w-account-personal-catalog .list-row-action ul','margin-left','-1','','','.w-account-personal-catalog'),(930000,'printshop','.w-account-personal-catalog .list-row-action li','margin-left','0','','','.w-account-personal-catalog'),(930001,'printshop','.w-account-personal-catalog .buy-box a + a','margin-left','10','5333','','.w-account-personal-catalog'),(930002,'printshop','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(930003,'printshop','.w-product-properties .property-ul','margin-left','0','','','.w-product-properties'),(930004,'printshop','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(930005,'printshop','.b-products-listing .mix-attributes .mult-qty-input .qty-box > input','margin-left','3','','','.b-products-listing'),(930006,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list'),(930007,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list-block'),(930008,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(930009,'printshop','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(930010,'printshop','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(930011,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin-left','0','5333','','.w-delivery-location-top-location-list'),(930012,'printshop','.w-delivery-location-featured-list .deliveryList ul','margin-left','0','','','.w-delivery-location-featured-list'),(930013,'printshop','.w-sale-category .left-count','margin-left','2','','','.w-sale-category'),(930014,'printshop','.w-sale-category .left-text-right','margin-left','2','','','.w-sale-category'),(930015,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(930016,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(930017,'printshop','.w-delivery-location-list-by-page .description ul','margin-left','0','','','.w-delivery-location-list-by-page'),(930018,'printshop','.w-delivery-location-list-by-page .item','margin-left','1','','','.w-delivery-location-list-by-page'),(930019,'printshop','.w-delivery-location-list-by-page .item','margin-left','0','5363','','.w-delivery-location-list-by-page'),(930020,'printshop','.w-delivery-location-cross-pages .description ul','margin-left','0','','','.w-delivery-location-cross-pages'),(930021,'printshop','.w-delivery-location-cross-pages .item','margin-left','1','','','.w-delivery-location-cross-pages'),(930022,'printshop','.w-delivery-location-cross-pages .item','margin-left','0','5363','','.w-delivery-location-cross-pages'),(930023,'printshop','.w-catalog-delivery-locations .item','margin-left','1','','','.w-catalog-delivery-locations'),(930024,'printshop','.w-catalog-delivery-locations .description ul','margin-left','0','','','.w-catalog-delivery-locations'),(930025,'printshop','.w-catalog-delivery-locations .item','margin-left','0','5333','','.w-catalog-delivery-locations'),(930026,'printshop','.w-product-designer-designer .prodDesignerType label','margin-left','10','','','.w-product-designer-designer'),(930027,'printshop','.w-press-reviews-widgets-press-reviews .date','margin-left','0','5333','','.w-press-reviews-widgets-press-reviews'),(930028,'printshop','.w-press-reviews-widgets-press-reviews-list .image','margin-left','0','','','.w-press-reviews-widgets-press-reviews-list'),(930029,'printshop','.w-press-reviews-widgets-press-reviews-list .item','margin-left','0','','','.w-press-reviews-widgets-press-reviews-list'),(930030,'printshop','.w-support-system-filter .filter_cats','margin-left','0','','','.w-support-system-filter'),(930031,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','margin-left','2','','','.w-rma-returns-history'),(930032,'printshop','.w-rma-returns-history .filterMessages','margin-left','-3','','','.w-rma-returns-history'),(930033,'printshop','.w-rma-returns-history .linkButton','margin-left','5','4','','.w-rma-returns-history'),(930034,'printshop','.w-rma-returns-history .column:last-child .title','margin-left','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(930035,'printshop','.w-product-designer-designer .productDesignerBox ul','margin-left','0','','','.w-product-designer-designer'),(930036,'printshop','.w-product-configurator .pc-item','margin-left','0','','','.w-product-configurator'),(930037,'printshop','.b-products-listing .promos-info .promo-name','margin-left','-30','','','.b-products-listing'),(930038,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-list'),(930039,'printshop','.w-multi-cart-save-cart button','margin-left','20','','','.w-multi-cart-save-cart'),(930040,'printshop','.w-predefined-promotion .promo-cart-discount .master .item','margin-left','12','','','.w-predefined-promotion'),(930041,'printshop','.w-predefined-promotion .promo-cart-discount .slave .item','margin-left','2','','','.w-predefined-promotion'),(930042,'printshop','.w-predefined-promotion .promo-salemaker .item','margin-left','2','','','.w-predefined-promotion'),(930043,'printshop','.w-product-model ','margin-left','0','','','.w-product-model'),(930044,'printshop','.tripleLine .text-banner-2 > div a','margin-left','10','4','','.tripleLine'),(930045,'printshop','.middleBanner .btn-1','margin-left','45','4','','.middleBanner'),(930046,'printshop','.bottomBanner .btn-1','margin-left','45','4','','.bottomBanner'),(930047,'printshop','.w-account-personal-catalog .buy-box a + a','margin-left','0','5363','','.w-account-personal-catalog'),(930048,'printshop','.b-bottom .confirm-popup .buttons .btn','margin-left','0','5333','','.b-bottom'),(930049,'printshop','.topBanner .content .btn','margin-left','15','4','','.topBanner'),(930050,'printshop','.topBanner .ourPick','margin-left','35','','','.topBanner'),(930051,'printshop','.bottomBanner .btn-1','margin-left','5','5363,4','','.bottomBanner'),(930052,'printshop','.middleBanner .btn-1','margin-left','5','5363,4','','.middleBanner'),(930053,'printshop','.tripleLine .banner-text-holder > div a','margin-left','10','4','','.tripleLine'),(930054,'printshop','.w-cart-discount-coupon .title','margin-left','10','4','','.w-cart-discount-coupon'),(930055,'printshop','.w-cart-checkout-btn .with-card','margin-left','15','4','','.w-cart-checkout-btn'),(930056,'printshop','.account-address-book .address_book .row-buttons a','margin-left','0','','','.account-address-book'),(930057,'printshop','.account-address-book .address_book h1','margin-left','0','','','.account-address-book'),(930058,'printshop','.account-address-book .address_book h2','margin-left','0','','','.account-address-book'),(930059,'printshop','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-left','2','','','.account-address-book'),(930060,'printshop','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-left','0','','','.account-address-book'),(930061,'printshop','.account-address-book .address_book_row h2 a','margin-left','15','','','.account-address-book'),(930062,'printshop','.account-address-book .buttonBox .info','margin-left','0','','','.account-address-book'),(930063,'printshop','.account-address-book .address_book_row .column','margin-left','0','5333','','.account-address-book'),(930064,'printshop','.account-address-book .address_book_row .column + .column','margin-left','0','5333','','.account-address-book'),(930065,'printshop','.account-address-book .topInfo > div','margin-left','0','5333','','.account-address-book'),(930066,'printshop','.account-address-book .topInfo > div + div','margin-left','0','5333','','.account-address-book'),(930079,'printshop','.account-order-pay .buttons','margin-left','0','','','.account-order-pay'),(930080,'printshop','.account-order-pay .history_info','margin-left','0','','','.account-order-pay'),(930081,'printshop','.account-order-pay .history_info > div','margin-left','0','5342','','.account-order-pay'),(930082,'printshop','.account-password-wrap .buttonedit','margin-left','0','','','.account-password-wrap'),(930083,'printshop','.account-samples .buttonBox','margin-left','0','','','.account-samples'),(930084,'printshop','.account-samples .order_history_table h2','margin-left','0','','','.account-samples'),(930085,'printshop','.account-sample-info .buttons','margin-left','0','','','.account-sample-info'),(930086,'printshop','.account-sample-info .history_info','margin-left','0','','','.account-sample-info'),(930087,'printshop','.account-sample-info .history_info > div','margin-left','0','5342','','.account-sample-info'),(930088,'printshop','.shopping-cart-index .closeable-heading .heading-2','margin-left','0','','','.shopping-cart-index'),(930089,'printshop','.checkout-success-wrap .w-success-continue-btn','margin-left','0','5363','','.checkout-success-wrap'),(930090,'printshop','.b-slick .slick-dots li','margin-left','5','','','.b-slick'),(930091,'printshop','.success-page .page-success .text-1','margin-left','-50','3','','.success-page'),(930092,'printshop','.b-multi-page-checkout .multi-page-checkout .buttons','margin-left','0','','','.b-multi-page-checkout'),(930093,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','margin-left','15','4','','.b-multi-page-checkout'),(930094,'printshop','.doubleBanner .w-banner .banner-holder','margin-left','-15','','','.doubleBanner'),(930095,'printshop','.bottomDoubleBanner .w-banner .banner-holder','margin-left','-15','','','.bottomDoubleBanner'),(930098,'printshop','.footer-menu .level-2 > li','margin-left','-18','3','','.footer-menu'),(930099,'printshop','.accout-box select[data-type=\"vat_number\"]','margin-left','0','','','.accout-box'),(930100,'printshop','.w-catalog-paging .next','margin-left','2','','','.w-catalog-paging'),(930101,'printshop','.w-sale .left-count','margin-left','2','','','.w-sale'),(930102,'printshop','.w-sale .left-text-right','margin-left','2','','','.w-sale'),(930103,'printshop','.b-bottom .cart-options .buttons','margin-left_important','important','','','.b-bottom'),(930104,'printshop','.w-product-quantity-discounts .item','margin-left_important','important','5342','','.w-product-quantity-discounts'),(930105,'printshop','.checkout-success-wrap .w-success-continue-btn','margin-left_important','important','5363','','.checkout-success-wrap'),(930106,'printshop','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(930107,'printshop','.w-checkout-billing-address .btn-cancel','margin-right','20','','','.w-checkout-billing-address'),(930108,'printshop','.w-catalog-items-on-page select','margin-right','10','','','.w-catalog-items-on-page'),(930109,'printshop','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-right','0','','','.b-fancybox'),(930110,'printshop','.p-quick-order-index ul.token-input-list','margin-right','30','','','.p-quick-order-index'),(930111,'printshop','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(930112,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(930116,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(930117,'printshop','.w-promotions .prom-multi-discount > .heading','margin-right','5','3','','.w-promotions'),(930118,'printshop','.w-promotions .nextdiscount .heading','margin-right','10','3','','.w-promotions'),(930119,'printshop','.w-promotions .icon','margin-right','15','','','.w-promotions'),(930120,'printshop','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','margin-right','5','3','','.w-promotions'),(930121,'printshop','.w-promotions .promo-salemaker .item','margin-right','2','','','.w-promotions'),(930122,'printshop','.w-promotions .promo-cart-discount .slave .item','margin-right','2','','','.w-promotions'),(930123,'printshop','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','margin-right','5','3','','.w-promotions'),(930124,'printshop','.w-promotions .promo-cart-discount .master .item','margin-right','12','','','.w-promotions'),(930125,'printshop','.b-warehouses-popup .warehouses-popup-link','margin-right','5','3','','.b-warehouses-popup'),(930126,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-right','20','','','.b-warehouses-popup'),(930127,'printshop','.bell-ico .heading-2','margin-right','10','3','','.bell-ico'),(930128,'printshop','.w-checkout-create-account .account-benefits strong','margin-right','5','3','','.w-checkout-create-account'),(930130,'printshop','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-right','0','','','.b-fancybox'),(930131,'printshop','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(930132,'printshop','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(930133,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(930134,'printshop','.b-messages .messages-menu ul','margin-right','0','','','.b-messages'),(930135,'printshop','.b-messages .messBtnMenuDelete','margin-right','8','3','','.b-messages'),(930136,'printshop','.b-messages .messBtnMenuUnread','margin-right','8','3','','.b-messages'),(930137,'printshop','.b-messages .msv_content','margin-right','0','','','.b-messages'),(930138,'printshop','.b-messages .msv_history','margin-right','0','','','.b-messages'),(930139,'printshop','.b-messages .messBtnMenuStarred','margin-right','8','3','','.b-messages'),(930140,'printshop','.b-messages .messages-menu li','margin-right','0','','','.b-messages'),(930141,'printshop','.b-messages .content_management_attach span::before','margin-right','5','','','.b-messages'),(930142,'printshop','.b-messages .content_management_attach span','margin-right','10','','','.b-messages'),(930143,'printshop','.w-tabs .tab-navigation','margin-right','0','','','.w-tabs'),(930144,'printshop','.w-sitemap-delivery-location > ul > li > ul','margin-right','0','','','.w-sitemap-delivery-location'),(930145,'printshop','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(930146,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(930147,'printshop','.w-sitemap-delivery-location > ul','margin-right','0','','','.w-sitemap-delivery-location'),(930148,'printshop','.p-payer-order-confirmation .ship-ico','margin-right','20','3','','.p-payer-order-confirmation'),(930149,'printshop','.p-payer-order-confirmation .pay-ico','margin-right','20','3','','.p-payer-order-confirmation'),(930150,'printshop','.p-payer-order-confirmation .discount-ico','margin-right','10','3','','.p-payer-order-confirmation'),(930151,'printshop','.p-payer-order-confirmation .comment-ico','margin-right','20','3','','.p-payer-order-confirmation'),(930152,'printshop','.p-payer-order-pay .ship-ico','margin-right','20','3','','.p-payer-order-pay'),(930153,'printshop','.p-payer-order-pay .pay-ico','margin-right','20','3','','.p-payer-order-pay'),(930154,'printshop','.p-payer-order-pay .discount-ico','margin-right','10','3','','.p-payer-order-pay'),(930155,'printshop','.p-payer-order-pay .comment-ico','margin-right','20','3','','.p-payer-order-pay'),(930156,'printshop','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(930157,'printshop','.b-delete-account .delete-box span','margin-right','10','','','.b-delete-account'),(930158,'printshop','.w-checkout-shipping-address .genders-title label','margin-right','20','','','.w-checkout-shipping-address'),(930159,'printshop','.w-checkout-shipping-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-shipping-address'),(930160,'printshop','.b-messages span.starred::before','margin-right','8','','','.b-messages'),(930161,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(930162,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(930163,'printshop','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(930164,'printshop','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(930165,'printshop','.w-menu-horizontal li','margin-right','0','','','.w-menu-horizontal'),(930166,'printshop','.w-menu-horizontal ul','margin-right','0','','','.w-menu-horizontal'),(930167,'printshop','.b-info .info ul','margin-right','0','','','.b-info'),(930168,'printshop','.b-info .info li','margin-right','0','','','.b-info'),(930169,'printshop','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(930170,'printshop','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(930171,'printshop','.b-info .info li','margin-right','0','','','.b-info'),(930172,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(930173,'printshop','.buttons .left-buttons .btn','margin-right','10','','',''),(930174,'printshop','.out-stock-icon','margin-right','3','3','',''),(930176,'printshop','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(930177,'printshop','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(930178,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(930179,'printshop','.w-filters .input-checkbox:checked + .checkbox-span','margin-right','10','','','.w-filters'),(930180,'printshop','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(930181,'printshop','.w-top-categories .categories','margin-right','-10','5347','','.w-top-categories'),(930182,'printshop','.b-info .info li','margin-right','0','','','.b-info'),(930183,'printshop','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(930184,'printshop','.b-info .info ul','margin-right','0','','','.b-info'),(930185,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-right','0','','','.b-select-suggest'),(930186,'printshop','.w-socials > li','margin-right','10','','','.w-socials'),(930189,'printshop','.w-socials > li','margin-right','10','','','.w-socials'),(930190,'printshop','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(930191,'printshop','.b-info .info ul','margin-right','0','','','.b-info'),(930192,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(930193,'printshop','.w-checkout-shipping-address .btn-cancel','margin-right','20','','','.w-checkout-shipping-address'),(930194,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(930195,'printshop','.w-multi-cart-actions .cart-actions .dropdown-toggle','margin-right','10','3','','.w-multi-cart-actions'),(930196,'printshop','.w-tabs .tab-li','margin-right','0','','','.w-tabs'),(930197,'printshop','.w-socials > li','margin-right','10','','','.w-socials'),(930198,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(930199,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(930200,'printshop','.w-cart-listing .actions > div','margin-right','20','','','.w-cart-listing'),(930201,'printshop','.b-form .required-message-wrap','margin-right','0','','','.b-form'),(930202,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(930203,'printshop','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(930204,'printshop','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(930207,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(930208,'printshop','.b-info .info li','margin-right','0','','','.b-info'),(930209,'printshop','.b-info .info ul','margin-right','0','','','.b-info'),(930210,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-right','5','','','.b-messages'),(930211,'printshop','.w-filters .filter-ul-content','margin-right','0','','','.w-filters'),(930212,'printshop','.transit-icon','margin-right','3','3','',''),(930213,'printshop','.in-stock-icon','margin-right','3','3','',''),(930214,'printshop','.savings-ico .heading-2','margin-right','10','3','','.savings-ico'),(930215,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(930216,'printshop','.b-select-suggest .select2-drop-mask','margin-right','0','','','.b-select-suggest'),(930217,'printshop','.js-stock-icon','margin-right','3','3','',''),(930218,'printshop','.b-form .addresses .address-item input[type=\"radio\"]','margin-right','5','','','.b-form'),(930219,'printshop','.products-quick-index ul','margin-right','0','','',''),(930220,'printshop','.b-fancybox .fancybox-title-float-wrap .child','margin-right','-100','','','.b-fancybox'),(930221,'printshop','.w-top-categories .categories h2','margin-right','0','','','.w-top-categories'),(930222,'printshop','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(930223,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(930224,'printshop','.b-form .col-gender label','margin-right','20','','','.b-form'),(930225,'printshop','.w-socials .post_item_img','margin-right','10','','','.w-socials'),(930226,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(930227,'printshop','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(930228,'printshop','.w-product-quantity .qty_packs .price_1','margin-right','25','4','','.w-product-quantity'),(930229,'printshop','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(930230,'printshop','.b-select-suggest .select2-container.select2-allowclear .select2-choice .select2-chosen','margin-right','42','','','.b-select-suggest'),(930231,'printshop','.b-select-suggest .select2-container .select2-choice > .select2-chosen','margin-right','26','','','.b-select-suggest'),(930232,'printshop','.b-select-suggest .select2-container','margin-right','0','','','.b-select-suggest'),(930233,'printshop','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(930234,'printshop','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(930235,'printshop','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(930236,'printshop','.w-checkout-billing-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-billing-address'),(930237,'printshop','.b-info .info ul','margin-right','0','','','.b-info'),(930238,'printshop','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(930239,'printshop','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(930240,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(930241,'printshop','.b-info .info li','margin-right','0','','','.b-info'),(930242,'printshop','.b-form .radio-buttons .radio-button','margin-right','30','','','.b-form'),(930243,'printshop','.b-form .checkbox-style:checked + .checkbox-span','margin-right','5','','','.b-form'),(930244,'printshop','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(930245,'printshop','.w-menu-big ul','margin-right','0','','','.w-menu-big'),(930247,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(930248,'printshop','.w-checkout-billing-address .genders-title label','margin-right','20','','','.w-checkout-billing-address'),(930249,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(930250,'printshop','.b-autocomplete .ui-autocomplete','margin-right','0','','','.b-autocomplete'),(930251,'printshop','.w-cart-checkout-btn + .w-image','margin-right','0','','','.w-cart-checkout-btn'),(930252,'printshop','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(930253,'printshop','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(930254,'printshop','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(930255,'printshop','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(930256,'printshop','.b-select-suggest .select2-results .select2-result-label','margin-right','0','','','.b-select-suggest'),(930258,'printshop','.b-bottom .pop-up-content .buttons','margin-right','0','','','.b-bottom'),(930259,'printshop','.w-menu-big li','margin-right','0','','','.w-menu-big'),(930260,'printshop','.w-socials > li','margin-right','10','','','.w-socials'),(930261,'printshop','.b-fancybox .fancybox-error','margin-right','0','','','.b-fancybox'),(930262,'printshop','.w-cart-compare .product .image','margin-right','10','','','.w-cart-compare'),(930263,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(930264,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','margin-right','5','3','','.b-form'),(930265,'printshop','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-right','0','','','.b-switch'),(930266,'printshop','.b-bottom .confirm-popup .buttons .btn','margin-right','10','','','.b-bottom'),(930267,'printshop','.b-info .info ul','margin-right','0','','','.b-info'),(930268,'printshop','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(930269,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(930270,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(930271,'printshop','.w-cart-checkout-btn .or-text','margin-right','0','','','.w-cart-checkout-btn'),(930272,'printshop','.w-cart-give-away .ga_column','margin-right','2','','','.w-cart-give-away'),(930273,'printshop','.w-cart-compare .product-actions .dropdown-toggle','margin-right','8','3','','.w-cart-compare'),(930274,'printshop','.w-social-links a','margin-right','5','','','.w-social-links'),(930275,'printshop','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(930276,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-right','0','','','.b-select-suggest'),(930277,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-right','0','','','.b-select-suggest'),(930278,'printshop','.b-select-suggest .select2-container-multi .select2-choices','margin-right','0','','','.b-select-suggest'),(930279,'printshop','.b-select-suggest .select2-results ul.select2-result-sub','margin-right','0','','','.b-select-suggest'),(930280,'printshop','.b-select-suggest .select2-search input','margin-right','0','','','.b-select-suggest'),(930281,'printshop','.b-select-suggest .select2-search','margin-right','0','','','.b-select-suggest'),(930282,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(930285,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(930286,'printshop','.b-products-listing .products-listing .bonus-points-cost','margin-right','12','','','.b-products-listing'),(930289,'printshop','.w-account-addresses-list .address-fields input[type=\"radio\"]','margin-right','10','','','.w-account-addresses-list'),(930290,'printshop','.b-products-listing .products-listing .description ul','margin-right','0','','','.b-products-listing'),(930291,'printshop','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(930292,'printshop','.b-products-listing .products-listing .bonus-points-price','margin-right','10','','','.b-products-listing'),(930293,'printshop','.w-checkout-gdpr .privacy-row','margin-right','0','','','.w-checkout-gdpr'),(930294,'printshop','.b-compare .compare-box-btn','margin-right','20','','','.b-compare'),(930295,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(930296,'printshop','.w-socials > li','margin-right','10','','','.w-socials'),(930297,'printshop','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(930298,'printshop','.w-product-reviews .reviews-list','margin-right','0','','','.w-product-reviews'),(930300,'printshop','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(930301,'printshop','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(930302,'printshop','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(930303,'printshop','.w-taxable label','margin-right','5','','','.w-taxable'),(930304,'printshop','.w-taxable input[type=\"checkbox\"]','margin-right','5','','','.w-taxable'),(930305,'printshop','.w-taxable select','margin-right','0','','','.w-taxable'),(930306,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-right','0','','',''),(930307,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-right','0','','','.b-h-inline'),(930308,'printshop','.b-form .checkbox-style','margin-right','0','','','.b-form'),(930309,'printshop','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(930310,'printshop','.w-filters .open','margin-right','10','3','','.w-filters'),(930311,'printshop','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(930312,'printshop','.b-info .info li','margin-right','0','','','.b-info'),(930313,'printshop','.products-quick-index .token-input-list','margin-right','0','','',''),(930314,'printshop','.w-cart-give-away .ga_attributes > div','margin-right','1','','','.w-cart-give-away'),(930315,'printshop','.w-product-cross-sell .buy-all-checker','margin-right','5','','','.w-product-cross-sell'),(930316,'printshop','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(930317,'printshop','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','margin-right','10','3','','.w-cart-listing'),(930318,'printshop','.w-cart-give-away .ga_img','margin-right','2','','','.w-cart-give-away'),(930319,'printshop','.w-cart-give-away .ga_column','margin-right','0','5333','','.w-cart-give-away'),(930321,'printshop','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(930322,'printshop','.w-top-categories .categories','margin-right','0','5333','','.w-top-categories'),(930323,'printshop','.w-socials > li','margin-right','10','','','.w-socials'),(930324,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(930325,'printshop','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(930326,'printshop','.b-form .password-forgotten-link','margin-right','0','','','.b-form'),(930328,'printshop','.w-catalog-listing-look .listing-look-title','margin-right','10','','','.w-catalog-listing-look'),(930329,'printshop','.w-filters .input-checkbox','margin-right','0','','','.w-filters'),(930330,'printshop','.products-quick-index ul.token-input-list','margin-right','0','','',''),(930331,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(930332,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span','margin-right','5','','','.b-form'),(930333,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-right','0','','','.w-contact-contacts'),(930337,'printshop','.b-form .required-message','margin-right','0','','','.b-form'),(930338,'printshop','.w-filters .input-checkbox:not(checked) + .checkbox-span','margin-right','10','','','.w-filters'),(930339,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(930340,'printshop','.b-product-images .media-popup .slick-dots','margin-right','0','','','.b-product-images'),(930341,'printshop','.b-product-images .media-popup .slick-dots li','margin-right','5','','','.b-product-images'),(930342,'printshop','.b-product-images .media-popup button.slick-next:active','margin-right','-3','','','.b-product-images'),(930343,'printshop','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-right','0','','','.b-menu-style'),(930344,'printshop','.b-trade-approval .steps-bar','margin-right','0','','','.b-trade-approval'),(930345,'printshop','.w-account-personal-catalog .list-switcher','margin-right','0','','','.w-account-personal-catalog'),(930346,'printshop','.w-account-subscription .info-popup','margin-right','20','','','.w-account-subscription'),(930347,'printshop','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-right','0','','','.w-catalog-additional-images'),(930348,'printshop','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-right','0','','','.b-cookie-notice'),(930349,'printshop','.lowestPricedBox .w-banner .banner','margin-right','-15','','','.lowestPricedBox'),(930350,'printshop','.tripleBanner ','margin-right','-15','','','.tripleBanner'),(930351,'printshop','.b-products-listing .products-listing.list-productlisting .stock','margin-right','0','','','.b-products-listing'),(930352,'printshop','.shopByCollectionBox .w-banner .banner','margin-right','-15','','','.shopByCollectionBox'),(930353,'printshop','.preFooter .w-banner .single_banner','margin-right','2','','','.preFooter'),(930354,'printshop','.b-slick .slick-list','margin-right','0','','','.b-slick'),(930355,'printshop','.b-slick .slick-track','margin-right','auto','','','.b-slick'),(930356,'printshop','.LeftCategories .w-menu-simple ul','margin-right','0','','','.LeftCategories'),(930357,'printshop','.w-breadcrumb .breadcrumb-li','margin-right','0','','','.w-breadcrumb'),(930358,'printshop','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(930359,'printshop','.w-quote .multicart .name','margin-right','-10','','','.w-quote'),(930360,'printshop','.w-compare .compare-list-buttons','margin-right','-250','','','.w-compare'),(930361,'printshop','.w-sample .multicart .name','margin-right','-10','','','.w-sample'),(930362,'printshop','.w-filters-simple .system-1','margin-right','20','','','.w-filters-simple'),(930363,'printshop','.w-cart-discount-coupon input[type=\"text\"]','margin-right','10','','','.w-cart-discount-coupon'),(930364,'printshop','.w-cart-sub-total ','margin-right','0','','','.w-cart-sub-total'),(930365,'printshop','.shipping-ico .heading-3','margin-right','0','','','.shipping-ico'),(930366,'printshop','.order-summary .heading-2','margin-right','0','','','.order-summary'),(930367,'printshop','.w-cart-gift-certificate .heading-4','margin-right','0','','','.w-cart-gift-certificate'),(930368,'printshop','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(930369,'printshop','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(930370,'printshop','.w-product-inventory input[type=\"radio\"]','margin-right','5','','','.w-product-inventory'),(930371,'printshop','.b-bottom .cart-options .buttons','margin-right','0','','','.b-bottom'),(930373,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-right','0','','','.b-products-listing'),(930374,'printshop','.b-pagination ul.pagination','margin-right','0','','','.b-pagination'),(930375,'printshop','.w-product-quantity-discounts .item:nth-child(2n+1)','margin-right','2','','','.w-product-quantity-discounts'),(930376,'printshop','.w-product-quantity-discounts .item','margin-right','0','5342','','.w-product-quantity-discounts'),(930377,'printshop','.w-product-properties-filters-widgets-chosen-filters .item','margin-right','5','','','.w-product-properties-filters-widgets-chosen-filters'),(930378,'printshop','.p-sample-checkout-index .order-summary .heading-2','margin-right','0','3','','.p-sample-checkout-index'),(930379,'printshop','.p-sample-checkout-index .order-summary .heading-2','margin-right','-100','4','','.p-sample-checkout-index'),(930380,'printshop','.w-account-personal-catalog .list-row-action ul','margin-right','-1','','','.w-account-personal-catalog'),(930381,'printshop','.w-account-personal-catalog .list-row-action li','margin-right','0','','','.w-account-personal-catalog'),(930382,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','margin-right','20','','','.w-account-personal-catalog'),(930383,'printshop','.w-product-properties .property-ul','margin-right','0','','','.w-product-properties'),(930384,'printshop','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(930385,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','margin-right','30','','','.w-questionnaire-widgets-questionnaire'),(930386,'printshop','.b-products-listing .mix-attributes .mult-qty-input .qty-box > input','margin-right','3','','','.b-products-listing'),(930387,'printshop','.b-products-listing .products-listing .attribute-color','margin-right','4','','','.b-products-listing'),(930388,'printshop','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','margin-right','10','3','','.w-product-custom-bundle'),(930389,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list'),(930390,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list-block'),(930391,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(930392,'printshop','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(930393,'printshop','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(930394,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin-right','0','5333','','.w-delivery-location-top-location-list'),(930395,'printshop','.w-delivery-location-featured-list .deliveryList ul','margin-right','0','','','.w-delivery-location-featured-list'),(930396,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(930397,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(930398,'printshop','.w-delivery-location-list-by-page .description ul','margin-right','0','','','.w-delivery-location-list-by-page'),(930399,'printshop','.w-delivery-location-list-by-page .item','margin-right','1','','','.w-delivery-location-list-by-page'),(930400,'printshop','.w-delivery-location-list-by-page .item','margin-right','0','5363','','.w-delivery-location-list-by-page'),(930401,'printshop','.w-delivery-location-cross-pages .description ul','margin-right','0','','','.w-delivery-location-cross-pages'),(930402,'printshop','.w-delivery-location-cross-pages .item','margin-right','1','','','.w-delivery-location-cross-pages'),(930403,'printshop','.w-delivery-location-cross-pages .item','margin-right','0','5363','','.w-delivery-location-cross-pages'),(930404,'printshop','.w-catalog-delivery-locations .item','margin-right','1','','','.w-catalog-delivery-locations'),(930405,'printshop','.w-catalog-delivery-locations .description ul','margin-right','0','','','.w-catalog-delivery-locations'),(930406,'printshop','.w-catalog-delivery-locations .item','margin-right','0','5333','','.w-catalog-delivery-locations'),(930407,'printshop','.w-product-bonus-points .bonus-points-cost','margin-right','12','','','.w-product-bonus-points'),(930408,'printshop','.w-product-designer-designer .prodDesignerType label','margin-right','10','','','.w-product-designer-designer'),(930409,'printshop','.w-press-reviews-widgets-press-reviews .date','margin-right','0','5333','','.w-press-reviews-widgets-press-reviews'),(930410,'printshop','.w-press-reviews-widgets-press-reviews-list .image','margin-right','0','','','.w-press-reviews-widgets-press-reviews-list'),(930411,'printshop','.w-press-reviews-widgets-press-reviews-list .item','margin-right','0','','','.w-press-reviews-widgets-press-reviews-list'),(930412,'printshop','.w-press-reviews-widgets-press-reviews-list .review-box > *','margin-right','30','','','.w-press-reviews-widgets-press-reviews-list'),(930413,'printshop','.w-press-reviews-widgets-press-reviews-list .review-box > *','margin-right','0','5363','','.w-press-reviews-widgets-press-reviews-list'),(930414,'printshop','.w-gift-wrap-message-checkout .max-counter, .w-gift-wrap-message-checkout .max-words','margin-right','20','','','.w-gift-wrap-message-checkout'),(930415,'printshop','.w-gift-wrap-message-checkout .text','margin-right','20','','','.w-gift-wrap-message-checkout'),(930416,'printshop','.w-support-system-filter .filter_cats','margin-right','0','','','.w-support-system-filter'),(930417,'printshop','.w-support-system-listing .product_icon','margin-right','20','','','.w-support-system-listing'),(930418,'printshop','.w-rma-returns-history .filterMessages','margin-right','-3','','','.w-rma-returns-history'),(930419,'printshop','.w-rma-returns-history label[for=\'sCreateFrom\']','margin-right','5','','','.w-rma-returns-history'),(930420,'printshop','.w-rma-returns-history .column:last-child .title','margin-right','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(930421,'printshop','.w-show-inactive-show-inactive .out_stock_label','margin-right','10','','','.w-show-inactive-show-inactive'),(930422,'printshop','.w-product-designer-button label > input[type=\"checkbox\"]','margin-right','7','','','.w-product-designer-button'),(930423,'printshop','.w-product-designer-designer .productDesignerBox ul','margin-right','0','','','.w-product-designer-designer'),(930424,'printshop','.w-product-configurator .pc-item','margin-right','0','','','.w-product-configurator'),(930425,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-list'),(930426,'printshop','.w-predefined-promotion .icon','margin-right','15','','','.w-predefined-promotion'),(930427,'printshop','.w-predefined-promotion .nextdiscount .heading','margin-right','10','3','','.w-predefined-promotion'),(930428,'printshop','.w-predefined-promotion .prom-multi-discount > .heading','margin-right','5','3','','.w-predefined-promotion'),(930429,'printshop','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','margin-right','5','3','','.w-predefined-promotion'),(930430,'printshop','.w-predefined-promotion .promo-cart-discount .master .item','margin-right','12','','','.w-predefined-promotion'),(930431,'printshop','.w-predefined-promotion .promo-cart-discount .slave .item','margin-right','2','','','.w-predefined-promotion'),(930432,'printshop','.w-predefined-promotion .promo-salemaker .item','margin-right','2','','','.w-predefined-promotion'),(930433,'printshop','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','margin-right','5','3','','.w-predefined-promotion'),(930434,'printshop','.w-supplier-purchase-supplier-products .select_item','margin-right','20','','','.w-supplier-purchase-supplier-products'),(930435,'printshop','.w-supplier-purchase-supplier-products .name','margin-right','20','','','.w-supplier-purchase-supplier-products'),(930436,'printshop','.w-supplier-purchase-supplier-products .col-full','margin-right','20','','','.w-supplier-purchase-supplier-products'),(930438,'printshop','.w-product-model ','margin-right','0','','','.w-product-model'),(930439,'printshop','.w-cart-listing .remove-btn','margin-right','2','3','','.w-cart-listing'),(930444,'printshop','.b-bottom .confirm-popup .buttons .btn','margin-right','0','5333','','.b-bottom'),(930445,'printshop','.w-compare .compare-list-buttons','margin-right','0','5342','','.w-compare'),(930446,'printshop','.topBanner .ourPick','margin-right','35','','','.topBanner'),(930447,'printshop','.w-promotions-widgets-promotion-icons-desc .promo-icon','margin-right','7','','','.w-promotions-widgets-promotion-icons-desc'),(930448,'printshop','.p-quote-checkout-index .comment-ico','margin-right','20','3','','.p-quote-checkout-index'),(930449,'printshop','.p-quote-checkout-index .pay-ico','margin-right','20','3','','.p-quote-checkout-index'),(930450,'printshop','.p-quote-checkout-index .ship-ico','margin-right','20','3','','.p-quote-checkout-index'),(930451,'printshop','.account-address-book .address_book .row-buttons a','margin-right','10','','','.account-address-book'),(930452,'printshop','.account-address-book .address_book h1','margin-right','0','','','.account-address-book'),(930453,'printshop','.account-address-book .address_book h2','margin-right','0','','','.account-address-book'),(930454,'printshop','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-right','0','','','.account-address-book'),(930455,'printshop','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-right','2','','','.account-address-book'),(930456,'printshop','.account-address-book .address_book_row h2 a','margin-right','0','','','.account-address-book'),(930457,'printshop','.account-address-book .buttonBox .info','margin-right','25','','','.account-address-book'),(930458,'printshop','.account-address-book .address_book_row .column','margin-right','0','5333','','.account-address-book'),(930459,'printshop','.account-address-book .address_book_row .column + .column','margin-right','0','5333','','.account-address-book'),(930460,'printshop','.account-address-book .topInfo > div','margin-right','0','5333','','.account-address-book'),(930461,'printshop','.account-address-book .topInfo > div + div','margin-right','0','5333','','.account-address-book'),(930473,'printshop','.account-order-pay .buttons','margin-right','0','','','.account-order-pay'),(930474,'printshop','.account-order-pay .history_info','margin-right','0','','','.account-order-pay'),(930475,'printshop','.account-order-pay .history_info > div','margin-right','0','5342','','.account-order-pay'),(930476,'printshop','.account-password-wrap .buttonedit','margin-right','0','','','.account-password-wrap'),(930477,'printshop','.account-samples .buttonBox','margin-right','0','','','.account-samples'),(930478,'printshop','.account-samples .order_history_table h2','margin-right','0','','','.account-samples'),(930479,'printshop','.account-sample-info .buttons','margin-right','0','','','.account-sample-info'),(930480,'printshop','.account-sample-info .history_info','margin-right','0','','','.account-sample-info'),(930481,'printshop','.account-sample-info .history_info > div','margin-right','0','5342','','.account-sample-info'),(930482,'printshop','.shopping-cart-index .closeable-heading .heading-2','margin-right','0','','','.shopping-cart-index'),(930483,'printshop','.checkout-index-wrap .comment-ico','margin-right','20','3','','.checkout-index-wrap'),(930484,'printshop','.checkout-index-wrap .pay-ico','margin-right','20','3','','.checkout-index-wrap'),(930485,'printshop','.checkout-index-wrap .ship-ico','margin-right','20','3','','.checkout-index-wrap'),(930486,'printshop','.checkout-order-confirmation .comment-ico','margin-right','20','3','','.checkout-order-confirmation'),(930487,'printshop','.checkout-order-confirmation .discount-ico','margin-right','10','3','','.checkout-order-confirmation'),(930488,'printshop','.checkout-order-confirmation .pay-ico','margin-right','20','3','','.checkout-order-confirmation'),(930489,'printshop','.checkout-order-confirmation .ship-ico','margin-right','20','3','','.checkout-order-confirmation'),(930490,'printshop','.b-slick .slick-dots li','margin-right','5','','','.b-slick'),(930492,'printshop','.success-page .comment-ico','margin-right','10','3','','.success-page'),(930493,'printshop','.success-page .discount-ico','margin-right','10','3','','.success-page'),(930494,'printshop','.success-page .order-ico','margin-right','10','3','','.success-page'),(930495,'printshop','.success-page .page-success .text-1','margin-right','10','3','','.success-page'),(930496,'printshop','.success-page .pay-ico','margin-right','10','3','','.success-page'),(930497,'printshop','.success-page .prod-ico','margin-right','10','3','','.success-page'),(930498,'printshop','.success-page .ship-ico','margin-right','10','3','','.success-page'),(930499,'printshop','.b-multi-page-checkout .multi-page-checkout .buttons','margin-right','0','','','.b-multi-page-checkout'),(930500,'printshop','.doubleBanner .w-banner .banner-holder','margin-right','-15','','','.doubleBanner'),(930501,'printshop','.bottomDoubleBanner .w-banner .banner-holder','margin-right','-15','','','.bottomDoubleBanner'),(930502,'printshop','.footer-menu .level-1 > li','margin-right','20','5342','','.footer-menu'),(930503,'printshop','.footer-menu .level-1 > li','margin-right','0','5333','','.footer-menu'),(930504,'printshop','.w-bestsellers .counter','margin-right','15','','','.w-bestsellers'),(930505,'printshop','.accout-box select[data-type=\"vat_number\"]','margin-right','0','','','.accout-box'),(930506,'printshop','.w-catalog-paging .prev','margin-right','5','','','.w-catalog-paging'),(930507,'printshop','.b-bottom .cart-options .buttons','margin-right_important','important','','','.b-bottom'),(930508,'printshop','.w-product-quantity-discounts .item','margin-right_important','important','5342','','.w-product-quantity-discounts'),(930509,'printshop','.b-info .info ul','margin-top','0','','','.b-info'),(930510,'printshop','.b-info .info li','margin-top','0','','','.b-info'),(930511,'printshop','.b-info .info ul','margin-top','0','','','.b-info'),(930512,'printshop','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-top','0','','','.b-switch'),(930513,'printshop','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(930514,'printshop','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(930515,'printshop','.w-catalog-items-on-page select','margin-top','0','','','.w-catalog-items-on-page'),(930516,'printshop','.p-quick-order-index ul.token-input-list','margin-top','0','','','.p-quick-order-index'),(930517,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(930521,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(930522,'printshop','.w-promotions .promo-salemaker .item','margin-top','2','','','.w-promotions'),(930523,'printshop','.w-promotions .promo-salemaker .content','margin-top','-18','','','.w-promotions'),(930524,'printshop','.w-promotions .promo-cart-discount .slave .item','margin-top','2','','','.w-promotions'),(930525,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-top','0','','','.b-warehouses-popup'),(930527,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(930528,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(930529,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(930530,'printshop','.b-messages .messages-menu ul','margin-top','0','','','.b-messages'),(930531,'printshop','.b-messages .msv_content','margin-top','15','','','.b-messages'),(930532,'printshop','.b-messages .msv_btn','margin-top','10','','','.b-messages'),(930533,'printshop','.b-messages .msv_history','margin-top','15','','','.b-messages'),(930534,'printshop','.b-messages .messages-menu li','margin-top','0','','','.b-messages'),(930535,'printshop','.w-sitemap-delivery-location > ul > li > ul','margin-top','0','','','.w-sitemap-delivery-location'),(930536,'printshop','.w-tabs .tab-navigation','margin-top','0','','','.w-tabs'),(930537,'printshop','.w-socials > li','margin-top','10','','','.w-socials'),(930538,'printshop','.b-form .g-recaptcha','margin-top','10','','','.b-form'),(930539,'printshop','.w-sitemap-delivery-location > ul','margin-top','0','','','.w-sitemap-delivery-location'),(930540,'printshop','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(930541,'printshop','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(930542,'printshop','.b-info .info','margin-top','-8','3','','.b-info'),(930543,'printshop','.b-fancybox #fancybox-loading','margin-top','-22','','','.b-fancybox'),(930544,'printshop','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(930545,'printshop','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(930546,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-template .btn','margin-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(930547,'printshop','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(930548,'printshop','.b-info .info ul','margin-top','0','','','.b-info'),(930549,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(930550,'printshop','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(930551,'printshop','.w-menu-horizontal ul','margin-top','0','','','.w-menu-horizontal'),(930552,'printshop','.w-menu-horizontal li','margin-top','0','','','.w-menu-horizontal'),(930553,'printshop','.b-form .password-forgotten-link','margin-top','0','','','.b-form'),(930554,'printshop','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(930555,'printshop','.b-info .info li','margin-top','0','','','.b-info'),(930556,'printshop','.b-info .info li','margin-top','0','','','.b-info'),(930557,'printshop','.b-form .privacy-row','margin-top','10','','','.b-form'),(930558,'printshop','.b-fancybox .fancybox-title-outside-wrap','margin-top','10','','','.b-fancybox'),(930559,'printshop','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(930560,'printshop','.b-info .info','margin-top','-8','3','','.b-info'),(930561,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(930562,'printshop','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(930563,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(930565,'printshop','.w-socials > li','margin-top','10','','','.w-socials'),(930566,'printshop','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(930568,'printshop','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(930569,'printshop','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(930570,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(930571,'printshop','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(930572,'printshop','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-top','0','','','.b-fancybox'),(930573,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-top','0','','','.b-select-suggest'),(930574,'printshop','.w-socials > li','margin-top','10','','','.w-socials'),(930576,'printshop','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(930577,'printshop','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(930578,'printshop','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(930579,'printshop','.w-cart-give-away .ga_attributes > div','margin-top','1','','','.w-cart-give-away'),(930580,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(930581,'printshop','.w-multi-cart-cart-switcher .cart-label','margin-top','-20','','','.w-multi-cart-cart-switcher'),(930582,'printshop','.w-tabs .tab-li','margin-top','0','','','.w-tabs'),(930583,'printshop','.w-socials > li','margin-top','10','','','.w-socials'),(930584,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(930585,'printshop','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(930586,'printshop','.b-form .required-message-wrap','margin-top','0','','','.b-form'),(930587,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(930588,'printshop','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(930589,'printshop','.b-delete-account .delete-box span','margin-top','10','','','.b-delete-account'),(930590,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-top','0','','','.b-messages'),(930591,'printshop','.w-filters .filter-ul-content','margin-top','0','','','.w-filters'),(930592,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(930593,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(930594,'printshop','.p-quick-order-index .dataTables_info','margin-top','5','','','.p-quick-order-index'),(930595,'printshop','.b-select-suggest .select2-drop-mask','margin-top','0','','','.b-select-suggest'),(930596,'printshop','.products-quick-index ul','margin-top','0','','',''),(930597,'printshop','.w-top-categories .categories h2','margin-top','0','','','.w-top-categories'),(930598,'printshop','.b-autocomplete .ui-autocomplete','margin-top','0','','','.b-autocomplete'),(930599,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(930600,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(930601,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(930602,'printshop','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(930603,'printshop','.w-product-quantity .qty_packs .price_1','margin-top','0','4','','.w-product-quantity'),(930604,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(930605,'printshop','.b-select-suggest .select2-container','margin-top','0','','','.b-select-suggest'),(930606,'printshop','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(930607,'printshop','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(930608,'printshop','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(930609,'printshop','.b-info .info','margin-top','-8','3','','.b-info'),(930610,'printshop','.b-info .info li','margin-top','0','','','.b-info'),(930611,'printshop','.b-info .info ul','margin-top','0','','','.b-info'),(930612,'printshop','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(930613,'printshop','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(930614,'printshop','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(930615,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(930616,'printshop','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(930618,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(930619,'printshop','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-top','0','','','.b-fancybox'),(930620,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(930621,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(930622,'printshop','.b-info .info ul','margin-top','0','','','.b-info'),(930623,'printshop','.w-top-categories .categories','margin-top','0','5333','','.w-top-categories'),(930624,'printshop','.w-cart-checkout-btn .or-text','margin-top','-5','','','.w-cart-checkout-btn'),(930625,'printshop','.w-promotions .promo-cart-discount .master .item','margin-top','12','','','.w-promotions'),(930626,'printshop','.w-promotions .promo-cart-discount .master .image','margin-top','-16','','','.w-promotions'),(930627,'printshop','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(930628,'printshop','.b-select-suggest .select2-results .select2-result-label','margin-top','0','','','.b-select-suggest'),(930629,'printshop','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(930630,'printshop','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(930631,'printshop','.b-info .info','margin-top','-8','3','','.b-info'),(930632,'printshop','.b-form .required-message','margin-top','0','','','.b-form'),(930633,'printshop','.b-bottom .pop-up-content .buttons','margin-top','15','','','.b-bottom'),(930635,'printshop','.w-menu-big ul','margin-top','0','','','.w-menu-big'),(930636,'printshop','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(930637,'printshop','.b-fancybox .fancybox-error','margin-top','0','','','.b-fancybox'),(930638,'printshop','.b-info .info li','margin-top','0','','','.b-info'),(930639,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','margin-top','0','','','.b-switch'),(930640,'printshop','.w-cart-compare .product .image','margin-top','0','','','.w-cart-compare'),(930641,'printshop','.b-fancybox .fancybox-nav span','margin-top','-18','','','.b-fancybox'),(930642,'printshop','.b-info .info','margin-top','-8','3','','.b-info'),(930643,'printshop','.w-product-customers-activity .buttons','margin-top','10','','','.w-product-customers-activity'),(930644,'printshop','.b-bottom .confirm-popup .buttons .btn','margin-top','10','','','.b-bottom'),(930645,'printshop','.b-info .info li','margin-top','0','','','.b-info'),(930646,'printshop','.b-info .info ul','margin-top','0','','','.b-info'),(930647,'printshop','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(930648,'printshop','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(930649,'printshop','.w-menu-big li','margin-top','0','','','.w-menu-big'),(930650,'printshop','.w-cart-checkout-btn + .w-image','margin-top','0','','','.w-cart-checkout-btn'),(930651,'printshop','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(930652,'printshop','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(930653,'printshop','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(930654,'printshop','.w-social-links a','margin-top','0','','','.w-social-links'),(930655,'printshop','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(930656,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-top','1','','','.b-select-suggest'),(930657,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-top','0','','','.b-select-suggest'),(930658,'printshop','.b-select-suggest .select2-container-multi .select2-choices','margin-top','0','','','.b-select-suggest'),(930659,'printshop','.b-select-suggest .select2-results ul.select2-result-sub','margin-top','0','','','.b-select-suggest'),(930660,'printshop','.w-checkout-shipping-address .change-ab','margin-top','5','','','.w-checkout-shipping-address'),(930661,'printshop','.w-checkout-contact-information .contact-info-buttons','margin-top','5','','','.w-checkout-contact-information'),(930662,'printshop','.b-select-suggest .select2-drop.select2-drop-above .select2-search input','margin-top','4','','','.b-select-suggest'),(930663,'printshop','.b-select-suggest .select2-search input','margin-top','0','','','.b-select-suggest'),(930664,'printshop','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(930665,'printshop','.b-select-suggest .select2-search','margin-top','0','','','.b-select-suggest'),(930666,'printshop','.b-select-suggest .select2-drop.select2-drop-above','margin-top','1','','','.b-select-suggest'),(930667,'printshop','.b-select-suggest .select2-drop','margin-top','-1','','','.b-select-suggest'),(930668,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(930670,'printshop','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(930673,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(930674,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(930675,'printshop','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(930676,'printshop','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(930679,'printshop','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(930680,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','margin-top','0','','','.w-contact-contacts'),(930681,'printshop','.b-products-listing .products-listing .description ul','margin-top','0','','','.b-products-listing'),(930682,'printshop','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(930683,'printshop','.w-checkout-gdpr .privacy-row','margin-top','0','','','.w-checkout-gdpr'),(930684,'printshop','.w-checkout-gdpr .bootstrap-switch','margin-top','0','','','.w-checkout-gdpr'),(930685,'printshop','.b-form .checkbox-style','margin-top','0','','','.b-form'),(930686,'printshop','.b-form .wedding-form .heading-2','margin-top','10','','','.b-form'),(930687,'printshop','.w-product-reviews .reviews-list','margin-top','10','','','.w-product-reviews'),(930688,'printshop','.w-taxable label','margin-top','0','','','.w-taxable'),(930689,'printshop','.w-taxable select','margin-top','0','','','.w-taxable'),(930690,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-top','0','','',''),(930691,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-top','0','','','.b-h-inline'),(930692,'printshop','.w-communication-new-topic .files-box','margin-top','50','','','.w-communication-new-topic'),(930693,'printshop','.b-form .addresses .address-item input[type=\"radio\"]','margin-top','0','','','.b-form'),(930694,'printshop','.w-top-categories .categories','margin-top','0','5347','','.w-top-categories'),(930695,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(930696,'printshop','.products-quick-index .token-input-list','margin-top','0','','',''),(930697,'printshop','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(930698,'printshop','.b-info .info','margin-top','-8','3','','.b-info'),(930699,'printshop','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(930700,'printshop','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(930701,'printshop','.w-cart-listing .points-redeem','margin-top','-2','3','','.w-cart-listing'),(930703,'printshop','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(930704,'printshop','.w-socials > li','margin-top','10','','','.w-socials'),(930705,'printshop','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(930707,'printshop','.w-filters .ui-slider','margin-top','5','','','.w-filters'),(930708,'printshop','.w-checkout-billing-address .bootstrap-switch','margin-top','-2','','','.w-checkout-billing-address'),(930709,'printshop','.w-socials .post_item_img','margin-top','0','','','.w-socials'),(930710,'printshop','.w-socials > li','margin-top','10','','','.w-socials'),(930711,'printshop','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(930712,'printshop','.w-filters .input-checkbox','margin-top','0','','','.w-filters'),(930713,'printshop','.products-quick-index ul.token-input-list','margin-top','0','','',''),(930714,'printshop','.message.success','margin-top','-8','3','',''),(930717,'printshop','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(930718,'printshop','.b-product-images .media-popup .slick-dots','margin-top','0','','','.b-product-images'),(930719,'printshop','.b-product-images .media-popup .slick-dots li','margin-top','0','','','.b-product-images'),(930720,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','margin-top','-50','','','.b-product-images'),(930721,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(930722,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-top','-44','','','.b-menu-lev_vis-click_icon'),(930723,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(930724,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(930725,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(930726,'printshop','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-top','0','','','.b-menu-style'),(930727,'printshop','.b-trade-approval .steps-bar','margin-top','0','','','.b-trade-approval'),(930728,'printshop','.w-account-personal-catalog .list-switcher','margin-top','0','','','.w-account-personal-catalog'),(930729,'printshop','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-top','0','','','.w-catalog-additional-images'),(930730,'printshop','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-top','0','','','.b-cookie-notice'),(930731,'printshop','.lowestPricedBox .w-banner .banner','margin-top','0','','','.lowestPricedBox'),(930732,'printshop','.tripleBanner ','margin-top','0','','','.tripleBanner'),(930733,'printshop','.shopByCollectionBox .w-banner .banner','margin-top','0','','','.shopByCollectionBox'),(930734,'printshop','.preFooter .w-banner .single_banner','margin-top','0','','','.preFooter'),(930735,'printshop','.b-slick .slick-list','margin-top','0','','','.b-slick'),(930736,'printshop','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-top','0','','','.b-slick'),(930737,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','margin-top','-20','','','.b-slick'),(930738,'printshop','.tripleBanner > .block','margin-top','10','5342','','.tripleBanner'),(930739,'printshop','.LeftCategories .w-menu-simple ul','margin-top','0','','','.LeftCategories'),(930740,'printshop','.w-breadcrumb .breadcrumb-li','margin-top','0','','','.w-breadcrumb'),(930741,'printshop','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(930742,'printshop','.w-quote .multicart .name','margin-top','0','','','.w-quote'),(930743,'printshop','.warrantyProduct .warranty','margin-top','-16','3','','.warrantyProduct'),(930744,'printshop','.warrantyProduct .delivery','margin-top','-15','3','','.warrantyProduct'),(930745,'printshop','.w-sample .cart-box-link','margin-top','-5','4','','.w-sample'),(930746,'printshop','.w-sample .multicart .name','margin-top','0','','','.w-sample'),(930747,'printshop','.w-cart-sub-total ','margin-top','0','','','.w-cart-sub-total'),(930748,'printshop','.shipping-ico .heading-3','margin-top','0','','','.shipping-ico'),(930749,'printshop','.order-summary .heading-2','margin-top','0','','','.order-summary'),(930750,'printshop','.w-cart-gift-certificate .heading-4','margin-top','0','','','.w-cart-gift-certificate'),(930751,'printshop','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(930752,'printshop','.w-product-bundle .bundle_price','margin-top','-5','','','.w-product-bundle'),(930753,'printshop','.b-bottom .cart-options .buttons','margin-top','10','','','.b-bottom'),(930754,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-top','0','','','.b-products-listing'),(930755,'printshop','.b-pagination ul.pagination','margin-top','0','','','.b-pagination'),(930756,'printshop','.w-product-quantity-discounts .item','margin-top','0','5342','','.w-product-quantity-discounts'),(930757,'printshop','.w-product-properties-filters-widgets-chosen-filters .item','margin-top','0','','','.w-product-properties-filters-widgets-chosen-filters'),(930759,'printshop','.w-account-personal-catalog .list-row-action ul','margin-top','-1','','','.w-account-personal-catalog'),(930760,'printshop','.w-account-personal-catalog .list-row-action li','margin-top','0','','','.w-account-personal-catalog'),(930761,'printshop','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(930762,'printshop','.w-product-properties .property-ul','margin-top','0','','','.w-product-properties'),(930763,'printshop','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(930764,'printshop','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(930765,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list'),(930766,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list-block'),(930767,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(930768,'printshop','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(930769,'printshop','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(930770,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','5333','','.w-delivery-location-top-location-list'),(930771,'printshop','.w-delivery-location-featured-list .deliveryList ul','margin-top','0','','','.w-delivery-location-featured-list'),(930772,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(930773,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(930774,'printshop','.w-delivery-location-list-by-page .description ul','margin-top','5','','','.w-delivery-location-list-by-page'),(930775,'printshop','.w-delivery-location-list-by-page .item','margin-top','0','','','.w-delivery-location-list-by-page'),(930776,'printshop','.w-delivery-location-list-by-page .item','margin-top','10','5363','','.w-delivery-location-list-by-page'),(930777,'printshop','.w-delivery-location-cross-pages .description ul','margin-top','5','','','.w-delivery-location-cross-pages'),(930778,'printshop','.w-delivery-location-cross-pages .item','margin-top','0','','','.w-delivery-location-cross-pages'),(930779,'printshop','.w-delivery-location-cross-pages .item','margin-top','10','5363','','.w-delivery-location-cross-pages'),(930780,'printshop','.w-catalog-delivery-locations .item','margin-top','0','','','.w-catalog-delivery-locations'),(930781,'printshop','.w-catalog-delivery-locations .description ul','margin-top','5','','','.w-catalog-delivery-locations'),(930782,'printshop','.w-catalog-delivery-locations .item','margin-top','0','5333','','.w-catalog-delivery-locations'),(930783,'printshop','.w-product-designer-designer .prodDesignerType label','margin-top','10','','','.w-product-designer-designer'),(930784,'printshop','.w-press-reviews-widgets-press-reviews .date','margin-top','10','5333','','.w-press-reviews-widgets-press-reviews'),(930785,'printshop','.w-press-reviews-widgets-press-reviews-list .image','margin-top','0','','','.w-press-reviews-widgets-press-reviews-list'),(930786,'printshop','.w-press-reviews-widgets-press-reviews-list .item','margin-top','10','','','.w-press-reviews-widgets-press-reviews-list'),(930787,'printshop','.w-support-system-filter .filter_cats','margin-top','0','','','.w-support-system-filter'),(930788,'printshop','.w-rma-returns-history .content-messages .messages-table .bottom','margin-top','10','','','.w-rma-returns-history'),(930789,'printshop','.w-rma-returns-history .content-messages .messages-table .top','margin-top','10','','','.w-rma-returns-history'),(930790,'printshop','.w-rma-returns-history .filterMessages','margin-top','0','','','.w-rma-returns-history'),(930791,'printshop','.w-rma-returns-history .column:last-child .title','margin-top','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(930792,'printshop','.w-product-designer-designer .productDesignerBox ul','margin-top','0','','','.w-product-designer-designer'),(930793,'printshop','.w-product-configurator .pc-item','margin-top','0','','','.w-product-configurator'),(930794,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-list'),(930795,'printshop','.w-predefined-promotion .promo-cart-discount .master .image','margin-top','-16','','','.w-predefined-promotion'),(930796,'printshop','.w-predefined-promotion .promo-cart-discount .master .item','margin-top','12','','','.w-predefined-promotion'),(930797,'printshop','.w-predefined-promotion .promo-cart-discount .slave .item','margin-top','2','','','.w-predefined-promotion'),(930798,'printshop','.w-predefined-promotion .promo-salemaker .content','margin-top','-18','','','.w-predefined-promotion'),(930799,'printshop','.w-predefined-promotion .promo-salemaker .item','margin-top','2','','','.w-predefined-promotion'),(930800,'printshop','.w-product-model ','margin-top','0','','','.w-product-model'),(930801,'printshop','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(930802,'printshop','.b-bottom .confirm-popup .buttons .btn','margin-top','10','5333','','.b-bottom'),(930803,'printshop','.topBanner .ourPick','margin-top','-20','3','','.topBanner'),(930804,'printshop','.topBanner .ourPick','margin-top','-20','4','','.topBanner'),(930805,'printshop','.topBanner .ourPick','margin-top','0','','','.topBanner'),(930806,'printshop','.topBanner .ourPick','margin-top','-14','5347,3','','.topBanner'),(930807,'printshop','.topBanner .ourPick','margin-top','-14','5347,4','','.topBanner'),(930808,'printshop','.topBanner .ourPick','margin-top','-9','5363,3','','.topBanner'),(930809,'printshop','.topBanner .ourPick','margin-top','-9','5363,4','','.topBanner'),(930810,'printshop','.w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp','margin-top','10','','','.w-cart-discount-coupon'),(930811,'printshop','.p-quote-checkout-index .dob-hide','margin-top','20','','','.p-quote-checkout-index'),(930812,'printshop','.account-address-book .address_book .row-buttons a','margin-top','0','','','.account-address-book'),(930813,'printshop','.account-address-book .address_book h1','margin-top','0','','','.account-address-book'),(930814,'printshop','.account-address-book .address_book h2','margin-top','0','','','.account-address-book'),(930815,'printshop','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-top','0','','','.account-address-book'),(930816,'printshop','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-top','0','','','.account-address-book'),(930817,'printshop','.account-address-book .address_book_row h2 a','margin-top','0','','','.account-address-book'),(930818,'printshop','.account-address-book .buttonBox .info','margin-top','0','','','.account-address-book'),(930819,'printshop','.account-address-book .address_book_row .column','margin-top','0','5333','','.account-address-book'),(930820,'printshop','.account-address-book .address_book_row .column + .column','margin-top','0','5333','','.account-address-book'),(930821,'printshop','.account-address-book .topInfo > div','margin-top','0','5333','','.account-address-book'),(930822,'printshop','.account-address-book .topInfo > div + div','margin-top','0','5333','','.account-address-book'),(930838,'printshop','.account-order-pay .buttons','margin-top','20','','','.account-order-pay'),(930839,'printshop','.account-order-pay .history_info','margin-top','0','','','.account-order-pay'),(930840,'printshop','.account-order-pay .history_info > div','margin-top','0','5342','','.account-order-pay'),(930841,'printshop','.account-password-wrap .buttonedit','margin-top','-40','','','.account-password-wrap'),(930842,'printshop','.account-password-wrap .buttons','margin-top','-70','','','.account-password-wrap'),(930843,'printshop','.account-samples .buttonBox','margin-top','15','','','.account-samples'),(930844,'printshop','.account-samples .order_history_table h2','margin-top','0','','','.account-samples'),(930845,'printshop','.account-sample-info .buttons','margin-top','20','','','.account-sample-info'),(930846,'printshop','.account-sample-info .history_info','margin-top','0','','','.account-sample-info'),(930847,'printshop','.account-sample-info .popup-tracking-number-link','margin-top','10','','','.account-sample-info'),(930848,'printshop','.account-sample-info .history_info > div','margin-top','0','5342','','.account-sample-info'),(930849,'printshop','.shopping-cart-index .closeable-heading .heading-2','margin-top','0','','','.shopping-cart-index'),(930850,'printshop','.checkout-index-wrap .dob-hide','margin-top','20','','','.checkout-index-wrap'),(930851,'printshop','.b-slick .slick-dots li','margin-top','0','','','.b-slick'),(930852,'printshop','.success-page .page-success .text-1','margin-top','0','3','','.success-page'),(930853,'printshop','.success-page .totals-line','margin-top','10','','','.success-page'),(930854,'printshop','.b-multi-page-checkout .multi-page-checkout .buttons','margin-top','0','','','.b-multi-page-checkout'),(930855,'printshop','.doubleBanner .w-banner .banner-holder','margin-top','0','','','.doubleBanner'),(930856,'printshop','.bottomDoubleBanner .w-banner .banner-holder','margin-top','0','','','.bottomDoubleBanner'),(930857,'printshop','.footer-menu .level-2 > li.component-item','margin-top','20','','','.footer-menu'),(930858,'printshop','.accout-box select[data-type=\"vat_number\"]','margin-top','0','','','.accout-box'),(930859,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top','0','','','.w-catalog-paging'),(930862,'printshop','.b-bottom .cart-options .buttons','margin-top_important','important','','','.b-bottom'),(930863,'printshop','.w-product-quantity-discounts .item','margin-top_important','important','5342','','.w-product-quantity-discounts'),(930864,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top_important','important','','','.w-catalog-paging'),(930865,'printshop','.p-quick-order-index ul.token-input-list','margin_bottom_measure','pt','','','.p-quick-order-index'),(930866,'printshop','.w-cart-give-away .ga_attributes > div','margin_bottom_measure','%','','','.w-cart-give-away'),(930867,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(930868,'printshop','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(930869,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','5333','','.w-delivery-location-top-location-list'),(930870,'printshop','.p-quick-order-index ul.token-input-list','margin_left_measure','pt','','','.p-quick-order-index'),(930871,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_left_measure','pt','','','.b-warehouses-popup'),(930872,'printshop','.w-cart-give-away .ga_column','margin_left_measure','%','','','.w-cart-give-away'),(930873,'printshop','.w-taxable select','margin_left_measure','pt','','','.w-taxable'),(930874,'printshop','.b-form .col-3 + .col-3','margin_left_measure','%','','','.b-form'),(930875,'printshop','.w-cart-give-away .ga_attributes > div','margin_left_measure','%','','','.w-cart-give-away'),(930876,'printshop','.b-trade-approval .col-3 + .col-3','margin_left_measure','%','','','.b-trade-approval'),(930877,'printshop','.w-delivery-day .left-count','margin_left_measure','%','','','.w-delivery-day'),(930878,'printshop','.w-delivery-day .left-text-right','margin_left_measure','%','','','.w-delivery-day'),(930879,'printshop','.w-product-sale-ends .left-count','margin_left_measure','%','','','.w-product-sale-ends'),(930880,'printshop','.w-product-sale-ends .left-text-right','margin_left_measure','%','','','.w-product-sale-ends'),(930881,'printshop','.w-product-quantity-discounts .item:nth-child(2n)','margin_left_measure','%','','','.w-product-quantity-discounts'),(930882,'printshop','.w-product-multi-inventory .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-multi-inventory'),(930883,'printshop','.p-sample-checkout-index .order-summary .heading-2','margin_left_measure','%','3','','.p-sample-checkout-index'),(930884,'printshop','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(930885,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(930886,'printshop','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(930887,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','5333','','.w-delivery-location-top-location-list'),(930888,'printshop','.w-sale-category .left-count','margin_left_measure','%','','','.w-sale-category'),(930889,'printshop','.w-sale-category .left-text-right','margin_left_measure','%','','','.w-sale-category'),(930890,'printshop','.w-delivery-location-list-by-page .item','margin_left_measure','%','','','.w-delivery-location-list-by-page'),(930891,'printshop','.w-delivery-location-cross-pages .item','margin_left_measure','%','','','.w-delivery-location-cross-pages'),(930892,'printshop','.w-catalog-delivery-locations .item','margin_left_measure','%','','','.w-catalog-delivery-locations'),(930893,'printshop','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin_left_measure','%','','','.account-address-book'),(930894,'printshop','.w-sale .left-count','margin_left_measure','%','','','.w-sale'),(930895,'printshop','.w-sale .left-text-right','margin_left_measure','%','','','.w-sale'),(930896,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_right_measure','pt','','','.b-warehouses-popup'),(930897,'printshop','.p-quick-order-index ul.token-input-list','margin_right_measure','pt','','','.p-quick-order-index'),(930898,'printshop','.b-fancybox .fancybox-title-float-wrap .child','margin_right_measure','%','','','.b-fancybox'),(930899,'printshop','.w-cart-give-away .ga_column','margin_right_measure','%','','','.w-cart-give-away'),(930900,'printshop','.w-taxable select','margin_right_measure','pt','','','.w-taxable'),(930901,'printshop','.w-cart-give-away .ga_img','margin_right_measure','%','','','.w-cart-give-away'),(930902,'printshop','.w-cart-give-away .ga_attributes > div','margin_right_measure','%','','','.w-cart-give-away'),(930903,'printshop','.w-product-quantity-discounts .item:nth-child(2n+1)','margin_right_measure','%','','','.w-product-quantity-discounts'),(930904,'printshop','.p-sample-checkout-index .order-summary .heading-2','margin_right_measure','%','4','','.p-sample-checkout-index'),(930905,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(930906,'printshop','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(930907,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','5333','','.w-delivery-location-top-location-list'),(930908,'printshop','.w-delivery-location-list-by-page .item','margin_right_measure','%','','','.w-delivery-location-list-by-page'),(930909,'printshop','.w-delivery-location-cross-pages .item','margin_right_measure','%','','','.w-delivery-location-cross-pages'),(930910,'printshop','.w-catalog-delivery-locations .item','margin_right_measure','%','','','.w-catalog-delivery-locations'),(930911,'printshop','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin_right_measure','%','','','.account-address-book'),(930913,'printshop','.p-quick-order-index ul.token-input-list','margin_top_measure','pt','','','.p-quick-order-index'),(930914,'printshop','.w-cart-give-away .ga_attributes > div','margin_top_measure','%','','','.w-cart-give-away'),(930915,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(930916,'printshop','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(930917,'printshop','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','5333','','.w-delivery-location-top-location-list'),(930918,'printshop','.w-promotions .prom-multi-discount .image img','max-height','80','','','.w-promotions'),(930919,'printshop','.w-promotions .promo-salemaker .image img','max-height','80','','','.w-promotions'),(930920,'printshop','.w-promotions .promo-cart-discount .image img','max-height','80','','','.w-promotions'),(930921,'printshop','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(930922,'printshop','.b-email-editor img','max-height','100','','','.b-email-editor'),(930923,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-height','100','','','.w-upload-customer-id-upload-customer-id-form'),(930924,'printshop','.w-product-images-additional .item-img','max-height','70','5363','','.w-product-images-additional'),(930925,'printshop','.w-product-images-additional .item-img','max-height','70','5363','','.w-product-images-additional'),(930926,'printshop','.b-email-editor img','max-height','100','','','.b-email-editor'),(930927,'printshop','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(930928,'printshop','.b-fancybox .fancybox-tmp','max-height','99999','','','.b-fancybox'),(930929,'printshop','.b-email-editor img','max-height','100','','','.b-email-editor'),(930930,'printshop','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(930931,'printshop','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(930932,'printshop','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(930933,'printshop','.b-fancybox .fancybox-image','max-height','100','','','.b-fancybox'),(930934,'printshop','.b-email-editor img','max-height','100','','','.b-email-editor'),(930935,'printshop','.b-email-editor img','max-height','100','','','.b-email-editor'),(930936,'printshop','.w-product-images-additional .item-img','max-height','70','5363','','.w-product-images-additional'),(930937,'printshop','.b-select-suggest .select2-results','max-height','200','','','.b-select-suggest'),(930938,'printshop','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(930939,'printshop','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-height','100','','','.b-products-listing'),(930940,'printshop','.b-email-editor img','max-height','100','','','.b-email-editor'),(930941,'printshop','.w-product-images-additional .item-img','max-height','70','5363','','.w-product-images-additional'),(930942,'printshop','.w-product-images-additional .item-img','max-height','70','5363','','.w-product-images-additional'),(930943,'printshop','.w-product-images-additional .item-img','max-height','70','5363','','.w-product-images-additional'),(930944,'printshop','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max-height','100','','','.b-product-images'),(930945,'printshop','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max-height','90','','','.b-product-images'),(930946,'printshop','.b-product-images .media-popup .mp-small-images img','max-height','90','','','.b-product-images'),(930947,'printshop','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','max-height','0','','','.b-menu-burger_icon'),(930948,'printshop','.b-menu-burger_icon .bi-opened .menu-style[data-open_from=\"top\"] .menu-content','max-height','2000','','','.b-menu-burger_icon'),(930949,'printshop','.w-product-images img','max-height','100','','','.w-product-images'),(930950,'printshop','.b-product-images .additional-horizontal .additional-images img','max-height','150','','','.b-product-images'),(930951,'printshop','.b-product-images .produst-image img','max-height','400','','','.b-product-images'),(930952,'printshop','.b-product-images .additional-horizontal .additional-images video','max-height','150','','','.b-product-images'),(930953,'printshop','.w-product-video .item img, .w-product-video .item video','max-height','150','','','.w-product-video'),(930954,'printshop','.w-catalog-additional-images img','max-height','150','','','.w-catalog-additional-images'),(930955,'printshop','.b-products-listing .products-listing .radio-attributes img','max-height','30','','','.b-products-listing'),(930956,'printshop','.b-product-images .additional-horizontal .additional-images img','max-height','100','5333','','.b-product-images'),(930957,'printshop','.b-product-images .additional-horizontal .additional-images video','max-height','100','5333','','.b-product-images'),(930958,'printshop','.w-sale-category .image img','max-height','300','','','.w-sale-category'),(930959,'printshop','.w-predefined-promotion .prom-multi-discount .image img','max-height','80','','','.w-predefined-promotion'),(930960,'printshop','.w-predefined-promotion .promo-cart-discount .image img','max-height','80','','','.w-predefined-promotion'),(930961,'printshop','.w-predefined-promotion .promo-salemaker .image img','max-height','80','','','.w-predefined-promotion'),(930963,'printshop','.w-categories picture img','max-height','250','','','.w-categories'),(930966,'printshop','.w-sale .image img','max-height','300','','','.w-sale'),(930967,'printshop','.b-product-images .additional-horizontal .additional-images img','max-height_important','important','','','.b-product-images'),(930968,'printshop','.b-product-images .additional-horizontal .additional-images video','max-height_important','important','','','.b-product-images'),(930969,'printshop','.b-product-images .additional-horizontal .additional-images img','max-height_important','important','5333','','.b-product-images'),(930970,'printshop','.b-product-images .additional-horizontal .additional-images video','max-height_important','important','5333','','.b-product-images'),(930971,'printshop','.w-checkout-guest-btn .btn-2','max-width','100','','','.w-checkout-guest-btn'),(930972,'printshop','.w-product-images-additional .item-img','max-width','70','5363','','.w-product-images-additional'),(930973,'printshop','.w-promotions .heading-3','max-width','calc(100% - 100px)','','','.w-promotions'),(930974,'printshop','.w-promotions .promo-salemaker .item','max-width','calc(50% - 4px)','','','.w-promotions'),(930975,'printshop','.w-promotions .promo-cart-discount .slave .item','max-width','calc(50% - 4px)','','','.w-promotions'),(930976,'printshop','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(930977,'printshop','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(930978,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-width','100','','','.w-upload-customer-id-upload-customer-id-form'),(930979,'printshop','.b-fancybox .fancybox-tmp','max-width','99999','','','.b-fancybox'),(930980,'printshop','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(930981,'printshop','.w-product-images-additional .item-img','max-width','70','5363','','.w-product-images-additional'),(930982,'printshop','.main-width, .type-1 > .block','max-width','1540','','',''),(930983,'printshop','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(930984,'printshop','textarea','max-width','100','','',''),(930985,'printshop','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(930986,'printshop','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(930987,'printshop','.w-product-images-additional .item-img','max-width','70','5363','','.w-product-images-additional'),(930988,'printshop','div.cart-popup','max-width','95','','',''),(930989,'printshop','.b-form .middle-form','max-width','560','','','.b-form'),(930990,'printshop','.b-email-editor img','max-width','100','','','.b-email-editor'),(930991,'printshop','.w-product-images-additional .item-img','max-width','70','5363','','.w-product-images-additional'),(930992,'printshop','.w-promotions .promo-cart-discount .master .item','max-width','calc(50% - 24px)','','','.w-promotions'),(930994,'printshop','.b-email-editor img','max-width','100','','','.b-email-editor'),(930997,'printshop','.w-product-images-additional .item-img','max-width','70','5363','','.w-product-images-additional'),(930999,'printshop','.w-catalog-b2b-add-button .b2b-add-box-wrap','max-width','1250','','','.w-catalog-b2b-add-button'),(931000,'printshop','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-width','100','','','.b-products-listing'),(931001,'printshop','.b-products-listing .promo','max-width','30','','','.b-products-listing'),(931002,'printshop','.b-bottom .terms-info-popup','max-width','95','','','.b-bottom'),(931003,'printshop','.w-checkout-create-btn .btn-2','max-width','100','','','.w-checkout-create-btn'),(931004,'printshop','.b-email-editor img','max-width','100','','','.b-email-editor'),(931005,'printshop','.b-fancybox .fancybox-image','max-width','100','','','.b-fancybox'),(931006,'printshop','.b-bottom .popup-credit-amount .popup-box','max-width','960','','','.b-bottom'),(931007,'printshop','.b-email-editor img','max-width','100','','','.b-email-editor'),(931008,'printshop','.b-email-editor img','max-width','100','','','.b-email-editor'),(931010,'printshop','.w-product-images-additional .item-img','max-width','70','5363','','.w-product-images-additional'),(931011,'printshop','.b-email-editor img','max-width','100','','','.b-email-editor'),(931012,'printshop','.b-upload-files .attached-block','max-width','300','','','.b-upload-files'),(931014,'printshop','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max-width','100','','','.b-product-images'),(931015,'printshop','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max-width','100','','','.b-product-images'),(931016,'printshop','.b-product-images .media-popup .mp-small-images img','max-width','90','','','.b-product-images'),(931017,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max-width','100','','','.b-menu-lev_display-slide'),(931018,'printshop','.b-trade-approval .middle-form','max-width','560','','','.b-trade-approval'),(931019,'printshop','.w-login-register .middle-form','max-width','100','','','.w-login-register'),(931020,'printshop','.w-login-returning .middle-form','max-width','100','','','.w-login-returning'),(931021,'printshop','.w-catalog-additional-images img','max-width','150','','','.w-catalog-additional-images'),(931022,'printshop','.b-products-listing .products-listing .radio-attributes img','max-width','30','','','.b-products-listing'),(931023,'printshop','.w-product-multi-inventory .radio-attributes label img','max-width','23','','','.w-product-multi-inventory'),(931024,'printshop','.b-products-listing .products-listing .radio-attributes label img','max-width','23','','','.b-products-listing'),(931025,'printshop','.w-product-attributes .radio-attributes label img','max-width','23','','','.w-product-attributes'),(931026,'printshop','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img','max-width','100','','','.w-product-groups'),(931027,'printshop','.w-product-properties-icons .hover-box img','max-width','150','','','.w-product-properties-icons'),(931028,'printshop','.w-press-reviews-widgets-press-reviews-small .item','max-width','100','','','.w-press-reviews-widgets-press-reviews-small'),(931029,'printshop','.w-predefined-promotion .heading-3','max-width','calc(100% - 100px)','','','.w-predefined-promotion'),(931030,'printshop','.w-predefined-promotion .promo-cart-discount .master .item','max-width','calc(50% - 24px)','','','.w-predefined-promotion'),(931031,'printshop','.w-predefined-promotion .promo-cart-discount .slave .item','max-width','calc(50% - 4px)','','','.w-predefined-promotion'),(931032,'printshop','.w-predefined-promotion .promo-salemaker .item','max-width','calc(50% - 4px)','','','.w-predefined-promotion'),(931033,'printshop','.bottomBanner .wrapper','max-width','800','','','.bottomBanner'),(931034,'printshop','.topBanner > .block','max-width','100','','','.topBanner'),(931035,'printshop','.bottomBanner .wrapper','max-width','540','5347','','.bottomBanner'),(931036,'printshop','.topBanner .content','max-width','33.25','','','.topBanner'),(931037,'printshop','.topBanner .ourPick','max-width','8.958','','','.topBanner'),(931038,'printshop','.topBanner .content','max-width','380','5347','','.topBanner'),(931039,'printshop','.topBanner .content','max-width','300','5342','','.topBanner'),(931040,'printshop','.topBanner .content','max-width','600','5333','','.topBanner'),(931041,'printshop','.topBanner .ourPick','max-width','150','5333','','.topBanner'),(931042,'printshop','.topBanner .ourPick','max-width','92','5363','','.topBanner'),(931043,'printshop','.p-quote-checkout-index .edit-address-popup .addresses.address-edit-holder','max-width','600','','','.p-quote-checkout-index'),(931045,'printshop','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','max-width','600','','','.checkout-index-wrap'),(931046,'printshop','.b-form .formWrapBox','max-width','500','','','.b-form'),(931047,'printshop','.doubleBanner .w-banner .text-top-center .banner-text-holder, .doubleBanner .w-banner .text-middle-center .banner-text-holder','max-width','100','','','.doubleBanner'),(931048,'printshop','.middleBanner div.banner-text-holder','max-width','680','','','.middleBanner'),(931049,'printshop','.middleBanner div.banner-text-holder','max-width','450','5347','','.middleBanner'),(931050,'printshop','.middleBanner div.banner-text-holder','max-width','100','5342','','.middleBanner'),(931051,'printshop','.bottomBanner .w-banner .banner-text-holder','max-width','100','','','.bottomBanner'),(931052,'printshop','.w-banner .banner-item.text-bottom-text .banner-text-holder','max-width','100','','','.w-banner'),(931053,'printshop','.w-banner .banner-text-holder','max-width','650','','','.w-banner'),(931054,'printshop','.w-banner .na-banner','max-width','200','','','.w-banner'),(931055,'printshop','.topBanner > .block','max-width_important','important','','','.topBanner'),(931056,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(931057,'printshop','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(931058,'printshop','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(931059,'printshop','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(931060,'printshop','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(931061,'printshop','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(931062,'printshop','.b-fancybox .fancybox-image','max_height_measure','%','','','.b-fancybox'),(931063,'printshop','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_height_measure','%','','','.b-products-listing'),(931064,'printshop','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(931065,'printshop','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max_height_measure','%','','','.b-product-images'),(931066,'printshop','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max_height_measure','%','','','.b-product-images'),(931067,'printshop','.b-product-images .media-popup .mp-small-images img','max_height_measure','%','','','.b-product-images'),(931068,'printshop','.w-product-images img','max_height_measure','%','','','.w-product-images'),(931069,'printshop','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(931070,'printshop','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(931071,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(931072,'printshop','.w-checkout-guest-btn .btn-2','max_width_measure','%','','','.w-checkout-guest-btn'),(931073,'printshop','.w-checkout-create-btn .btn-2','max_width_measure','%','','','.w-checkout-create-btn'),(931074,'printshop','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(931075,'printshop','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(931076,'printshop','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(931077,'printshop','textarea','max_width_measure','%','','',''),(931078,'printshop','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(931079,'printshop','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(931080,'printshop','div.cart-popup','max_width_measure','%','','',''),(931081,'printshop','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(931082,'printshop','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(931083,'printshop','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(931084,'printshop','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_width_measure','%','','','.b-products-listing'),(931085,'printshop','.b-products-listing .promo','max_width_measure','%','','','.b-products-listing'),(931086,'printshop','.b-bottom .terms-info-popup','max_width_measure','%','','','.b-bottom'),(931087,'printshop','.b-fancybox .fancybox-image','max_width_measure','%','','','.b-fancybox'),(931088,'printshop','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(931089,'printshop','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(931090,'printshop','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max_width_measure','%','','','.b-product-images'),(931091,'printshop','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max_width_measure','%','','','.b-product-images'),(931092,'printshop','.b-product-images .media-popup .mp-small-images img','max_width_measure','%','','','.b-product-images'),(931093,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max_width_measure','vw','','','.b-menu-lev_display-slide'),(931094,'printshop','.w-login-register .middle-form','max_width_measure','%','','','.w-login-register'),(931095,'printshop','.w-login-returning .middle-form','max_width_measure','%','','','.w-login-returning'),(931096,'printshop','.topBanner > .block','max_width_measure','%','','','.topBanner'),(931097,'printshop','.topBanner .content','max_width_measure','vw','','','.topBanner'),(931098,'printshop','.topBanner .ourPick','max_width_measure','vw','','','.topBanner'),(931099,'printshop','.doubleBanner .w-banner .text-top-center .banner-text-holder, .doubleBanner .w-banner .text-middle-center .banner-text-holder','max_width_measure','%','','','.doubleBanner'),(931100,'printshop','.middleBanner div.banner-text-holder','max_width_measure','%','5342','','.middleBanner'),(931101,'printshop','.bottomBanner .w-banner .banner-text-holder','max_width_measure','%','','','.bottomBanner'),(931102,'printshop','.w-banner .banner-item.text-bottom-text .banner-text-holder','max_width_measure','%','','','.w-banner'),(931103,'printshop','.topBanner > .block','max_width_measure_important','important','','','.topBanner'),(931104,'printshop','.b-select-suggest .select2-results .select2-result-label','min-height','1','','','.b-select-suggest'),(931105,'printshop','.b-select-suggest .select2-container-multi .select2-choices','min-height','26','','','.b-select-suggest'),(931106,'printshop','.b-select-suggest .select2-search input','min-height','26','','','.b-select-suggest'),(931107,'printshop','.b-select-suggest .select2-search','min-height','26','','','.b-select-suggest'),(931108,'printshop','.b-select-suggest .select2-drop-mask','min-height','100','','','.b-select-suggest'),(931111,'printshop','.w-cart-listing .item > div','min-height','1','','','.w-cart-listing'),(931112,'printshop','.b-slick .slick-slide','min-height','1','','','.b-slick'),(931113,'printshop','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(931114,'printshop','.w-supplier-purchase-supplier-products .qty_col','min-height','40','','','.w-supplier-purchase-supplier-products'),(931115,'printshop','.tripleLine .single_banner','min-height','52','','','.tripleLine'),(931116,'printshop','.bottomBanner .icon-box > div','min-height','105','3','','.bottomBanner'),(931117,'printshop','.bottomBanner .icon-box > div','min-height','65','5347,3','','.bottomBanner'),(931118,'printshop','.tripleLine .banner-image','min-height','52','','','.tripleLine'),(931121,'printshop','.w-communication-new-topic #communication_group_holder table','min-width','800','','','.w-communication-new-topic'),(931122,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.p-quick-order-index'),(931123,'printshop','.p-quick-order-index .al_incart, .p-quick-order-index .al-incart','min-width','60','','','.p-quick-order-index'),(931124,'printshop','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(931125,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.p-quick-order-index'),(931126,'printshop','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','min-width','150','','','.w-menu-horizontal'),(931127,'printshop','.w-communication-post .btn-submit','min-width','200','','','.w-communication-post'),(931128,'printshop','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','min-width','70','','','.b-form'),(931129,'printshop','.b-bottom .popup-box.popupCompare','min-width','800','','','.b-bottom'),(931130,'printshop','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(931131,'printshop','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(931132,'printshop','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(931133,'printshop','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(931134,'printshop','.b-select-suggest .select2-drop-mask','min-width','100','','','.b-select-suggest'),(931135,'printshop','.w-menu-horizontal > ul > li > ul > li','min-width','150','','','.w-menu-horizontal'),(931136,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.b-data-table'),(931137,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.b-data-table'),(931138,'printshop','.w-communication-new-topic .quantity','min-width','70','','','.w-communication-new-topic'),(931139,'printshop','.w-communication-new-topic #communication_group_holder table table','min-width','0','','','.w-communication-new-topic'),(931140,'printshop','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','min-width','70','','','.w-contact-contacts'),(931141,'printshop','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','min-width','200','','','.b-menu-lev_display-down'),(931142,'printshop','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','min-width','200','','','.b-menu-lev_display-down'),(931143,'printshop','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','min-width','200','','','.b-menu-lev_display-down'),(931144,'printshop','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','min-width','200','','','.b-menu-lev_display-down'),(931145,'printshop','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','min-width','200','','','.b-menu-lev_display-down'),(931146,'printshop','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','min-width','200','','','.b-menu-lev_display-left'),(931147,'printshop','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','min-width','200','','','.b-menu-lev_display-left'),(931148,'printshop','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','min-width','200','','','.b-menu-lev_display-left'),(931149,'printshop','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','min-width','200','','','.b-menu-lev_display-left'),(931150,'printshop','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','min-width','200','','','.b-menu-lev_display-left'),(931151,'printshop','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','min-width','200','','','.b-menu-lev_display-lra'),(931152,'printshop','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','min-width','200','','','.b-menu-lev_display-lra'),(931153,'printshop','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','min-width','200','','','.b-menu-lev_display-lra'),(931154,'printshop','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','min-width','200','','','.b-menu-lev_display-lra'),(931155,'printshop','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','min-width','200','','','.b-menu-lev_display-lra'),(931156,'printshop','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','min-width','200','','','.b-menu-lev_display-right'),(931157,'printshop','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','min-width','200','','','.b-menu-lev_display-right'),(931158,'printshop','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','min-width','200','','','.b-menu-lev_display-right'),(931159,'printshop','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','min-width','200','','','.b-menu-lev_display-right'),(931160,'printshop','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','min-width','200','','','.b-menu-lev_display-right'),(931162,'printshop','.w-quote .no-text','min-width','120','','','.w-quote'),(931163,'printshop','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(931164,'printshop','.w-sample .no-text','min-width','120','','','.w-sample'),(931165,'printshop','.b-pagination .pagination .next-pages','min-width','30','','','.b-pagination'),(931166,'printshop','.b-pagination .pagination .page-number','min-width','30','','','.b-pagination'),(931167,'printshop','.b-pagination .pagination .prev-pages','min-width','30','','','.b-pagination'),(931168,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','min-width','30','','','.b-pagination'),(931169,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','min-width','30','','','.b-pagination'),(931170,'printshop','.b-pagination .pagination span','min-width','30','2','','.b-pagination'),(931172,'printshop','.w-catalog-paging ','min-width','30','2','','.w-catalog-paging'),(931173,'printshop','.w-catalog-paging .next','min-width','30','','','.w-catalog-paging'),(931174,'printshop','.w-catalog-paging .next-pages','min-width','30','','','.w-catalog-paging'),(931175,'printshop','.w-catalog-paging .page-number','min-width','30','','','.w-catalog-paging'),(931176,'printshop','.w-catalog-paging .prev','min-width','30','','','.w-catalog-paging'),(931177,'printshop','.w-catalog-paging .prev-pages','min-width','30','','','.w-catalog-paging'),(931178,'printshop','.b-select-suggest .select2-results .select2-result-label','min_height_measure','em','','','.b-select-suggest'),(931179,'printshop','.b-select-suggest .select2-drop-mask','min_height_measure','%','','','.b-select-suggest'),(931180,'printshop','.b-select-suggest .select2-drop-mask','min_width_measure','%','','','.b-select-suggest'),(931181,'printshop','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','opacity','0','','','.b-switch'),(931182,'printshop','.p-quick-order-index .paginate_button.next.disabled','opacity','0.3','3','','.p-quick-order-index'),(931183,'printshop','.p-quick-order-index .paginate_button.previous.disabled','opacity','0.3','3','','.p-quick-order-index'),(931184,'printshop','.b-fancybox #fancybox-loading','opacity','0.8','','','.b-fancybox'),(931185,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','opacity','0.5','','','.b-switch'),(931186,'printshop','.b-form .hide-billing-address','opacity','0.7','','','.b-form'),(931187,'printshop','.disabled-area','opacity','0.5','','',''),(931188,'printshop','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled.readonly','opacity','0.7','','','.b-switch'),(931189,'printshop','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled','opacity','0.4','','','.b-switch'),(931190,'printshop','.b-form .checkbox-style','opacity','0','','','.b-form'),(931191,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','opacity','0.5','','','.b-switch'),(931192,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','opacity','0.5','','','.b-switch'),(931193,'printshop','.b-select-suggest .select2-drop-mask','opacity','0','','','.b-select-suggest'),(931194,'printshop','.b-products-listing .products-listing .qty-input.hidden','opacity','0.7','3','','.b-products-listing'),(931195,'printshop','.b-form .required-message','opacity','0.5','1','','.b-form'),(931196,'printshop','.w-filters .input-checkbox','opacity','0','','','.w-filters'),(931197,'printshop','.b-slick button.slick-disabled','opacity','0.3','','','.b-slick'),(931198,'printshop','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(931199,'printshop','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(931200,'printshop','.b-pagination .pagination .paging span.prev, .b-pagination .pagination .paging span.next','opacity','0.3','','','.b-pagination'),(931201,'printshop','.w-product-groups .radioBox label input','opacity','0','','','.w-product-groups'),(931202,'printshop','.w-product-designer-designer .productDesignerBox input','opacity','0','','','.w-product-designer-designer'),(931204,'printshop','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-order-pay'),(931205,'printshop','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-sample-info'),(931206,'printshop','.w-catalog-paging .paging span.prev, .w-catalog-paging .paging span.next','opacity','0.3','','','.w-catalog-paging'),(931207,'printshop','.w-promotions .promo-cart-discount .slave .heading','order','1','','','.w-promotions'),(931208,'printshop','.w-promotions .promo-cart-discount .slave .content','order','3','','','.w-promotions'),(931209,'printshop','.w-promotions .promo-cart-discount .slave .condition','order','2','','','.w-promotions'),(931210,'printshop','.w-cart-gift-certificate .input-apple .btn','order','2','','','.w-cart-gift-certificate'),(931211,'printshop','.w-cart-gift-certificate .input-apple div','order','1','','','.w-cart-gift-certificate'),(931212,'printshop','.w-cart-order-reference .input-apple div','order','1','','','.w-cart-order-reference'),(931213,'printshop','.w-cart-order-reference .input-apple button','order','2','','','.w-cart-order-reference'),(931215,'printshop','.w-press-reviews-widgets-press-reviews-list .date-added','order','4','','','.w-press-reviews-widgets-press-reviews-list'),(931216,'printshop','.w-press-reviews-widgets-press-reviews-list .description','order','5','','','.w-press-reviews-widgets-press-reviews-list'),(931217,'printshop','.w-press-reviews-widgets-press-reviews-list .image','order','1','','','.w-press-reviews-widgets-press-reviews-list'),(931218,'printshop','.w-press-reviews-widgets-press-reviews-list .out-link','order','6','','','.w-press-reviews-widgets-press-reviews-list'),(931219,'printshop','.w-press-reviews-widgets-press-reviews-list .rating','order','2','','','.w-press-reviews-widgets-press-reviews-list'),(931220,'printshop','.w-press-reviews-widgets-press-reviews-list .short-description','order','3','','','.w-press-reviews-widgets-press-reviews-list'),(931221,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition','order','2','','','.w-predefined-promotion'),(931222,'printshop','.w-predefined-promotion .promo-cart-discount .slave .content','order','3','','','.w-predefined-promotion'),(931223,'printshop','.w-predefined-promotion .promo-cart-discount .slave .heading','order','1','','','.w-predefined-promotion'),(931229,'printshop','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','outline','none','','','.b-fancybox'),(931230,'printshop','.b-select-suggest .select2-container .select2-choice abbr','outline','0','','','.b-select-suggest'),(931231,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-focused','outline','0','','','.b-switch'),(931232,'printshop','.b-select-suggest .select2-search-choice-close','outline','none','','','.b-select-suggest'),(931233,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','outline','0','','','.b-select-suggest'),(931234,'printshop','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(931235,'printshop','.b-select-suggest .select2-container-active .select2-choice, .b-select-suggest .select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(931236,'printshop','.b-select-suggest .select2-search input','outline','0','','','.b-select-suggest'),(931237,'printshop','input:focus','outline','none','','',''),(931238,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline','0','','','.b-select-suggest'),(931239,'printshop','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','outline','none','','','.b-fancybox'),(931240,'printshop','.b-product-images .media-popup .mp-big-images .item','outline','none','','','.b-product-images'),(931241,'printshop','.b-product-images .media-popup .mp-small-images .item','outline','none','','','.b-product-images'),(931242,'printshop','.b-slick .slick-list:focus','outline','none','','','.b-slick'),(931243,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline_important','important','','','.b-select-suggest'),(931244,'printshop','.w-communication-new-topic #communication_group_holder','overflow','auto','','','.w-communication-new-topic'),(931245,'printshop','.b-form .shipping-method .sub-title','overflow','hidden','','','.b-form'),(931246,'printshop','.p-quick-order-index .top','overflow','hidden','','','.p-quick-order-index'),(931247,'printshop','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','overflow','hidden','','','.w-promotions'),(931248,'printshop','.w-cart-compare .product .name','overflow','hidden','','','.w-cart-compare'),(931249,'printshop','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(931250,'printshop','.b-switch .bootstrap-switch','overflow','hidden','','','.b-switch'),(931251,'printshop','.b-fancybox .fancybox-lock .fancybox-overlay','overflow','auto','','','.b-fancybox'),(931252,'printshop','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(931253,'printshop','.b-select-suggest .select2-measure-scrollbar','overflow','scroll','','','.b-select-suggest'),(931254,'printshop','.b-fancybox .fancybox-tmp','overflow','visible','','','.b-fancybox'),(931255,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow','hidden','','','.b-select-suggest'),(931256,'printshop','.p-quick-order-index .bottom','overflow','hidden','','','.p-quick-order-index'),(931257,'printshop','.w-cart-listing .right-area','overflow','hidden','5342','','.w-cart-listing'),(931259,'printshop','.b-fancybox .fancybox-inner','overflow','hidden','','','.b-fancybox'),(931260,'printshop','.b-fancybox .fancybox-lock','overflow','hidden','','','.b-fancybox'),(931261,'printshop','.b-fancybox .fancybox-overlay','overflow','hidden','','','.b-fancybox'),(931262,'printshop','.b-select-suggest .select2-container .select2-choice','overflow','hidden','','','.b-select-suggest'),(931263,'printshop','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(931264,'printshop','.b-bottom .cart-options .options','overflow','hidden','','','.b-bottom'),(931265,'printshop','.b-autocomplete .ui-autocomplete','overflow','auto','','','.b-autocomplete'),(931266,'printshop','.b-upload-files .attach-active-holder','overflow','hidden','','','.b-upload-files'),(931267,'printshop','.b-upload-files .added-file','overflow','hidden','','','.b-upload-files'),(931268,'printshop','.b-fancybox .fancybox-lock body','overflow','hidden','','','.b-fancybox'),(931269,'printshop','.w-checkout-shipping-choice input','overflow','hidden','','','.w-checkout-shipping-choice'),(931270,'printshop','.w-checkout-shipping-choice #shippingchoice-choice','overflow','hidden','','','.w-checkout-shipping-choice'),(931271,'printshop','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(931272,'printshop','.b-select-suggest .select2-container-multi .select2-choices','overflow','hidden','','','.b-select-suggest'),(931273,'printshop','.b-preloader .preloader','overflow','hidden','3','','.b-preloader'),(931274,'printshop','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(931275,'printshop','.w-account-addresses-list ','overflow','hidden','','','.w-account-addresses-list'),(931276,'printshop','.b-products-listing .btn-preloader','overflow','hidden','3','','.b-products-listing'),(931277,'printshop','.b-products-listing .loader','overflow','hidden','4','','.b-products-listing'),(931278,'printshop','.b-compare .compare-box-item','overflow','hidden','','','.b-compare'),(931280,'printshop','.b-form .payment-method .item-radio label span','overflow','hidden','','','.b-form'),(931281,'printshop','.w-quote .no-text','overflow','hidden','','','.w-quote'),(931282,'printshop','.b-compare .col-two','overflow','hidden','','','.b-compare'),(931283,'printshop','.w-cart-give-away .ga_ovr','overflow','hidden','','','.w-cart-give-away'),(931284,'printshop','.w-cart-give-away .ga_wrapper','overflow','hidden','','','.w-cart-give-away'),(931287,'printshop','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(931288,'printshop','.w-cart-shipping-estimator .item .row','overflow','hidden','','','.w-cart-shipping-estimator'),(931289,'printshop','.b-upload-files .attached-block','overflow','hidden','','','.b-upload-files'),(931290,'printshop','.b-upload-files .attach-block','overflow','hidden','','','.b-upload-files'),(931291,'printshop','.b-select-suggest .select2-container .select2-choice > .select2-chosen','overflow','hidden','','','.b-select-suggest'),(931292,'printshop','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','overflow','hidden','','','.b-menu-burger_icon'),(931293,'printshop','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','overflow','auto','','','.b-menu-lev_display-width'),(931294,'printshop','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','overflow','auto','','','.b-menu-lev_display-width'),(931295,'printshop','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','overflow','auto','','','.b-menu-lev_display-width'),(931296,'printshop','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','overflow','auto','','','.b-menu-lev_display-width'),(931297,'printshop','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','overflow','auto','','','.b-menu-lev_display-width'),(931298,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','overflow','auto','','','.b-menu-lev_display-width_cont'),(931299,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','overflow','auto','','','.b-menu-lev_display-width_cont'),(931300,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','overflow','auto','','','.b-menu-lev_display-width_cont'),(931301,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','overflow','auto','','','.b-menu-lev_display-width_cont'),(931302,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','overflow','auto','','','.b-menu-lev_display-width_cont'),(931303,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','overflow','auto','','','.b-menu-open_from-left'),(931304,'printshop','.b-trade-approval .steps-bar','overflow','hidden','','','.b-trade-approval'),(931305,'printshop','.w-catalog-compare .compare','overflow','hidden','','','.w-catalog-compare'),(931306,'printshop','.w-delivery-day .time-left','overflow','hidden','','','.w-delivery-day'),(931307,'printshop','.w-product-images .slick-vertical + .produst-image','overflow','hidden','','','.w-product-images'),(931308,'printshop','.b-slick .slick-list','overflow','hidden','','','.b-slick'),(931309,'printshop','.w-quote .multicart .sub-total-row','overflow','hidden','','','.w-quote'),(931310,'printshop','.w-quote .sub-total-row','overflow','hidden','','','.w-quote'),(931311,'printshop','.w-product-sale-ends .left','overflow','hidden','','','.w-product-sale-ends'),(931312,'printshop','.w-compare .compare-list-holder','overflow','hidden','','','.w-compare'),(931313,'printshop','.w-compare .item-holder','overflow','hidden','','','.w-compare'),(931314,'printshop','.w-sample .multicart .sub-total-row','overflow','hidden','','','.w-sample'),(931315,'printshop','.w-sample .no-text','overflow','hidden','','','.w-sample'),(931316,'printshop','.w-sample .sub-total-row','overflow','hidden','','','.w-sample'),(931317,'printshop','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(931318,'printshop','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(931319,'printshop','.w-product-bundle .bundle_item','overflow','hidden','','','.w-product-bundle'),(931320,'printshop','.w-product-in-bundles .bundle_item','overflow','hidden','','','.w-product-in-bundles'),(931321,'printshop','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(931322,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','overflow','hidden','','','.w-account-personal-catalog'),(931323,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','overflow','visible','1','','.w-account-personal-catalog'),(931324,'printshop','.w-product-groups .radioBox','overflow','hidden','','','.w-product-groups'),(931325,'printshop','.w-sale-category .left','overflow','hidden','','','.w-sale-category'),(931326,'printshop','.w-sale-category .sale-holder','overflow','hidden','','','.w-sale-category'),(931327,'printshop','.w-gift-wrap-message-checkout ','overflow','hidden','','','.w-gift-wrap-message-checkout'),(931328,'printshop','.w-support-system-listing .support-head','overflow','hidden','','','.w-support-system-listing'),(931329,'printshop','.w-rma-returns-history .content-messages .messages-table .top','overflow','hidden','','','.w-rma-returns-history'),(931330,'printshop','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','overflow','hidden','','','.w-predefined-promotion'),(931331,'printshop','.account-address-book .buttonBox','overflow','hidden','','','.account-address-book'),(931336,'printshop','.account-order-pay .history_info','overflow','hidden','','','.account-order-pay'),(931337,'printshop','.account-sample-info .history_info','overflow','hidden','','','.account-sample-info'),(931338,'printshop','.fake-input','overflow','hidden','','',''),(931339,'printshop','.payment-method-tf label','overflow','hidden','','','.payment-method-tf'),(931340,'printshop','.w-banner .banner .image-box','overflow','hidden','','','.w-banner'),(931341,'printshop','.w-catalog-paging .paging-holder','overflow','hidden','','','.w-catalog-paging'),(931342,'printshop','.w-catalog-paging .paging-holder.slick-slider','overflow','visible','','','.w-catalog-paging'),(931343,'printshop','.w-sale .left','overflow','hidden','','','.w-sale'),(931344,'printshop','.w-sale .sale-holder','overflow','hidden','','','.w-sale'),(931345,'printshop','.b-compare .compare_list','overflow-x','hidden','','','.b-compare'),(931346,'printshop','.b-select-suggest .select2-results','overflow-x','hidden','','','.b-select-suggest'),(931347,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-x','hidden','','','.b-menu-lev_display-slide'),(931348,'printshop','.b-compare .compare_list','overflow-y','auto','','','.b-compare'),(931349,'printshop','.b-fancybox .fancybox-lock .fancybox-overlay','overflow-y','scroll','','','.b-fancybox'),(931350,'printshop','.b-fancybox .fancybox-lock-test','overflow-y','hidden','','','.b-fancybox'),(931351,'printshop','.b-select-suggest .select2-results','overflow-y','auto','','','.b-select-suggest'),(931352,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-y','auto','','','.b-menu-lev_display-slide'),(931353,'printshop','.b-fancybox .fancybox-lock-test','overflow-y_important','important','','','.b-fancybox'),(931354,'printshop','.b-fancybox .fancybox-lock','overflow_important','important','','','.b-fancybox'),(931355,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow_important','important','','','.b-select-suggest'),(931356,'printshop','.b-fancybox .fancybox-tmp','overflow_important','important','','','.b-fancybox'),(931357,'printshop','.b-fancybox .fancybox-lock body','overflow_important','important','','','.b-fancybox'),(931358,'printshop','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-bottom','10','','','.w-communication-new-topic'),(931359,'printshop','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(931360,'printshop','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(931361,'printshop','.b-email .heading-model','padding-bottom','5','','','.b-email'),(931362,'printshop','.b-table .table td','padding-bottom','15','','','.b-table'),(931363,'printshop','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(931364,'printshop','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(931365,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(931366,'printshop','.w-product-images-additional .images','padding-bottom','20','5363','','.w-product-images-additional'),(931369,'printshop','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(931370,'printshop','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(931371,'printshop','.p-quick-order-index ul.token-input-list','padding-bottom','0','','','.p-quick-order-index'),(931372,'printshop','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-bottom','7','','','.p-quick-order-index'),(931373,'printshop','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-bottom','8','','','.p-quick-order-index'),(931374,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.p-quick-order-index'),(931375,'printshop','.w-promotions .promo-item','padding-bottom','20','','','.w-promotions'),(931376,'printshop','.w-top-categories h2.name','padding-bottom','3','','','.w-top-categories'),(931377,'printshop','.w-cart-compare .attributes-label','padding-bottom','10','','','.w-cart-compare'),(931384,'printshop','.w-personal-gift-status-bar .start-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(931385,'printshop','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(931386,'printshop','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(931387,'printshop','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(931388,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(931389,'printshop','.testimonials .review','padding-bottom','10','','',''),(931390,'printshop','.testimonials .heading-3','padding-bottom','10','','',''),(931391,'printshop','.testimonials .reviews-list .name','padding-bottom','5','','',''),(931392,'printshop','.testimonials .name','padding-bottom','5','','',''),(931393,'printshop','.w-categories .image','padding-bottom','75','','','.w-categories'),(931394,'printshop','.w-promotions .prom-multi-discount .promo-range','padding-bottom','0','','','.w-promotions'),(931395,'printshop','.w-promotions .prom-multi-discount .promo-product','padding-bottom','20','','','.w-promotions'),(931396,'printshop','.w-promotions .nextdiscount .promo-for-each','padding-bottom','2','','','.w-promotions'),(931397,'printshop','.w-promotions .nextdiscount .content > div','padding-bottom','10','','','.w-promotions'),(931398,'printshop','.w-promotions .promo-salemaker .item','padding-bottom','20','','','.w-promotions'),(931399,'printshop','.w-promotions .promo-salemaker .discount','padding-bottom','0','','','.w-promotions'),(931400,'printshop','.w-promotions .promo-cart-discount .slave .item','padding-bottom','20','','','.w-promotions'),(931401,'printshop','.w-promotions .promo-cart-discount .slave .heading','padding-bottom','1','','','.w-promotions'),(931402,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','padding-bottom','0','','','.w-promotions'),(931403,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','padding-bottom','0','','','.w-promotions'),(931404,'printshop','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-bottom','20','','','.b-warehouses-popup'),(931405,'printshop','.w-product-available-in-warehouses .warehouse-item','padding-bottom','20','','','.w-product-available-in-warehouses'),(931406,'printshop','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-bottom','6','','','.b-products-listing'),(931408,'printshop','.w-cart-compare .attributes-cell','padding-bottom','8','','','.w-cart-compare'),(931409,'printshop','.b-bottom .confirm-popup .confirm-text','padding-bottom','30','','','.b-bottom'),(931410,'printshop','.b-messages .msv_btn','padding-bottom','12','','','.b-messages'),(931411,'printshop','.b-messages .msv_content','padding-bottom','10','','','.b-messages'),(931412,'printshop','.b-messages .msv_history','padding-bottom','10','','','.b-messages'),(931413,'printshop','.b-messages .messMenuButton span','padding-bottom','10','','','.b-messages'),(931414,'printshop','.b-messages .messages-menu li a','padding-bottom','8','','','.b-messages'),(931415,'printshop','.b-messages .messages-menu li','padding-bottom','0','','','.b-messages'),(931416,'printshop','.b-messages .messages-menu ul','padding-bottom','0','','','.b-messages'),(931417,'printshop','.b-messages .content_management_attach button','padding-bottom','1','','','.b-messages'),(931418,'printshop','.b-messages .email-heading','padding-bottom','15','','','.b-messages'),(931419,'printshop','.b-messages .content_management_attach','padding-bottom','8','','','.b-messages'),(931420,'printshop','.b-messages .emailLineTextArea textarea','padding-bottom','30','','','.b-messages'),(931421,'printshop','.b-messages .msv_to_cc','padding-bottom','10','','','.b-messages'),(931422,'printshop','.b-messages .emailBtn','padding-bottom','10','','','.b-messages'),(931423,'printshop','.b-messages .dataTables_wrapper > .bottom','padding-bottom','4','','','.b-messages'),(931424,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-bottom','5','','','.b-messages'),(931425,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-bottom','6','','',''),(931426,'printshop','.w-sitemap-delivery-location > ul > li > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(931428,'printshop','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(931429,'printshop','.w-reviews-content .item','padding-bottom','25','','','.w-reviews-content'),(931430,'printshop','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(931431,'printshop','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(931432,'printshop','.w-sitemap-delivery-location > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(931433,'printshop','.w-checkout-terms .required-message','padding-bottom','5','','','.w-checkout-terms'),(931434,'printshop','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(931435,'printshop','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(931436,'printshop','.b-email .model','padding-bottom','5','','','.b-email'),(931437,'printshop','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(931438,'printshop','.w-checkout-shipping-address .edit-ab','padding-bottom','0','','','.w-checkout-shipping-address'),(931439,'printshop','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(931440,'printshop','.w-reviews-content .author','padding-bottom','20','','','.w-reviews-content'),(931441,'printshop','.w-promo-code .holder','padding-bottom','20','5363','','.w-promo-code'),(931442,'printshop','.w-cart-listing .item .remove','padding-bottom','5','5342','','.w-cart-listing'),(931443,'printshop','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(931444,'printshop','.b-email .image','padding-bottom','5','','','.b-email'),(931445,'printshop','.b-email .heading-price','padding-bottom','5','','','.b-email'),(931446,'printshop','.b-email .heading-image','padding-bottom','5','','','.b-email'),(931447,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(931448,'printshop','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(931449,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(931450,'printshop','.w-filters .filter-ul-content','padding-bottom','0','','','.w-filters'),(931451,'printshop','.w-filters .filter-box-head','padding-bottom','5','','','.w-filters'),(931452,'printshop','.w-filters .filter-li-content','padding-bottom','15','','','.w-filters'),(931453,'printshop','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(931454,'printshop','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(931455,'printshop','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(931456,'printshop','.w-menu-horizontal > ul > li > ul > li','padding-bottom','2','','','.w-menu-horizontal'),(931457,'printshop','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-bottom','2','','','.w-menu-horizontal'),(931458,'printshop','.w-menu-horizontal ul','padding-bottom','0','','','.w-menu-horizontal'),(931459,'printshop','.w-tabs .tab-navigation','padding-bottom','0','','','.w-tabs'),(931460,'printshop','.b-table .table td','padding-bottom','15','','','.b-table'),(931461,'printshop','.b-email .heading-name','padding-bottom','5','','','.b-email'),(931462,'printshop','.b-email .heading-model','padding-bottom','5','','','.b-email'),(931464,'printshop','.b-email .totals-value','padding-bottom','5','','','.b-email'),(931465,'printshop','.b-email .name','padding-bottom','5','','','.b-email'),(931466,'printshop','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(931467,'printshop','.b-email .qty','padding-bottom','5','','','.b-email'),(931468,'printshop','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(931469,'printshop','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(931470,'printshop','.b-bottom .terms-info-popup .pop-up-content','padding-bottom','20','','','.b-bottom'),(931471,'printshop','.w-cart-compare .dropdown .dropdown-menu','padding-bottom','5','','','.w-cart-compare'),(931472,'printshop','.no-found','padding-bottom','20','','',''),(931473,'printshop','textarea','padding-bottom','5','','',''),(931474,'printshop','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(931475,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(931476,'printshop','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(931477,'printshop','.p-quick-order-index .bottom','padding-bottom','10','','','.p-quick-order-index'),(931480,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-bottom','10','','','.w-image-maps'),(931481,'printshop','.b-table .table td','padding-bottom','15','','','.b-table'),(931482,'printshop','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(931483,'printshop','.message.success','padding-bottom','15','','',''),(931484,'printshop','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(931485,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(931486,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(931487,'printshop','.b-email .image','padding-bottom','5','','','.b-email'),(931488,'printshop','.b-email .heading-price','padding-bottom','5','','','.b-email'),(931489,'printshop','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-bottom','0','','','.b-fancybox'),(931490,'printshop','.w-checkout-shipping-choice span','padding-bottom','4','','','.w-checkout-shipping-choice'),(931491,'printshop','.b-info .info','padding-bottom','15','','','.b-info'),(931492,'printshop','.b-email .model','padding-bottom','5','','','.b-email'),(931493,'printshop','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(931494,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-bottom','0','','','.b-select-suggest'),(931495,'printshop','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(931496,'printshop','.w-reviews .review','padding-bottom','5','','','.w-reviews'),(931497,'printshop','.w-socials > li','padding-bottom','15','','','.w-socials'),(931499,'printshop','.b-info-popup .info-popup div','padding-bottom','10','','','.b-info-popup'),(931500,'printshop','.b-form .payment-method .item','padding-bottom','7','','','.b-form'),(931501,'printshop','.w-checkout-create-account .create-account','padding-bottom','10','','','.w-checkout-create-account'),(931502,'printshop','.b-form .password-forgotten-link','padding-bottom','0','','','.b-form'),(931503,'printshop','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(931504,'printshop','.w-catalog-sorting .before','padding-bottom','0','','','.w-catalog-sorting'),(931506,'printshop','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(931507,'printshop','.b-email .qty','padding-bottom','5','','','.b-email'),(931508,'printshop','.b-email .heading-price','padding-bottom','5','','','.b-email'),(931509,'printshop','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(931510,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(931511,'printshop','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-bottom','3','','','.w-multi-cart-actions'),(931512,'printshop','.w-top-categories .item','padding-bottom','30','','','.w-top-categories'),(931513,'printshop','.w-tabs > .block','padding-bottom','20','','','.w-tabs'),(931514,'printshop','.w-tabs .accordion-heading','padding-bottom','6','2','','.w-tabs'),(931515,'printshop','.w-tabs .accordion-heading','padding-bottom','9','5333','','.w-tabs'),(931516,'printshop','.w-cart-cart-tabs .w-tabs > .block','padding-bottom','0','','','.w-cart-cart-tabs'),(931517,'printshop','.w-tabs .tab-a','padding-bottom','12','','','.w-tabs'),(931518,'printshop','.w-socials > li','padding-bottom','15','','','.w-socials'),(931519,'printshop','.b-info .info li','padding-bottom','0','','','.b-info'),(931520,'printshop','.w-promo-code .holder','padding-bottom','20','5363','','.w-promo-code'),(931521,'printshop','.b-bottom .popup-buttons','padding-bottom','15','','','.b-bottom'),(931522,'printshop','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-bottom','7','','','.order-summary'),(931523,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(931524,'printshop','.b-sub-totals .historyTotal td','padding-bottom','2','','','.b-sub-totals'),(931525,'printshop','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(931526,'printshop','.b-form .required-message','padding-bottom','0','','','.b-form'),(931527,'printshop','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(931528,'printshop','.btn-1','padding-bottom','6','','',''),(931529,'printshop','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(931530,'printshop','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(931531,'printshop','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(931532,'printshop','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(931533,'printshop','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(931535,'printshop','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(931536,'printshop','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(931537,'printshop','.b-info .info','padding-bottom','15','','','.b-info'),(931538,'printshop','.btn-3','padding-bottom','6','','',''),(931539,'printshop','.b-products-listing .products-listing .buyButton .btn','padding-bottom','4','','','.b-products-listing'),(931540,'printshop','.w-product-images-additional .images','padding-bottom','20','5363','','.w-product-images-additional'),(931541,'printshop','.b-form .required-message-wrap','padding-bottom','0','','','.b-form'),(931542,'printshop','.b-email .image','padding-bottom','5','','','.b-email'),(931543,'printshop','.b-info .info li','padding-bottom','0','','','.b-info'),(931544,'printshop','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(931545,'printshop','.b-email .heading-image','padding-bottom','5','','','.b-email'),(931546,'printshop','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(931547,'printshop','.b-email .heading-model','padding-bottom','5','','','.b-email'),(931548,'printshop','.order-summary .price-row','padding-bottom','7','','','.order-summary'),(931549,'printshop','.b-email .heading-model','padding-bottom','5','','','.b-email'),(931550,'printshop','.b-email .price','padding-bottom','5','','','.b-email'),(931551,'printshop','.b-email .heading-name','padding-bottom','5','','','.b-email'),(931552,'printshop','.w-socials > li','padding-bottom','15','','','.w-socials'),(931553,'printshop','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(931554,'printshop','.b-upload-file .upload-file-template','padding-bottom','25','','','.b-upload-file'),(931556,'printshop','.b-select-suggest .select2-drop-mask','padding-bottom','0','','','.b-select-suggest'),(931557,'printshop','.w-quote .cart-box-link','padding-bottom','0','','','.w-quote'),(931558,'printshop','.w-reviews .author','padding-bottom','10','','','.w-reviews'),(931559,'printshop','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(931560,'printshop','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(931561,'printshop','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(931563,'printshop','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(931564,'printshop','.b-email .price','padding-bottom','5','','','.b-email'),(931565,'printshop','.b-fancybox .fancybox-title-float-wrap .child','padding-bottom','2','','','.b-fancybox'),(931566,'printshop','.w-checkout-shipping-choice span','padding-bottom','4','5363','','.w-checkout-shipping-choice'),(931567,'printshop','.w-top-categories .categories h2','padding-bottom','0','','','.w-top-categories'),(931568,'printshop','.w-top-categories .image','padding-bottom','75','','','.w-top-categories'),(931569,'printshop','.w-product-reviews .reviews-list .review','padding-bottom','10','','','.w-product-reviews'),(931570,'printshop','.w-product-reviews .reviews-list .name','padding-bottom','5','','','.w-product-reviews'),(931571,'printshop','.w-reviews-content .rating','padding-bottom','10','','','.w-reviews-content'),(931572,'printshop','.b-email .totals-value','padding-bottom','5','','','.b-email'),(931573,'printshop','.b-info .info ul','padding-bottom','0','','','.b-info'),(931574,'printshop','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(931575,'printshop','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(931576,'printshop','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(931577,'printshop','.b-table .table td','padding-bottom','15','','','.b-table'),(931578,'printshop','.b-bottom .rfq-form','padding-bottom','0','','','.b-bottom'),(931579,'printshop','.b-bottom .popup-simple','padding-bottom','20','','','.b-bottom'),(931580,'printshop','.b-bottom .popup-heading','padding-bottom','12','','','.b-bottom'),(931581,'printshop','.b-email .model','padding-bottom','5','','','.b-email'),(931582,'printshop','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(931583,'printshop','.b-email .image','padding-bottom','5','','','.b-email'),(931584,'printshop','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(931585,'printshop','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(931586,'printshop','.b-email .image','padding-bottom','5','','','.b-email'),(931587,'printshop','.b-email .name','padding-bottom','5','','','.b-email'),(931588,'printshop','.b-email .heading-price','padding-bottom','5','','','.b-email'),(931589,'printshop','.b-email .heading-model','padding-bottom','5','','','.b-email'),(931590,'printshop','.b-email .totals-title','padding-bottom','5','','','.b-email'),(931591,'printshop','.b-email .totals-value','padding-bottom','5','','','.b-email'),(931592,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(931593,'printshop','.b-email .qty','padding-bottom','5','','','.b-email'),(931594,'printshop','.b-email .model','padding-bottom','5','','','.b-email'),(931595,'printshop','.b-email .price','padding-bottom','5','','','.b-email'),(931596,'printshop','.b-email .heading-name','padding-bottom','5','','','.b-email'),(931597,'printshop','.b-email .heading-image','padding-bottom','5','','','.b-email'),(931598,'printshop','.w-checkout-shipping .sub-item','padding-bottom','5','','','.w-checkout-shipping'),(931599,'printshop','.b-info .info','padding-bottom','15','','','.b-info'),(931600,'printshop','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(931601,'printshop','.b-email .totals-value','padding-bottom','5','','','.b-email'),(931602,'printshop','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(931603,'printshop','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(931604,'printshop','.b-table .table td','padding-bottom','15','','','.b-table'),(931605,'printshop','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(931606,'printshop','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(931607,'printshop','.w-promo-code .holder','padding-bottom','20','5363','','.w-promo-code'),(931608,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(931609,'printshop','.b-form .center-buttons','padding-bottom','20','','','.b-form'),(931610,'printshop','.b-form .shipping-method .input','padding-bottom','0','','','.b-form'),(931611,'printshop','.w-reviews .item','padding-bottom','15','','','.w-reviews'),(931612,'printshop','.w-reviews .product-name','padding-bottom','12','','','.w-reviews'),(931613,'printshop','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(931614,'printshop','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(931615,'printshop','.b-select-suggest .select2-container .select2-choice','padding-bottom','0','','','.b-select-suggest'),(931616,'printshop','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(931617,'printshop','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(931618,'printshop','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(931619,'printshop','.w-cart-compare .price-label','padding-bottom','10','','','.w-cart-compare'),(931620,'printshop','.b-info .info','padding-bottom','15','','','.b-info'),(931621,'printshop','.b-info .info li','padding-bottom','0','','','.b-info'),(931622,'printshop','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(931623,'printshop','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(931625,'printshop','.b-upload-files .upload-files','padding-bottom','10','','','.b-upload-files'),(931626,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(931627,'printshop','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(931628,'printshop','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(931629,'printshop','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(931630,'printshop','.b-form .col-full-padding','padding-bottom','30','','','.b-form'),(931631,'printshop','.b-info .info ul','padding-bottom','0','','','.b-info'),(931632,'printshop','.w-categories .item','padding-bottom','30','','','.w-categories'),(931633,'printshop','.b-form .form-buttons','padding-bottom','50','','','.b-form'),(931634,'printshop','.b-fancybox .fancybox-title-over-wrap','padding-bottom','10','','','.b-fancybox'),(931635,'printshop','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(931636,'printshop','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(931637,'printshop','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(931638,'printshop','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(931639,'printshop','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(931640,'printshop','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(931641,'printshop','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(931642,'printshop','.w-cart-compare .delete-cart','padding-bottom','10','','','.w-cart-compare'),(931643,'printshop','.p-quick-order-index .all-scroll-div','padding-bottom','10','','','.p-quick-order-index'),(931644,'printshop','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(931645,'printshop','.w-checkout-billing-address .same-address','padding-bottom','10','','','.w-checkout-billing-address'),(931646,'printshop','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(931647,'printshop','.b-email .heading-image','padding-bottom','5','','','.b-email'),(931648,'printshop','.b-email .price','padding-bottom','5','','','.b-email'),(931649,'printshop','.b-email .heading-name','padding-bottom','5','','','.b-email'),(931650,'printshop','.b-email .model','padding-bottom','5','','','.b-email'),(931651,'printshop','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-bottom','10','','','.b-bottom'),(931652,'printshop','.w-cart-compare .cart-cell','padding-bottom','20','','','.w-cart-compare'),(931653,'printshop','.w-promotions .promo-cart-discount .master .item','padding-bottom','20','','','.w-promotions'),(931654,'printshop','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(931655,'printshop','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(931656,'printshop','.b-bottom .cart-options','padding-bottom','20','','','.b-bottom'),(931657,'printshop','.b-bottom .alert-message','padding-bottom','20','','','.b-bottom'),(931658,'printshop','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(931659,'printshop','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(931660,'printshop','.b-select-suggest .select2-results .select2-result-label','padding-bottom','4','','','.b-select-suggest'),(931661,'printshop','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(931662,'printshop','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(931663,'printshop','.b-email .totals-title','padding-bottom','5','','','.b-email'),(931664,'printshop','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(931665,'printshop','.w-reviews-content .product-name','padding-bottom','20','','','.w-reviews-content'),(931666,'printshop','.b-email .name','padding-bottom','5','','','.b-email'),(931667,'printshop','.b-email .heading-price','padding-bottom','5','','','.b-email'),(931668,'printshop','.b-email .heading-image','padding-bottom','5','','','.b-email'),(931669,'printshop','.b-email .heading-name','padding-bottom','5','','','.b-email'),(931670,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(931671,'printshop','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(931672,'printshop','.b-info .info ul','padding-bottom','0','','','.b-info'),(931673,'printshop','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-bottom','4','','','.b-compare'),(931674,'printshop','.b-bottom .pop-up-close','padding-bottom','1','','','.b-bottom'),(931675,'printshop','.b-bottom .footerTitle','padding-bottom','9','5333','','.b-bottom'),(931676,'printshop','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(931677,'printshop','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(931678,'printshop','.w-cart-up-sell .w-list-type-1','padding-bottom','0','','','.w-cart-up-sell'),(931679,'printshop','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','0','1','','.w-cart-up-sell'),(931680,'printshop','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','1','','','.w-cart-up-sell'),(931681,'printshop','.b-upload-files .added-file','padding-bottom','5','','','.b-upload-files'),(931683,'printshop','.w-menu-big ul','padding-bottom','0','','','.w-menu-big'),(931684,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(931685,'printshop','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(931686,'printshop','.w-categories h2.name','padding-bottom','11','','','.w-categories'),(931687,'printshop','.b-bottom .header-info','padding-bottom','20','','','.b-bottom'),(931688,'printshop','.b-bottom .popup-box-wrap','padding-bottom','10','','','.b-bottom'),(931689,'printshop','.w-product-images-additional .images','padding-bottom','20','5363','','.w-product-images-additional'),(931690,'printshop','.b-bottom .pop-up-info','padding-bottom','20','','','.b-bottom'),(931691,'printshop','.b-email .price','padding-bottom','5','','','.b-email'),(931692,'printshop','.b-fancybox .fancybox-error','padding-bottom','15','','','.b-fancybox'),(931693,'printshop','.b-info .info li','padding-bottom','0','','','.b-info'),(931694,'printshop','.w-product-customers-activity .customers-activity','padding-bottom','20','','','.w-product-customers-activity'),(931695,'printshop','.b-compare .compare-box-item','padding-bottom','10','','','.b-compare'),(931696,'printshop','.b-bottom .confirm-popup .buttons','padding-bottom','30','','','.b-bottom'),(931697,'printshop','.b-compare .compare-head','padding-bottom','0','','','.b-compare'),(931698,'printshop','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(931699,'printshop','.b-email .heading-image','padding-bottom','5','','','.b-email'),(931700,'printshop','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(931701,'printshop','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(931702,'printshop','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(931703,'printshop','.b-info .info li','padding-bottom','0','','','.b-info'),(931704,'printshop','.b-form .login-col-1','padding-bottom','0','','','.b-form'),(931705,'printshop','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(931706,'printshop','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(931708,'printshop','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(931709,'printshop','.w-checkout-billing-address .edit-ab','padding-bottom','0','','','.w-checkout-billing-address'),(931710,'printshop','.w-checkout-shipping-choice #shippingchoice-choice','padding-bottom','7','','','.w-checkout-shipping-choice'),(931711,'printshop','.w-promo-code .holder','padding-bottom','20','5363','','.w-promo-code'),(931712,'printshop','.w-product-images-additional .images','padding-bottom','20','5363','','.w-product-images-additional'),(931713,'printshop','.b-bottom .header-error','padding-bottom','20','','','.b-bottom'),(931714,'printshop','.w-tabs .accordion-heading','padding-bottom','8','','','.w-tabs'),(931715,'printshop','.w-socials > li','padding-bottom','15','','','.w-socials'),(931716,'printshop','.b-autocomplete .ui-autocomplete li','padding-bottom','3','','','.b-autocomplete'),(931717,'printshop','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(931718,'printshop','.w-cart-give-away .ga_column','padding-bottom','15','','','.w-cart-give-away'),(931719,'printshop','.w-cart-compare .price-cell','padding-bottom','8','','','.w-cart-compare'),(931720,'printshop','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(931721,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(931722,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(931723,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-bottom','5','','','.b-select-suggest'),(931724,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-bottom','0','','','.b-select-suggest'),(931725,'printshop','.b-select-suggest .select2-locked','padding-bottom','3','','','.b-select-suggest'),(931726,'printshop','.b-select-suggest .select2-container-multi .select2-choices','padding-bottom','0','','','.b-select-suggest'),(931727,'printshop','.b-select-suggest .select2-results','padding-bottom','0','','','.b-select-suggest'),(931728,'printshop','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','5','','','.w-menu-horizontal'),(931729,'printshop','.b-form .shipping-method .item + .item','padding-bottom','5','','','.b-form'),(931730,'printshop','.b-select-suggest .select2-search input','padding-bottom','4','','','.b-select-suggest'),(931731,'printshop','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(931732,'printshop','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','12','5342','','.w-menu-horizontal'),(931733,'printshop','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(931734,'printshop','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(931735,'printshop','.w-socials > li','padding-bottom','15','','','.w-socials'),(931738,'printshop','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(931739,'printshop','.w-cart-compare .dropdown li','padding-bottom','5','','','.w-cart-compare'),(931740,'printshop','.w-cart-compare .product-label','padding-bottom','15','','','.w-cart-compare'),(931743,'printshop','.b-compare .col-two label','padding-bottom','5','','','.b-compare'),(931744,'printshop','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(931747,'printshop','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(931748,'printshop','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(931749,'printshop','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(931750,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(931751,'printshop','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(931752,'printshop','.w-account-addresses-list .addsess-suggestion-item','padding-bottom','20','','','.w-account-addresses-list'),(931753,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.b-data-table'),(931754,'printshop','.w-communication-post .communication-post','padding-bottom','5','','','.w-communication-post'),(931755,'printshop','.w-communication-post .communication-post-author','padding-bottom','10','','','.w-communication-post'),(931756,'printshop','.b-products-listing .in-cart','padding-bottom','4','','','.b-products-listing'),(931757,'printshop','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-bottom','5','','','.w-catalog-b2b-add-button'),(931758,'printshop','.b-products-listing .promos-info .promo-item','padding-bottom','3','','','.b-products-listing'),(931759,'printshop','.b-products-listing .promos-info .promo-name','padding-bottom','3','','','.b-products-listing'),(931765,'printshop','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(931766,'printshop','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(931767,'printshop','.w-checkout-gdpr .privacy-row','padding-bottom','0','','','.w-checkout-gdpr'),(931768,'printshop','.w-checkout-gdpr .terms-login','padding-bottom','0','','','.w-checkout-gdpr'),(931769,'printshop','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(931770,'printshop','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(931771,'printshop','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(931772,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(931773,'printshop','.b-email .qty','padding-bottom','5','','','.b-email'),(931774,'printshop','.b-email .name','padding-bottom','5','','','.b-email'),(931775,'printshop','.b-email .heading-price','padding-bottom','5','','','.b-email'),(931776,'printshop','.w-reviews .heading-3','padding-bottom','15','','','.w-reviews'),(931778,'printshop','.w-personal-gift-status-bar .timeline','padding-bottom','16','','','.w-personal-gift-status-bar'),(931779,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(931780,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(931781,'printshop','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(931782,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-bottom','0','','',''),(931783,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-bottom','0','','','.b-h-inline'),(931784,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-bottom','0','','','.w-communication-new-topic'),(931785,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-bottom','5','','','.w-communication-new-topic'),(931786,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-bottom','5','','','.w-communication-new-topic'),(931787,'printshop','.w-communication-new-topic #communication_topic_form .middle-form','padding-bottom','0','','','.w-communication-new-topic'),(931788,'printshop','.b-info .info ul','padding-bottom','0','','','.b-info'),(931789,'printshop','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(931790,'printshop','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(931791,'printshop','.b-bottom .popup-content','padding-bottom','15','','','.b-bottom'),(931792,'printshop','.b-compare .compare_pagination','padding-bottom','10','','','.b-compare'),(931793,'printshop','.w-promo-code .holder','padding-bottom','20','5363','','.w-promo-code'),(931794,'printshop','.w-top-categories .item','padding-bottom','30','5333','','.w-top-categories'),(931795,'printshop','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(931796,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(931797,'printshop','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(931800,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(931801,'printshop','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(931802,'printshop','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(931803,'printshop','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-bottom','0','','','.b-fancybox'),(931804,'printshop','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(931805,'printshop','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(931806,'printshop','.b-email .qty','padding-bottom','5','','','.b-email'),(931807,'printshop','.b-email .totals-title','padding-bottom','5','','','.b-email'),(931808,'printshop','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(931809,'printshop','.b-email .name','padding-bottom','5','','','.b-email'),(931810,'printshop','.products-quick-index .token-input-list','padding-bottom','0','','',''),(931811,'printshop','.w-cart-compare .product','padding-bottom','10','','','.w-cart-compare'),(931812,'printshop','.w-cart-compare .product-actions','padding-bottom','0','','','.w-cart-compare'),(931813,'printshop','.w-cart-shipping-estimator .address-item','padding-bottom','20','','','.w-cart-shipping-estimator'),(931814,'printshop','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(931815,'printshop','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(931816,'printshop','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(931817,'printshop','.b-info .info li','padding-bottom','0','','','.b-info'),(931818,'printshop','.b-form .shipping-method .item','padding-bottom','5','','','.b-form'),(931819,'printshop','.b-info .info','padding-bottom','15','','','.b-info'),(931820,'printshop','.b-email .model','padding-bottom','5','','','.b-email'),(931821,'printshop','.b-form .middle-form','padding-bottom','0','','','.b-form'),(931822,'printshop','.b-email .totals-title','padding-bottom','5','','','.b-email'),(931823,'printshop','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(931824,'printshop','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(931825,'printshop','.w-product-images-additional .images','padding-bottom','20','5363','','.w-product-images-additional'),(931826,'printshop','.b-email .totals-value','padding-bottom','5','','','.b-email'),(931827,'printshop','.w-cart-listing .item .gift-wrap label','padding-bottom','10','','','.w-cart-listing'),(931828,'printshop','.w-cart-listing .item > div','padding-bottom','10','','','.w-cart-listing'),(931829,'printshop','.w-cart-listing .points-earn','padding-bottom','5','','','.w-cart-listing'),(931830,'printshop','.w-cart-listing .points-redeem','padding-bottom','10','','','.w-cart-listing'),(931836,'printshop','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(931837,'printshop','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(931838,'printshop','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(931839,'printshop','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(931840,'printshop','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(931841,'printshop','.b-email .totals-value','padding-bottom','5','','','.b-email'),(931842,'printshop','.b-email .totals-title','padding-bottom','5','','','.b-email'),(931843,'printshop','.b-email .price','padding-bottom','5','','','.b-email'),(931844,'printshop','.b-email .name','padding-bottom','5','','','.b-email'),(931845,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(931846,'printshop','.b-email .heading-name','padding-bottom','5','','','.b-email'),(931847,'printshop','.b-email .image','padding-bottom','5','','','.b-email'),(931848,'printshop','.w-product-images-additional .images','padding-bottom','20','5363','','.w-product-images-additional'),(931849,'printshop','.w-promo-code .holder','padding-bottom','20','5363','','.w-promo-code'),(931850,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(931851,'printshop','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(931852,'printshop','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(931853,'printshop','.w-contact-contacts table td','padding-bottom','0','','','.w-contact-contacts'),(931854,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-bottom','0','','','.w-contact-contacts'),(931856,'printshop','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(931857,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(931858,'printshop','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(931859,'printshop','.w-filters .fsl_handle','padding-bottom','15','','','.w-filters'),(931860,'printshop','.w-filters .head-filter-widget','padding-bottom','0','5342','','.w-filters'),(931861,'printshop','.w-filters .filter-box-content','padding-bottom','20','','','.w-filters'),(931862,'printshop','.w-filters .ui-slider-range','padding-bottom','0','','','.w-filters'),(931863,'printshop','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(931865,'printshop','.w-filters .head-filter-widget','padding-bottom','10','','','.w-filters'),(931866,'printshop','.b-autocomplete .ui-autocomplete','padding-bottom','2','','','.b-autocomplete'),(931867,'printshop','.b-bottom .notify-form','padding-bottom','0','','','.b-bottom'),(931868,'printshop','.order-summary .heading-2','padding-bottom','0','','','.order-summary'),(931869,'printshop','.w-personal-gift-status-bar .end-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(931870,'printshop','.b-compare .column_wrapper','padding-bottom','10','','','.b-compare'),(931871,'printshop','.b-info .info','padding-bottom','15','','','.b-info'),(931872,'printshop','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(931873,'printshop','.b-email .heading-model','padding-bottom','5','','','.b-email'),(931874,'printshop','.b-info .info ul','padding-bottom','0','','','.b-info'),(931875,'printshop','.w-socials > li','padding-bottom','15','','','.w-socials'),(931876,'printshop','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(931877,'printshop','.w-reviews-content .review','padding-bottom','10','','','.w-reviews-content'),(931878,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom','0','','','.b-data-table'),(931879,'printshop','.b-data-table table.dataTable tbody td','padding-bottom','10','','','.b-data-table'),(931880,'printshop','.b-data-table table.dataTable thead td','padding-bottom','10','','','.b-data-table'),(931881,'printshop','.b-compare .popupCompare .pop-up-content','padding-bottom','10','','','.b-compare'),(931883,'printshop','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(931884,'printshop','.btn-2','padding-bottom','8','','',''),(931886,'printshop','.w-quote-products .empty','padding-bottom','100','','','.w-quote-products'),(931887,'printshop','.b-table .table td','padding-bottom','15','','','.b-table'),(931888,'printshop','.b-info .info ul','padding-bottom','0','','','.b-info'),(931889,'printshop','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(931890,'printshop','.b-compare .col-gender','padding-bottom','10','','','.b-compare'),(931891,'printshop','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(931892,'printshop','.b-email .totals-title','padding-bottom','5','','','.b-email'),(931893,'printshop','.b-email .qty','padding-bottom','5','','','.b-email'),(931894,'printshop','.btn','padding-bottom','8','','',''),(931895,'printshop','.b-product-images .media-popup .mp-content','padding-bottom','0','','','.b-product-images'),(931896,'printshop','.b-product-images .media-popup .mp-small-images .item','padding-bottom','10','','','.b-product-images'),(931897,'printshop','.b-product-images .media-popup .slick-dots','padding-bottom','0','','','.b-product-images'),(931898,'printshop','.b-product-images .media-popup .slick-dots li','padding-bottom','0','','','.b-product-images'),(931899,'printshop','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-bottom','0','','','.b-menu-style'),(931900,'printshop','.b-personal-catalog-popup #personal_catalog_popup','padding-bottom','20','','','.b-personal-catalog-popup'),(931901,'printshop','.b-trade-approval .steps-bar li a','padding-bottom','7','','','.b-trade-approval'),(931902,'printshop','.b-trade-approval .middle-form','padding-bottom','20','','','.b-trade-approval'),(931903,'printshop','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-bottom','5','','','.b-trade-approval'),(931904,'printshop','.b-trade-approval .steps-bar','padding-bottom','0','','','.b-trade-approval'),(931905,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-bottom','6','','','.b-trade-approval'),(931906,'printshop','.b-trade-approval .center-buttons','padding-bottom','20','','','.b-trade-approval'),(931907,'printshop','.w-account-personal-catalog .list-switcher','padding-bottom','0','','','.w-account-personal-catalog'),(931908,'printshop','.w-account-personal-catalog .list-switcher a','padding-bottom','12','','','.w-account-personal-catalog'),(931909,'printshop','.w-account-subscription .subscription-variant','padding-bottom','10','','','.w-account-subscription'),(931910,'printshop','.w-catalog-additional-images li','padding-bottom','10','','','.w-catalog-additional-images'),(931911,'printshop','.w-catalog-additional-images ul','padding-bottom','0','','','.w-catalog-additional-images'),(931912,'printshop','.w-catalog-compare td','padding-bottom','10','','','.w-catalog-compare'),(931913,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-bottom','0','','','.w-catalog-compare'),(931914,'printshop','.w-catalog-compare .cross-box .different-all > div','padding-bottom','11','2','','.w-catalog-compare'),(931915,'printshop','.w-catalog-compare .cross-box .different-all > div','padding-bottom','10','','','.w-catalog-compare'),(931916,'printshop','.w-delivery-day .left-count','padding-bottom','0','','','.w-delivery-day'),(931917,'printshop','.w-delivery-day .left-text-left','padding-bottom','24','','','.w-delivery-day'),(931918,'printshop','.w-delivery-day .left-text-right','padding-bottom','24','','','.w-delivery-day'),(931919,'printshop','.w-top-text .top-text','padding-bottom','5','','','.w-top-text'),(931920,'printshop','.w-cart-listing .points','padding-bottom','0','5333','','.w-cart-listing'),(931921,'printshop','.w-product-images .additional-horizontal .item','padding-bottom','10','','','.w-product-images'),(931922,'printshop','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-bottom','10','','','.b-cookie-notice'),(931923,'printshop','.lowestPricedBox .w-banner .single_banner','padding-bottom','0','','','.lowestPricedBox'),(931924,'printshop','.lowestPricedBox .w-banner .banner','padding-bottom','30','','','.lowestPricedBox'),(931925,'printshop','.tripleBanner ','padding-bottom','30','','','.tripleBanner'),(931926,'printshop','.tripleBanner > .block','padding-bottom','0','','','.tripleBanner'),(931927,'printshop','.tripleBanner .w-html_box','padding-bottom','16','','','.tripleBanner'),(931928,'printshop','.shopByCollectionBox .w-banner .single_banner','padding-bottom','0','','','.shopByCollectionBox'),(931929,'printshop','.b-slick .slick-list','padding-bottom','0','','','.b-slick'),(931930,'printshop','.b-slick .slick-vertical button.slick-next','padding-bottom','0','3','','.b-slick'),(931931,'printshop','.b-slick .slick-vertical button.slick-prev','padding-bottom','0','3','','.b-slick'),(931932,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','padding-bottom','0','','','.b-slick'),(931933,'printshop','.w-cart-listing .headings .head','padding-bottom','10','','','.w-cart-listing'),(931934,'printshop','.b-products-listing .item-nav > div','padding-bottom','10','','','.b-products-listing'),(931935,'printshop','.LeftCategories .w-menu-simple ul','padding-bottom','0','','','.LeftCategories'),(931936,'printshop','.LeftCategories .w-menu-simple ul li a','padding-bottom','4','','','.LeftCategories'),(931937,'printshop','.w-filters .filter-widget','padding-bottom','20','','','.w-filters'),(931938,'printshop','.b-products-listing .products-listing.list-productlisting .item','padding-bottom','20','','','.b-products-listing'),(931939,'printshop','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-bottom','15','','','.b-products-listing'),(931940,'printshop','.b-products-listing .products-listing.list-rows .item-nav > div','padding-bottom','0','','','.b-products-listing'),(931941,'printshop','.w-breadcrumb .breadcrumb-li','padding-bottom','0','','','.w-breadcrumb'),(931942,'printshop','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(931943,'printshop','.w-subscribers .btn-submit','padding-bottom','6','','','.w-subscribers'),(931944,'printshop','.w-quote .buttons','padding-bottom','15','','','.w-quote'),(931945,'printshop','.w-quote .buttons .btn','padding-bottom','4','','','.w-quote'),(931946,'printshop','.w-quote .cart-content','padding-bottom','5','','','.w-quote'),(931947,'printshop','.w-quote .cart-total','padding-bottom','10','','','.w-quote'),(931948,'printshop','.w-quote .multicart .cart-content','padding-bottom','0','','','.w-quote'),(931949,'printshop','.w-quote .multicart .item','padding-bottom','15','','','.w-quote'),(931950,'printshop','.w-quote .multicart .name','padding-bottom','0','','','.w-quote'),(931951,'printshop','.w-quote .no-text','padding-bottom','0','','','.w-quote'),(931952,'printshop','.w-quote a.item','padding-bottom','5','','','.w-quote'),(931953,'printshop','.w-product-images .additional-vertical .additional-images','padding-bottom','30','','','.w-product-images'),(931954,'printshop','.w-product-model > div','padding-bottom','7','','','.w-product-model'),(931955,'printshop','.w-product-sale-ends .left-count','padding-bottom','0','','','.w-product-sale-ends'),(931956,'printshop','.w-product-sale-ends .left-text-left','padding-bottom','24','','','.w-product-sale-ends'),(931957,'printshop','.w-product-sale-ends .left-text-right','padding-bottom','24','','','.w-product-sale-ends'),(931958,'printshop','.w-product-sale-ends .left-count-days','padding-bottom','7','','','.w-product-sale-ends'),(931959,'printshop','.w-product-sale-ends .left-count-hours','padding-bottom','7','','','.w-product-sale-ends'),(931960,'printshop','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(931961,'printshop','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(931962,'printshop','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(931963,'printshop','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(931964,'printshop','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(931965,'printshop','.warrantyProduct .warranty, .warrantyProduct .delivery','padding-bottom','10','','','.warrantyProduct'),(931966,'printshop','.w-compare .compare-list-buttons','padding-bottom','10','','','.w-compare'),(931967,'printshop','.w-compare .item-holder','padding-bottom','10','','','.w-compare'),(931968,'printshop','.w-compare .compare-list-products','padding-bottom','0','','','.w-compare'),(931969,'printshop','.w-files-catalog-widgets-files-catalog .name','padding-bottom','10','','','.w-files-catalog-widgets-files-catalog'),(931970,'printshop','.w-sample .buttons','padding-bottom','15','','','.w-sample'),(931971,'printshop','.w-sample .buttons .btn','padding-bottom','4','','','.w-sample'),(931972,'printshop','.w-sample .cart-box-link','padding-bottom','0','','','.w-sample'),(931973,'printshop','.w-sample .cart-content','padding-bottom','5','','','.w-sample'),(931974,'printshop','.w-sample .cart-total','padding-bottom','10','','','.w-sample'),(931975,'printshop','.w-sample .multicart .cart-content','padding-bottom','0','','','.w-sample'),(931976,'printshop','.w-sample .multicart .item','padding-bottom','15','','','.w-sample'),(931977,'printshop','.w-sample .multicart .name','padding-bottom','0','','','.w-sample'),(931978,'printshop','.w-sample .no-text','padding-bottom','0','','','.w-sample'),(931979,'printshop','.w-sample a.item','padding-bottom','5','','','.w-sample'),(931980,'printshop','.w-cart-listing .item > div.points','padding-bottom','0','','','.w-cart-listing'),(931981,'printshop','.w-filters-simple .integrate-price-holder','padding-bottom','10','','','.w-filters-simple'),(931982,'printshop','.w-product-video .item','padding-bottom','10','','','.w-product-video'),(931983,'printshop','.w-cart-bonus-points .title','padding-bottom','5','','','.w-cart-bonus-points'),(931984,'printshop','.shipping-ico .heading-3','padding-bottom','10','','','.shipping-ico'),(931985,'printshop','.w-cart-order-reference .btn','padding-bottom','4','','','.w-cart-order-reference'),(931986,'printshop','.w-cart-gift-certificate .btn','padding-bottom','4','','','.w-cart-gift-certificate'),(931987,'printshop','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(931988,'printshop','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(931989,'printshop','.w-product-in-bundles .attributes-item','padding-bottom','10','','','.w-product-in-bundles'),(931990,'printshop','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(931991,'printshop','.w-cart-listing .item > div.actions','padding-bottom','10','5333','','.w-cart-listing'),(931993,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-bottom','0','','','.b-products-listing'),(931994,'printshop','.b-pagination ul.pagination','padding-bottom','0','','','.b-pagination'),(931995,'printshop','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','padding-bottom','10','','','.w-catalog-compare'),(931996,'printshop','.w-product-properties-filters-widgets-chosen-filters .item','padding-bottom','3','','','.w-product-properties-filters-widgets-chosen-filters'),(931997,'printshop','.p-quote-checkout-index .datepicker-inline','padding-bottom','10','','','.p-quote-checkout-index'),(931998,'printshop','.p-sample-checkout-index .datepicker-inline','padding-bottom','10','','','.p-sample-checkout-index'),(932002,'printshop','.w-product-multi-inventory .radio-attributes','padding-bottom','5','','','.w-product-multi-inventory'),(932003,'printshop','.w-product-multi-inventory .radio-attributes .option-item','padding-bottom','10','','','.w-product-multi-inventory'),(932004,'printshop','.w-product-multi-inventory .radio-attributes > label','padding-bottom','10','','','.w-product-multi-inventory'),(932005,'printshop','.w-account-personal-catalog .list-row-action ul','padding-bottom','0','','','.w-account-personal-catalog'),(932006,'printshop','.w-account-personal-catalog .list-row-action li','padding-bottom','5','','','.w-account-personal-catalog'),(932007,'printshop','.w-account-personal-catalog .buy-box','padding-bottom','0','5333','','.w-account-personal-catalog'),(932008,'printshop','.b-products-listing .products-listing .radio-attributes','padding-bottom','5','','','.b-products-listing'),(932009,'printshop','.b-products-listing .products-listing .radio-attributes .option','padding-bottom','10','','','.b-products-listing'),(932010,'printshop','.b-products-listing .products-listing .radio-attributes > label','padding-bottom','10','','','.b-products-listing'),(932011,'printshop','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(932012,'printshop','.w-product-collection .right-area .btn','padding-bottom','14','','','.w-product-collection'),(932013,'printshop','.w-product-collection .right-area','padding-bottom','20','5342','','.w-product-collection'),(932014,'printshop','.w-product-attributes .radio-attributes','padding-bottom','5','','','.w-product-attributes'),(932015,'printshop','.w-product-attributes .radio-attributes .option-item','padding-bottom','10','','','.w-product-attributes'),(932016,'printshop','.w-product-attributes .radio-attributes > label','padding-bottom','10','','','.w-product-attributes'),(932017,'printshop','.w-product-properties .property-ul','padding-bottom','0','','','.w-product-properties'),(932018,'printshop','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(932019,'printshop','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(932020,'printshop','.w-product-groups ','padding-bottom','30','','','.w-product-groups'),(932021,'printshop','.w-product-groups .radioBox','padding-bottom','20','','','.w-product-groups'),(932022,'printshop','.w-product-groups .radioBox label','padding-bottom','0','','','.w-product-groups'),(932023,'printshop','.w-product-groups .radioBox label .containerBlock','padding-bottom','20','','','.w-product-groups'),(932024,'printshop','.w-product-groups .radioBox label .containerBlock','padding-bottom','5','5363','','.w-product-groups'),(932025,'printshop','.b-products-listing .mix-attributes .attribute-qty-block','padding-bottom','5','','','.b-products-listing'),(932026,'printshop','.b-products-listing .products-listing .attribute-qty-block','padding-bottom','5','','','.b-products-listing'),(932027,'printshop','.blogsidebar','padding-bottom','0','5342','',''),(932028,'printshop','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(932029,'printshop','.w-product-custom-bundle .chosen-products','padding-bottom','10','','','.w-product-custom-bundle'),(932030,'printshop','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-bottom','12','','','.w-product-custom-bundle'),(932031,'printshop','.w-product-custom-bundle .right-area .main-button','padding-bottom','20','5342','','.w-product-custom-bundle'),(932032,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list'),(932033,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list'),(932034,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list-block'),(932035,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list-block'),(932036,'printshop','.w-delivery-location-top-location-list .deliveryName','padding-bottom','10','','','.w-delivery-location-top-location-list'),(932037,'printshop','.w-delivery-location-location-list .deliveryName','padding-bottom','10','','','.w-delivery-location-location-list'),(932038,'printshop','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(932039,'printshop','.w-delivery-location-location-description .deliveryDesc','padding-bottom','10','','','.w-delivery-location-location-description'),(932040,'printshop','.w-delivery-location-location-long-description ','padding-bottom','20','','','.w-delivery-location-location-long-description'),(932041,'printshop','.w-delivery-location-location-list .deliveryListParrent a','padding-bottom','6','','','.w-delivery-location-location-list'),(932042,'printshop','.w-delivery-location-location-list .deliveryList li a','padding-bottom','10','','','.w-delivery-location-location-list'),(932043,'printshop','.w-delivery-location-featured-list .deliveryName','padding-bottom','10','','','.w-delivery-location-featured-list'),(932044,'printshop','.btn-2','padding-bottom','6','5333','',''),(932045,'printshop','.w-sale-category .holder-1','padding-bottom','20','','','.w-sale-category'),(932046,'printshop','.w-sale-category .holder-2','padding-bottom','20','','','.w-sale-category'),(932047,'printshop','.w-sale-category .left-count','padding-bottom','0','','','.w-sale-category'),(932048,'printshop','.w-sale-category .left-text-left','padding-bottom','24','','','.w-sale-category'),(932049,'printshop','.w-sale-category .left-text-right','padding-bottom','24','','','.w-sale-category'),(932050,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(932051,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(932052,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(932053,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(932054,'printshop','.w-product-properties-icons .property-image','padding-bottom','10','','','.w-product-properties-icons'),(932055,'printshop','.w-product-properties-icons .hover-box-content','padding-bottom','10','','','.w-product-properties-icons'),(932056,'printshop','.w-delivery-location-product-categories .item.category-link','padding-bottom','15','','','.w-delivery-location-product-categories'),(932057,'printshop','.w-delivery-location-product-categories .item.category-link','padding-bottom','10','5342','','.w-delivery-location-product-categories'),(932058,'printshop','.w-delivery-location-product-categories .item.category-link','padding-bottom','10','5363','','.w-delivery-location-product-categories'),(932059,'printshop','.w-delivery-location-product-categories .name','padding-bottom','10','','','.w-delivery-location-product-categories'),(932060,'printshop','.w-catalog-delivery-locations .name','padding-bottom','10','','','.w-catalog-delivery-locations'),(932061,'printshop','.delivery-options-popup','padding-bottom','20','','',''),(932062,'printshop','.w-product-bonus-points .bonus-points-cost','padding-bottom','7','','','.w-product-bonus-points'),(932063,'printshop','.w-product-designer-designer .grnamebox .title-sortable','padding-bottom','8','','','.w-product-designer-designer'),(932064,'printshop','.w-product-designer-designer .prodDesignerType label','padding-bottom','10','','','.w-product-designer-designer'),(932065,'printshop','.w-press-reviews-widgets-press-reviews-small ','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews-small'),(932066,'printshop','.w-press-reviews-widgets-press-reviews ','padding-bottom','30','','','.w-press-reviews-widgets-press-reviews'),(932067,'printshop','.w-press-reviews-widgets-press-reviews .author','padding-bottom','20','','','.w-press-reviews-widgets-press-reviews'),(932068,'printshop','.w-press-reviews-widgets-press-reviews .item','padding-bottom','20','','','.w-press-reviews-widgets-press-reviews'),(932069,'printshop','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-bottom','30','','','.w-press-reviews-widgets-press-reviews'),(932070,'printshop','.w-press-reviews-widgets-press-reviews .rating','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews'),(932071,'printshop','.w-press-reviews-widgets-press-reviews .review','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews'),(932072,'printshop','.w-press-reviews-widgets-press-reviews ','padding-bottom','20','5333','','.w-press-reviews-widgets-press-reviews'),(932073,'printshop','.w-press-reviews-widgets-press-reviews .author','padding-bottom','0','5333','','.w-press-reviews-widgets-press-reviews'),(932074,'printshop','.w-press-reviews-widgets-press-reviews .item','padding-bottom','15','5333','','.w-press-reviews-widgets-press-reviews'),(932075,'printshop','.w-press-reviews-widgets-press-reviews .review','padding-bottom','10','5333','','.w-press-reviews-widgets-press-reviews'),(932076,'printshop','.w-press-reviews-widgets-press-reviews-list .date-added','padding-bottom','20','','','.w-press-reviews-widgets-press-reviews-list'),(932077,'printshop','.w-press-reviews-widgets-press-reviews-list .item','padding-bottom','0','','','.w-press-reviews-widgets-press-reviews-list'),(932078,'printshop','.w-press-reviews-widgets-press-reviews-list .rating','padding-bottom','5','','','.w-press-reviews-widgets-press-reviews-list'),(932079,'printshop','.w-press-reviews-widgets-press-reviews-list .short-description','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(932080,'printshop','.b-products-listing .productGroup label a','padding-bottom','5','','','.b-products-listing'),(932081,'printshop','.w-support-system-filter ','padding-bottom','25','','','.w-support-system-filter'),(932082,'printshop','.w-support-system-filter .filter_cats','padding-bottom','0','','','.w-support-system-filter'),(932083,'printshop','.w-support-system-listing .support-head','padding-bottom','13','','','.w-support-system-listing'),(932084,'printshop','.w-communication-post .btn.refresh','padding-bottom','0','','','.w-communication-post'),(932085,'printshop','.w-rma-returns-history .btn','padding-bottom','7','','','.w-rma-returns-history'),(932086,'printshop','.w-rma-returns-history .column','padding-bottom','0','','','.w-rma-returns-history'),(932087,'printshop','.w-rma-returns-history .column .title','padding-bottom','5','','','.w-rma-returns-history'),(932088,'printshop','.w-rma-returns-history .topRow','padding-bottom','10','','','.w-rma-returns-history'),(932089,'printshop','.w-rma-returns-history .column:last-child .title','padding-bottom','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(932090,'printshop','.w-product-designer-designer .productDesignerBox ul','padding-bottom','0','','','.w-product-designer-designer'),(932091,'printshop','.w-product-configurator .pc-item','padding-bottom','0','','','.w-product-configurator'),(932092,'printshop','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(932093,'printshop','.w-product-configurator .pc_item','padding-bottom','10','5342','','.w-product-configurator'),(932094,'printshop','.w-product-configurator .pc_attr','padding-bottom','5','5333','','.w-product-configurator'),(932095,'printshop','.b-products-listing .products-listing .bonus-points-cost','padding-bottom','7','','','.b-products-listing'),(932096,'printshop','.b-products-listing .promos-info .promo-name-span','padding-bottom','3','','','.b-products-listing'),(932097,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-list'),(932098,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-bottom','20','','','.w-catalog-pages-category-pages-list'),(932099,'printshop','.w-predefined-promotion .nextdiscount .content > div','padding-bottom','10','','','.w-predefined-promotion'),(932100,'printshop','.w-predefined-promotion .nextdiscount .promo-for-each','padding-bottom','2','','','.w-predefined-promotion'),(932101,'printshop','.w-predefined-promotion .prom-multi-discount .promo-product','padding-bottom','20','','','.w-predefined-promotion'),(932102,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','padding-bottom','0','','','.w-predefined-promotion'),(932103,'printshop','.w-predefined-promotion .promo-cart-discount .master .item','padding-bottom','20','','','.w-predefined-promotion'),(932104,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-bottom','0','','','.w-predefined-promotion'),(932105,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-bottom','0','','','.w-predefined-promotion'),(932106,'printshop','.w-predefined-promotion .promo-cart-discount .slave .heading','padding-bottom','1','','','.w-predefined-promotion'),(932107,'printshop','.w-predefined-promotion .promo-cart-discount .slave .item','padding-bottom','20','','','.w-predefined-promotion'),(932108,'printshop','.w-predefined-promotion .promo-item','padding-bottom','20','','','.w-predefined-promotion'),(932109,'printshop','.w-predefined-promotion .promo-salemaker .discount','padding-bottom','0','','','.w-predefined-promotion'),(932110,'printshop','.w-predefined-promotion .promo-salemaker .item','padding-bottom','20','','','.w-predefined-promotion'),(932111,'printshop','.w-supplier-purchase-supplier-products .item','padding-bottom','10','','','.w-supplier-purchase-supplier-products'),(932116,'printshop','.b-products-listing .products-listing .compare .checkbox input:not(checked) + span:before','padding-bottom','0','','','.b-products-listing'),(932117,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','padding-bottom','10','','','.w-filters'),(932118,'printshop','.w-filters .filter-widget-horizontal .filter-box-head','padding-bottom','0','','','.w-filters'),(932119,'printshop','.b-quantity .qty-box input[type=\"text\"]','padding-bottom','5','','','.b-quantity'),(932120,'printshop','.w-product-model ','padding-bottom','10','','','.w-product-model'),(932121,'printshop','.w-product-model > div:last-of-type','padding-bottom','0','','','.w-product-model'),(932122,'printshop','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(932123,'printshop','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(932124,'printshop','.lowestPricedBox .btn-2','padding-bottom','16','','','.lowestPricedBox'),(932125,'printshop','.doubleBanner .btn-2','padding-bottom','16','','','.doubleBanner'),(932126,'printshop','.doubleBanner .btn-2','padding-bottom','10','5347','','.doubleBanner'),(932127,'printshop','.middleBanner .btn-1','padding-bottom','17','','','.middleBanner'),(932128,'printshop','.middleBanner .title','padding-bottom','20','','','.middleBanner'),(932129,'printshop','.middleBanner .descr','padding-bottom','30','','','.middleBanner'),(932130,'printshop','.bottomDoubleBanner .btn-2','padding-bottom','16','','','.bottomDoubleBanner'),(932131,'printshop','.bottomDoubleBanner .btn-2','padding-bottom','10','5347','','.bottomDoubleBanner'),(932132,'printshop','.bottomDoubleBanner .title','padding-bottom','20','','','.bottomDoubleBanner'),(932133,'printshop','.bottomBanner .title','padding-bottom','20','','','.bottomBanner'),(932134,'printshop','.bottomBanner .descr','padding-bottom','20','','','.bottomBanner'),(932135,'printshop','.bottomBanner .btn-1','padding-bottom','17','','','.bottomBanner'),(932136,'printshop','.bottomBanner .wrapper','padding-bottom','20','','','.bottomBanner'),(932137,'printshop','.bottomBanner .icon-box > div','padding-bottom','0','','','.bottomBanner'),(932138,'printshop','.bottomBanner .icon-box','padding-bottom','20','','','.bottomBanner'),(932139,'printshop','.topBanner > .block','padding-bottom','0','','','.topBanner'),(932142,'printshop','.doubleBanner .title','padding-bottom','20','5363','','.doubleBanner'),(932143,'printshop','.middleBanner .btn-1','padding-bottom','12','5342','','.middleBanner'),(932144,'printshop','.middleBanner .btn-1','padding-bottom','8','5333','','.middleBanner'),(932145,'printshop','.bottomBanner .btn-1','padding-bottom','11','5347','','.bottomBanner'),(932146,'printshop','.bottomBanner .icon-box','padding-bottom','20','5347','','.bottomBanner'),(932147,'printshop','.bottomBanner .icon-box > div','padding-bottom','0','5347','','.bottomBanner'),(932148,'printshop','.tripleLine .w-banner .image-text-banner.bottom-center','padding-bottom','20','5363','','.tripleLine'),(932149,'printshop','.w-multi-cart-save-cart .btn','padding-bottom','8','5363','','.w-multi-cart-save-cart'),(932150,'printshop','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-bottom','0','','','.b-products-listing'),(932151,'printshop','.b-products-listing .products-listing.list-productlisting .item','padding-bottom','10','5363','','.b-products-listing'),(932152,'printshop','.w-filters .filter-widget','padding-bottom','10','5342','','.w-filters'),(932153,'printshop','.w-tabs > .block','padding-bottom','10','5363','','.w-tabs'),(932154,'printshop','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-bottom','10','5363','','.b-products-listing'),(932155,'printshop','.w-account-personal-catalog .buy-box','padding-bottom','0','5363','','.w-account-personal-catalog'),(932156,'printshop','.trade_form > .type-1 > .block','padding-bottom','0','','',''),(932157,'printshop','.p-payer-order-pay .price-row','padding-bottom','5','','','.p-payer-order-pay'),(932158,'printshop','.p-payer-order-pay .payer > .type-1 > .block','padding-bottom','0','','','.p-payer-order-pay'),(932159,'printshop','.p-payer-order-confirmation .payer > .type-1 > .block','padding-bottom','0','','','.p-payer-order-confirmation'),(932160,'printshop','.p-payer-order-confirmation .price-row','padding-bottom','5','','','.p-payer-order-confirmation'),(932161,'printshop','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','padding-bottom','8','','','.w-product-buttons'),(932162,'printshop','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','padding-bottom','14','5363','','.w-product-buttons'),(932163,'printshop','.w-product-groups ','padding-bottom','0','5347','','.w-product-groups'),(932164,'printshop','.b-products-listing .products-listing .compare','padding-bottom','10','5342','','.b-products-listing'),(932165,'printshop','.topBanner .content .btn','padding-bottom','1','','','.topBanner'),(932166,'printshop','.topBanner .descr','padding-bottom','40','','','.topBanner'),(932167,'printshop','.topBanner .ourPick .bottom','padding-bottom','0.25','','','.topBanner'),(932168,'printshop','.topBanner .ourPick .top','padding-bottom','0','','','.topBanner'),(932169,'printshop','.topBanner .title','padding-bottom','20','','','.topBanner'),(932170,'printshop','.topBanner .content .btn','padding-bottom','16','5410','','.topBanner'),(932171,'printshop','.topBanner .descr','padding-bottom','20','5347','','.topBanner'),(932172,'printshop','.topBanner .content .btn','padding-bottom','12','5342','','.topBanner'),(932173,'printshop','.topBanner .ourPick .top','padding-bottom','0','5342','','.topBanner'),(932174,'printshop','.topBanner .title','padding-bottom','10','5342','','.topBanner'),(932175,'printshop','.topBanner .content','padding-bottom','0','5333','','.topBanner'),(932176,'printshop','.topBanner .descr','padding-bottom','5','5333','','.topBanner'),(932177,'printshop','.topBanner .content .btn','padding-bottom','5','5363','','.topBanner'),(932178,'printshop','.bottomBanner .btn-1','padding-bottom','6','5363','','.bottomBanner'),(932179,'printshop','.bottomBanner .wrapper','padding-bottom','15','5363','','.bottomBanner'),(932180,'printshop','.middleBanner .btn-1','padding-bottom','6','5363','','.middleBanner'),(932181,'printshop','.w-promotions-widgets-promotion-icons-desc .w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','padding-bottom','5','','','.w-promotions-widgets-promotion-icons-desc'),(932182,'printshop','.tripleLine .w-banner .banner-item.text-bottom-center','padding-bottom','20','5363','','.tripleLine'),(932183,'printshop','.order-summary ','padding-bottom','10','','','.order-summary'),(932184,'printshop','.order-summary .w-cart-listing .item > div ~ div','padding-bottom','10','','','.order-summary'),(932185,'printshop','.order-summary ','padding-bottom','10','5333','','.order-summary'),(932186,'printshop','.w-cart-discount-coupon .discount-box','padding-bottom','5','','','.w-cart-discount-coupon'),(932187,'printshop','.w-cart-shipping-estimator .shipping-estimator','padding-bottom','30','','','.w-cart-shipping-estimator'),(932188,'printshop','.p-quote-checkout-index .edit-address-popup','padding-bottom','20','','','.p-quote-checkout-index'),(932189,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','padding-bottom','6','','','.p-quote-checkout-index'),(932190,'printshop','.w-quote-products ','padding-bottom','10','','','.w-quote-products'),(932195,'printshop','.account-address-book .address_book','padding-bottom','30','','','.account-address-book'),(932196,'printshop','.account-address-book .address_book h1','padding-bottom','5','','','.account-address-book'),(932197,'printshop','.account-address-book .address_book h2','padding-bottom','10','','','.account-address-book'),(932198,'printshop','.account-address-book .address_book, .account-address-book .account_history_info','padding-bottom','10','','','.account-address-book'),(932199,'printshop','.account-address-book .buttonBox','padding-bottom','15','','','.account-address-book'),(932200,'printshop','.account-address-book .rightMes ul','padding-bottom','0','','','.account-address-book'),(932201,'printshop','.account-address-book .topButtons','padding-bottom','15','','','.account-address-book'),(932237,'printshop','.account-order-pay .contentColumn','padding-bottom','10','','','.account-order-pay'),(932238,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-bottom','5','','','.account-order-pay'),(932239,'printshop','.account-order-pay .history_info > div + div','padding-bottom','0','','','.account-order-pay'),(932240,'printshop','.account-order-pay .history_info > div','padding-bottom','0','5342','','.account-order-pay'),(932241,'printshop','.account-order-pay .history_info > div + div','padding-bottom','0','5342','','.account-order-pay'),(932242,'printshop','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-bottom','10','','','.account-samples'),(932243,'printshop','.account-samples .orders-table th','padding-bottom','2','','','.account-samples'),(932244,'printshop','.account-samples .order_history_table th','padding-bottom','10','','','.account-samples'),(932245,'printshop','.account-samples .view_link','padding-bottom','0','','','.account-samples'),(932246,'printshop','.account-samples .orders-table .item','padding-bottom','60','5342','','.account-samples'),(932247,'printshop','.account-samples .orders-table .td-alignright','padding-bottom','5','5342','','.account-samples'),(932248,'printshop','.account-samples .orders-table td','padding-bottom','5','5342','','.account-samples'),(932249,'printshop','.account-sample-info .contentColumn','padding-bottom','10','','','.account-sample-info'),(932250,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-bottom','5','','','.account-sample-info'),(932251,'printshop','.account-sample-info .history_info > div + div','padding-bottom','0','','','.account-sample-info'),(932252,'printshop','.account-sample-info .popup-tracking-number','padding-bottom','10','','','.account-sample-info'),(932253,'printshop','.account-sample-info .history_info > div','padding-bottom','0','5342','','.account-sample-info'),(932254,'printshop','.account-sample-info .history_info > div + div','padding-bottom','0','5342','','.account-sample-info'),(932255,'printshop','.catalog-product-wrap .next-product','padding-bottom','20','','','.catalog-product-wrap'),(932256,'printshop','.catalog-product-wrap .pn-direction','padding-bottom','0','','','.catalog-product-wrap'),(932257,'printshop','.catalog-product-wrap .pn-image','padding-bottom','20','','','.catalog-product-wrap'),(932258,'printshop','.catalog-product-wrap .prev-product','padding-bottom','20','','','.catalog-product-wrap'),(932259,'printshop','.catalog-product-wrap .next-product','padding-bottom','20','5342','','.catalog-product-wrap'),(932260,'printshop','.catalog-product-wrap .pn-direction','padding-bottom','0','5342','','.catalog-product-wrap'),(932261,'printshop','.catalog-product-wrap .prev-product','padding-bottom','20','5342','','.catalog-product-wrap'),(932262,'printshop','.shopping-cart-index .btn-3','padding-bottom','11','','','.shopping-cart-index'),(932263,'printshop','.shopping-cart-index .cart-page .empty','padding-bottom','100','','','.shopping-cart-index'),(932264,'printshop','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-bottom','10','','','.shopping-cart-index'),(932265,'printshop','.checkout-index-wrap .datepicker-inline','padding-bottom','10','','','.checkout-index-wrap'),(932266,'printshop','.checkout-index-wrap .edit-address-popup','padding-bottom','20','','','.checkout-index-wrap'),(932267,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-bottom','6','','','.checkout-index-wrap'),(932268,'printshop','.checkout-index-wrap .hiding-box .checkout-cart-listing','padding-bottom','30','','','.checkout-index-wrap'),(932269,'printshop','.checkout-order-confirmation .price-row','padding-bottom','5','','','.checkout-order-confirmation'),(932270,'printshop','.b-bottom .pop-up-content','padding-bottom','20','','','.b-bottom'),(932271,'printshop','.b-form .columns .col-2','padding-bottom','0','','','.b-form'),(932272,'printshop','.b-slick .slick-dots li','padding-bottom','5','','','.b-slick'),(932273,'printshop','.success-page .check-ico-block','padding-bottom','0','','','.success-page'),(932274,'printshop','.success-page .order_totals .price-row','padding-bottom','5','','','.success-page'),(932275,'printshop','.success-page .price-row','padding-bottom','5','','','.success-page'),(932276,'printshop','.success-page .w-cart-listing .qty','padding-bottom','0','','','.success-page'),(932277,'printshop','.b-multi-page-checkout .multi-page-checkout .buttons','padding-bottom','0','','','.b-multi-page-checkout'),(932278,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-bottom','20','','','.b-multi-page-checkout'),(932279,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-bottom','6','','','.b-multi-page-checkout'),(932280,'printshop','.tripleLine .banner-text','padding-bottom','0','','','.tripleLine'),(932281,'printshop','.doubleBanner .w-banner .banner-holder','padding-bottom','30','','','.doubleBanner'),(932282,'printshop','.doubleBanner .w-banner .banner-item','padding-bottom','0','','','.doubleBanner'),(932283,'printshop','.doubleBanner .w-banner .banner-text','padding-bottom','0','','','.doubleBanner'),(932284,'printshop','.middleBanner .banner-text-holder','padding-bottom','15','5363','','.middleBanner'),(932285,'printshop','.middleBanner div.banner-text-holder','padding-bottom','20','','','.middleBanner'),(932286,'printshop','.middleBanner div.banner-text','padding-bottom','0','','','.middleBanner'),(932287,'printshop','.bottomBanner .w-banner .banner-text','padding-bottom','0','','','.bottomBanner'),(932288,'printshop','.bottomDoubleBanner .w-banner .banner-holder','padding-bottom','30','','','.bottomDoubleBanner'),(932289,'printshop','.bottomDoubleBanner .w-banner .banner-text-holder','padding-bottom','0','','','.bottomDoubleBanner'),(932290,'printshop','.bottomDoubleBanner .w-banner .banner-text','padding-bottom','0','','','.bottomDoubleBanner'),(932291,'printshop','.bottomDoubleBanner .w-banner .banner-holder','padding-bottom','0','5363','','.bottomDoubleBanner'),(932292,'printshop','.bottomDoubleBanner .w-banner .banner-item','padding-bottom','0','','','.bottomDoubleBanner'),(932297,'printshop','.footer-menu ','padding-bottom','20','5342','','.footer-menu'),(932298,'printshop','.footer-menu .level-1 > li > .no-link','padding-bottom','10','5342','','.footer-menu'),(932299,'printshop','.footer-menu .level-2','padding-bottom','20','5342','','.footer-menu'),(932300,'printshop','.w-bestsellers .heading-3','padding-bottom','15','','','.w-bestsellers'),(932301,'printshop','.w-banner .banner-text','padding-bottom','20','','','.w-banner'),(932302,'printshop','.w-banner .carousel-text > span','padding-bottom','20','','','.w-banner'),(932303,'printshop','.w-catalog-paging .paging-item','padding-bottom','0','','','.w-catalog-paging'),(932307,'printshop','.w-sale .holder-1','padding-bottom','20','','','.w-sale'),(932308,'printshop','.w-sale .holder-2','padding-bottom','20','','','.w-sale'),(932309,'printshop','.w-sale .left-count','padding-bottom','0','','','.w-sale'),(932310,'printshop','.w-sale .left-text-left','padding-bottom','24','','','.w-sale'),(932311,'printshop','.w-sale .left-text-right','padding-bottom','24','','','.w-sale'),(932312,'printshop','.w-social-links a','padding-bottom','4','','','.w-social-links'),(932313,'printshop','.b-data-table table.dataTable tbody td','padding-bottom_important','important','','','.b-data-table'),(932314,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom_important','important','','','.b-data-table'),(932315,'printshop','.b-data-table table.dataTable thead td','padding-bottom_important','important','','','.b-data-table'),(932316,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom_important','important','','','.b-data-table'),(932317,'printshop','.w-cart-listing .points','padding-bottom_important','important','5333','','.w-cart-listing'),(932318,'printshop','.w-account-personal-catalog .buy-box','padding-bottom_important','important','5333','','.w-account-personal-catalog'),(932319,'printshop','.topBanner > .block','padding-bottom_important','important','','','.topBanner'),(932320,'printshop','.w-account-personal-catalog .buy-box','padding-bottom_important','important','5363','','.w-account-personal-catalog'),(932321,'printshop','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-left','10','','','.w-communication-new-topic'),(932322,'printshop','.b-email .heading-name','padding-left','10','','','.b-email'),(932323,'printshop','.b-email .name','padding-left','10','','','.b-email'),(932324,'printshop','.b-email .heading-image','padding-left','10','','','.b-email'),(932325,'printshop','.b-email .heading-price','padding-left','10','','','.b-email'),(932326,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(932327,'printshop','.order-summary .btn-2, .order-summary .btn-3','padding-left','5','','','.order-summary'),(932328,'printshop','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(932329,'printshop','.w-promo-code .holder','padding-left','20','5363','','.w-promo-code'),(932332,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(932333,'printshop','.b-email .totals-value','padding-left','10','','','.b-email'),(932334,'printshop','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(932335,'printshop','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-left','10','','','.p-quick-order-index'),(932336,'printshop','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-left','10','','','.p-quick-order-index'),(932337,'printshop','.p-quick-order-index ul.token-input-list','padding-left','0','','','.p-quick-order-index'),(932338,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.p-quick-order-index'),(932339,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.p-quick-order-index'),(932340,'printshop','.w-promotions .promo-item','padding-left','40','','','.w-promotions'),(932341,'printshop','.w-top-categories h2.name','padding-left','3','','','.w-top-categories'),(932342,'printshop','.w-cart-compare .attributes-label','padding-left','10','','','.w-cart-compare'),(932348,'printshop','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(932349,'printshop','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(932350,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(932351,'printshop','.b-email .heading-price','padding-left','10','','','.b-email'),(932352,'printshop','.b-email .name','padding-left','10','','','.b-email'),(932353,'printshop','.testimonials .review','padding-left','10','','',''),(932354,'printshop','.testimonials .heading-3','padding-left','55','','',''),(932355,'printshop','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(932356,'printshop','.w-categories .image','padding-left','0','','','.w-categories'),(932357,'printshop','.w-promotions .prom-multi-discount .promo-range','padding-left','20','','','.w-promotions'),(932358,'printshop','.w-promotions .prom-multi-discount .promo-product','padding-left','20','','','.w-promotions'),(932359,'printshop','.w-promotions .nextdiscount .promo-for-each','padding-left','10','','','.w-promotions'),(932360,'printshop','.w-promotions .nextdiscount .content > div','padding-left','10','','','.w-promotions'),(932361,'printshop','.w-promotions .promo-salemaker .item','padding-left','20','','','.w-promotions'),(932362,'printshop','.w-promotions .promo-salemaker .promo-manufacturers','padding-left','12','','','.w-promotions'),(932363,'printshop','.w-promotions .promo-salemaker .discount','padding-left','20','','','.w-promotions'),(932364,'printshop','.w-promotions .promo-cart-discount .slave .item','padding-left','20','','','.w-promotions'),(932365,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','padding-left','20','','','.w-promotions'),(932366,'printshop','.w-promotions .promo-cart-discount .slave','padding-left','15','','','.w-promotions'),(932367,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','padding-left','20','','','.w-promotions'),(932368,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','padding-left','17','','','.b-warehouses-popup'),(932369,'printshop','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-left','20','','','.b-warehouses-popup'),(932370,'printshop','.w-product-available-in-warehouses .warehouse-item','padding-left','0','','','.w-product-available-in-warehouses'),(932371,'printshop','.w-checkout-create-account .account-benefits ul','padding-left','20','','','.w-checkout-create-account'),(932372,'printshop','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-left','2','','','.b-products-listing'),(932374,'printshop','.w-cart-compare .dropdown li','padding-left','10','','','.w-cart-compare'),(932375,'printshop','.w-cart-compare .attributes-cell','padding-left','20','','','.w-cart-compare'),(932377,'printshop','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(932379,'printshop','.w-login-block .new','padding-left','40','','','.w-login-block'),(932380,'printshop','.b-bottom .confirm-popup .confirm-text','padding-left','0','','','.b-bottom'),(932381,'printshop','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(932382,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(932383,'printshop','.b-messages .messages-menu ul','padding-left','0','','','.b-messages'),(932384,'printshop','.b-messages .development-content .type-6 .content','padding-left','0','','','.b-messages'),(932385,'printshop','.b-messages .msv_btn','padding-left','0','','','.b-messages'),(932386,'printshop','.b-messages .msv_content','padding-left','20','','','.b-messages'),(932387,'printshop','.b-messages .msv_history','padding-left','20','','','.b-messages'),(932388,'printshop','.b-messages .messMenuButton span','padding-left','15','','','.b-messages'),(932389,'printshop','.b-messages .messages-menu li a','padding-left','0','','','.b-messages'),(932390,'printshop','.b-messages .messages-menu li','padding-left','0','','','.b-messages'),(932391,'printshop','.b-messages .content_management_attach button','padding-left','27','','','.b-messages'),(932392,'printshop','.b-messages .email-heading','padding-left','15','','','.b-messages'),(932393,'printshop','.b-messages .content_management_attach','padding-left','8','','','.b-messages'),(932394,'printshop','.b-messages .emailLineTextArea textarea','padding-left','10','','','.b-messages'),(932395,'printshop','.b-messages .msv_to_cc','padding-left','15','','','.b-messages'),(932396,'printshop','.b-messages .emailBtn','padding-left','10','','','.b-messages'),(932397,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-left','10','','','.b-messages'),(932398,'printshop','.w-sitemap-delivery-location > ul > li > ul','padding-left','0','','','.w-sitemap-delivery-location'),(932399,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-left','10','','',''),(932400,'printshop','.w-sitemap-delivery-location > ul > li > ul ul','padding-left','20','','','.w-sitemap-delivery-location'),(932401,'printshop','.w-tabs .tab-navigation','padding-left','0','','','.w-tabs'),(932402,'printshop','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(932403,'printshop','.w-reviews-content .item','padding-left','0','','','.w-reviews-content'),(932404,'printshop','.p-quick-order-index .bottom','padding-left','0','','','.p-quick-order-index'),(932405,'printshop','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(932406,'printshop','.w-sitemap-delivery-location > ul','padding-left','0','','','.w-sitemap-delivery-location'),(932407,'printshop','.w-checkout-terms .required-message','padding-left','10','','','.w-checkout-terms'),(932408,'printshop','.w-cart-listing .item .remove','padding-left','10','5342','','.w-cart-listing'),(932409,'printshop','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(932410,'printshop','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(932411,'printshop','.w-socials > li','padding-left','15','','','.w-socials'),(932412,'printshop','.b-info .info','padding-left','40','','','.b-info'),(932413,'printshop','.b-form .required-message-wrap','padding-left','0','','','.b-form'),(932414,'printshop','.b-email .image','padding-left','10','','','.b-email'),(932415,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-preview','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(932416,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-details','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(932417,'printshop','.b-table .table .headings td','padding-left','10','','','.b-table'),(932418,'printshop','.b-info .info li','padding-left','0','','','.b-info'),(932419,'printshop','.b-email .model','padding-left','10','','','.b-email'),(932420,'printshop','.b-email .heading-name','padding-left','10','','','.b-email'),(932421,'printshop','.b-email .heading-model','padding-left','10','','','.b-email'),(932422,'printshop','.b-products-listing .products-listing .bonus-points-cost','padding-left','30','','','.b-products-listing'),(932423,'printshop','.w-login-block .guest','padding-left','40','','','.w-login-block'),(932424,'printshop','.w-login-block .new','padding-left','40','','','.w-login-block'),(932425,'printshop','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(932426,'printshop','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-left','10','','','.w-menu-horizontal'),(932427,'printshop','.w-menu-horizontal > ul > li > ul > li','padding-left','10','','','.w-menu-horizontal'),(932428,'printshop','.w-menu-horizontal ul','padding-left','0','','','.w-menu-horizontal'),(932429,'printshop','.b-table .table td','padding-left','15','','','.b-table'),(932430,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(932431,'printshop','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(932432,'printshop','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(932433,'printshop','.w-product-images-additional .images','padding-left','0','5363','','.w-product-images-additional'),(932434,'printshop','.b-form .login-col-1','padding-left','0','','','.b-form'),(932435,'printshop','.b-email .heading-image','padding-left','10','','','.b-email'),(932437,'printshop','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(932438,'printshop','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-left','0','','','.order-summary'),(932439,'printshop','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(932440,'printshop','.b-email .price','padding-left','10','','','.b-email'),(932441,'printshop','.b-email .heading-model','padding-left','10','','','.b-email'),(932443,'printshop','.w-categories .item','padding-left','20','','','.w-categories'),(932444,'printshop','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(932445,'printshop','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(932446,'printshop','.b-bottom .terms-info-popup .pop-up-content','padding-left','20','','','.b-bottom'),(932447,'printshop','.w-cart-compare .dropdown .dropdown-menu','padding-left','0','','','.w-cart-compare'),(932448,'printshop','textarea','padding-left','10','','',''),(932452,'printshop','.w-socials > li','padding-left','15','','','.w-socials'),(932453,'printshop','.w-reviews-content .review','padding-left','20','','','.w-reviews-content'),(932455,'printshop','.w-filters .filter-ul-content','padding-left','0','','','.w-filters'),(932456,'printshop','.message.success','padding-left','40','','',''),(932457,'printshop','.p-quick-order-index .all-scroll-div','padding-left','0','','','.p-quick-order-index'),(932458,'printshop','.w-personal-gift-status-bar .end-label','padding-left','5','','','.w-personal-gift-status-bar'),(932459,'printshop','.w-promo-code .heading-4','padding-left','30','5363','','.w-promo-code'),(932460,'printshop','.b-email .heading-model','padding-left','10','','','.b-email'),(932461,'printshop','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(932462,'printshop','.b-email .heading-name','padding-left','10','','','.b-email'),(932463,'printshop','.b-email .name','padding-left','10','','','.b-email'),(932464,'printshop','.b-email .qty','padding-left','10','','','.b-email'),(932465,'printshop','.b-email .totals-value','padding-left','10','','','.b-email'),(932466,'printshop','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-left','0','','','.b-fancybox'),(932467,'printshop','.w-checkout-shipping-choice span','padding-left','0','','','.w-checkout-shipping-choice'),(932469,'printshop','.b-info .info','padding-left','40','','','.b-info'),(932470,'printshop','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(932471,'printshop','.b-fancybox .fancybox-title-over-wrap','padding-left','10','','','.b-fancybox'),(932472,'printshop','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(932473,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-left','0','','','.b-select-suggest'),(932474,'printshop','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(932475,'printshop','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(932476,'printshop','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(932477,'printshop','.w-reviews .review','padding-left','0','','','.w-reviews'),(932478,'printshop','.w-socials > li','padding-left','15','','','.w-socials'),(932481,'printshop','.b-compare .popupCompare td.level-2:first-child','padding-left','12','','','.b-compare'),(932482,'printshop','.b-info-popup .info-popup div','padding-left','15','','','.b-info-popup'),(932483,'printshop','.b-form .payment-method .item','padding-left','0','','','.b-form'),(932484,'printshop','.b-form .password-forgotten-link','padding-left','0','','','.b-form'),(932485,'printshop','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(932486,'printshop','.w-cart-compare .price-label','padding-left','10','','','.w-cart-compare'),(932487,'printshop','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(932488,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-left','10','','','.w-image-maps'),(932489,'printshop','.w-promo-code .holder','padding-left','20','5363','','.w-promo-code'),(932490,'printshop','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(932492,'printshop','.w-reviews .heading-3','padding-left','55','','','.w-reviews'),(932493,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(932495,'printshop','.b-email .name','padding-left','10','','','.b-email'),(932496,'printshop','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(932497,'printshop','.b-email .heading-name','padding-left','10','','','.b-email'),(932498,'printshop','.b-email .heading-image','padding-left','10','','','.b-email'),(932499,'printshop','.b-email .image','padding-left','10','','','.b-email'),(932500,'printshop','.b-email .heading-qty','padding-left','10','','','.b-email'),(932501,'printshop','.b-email .totals-value','padding-left','10','','','.b-email'),(932502,'printshop','.b-email .price','padding-left','10','','','.b-email'),(932503,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(932504,'printshop','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-left','0','','','.w-multi-cart-actions'),(932506,'printshop','.w-top-categories .item','padding-left','20','','','.w-top-categories'),(932507,'printshop','.w-tabs > .block','padding-left','20','','','.w-tabs'),(932508,'printshop','.w-cart-cart-tabs .w-tabs > .block','padding-left','0','','','.w-cart-cart-tabs'),(932509,'printshop','.w-tabs .accordion-heading','padding-left','8','5333','','.w-tabs'),(932510,'printshop','.w-tabs .tab-a','padding-left','6','','','.w-tabs'),(932511,'printshop','.w-socials > li','padding-left','15','','','.w-socials'),(932514,'printshop','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(932515,'printshop','.b-bottom .popup-box-wrap','padding-left','10','','','.b-bottom'),(932516,'printshop','.b-bottom .popup-buttons','padding-left','15','','','.b-bottom'),(932518,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(932520,'printshop','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(932521,'printshop','.b-form .required-message','padding-left','3','','','.b-form'),(932522,'printshop','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(932523,'printshop','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(932524,'printshop','.btn-1','padding-left','25','','',''),(932525,'printshop','.b-autocomplete .ui-autocomplete li','padding-left','10','','','.b-autocomplete'),(932526,'printshop','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(932527,'printshop','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(932528,'printshop','.b-table .table td','padding-left','15','','','.b-table'),(932529,'printshop','.b-table .table .headings td','padding-left','10','','','.b-table'),(932530,'printshop','.w-socials > li','padding-left','15','','','.w-socials'),(932531,'printshop','.w-login-block .guest','padding-left','40','','','.w-login-block'),(932532,'printshop','.b-products-listing .products-listing .buyButton .btn','padding-left','10','','','.b-products-listing'),(932533,'printshop','.w-product-images-additional .images','padding-left','0','5363','','.w-product-images-additional'),(932534,'printshop','.b-products-listing .products-listing .bonus-points-price','padding-left','20','','','.b-products-listing'),(932535,'printshop','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(932536,'printshop','.b-email .heading-qty','padding-left','10','','','.b-email'),(932537,'printshop','.order-summary .price-row','padding-left','0','','','.order-summary'),(932538,'printshop','.b-email .heading-image','padding-left','10','','','.b-email'),(932539,'printshop','.w-quote .no-text','padding-left','20','','','.w-quote'),(932540,'printshop','.b-select-suggest .select2-drop-mask','padding-left','0','','','.b-select-suggest'),(932541,'printshop','.w-reviews .author','padding-left','0','','','.w-reviews'),(932543,'printshop','.testimonials .answer','padding-left','30','','',''),(932544,'printshop','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(932545,'printshop','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(932546,'printshop','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(932548,'printshop','.b-fancybox .fancybox-title-float-wrap .child','padding-left','20','','','.b-fancybox'),(932549,'printshop','.w-checkout-shipping-choice span','padding-left','10','5363','','.w-checkout-shipping-choice'),(932550,'printshop','.w-top-categories .categories h2','padding-left','0','','','.w-top-categories'),(932551,'printshop','.w-top-categories .image','padding-left','0','','','.w-top-categories'),(932552,'printshop','.w-product-reviews .reviews-list .review','padding-left','10','','','.w-product-reviews'),(932553,'printshop','.b-email .model','padding-left','10','','','.b-email'),(932554,'printshop','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(932555,'printshop','.b-email .price','padding-left','10','','','.b-email'),(932556,'printshop','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(932557,'printshop','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(932558,'printshop','.w-promo-code .heading-4','padding-left','30','5363','','.w-promo-code'),(932559,'printshop','.w-product-images-additional .images','padding-left','0','5363','','.w-product-images-additional'),(932560,'printshop','.b-bottom .popup-heading','padding-left','15','','','.b-bottom'),(932561,'printshop','.b-bottom .popup-simple','padding-left','20','','','.b-bottom'),(932562,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(932563,'printshop','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(932564,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(932565,'printshop','.b-email .image','padding-left','10','','','.b-email'),(932566,'printshop','.b-email .heading-qty','padding-left','10','','','.b-email'),(932567,'printshop','.b-email .name','padding-left','10','','','.b-email'),(932568,'printshop','.b-email .heading-price','padding-left','10','','','.b-email'),(932569,'printshop','.b-email .heading-model','padding-left','10','','','.b-email'),(932570,'printshop','.b-email .totals-value','padding-left','10','','','.b-email'),(932571,'printshop','.b-email .qty','padding-left','10','','','.b-email'),(932572,'printshop','.b-email .totals-title','padding-left','10','','','.b-email'),(932573,'printshop','.b-email .model','padding-left','10','','','.b-email'),(932574,'printshop','.b-email .heading-name','padding-left','10','','','.b-email'),(932575,'printshop','.b-email .heading-image','padding-left','10','','','.b-email'),(932576,'printshop','.w-checkout-create-account .create-account','padding-left','0','','','.w-checkout-create-account'),(932577,'printshop','.w-checkout-shipping .sub-item','padding-left','0','','','.w-checkout-shipping'),(932578,'printshop','.b-info .info','padding-left','40','','','.b-info'),(932579,'printshop','.b-email .totals-value','padding-left','10','','','.b-email'),(932580,'printshop','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(932581,'printshop','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(932582,'printshop','.b-table .table td','padding-left','15','','','.b-table'),(932583,'printshop','.b-table .table .headings td','padding-left','10','','','.b-table'),(932584,'printshop','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(932585,'printshop','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(932586,'printshop','.w-promo-code .holder','padding-left','20','5363','','.w-promo-code'),(932587,'printshop','.w-promo-code .heading-4','padding-left','30','5363','','.w-promo-code'),(932588,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(932589,'printshop','.b-form .shipping-method .input','padding-left','0','','','.b-form'),(932590,'printshop','.b-form .center-buttons','padding-left','0','','','.b-form'),(932591,'printshop','.b-info .info li','padding-left','0','','','.b-info'),(932592,'printshop','.w-reviews .item','padding-left','0','','','.w-reviews'),(932593,'printshop','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(932594,'printshop','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(932595,'printshop','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(932596,'printshop','.b-select-suggest .select2-container .select2-choice','padding-left','8','','','.b-select-suggest'),(932600,'printshop','.b-sub-totals .historyTotal td','padding-left','5','','','.b-sub-totals'),(932601,'printshop','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(932602,'printshop','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(932603,'printshop','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(932604,'printshop','.b-info .info','padding-left','40','','','.b-info'),(932605,'printshop','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(932607,'printshop','.b-upload-files .upload-files','padding-left','10','','','.b-upload-files'),(932608,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(932609,'printshop','.w-login-block .guest','padding-left','40','','','.w-login-block'),(932610,'printshop','.w-login-block .new','padding-left','40','','','.w-login-block'),(932611,'printshop','.w-product-images-additional .images','padding-left','0','5363','','.w-product-images-additional'),(932612,'printshop','.w-checkout-shipping-address .edit-ab','padding-left','15','','','.w-checkout-shipping-address'),(932613,'printshop','.b-info .info ul','padding-left','0','','','.b-info'),(932614,'printshop','.b-info .info li','padding-left','0','','','.b-info'),(932615,'printshop','.b-bottom .header-error','padding-left','20','','','.b-bottom'),(932616,'printshop','.w-categories h2.name','padding-left','3','','','.w-categories'),(932617,'printshop','.b-form .form-buttons','padding-left','0','','','.b-form'),(932618,'printshop','.b-form .payment-method .item-radio label span','padding-left','5','','','.b-form'),(932619,'printshop','.w-checkout-billing-address .same-address','padding-left','10','','','.w-checkout-billing-address'),(932620,'printshop','.btn-3','padding-left','25','','',''),(932621,'printshop','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(932622,'printshop','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(932623,'printshop','.w-cart-compare .delete-cart','padding-left','10','','','.w-cart-compare'),(932624,'printshop','.w-cart-compare .price-cell','padding-left','20','','','.w-cart-compare'),(932625,'printshop','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','60','','','.b-select-suggest'),(932626,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(932627,'printshop','.b-info .info','padding-left','40','','','.b-info'),(932628,'printshop','.b-info .info li','padding-left','0','','','.b-info'),(932629,'printshop','.b-email .totals-title','padding-left','10','','','.b-email'),(932630,'printshop','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(932631,'printshop','.b-email .heading-qty','padding-left','10','','','.b-email'),(932632,'printshop','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','padding-left','10','','','.b-bottom'),(932633,'printshop','.w-product-images-additional .images','padding-left','0','5363','','.w-product-images-additional'),(932634,'printshop','.w-promo-code .heading-4','padding-left','30','5363','','.w-promo-code'),(932635,'printshop','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-left','20','','','.b-bottom'),(932636,'printshop','.b-bottom .cart-options .cart-item input[type=\"text\"]','padding-left','0','','','.b-bottom'),(932637,'printshop','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-left','6','','','.b-compare'),(932638,'printshop','.w-cart-compare .cart-cell','padding-left','7','','','.w-cart-compare'),(932639,'printshop','.w-cart-compare .product','padding-left','15','','','.w-cart-compare'),(932640,'printshop','.w-promotions .promo-cart-discount .master .item','padding-left','20','','','.w-promotions'),(932642,'printshop','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(932643,'printshop','.b-bottom .alert-message','padding-left','20','','','.b-bottom'),(932644,'printshop','.b-bottom .cart-options','padding-left','20','','','.b-bottom'),(932645,'printshop','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','5342','','.w-menu-horizontal'),(932646,'printshop','.w-login-block .guest','padding-left','40','','','.w-login-block'),(932647,'printshop','.b-select-suggest .select2-results .select2-result-label','padding-left','7','','','.b-select-suggest'),(932648,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(932649,'printshop','.w-login-block .new','padding-left','40','','','.w-login-block'),(932650,'printshop','.w-login-block .guest','padding-left','40','','','.w-login-block'),(932651,'printshop','.w-quote .cart-box-link','padding-left','10','','','.w-quote'),(932652,'printshop','.b-info .info ul','padding-left','0','','','.b-info'),(932653,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(932654,'printshop','.b-email .totals-value','padding-left','10','','','.b-email'),(932655,'printshop','.b-info .info ul','padding-left','0','','','.b-info'),(932656,'printshop','.b-email .totals-title','padding-left','10','','','.b-email'),(932657,'printshop','.b-email .qty','padding-left','10','','','.b-email'),(932658,'printshop','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(932659,'printshop','.b-email .heading-price','padding-left','10','','','.b-email'),(932660,'printshop','.b-bottom .rfq-form','padding-left','20','','','.b-bottom'),(932661,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(932662,'printshop','.b-bottom .footerTitle','padding-left','0','5333','','.b-bottom'),(932663,'printshop','.b-bottom .pop-up-close','padding-left','1','','','.b-bottom'),(932664,'printshop','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(932665,'printshop','.b-info .info li','padding-left','0','','','.b-info'),(932666,'printshop','.w-cart-up-sell .w-list-type-1','padding-left','0','','','.w-cart-up-sell'),(932667,'printshop','.w-cart-shipping-estimator .address-item','padding-left','0','','','.w-cart-shipping-estimator'),(932668,'printshop','.w-cart-up-sell .w-list-type-1 .item','padding-left','20','1','','.w-cart-up-sell'),(932669,'printshop','.w-cart-up-sell .w-list-type-1 .item','padding-left','21','','','.w-cart-up-sell'),(932670,'printshop','.b-upload-files .added-file','padding-left','0','','','.b-upload-files'),(932671,'printshop','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(932672,'printshop','.w-menu-big ul','padding-left','0','','','.w-menu-big'),(932673,'printshop','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(932674,'printshop','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(932675,'printshop','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(932677,'printshop','.w-promo-code .holder','padding-left','20','5363','','.w-promo-code'),(932678,'printshop','.b-bottom .pop-up-info','padding-left','20','','','.b-bottom'),(932679,'printshop','.b-email .heading-price','padding-left','10','','','.b-email'),(932680,'printshop','.b-email .image','padding-left','10','','','.b-email'),(932681,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(932682,'printshop','.b-fancybox .fancybox-error','padding-left','15','','','.b-fancybox'),(932683,'printshop','.w-cart-compare .product .stock','padding-left','3','','','.w-cart-compare'),(932684,'printshop','.b-fancybox .fancybox-next span','padding-left','4','3','','.b-fancybox'),(932685,'printshop','.b-info .info','padding-left','40','','','.b-info'),(932686,'printshop','.b-form .middle-form','padding-left','0','','','.b-form'),(932687,'printshop','.b-info .info ul','padding-left','0','','','.b-info'),(932688,'printshop','.w-product-customers-activity .customers-activity','padding-left','20','','','.w-product-customers-activity'),(932689,'printshop','.b-table .table td','padding-left','15','','','.b-table'),(932690,'printshop','.b-compare .compare-box-item','padding-left','10','','','.b-compare'),(932691,'printshop','.b-compare .compare-head','padding-left','10','','','.b-compare'),(932692,'printshop','.b-email .model','padding-left','10','','','.b-email'),(932693,'printshop','.b-email .image','padding-left','10','','','.b-email'),(932694,'printshop','.b-email .heading-qty','padding-left','10','','','.b-email'),(932695,'printshop','.b-email .totals-title','padding-left','10','','','.b-email'),(932696,'printshop','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(932697,'printshop','.b-table .table .headings td','padding-left','10','','','.b-table'),(932700,'printshop','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(932702,'printshop','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(932703,'printshop','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(932704,'printshop','.w-login-block .new','padding-left','40','','','.w-login-block'),(932705,'printshop','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(932706,'printshop','.w-login-block .guest','padding-left','40','','','.w-login-block'),(932708,'printshop','.w-checkout-billing-address .edit-ab','padding-left','15','','','.w-checkout-billing-address'),(932709,'printshop','.w-checkout-billing-address .addresses.address-main label','padding-left','0','','','.w-checkout-billing-address'),(932710,'printshop','.w-checkout-billing-address .addresses .address-item label','padding-left','15','','','.w-checkout-billing-address'),(932711,'printshop','.w-promo-code .holder','padding-left','20','5363','','.w-promo-code'),(932712,'printshop','.w-promo-code .heading-4','padding-left','30','5363','','.w-promo-code'),(932713,'printshop','.w-product-images-additional .images','padding-left','0','5363','','.w-product-images-additional'),(932714,'printshop','.w-cart-checkout-btn a','padding-left','12','5333','','.w-cart-checkout-btn'),(932715,'printshop','.w-tabs .accordion-heading','padding-left','6','','','.w-tabs'),(932716,'printshop','.b-bottom .header-info','padding-left','20','','','.b-bottom'),(932717,'printshop','.w-personal-gift-status-bar .start-label','padding-left','30','','','.w-personal-gift-status-bar'),(932718,'printshop','.b-upload-file .upload-file-template','padding-left','1','','','.b-upload-file'),(932719,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(932720,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','padding-left','5','','','.b-switch'),(932721,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-left','5','','','.b-select-suggest'),(932722,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-left','18','','','.b-select-suggest'),(932724,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-left','5','','','.b-select-suggest'),(932725,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-left','0','','','.b-select-suggest'),(932726,'printshop','.b-select-suggest .select2-locked','padding-left','5','','','.b-select-suggest'),(932727,'printshop','.b-select-suggest .select2-container-multi .select2-choices','padding-left','0','','','.b-select-suggest'),(932728,'printshop','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','100','','','.b-select-suggest'),(932729,'printshop','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','120','','','.b-select-suggest'),(932730,'printshop','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','110','','','.b-select-suggest'),(932731,'printshop','.b-select-suggest .select2-results ul.select2-result-sub','padding-left','0','','','.b-select-suggest'),(932732,'printshop','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','80','','','.b-select-suggest'),(932733,'printshop','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','40','','','.b-select-suggest'),(932734,'printshop','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','','','.w-menu-horizontal'),(932735,'printshop','.b-select-suggest .select2-results','padding-left','4','','','.b-select-suggest'),(932736,'printshop','.w-checkout-shipping-address .addresses .address-item label','padding-left','15','','','.w-checkout-shipping-address'),(932737,'printshop','.b-select-suggest .select2-results ul.select2-result-sub > li .select2-result-label','padding-left','20','','','.b-select-suggest'),(932738,'printshop','.b-form .shipping-method .item + .item','padding-left','0','','','.b-form'),(932739,'printshop','.w-checkout-shipping-address .addresses.address-main label','padding-left','0','','','.w-checkout-shipping-address'),(932740,'printshop','.b-select-suggest .select2-search input','padding-left','5','','','.b-select-suggest'),(932741,'printshop','.b-select-suggest .select2-search','padding-left','4','','','.b-select-suggest'),(932742,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(932746,'printshop','.w-cart-compare .product-label','padding-left','10','','','.w-cart-compare'),(932747,'printshop','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(932748,'printshop','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(932749,'printshop','.b-table .table .headings td','padding-left','10','','','.b-table'),(932750,'printshop','.b-compare .col-two label','padding-left','0','','','.b-compare'),(932753,'printshop','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(932754,'printshop','.b-bottom .notify-form','padding-left','20','','','.b-bottom'),(932755,'printshop','.w-account-addresses-list .addsess-suggestion-item','padding-left','0','','','.w-account-addresses-list'),(932756,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.b-data-table'),(932757,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.b-data-table'),(932758,'printshop','.w-communication-post .communication-post-author','padding-left','0','','','.w-communication-post'),(932759,'printshop','.b-products-listing .in-cart','padding-left','10','','','.b-products-listing'),(932760,'printshop','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-left','5','','','.w-catalog-b2b-add-button'),(932761,'printshop','.b-products-listing .promos-info .promo-item','padding-left','0','','','.b-products-listing'),(932762,'printshop','.b-products-listing .promos-info .promo-name','padding-left','15','','','.b-products-listing'),(932763,'printshop','.blogsidebar','padding-left','35','','',''),(932769,'printshop','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(932770,'printshop','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(932771,'printshop','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(932772,'printshop','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(932773,'printshop','.w-checkout-gdpr .terms-login','padding-left','0','','','.w-checkout-gdpr'),(932774,'printshop','.w-contact-contacts table td','padding-left','0','','','.w-contact-contacts'),(932775,'printshop','.w-checkout-gdpr .privacy-row','padding-left','0','','','.w-checkout-gdpr'),(932776,'printshop','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(932777,'printshop','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(932778,'printshop','.b-compare .column_wrapper','padding-left','10','','','.b-compare'),(932779,'printshop','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(932780,'printshop','.b-email .price','padding-left','10','','','.b-email'),(932781,'printshop','.b-email .heading-name','padding-left','10','','','.b-email'),(932782,'printshop','.b-email .heading-model','padding-left','10','','','.b-email'),(932783,'printshop','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(932785,'printshop','.w-top-categories .item','padding-left','10','5333','','.w-top-categories'),(932786,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(932787,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-left','0','','','.w-contact-contacts'),(932788,'printshop','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(932789,'printshop','.w-personal-gift-status-bar .timeline','padding-left','10','','','.w-personal-gift-status-bar'),(932790,'printshop','.b-table .table td','padding-left','15','','','.b-table'),(932791,'printshop','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(932792,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-left','0','','',''),(932793,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-left','0','','','.b-h-inline'),(932794,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-left','5','','','.w-communication-new-topic'),(932795,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-left','10','','','.w-communication-new-topic'),(932796,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-left','5','','','.w-communication-new-topic'),(932797,'printshop','.w-communication-new-topic #communication_topic_form .middle-form','padding-left','0','','','.w-communication-new-topic'),(932798,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(932799,'printshop','.b-email .heading-price','padding-left','10','','','.b-email'),(932800,'printshop','.b-email .image','padding-left','10','','','.b-email'),(932801,'printshop','.btn-2','padding-left','25','','',''),(932802,'printshop','.b-compare .compare_pagination','padding-left','0','','','.b-compare'),(932803,'printshop','.b-bottom .popup-content','padding-left','15','','','.b-bottom'),(932804,'printshop','.w-reviews-content .author','padding-left','20','','','.w-reviews-content'),(932805,'printshop','.b-email .qty','padding-left','10','','','.b-email'),(932806,'printshop','.w-login-block .new','padding-left','40','','','.w-login-block'),(932808,'printshop','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(932809,'printshop','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-left','0','','','.b-fancybox'),(932810,'printshop','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(932811,'printshop','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(932812,'printshop','.b-email .heading-image','padding-left','10','','','.b-email'),(932813,'printshop','.b-email .price','padding-left','10','','','.b-email'),(932814,'printshop','.products-quick-index .token-input-list','padding-left','0','','',''),(932817,'printshop','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(932818,'printshop','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(932819,'printshop','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(932820,'printshop','.b-info .info ul','padding-left','0','','','.b-info'),(932821,'printshop','.b-form .shipping-method .item','padding-left','0','','','.b-form'),(932822,'printshop','.b-email .model','padding-left','10','','','.b-email'),(932823,'printshop','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(932824,'printshop','.w-promo-code .holder','padding-left','20','5363','','.w-promo-code'),(932825,'printshop','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(932826,'printshop','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(932827,'printshop','.w-cart-listing .item .gift-wrap label','padding-left','10','','','.w-cart-listing'),(932828,'printshop','.w-cart-listing .item > div','padding-left','10','','','.w-cart-listing'),(932829,'printshop','.w-cart-listing .points-earn','padding-left','10','','','.w-cart-listing'),(932830,'printshop','.w-cart-listing .points-redeem','padding-left','25','','','.w-cart-listing'),(932831,'printshop','.w-cart-listing .item .gift-wrap .value','padding-left','5','','','.w-cart-listing'),(932832,'printshop','.w-cart-listing .item .gift-wrap','padding-left','0','5342','','.w-cart-listing'),(932833,'printshop','.w-cart-give-away .ga_img','padding-left','1','','','.w-cart-give-away'),(932840,'printshop','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(932841,'printshop','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(932842,'printshop','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(932843,'printshop','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(932844,'printshop','.b-info .info li','padding-left','0','','','.b-info'),(932845,'printshop','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(932846,'printshop','.b-email .heading-model','padding-left','10','','','.b-email'),(932847,'printshop','.b-email .model','padding-left','10','','','.b-email'),(932848,'printshop','.b-compare .col-gender','padding-left','0','','','.b-compare'),(932850,'printshop','.w-socials > li','padding-left','15','','','.w-socials'),(932851,'printshop','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(932852,'printshop','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(932853,'printshop','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(932855,'printshop','.b-compare .popupCompare td.level-3:first-child','padding-left','18','','','.b-compare'),(932857,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(932858,'printshop','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(932859,'printshop','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(932860,'printshop','.b-table .table .headings td','padding-left','10','','','.b-table'),(932861,'printshop','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(932863,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(932864,'printshop','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(932865,'printshop','.w-filters .fsl_handle','padding-left','0','','','.w-filters'),(932866,'printshop','.w-filters .head-filter-widget','padding-left','10','5342','','.w-filters'),(932867,'printshop','.w-catalog-sorting .before','padding-left','0','','','.w-catalog-sorting'),(932868,'printshop','.w-filters .ui-slider-range','padding-left','0','','','.w-filters'),(932870,'printshop','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(932871,'printshop','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(932872,'printshop','.w-filters .head-filter-widget','padding-left','0','','','.w-filters'),(932873,'printshop','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(932874,'printshop','.b-autocomplete .ui-autocomplete','padding-left','2','','','.b-autocomplete'),(932875,'printshop','.w-promo-code .heading-4','padding-left','30','5363','','.w-promo-code'),(932876,'printshop','.order-summary .heading-2','padding-left','25','','','.order-summary'),(932877,'printshop','.b-email .name','padding-left','10','','','.b-email'),(932878,'printshop','.b-email .totals-title','padding-left','10','','','.b-email'),(932879,'printshop','.b-email .heading-qty','padding-left','10','','','.b-email'),(932881,'printshop','.b-data-table table.dataTable tbody td','padding-left','20','','','.b-data-table'),(932882,'printshop','.b-data-table table.dataTable thead td','padding-left','20','','','.b-data-table'),(932883,'printshop','.b-compare .popupCompare .pop-up-content','padding-left','10','','','.b-compare'),(932886,'printshop','.w-contact-contacts .contacts-icons .hours-content','padding-left','30','','','.w-contact-contacts'),(932887,'printshop','.b-table .table td','padding-left','15','','','.b-table'),(932888,'printshop','.b-info .info ul','padding-left','0','','','.b-info'),(932889,'printshop','.b-email .qty','padding-left','10','','','.b-email'),(932890,'printshop','.b-email .totals-title','padding-left','10','','','.b-email'),(932891,'printshop','.b-email .qty','padding-left','10','','','.b-email'),(932892,'printshop','.b-email .price','padding-left','10','','','.b-email'),(932893,'printshop','.btn','padding-left','25','','',''),(932894,'printshop','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(932895,'printshop','.b-product-images .media-popup .mp-content','padding-left','5','','','.b-product-images'),(932896,'printshop','.b-product-images .media-popup .mp-small-images .item','padding-left','10','','','.b-product-images'),(932897,'printshop','.b-product-images .media-popup .slick-dots','padding-left','0','','','.b-product-images'),(932898,'printshop','.b-product-images .media-popup .slick-dots li','padding-left','0','','','.b-product-images'),(932899,'printshop','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-left','0','','','.b-menu-style'),(932900,'printshop','.b-personal-catalog-popup #personal_catalog_popup','padding-left','0','','','.b-personal-catalog-popup'),(932901,'printshop','.b-trade-approval .steps-bar li a','padding-left','0','','','.b-trade-approval'),(932902,'printshop','.b-trade-approval .middle-form','padding-left','0','','','.b-trade-approval'),(932903,'printshop','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-left','5','','','.b-trade-approval'),(932904,'printshop','.b-trade-approval .steps-bar','padding-left','12','','','.b-trade-approval'),(932905,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-left','10','','','.b-trade-approval'),(932906,'printshop','.b-trade-approval .center-buttons','padding-left','0','','','.b-trade-approval'),(932907,'printshop','.w-account-personal-catalog .list-switcher','padding-left','0','','','.w-account-personal-catalog'),(932908,'printshop','.w-account-personal-catalog .list-switcher a','padding-left','6','','','.w-account-personal-catalog'),(932909,'printshop','.w-account-subscription .subscription-variant','padding-left','10','','','.w-account-subscription'),(932910,'printshop','.w-catalog-additional-images li','padding-left','10','','','.w-catalog-additional-images'),(932911,'printshop','.w-catalog-additional-images ul','padding-left','0','','','.w-catalog-additional-images'),(932912,'printshop','.w-catalog-compare td','padding-left','20','','','.w-catalog-compare'),(932913,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-left','0','','','.w-catalog-compare'),(932914,'printshop','.w-catalog-compare .cross-box .different-all > div','padding-left','5','2','','.w-catalog-compare'),(932915,'printshop','.w-catalog-compare .cross-box .different-all > div','padding-left','5','','','.w-catalog-compare'),(932916,'printshop','.w-catalog-compare .cross-box .return','padding-left','20','','','.w-catalog-compare'),(932917,'printshop','.w-delivery-day .left-count','padding-left','5','','','.w-delivery-day'),(932918,'printshop','.w-top-text .top-text','padding-left','10','','','.w-top-text'),(932919,'printshop','.w-cart-listing .points','padding-left','0','5333','','.w-cart-listing'),(932920,'printshop','.w-product-images .additional-horizontal .item','padding-left','10','','','.w-product-images'),(932921,'printshop','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-left','10','','','.b-cookie-notice'),(932923,'printshop','.lowestPricedBox .w-banner .single_banner','padding-left','15','','','.lowestPricedBox'),(932924,'printshop','.lowestPricedBox .w-banner .banner','padding-left','0','','','.lowestPricedBox'),(932925,'printshop','.tripleBanner > .block','padding-left','15','','','.tripleBanner'),(932926,'printshop','.tripleBanner .w-html_box','padding-left','90','','','.tripleBanner'),(932927,'printshop','.shopByCollectionBox .w-banner .single_banner','padding-left','15','','','.shopByCollectionBox'),(932928,'printshop','.b-slick .slick-list','padding-left','0','','','.b-slick'),(932929,'printshop','.b-slick .slick-vertical button.slick-next','padding-left','0','3','','.b-slick'),(932930,'printshop','.b-slick .slick-vertical button.slick-prev','padding-left','0','3','','.b-slick'),(932931,'printshop','.b-slick button.slick-next','padding-left','4','3','','.b-slick'),(932932,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','padding-left','0','','','.b-slick'),(932933,'printshop','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-left','15','','',''),(932934,'printshop','.w-cart-listing .headings .head','padding-left','0','','','.w-cart-listing'),(932935,'printshop','.b-products-listing .item-nav > div','padding-left','15','','','.b-products-listing'),(932936,'printshop','.LeftCategories .w-menu-simple ul','padding-left','0','','','.LeftCategories'),(932937,'printshop','.LeftCategories .w-menu-simple ul li a','padding-left','25','','','.LeftCategories'),(932938,'printshop','.w-filters .filter-widget','padding-left','25','','','.w-filters'),(932939,'printshop','.b-products-listing .products-listing.list-productlisting .item','padding-left','15','','','.b-products-listing'),(932940,'printshop','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-left','25','','','.b-products-listing'),(932941,'printshop','.b-products-listing .products-listing.list-rows .item-nav > div','padding-left','5','','','.b-products-listing'),(932942,'printshop','.w-breadcrumb .breadcrumb-li','padding-left','0','','','.w-breadcrumb'),(932943,'printshop','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(932944,'printshop','.w-subscribers .btn-submit','padding-left','25','','','.w-subscribers'),(932945,'printshop','.w-quote .buttons','padding-left','15','','','.w-quote'),(932946,'printshop','.w-quote .buttons .btn','padding-left','15','','','.w-quote'),(932947,'printshop','.w-quote .cart-content','padding-left','15','','','.w-quote'),(932948,'printshop','.w-quote .cart-total','padding-left','0','','','.w-quote'),(932949,'printshop','.w-quote .multicart .cart-content','padding-left','0','','','.w-quote'),(932950,'printshop','.w-quote .multicart .item','padding-left','45','','','.w-quote'),(932951,'printshop','.w-quote .multicart .name','padding-left','10','','','.w-quote'),(932952,'printshop','.w-quote .qty','padding-left','5','4','','.w-quote'),(932953,'printshop','.w-quote a.item','padding-left','90','','','.w-quote'),(932954,'printshop','.w-product-images .additional-vertical .additional-images','padding-left','0','','','.w-product-images'),(932955,'printshop','.w-product-sale-ends .left-count','padding-left','5','','','.w-product-sale-ends'),(932956,'printshop','.w-product-sale-ends .left-count-days','padding-left','0','','','.w-product-sale-ends'),(932957,'printshop','.w-product-sale-ends .left-count-hours','padding-left','0','','','.w-product-sale-ends'),(932958,'printshop','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(932959,'printshop','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(932960,'printshop','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(932961,'printshop','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(932962,'printshop','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(932963,'printshop','.w-product-bonus-points > div > div','padding-left','25','','','.w-product-bonus-points'),(932964,'printshop','.warrantyProduct .warranty, .warrantyProduct .delivery','padding-left','50','','','.warrantyProduct'),(932965,'printshop','.w-compare .compare-list-buttons','padding-left','10','','','.w-compare'),(932966,'printshop','.w-compare .item-holder','padding-left','90','','','.w-compare'),(932967,'printshop','.w-compare .compare-list-products','padding-left','30','','','.w-compare'),(932968,'printshop','.w-files-catalog-widgets-files-catalog .name','padding-left','10','','','.w-files-catalog-widgets-files-catalog'),(932969,'printshop','.w-files-catalog-widgets-files-list .file','padding-left','20','','','.w-files-catalog-widgets-files-list'),(932970,'printshop','.w-sample .buttons','padding-left','15','','','.w-sample'),(932971,'printshop','.w-sample .buttons .btn','padding-left','15','','','.w-sample'),(932972,'printshop','.w-sample .cart-box-link','padding-left','10','','','.w-sample'),(932973,'printshop','.w-sample .cart-content','padding-left','15','','','.w-sample'),(932974,'printshop','.w-sample .cart-total','padding-left','0','','','.w-sample'),(932975,'printshop','.w-sample .multicart .cart-content','padding-left','0','','','.w-sample'),(932976,'printshop','.w-sample .multicart .item','padding-left','45','','','.w-sample'),(932977,'printshop','.w-sample .multicart .name','padding-left','10','','','.w-sample'),(932978,'printshop','.w-sample .no-text','padding-left','20','','','.w-sample'),(932979,'printshop','.w-sample .qty','padding-left','5','4','','.w-sample'),(932980,'printshop','.w-sample a.item','padding-left','90','','','.w-sample'),(932981,'printshop','.w-cart-listing .item > div.points','padding-left','0','','','.w-cart-listing'),(932982,'printshop','.w-filters-simple .integrate-price-holder','padding-left','0','','','.w-filters-simple'),(932983,'printshop','.w-product-video .item','padding-left','10','','','.w-product-video'),(932984,'printshop','.shipping-ico .heading-3','padding-left','0','','','.shipping-ico'),(932985,'printshop','.w-cart-order-reference .btn','padding-left','25','','','.w-cart-order-reference'),(932986,'printshop','.w-cart-gift-certificate .btn','padding-left','25','','','.w-cart-gift-certificate'),(932987,'printshop','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(932988,'printshop','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(932989,'printshop','.w-product-in-bundles .attributes-item','padding-left','0','','','.w-product-in-bundles'),(932990,'printshop','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(932991,'printshop','.w-cart-listing .item > div.actions','padding-left','10','5333','','.w-cart-listing'),(932993,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-left','0','','','.b-products-listing'),(932994,'printshop','.b-pagination .pagination .next-pages','padding-left','5','','','.b-pagination'),(932995,'printshop','.b-pagination .pagination .page-number','padding-left','5','','','.b-pagination'),(932996,'printshop','.b-pagination .pagination .prev-pages','padding-left','5','','','.b-pagination'),(932997,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','padding-left','5','','','.b-pagination'),(932998,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','padding-left','5','','','.b-pagination'),(932999,'printshop','.b-pagination .pagination span','padding-left','5','2','','.b-pagination'),(933000,'printshop','.b-pagination ul.pagination','padding-left','0','','','.b-pagination'),(933001,'printshop','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','padding-left','10','','','.w-catalog-compare'),(933002,'printshop','.w-product-properties-filters-widgets-chosen-filters .item','padding-left','10','','','.w-product-properties-filters-widgets-chosen-filters'),(933003,'printshop','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block, .checkout > .type-1 > .block','padding-left','15','','',''),(933004,'printshop','.p-quote-checkout-index .datepicker-inline','padding-left','0','','','.p-quote-checkout-index'),(933005,'printshop','.p-sample-checkout-index .datepicker-inline','padding-left','0','','','.p-sample-checkout-index'),(933009,'printshop','.w-product-multi-inventory .radio-attributes .option-item','padding-left','15','','','.w-product-multi-inventory'),(933010,'printshop','.w-account-personal-catalog .list-row-action ul','padding-left','0','','','.w-account-personal-catalog'),(933011,'printshop','.w-account-personal-catalog .list-row-action li','padding-left','10','','','.w-account-personal-catalog'),(933012,'printshop','.w-account-personal-catalog .buy-box','padding-left','0','5333','','.w-account-personal-catalog'),(933013,'printshop','.b-products-listing .products-listing .radio-attributes .option','padding-left','15','','','.b-products-listing'),(933014,'printshop','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(933015,'printshop','.w-product-collection .right-area .btn','padding-left','25','','','.w-product-collection'),(933016,'printshop','.w-product-collection .right-area','padding-left','2','','','.w-product-collection'),(933017,'printshop','.w-product-collection .right-area','padding-left','0','5342','','.w-product-collection'),(933018,'printshop','.w-product-attributes .radio-attributes .option-item','padding-left','15','','','.w-product-attributes'),(933019,'printshop','.w-product-properties .property-ul','padding-left','0','','','.w-product-properties'),(933020,'printshop','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(933021,'printshop','.w-product-properties li','padding-left','0','','','.w-product-properties'),(933022,'printshop','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(933023,'printshop','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(933024,'printshop','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(933025,'printshop','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(933026,'printshop','.w-product-groups .radioBox','padding-left','0','','','.w-product-groups'),(933027,'printshop','.w-product-groups .radioBox label','padding-left','0','','','.w-product-groups'),(933028,'printshop','.w-product-groups .radioBox label .containerBlock','padding-left','10','','','.w-product-groups'),(933029,'printshop','.w-product-groups .radioBox label .containerBlock','padding-left','10','5363','','.w-product-groups'),(933030,'printshop','.w-product-groups .radioBox label .containerBlock img + .name','padding-left','60','','','.w-product-groups'),(933031,'printshop','.w-product-groups .radioBox label .containerBlock img + .name + .val2','padding-left','60','','','.w-product-groups'),(933032,'printshop','.b-products-listing .mix-attributes .attribute-qty-block','padding-left','10','','','.b-products-listing'),(933033,'printshop','.b-products-listing .products-listing .attribute-qty-block','padding-left','5','','','.b-products-listing'),(933034,'printshop','.blogsidebar','padding-left','0','5342','',''),(933035,'printshop','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(933036,'printshop','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-left','25','','','.w-product-custom-bundle'),(933037,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list'),(933038,'printshop','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(933039,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-left','10','','','.w-catalog-pages-category-pages-last-list'),(933040,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list-block'),(933041,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-left','10','','','.w-catalog-pages-category-pages-last-list-block'),(933042,'printshop','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(933043,'printshop','.w-delivery-location-location-description .deliveryDesc','padding-left','0','','','.w-delivery-location-location-description'),(933044,'printshop','.w-delivery-location-location-list .deliveryListParrent a','padding-left','25','','','.w-delivery-location-location-list'),(933045,'printshop','.w-delivery-location-location-list .deliveryList li a','padding-left','15','','','.w-delivery-location-location-list'),(933046,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding-left','2','','','.w-delivery-location-featured-list'),(933047,'printshop','.w-delivery-location-featured-list .deliveryList > ul','padding-left','0','','','.w-delivery-location-featured-list'),(933048,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding-left','0','5363','','.w-delivery-location-featured-list'),(933049,'printshop','.btn-2','padding-left','25','5333','',''),(933050,'printshop','.w-sale-category .holder-1','padding-left','20','','','.w-sale-category'),(933051,'printshop','.w-sale-category .holder-2','padding-left','20','','','.w-sale-category'),(933052,'printshop','.w-sale-category .left-count','padding-left','5','','','.w-sale-category'),(933053,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(933054,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-left','10','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(933055,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(933056,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-left','10','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(933057,'printshop','.w-delivery-location-list-by-page .description ul','padding-left','30','','','.w-delivery-location-list-by-page'),(933058,'printshop','.w-product-properties-icons .property-image','padding-left','10','','','.w-product-properties-icons'),(933059,'printshop','.w-product-properties-icons .hover-box-content','padding-left','10','','','.w-product-properties-icons'),(933060,'printshop','.w-delivery-location-cross-pages .description ul','padding-left','30','','','.w-delivery-location-cross-pages'),(933061,'printshop','.w-delivery-location-product-categories .item.category-link','padding-left','15','','','.w-delivery-location-product-categories'),(933062,'printshop','.w-delivery-location-product-categories .item.category-link','padding-left','10','5342','','.w-delivery-location-product-categories'),(933063,'printshop','.w-delivery-location-product-categories .item.category-link','padding-left','0','5363','','.w-delivery-location-product-categories'),(933064,'printshop','.w-delivery-location-product-categories .name','padding-left','15','','','.w-delivery-location-product-categories'),(933065,'printshop','.w-catalog-delivery-locations .description ul','padding-left','30','','','.w-catalog-delivery-locations'),(933066,'printshop','.delivery-options-popup','padding-left','20','','',''),(933067,'printshop','.w-product-bonus-points .bonus-points-cost','padding-left','30','','','.w-product-bonus-points'),(933068,'printshop','.w-product-designer-designer .grnamebox .title-sortable','padding-left','15','','','.w-product-designer-designer'),(933069,'printshop','.w-product-designer-designer .prodDesignerType label','padding-left','10','','','.w-product-designer-designer'),(933070,'printshop','.w-press-reviews-widgets-press-reviews ','padding-left','30','','','.w-press-reviews-widgets-press-reviews'),(933071,'printshop','.w-press-reviews-widgets-press-reviews .author','padding-left','25','','','.w-press-reviews-widgets-press-reviews'),(933072,'printshop','.w-press-reviews-widgets-press-reviews .item','padding-left','20','','','.w-press-reviews-widgets-press-reviews'),(933073,'printshop','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-left','30','','','.w-press-reviews-widgets-press-reviews'),(933074,'printshop','.w-press-reviews-widgets-press-reviews .rating','padding-left','15','','','.w-press-reviews-widgets-press-reviews'),(933075,'printshop','.w-press-reviews-widgets-press-reviews .review','padding-left','25','','','.w-press-reviews-widgets-press-reviews'),(933076,'printshop','.w-press-reviews-widgets-press-reviews .sub-box','padding-left','20','','','.w-press-reviews-widgets-press-reviews'),(933077,'printshop','.w-press-reviews-widgets-press-reviews .sub-box ul','padding-left','20','','','.w-press-reviews-widgets-press-reviews'),(933078,'printshop','.w-press-reviews-widgets-press-reviews .title','padding-left','15','','','.w-press-reviews-widgets-press-reviews'),(933079,'printshop','.w-press-reviews-widgets-press-reviews ','padding-left','15','5333','','.w-press-reviews-widgets-press-reviews'),(933080,'printshop','.w-press-reviews-widgets-press-reviews .author','padding-left','0','5333','','.w-press-reviews-widgets-press-reviews'),(933081,'printshop','.w-press-reviews-widgets-press-reviews .item','padding-left','0','5333','','.w-press-reviews-widgets-press-reviews'),(933082,'printshop','.w-press-reviews-widgets-press-reviews .rating','padding-left','0','5333','','.w-press-reviews-widgets-press-reviews'),(933083,'printshop','.w-press-reviews-widgets-press-reviews .review','padding-left','0','5333','','.w-press-reviews-widgets-press-reviews'),(933084,'printshop','.w-press-reviews-widgets-press-reviews .title','padding-left','0','5333','','.w-press-reviews-widgets-press-reviews'),(933085,'printshop','.w-press-reviews-widgets-press-reviews-list .item','padding-left','25','','','.w-press-reviews-widgets-press-reviews-list'),(933086,'printshop','.w-press-reviews-widgets-press-reviews-list .short-description','padding-left','0','','','.w-press-reviews-widgets-press-reviews-list'),(933087,'printshop','.b-products-listing .productGroup label a','padding-left','16','','','.b-products-listing'),(933088,'printshop','.w-support-system-filter ','padding-left','0','','','.w-support-system-filter'),(933089,'printshop','.w-support-system-filter .filter_cats','padding-left','0','','','.w-support-system-filter'),(933090,'printshop','.w-support-system-listing .support-head','padding-left','13','','','.w-support-system-listing'),(933091,'printshop','.w-communication-post .btn.refresh','padding-left','0','','','.w-communication-post'),(933092,'printshop','.w-rma-returns-history .btn','padding-left','10','','','.w-rma-returns-history'),(933093,'printshop','.w-rma-returns-history .column','padding-left','3','','','.w-rma-returns-history'),(933094,'printshop','.w-rma-returns-history .column .title','padding-left','10','','','.w-rma-returns-history'),(933095,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','padding-left','5','','','.w-rma-returns-history'),(933096,'printshop','.w-rma-returns-history .icons .print','padding-left','15','','','.w-rma-returns-history'),(933097,'printshop','.w-rma-returns-history .topRow','padding-left','0','','','.w-rma-returns-history'),(933098,'printshop','.w-rma-returns-history .column:last-child .title','padding-left','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(933099,'printshop','.w-product-designer-designer .productDesignerBox ul','padding-left','0','','','.w-product-designer-designer'),(933100,'printshop','.w-product-configurator .pc-item','padding-left','0','','','.w-product-configurator'),(933101,'printshop','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(933102,'printshop','.w-product-configurator .pc_item','padding-left','0','5342','','.w-product-configurator'),(933103,'printshop','.w-product-configurator .pc_attr','padding-left','0','5333','','.w-product-configurator'),(933104,'printshop','.w-product-configurator .pc-item label','padding-left','20','','','.w-product-configurator'),(933105,'printshop','.b-products-listing .promos-info .promo-name-span','padding-left','40','','','.b-products-listing'),(933106,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-list'),(933107,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-left','10','','','.w-catalog-pages-category-pages-list'),(933108,'printshop','.w-predefined-promotion .nextdiscount .content > div','padding-left','10','','','.w-predefined-promotion'),(933109,'printshop','.w-predefined-promotion .nextdiscount .promo-for-each','padding-left','10','','','.w-predefined-promotion'),(933110,'printshop','.w-predefined-promotion .prom-multi-discount .promo-product','padding-left','20','','','.w-predefined-promotion'),(933111,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','padding-left','20','','','.w-predefined-promotion'),(933112,'printshop','.w-predefined-promotion .promo-cart-discount .master .item','padding-left','20','','','.w-predefined-promotion'),(933113,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-left','20','','','.w-predefined-promotion'),(933114,'printshop','.w-predefined-promotion .promo-cart-discount .slave','padding-left','15','','','.w-predefined-promotion'),(933115,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-left','20','','','.w-predefined-promotion'),(933116,'printshop','.w-predefined-promotion .promo-cart-discount .slave .item','padding-left','20','','','.w-predefined-promotion'),(933117,'printshop','.w-predefined-promotion .promo-item','padding-left','40','','','.w-predefined-promotion'),(933118,'printshop','.w-predefined-promotion .promo-salemaker .discount','padding-left','20','','','.w-predefined-promotion'),(933119,'printshop','.w-predefined-promotion .promo-salemaker .item','padding-left','20','','','.w-predefined-promotion'),(933120,'printshop','.w-predefined-promotion .promo-salemaker .promo-manufacturers','padding-left','12','','','.w-predefined-promotion'),(933121,'printshop','.w-supplier-purchase-supplier-products .item','padding-left','20','','','.w-supplier-purchase-supplier-products'),(933126,'printshop','.b-products-listing .products-listing .compare .checkbox input:not(checked) + span:before','padding-left','2','','','.b-products-listing'),(933127,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','padding-left','20','','','.w-filters'),(933128,'printshop','.b-quantity .qty-box input[type=\"text\"]','padding-left','3','','','.b-quantity'),(933129,'printshop','.w-product-model ','padding-left','10','','','.w-product-model'),(933130,'printshop','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(933131,'printshop','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(933132,'printshop','.lowestPricedBox .btn-2','padding-left','40','','','.lowestPricedBox'),(933133,'printshop','.doubleBanner .btn-2','padding-left','40','','','.doubleBanner'),(933134,'printshop','.doubleBanner .btn-2','padding-left','25','5347','','.doubleBanner'),(933135,'printshop','.middleBanner .btn-1','padding-left','30','','','.middleBanner'),(933136,'printshop','.bottomDoubleBanner .btn-2','padding-left','40','','','.bottomDoubleBanner'),(933137,'printshop','.bottomDoubleBanner .btn-2','padding-left','25','5347','','.bottomDoubleBanner'),(933138,'printshop','.bottomBanner .btn-1','padding-left','30','','','.bottomBanner'),(933139,'printshop','.bottomBanner .wrapper','padding-left','30','','','.bottomBanner'),(933140,'printshop','.bottomBanner .icon-box > div','padding-left','5','','','.bottomBanner'),(933141,'printshop','.bottomBanner .icon-box','padding-left','0','','','.bottomBanner'),(933142,'printshop','.topBanner > .block','padding-left','0','','','.topBanner'),(933145,'printshop','.middleBanner .btn-1','padding-left','15','5342','','.middleBanner'),(933146,'printshop','.middleBanner .btn-1','padding-left','15','5333','','.middleBanner'),(933147,'printshop','.bottomBanner .btn-1','padding-left','30','5347','','.bottomBanner'),(933148,'printshop','.bottomBanner .icon-box','padding-left','0','5347','','.bottomBanner'),(933149,'printshop','.bottomBanner .icon-box > div','padding-left','2','5347','','.bottomBanner'),(933150,'printshop','.w-multi-cart-save-cart .btn','padding-left','14','5363','','.w-multi-cart-save-cart'),(933151,'printshop','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-left','0','','','.b-products-listing'),(933152,'printshop','.b-products-listing .item-content','padding-left','10','','','.b-products-listing'),(933153,'printshop','.b-products-listing .products-listing.list-productlisting .item','padding-left','0','5363','','.b-products-listing'),(933154,'printshop','.w-filters .filter-widget','padding-left','15','5342','','.w-filters'),(933155,'printshop','.b-products-listing .item-content','padding-left','0','5342','','.b-products-listing'),(933156,'printshop','.w-tabs > .block','padding-left','10','5363','','.w-tabs'),(933157,'printshop','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-left','15','5363','','.b-products-listing'),(933158,'printshop','.w-account-personal-catalog .buy-box','padding-left','15','5363','','.w-account-personal-catalog'),(933159,'printshop','.b-bottom .confirm-popup .buttons','padding-left','20','','','.b-bottom'),(933160,'printshop','.trade_form > .type-1 > .block','padding-left','15','','',''),(933161,'printshop','.p-payer-order-pay .price-row','padding-left','0','','','.p-payer-order-pay'),(933162,'printshop','.p-payer-order-pay .payer > .type-1 > .block','padding-left','15','','','.p-payer-order-pay'),(933163,'printshop','.p-payer-order-confirmation .payer > .type-1 > .block','padding-left','15','','','.p-payer-order-confirmation'),(933164,'printshop','.p-payer-order-confirmation .price-row','padding-left','0','','','.p-payer-order-confirmation'),(933165,'printshop','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','padding-left','25','','','.w-product-buttons'),(933166,'printshop','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','padding-left','25','5363','','.w-product-buttons'),(933167,'printshop','.topBanner .content .btn','padding-left','1.875','','','.topBanner'),(933168,'printshop','.topBanner .ourPick .bottom','padding-left','5','','','.topBanner'),(933169,'printshop','.topBanner .ourPick .top','padding-left','15','','','.topBanner'),(933170,'printshop','.topBanner .content .btn','padding-left','30','5410','','.topBanner'),(933171,'printshop','.topBanner .content .btn','padding-left','15','5342','','.topBanner'),(933172,'printshop','.topBanner .ourPick .top','padding-left','10','5342','','.topBanner'),(933173,'printshop','.topBanner .content','padding-left','10','5333','','.topBanner'),(933174,'printshop','.topBanner .content .btn','padding-left','10','5363','','.topBanner'),(933175,'printshop','.bottomBanner .btn-1','padding-left','10','5363','','.bottomBanner'),(933176,'printshop','.bottomBanner .wrapper','padding-left','15','5363','','.bottomBanner'),(933177,'printshop','.middleBanner .btn-1','padding-left','7','5363','','.middleBanner'),(933178,'printshop','.w-promotions-widgets-promotion-icons-desc .w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','padding-left','0','','','.w-promotions-widgets-promotion-icons-desc'),(933179,'printshop','.order-summary ','padding-left','25','','','.order-summary'),(933180,'printshop','.order-summary .w-cart-listing .item .name','padding-left','0','','','.order-summary'),(933181,'printshop','.order-summary .w-cart-listing .item > div ~ div','padding-left','10','','','.order-summary'),(933182,'printshop','.order-summary ','padding-left','15','5333','','.order-summary'),(933183,'printshop','.w-cart-discount-coupon .discount-box','padding-left','10','','','.w-cart-discount-coupon'),(933184,'printshop','.p-quote-checkout-index .edit-address-popup','padding-left','20','','','.p-quote-checkout-index'),(933185,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','padding-left','15','','','.p-quote-checkout-index'),(933186,'printshop','.w-quote-products ','padding-left','10','','','.w-quote-products'),(933191,'printshop','.account-address-book .address_book','padding-left','0','','','.account-address-book'),(933192,'printshop','.account-address-book .address_book h1','padding-left','0','','','.account-address-book'),(933193,'printshop','.account-address-book .address_book h2','padding-left','10','','','.account-address-book'),(933194,'printshop','.account-address-book .address_book, .account-address-book .account_history_info','padding-left','0','','','.account-address-book'),(933195,'printshop','.account-address-book .buttonBox','padding-left','0','','','.account-address-book'),(933196,'printshop','.account-address-book .leftMes ul','padding-left','0','','','.account-address-book'),(933197,'printshop','.account-address-book .rightMes ul','padding-left','19','','','.account-address-book'),(933198,'printshop','.account-address-book .topButtons','padding-left','0','','','.account-address-book'),(933237,'printshop','.account-order-pay .contentColumn','padding-left','40','','','.account-order-pay'),(933238,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-left','40','','','.account-order-pay'),(933239,'printshop','.account-order-pay .history_info > div + div','padding-left','2','','','.account-order-pay'),(933240,'printshop','.account-order-pay .history_info > div','padding-left','0','5342','','.account-order-pay'),(933241,'printshop','.account-order-pay .history_info > div + div','padding-left','0','5342','','.account-order-pay'),(933242,'printshop','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-left','10','','','.account-samples'),(933243,'printshop','.account-samples .orders-table th','padding-left','10','','','.account-samples'),(933244,'printshop','.account-samples .order_history_table th','padding-left','10','','','.account-samples'),(933245,'printshop','.account-samples .view_link','padding-left','0','','','.account-samples'),(933246,'printshop','.account-samples .orders-table .td-alignright','padding-left','10','5342','','.account-samples'),(933247,'printshop','.account-samples .orders-table td','padding-left','10','5342','','.account-samples'),(933248,'printshop','.account-sample-info .contentColumn','padding-left','40','','','.account-sample-info'),(933249,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-left','40','','','.account-sample-info'),(933250,'printshop','.account-sample-info .history_info > div + div','padding-left','2','','','.account-sample-info'),(933251,'printshop','.account-sample-info .popup-tracking-number','padding-left','10','','','.account-sample-info'),(933252,'printshop','.account-sample-info .history_info > div','padding-left','0','5342','','.account-sample-info'),(933253,'printshop','.account-sample-info .history_info > div + div','padding-left','0','5342','','.account-sample-info'),(933254,'printshop','.catalog-product-wrap .next-product','padding-left','20','','','.catalog-product-wrap'),(933255,'printshop','.catalog-product-wrap .next-product .pn-image','padding-left','2','3','','.catalog-product-wrap'),(933256,'printshop','.catalog-product-wrap .pn-direction','padding-left','4','','','.catalog-product-wrap'),(933257,'printshop','.catalog-product-wrap .pn-image','padding-left','5','','','.catalog-product-wrap'),(933258,'printshop','.catalog-product-wrap .prev-product','padding-left','50','','','.catalog-product-wrap'),(933259,'printshop','.catalog-product-wrap .next-product','padding-left','0','5342','','.catalog-product-wrap'),(933260,'printshop','.catalog-product-wrap .pn-direction','padding-left','0','5342','','.catalog-product-wrap'),(933261,'printshop','.catalog-product-wrap .prev-product','padding-left','0','5342','','.catalog-product-wrap'),(933262,'printshop','.shopping-cart-index .btn-3','padding-left','25','','','.shopping-cart-index'),(933263,'printshop','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-left','20','','','.shopping-cart-index'),(933264,'printshop','.checkout-index-wrap .datepicker-inline','padding-left','0','','','.checkout-index-wrap'),(933265,'printshop','.checkout-index-wrap .edit-address-popup','padding-left','20','','','.checkout-index-wrap'),(933266,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-left','15','','','.checkout-index-wrap'),(933267,'printshop','.checkout-index-wrap .hiding-box .checkout-cart-listing','padding-left','30','','','.checkout-index-wrap'),(933268,'printshop','.checkout-order-confirmation .price-row','padding-left','0','','','.checkout-order-confirmation'),(933269,'printshop','.b-bottom .pop-up-content','padding-left','20','','','.b-bottom'),(933270,'printshop','.b-form .address-main.addresses .address-item','padding-left','0','','','.b-form'),(933271,'printshop','.b-form .columns .col-2','padding-left','5','','','.b-form'),(933272,'printshop','.b-slick .slick-dots li','padding-left','5','','','.b-slick'),(933274,'printshop','.success-page .check-ico-block','padding-left','10','','','.success-page'),(933275,'printshop','.success-page .order-summary2 .btn-2','padding-left','50','','','.success-page'),(933276,'printshop','.success-page .order_totals .price-row','padding-left','0','','','.success-page'),(933277,'printshop','.success-page .price-row','padding-left','0','','','.success-page'),(933278,'printshop','.success-page .w-cart-listing .item.sub-product','padding-left','50','','','.success-page'),(933279,'printshop','.success-page .w-cart-listing .qty','padding-left','0','','','.success-page'),(933280,'printshop','.success-page .w-cart-listing .sub-product .image','padding-left','0','','','.success-page'),(933281,'printshop','.b-multi-page-checkout .multi-page-checkout .buttons','padding-left','0','','','.b-multi-page-checkout'),(933282,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-left','10','','','.b-multi-page-checkout'),(933283,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-left','10','','','.b-multi-page-checkout'),(933284,'printshop','.tripleLine .banner-text','padding-left','0','','','.tripleLine'),(933285,'printshop','.doubleBanner .w-banner .banner-holder','padding-left','0','','','.doubleBanner'),(933286,'printshop','.doubleBanner .w-banner .banner-item','padding-left','15','','','.doubleBanner'),(933287,'printshop','.doubleBanner .w-banner .banner-text','padding-left','0','','','.doubleBanner'),(933288,'printshop','.middleBanner .banner-text-holder','padding-left','10','5363','','.middleBanner'),(933289,'printshop','.middleBanner div.banner-text-holder','padding-left','30','','','.middleBanner'),(933290,'printshop','.middleBanner div.banner-text','padding-left','0','','','.middleBanner'),(933291,'printshop','.bottomBanner .w-banner .banner-text','padding-left','0','','','.bottomBanner'),(933292,'printshop','.bottomDoubleBanner .w-banner .banner-holder','padding-left','0','','','.bottomDoubleBanner'),(933293,'printshop','.bottomDoubleBanner .w-banner .banner-text-holder','padding-left','30','','','.bottomDoubleBanner'),(933294,'printshop','.bottomDoubleBanner .w-banner .banner-text','padding-left','0','','','.bottomDoubleBanner'),(933295,'printshop','.bottomDoubleBanner .w-banner .banner-holder','padding-left','0','5363','','.bottomDoubleBanner'),(933296,'printshop','.bottomDoubleBanner .w-banner .banner-item','padding-left','15','','','.bottomDoubleBanner'),(933301,'printshop','.footer-menu .level-2 > li','padding-left','18','','','.footer-menu'),(933302,'printshop','.footer-menu .level-2 > li.component-item','padding-left','0','','','.footer-menu'),(933303,'printshop','.footer-menu .level-1 > li > .no-link','padding-left','0','5342','','.footer-menu'),(933304,'printshop','.w-bestsellers .heading-3','padding-left','55','','','.w-bestsellers'),(933305,'printshop','.w-banner .banner-text','padding-left','20','','','.w-banner'),(933306,'printshop','.w-banner .carousel-text > span','padding-left','20','','','.w-banner'),(933307,'printshop','.w-catalog-paging ','padding-left','5','2','','.w-catalog-paging'),(933308,'printshop','.w-catalog-paging .next','padding-left','5','','','.w-catalog-paging'),(933309,'printshop','.w-catalog-paging .next-pages','padding-left','5','','','.w-catalog-paging'),(933310,'printshop','.w-catalog-paging .page-number','padding-left','5','','','.w-catalog-paging'),(933311,'printshop','.w-catalog-paging .paging-item','padding-left','2','','','.w-catalog-paging'),(933312,'printshop','.w-catalog-paging .prev','padding-left','5','','','.w-catalog-paging'),(933313,'printshop','.w-catalog-paging .prev-pages','padding-left','5','','','.w-catalog-paging'),(933318,'printshop','.w-sale .holder-1','padding-left','20','','','.w-sale'),(933319,'printshop','.w-sale .holder-2','padding-left','20','','','.w-sale'),(933320,'printshop','.w-sale .left-count','padding-left','5','','','.w-sale'),(933321,'printshop','.w-social-links a','padding-left','8','','','.w-social-links'),(933322,'printshop','.b-data-table table.dataTable tbody td','padding-left_important','important','','','.b-data-table'),(933323,'printshop','.b-data-table table.dataTable thead td','padding-left_important','important','','','.b-data-table'),(933324,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left_important','important','','','.b-data-table'),(933325,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left_important','important','','','.b-data-table'),(933326,'printshop','.w-cart-listing .points','padding-left_important','important','5333','','.w-cart-listing'),(933327,'printshop','.w-account-personal-catalog .buy-box','padding-left_important','important','5333','','.w-account-personal-catalog'),(933328,'printshop','.topBanner > .block','padding-left_important','important','','','.topBanner'),(933329,'printshop','.w-account-personal-catalog .buy-box','padding-left_important','important','5363','','.w-account-personal-catalog'),(933330,'printshop','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-right','10','','','.w-communication-new-topic'),(933331,'printshop','.b-email .image','padding-right','10','','','.b-email'),(933332,'printshop','.order-summary .btn-2, .order-summary .btn-3','padding-right','5','','','.order-summary'),(933333,'printshop','.b-table .table td','padding-right','15','','','.b-table'),(933336,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(933337,'printshop','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(933338,'printshop','.b-form .required-message-wrap','padding-right','0','','','.b-form'),(933339,'printshop','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-right','10','','','.p-quick-order-index'),(933340,'printshop','.p-quick-order-index ul.token-input-list','padding-right','0','','','.p-quick-order-index'),(933341,'printshop','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-right','10','','','.p-quick-order-index'),(933342,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.p-quick-order-index'),(933343,'printshop','.w-promotions .promo-date > div','padding-right','50','','','.w-promotions'),(933344,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.p-quick-order-index'),(933345,'printshop','.w-promotions .promo-item','padding-right','40','','','.w-promotions'),(933346,'printshop','.w-socials > li','padding-right','15','','','.w-socials'),(933347,'printshop','.w-cart-compare .attributes-label','padding-right','10','','','.w-cart-compare'),(933352,'printshop','.w-personal-gift-status-bar .start-label','padding-right','5','','','.w-personal-gift-status-bar'),(933353,'printshop','.w-personal-gift-status-bar .end-label','padding-right','30','','','.w-personal-gift-status-bar'),(933354,'printshop','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(933355,'printshop','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(933356,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(933357,'printshop','.b-email .image','padding-right','10','','','.b-email'),(933358,'printshop','.b-email .heading-qty','padding-right','10','','','.b-email'),(933359,'printshop','.b-email .totals-value','padding-right','10','','','.b-email'),(933360,'printshop','.b-email .model','padding-right','10','','','.b-email'),(933361,'printshop','.testimonials .heading-3','padding-right','0','','',''),(933362,'printshop','.testimonials .review','padding-right','10','','',''),(933363,'printshop','.testimonials .reviews-list .name','padding-right','10','','',''),(933364,'printshop','.testimonials .name','padding-right','10','','',''),(933365,'printshop','.w-categories .image','padding-right','0','','','.w-categories'),(933366,'printshop','.w-promotions .prom-multi-discount .promo-range','padding-right','20','','','.w-promotions'),(933367,'printshop','.w-promotions .prom-multi-discount .promo-product','padding-right','20','','','.w-promotions'),(933368,'printshop','.w-promotions .nextdiscount .item-holder .image','padding-right','10','','','.w-promotions'),(933369,'printshop','.w-promotions .nextdiscount .content > div','padding-right','10','','','.w-promotions'),(933370,'printshop','.w-promotions .master','padding-right','15','','','.w-promotions'),(933371,'printshop','.w-promotions .nextdiscount .promo-for-each','padding-right','20','','','.w-promotions'),(933372,'printshop','.w-promotions .heading','padding-right','10','','','.w-promotions'),(933373,'printshop','.w-promotions .promo-salemaker .promo-categories','padding-right','12','','','.w-promotions'),(933374,'printshop','.w-promotions .promo-salemaker .item','padding-right','20','','','.w-promotions'),(933375,'printshop','.w-promotions .promo-salemaker .discount','padding-right','20','','','.w-promotions'),(933376,'printshop','.w-promotions .promo-cart-discount .slave .item','padding-right','20','','','.w-promotions'),(933377,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','padding-right','20','','','.w-promotions'),(933378,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','padding-right','20','','','.w-promotions'),(933379,'printshop','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-right','20','','','.b-warehouses-popup'),(933380,'printshop','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-right','2','','','.b-products-listing'),(933382,'printshop','.w-cart-compare .attributes-cell','padding-right','20','','','.w-cart-compare'),(933383,'printshop','.b-table .table td','padding-right','15','','','.b-table'),(933384,'printshop','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(933385,'printshop','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(933387,'printshop','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(933388,'printshop','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(933389,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(933390,'printshop','.b-bottom .confirm-popup .confirm-text','padding-right','0','','','.b-bottom'),(933391,'printshop','.w-top-categories h2.name','padding-right','3','','','.w-top-categories'),(933392,'printshop','.b-messages .messages-menu ul','padding-right','0','','','.b-messages'),(933393,'printshop','.b-messages .development-content .type-6 .content','padding-right','40','','','.b-messages'),(933394,'printshop','.b-messages .msv_btn','padding-right','0','','','.b-messages'),(933395,'printshop','.b-messages .msv_content','padding-right','20','','','.b-messages'),(933396,'printshop','.b-messages .msv_history','padding-right','20','','','.b-messages'),(933397,'printshop','.b-messages .messMenuButton span','padding-right','15','','','.b-messages'),(933398,'printshop','.b-messages .messages-menu li a','padding-right','0','','','.b-messages'),(933399,'printshop','.b-messages .messages-menu li','padding-right','0','','','.b-messages'),(933400,'printshop','.b-messages .content_management_attach button','padding-right','27','','','.b-messages'),(933401,'printshop','.b-messages .email-heading','padding-right','15','','','.b-messages'),(933402,'printshop','.b-messages .content_management_attach','padding-right','8','','','.b-messages'),(933403,'printshop','.b-messages .emailLineTextArea textarea','padding-right','10','','','.b-messages'),(933404,'printshop','.b-messages .msv_to_cc','padding-right','15','','','.b-messages'),(933405,'printshop','.b-messages .emailBtn','padding-right','10','','','.b-messages'),(933406,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-right','10','','','.b-messages'),(933407,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-right','10','','',''),(933408,'printshop','.w-sitemap-delivery-location > ul > li > ul > li','padding-right','20','','','.w-sitemap-delivery-location'),(933409,'printshop','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(933410,'printshop','.w-reviews-content .item','padding-right','0','','','.w-reviews-content'),(933411,'printshop','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(933412,'printshop','.w-sitemap-delivery-location > ul > li > ul','padding-right','0','','','.w-sitemap-delivery-location'),(933413,'printshop','.w-sitemap-delivery-location > ul','padding-right','0','','','.w-sitemap-delivery-location'),(933414,'printshop','.w-checkout-terms .required-message','padding-right','10','','','.w-checkout-terms'),(933415,'printshop','.w-cart-listing .item .remove','padding-right','10','5342','','.w-cart-listing'),(933416,'printshop','.b-table .table td','padding-right','15','','','.b-table'),(933417,'printshop','.b-info .info li','padding-right','0','','','.b-info'),(933418,'printshop','.b-info .info ul','padding-right','0','','','.b-info'),(933419,'printshop','.b-email .model','padding-right','10','','','.b-email'),(933420,'printshop','.b-upload-file .upload-file-template','padding-right','1','','','.b-upload-file'),(933421,'printshop','.b-email .heading-image','padding-right','10','','','.b-email'),(933422,'printshop','.b-email .heading-image','padding-right','10','','','.b-email'),(933423,'printshop','.b-email .heading-price','padding-right','10','','','.b-email'),(933424,'printshop','.b-email .heading-name','padding-right','10','','','.b-email'),(933425,'printshop','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(933426,'printshop','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(933427,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(933428,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(933429,'printshop','.b-email .price','padding-right','10','','','.b-email'),(933430,'printshop','.w-filters .filter-ul-content','padding-right','0','','','.w-filters'),(933431,'printshop','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(933432,'printshop','.w-login-block .returning','padding-right','40','','','.w-login-block'),(933433,'printshop','.w-menu-horizontal > ul > li > ul > li','padding-right','10','','','.w-menu-horizontal'),(933434,'printshop','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-right','10','','','.w-menu-horizontal'),(933435,'printshop','.w-menu-horizontal ul','padding-right','0','','','.w-menu-horizontal'),(933436,'printshop','.w-tabs .tab-navigation','padding-right','0','','','.w-tabs'),(933437,'printshop','.b-email .heading-model','padding-right','10','','','.b-email'),(933438,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(933439,'printshop','.b-email .heading-price','padding-right','10','','','.b-email'),(933441,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(933442,'printshop','.b-fancybox .fancybox-title-over-wrap','padding-right','10','','','.b-fancybox'),(933443,'printshop','.b-email .image','padding-right','10','','','.b-email'),(933444,'printshop','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(933445,'printshop','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(933446,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(933447,'printshop','.b-table .table .headings td','padding-right','10','','','.b-table'),(933448,'printshop','.b-sub-totals .historyTotal td','padding-right','5','','','.b-sub-totals'),(933449,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(933450,'printshop','.b-email .heading-price','padding-right','10','','','.b-email'),(933451,'printshop','.b-email .qty','padding-right','10','','','.b-email'),(933452,'printshop','.w-cart-compare .dropdown .dropdown-menu','padding-right','0','','','.w-cart-compare'),(933453,'printshop','textarea','padding-right','10','','',''),(933454,'printshop','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(933455,'printshop','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(933456,'printshop','.w-cart-compare .product','padding-right','15','','','.w-cart-compare'),(933457,'printshop','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(933458,'printshop','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(933460,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-right','10','','','.w-image-maps'),(933461,'printshop','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(933462,'printshop','.b-table .table .headings td','padding-right','10','','','.b-table'),(933463,'printshop','.b-form .payment-method .item','padding-right','0','','','.b-form'),(933464,'printshop','.message.success','padding-right','0','','',''),(933465,'printshop','.w-promo-code .holder','padding-right','20','5363','','.w-promo-code'),(933466,'printshop','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(933467,'printshop','.w-checkout-shipping-choice span','padding-right','0','','','.w-checkout-shipping-choice'),(933468,'printshop','.b-info .info ul','padding-right','0','','','.b-info'),(933469,'printshop','.b-email .heading-qty','padding-right','10','','','.b-email'),(933470,'printshop','.p-quick-order-index .bottom','padding-right','0','','','.p-quick-order-index'),(933471,'printshop','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(933472,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-right','0','','','.b-select-suggest'),(933473,'printshop','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(933474,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(933475,'printshop','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(933476,'printshop','.w-reviews .review','padding-right','10','','','.w-reviews'),(933477,'printshop','.w-socials > li','padding-right','15','','','.w-socials'),(933480,'printshop','.b-info-popup .info-popup div','padding-right','15','','','.b-info-popup'),(933481,'printshop','.b-form .password-forgotten-link','padding-right','0','','','.b-form'),(933483,'printshop','.w-cart-compare .atr-col','padding-right','30','','','.w-cart-compare'),(933484,'printshop','.w-reviews .author','padding-right','10','','','.w-reviews'),(933485,'printshop','.b-info .info ul','padding-right','0','','','.b-info'),(933486,'printshop','.b-form .login-col-1','padding-right','20','','','.b-form'),(933487,'printshop','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(933488,'printshop','.w-promo-code .holder','padding-right','20','5363','','.w-promo-code'),(933489,'printshop','.w-product-images-additional .images','padding-right','0','5363','','.w-product-images-additional'),(933490,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(933491,'printshop','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-right','0','','','.w-multi-cart-actions'),(933492,'printshop','.w-top-categories .item','padding-right','20','','','.w-top-categories'),(933493,'printshop','.w-tabs > .block','padding-right','20','','','.w-tabs'),(933494,'printshop','.w-tabs .accordion-heading','padding-right','8','5333','','.w-tabs'),(933495,'printshop','.w-cart-cart-tabs .w-tabs > .block','padding-right','0','','','.w-cart-cart-tabs'),(933496,'printshop','.w-tabs .tab-a','padding-right','6','','','.w-tabs'),(933497,'printshop','.w-socials > li','padding-right','15','','','.w-socials'),(933498,'printshop','.b-autocomplete .ui-autocomplete li','padding-right','10','','','.b-autocomplete'),(933499,'printshop','.b-bottom .popup-buttons','padding-right','15','','','.b-bottom'),(933500,'printshop','.b-bottom .popup-content','padding-right','15','','','.b-bottom'),(933501,'printshop','.w-product-images-additional .images','padding-right','0','5363','','.w-product-images-additional'),(933502,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(933503,'printshop','.b-form .required-message','padding-right','3','','','.b-form'),(933504,'printshop','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(933505,'printshop','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(933506,'printshop','.btn-1','padding-right','25','','',''),(933507,'printshop','.w-reviews-content .review','padding-right','20','','','.w-reviews-content'),(933508,'printshop','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(933509,'printshop','.b-table .table .headings td','padding-right','10','','','.b-table'),(933510,'printshop','.b-info .info','padding-right','0','','','.b-info'),(933511,'printshop','.btn-3','padding-right','25','','',''),(933512,'printshop','.w-filters .filter-widget-horizontal .filter-box','padding-right','20','','','.w-filters'),(933513,'printshop','.w-product-images-additional .images','padding-right','0','5363','','.w-product-images-additional'),(933514,'printshop','.b-products-listing .products-listing .buyButton .btn','padding-right','10','','','.b-products-listing'),(933515,'printshop','.b-bottom .popup-heading','padding-right','15','','','.b-bottom'),(933516,'printshop','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(933517,'printshop','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(933518,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(933519,'printshop','.b-info .info li','padding-right','0','','','.b-info'),(933520,'printshop','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(933521,'printshop','.b-email .totals-title','padding-right','10','','','.b-email'),(933522,'printshop','.b-email .price','padding-right','10','','','.b-email'),(933523,'printshop','.b-email .totals-value','padding-right','10','','','.b-email'),(933524,'printshop','.b-email .heading-name','padding-right','10','','','.b-email'),(933525,'printshop','.b-email .image','padding-right','10','','','.b-email'),(933526,'printshop','.b-email .name','padding-right','10','','','.b-email'),(933527,'printshop','.order-summary .price-row','padding-right','0','','','.order-summary'),(933528,'printshop','.b-email .name','padding-right','10','','','.b-email'),(933529,'printshop','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-right','0','','','.b-fancybox'),(933530,'printshop','.w-socials > li','padding-right','15','','','.w-socials'),(933532,'printshop','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(933533,'printshop','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(933534,'printshop','.b-select-suggest .select2-drop-mask','padding-right','0','','','.b-select-suggest'),(933536,'printshop','.w-quote .cart-box-link','padding-right','10','','','.w-quote'),(933537,'printshop','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(933538,'printshop','.b-email .price','padding-right','10','','','.b-email'),(933539,'printshop','.b-fancybox .fancybox-title-float-wrap .child','padding-right','20','','','.b-fancybox'),(933540,'printshop','.w-checkout-shipping-choice span','padding-right','10','5363','','.w-checkout-shipping-choice'),(933541,'printshop','.w-top-categories .categories h2','padding-right','0','','','.w-top-categories'),(933542,'printshop','.w-top-categories .image','padding-right','0','','','.w-top-categories'),(933543,'printshop','.w-product-reviews .reviews-list .review','padding-right','10','','','.w-product-reviews'),(933544,'printshop','.w-reviews-content .product-image','padding-right','10','','','.w-reviews-content'),(933545,'printshop','.w-product-reviews .reviews-list .name','padding-right','10','','','.w-product-reviews'),(933546,'printshop','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(933547,'printshop','.b-email .name','padding-right','10','','','.b-email'),(933548,'printshop','.b-fancybox .fancybox-prev span','padding-right','4','3','','.b-fancybox'),(933549,'printshop','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(933550,'printshop','.b-bottom .popup-simple','padding-right','20','','','.b-bottom'),(933551,'printshop','.b-bottom .rfq-form','padding-right','20','','','.b-bottom'),(933552,'printshop','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(933553,'printshop','.b-email .heading-image','padding-right','10','','','.b-email'),(933554,'printshop','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(933555,'printshop','.b-email .model','padding-right','10','','','.b-email'),(933556,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(933557,'printshop','.b-email .name','padding-right','10','','','.b-email'),(933558,'printshop','.b-email .heading-price','padding-right','10','','','.b-email'),(933559,'printshop','.b-email .heading-qty','padding-right','10','','','.b-email'),(933560,'printshop','.b-email .image','padding-right','10','','','.b-email'),(933561,'printshop','.b-email .price','padding-right','10','','','.b-email'),(933562,'printshop','.b-email .heading-model','padding-right','10','','','.b-email'),(933563,'printshop','.b-email .totals-title','padding-right','10','','','.b-email'),(933564,'printshop','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(933565,'printshop','.b-email .totals-value','padding-right','10','','','.b-email'),(933566,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(933567,'printshop','.b-email .price','padding-right','10','','','.b-email'),(933568,'printshop','.b-email .qty','padding-right','10','','','.b-email'),(933569,'printshop','.b-email .heading-name','padding-right','10','','','.b-email'),(933570,'printshop','.b-email .heading-image','padding-right','10','','','.b-email'),(933571,'printshop','.b-info .info li','padding-right','0','','','.b-info'),(933572,'printshop','.w-checkout-shipping .sub-item','padding-right','0','','','.w-checkout-shipping'),(933573,'printshop','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(933574,'printshop','.b-table .table .headings td','padding-right','10','','','.b-table'),(933575,'printshop','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(933576,'printshop','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(933577,'printshop','.w-promo-code .holder','padding-right','20','5363','','.w-promo-code'),(933578,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(933579,'printshop','.b-form .center-buttons','padding-right','0','','','.b-form'),(933580,'printshop','.b-form .shipping-method .input','padding-right','10','','','.b-form'),(933581,'printshop','.w-reviews .item','padding-right','0','','','.w-reviews'),(933582,'printshop','.w-reviews .product-image','padding-right','20','','','.w-reviews'),(933583,'printshop','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(933584,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(933585,'printshop','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(933586,'printshop','.b-select-suggest .select2-container .select2-choice','padding-right','0','','','.b-select-suggest'),(933587,'printshop','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(933588,'printshop','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(933589,'printshop','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(933590,'printshop','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(933591,'printshop','.b-info .info','padding-right','0','','','.b-info'),(933592,'printshop','.b-info .info li','padding-right','0','','','.b-info'),(933593,'printshop','.b-info .info ul','padding-right','0','','','.b-info'),(933594,'printshop','.b-bottom .terms-info-popup .pop-up-content','padding-right','20','','','.b-bottom'),(933595,'printshop','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','5342','','.w-menu-horizontal'),(933596,'printshop','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(933597,'printshop','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(933598,'printshop','.b-upload-files .upload-files','padding-right','10','','','.b-upload-files'),(933599,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(933600,'printshop','.w-login-block .returning','padding-right','40','','','.w-login-block'),(933601,'printshop','.b-form .form-buttons','padding-right','0','','','.b-form'),(933602,'printshop','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(933603,'printshop','.w-login-block .returning','padding-right','40','','','.w-login-block'),(933604,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(933606,'printshop','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(933607,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(933608,'printshop','.w-cart-compare .delete-cart','padding-right','10','','','.w-cart-compare'),(933609,'printshop','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(933610,'printshop','.b-email .name','padding-right','10','','','.b-email'),(933611,'printshop','.b-email .totals-value','padding-right','10','','','.b-email'),(933612,'printshop','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(933613,'printshop','.b-email .qty','padding-right','10','','','.b-email'),(933614,'printshop','.b-email .heading-name','padding-right','10','','','.b-email'),(933615,'printshop','.b-email .heading-model','padding-right','10','','','.b-email'),(933616,'printshop','.w-categories .item','padding-right','20','','','.w-categories'),(933617,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(933618,'printshop','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(933619,'printshop','.b-email .heading-image','padding-right','10','','','.b-email'),(933620,'printshop','.b-email .heading-price','padding-right','10','','','.b-email'),(933621,'printshop','.b-email .image','padding-right','10','','','.b-email'),(933622,'printshop','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-right','20','','','.b-bottom'),(933623,'printshop','.w-promo-code .holder','padding-right','20','5363','','.w-promo-code'),(933624,'printshop','.b-compare .popupCompare .pop-up-content','padding-right','10','','','.b-compare'),(933625,'printshop','.w-promotions .promo-cart-discount .master .item','padding-right','20','','','.w-promotions'),(933626,'printshop','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(933627,'printshop','.b-bottom .cart-options','padding-right','20','','','.b-bottom'),(933628,'printshop','.b-bottom .alert-message','padding-right','20','','','.b-bottom'),(933629,'printshop','.b-select-suggest .select2-results .select2-result-label','padding-right','7','','','.b-select-suggest'),(933630,'printshop','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(933631,'printshop','.b-email .totals-title','padding-right','10','','','.b-email'),(933634,'printshop','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(933635,'printshop','.b-email .heading-model','padding-right','10','','','.b-email'),(933636,'printshop','.b-email .heading-qty','padding-right','10','','','.b-email'),(933637,'printshop','.b-info .info','padding-right','0','','','.b-info'),(933638,'printshop','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(933639,'printshop','.b-email .model','padding-right','10','','','.b-email'),(933640,'printshop','.b-email .heading-model','padding-right','10','','','.b-email'),(933641,'printshop','.b-bottom .footerTitle','padding-right','0','5333','','.b-bottom'),(933642,'printshop','.b-bottom .pop-up-close','padding-right','1','','','.b-bottom'),(933643,'printshop','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(933644,'printshop','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(933645,'printshop','.w-cart-shipping-estimator .address-item','padding-right','10','','','.w-cart-shipping-estimator'),(933646,'printshop','.w-cart-up-sell .w-list-type-1','padding-right','0','','','.w-cart-up-sell'),(933647,'printshop','.w-cart-up-sell .w-list-type-1 .item','padding-right','21','','','.w-cart-up-sell'),(933648,'printshop','.w-cart-up-sell .w-list-type-1 .item','padding-right','20','1','','.w-cart-up-sell'),(933649,'printshop','.b-upload-files .added-file','padding-right','0','','','.b-upload-files'),(933650,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(933651,'printshop','.b-bottom .popup-box-wrap','padding-right','10','','','.b-bottom'),(933652,'printshop','.b-bottom .pop-up-info','padding-right','20','','','.b-bottom'),(933653,'printshop','.b-email .qty','padding-right','10','','','.b-email'),(933654,'printshop','.b-email .name','padding-right','10','','','.b-email'),(933655,'printshop','.b-email .heading-qty','padding-right','10','','','.b-email'),(933656,'printshop','.b-fancybox .fancybox-error','padding-right','15','','','.b-fancybox'),(933657,'printshop','.b-email .totals-title','padding-right','10','','','.b-email'),(933658,'printshop','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(933659,'printshop','.w-product-customers-activity .customers-activity','padding-right','20','','','.w-product-customers-activity'),(933660,'printshop','.w-product-available-in-warehouses .warehouse-item','padding-right','20','','','.w-product-available-in-warehouses'),(933661,'printshop','.b-table .table td','padding-right','15','','','.b-table'),(933662,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(933663,'printshop','.b-email .heading-name','padding-right','10','','','.b-email'),(933664,'printshop','.b-email .heading-model','padding-right','10','','','.b-email'),(933665,'printshop','.b-table .table .headings td','padding-right','10','','','.b-table'),(933666,'printshop','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(933667,'printshop','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(933668,'printshop','.w-cart-compare .price-label','padding-right','10','','','.w-cart-compare'),(933669,'printshop','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(933670,'printshop','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(933671,'printshop','.w-checkout-billing-address .edit-ab','padding-right','0','','','.w-checkout-billing-address'),(933672,'printshop','.w-checkout-billing-address .addresses .address-item label','padding-right','10','','','.w-checkout-billing-address'),(933673,'printshop','.w-promo-code .holder','padding-right','20','5363','','.w-promo-code'),(933674,'printshop','.w-product-images-additional .images','padding-right','0','5363','','.w-product-images-additional'),(933675,'printshop','.w-categories h2.name','padding-right','3','','','.w-categories'),(933676,'printshop','.w-tabs .accordion-heading','padding-right','6','','','.w-tabs'),(933677,'printshop','.w-socials > li','padding-right','15','','','.w-socials'),(933678,'printshop','.w-product-images-additional .images','padding-right','0','5363','','.w-product-images-additional'),(933679,'printshop','.w-promo-code .holder','padding-right','20','5363','','.w-promo-code'),(933680,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','padding-right','5','','','.b-switch'),(933681,'printshop','.p-quick-order-index .all-scroll-div','padding-right','0','','','.p-quick-order-index'),(933682,'printshop','.w-cart-compare .price-cell','padding-right','20','','','.w-cart-compare'),(933683,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(933684,'printshop','.w-checkout-shipping-address .edit-ab','padding-right','0','','','.w-checkout-shipping-address'),(933685,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(933686,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-right','5','','','.b-select-suggest'),(933687,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-right','0','','','.b-select-suggest'),(933688,'printshop','.b-select-suggest .select2-locked','padding-right','5','','','.b-select-suggest'),(933689,'printshop','.b-select-suggest .select2-container-multi .select2-choices','padding-right','0','','','.b-select-suggest'),(933690,'printshop','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','','','.w-menu-horizontal'),(933691,'printshop','.b-form .shipping-method .item + .item','padding-right','0','','','.b-form'),(933692,'printshop','.w-checkout-shipping-address .addresses .address-item label','padding-right','10','','','.w-checkout-shipping-address'),(933693,'printshop','.b-select-suggest .select2-search','padding-right','4','','','.b-select-suggest'),(933694,'printshop','.b-select-suggest .select2-search input','padding-right','20','','','.b-select-suggest'),(933695,'printshop','.b-select-suggest .select2-results','padding-right','4','','','.b-select-suggest'),(933696,'printshop','.p-wedding-registry-search .search-list','padding-right','20','','','.p-wedding-registry-search'),(933700,'printshop','.b-compare .compare-box-item','padding-right','10','','','.b-compare'),(933701,'printshop','.w-cart-compare .product-label','padding-right','10','','','.w-cart-compare'),(933702,'printshop','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(933703,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(933704,'printshop','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(933705,'printshop','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(933706,'printshop','.w-cart-compare .dropdown li','padding-right','10','','','.w-cart-compare'),(933708,'printshop','.w-login-block .returning','padding-right','40','','','.w-login-block'),(933709,'printshop','.w-menu-big ul','padding-right','0','','','.w-menu-big'),(933710,'printshop','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(933711,'printshop','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(933712,'printshop','.b-bottom .notify-form','padding-right','20','','','.b-bottom'),(933713,'printshop','.w-account-addresses-list .addsess-suggestion-item','padding-right','20','','','.w-account-addresses-list'),(933714,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.b-data-table'),(933715,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.b-data-table'),(933716,'printshop','.w-communication-post .communication-post-author','padding-right','0','','','.w-communication-post'),(933717,'printshop','.b-products-listing .in-cart','padding-right','10','','','.b-products-listing'),(933718,'printshop','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-right','5','','','.w-catalog-b2b-add-button'),(933719,'printshop','.b-products-listing .promos-info .promo-name','padding-right','15','','','.b-products-listing'),(933720,'printshop','.b-products-listing .promos-info .promo-item','padding-right','10','','','.b-products-listing'),(933721,'printshop','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(933727,'printshop','.b-compare .col-two label','padding-right','0','','','.b-compare'),(933728,'printshop','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(933729,'printshop','.w-checkout-gdpr .privacy-row','padding-right','0','','','.w-checkout-gdpr'),(933730,'printshop','.w-checkout-gdpr .terms-login','padding-right','0','','','.w-checkout-gdpr'),(933731,'printshop','.b-table .table td','padding-right','15','','','.b-table'),(933732,'printshop','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(933733,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(933734,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(933735,'printshop','.b-info .info ul','padding-right','0','','','.b-info'),(933736,'printshop','.b-form .middle-form','padding-right','0','','','.b-form'),(933737,'printshop','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(933739,'printshop','.w-checkout-billing-address .same-address','padding-right','10','','','.w-checkout-billing-address'),(933740,'printshop','.w-reviews .heading-3','padding-right','0','','','.w-reviews'),(933741,'printshop','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(933742,'printshop','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(933743,'printshop','.w-personal-gift-status-bar .timeline','padding-right','10','','','.w-personal-gift-status-bar'),(933744,'printshop','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(933745,'printshop','.w-catalog-sorting .before','padding-right','5','','','.w-catalog-sorting'),(933747,'printshop','.b-compare .compare-head','padding-right','10','','','.b-compare'),(933748,'printshop','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(933749,'printshop','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(933750,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-right','0','','',''),(933751,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-right','0','','','.b-h-inline'),(933752,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-right','0','','','.w-communication-new-topic'),(933753,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-right','10','','','.w-communication-new-topic'),(933754,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-right','5','','','.w-communication-new-topic'),(933755,'printshop','.w-communication-new-topic #communication_topic_form .middle-form','padding-right','0','','','.w-communication-new-topic'),(933756,'printshop','.b-info .info','padding-right','0','','','.b-info'),(933757,'printshop','.b-info .info li','padding-right','0','','','.b-info'),(933758,'printshop','.b-email .totals-title','padding-right','10','','','.b-email'),(933759,'printshop','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(933760,'printshop','.b-email .heading-qty','padding-right','10','','','.b-email'),(933761,'printshop','.b-email .model','padding-right','10','','','.b-email'),(933762,'printshop','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-right','6','','','.b-compare'),(933763,'printshop','.btn-2','padding-right','25','','',''),(933764,'printshop','.b-compare .compare_pagination','padding-right','0','','','.b-compare'),(933765,'printshop','.w-product-images-additional .images','padding-right','0','5363','','.w-product-images-additional'),(933766,'printshop','.b-bottom .header-info','padding-right','20','','','.b-bottom'),(933767,'printshop','.w-cart-checkout-btn a','padding-right','12','5333','','.w-cart-checkout-btn'),(933768,'printshop','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(933769,'printshop','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-right','10','','','.order-summary'),(933772,'printshop','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(933773,'printshop','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(933774,'printshop','.b-table .table td','padding-right','15','','','.b-table'),(933775,'printshop','.b-info .info','padding-right','0','','','.b-info'),(933776,'printshop','.b-info .info ul','padding-right','0','','','.b-info'),(933777,'printshop','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-right','0','','','.b-fancybox'),(933778,'printshop','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(933779,'printshop','.products-quick-index .token-input-list','padding-right','0','','',''),(933780,'printshop','.w-cart-compare .cart-cell','padding-right','7','','','.w-cart-compare'),(933781,'printshop','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(933782,'printshop','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(933783,'printshop','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(933784,'printshop','.b-form .shipping-method .item','padding-right','0','','','.b-form'),(933785,'printshop','.b-email .price','padding-right','10','','','.b-email'),(933786,'printshop','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(933787,'printshop','.b-email .heading-image','padding-right','10','','','.b-email'),(933788,'printshop','.w-cart-listing .item .attributes strong','padding-right','10','','','.w-cart-listing'),(933789,'printshop','.w-cart-listing .item .gift-wrap label','padding-right','10','','','.w-cart-listing'),(933790,'printshop','.w-cart-listing .item > div','padding-right','10','','','.w-cart-listing'),(933791,'printshop','.w-cart-listing .points-earn','padding-right','0','','','.w-cart-listing'),(933792,'printshop','.w-cart-listing .points-redeem','padding-right','0','','','.w-cart-listing'),(933793,'printshop','.w-cart-give-away .ga_img','padding-right','1','','','.w-cart-give-away'),(933794,'printshop','.b-bottom .header-error','padding-right','20','','','.b-bottom'),(933795,'printshop','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(933802,'printshop','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(933803,'printshop','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(933804,'printshop','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(933805,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(933806,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(933807,'printshop','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(933808,'printshop','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(933809,'printshop','.b-compare .col-gender','padding-right','0','','','.b-compare'),(933810,'printshop','.b-email .qty','padding-right','10','','','.b-email'),(933811,'printshop','.b-email .heading-price','padding-right','10','','','.b-email'),(933812,'printshop','.w-top-categories .item','padding-right','10','5333','','.w-top-categories'),(933813,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(933814,'printshop','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(933817,'printshop','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(933818,'printshop','.w-socials > li','padding-right','15','','','.w-socials'),(933819,'printshop','.w-contact-contacts table td','padding-right','10','','','.w-contact-contacts'),(933820,'printshop','.w-login-block .returning','padding-right','40','','','.w-login-block'),(933822,'printshop','.w-filters .fsl_handle','padding-right','0','','','.w-filters'),(933823,'printshop','.w-filters .head-filter-widget','padding-right','10','5342','','.w-filters'),(933824,'printshop','.w-filters .ui-slider-range','padding-right','0','','','.w-filters'),(933825,'printshop','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(933826,'printshop','.w-filters .head-filter-widget','padding-right','0','','','.w-filters'),(933827,'printshop','.w-filters .handle_tit','padding-right','5','','','.w-filters'),(933828,'printshop','.b-autocomplete .ui-autocomplete','padding-right','2','','','.b-autocomplete'),(933829,'printshop','.order-summary .heading-2','padding-right','25','','','.order-summary'),(933830,'printshop','.b-compare .column_wrapper','padding-right','10','','','.b-compare'),(933831,'printshop','.b-email .totals-value','padding-right','10','','','.b-email'),(933832,'printshop','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(933833,'printshop','.b-email .model','padding-right','10','','','.b-email'),(933834,'printshop','.b-email .heading-name','padding-right','10','','','.b-email'),(933835,'printshop','.b-info .info li','padding-right','0','','','.b-info'),(933836,'printshop','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(933837,'printshop','.w-reviews-content .author','padding-right','20','','','.w-reviews-content'),(933838,'printshop','.w-login-block .returning','padding-right','40','','','.w-login-block'),(933839,'printshop','.b-data-table table.dataTable tbody td','padding-right','20','','','.b-data-table'),(933840,'printshop','.b-data-table table.dataTable thead td','padding-right','20','','','.b-data-table'),(933841,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-right','0','','','.w-contact-contacts'),(933842,'printshop','.b-table .table .headings td','padding-right','10','','','.b-table'),(933845,'printshop','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(933846,'printshop','.w-checkout-create-account .create-account','padding-right','0','','','.w-checkout-create-account'),(933847,'printshop','.b-info .info','padding-right','0','','','.b-info'),(933848,'printshop','.b-email .totals-title','padding-right','10','','','.b-email'),(933849,'printshop','.b-email .totals-value','padding-right','10','','','.b-email'),(933850,'printshop','.b-email .qty','padding-right','10','','','.b-email'),(933851,'printshop','.btn','padding-right','25','','',''),(933852,'printshop','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(933853,'printshop','.b-product-images .media-popup .mp-content','padding-right','5','','','.b-product-images'),(933854,'printshop','.b-product-images .media-popup .mp-small-images .item','padding-right','10','','','.b-product-images'),(933855,'printshop','.b-product-images .media-popup .slick-dots','padding-right','0','','','.b-product-images'),(933856,'printshop','.b-product-images .media-popup .slick-dots li','padding-right','0','','','.b-product-images'),(933857,'printshop','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-right','0','','','.b-menu-style'),(933858,'printshop','.b-personal-catalog-popup #personal_catalog_popup','padding-right','0','','','.b-personal-catalog-popup'),(933859,'printshop','.b-trade-approval .steps-bar li a','padding-right','0','','','.b-trade-approval'),(933860,'printshop','.b-trade-approval .middle-form','padding-right','0','','','.b-trade-approval'),(933861,'printshop','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-right','5','','','.b-trade-approval'),(933862,'printshop','.b-trade-approval .steps-bar','padding-right','0','','','.b-trade-approval'),(933863,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-right','10','','','.b-trade-approval'),(933864,'printshop','.b-trade-approval .center-buttons','padding-right','0','','','.b-trade-approval'),(933865,'printshop','.w-account-personal-catalog .list-switcher','padding-right','0','','','.w-account-personal-catalog'),(933866,'printshop','.w-account-personal-catalog .list-switcher a','padding-right','6','','','.w-account-personal-catalog'),(933867,'printshop','.w-account-subscription .subscription-variant','padding-right','10','','','.w-account-subscription'),(933868,'printshop','.w-catalog-additional-images li','padding-right','10','','','.w-catalog-additional-images'),(933869,'printshop','.w-catalog-additional-images ul','padding-right','0','','','.w-catalog-additional-images'),(933870,'printshop','.w-catalog-compare td','padding-right','20','','','.w-catalog-compare'),(933871,'printshop','.w-catalog-compare .image','padding-right','10','','','.w-catalog-compare'),(933872,'printshop','.w-catalog-compare .cross-box .different-all > div','padding-right','5','2','','.w-catalog-compare'),(933873,'printshop','.w-catalog-compare .cross-box .different-all > div','padding-right','5','','','.w-catalog-compare'),(933874,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-right','0','','','.w-catalog-compare'),(933875,'printshop','.w-delivery-day .left-count','padding-right','5','','','.w-delivery-day'),(933876,'printshop','.w-top-text .top-text','padding-right','10','','','.w-top-text'),(933877,'printshop','.w-cart-listing .points','padding-right','0','5333','','.w-cart-listing'),(933878,'printshop','.w-product-images .additional-horizontal .item','padding-right','10','','','.w-product-images'),(933879,'printshop','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-right','10','','','.b-cookie-notice'),(933880,'printshop','.lowestPricedBox .w-banner .single_banner','padding-right','15','','','.lowestPricedBox'),(933881,'printshop','.lowestPricedBox .w-banner .banner','padding-right','0','','','.lowestPricedBox'),(933882,'printshop','.tripleBanner > .block','padding-right','15','','','.tripleBanner'),(933883,'printshop','.shopByCollectionBox .w-banner .single_banner','padding-right','15','','','.shopByCollectionBox'),(933884,'printshop','.b-slick .slick-list','padding-right','0','','','.b-slick'),(933885,'printshop','.b-slick .slick-vertical button.slick-next','padding-right','0','3','','.b-slick'),(933886,'printshop','.b-slick .slick-vertical button.slick-prev','padding-right','0','3','','.b-slick'),(933887,'printshop','.b-slick button.slick-prev','padding-right','4','3','','.b-slick'),(933888,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','padding-right','0','','','.b-slick'),(933889,'printshop','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-right','15','','',''),(933890,'printshop','.w-cart-listing .headings .head','padding-right','0','','','.w-cart-listing'),(933891,'printshop','.w-cart-listing .item div.price','padding-right','0','','','.w-cart-listing'),(933892,'printshop','.b-products-listing .item-nav > div','padding-right','15','','','.b-products-listing'),(933893,'printshop','.LeftCategories .w-menu-simple ul','padding-right','0','','','.LeftCategories'),(933894,'printshop','.LeftCategories .w-menu-simple ul li a','padding-right','25','','','.LeftCategories'),(933895,'printshop','.w-filters .filter-widget','padding-right','25','','','.w-filters'),(933896,'printshop','.b-products-listing .products-listing.list-productlisting .item','padding-right','15','','','.b-products-listing'),(933897,'printshop','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-right','25','','','.b-products-listing'),(933898,'printshop','.b-products-listing .products-listing.list-rows .item-nav > div','padding-right','5','','','.b-products-listing'),(933899,'printshop','.w-breadcrumb .breadcrumb-li','padding-right','0','','','.w-breadcrumb'),(933900,'printshop','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(933901,'printshop','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(933902,'printshop','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(933903,'printshop','.w-subscribers .btn-submit','padding-right','25','','','.w-subscribers'),(933904,'printshop','.w-quote .buttons','padding-right','15','','','.w-quote'),(933905,'printshop','.w-quote .buttons .btn','padding-right','15','','','.w-quote'),(933906,'printshop','.w-quote .cart-content','padding-right','15','','','.w-quote'),(933907,'printshop','.w-quote .cart-total','padding-right','0','','','.w-quote'),(933908,'printshop','.w-quote .multicart .cart-content','padding-right','0','','','.w-quote'),(933909,'printshop','.w-quote .multicart .item','padding-right','15','','','.w-quote'),(933910,'printshop','.w-quote .multicart .name','padding-right','10','','','.w-quote'),(933911,'printshop','.w-quote .no-text','padding-right','20','','','.w-quote'),(933912,'printshop','.w-quote .qty','padding-right','5','4','','.w-quote'),(933913,'printshop','.w-quote a.item','padding-right','0','','','.w-quote'),(933914,'printshop','.w-product-images .additional-vertical .additional-images','padding-right','0','','','.w-product-images'),(933915,'printshop','.w-product-sale-ends .left-count','padding-right','5','','','.w-product-sale-ends'),(933916,'printshop','.w-product-sale-ends .left-count-days','padding-right','0','','','.w-product-sale-ends'),(933917,'printshop','.w-product-sale-ends .left-count-hours','padding-right','0','','','.w-product-sale-ends'),(933918,'printshop','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(933919,'printshop','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(933920,'printshop','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(933921,'printshop','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(933922,'printshop','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(933923,'printshop','.w-compare .compare-list-holder','padding-right','250','','','.w-compare'),(933924,'printshop','.w-compare .compare-list-buttons','padding-right','10','','','.w-compare'),(933925,'printshop','.w-compare .item-holder','padding-right','10','','','.w-compare'),(933926,'printshop','.w-compare .compare-list-products','padding-right','30','','','.w-compare'),(933927,'printshop','.w-files-catalog-widgets-files-catalog .name','padding-right','10','','','.w-files-catalog-widgets-files-catalog'),(933928,'printshop','.w-sample .buttons','padding-right','15','','','.w-sample'),(933929,'printshop','.w-sample .buttons .btn','padding-right','15','','','.w-sample'),(933930,'printshop','.w-sample .cart-box-link','padding-right','10','','','.w-sample'),(933931,'printshop','.w-sample .cart-content','padding-right','15','','','.w-sample'),(933932,'printshop','.w-sample .cart-total','padding-right','0','','','.w-sample'),(933933,'printshop','.w-sample .multicart .cart-content','padding-right','0','','','.w-sample'),(933934,'printshop','.w-sample .multicart .item','padding-right','15','','','.w-sample'),(933935,'printshop','.w-sample .multicart .name','padding-right','10','','','.w-sample'),(933936,'printshop','.w-sample .no-text','padding-right','20','','','.w-sample'),(933937,'printshop','.w-sample .qty','padding-right','5','4','','.w-sample'),(933938,'printshop','.w-sample a.item','padding-right','0','','','.w-sample'),(933939,'printshop','.w-cart-listing .item > div.points','padding-right','0','','','.w-cart-listing'),(933940,'printshop','.w-filters-simple .integrate-price-holder','padding-right','0','','','.w-filters-simple'),(933941,'printshop','.w-product-video .item','padding-right','10','','','.w-product-video'),(933942,'printshop','.shipping-ico .heading-3','padding-right','0','','','.shipping-ico'),(933943,'printshop','.w-cart-order-reference .btn','padding-right','25','','','.w-cart-order-reference'),(933944,'printshop','.w-cart-gift-certificate .btn','padding-right','25','','','.w-cart-gift-certificate'),(933945,'printshop','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(933946,'printshop','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(933947,'printshop','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(933948,'printshop','.w-product-in-bundles .attributes-item','padding-right','2','','','.w-product-in-bundles'),(933949,'printshop','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(933950,'printshop','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(933951,'printshop','.w-cart-listing .item > div.actions','padding-right','0','5333','','.w-cart-listing'),(933952,'printshop','.w-cart-listing .item div.price','padding-right','10','5342','','.w-cart-listing'),(933954,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-right','0','','','.b-products-listing'),(933955,'printshop','.b-pagination .pagination .next-pages','padding-right','5','','','.b-pagination'),(933956,'printshop','.b-pagination .pagination .page-number','padding-right','5','','','.b-pagination'),(933957,'printshop','.b-pagination .pagination .prev-pages','padding-right','5','','','.b-pagination'),(933958,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','padding-right','5','','','.b-pagination'),(933959,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','padding-right','5','','','.b-pagination'),(933960,'printshop','.b-pagination .pagination span','padding-right','5','2','','.b-pagination'),(933961,'printshop','.b-pagination ul.pagination','padding-right','0','','','.b-pagination'),(933962,'printshop','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','padding-right','10','','','.w-catalog-compare'),(933963,'printshop','.w-product-properties-filters-widgets-chosen-filters .item','padding-right','6','','','.w-product-properties-filters-widgets-chosen-filters'),(933964,'printshop','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block, .checkout > .type-1 > .block','padding-right','15','','',''),(933965,'printshop','.w-tabs .tab-li:last-of-type','padding-right','0','','','.w-tabs'),(933966,'printshop','.w-cart-listing .no-price .headings .qty','padding-right','10','','','.w-cart-listing'),(933967,'printshop','.p-quote-checkout-index .datepicker-inline','padding-right','0','','','.p-quote-checkout-index'),(933968,'printshop','.p-sample-checkout-index .datepicker-inline','padding-right','0','','','.p-sample-checkout-index'),(933971,'printshop','.w-quote-products .cart-listing .qty','padding-right','10','','','.w-quote-products'),(933972,'printshop','.w-product-multi-inventory .radio-attributes .option-item','padding-right','15','','','.w-product-multi-inventory'),(933973,'printshop','.w-product-multi-inventory .radio-attributes > label','padding-right','10','','','.w-product-multi-inventory'),(933974,'printshop','.w-account-personal-catalog .list-row-action ul','padding-right','20','','','.w-account-personal-catalog'),(933975,'printshop','.w-account-personal-catalog .list-row-action li','padding-right','10','','','.w-account-personal-catalog'),(933976,'printshop','.tripleBanner .w-html_box','padding-right','10','','','.tripleBanner'),(933977,'printshop','.w-account-personal-catalog .buy-box','padding-right','0','5333','','.w-account-personal-catalog'),(933978,'printshop','.b-products-listing .products-listing .radio-attributes .option','padding-right','15','','','.b-products-listing'),(933979,'printshop','.b-products-listing .products-listing .radio-attributes > label','padding-right','10','','','.b-products-listing'),(933980,'printshop','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(933981,'printshop','.w-product-collection .right-area .btn','padding-right','25','','','.w-product-collection'),(933982,'printshop','.w-product-attributes .radio-attributes .option-item','padding-right','15','','','.w-product-attributes'),(933983,'printshop','.w-product-attributes .radio-attributes > label','padding-right','10','','','.w-product-attributes'),(933984,'printshop','.w-product-properties .property-ul','padding-right','0','','','.w-product-properties'),(933985,'printshop','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(933986,'printshop','.w-product-properties li','padding-right','5','','','.w-product-properties'),(933987,'printshop','.w-product-groups .radioBox','padding-right','0','','','.w-product-groups'),(933988,'printshop','.w-product-groups .radioBox label','padding-right','15','','','.w-product-groups'),(933989,'printshop','.w-product-groups .radioBox label .containerBlock','padding-right','10','','','.w-product-groups'),(933990,'printshop','.w-product-groups .radioBox label','padding-right','0','5363','','.w-product-groups'),(933991,'printshop','.w-product-groups .radioBox label .containerBlock','padding-right','10','5363','','.w-product-groups'),(933992,'printshop','.b-products-listing .mix-attributes .attribute-qty-block','padding-right','10','','','.b-products-listing'),(933993,'printshop','.b-products-listing .products-listing .attribute-qty-block','padding-right','5','','','.b-products-listing'),(933994,'printshop','.blogsidebar','padding-right','0','5342','',''),(933995,'printshop','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(933996,'printshop','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-right','25','','','.w-product-custom-bundle'),(933997,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list'),(933998,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-right','10','','','.w-catalog-pages-category-pages-last-list'),(933999,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list-block'),(934000,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-right','10','','','.w-catalog-pages-category-pages-last-list-block'),(934001,'printshop','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(934002,'printshop','.w-delivery-location-location-description .deliveryDesc','padding-right','0','','','.w-delivery-location-location-description'),(934003,'printshop','.w-delivery-location-location-list .deliveryListParrent a','padding-right','25','','','.w-delivery-location-location-list'),(934004,'printshop','.w-delivery-location-location-list .deliveryList li a','padding-right','15','','','.w-delivery-location-location-list'),(934005,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding-right','2','','','.w-delivery-location-featured-list'),(934006,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding-right','0','5363','','.w-delivery-location-featured-list'),(934007,'printshop','.btn-2','padding-right','25','5333','',''),(934008,'printshop','.w-sale-category .holder-1','padding-right','20','','','.w-sale-category'),(934009,'printshop','.w-sale-category .holder-2','padding-right','20','','','.w-sale-category'),(934010,'printshop','.w-sale-category .left-count','padding-right','5','','','.w-sale-category'),(934011,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(934012,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-right','10','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(934013,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(934014,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-right','10','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(934015,'printshop','.w-product-properties-icons .property-image','padding-right','10','','','.w-product-properties-icons'),(934016,'printshop','.w-product-properties-icons .hover-box-content','padding-right','10','','','.w-product-properties-icons'),(934017,'printshop','.w-delivery-location-product-categories .item.category-link','padding-right','15','','','.w-delivery-location-product-categories'),(934018,'printshop','.w-delivery-location-product-categories .item.category-link','padding-right','10','5342','','.w-delivery-location-product-categories'),(934019,'printshop','.w-delivery-location-product-categories .item.category-link','padding-right','0','5363','','.w-delivery-location-product-categories'),(934020,'printshop','.w-delivery-location-product-categories .name','padding-right','15','','','.w-delivery-location-product-categories'),(934021,'printshop','.delivery-options-popup','padding-right','20','','',''),(934022,'printshop','.w-product-bonus-points .bonus-points-cost','padding-right','15','','','.w-product-bonus-points'),(934023,'printshop','.w-product-designer-designer .grnamebox .title-sortable','padding-right','15','','','.w-product-designer-designer'),(934024,'printshop','.w-product-designer-designer .prodDesignerType label','padding-right','10','','','.w-product-designer-designer'),(934025,'printshop','.w-press-reviews-widgets-press-reviews ','padding-right','30','','','.w-press-reviews-widgets-press-reviews'),(934026,'printshop','.w-press-reviews-widgets-press-reviews .author','padding-right','25','','','.w-press-reviews-widgets-press-reviews'),(934027,'printshop','.w-press-reviews-widgets-press-reviews .image','padding-right','10','','','.w-press-reviews-widgets-press-reviews'),(934028,'printshop','.w-press-reviews-widgets-press-reviews .item','padding-right','20','','','.w-press-reviews-widgets-press-reviews'),(934029,'printshop','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-right','30','','','.w-press-reviews-widgets-press-reviews'),(934030,'printshop','.w-press-reviews-widgets-press-reviews .review','padding-right','25','','','.w-press-reviews-widgets-press-reviews'),(934031,'printshop','.w-press-reviews-widgets-press-reviews ','padding-right','15','5333','','.w-press-reviews-widgets-press-reviews'),(934032,'printshop','.w-press-reviews-widgets-press-reviews .item','padding-right','0','5333','','.w-press-reviews-widgets-press-reviews'),(934033,'printshop','.w-press-reviews-widgets-press-reviews .review','padding-right','0','5333','','.w-press-reviews-widgets-press-reviews'),(934034,'printshop','.w-press-reviews-widgets-press-reviews-list .item','padding-right','25','','','.w-press-reviews-widgets-press-reviews-list'),(934035,'printshop','.w-press-reviews-widgets-press-reviews-list .short-description','padding-right','0','','','.w-press-reviews-widgets-press-reviews-list'),(934036,'printshop','.b-products-listing .productGroup label a','padding-right','16','','','.b-products-listing'),(934037,'printshop','.w-support-system-filter ','padding-right','40','','','.w-support-system-filter'),(934038,'printshop','.w-support-system-filter .filter_cats','padding-right','0','','','.w-support-system-filter'),(934039,'printshop','.w-support-system-listing .support-head','padding-right','13','','','.w-support-system-listing'),(934040,'printshop','.w-communication-post .btn.refresh','padding-right','0','','','.w-communication-post'),(934041,'printshop','.w-rma-returns-history .btn','padding-right','10','','','.w-rma-returns-history'),(934042,'printshop','.w-rma-returns-history .column','padding-right','3','','','.w-rma-returns-history'),(934043,'printshop','.w-rma-returns-history .column .title','padding-right','10','','','.w-rma-returns-history'),(934044,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','padding-right','5','','','.w-rma-returns-history'),(934045,'printshop','.w-rma-returns-history .topRow','padding-right','0','','','.w-rma-returns-history'),(934046,'printshop','.w-rma-returns-history .column:last-child .title','padding-right','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(934047,'printshop','.w-product-designer-designer .productDesignerBox ul','padding-right','0','','','.w-product-designer-designer'),(934048,'printshop','.w-product-configurator .pc-item','padding-right','0','','','.w-product-configurator'),(934049,'printshop','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(934050,'printshop','.w-product-configurator .pc_item','padding-right','0','5342','','.w-product-configurator'),(934051,'printshop','.w-product-configurator .pc_attr','padding-right','0','5333','','.w-product-configurator'),(934052,'printshop','.b-products-listing .products-listing .bonus-points-cost','padding-right','15','','','.b-products-listing'),(934053,'printshop','.b-products-listing .promos-info .promo-name-span','padding-right','40','','','.b-products-listing'),(934054,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-list'),(934055,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-right','10','','','.w-catalog-pages-category-pages-list'),(934056,'printshop','.w-predefined-promotion .heading','padding-right','10','','','.w-predefined-promotion'),(934057,'printshop','.w-predefined-promotion .master','padding-right','15','','','.w-predefined-promotion'),(934058,'printshop','.w-predefined-promotion .nextdiscount .content > div','padding-right','10','','','.w-predefined-promotion'),(934059,'printshop','.w-predefined-promotion .nextdiscount .item-holder .image','padding-right','10','','','.w-predefined-promotion'),(934060,'printshop','.w-predefined-promotion .nextdiscount .promo-for-each','padding-right','20','','','.w-predefined-promotion'),(934061,'printshop','.w-predefined-promotion .prom-multi-discount .promo-product','padding-right','20','','','.w-predefined-promotion'),(934062,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','padding-right','20','','','.w-predefined-promotion'),(934063,'printshop','.w-predefined-promotion .promo-cart-discount .master .item','padding-right','20','','','.w-predefined-promotion'),(934064,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-right','20','','','.w-predefined-promotion'),(934065,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-right','20','','','.w-predefined-promotion'),(934066,'printshop','.w-predefined-promotion .promo-cart-discount .slave .item','padding-right','20','','','.w-predefined-promotion'),(934067,'printshop','.w-predefined-promotion .promo-date > div','padding-right','50','','','.w-predefined-promotion'),(934068,'printshop','.w-predefined-promotion .promo-item','padding-right','40','','','.w-predefined-promotion'),(934069,'printshop','.w-predefined-promotion .promo-salemaker .discount','padding-right','20','','','.w-predefined-promotion'),(934070,'printshop','.w-predefined-promotion .promo-salemaker .item','padding-right','20','','','.w-predefined-promotion'),(934071,'printshop','.w-predefined-promotion .promo-salemaker .promo-categories','padding-right','12','','','.w-predefined-promotion'),(934072,'printshop','.w-supplier-purchase-supplier-products .item','padding-right','20','','','.w-supplier-purchase-supplier-products'),(934077,'printshop','.b-products-listing .products-listing .compare .checkbox input:not(checked) + span:before','padding-right','2','','','.b-products-listing'),(934078,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','padding-right','20','','','.w-filters'),(934079,'printshop','.b-quantity .qty-box input[type=\"text\"]','padding-right','3','','','.b-quantity'),(934080,'printshop','.w-product-model ','padding-right','10','','','.w-product-model'),(934081,'printshop','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(934082,'printshop','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(934083,'printshop','.lowestPricedBox .btn-2','padding-right','40','','','.lowestPricedBox'),(934084,'printshop','.doubleBanner .btn-2','padding-right','40','','','.doubleBanner'),(934085,'printshop','.doubleBanner .btn-2','padding-right','25','5347','','.doubleBanner'),(934086,'printshop','.middleBanner .btn-1','padding-right','30','','','.middleBanner'),(934087,'printshop','.bottomDoubleBanner .btn-2','padding-right','40','','','.bottomDoubleBanner'),(934088,'printshop','.bottomDoubleBanner .btn-2','padding-right','25','5347','','.bottomDoubleBanner'),(934089,'printshop','.bottomBanner .btn-1','padding-right','30','','','.bottomBanner'),(934090,'printshop','.bottomBanner .wrapper','padding-right','30','','','.bottomBanner'),(934091,'printshop','.bottomBanner .icon-box > div','padding-right','5','','','.bottomBanner'),(934092,'printshop','.bottomBanner .icon-box','padding-right','0','','','.bottomBanner'),(934093,'printshop','.topBanner > .block','padding-right','0','','','.topBanner'),(934096,'printshop','.middleBanner .btn-1','padding-right','15','5342','','.middleBanner'),(934097,'printshop','.middleBanner .btn-1','padding-right','15','5333','','.middleBanner'),(934098,'printshop','.bottomBanner .btn-1','padding-right','30','5347','','.bottomBanner'),(934099,'printshop','.bottomBanner .icon-box','padding-right','0','5347','','.bottomBanner'),(934100,'printshop','.bottomBanner .icon-box > div','padding-right','2','5347','','.bottomBanner'),(934101,'printshop','.w-cart-listing .points-earn','padding-right','10','5342','','.w-cart-listing'),(934102,'printshop','.w-multi-cart-save-cart .btn','padding-right','14','5363','','.w-multi-cart-save-cart'),(934103,'printshop','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-right','0','','','.b-products-listing'),(934104,'printshop','.b-products-listing .products-listing.list-productlisting .item','padding-right','0','5363','','.b-products-listing'),(934105,'printshop','.w-filters .filter-widget','padding-right','15','5342','','.w-filters'),(934106,'printshop','.w-product-multi-inventory .radio-attributes > label','padding-right','0','5363','','.w-product-multi-inventory'),(934107,'printshop','.w-product-attributes .radio-attributes > label','padding-right','0','5363','','.w-product-attributes'),(934108,'printshop','.w-tabs > .block','padding-right','10','5363','','.w-tabs'),(934109,'printshop','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-right','15','5363','','.b-products-listing'),(934110,'printshop','.w-account-personal-catalog .buy-box','padding-right','15','5363','','.w-account-personal-catalog'),(934111,'printshop','.b-bottom .confirm-popup .buttons','padding-right','20','','','.b-bottom'),(934112,'printshop','.trade_form > .type-1 > .block','padding-right','15','','',''),(934113,'printshop','.p-payer-order-pay .price-row','padding-right','0','','','.p-payer-order-pay'),(934114,'printshop','.p-payer-order-pay .payer > .type-1 > .block','padding-right','15','','','.p-payer-order-pay'),(934115,'printshop','.p-payer-order-confirmation .payer > .type-1 > .block','padding-right','15','','','.p-payer-order-confirmation'),(934116,'printshop','.p-payer-order-confirmation .price-row','padding-right','0','','','.p-payer-order-confirmation'),(934117,'printshop','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','padding-right','25','','','.w-product-buttons'),(934118,'printshop','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','padding-right','25','5363','','.w-product-buttons'),(934119,'printshop','.w-compare .compare-list-holder','padding-right','0','5342','','.w-compare'),(934120,'printshop','.topBanner .content .btn','padding-right','1.875','','','.topBanner'),(934121,'printshop','.topBanner .ourPick .bottom','padding-right','5','','','.topBanner'),(934122,'printshop','.topBanner .ourPick .top','padding-right','15','','','.topBanner'),(934123,'printshop','.topBanner .content .btn','padding-right','30','5410','','.topBanner'),(934124,'printshop','.topBanner .content .btn','padding-right','15','5342','','.topBanner'),(934125,'printshop','.topBanner .ourPick .top','padding-right','10','5342','','.topBanner'),(934126,'printshop','.topBanner .content','padding-right','10','5333','','.topBanner'),(934127,'printshop','.topBanner .content .btn','padding-right','10','5363','','.topBanner'),(934128,'printshop','.bottomBanner .btn-1','padding-right','10','5363','','.bottomBanner'),(934129,'printshop','.bottomBanner .wrapper','padding-right','15','5363','','.bottomBanner'),(934130,'printshop','.middleBanner .btn-1','padding-right','7','5363','','.middleBanner'),(934131,'printshop','.w-promotions-widgets-promotion-icons-desc .w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','padding-right','0','','','.w-promotions-widgets-promotion-icons-desc'),(934132,'printshop','.order-summary ','padding-right','25','','','.order-summary'),(934133,'printshop','.order-summary .w-cart-listing .item > div ~ div','padding-right','0','','','.order-summary'),(934134,'printshop','.order-summary ','padding-right','15','5333','','.order-summary'),(934135,'printshop','.w-cart-discount-coupon .discount-box','padding-right','10','','','.w-cart-discount-coupon'),(934136,'printshop','.p-quote-checkout-index .closeable-heading','padding-right','25','','','.p-quote-checkout-index'),(934137,'printshop','.p-quote-checkout-index .edit-address-popup','padding-right','20','','','.p-quote-checkout-index'),(934138,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','padding-right','15','','','.p-quote-checkout-index'),(934139,'printshop','.w-quote-products ','padding-right','10','','','.w-quote-products'),(934143,'printshop','.account-address-book .address_book','padding-right','0','','','.account-address-book'),(934144,'printshop','.account-address-book .address_book h1','padding-right','0','','','.account-address-book'),(934145,'printshop','.account-address-book .address_book h2','padding-right','10','','','.account-address-book'),(934146,'printshop','.account-address-book .address_book, .account-address-book .account_history_info','padding-right','0','','','.account-address-book'),(934147,'printshop','.account-address-book .buttonBox','padding-right','0','','','.account-address-book'),(934148,'printshop','.account-address-book .rightMes ul','padding-right','0','','','.account-address-book'),(934149,'printshop','.account-address-book .topButtons','padding-right','0','','','.account-address-book'),(934184,'printshop','.account-order-pay .contentColumn','padding-right','10','','','.account-order-pay'),(934185,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-right','0','','','.account-order-pay'),(934186,'printshop','.account-order-pay .history_attr div strong, .account-order-pay .history_attr div span','padding-right','10','','','.account-order-pay'),(934187,'printshop','.account-order-pay .history_info > div + div','padding-right','0','','','.account-order-pay'),(934188,'printshop','.account-order-pay .history_info > div','padding-right','0','5342','','.account-order-pay'),(934189,'printshop','.account-order-pay .history_info > div + div','padding-right','0','5342','','.account-order-pay'),(934190,'printshop','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-right','10','','','.account-samples'),(934191,'printshop','.account-samples .orders-table th','padding-right','10','','','.account-samples'),(934192,'printshop','.account-samples .order_history_table th','padding-right','10','','','.account-samples'),(934193,'printshop','.account-samples .view_link','padding-right','20','','','.account-samples'),(934194,'printshop','.account-samples .orders-table .td-alignright','padding-right','10','5342','','.account-samples'),(934195,'printshop','.account-samples .orders-table td','padding-right','10','5342','','.account-samples'),(934196,'printshop','.account-sample-info .contentColumn','padding-right','10','','','.account-sample-info'),(934197,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-right','0','','','.account-sample-info'),(934198,'printshop','.account-sample-info .history_attr div strong, .account-sample-info .history_attr div span','padding-right','10','','','.account-sample-info'),(934199,'printshop','.account-sample-info .history_info > div + div','padding-right','0','','','.account-sample-info'),(934200,'printshop','.account-sample-info .popup-tracking-number','padding-right','10','','','.account-sample-info'),(934201,'printshop','.account-sample-info .history_info > div','padding-right','0','5342','','.account-sample-info'),(934202,'printshop','.account-sample-info .history_info > div + div','padding-right','0','5342','','.account-sample-info'),(934203,'printshop','.catalog-product-wrap .next-product','padding-right','50','','','.catalog-product-wrap'),(934204,'printshop','.catalog-product-wrap .pn-direction','padding-right','4','','','.catalog-product-wrap'),(934205,'printshop','.catalog-product-wrap .pn-image','padding-right','5','','','.catalog-product-wrap'),(934206,'printshop','.catalog-product-wrap .prev-product','padding-right','20','','','.catalog-product-wrap'),(934207,'printshop','.catalog-product-wrap .prev-product .pn-image','padding-right','2','3','','.catalog-product-wrap'),(934208,'printshop','.catalog-product-wrap .next-product','padding-right','0','5342','','.catalog-product-wrap'),(934209,'printshop','.catalog-product-wrap .pn-direction','padding-right','0','5342','','.catalog-product-wrap'),(934210,'printshop','.catalog-product-wrap .prev-product','padding-right','0','5342','','.catalog-product-wrap'),(934211,'printshop','.shopping-cart-index .btn-3','padding-right','25','','','.shopping-cart-index'),(934212,'printshop','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-right','20','','','.shopping-cart-index'),(934213,'printshop','.checkout-index-wrap .closeable-heading','padding-right','25','','','.checkout-index-wrap'),(934214,'printshop','.checkout-index-wrap .datepicker-inline','padding-right','0','','','.checkout-index-wrap'),(934215,'printshop','.checkout-index-wrap .edit-address-popup','padding-right','20','','','.checkout-index-wrap'),(934216,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-right','15','','','.checkout-index-wrap'),(934217,'printshop','.checkout-index-wrap .hiding-box .checkout-cart-listing','padding-right','30','','','.checkout-index-wrap'),(934218,'printshop','.checkout-order-confirmation .price-row','padding-right','0','','','.checkout-order-confirmation'),(934219,'printshop','.b-bottom .pop-up-content','padding-right','20','','','.b-bottom'),(934220,'printshop','.b-form .columns .col-2','padding-right','5','','','.b-form'),(934221,'printshop','.b-slick .slick-dots li','padding-right','5','','','.b-slick'),(934222,'printshop','.success-page .check-ico-block','padding-right','0','','','.success-page'),(934223,'printshop','.success-page .order-summary2 .btn-2','padding-right','50','','','.success-page'),(934224,'printshop','.success-page .order_totals .price-row','padding-right','0','','','.success-page'),(934225,'printshop','.success-page .price-row','padding-right','0','','','.success-page'),(934226,'printshop','.success-page .w-cart-listing .price','padding-right','0','','','.success-page'),(934227,'printshop','.success-page .w-cart-listing .qty','padding-right','0','','','.success-page'),(934228,'printshop','.b-multi-page-checkout .multi-page-checkout .buttons','padding-right','0','','','.b-multi-page-checkout'),(934229,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-right','10','','','.b-multi-page-checkout'),(934230,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-right','10','','','.b-multi-page-checkout'),(934231,'printshop','.tripleLine .banner-text','padding-right','0','','','.tripleLine'),(934232,'printshop','.doubleBanner .w-banner .banner-holder','padding-right','0','','','.doubleBanner'),(934233,'printshop','.doubleBanner .w-banner .banner-item','padding-right','15','','','.doubleBanner'),(934234,'printshop','.doubleBanner .w-banner .banner-text','padding-right','0','','','.doubleBanner'),(934235,'printshop','.middleBanner .banner-text-holder','padding-right','10','5363','','.middleBanner'),(934236,'printshop','.middleBanner div.banner-text-holder','padding-right','30','','','.middleBanner'),(934237,'printshop','.middleBanner div.banner-text','padding-right','0','','','.middleBanner'),(934238,'printshop','.bottomBanner .w-banner .banner-text','padding-right','0','','','.bottomBanner'),(934239,'printshop','.bottomDoubleBanner .w-banner .banner-holder','padding-right','0','','','.bottomDoubleBanner'),(934240,'printshop','.bottomDoubleBanner .w-banner .banner-text-holder','padding-right','30','','','.bottomDoubleBanner'),(934241,'printshop','.bottomDoubleBanner .w-banner .banner-text','padding-right','0','','','.bottomDoubleBanner'),(934242,'printshop','.bottomDoubleBanner .w-banner .banner-holder','padding-right','0','5363','','.bottomDoubleBanner'),(934243,'printshop','.bottomDoubleBanner .w-banner .banner-item','padding-right','15','','','.bottomDoubleBanner'),(934244,'printshop','.b-form .addresses .address-item','padding-right','20','','','.b-form'),(934250,'printshop','.footer-menu .level-1 > li > .no-link','padding-right','0','5342','','.footer-menu'),(934251,'printshop','.w-bestsellers .heading-3','padding-right','0','','','.w-bestsellers'),(934252,'printshop','.w-banner .banner-text','padding-right','20','','','.w-banner'),(934253,'printshop','.w-banner .carousel-text > span','padding-right','20','','','.w-banner'),(934254,'printshop','.w-catalog-paging ','padding-right','5','2','','.w-catalog-paging'),(934255,'printshop','.w-catalog-paging .next','padding-right','5','','','.w-catalog-paging'),(934256,'printshop','.w-catalog-paging .next-pages','padding-right','5','','','.w-catalog-paging'),(934257,'printshop','.w-catalog-paging .page-number','padding-right','5','','','.w-catalog-paging'),(934258,'printshop','.w-catalog-paging .paging-item','padding-right','2','','','.w-catalog-paging'),(934259,'printshop','.w-catalog-paging .prev','padding-right','5','','','.w-catalog-paging'),(934260,'printshop','.w-catalog-paging .prev-pages','padding-right','5','','','.w-catalog-paging'),(934264,'printshop','.w-sale .holder-1','padding-right','20','','','.w-sale'),(934265,'printshop','.w-sale .holder-2','padding-right','20','','','.w-sale'),(934266,'printshop','.w-sale .left-count','padding-right','5','','','.w-sale'),(934267,'printshop','.w-social-links a','padding-right','8','','','.w-social-links'),(934268,'printshop','.b-data-table table.dataTable tbody td','padding-right_important','important','','','.b-data-table'),(934269,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right_important','important','','','.b-data-table'),(934270,'printshop','.b-data-table table.dataTable thead td','padding-right_important','important','','','.b-data-table'),(934271,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right_important','important','','','.b-data-table'),(934272,'printshop','.w-cart-listing .points','padding-right_important','important','5333','','.w-cart-listing'),(934273,'printshop','.w-account-personal-catalog .buy-box','padding-right_important','important','5333','','.w-account-personal-catalog'),(934274,'printshop','.topBanner > .block','padding-right_important','important','','','.topBanner'),(934275,'printshop','.w-account-personal-catalog .buy-box','padding-right_important','important','5363','','.w-account-personal-catalog'),(934276,'printshop','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-top','10','','','.w-communication-new-topic'),(934277,'printshop','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(934278,'printshop','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(934279,'printshop','.heading-4 .edit, h4 .edit','padding-top','2','','',''),(934280,'printshop','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(934281,'printshop','.b-info .info','padding-top','20','','','.b-info'),(934282,'printshop','.b-form .password-forgotten-link','padding-top','15','','','.b-form'),(934283,'printshop','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(934286,'printshop','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(934287,'printshop','.b-email .totals-title','padding-top','5','','','.b-email'),(934288,'printshop','.p-quick-order-index ul.token-input-list','padding-top','0','','','.p-quick-order-index'),(934289,'printshop','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-top','7','','','.p-quick-order-index'),(934290,'printshop','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-top','8','','','.p-quick-order-index'),(934291,'printshop','.w-promotions .promo-item','padding-top','30','','','.w-promotions'),(934292,'printshop','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(934293,'printshop','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(934294,'printshop','.w-cart-compare .attributes-label','padding-top','10','','','.w-cart-compare'),(934301,'printshop','.w-personal-gift-status-bar .end-label','padding-top','0','','','.w-personal-gift-status-bar'),(934302,'printshop','.p-sample-checkout-success .page-success .text-1','padding-top','120','','','.p-sample-checkout-success'),(934303,'printshop','.w-personal-gift-status-bar .start-label','padding-top','0','','','.w-personal-gift-status-bar'),(934304,'printshop','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(934305,'printshop','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(934306,'printshop','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(934307,'printshop','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(934308,'printshop','.b-email .heading-image','padding-top','5','','','.b-email'),(934309,'printshop','.w-product-images-additional .images','padding-top','10','5363','','.w-product-images-additional'),(934310,'printshop','.testimonials .reviews-list .name','padding-top','5','','',''),(934311,'printshop','.testimonials .heading-3','padding-top','7','','',''),(934312,'printshop','.testimonials .review','padding-top','10','','',''),(934313,'printshop','.testimonials .name','padding-top','5','','',''),(934314,'printshop','.testimonials .reviews-list .answer .name','padding-top','10','','',''),(934315,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(934316,'printshop','.w-categories .image','padding-top','0','','','.w-categories'),(934317,'printshop','.w-promotions .prom-multi-discount .promo-range','padding-top','0','','','.w-promotions'),(934318,'printshop','.w-promotions .prom-multi-discount .promo-product','padding-top','20','','','.w-promotions'),(934319,'printshop','.w-catalog-items-on-page .before, .w-catalog-items-on-page .after','padding-top','5','','','.w-catalog-items-on-page'),(934320,'printshop','.w-promotions .nextdiscount .content > div','padding-top','10','','','.w-promotions'),(934321,'printshop','.w-promotions .nextdiscount .promo-for-each','padding-top','3','','','.w-promotions'),(934322,'printshop','.w-promotions .promo-salemaker .item','padding-top','20','','','.w-promotions'),(934323,'printshop','.w-promotions .promo-salemaker .discount','padding-top','0','','','.w-promotions'),(934324,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.p-quick-order-index'),(934325,'printshop','.w-promotions .promo-cart-discount .slave .item','padding-top','20','','','.w-promotions'),(934326,'printshop','.w-promotions .promo-cart-discount .slave .condition-holder','padding-top','0','','','.w-promotions'),(934327,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','padding-top','0','','','.w-promotions'),(934328,'printshop','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-top','20','','','.b-warehouses-popup'),(934329,'printshop','.w-product-available-in-warehouses .warehouse-item','padding-top','0','','','.w-product-available-in-warehouses'),(934331,'printshop','.w-cart-give-away .ga_column','padding-top','15','','','.w-cart-give-away'),(934332,'printshop','.w-cart-compare .attributes-cell','padding-top','8','','','.w-cart-compare'),(934333,'printshop','.p-quick-order-index .bottom','padding-top','10','','','.p-quick-order-index'),(934334,'printshop','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(934335,'printshop','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(934336,'printshop','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(934337,'printshop','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(934338,'printshop','.b-messages .messages-menu ul','padding-top','0','','','.b-messages'),(934339,'printshop','.b-messages .messages-menu li','padding-top','0','','','.b-messages'),(934340,'printshop','.b-messages .messMenuButton span','padding-top','10','','','.b-messages'),(934341,'printshop','.b-messages .msv_btn','padding-top','12','','','.b-messages'),(934342,'printshop','.b-messages .msv_content','padding-top','10','','','.b-messages'),(934343,'printshop','.b-messages .msv_history','padding-top','10','','','.b-messages'),(934344,'printshop','.b-messages .messages-menu li a','padding-top','10','','','.b-messages'),(934345,'printshop','.b-messages .email-heading','padding-top','15','','','.b-messages'),(934346,'printshop','.b-messages .content_management_attach button','padding-top','1','','','.b-messages'),(934347,'printshop','.b-messages .content_management_attach','padding-top','8','','','.b-messages'),(934348,'printshop','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(934349,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','padding-top','4','','','.b-messages'),(934350,'printshop','.b-messages .emailBtn','padding-top','10','','','.b-messages'),(934351,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-top','5','','','.b-messages'),(934352,'printshop','.b-messages .msv_to_cc','padding-top','10','','','.b-messages'),(934353,'printshop','.b-messages .messMenuButtonTop','padding-top','5','','','.b-messages'),(934354,'printshop','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-top','4','','',''),(934355,'printshop','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(934356,'printshop','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(934357,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(934358,'printshop','.w-sitemap-delivery-location > ul > li > ul','padding-top','0','','','.w-sitemap-delivery-location'),(934359,'printshop','.w-sitemap-delivery-location > ul','padding-top','0','','','.w-sitemap-delivery-location'),(934360,'printshop','.w-checkout-terms .required-message','padding-top','5','','','.w-checkout-terms'),(934361,'printshop','.w-cart-listing .item .remove','padding-top','5','5342','','.w-cart-listing'),(934362,'printshop','.b-table .table td','padding-top','15','','','.b-table'),(934363,'printshop','.b-table .table .headings td','padding-top','5','','','.b-table'),(934364,'printshop','.b-email .heading-image','padding-top','5','','','.b-email'),(934365,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(934366,'printshop','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(934367,'printshop','.w-reviews-content .item','padding-top','20','','','.w-reviews-content'),(934369,'printshop','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(934370,'printshop','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(934371,'printshop','.b-email .heading-name','padding-top','5','','','.b-email'),(934372,'printshop','.b-email .heading-price','padding-top','5','','','.b-email'),(934373,'printshop','.b-email .heading-model','padding-top','5','','','.b-email'),(934374,'printshop','.p-quick-order-index .all-scroll-div','padding-top','10','','','.p-quick-order-index'),(934375,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-template','padding-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(934376,'printshop','.b-email .name','padding-top','5','','','.b-email'),(934377,'printshop','.b-email .qty','padding-top','5','','','.b-email'),(934378,'printshop','.b-email .heading-qty','padding-top','5','','','.b-email'),(934379,'printshop','.b-email .heading-model','padding-top','5','','','.b-email'),(934380,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(934381,'printshop','.w-filters .filter-ul-content','padding-top','0','','','.w-filters'),(934382,'printshop','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(934383,'printshop','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(934384,'printshop','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-top','2','','','.w-menu-horizontal'),(934385,'printshop','.w-menu-horizontal ul','padding-top','0','','','.w-menu-horizontal'),(934386,'printshop','.w-tabs .tab-navigation','padding-top','0','','','.w-tabs'),(934387,'printshop','.w-promo-code .holder','padding-top','20','5363','','.w-promo-code'),(934388,'printshop','.b-info .info ul','padding-top','0','','','.b-info'),(934389,'printshop','.w-promo-code .holder','padding-top','20','5363','','.w-promo-code'),(934390,'printshop','.w-product-images-additional .images','padding-top','10','5363','','.w-product-images-additional'),(934391,'printshop','.p-quote-checkout-success .page-success .text-1','padding-top','5','5333','','.p-quote-checkout-success'),(934392,'printshop','.b-fancybox .fancybox-title-over-wrap','padding-top','10','','','.b-fancybox'),(934393,'printshop','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(934394,'printshop','.b-fancybox .fancybox-title-inside-wrap','padding-top','10','','','.b-fancybox'),(934395,'printshop','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(934396,'printshop','.b-info .info ul','padding-top','0','','','.b-info'),(934397,'printshop','.w-multi-cart-cart-switcher .carts-switcher','padding-top','20','','','.w-multi-cart-cart-switcher'),(934398,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(934399,'printshop','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(934400,'printshop','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(934401,'printshop','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(934402,'printshop','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-top','0','','','.b-fancybox'),(934403,'printshop','.w-cart-compare .dropdown li','padding-top','5','','','.w-cart-compare'),(934404,'printshop','.no-found','padding-top','20','','',''),(934406,'printshop','.b-upload-files .attached-block','padding-top','10','','','.b-upload-files'),(934408,'printshop','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(934409,'printshop','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(934410,'printshop','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(934411,'printshop','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(934413,'printshop','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(934414,'printshop','.message.success','padding-top','20','','',''),(934415,'printshop','.w-cart-compare .dropdown .dropdown-menu','padding-top','5','','','.w-cart-compare'),(934416,'printshop','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(934417,'printshop','.b-email .heading-qty','padding-top','5','','','.b-email'),(934418,'printshop','.b-email .model','padding-top','5','','','.b-email'),(934419,'printshop','.b-email .totals-title','padding-top','5','','','.b-email'),(934420,'printshop','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(934421,'printshop','.b-info .info','padding-top','20','','','.b-info'),(934422,'printshop','.b-info .info li','padding-top','0','','','.b-info'),(934423,'printshop','.b-info .info li','padding-top','0','','','.b-info'),(934424,'printshop','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(934425,'printshop','.b-email .totals-value','padding-top','5','','','.b-email'),(934426,'printshop','.b-email .heading-name','padding-top','5','','','.b-email'),(934427,'printshop','.b-email .name','padding-top','5','','','.b-email'),(934428,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-top','0','','','.b-select-suggest'),(934429,'printshop','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(934430,'printshop','.w-reviews .review','padding-top','10','','','.w-reviews'),(934431,'printshop','.w-socials > li','padding-top','15','','','.w-socials'),(934434,'printshop','.w-cart-compare .product','padding-top','10','','','.w-cart-compare'),(934435,'printshop','.b-info-popup .info-popup div','padding-top','10','','','.b-info-popup'),(934437,'printshop','.w-quote .cart-box-link','padding-top','0','','','.w-quote'),(934438,'printshop','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-top','7','','','.order-summary'),(934439,'printshop','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(934440,'printshop','.w-reviews .author','padding-top','0','','','.w-reviews'),(934441,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(934442,'printshop','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(934443,'printshop','.b-email .heading-model','padding-top','5','','','.b-email'),(934444,'printshop','.b-email .model','padding-top','5','','','.b-email'),(934445,'printshop','textarea','padding-top','5','','',''),(934446,'printshop','.p-quote-checkout-success .page-success .text-1','padding-top','5','5333','','.p-quote-checkout-success'),(934447,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(934448,'printshop','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-top','3','','','.w-multi-cart-actions'),(934449,'printshop','.w-top-categories h2.name','padding-top','3','','','.w-top-categories'),(934450,'printshop','.w-top-categories .item','padding-top','5','','','.w-top-categories'),(934451,'printshop','.w-tabs .accordion-heading','padding-top','9','5333','','.w-tabs'),(934452,'printshop','.w-tabs > .block','padding-top','20','','','.w-tabs'),(934453,'printshop','.w-cart-cart-tabs .w-tabs > .block','padding-top','0','','','.w-cart-cart-tabs'),(934454,'printshop','.w-tabs .tab-a','padding-top','14','','','.w-tabs'),(934455,'printshop','.w-tabs .tab-a','padding-top','12','2','','.w-tabs'),(934456,'printshop','.w-socials > li','padding-top','15','','','.w-socials'),(934457,'printshop','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(934458,'printshop','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(934459,'printshop','.b-bottom .popup-buttons','padding-top','15','','','.b-bottom'),(934460,'printshop','.b-autocomplete .ui-autocomplete li','padding-top','3','','','.b-autocomplete'),(934461,'printshop','.b-bottom .popup-content','padding-top','15','','','.b-bottom'),(934462,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(934463,'printshop','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(934464,'printshop','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(934465,'printshop','.btn-1','padding-top','6','','',''),(934466,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(934467,'printshop','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(934468,'printshop','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(934469,'printshop','.p-sample-checkout-success .page-success .text-1','padding-top','5','5333','','.p-sample-checkout-success'),(934470,'printshop','.b-info .info ul','padding-top','0','','','.b-info'),(934471,'printshop','.b-messages .emailLineTextArea textarea','padding-top','30','','','.b-messages'),(934472,'printshop','.btn-3','padding-top','6','','',''),(934473,'printshop','.b-bottom .confirm-popup .confirm-text','padding-top','40','','','.b-bottom'),(934474,'printshop','.w-product-images-additional .images','padding-top','10','5363','','.w-product-images-additional'),(934475,'printshop','.b-products-listing .products-listing .buyButton .btn','padding-top','5','','','.b-products-listing'),(934476,'printshop','.heading-3 .right-text, h3 .right-text','padding-top','3','','',''),(934477,'printshop','.b-bottom .popup-heading','padding-top','10','','','.b-bottom'),(934478,'printshop','.b-form .shipping-method .item + .item','padding-top','5','','','.b-form'),(934479,'printshop','.heading-3 .edit, h3 .edit','padding-top','2','','',''),(934480,'printshop','.b-info .info li','padding-top','0','','','.b-info'),(934481,'printshop','.b-email .model','padding-top','5','','','.b-email'),(934482,'printshop','.b-upload-file .upload-file-template','padding-top','25','','','.b-upload-file'),(934483,'printshop','.p-quote-checkout-success .page-success .text-1','padding-top','5','5333','','.p-quote-checkout-success'),(934484,'printshop','.b-form .middle-form','padding-top','20','','','.b-form'),(934485,'printshop','.b-email .qty','padding-top','5','','','.b-email'),(934486,'printshop','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(934487,'printshop','.b-email .heading-price','padding-top','5','','','.b-email'),(934488,'printshop','.w-socials > li','padding-top','15','','','.w-socials'),(934489,'printshop','.order-summary .price-row','padding-top','7','','','.order-summary'),(934490,'printshop','.b-email .model','padding-top','5','','','.b-email'),(934491,'printshop','.b-email .image','padding-top','5','','','.b-email'),(934492,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(934493,'printshop','.b-select-suggest .select2-drop-mask','padding-top','0','','','.b-select-suggest'),(934495,'printshop','.w-reviews-content .review','padding-top','20','','','.w-reviews-content'),(934496,'printshop','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(934497,'printshop','.b-email .price','padding-top','5','','','.b-email'),(934498,'printshop','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(934499,'printshop','.b-fancybox .fancybox-title-float-wrap .child','padding-top','2','','','.b-fancybox'),(934500,'printshop','.w-checkout-shipping-choice span','padding-top','7','5363','','.w-checkout-shipping-choice'),(934501,'printshop','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(934502,'printshop','.w-top-categories .categories h2','padding-top','0','','','.w-top-categories'),(934503,'printshop','.w-top-categories .image','padding-top','0','','','.w-top-categories'),(934504,'printshop','.w-product-reviews .reviews-list .review','padding-top','10','','','.w-product-reviews'),(934505,'printshop','.w-product-reviews .reviews-list .name','padding-top','5','','','.w-product-reviews'),(934506,'printshop','.b-email .heading-qty','padding-top','5','','','.b-email'),(934507,'printshop','.b-email .name','padding-top','5','','','.b-email'),(934508,'printshop','.b-form .required-message','padding-top','0','','','.b-form'),(934509,'printshop','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(934510,'printshop','.p-quote-checkout-success .page-success .text-1','padding-top','5','5333','','.p-quote-checkout-success'),(934511,'printshop','.w-promo-code .holder','padding-top','20','5363','','.w-promo-code'),(934512,'printshop','.b-bottom .popup-simple','padding-top','20','','','.b-bottom'),(934513,'printshop','.b-bottom .rfq-form','padding-top','0','','','.b-bottom'),(934514,'printshop','.b-email .heading-model','padding-top','5','','','.b-email'),(934515,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(934516,'printshop','.b-email .price','padding-top','5','','','.b-email'),(934517,'printshop','.b-email .heading-name','padding-top','5','','','.b-email'),(934518,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(934519,'printshop','.b-email .model','padding-top','5','','','.b-email'),(934520,'printshop','.b-email .heading-price','padding-top','5','','','.b-email'),(934521,'printshop','.b-email .heading-qty','padding-top','5','','','.b-email'),(934522,'printshop','.b-email .heading-model','padding-top','5','','','.b-email'),(934523,'printshop','.b-email .qty','padding-top','5','','','.b-email'),(934524,'printshop','.b-email .totals-value','padding-top','5','','','.b-email'),(934525,'printshop','.b-email .totals-title','padding-top','5','','','.b-email'),(934526,'printshop','.b-email .image','padding-top','5','','','.b-email'),(934527,'printshop','.b-email .price','padding-top','5','','','.b-email'),(934528,'printshop','.b-email .qty','padding-top','5','','','.b-email'),(934529,'printshop','.b-email .name','padding-top','5','','','.b-email'),(934530,'printshop','.b-email .heading-image','padding-top','5','','','.b-email'),(934531,'printshop','.b-email .heading-name','padding-top','5','','','.b-email'),(934532,'printshop','.w-checkout-shipping .sub-item','padding-top','5','','','.w-checkout-shipping'),(934533,'printshop','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(934534,'printshop','.b-table .table .headings td','padding-top','5','','','.b-table'),(934535,'printshop','.b-table .table td','padding-top','15','','','.b-table'),(934536,'printshop','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(934537,'printshop','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(934538,'printshop','.w-promo-code .holder','padding-top','20','5363','','.w-promo-code'),(934539,'printshop','.w-socials > li','padding-top','15','','','.w-socials'),(934540,'printshop','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(934541,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(934542,'printshop','.b-form .center-buttons','padding-top','20','','','.b-form'),(934543,'printshop','.b-form .shipping-method .input','padding-top','0','','','.b-form'),(934544,'printshop','.w-reviews .heading-3','padding-top','7','','','.w-reviews'),(934545,'printshop','.w-checkout-shipping-address .edit-ab','padding-top','5','','','.w-checkout-shipping-address'),(934546,'printshop','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(934547,'printshop','.b-select-suggest .select2-container .select2-choice','padding-top','0','','','.b-select-suggest'),(934548,'printshop','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(934549,'printshop','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(934550,'printshop','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(934551,'printshop','.b-info .info','padding-top','20','','','.b-info'),(934552,'printshop','.b-info .info li','padding-top','0','','','.b-info'),(934553,'printshop','.b-bottom .terms-info-popup .pop-up-content','padding-top','20','','','.b-bottom'),(934554,'printshop','.w-checkout-create-account .create-account-switcher','padding-top','8','','','.w-checkout-create-account'),(934555,'printshop','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','12','5342','','.w-menu-horizontal'),(934556,'printshop','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(934557,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(934558,'printshop','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(934559,'printshop','.w-product-images-additional .images','padding-top','10','5363','','.w-product-images-additional'),(934560,'printshop','.b-info .info ul','padding-top','0','','','.b-info'),(934561,'printshop','.b-form .login-col-1','padding-top','40','','','.b-form'),(934562,'printshop','.b-form .form-buttons','padding-top','17','','','.b-form'),(934563,'printshop','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(934564,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(934565,'printshop','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(934567,'printshop','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(934568,'printshop','.w-cart-compare .delete-cart','padding-top','10','','','.w-cart-compare'),(934569,'printshop','.w-catalog-listing-look .listing-look-title','padding-top','4','','','.w-catalog-listing-look'),(934570,'printshop','.b-table .table td','padding-top','15','','','.b-table'),(934571,'printshop','.b-email .heading-price','padding-top','5','','','.b-email'),(934572,'printshop','.b-email .image','padding-top','5','','','.b-email'),(934573,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(934574,'printshop','.b-email .price','padding-top','5','','','.b-email'),(934575,'printshop','.w-product-images-additional .images','padding-top','10','5363','','.w-product-images-additional'),(934576,'printshop','.b-bottom .cart-options .heading-4','padding-top','10','','','.b-bottom'),(934577,'printshop','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-top','0','','','.b-bottom'),(934578,'printshop','.b-compare .popupCompare .pop-up-content','padding-top','0','','','.b-compare'),(934579,'printshop','.w-promotions .promo-cart-discount .master .item','padding-top','0','','','.w-promotions'),(934580,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(934581,'printshop','.b-bottom .alert-message','padding-top','20','','','.b-bottom'),(934582,'printshop','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(934583,'printshop','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(934584,'printshop','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(934585,'printshop','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(934586,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(934587,'printshop','.b-email .image','padding-top','5','','','.b-email'),(934588,'printshop','.b-bottom .cart-options','padding-top','20','','','.b-bottom'),(934589,'printshop','.b-info .info','padding-top','20','','','.b-info'),(934590,'printshop','.b-email .totals-title','padding-top','5','','','.b-email'),(934591,'printshop','.b-email .price','padding-top','5','','','.b-email'),(934592,'printshop','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(934593,'printshop','.b-email .image','padding-top','5','','','.b-email'),(934594,'printshop','.b-email .heading-image','padding-top','5','','','.b-email'),(934595,'printshop','.b-email .heading-qty','padding-top','5','','','.b-email'),(934596,'printshop','.b-bottom .footerTitle','padding-top','9','5333','','.b-bottom'),(934597,'printshop','.b-bottom .pop-up-info','padding-top','20','','','.b-bottom'),(934598,'printshop','.b-bottom .pop-up-close','padding-top','1','','','.b-bottom'),(934599,'printshop','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(934600,'printshop','.w-cart-up-sell .w-list-type-1','padding-top','0','','','.w-cart-up-sell'),(934601,'printshop','.w-cart-up-sell .w-list-type-1 .item','padding-top','1','','','.w-cart-up-sell'),(934602,'printshop','.w-cart-shipping-estimator .address-item','padding-top','0','','','.w-cart-shipping-estimator'),(934603,'printshop','.w-cart-up-sell .w-list-type-1 .item','padding-top','0','1','','.w-cart-up-sell'),(934604,'printshop','.b-upload-files .added-file','padding-top','5','','','.b-upload-files'),(934605,'printshop','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(934606,'printshop','.w-socials > li','padding-top','15','','','.w-socials'),(934607,'printshop','.p-quote-checkout-success .page-success .text-1','padding-top','5','5333','','.p-quote-checkout-success'),(934608,'printshop','.b-bottom .popup-box-wrap','padding-top','10','','','.b-bottom'),(934609,'printshop','.b-fancybox .fancybox-error','padding-top','15','','','.b-fancybox'),(934610,'printshop','.b-info .info','padding-top','20','','','.b-info'),(934611,'printshop','.b-info .info ul','padding-top','0','','','.b-info'),(934612,'printshop','.b-form .privacy-row','padding-top','10','','','.b-form'),(934613,'printshop','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(934614,'printshop','.b-form .payment-method .item','padding-top','7','','','.b-form'),(934615,'printshop','.b-form .required-message-wrap','padding-top','0','','','.b-form'),(934616,'printshop','.w-product-customers-activity .customers-activity','padding-top','35','','','.w-product-customers-activity'),(934617,'printshop','.b-table .table .headings td','padding-top','5','','','.b-table'),(934618,'printshop','.b-email .name','padding-top','5','','','.b-email'),(934619,'printshop','.b-email .heading-price','padding-top','5','','','.b-email'),(934620,'printshop','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(934621,'printshop','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(934622,'printshop','.w-checkout-billing-address .edit-ab','padding-top','5','','','.w-checkout-billing-address'),(934623,'printshop','.w-checkout-shipping-choice span','padding-top','7','','','.w-checkout-shipping-choice'),(934624,'printshop','.w-promo-code .holder','padding-top','20','5363','','.w-promo-code'),(934625,'printshop','.w-product-images-additional .images','padding-top','10','5363','','.w-product-images-additional'),(934626,'printshop','.w-categories .item','padding-top','5','','','.w-categories'),(934627,'printshop','.w-tabs .accordion-heading','padding-top','6','','','.w-tabs'),(934628,'printshop','.w-socials > li','padding-top','15','','','.w-socials'),(934629,'printshop','.b-form .shipping-method .sub-title','padding-top','2','','','.b-form'),(934630,'printshop','.w-categories h2.name','padding-top','11','','','.w-categories'),(934631,'printshop','.b-table .table .headings td','padding-top','5','','','.b-table'),(934632,'printshop','.w-catalog-sorting .before','padding-top','5','','','.w-catalog-sorting'),(934633,'printshop','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(934635,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(934636,'printshop','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(934637,'printshop','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(934638,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(934639,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-top','0','','','.b-select-suggest'),(934640,'printshop','.b-select-suggest .select2-locked','padding-top','3','','','.b-select-suggest'),(934641,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-top','5','','','.b-select-suggest'),(934642,'printshop','.b-select-suggest .select2-container-multi .select2-choices','padding-top','0','','','.b-select-suggest'),(934643,'printshop','.b-select-suggest .select2-results .select2-result-label','padding-top','3','','','.b-select-suggest'),(934644,'printshop','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','5','','','.w-menu-horizontal'),(934645,'printshop','.b-select-suggest .select2-results','padding-top','0','','','.b-select-suggest'),(934646,'printshop','.b-select-suggest .select2-container .select2-choice > .select2-chosen','padding-top','4','','','.b-select-suggest'),(934647,'printshop','.b-select-suggest .select2-search input','padding-top','4','','','.b-select-suggest'),(934648,'printshop','.b-bottom .notify-form','padding-top','0','','','.b-bottom'),(934649,'printshop','.b-select-suggest .select2-drop-auto-width .select2-search','padding-top','4','','','.b-select-suggest'),(934650,'printshop','.w-neighbour-checkout .neighbour-comment-box','padding-top','10','','','.w-neighbour-checkout'),(934651,'printshop','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(934652,'printshop','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(934653,'printshop','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(934655,'printshop','.w-checkout-billing-address .same-address','padding-top','10','','','.w-checkout-billing-address'),(934656,'printshop','.w-menu-horizontal > ul > li > ul > li','padding-top','2','','','.w-menu-horizontal'),(934657,'printshop','.w-menu-big ul','padding-top','0','','','.w-menu-big'),(934661,'printshop','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(934662,'printshop','.w-cart-compare .product-label','padding-top','15','','','.w-cart-compare'),(934663,'printshop','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(934664,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(934665,'printshop','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(934666,'printshop','.b-sub-totals .historyTotal td','padding-top','2','','','.b-sub-totals'),(934667,'printshop','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(934668,'printshop','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(934669,'printshop','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(934670,'printshop','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(934671,'printshop','.w-cart-compare .price-cell','padding-top','8','','','.w-cart-compare'),(934675,'printshop','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(934676,'printshop','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(934677,'printshop','.w-account-addresses-list .addsess-suggestion-item','padding-top','0','','','.w-account-addresses-list'),(934678,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top','0','','','.b-data-table'),(934679,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.b-data-table'),(934680,'printshop','.w-communication-post .communication-post-author','padding-top','10','','','.w-communication-post'),(934681,'printshop','.b-products-listing .in-cart','padding-top','5','','','.b-products-listing'),(934682,'printshop','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-top','4','','','.b-products-listing'),(934683,'printshop','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-top','5','','','.w-catalog-b2b-add-button'),(934684,'printshop','.b-products-listing .promos-info .promo-name','padding-top','3','','','.b-products-listing'),(934685,'printshop','.b-products-listing .promos-info .promo-item','padding-top','3','','','.b-products-listing'),(934691,'printshop','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(934692,'printshop','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(934693,'printshop','.p-quote-checkout-success .page-success .text-1','padding-top','5','5333','','.p-quote-checkout-success'),(934694,'printshop','.w-checkout-gdpr .privacy-row','padding-top','0','','','.w-checkout-gdpr'),(934695,'printshop','.w-checkout-gdpr .terms-login','padding-top','0','','','.w-checkout-gdpr'),(934696,'printshop','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(934697,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow b','padding-top','3','3','','.b-select-suggest'),(934698,'printshop','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(934699,'printshop','.b-table .table .headings td','padding-top','5','','','.b-table'),(934700,'printshop','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(934701,'printshop','.b-compare .compare-box-item','padding-top','10','','','.b-compare'),(934702,'printshop','.b-email .heading-qty','padding-top','5','','','.b-email'),(934703,'printshop','.b-bottom .header-info','padding-top','20','','','.b-bottom'),(934704,'printshop','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(934705,'printshop','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(934706,'printshop','.b-compare .compare-head','padding-top','10','','','.b-compare'),(934707,'printshop','.heading-4 .right-text, h4 .right-text','padding-top','4','','',''),(934708,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-top','0','','',''),(934709,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-top','0','','','.b-h-inline'),(934710,'printshop','h1, .heading-1','padding-top','20','','',''),(934711,'printshop','.w-communication-new-topic .topick-left-col','padding-top','24','','','.w-communication-new-topic'),(934712,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-top','0','','','.w-communication-new-topic'),(934713,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-top','5','','','.w-communication-new-topic'),(934714,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-top','5','','','.w-communication-new-topic'),(934715,'printshop','.w-communication-new-topic #communication_topic_form .middle-form','padding-top','20','','','.w-communication-new-topic'),(934716,'printshop','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(934717,'printshop','.b-email .heading-image','padding-top','5','','','.b-email'),(934718,'printshop','.b-email .price','padding-top','5','','','.b-email'),(934719,'printshop','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-top','4','','','.b-compare'),(934721,'printshop','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(934722,'printshop','.w-cart-compare .price-label','padding-top','10','','','.w-cart-compare'),(934723,'printshop','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(934725,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','padding-top','0','','','.w-contact-contacts'),(934726,'printshop','.b-table .table td','padding-top','15','','','.b-table'),(934727,'printshop','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(934728,'printshop','.b-info .info li','padding-top','0','','','.b-info'),(934729,'printshop','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(934730,'printshop','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(934731,'printshop','.b-email .model','padding-top','5','','','.b-email'),(934732,'printshop','.b-email .totals-value','padding-top','5','','','.b-email'),(934733,'printshop','.b-email .heading-name','padding-top','5','','','.b-email'),(934734,'printshop','.products-quick-index .token-input-list','padding-top','0','','',''),(934735,'printshop','.w-cart-compare .cart-cell','padding-top','0','','','.w-cart-compare'),(934737,'printshop','.w-reviews .item','padding-top','15','','','.w-reviews'),(934738,'printshop','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(934739,'printshop','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(934740,'printshop','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(934741,'printshop','.b-email .name','padding-top','5','','','.b-email'),(934742,'printshop','.b-form .shipping-method .item','padding-top','0','','','.b-form'),(934743,'printshop','.b-email .heading-name','padding-top','5','','','.b-email'),(934744,'printshop','.b-email .qty','padding-top','5','','','.b-email'),(934745,'printshop','.b-email .totals-value','padding-top','5','','','.b-email'),(934746,'printshop','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(934747,'printshop','.b-email .heading-model','padding-top','5','','','.b-email'),(934748,'printshop','.b-compare .col-two label','padding-top','5','','','.b-compare'),(934749,'printshop','.w-cart-listing .item .attributes','padding-top','5','','','.w-cart-listing'),(934750,'printshop','.w-cart-listing .item .gift-wrap label','padding-top','10','','','.w-cart-listing'),(934751,'printshop','.w-cart-listing .item > div','padding-top','10','','','.w-cart-listing'),(934752,'printshop','.w-cart-listing .points-earn','padding-top','5','','','.w-cart-listing'),(934753,'printshop','.w-cart-listing .points-redeem','padding-top','0','','','.w-cart-listing'),(934754,'printshop','.b-bottom .header-error','padding-top','20','','','.b-bottom'),(934760,'printshop','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(934761,'printshop','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(934762,'printshop','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(934763,'printshop','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(934764,'printshop','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(934765,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-top','10','','','.w-image-maps'),(934766,'printshop','.b-info .info ul','padding-top','0','','','.b-info'),(934767,'printshop','.b-compare .col-gender','padding-top','0','','','.b-compare'),(934768,'printshop','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(934769,'printshop','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-top','0','','','.b-fancybox'),(934770,'printshop','.b-compare .compare_pagination','padding-top','10','','','.b-compare'),(934771,'printshop','.w-top-categories .item','padding-top','5','5333','','.w-top-categories'),(934772,'printshop','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(934775,'printshop','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(934776,'printshop','.b-table .table td','padding-top','15','','','.b-table'),(934777,'printshop','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(934778,'printshop','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(934780,'printshop','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(934781,'printshop','.w-filters .fsl_handle','padding-top','20','','','.w-filters'),(934782,'printshop','.w-filters .head-filter-widget','padding-top','0','5342','','.w-filters'),(934783,'printshop','.w-filters .ui-slider-range','padding-top','0','','','.w-filters'),(934784,'printshop','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(934785,'printshop','.w-filters .head-filter-widget','padding-top','0','','','.w-filters'),(934786,'printshop','.b-autocomplete .ui-autocomplete','padding-top','2','','','.b-autocomplete'),(934787,'printshop','.w-promo-code .holder','padding-top','20','5363','','.w-promo-code'),(934789,'printshop','.order-summary .heading-2','padding-top','10','','','.order-summary'),(934790,'printshop','.b-compare .column_wrapper','padding-top','0','','','.b-compare'),(934791,'printshop','.b-email .image','padding-top','5','','','.b-email'),(934792,'printshop','.b-email .heading-price','padding-top','5','','','.b-email'),(934793,'printshop','.b-email .heading-image','padding-top','5','','','.b-email'),(934794,'printshop','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(934795,'printshop','.b-table .table .headings td','padding-top','5','','','.b-table'),(934796,'printshop','.w-reviews-content .author','padding-top','0','','','.w-reviews-content'),(934797,'printshop','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(934798,'printshop','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(934799,'printshop','.price .old','padding-top','0.3','','',''),(934800,'printshop','.b-data-table table.dataTable tbody td','padding-top','10','','','.b-data-table'),(934801,'printshop','.b-data-table table.dataTable thead td','padding-top','10','','','.b-data-table'),(934802,'printshop','.w-contact-contacts table td','padding-top','0','','','.w-contact-contacts'),(934803,'printshop','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(934804,'printshop','.b-table .table td','padding-top','15','','','.b-table'),(934806,'printshop','.btn-2','padding-top','8','','',''),(934807,'printshop','.w-quote-products .empty','padding-top','100','','','.w-quote-products'),(934808,'printshop','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(934809,'printshop','.b-info .info li','padding-top','0','','','.b-info'),(934810,'printshop','.b-info .info','padding-top','20','','','.b-info'),(934811,'printshop','.w-checkout-create-account .create-account','padding-top','10','','','.w-checkout-create-account'),(934812,'printshop','.b-email .totals-title','padding-top','5','','','.b-email'),(934813,'printshop','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(934814,'printshop','.b-upload-files .upload-files','padding-top','0','','','.b-upload-files'),(934815,'printshop','.b-email .totals-value','padding-top','5','','','.b-email'),(934816,'printshop','.b-email .totals-value','padding-top','5','','','.b-email'),(934817,'printshop','.b-email .totals-title','padding-top','5','','','.b-email'),(934818,'printshop','.b-email .qty','padding-top','5','','','.b-email'),(934819,'printshop','.btn','padding-top','8','','',''),(934820,'printshop','.w-personal-gift-status-bar .timeline','padding-top','16','','','.w-personal-gift-status-bar'),(934821,'printshop','.b-product-images .media-popup .mp-content','padding-top','0','','','.b-product-images'),(934822,'printshop','.b-product-images .media-popup .mp-small-images .item','padding-top','10','','','.b-product-images'),(934823,'printshop','.b-product-images .media-popup .slick-dots','padding-top','0','','','.b-product-images'),(934824,'printshop','.b-product-images .media-popup .slick-dots li','padding-top','0','','','.b-product-images'),(934825,'printshop','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-top','0','','','.b-menu-style'),(934826,'printshop','.b-personal-catalog-popup #personal_catalog_popup','padding-top','20','','','.b-personal-catalog-popup'),(934827,'printshop','.b-trade-approval .steps-bar li a','padding-top','7','','','.b-trade-approval'),(934828,'printshop','.b-trade-approval .middle-form','padding-top','20','','','.b-trade-approval'),(934829,'printshop','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-top','5','','','.b-trade-approval'),(934830,'printshop','.b-trade-approval .steps-bar','padding-top','0','','','.b-trade-approval'),(934831,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-top','4','','','.b-trade-approval'),(934832,'printshop','.b-trade-approval .center-buttons','padding-top','20','','','.b-trade-approval'),(934833,'printshop','.w-account-personal-catalog .list-switcher','padding-top','0','','','.w-account-personal-catalog'),(934834,'printshop','.w-account-personal-catalog .list-switcher a','padding-top','14','','','.w-account-personal-catalog'),(934835,'printshop','.w-account-personal-catalog .list-switcher a','padding-top','12','2','','.w-account-personal-catalog'),(934836,'printshop','.w-account-subscription .subscription-variant','padding-top','10','','','.w-account-subscription'),(934837,'printshop','.w-catalog-additional-images li','padding-top','10','','','.w-catalog-additional-images'),(934838,'printshop','.w-catalog-additional-images ul','padding-top','0','','','.w-catalog-additional-images'),(934839,'printshop','.w-catalog-compare td','padding-top','10','','','.w-catalog-compare'),(934840,'printshop','.w-catalog-compare .cross-box .different-all > div','padding-top','12','','','.w-catalog-compare'),(934841,'printshop','.w-catalog-compare .cross-box .different-all > div','padding-top','10','2','','.w-catalog-compare'),(934842,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-top','0','','','.w-catalog-compare'),(934843,'printshop','.w-delivery-day .left-count','padding-top','5','','','.w-delivery-day'),(934844,'printshop','.w-delivery-day .left-text-left','padding-top','24','','','.w-delivery-day'),(934845,'printshop','.w-delivery-day .left-text-right','padding-top','24','','','.w-delivery-day'),(934846,'printshop','.w-top-text .top-text','padding-top','5','','','.w-top-text'),(934847,'printshop','.w-product-images .slick-vertical + .produst-image','padding-top','400','','','.w-product-images'),(934848,'printshop','.w-cart-listing .points','padding-top','0','5333','','.w-cart-listing'),(934849,'printshop','.w-product-images .additional-horizontal .item','padding-top','10','','','.w-product-images'),(934850,'printshop','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-top','10','','','.b-cookie-notice'),(934851,'printshop','.lowestPricedBox .w-banner .single_banner','padding-top','0','','','.lowestPricedBox'),(934852,'printshop','.lowestPricedBox .w-banner .banner','padding-top','30','','','.lowestPricedBox'),(934853,'printshop','.tripleBanner ','padding-top','15','','','.tripleBanner'),(934854,'printshop','.tripleBanner > .block','padding-top','0','','','.tripleBanner'),(934855,'printshop','.tripleBanner .w-html_box','padding-top','17','','','.tripleBanner'),(934856,'printshop','.shopByCollectionBox .w-banner .single_banner','padding-top','0','','','.shopByCollectionBox'),(934857,'printshop','.preFooter .w-banner .single_banner picture','padding-top','0','','','.preFooter'),(934858,'printshop','.b-slick .slick-list','padding-top','0','','','.b-slick'),(934859,'printshop','.b-slick .slick-vertical button.slick-next','padding-top','0','3','','.b-slick'),(934860,'printshop','.b-slick .slick-vertical button.slick-prev','padding-top','0','3','','.b-slick'),(934861,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','padding-top','0','','','.b-slick'),(934862,'printshop','body','padding-top','75','5342','',''),(934863,'printshop','.w-cart-listing .headings .head','padding-top','10','','','.w-cart-listing'),(934864,'printshop','.b-products-listing .item-nav > div','padding-top','10','','','.b-products-listing'),(934865,'printshop','.LeftCategories .w-menu-simple ul','padding-top','0','','','.LeftCategories'),(934866,'printshop','.LeftCategories .w-menu-simple ul li a','padding-top','4','','','.LeftCategories'),(934867,'printshop','.w-filters .filter-widget','padding-top','20','','','.w-filters'),(934868,'printshop','.b-products-listing .products-listing.list-productlisting .item','padding-top','20','','','.b-products-listing'),(934869,'printshop','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-top','15','','','.b-products-listing'),(934870,'printshop','.b-products-listing .products-listing.list-rows .item-nav > div','padding-top','0','','','.b-products-listing'),(934871,'printshop','.b-products-listing .products-listing.list-rows .item:first-of-type .BlockBox.item-holder','padding-top','10','','','.b-products-listing'),(934872,'printshop','.w-breadcrumb .breadcrumb-li','padding-top','0','','','.w-breadcrumb'),(934873,'printshop','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(934874,'printshop','.w-subscribers .btn-submit','padding-top','5','','','.w-subscribers'),(934875,'printshop','.w-quote .buttons','padding-top','15','','','.w-quote'),(934876,'printshop','.w-quote .buttons .btn','padding-top','5','','','.w-quote'),(934877,'printshop','.w-quote .cart-content','padding-top','15','','','.w-quote'),(934878,'printshop','.w-quote .cart-total','padding-top','10','','','.w-quote'),(934879,'printshop','.w-quote .multicart .cart-content','padding-top','0','','','.w-quote'),(934880,'printshop','.w-quote .multicart .item','padding-top','15','','','.w-quote'),(934881,'printshop','.w-quote .multicart .name','padding-top','0','','','.w-quote'),(934882,'printshop','.w-quote .no-text','padding-top','0','','','.w-quote'),(934883,'printshop','.w-quote a.item','padding-top','5','','','.w-quote'),(934884,'printshop','.w-product-images .additional-vertical .additional-images','padding-top','30','','','.w-product-images'),(934885,'printshop','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(934886,'printshop','.w-product-sale-ends .left-count','padding-top','5','','','.w-product-sale-ends'),(934887,'printshop','.w-product-sale-ends .left-text-left','padding-top','24','','','.w-product-sale-ends'),(934888,'printshop','.w-product-sale-ends .left-text-right','padding-top','24','','','.w-product-sale-ends'),(934889,'printshop','.w-product-sale-ends .left-count-days','padding-top','7','','','.w-product-sale-ends'),(934890,'printshop','.w-product-sale-ends .left-count-hours','padding-top','7','','','.w-product-sale-ends'),(934891,'printshop','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(934892,'printshop','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(934893,'printshop','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(934894,'printshop','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(934895,'printshop','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(934896,'printshop','.warrantyProduct .warranty, .warrantyProduct .delivery','padding-top','10','','','.warrantyProduct'),(934897,'printshop','.w-compare .compare-list-buttons','padding-top','10','','','.w-compare'),(934898,'printshop','.w-compare .item-holder','padding-top','10','','','.w-compare'),(934899,'printshop','.w-compare .compare-list-products','padding-top','0','','','.w-compare'),(934900,'printshop','.w-files-catalog-widgets-files-catalog .name','padding-top','10','','','.w-files-catalog-widgets-files-catalog'),(934901,'printshop','.w-files-catalog-widgets-files-list .item + .item','padding-top','30','','','.w-files-catalog-widgets-files-list'),(934902,'printshop','.w-sample .buttons','padding-top','15','','','.w-sample'),(934903,'printshop','.w-sample .buttons .btn','padding-top','5','','','.w-sample'),(934904,'printshop','.w-sample .cart-box-link','padding-top','0','','','.w-sample'),(934905,'printshop','.w-sample .cart-content','padding-top','15','','','.w-sample'),(934906,'printshop','.w-sample .cart-total','padding-top','10','','','.w-sample'),(934907,'printshop','.w-sample .multicart .cart-content','padding-top','0','','','.w-sample'),(934908,'printshop','.w-sample .multicart .item','padding-top','15','','','.w-sample'),(934909,'printshop','.w-sample .multicart .name','padding-top','0','','','.w-sample'),(934910,'printshop','.w-sample .no-text','padding-top','0','','','.w-sample'),(934911,'printshop','.w-sample a.item','padding-top','5','','','.w-sample'),(934912,'printshop','.w-cart-listing .item > div.points','padding-top','0','','','.w-cart-listing'),(934913,'printshop','.w-filters-simple .integrate-price-holder','padding-top','10','','','.w-filters-simple'),(934914,'printshop','.w-product-video .item','padding-top','10','','','.w-product-video'),(934915,'printshop','.shipping-ico .heading-3','padding-top','0','','','.shipping-ico'),(934916,'printshop','.w-cart-order-reference .btn','padding-top','6','','','.w-cart-order-reference'),(934917,'printshop','.w-cart-gift-certificate .btn','padding-top','6','','','.w-cart-gift-certificate'),(934918,'printshop','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(934919,'printshop','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(934920,'printshop','.w-product-in-bundles .attributes-item','padding-top','0','','','.w-product-in-bundles'),(934921,'printshop','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(934922,'printshop','.w-cart-listing .item > div.actions','padding-top','10','5333','','.w-cart-listing'),(934924,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-top','0','','','.b-products-listing'),(934925,'printshop','.b-pagination ul.pagination','padding-top','0','','','.b-pagination'),(934926,'printshop','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','padding-top','10','','','.w-catalog-compare'),(934927,'printshop','.w-product-properties-filters-widgets-chosen-filters .item','padding-top','3','','','.w-product-properties-filters-widgets-chosen-filters'),(934928,'printshop','.p-quote-checkout-index .datepicker-inline','padding-top','10','','','.p-quote-checkout-index'),(934929,'printshop','.p-sample-checkout-index .datepicker-inline','padding-top','10','','','.p-sample-checkout-index'),(934933,'printshop','.w-product-multi-inventory .radio-attributes .option-item','padding-top','10','','','.w-product-multi-inventory'),(934934,'printshop','.w-account-personal-catalog .list-row-action ul','padding-top','0','','','.w-account-personal-catalog'),(934935,'printshop','.w-account-personal-catalog .list-row-action li','padding-top','5','','','.w-account-personal-catalog'),(934936,'printshop','.w-account-personal-catalog .buy-box','padding-top','0','5333','','.w-account-personal-catalog'),(934937,'printshop','.b-products-listing .products-listing .radio-attributes .option','padding-top','10','','','.b-products-listing'),(934938,'printshop','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(934939,'printshop','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(934940,'printshop','.w-product-collection .choose-products','padding-top','20','','','.w-product-collection'),(934941,'printshop','.w-product-collection .right-area .btn','padding-top','12','','','.w-product-collection'),(934942,'printshop','.w-product-attributes .radio-attributes .option-item','padding-top','10','','','.w-product-attributes'),(934943,'printshop','.w-product-properties .property-ul','padding-top','0','','','.w-product-properties'),(934944,'printshop','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(934945,'printshop','.w-product-properties li','padding-top','5','','','.w-product-properties'),(934946,'printshop','.w-questionnaire-widgets-questionnaire .question + .question','padding-top','20','','','.w-questionnaire-widgets-questionnaire'),(934947,'printshop','.w-product-groups .radioBox','padding-top','0','','','.w-product-groups'),(934948,'printshop','.w-product-groups .radioBox label','padding-top','0','','','.w-product-groups'),(934949,'printshop','.w-product-groups .radioBox label .containerBlock','padding-top','20','','','.w-product-groups'),(934950,'printshop','.w-product-groups .radioBox label .containerBlock','padding-top','5','5363','','.w-product-groups'),(934951,'printshop','.b-products-listing .mix-attributes .attribute-qty-block','padding-top','5','','','.b-products-listing'),(934952,'printshop','.b-products-listing .products-listing .attribute-qty-block','padding-top','5','','','.b-products-listing'),(934953,'printshop','.blogsidebar','padding-top','0','5342','',''),(934954,'printshop','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(934955,'printshop','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(934956,'printshop','.w-product-custom-bundle .choose-products','padding-top','10','','','.w-product-custom-bundle'),(934957,'printshop','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-top','14','','','.w-product-custom-bundle'),(934958,'printshop','.w-product-custom-bundle .right-area','padding-top','0','5342','','.w-product-custom-bundle'),(934959,'printshop','.w-product-custom-bundle .right-area .price','padding-top','20','5342','','.w-product-custom-bundle'),(934960,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list'),(934961,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-top','0','','','.w-catalog-pages-category-pages-last-list'),(934962,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list-block'),(934963,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-top','0','','','.w-catalog-pages-category-pages-last-list-block'),(934964,'printshop','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(934965,'printshop','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(934966,'printshop','.w-delivery-location-location-description .deliveryDesc','padding-top','10','','','.w-delivery-location-location-description'),(934967,'printshop','.w-delivery-location-location-list .deliveryListParrent a','padding-top','6','','','.w-delivery-location-location-list'),(934968,'printshop','.w-delivery-location-location-list .deliveryList li a','padding-top','10','','','.w-delivery-location-location-list'),(934969,'printshop','.btn-2','padding-top','7','5333','',''),(934970,'printshop','.w-sale-category .holder-1','padding-top','20','','','.w-sale-category'),(934971,'printshop','.w-sale-category .holder-2','padding-top','20','','','.w-sale-category'),(934972,'printshop','.w-sale-category .left-count','padding-top','5','','','.w-sale-category'),(934973,'printshop','.w-sale-category .left-text-left','padding-top','24','','','.w-sale-category'),(934974,'printshop','.w-sale-category .left-text-right','padding-top','24','','','.w-sale-category'),(934975,'printshop','.w-sale-category .text','padding-top','10','','','.w-sale-category'),(934976,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(934977,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(934978,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(934979,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(934980,'printshop','.w-delivery-location-list-by-page .item','padding-top','20','','','.w-delivery-location-list-by-page'),(934981,'printshop','.w-product-properties-icons .property-image','padding-top','10','','','.w-product-properties-icons'),(934982,'printshop','.w-product-properties-icons .hover-box-content','padding-top','10','','','.w-product-properties-icons'),(934983,'printshop','.w-delivery-location-cross-pages .item','padding-top','20','','','.w-delivery-location-cross-pages'),(934984,'printshop','.w-delivery-location-product-categories .item.category-link','padding-top','15','','','.w-delivery-location-product-categories'),(934985,'printshop','.w-delivery-location-product-categories .item.category-link','padding-top','10','5342','','.w-delivery-location-product-categories'),(934986,'printshop','.w-delivery-location-product-categories .item.category-link','padding-top','10','5363','','.w-delivery-location-product-categories'),(934987,'printshop','.w-delivery-location-product-categories .name','padding-top','10','','','.w-delivery-location-product-categories'),(934988,'printshop','.delivery-options-popup','padding-top','20','','',''),(934989,'printshop','.w-product-bonus-points .bonus-points-cost','padding-top','8','','','.w-product-bonus-points'),(934990,'printshop','.w-product-designer-designer .grnamebox .title-sortable','padding-top','7','','','.w-product-designer-designer'),(934991,'printshop','.w-product-designer-designer .prodDesignerType label','padding-top','10','','','.w-product-designer-designer'),(934992,'printshop','.w-press-reviews-widgets-press-reviews ','padding-top','30','','','.w-press-reviews-widgets-press-reviews'),(934993,'printshop','.w-press-reviews-widgets-press-reviews .author','padding-top','0','','','.w-press-reviews-widgets-press-reviews'),(934994,'printshop','.w-press-reviews-widgets-press-reviews .item','padding-top','20','','','.w-press-reviews-widgets-press-reviews'),(934995,'printshop','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-top','30','','','.w-press-reviews-widgets-press-reviews'),(934996,'printshop','.w-press-reviews-widgets-press-reviews .review','padding-top','10','','','.w-press-reviews-widgets-press-reviews'),(934997,'printshop','.w-press-reviews-widgets-press-reviews ','padding-top','20','5333','','.w-press-reviews-widgets-press-reviews'),(934998,'printshop','.w-press-reviews-widgets-press-reviews .item','padding-top','15','5333','','.w-press-reviews-widgets-press-reviews'),(934999,'printshop','.w-press-reviews-widgets-press-reviews .review','padding-top','10','5333','','.w-press-reviews-widgets-press-reviews'),(935000,'printshop','.w-press-reviews-widgets-press-reviews-list .item','padding-top','0','','','.w-press-reviews-widgets-press-reviews-list'),(935001,'printshop','.w-press-reviews-widgets-press-reviews-list .short-description','padding-top','0','','','.w-press-reviews-widgets-press-reviews-list'),(935002,'printshop','.b-products-listing .productGroup label a','padding-top','5','','','.b-products-listing'),(935003,'printshop','.w-gift-wrap-message-checkout .text','padding-top','2','','','.w-gift-wrap-message-checkout'),(935004,'printshop','.w-support-system-filter ','padding-top','0','','','.w-support-system-filter'),(935005,'printshop','.w-support-system-filter .filter_cats','padding-top','0','','','.w-support-system-filter'),(935006,'printshop','.w-support-system-listing .support-head','padding-top','13','','','.w-support-system-listing'),(935007,'printshop','.w-communication-post .btn.refresh','padding-top','0','','','.w-communication-post'),(935008,'printshop','.w-rma-returns-history .btn','padding-top','7','','','.w-rma-returns-history'),(935009,'printshop','.w-rma-returns-history .column','padding-top','0','','','.w-rma-returns-history'),(935010,'printshop','.w-rma-returns-history .column .title','padding-top','5','','','.w-rma-returns-history'),(935011,'printshop','.w-rma-returns-history .topRow','padding-top','10','','','.w-rma-returns-history'),(935012,'printshop','.w-rma-returns-history .column:last-child .title','padding-top','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(935013,'printshop','.w-show-inactive-show-inactive .out_stock_label','padding-top','2','','','.w-show-inactive-show-inactive'),(935014,'printshop','.w-product-designer-designer .productDesignerBox ul','padding-top','0','','','.w-product-designer-designer'),(935015,'printshop','.w-product-configurator .pc-item','padding-top','0','','','.w-product-configurator'),(935016,'printshop','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(935017,'printshop','.w-product-configurator .pc_item','padding-top','10','5342','','.w-product-configurator'),(935018,'printshop','.w-product-configurator .pc_attr','padding-top','5','5333','','.w-product-configurator'),(935019,'printshop','.b-products-listing .products-listing .bonus-points-cost','padding-top','8','','','.b-products-listing'),(935020,'printshop','.b-products-listing .promos-info .promo-name-span','padding-top','3','','','.b-products-listing'),(935021,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-list'),(935022,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-top','0','','','.w-catalog-pages-category-pages-list'),(935023,'printshop','.w-predefined-promotion .nextdiscount .content > div','padding-top','10','','','.w-predefined-promotion'),(935024,'printshop','.w-predefined-promotion .nextdiscount .promo-for-each','padding-top','3','','','.w-predefined-promotion'),(935025,'printshop','.w-predefined-promotion .prom-multi-discount .promo-product','padding-top','20','','','.w-predefined-promotion'),(935026,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','padding-top','0','','','.w-predefined-promotion'),(935027,'printshop','.w-predefined-promotion .promo-cart-discount .master .item','padding-top','0','','','.w-predefined-promotion'),(935028,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-top','0','','','.w-predefined-promotion'),(935029,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-top','0','','','.w-predefined-promotion'),(935030,'printshop','.w-predefined-promotion .promo-cart-discount .slave .item','padding-top','20','','','.w-predefined-promotion'),(935031,'printshop','.w-predefined-promotion .promo-item','padding-top','30','','','.w-predefined-promotion'),(935032,'printshop','.w-predefined-promotion .promo-salemaker .discount','padding-top','0','','','.w-predefined-promotion'),(935033,'printshop','.w-predefined-promotion .promo-salemaker .item','padding-top','20','','','.w-predefined-promotion'),(935034,'printshop','.w-supplier-purchase-supplier-products .item','padding-top','10','','','.w-supplier-purchase-supplier-products'),(935039,'printshop','.b-products-listing .products-listing .compare .checkbox input:not(checked) + span:before','padding-top','0','','','.b-products-listing'),(935040,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','padding-top','10','','','.w-filters'),(935041,'printshop','.b-quantity .qty-box input[type=\"text\"]','padding-top','5','','','.b-quantity'),(935042,'printshop','.w-product-model ','padding-top','10','','','.w-product-model'),(935043,'printshop','.tripleLine picture[id], .tripleLine picture[style]','padding-top','0','','','.tripleLine'),(935044,'printshop','.cartTitle span','padding-top','20','','','.cartTitle'),(935045,'printshop','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(935046,'printshop','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(935047,'printshop','.lowestPricedBox .btn-2','padding-top','15','','','.lowestPricedBox'),(935048,'printshop','.lowestPricedBox .title','padding-top','50','','','.lowestPricedBox'),(935049,'printshop','.doubleBanner .btn-2','padding-top','15','','','.doubleBanner'),(935050,'printshop','.doubleBanner .title','padding-top','50','','','.doubleBanner'),(935051,'printshop','.doubleBanner .btn-2','padding-top','10','5347','','.doubleBanner'),(935052,'printshop','.doubleBanner .title','padding-top','30','5347','','.doubleBanner'),(935053,'printshop','.middleBanner .btn-1','padding-top','16','','','.middleBanner'),(935054,'printshop','.middleBanner .title','padding-top','30','','','.middleBanner'),(935055,'printshop','.bottomDoubleBanner .btn-2','padding-top','15','','','.bottomDoubleBanner'),(935056,'printshop','.bottomDoubleBanner .title','padding-top','30','','','.bottomDoubleBanner'),(935057,'printshop','.bottomDoubleBanner .btn-2','padding-top','10','5347','','.bottomDoubleBanner'),(935058,'printshop','.bottomDoubleBanner .title','padding-top','30','5347','','.bottomDoubleBanner'),(935059,'printshop','.bottomBanner .btn-1','padding-top','16','','','.bottomBanner'),(935060,'printshop','.bottomBanner .wrapper','padding-top','20','','','.bottomBanner'),(935061,'printshop','.bottomBanner .icon-box > div','padding-top','0','','','.bottomBanner'),(935062,'printshop','.bottomBanner .icon-box','padding-top','70','','','.bottomBanner'),(935063,'printshop','.topBanner > .block','padding-top','0','','','.topBanner'),(935064,'printshop','.productNavigation .type-1 > .block > .type-2 > .block:nth-child(1) + .block:nth-child(2) .w-product-stock','padding-top','10','','','.productNavigation'),(935068,'printshop','.middleBanner .btn-1','padding-top','11','5342','','.middleBanner'),(935069,'printshop','.middleBanner .title','padding-top','0','5333','','.middleBanner'),(935070,'printshop','.middleBanner .btn-1','padding-top','7','5333','','.middleBanner'),(935071,'printshop','.bottomBanner .btn-1','padding-top','11','5347','','.bottomBanner'),(935072,'printshop','.bottomBanner .icon-box','padding-top','50','5347','','.bottomBanner'),(935073,'printshop','.bottomBanner .icon-box > div','padding-top','0','5347','','.bottomBanner'),(935074,'printshop','.w-multi-cart-cart-switcher .carts-switcher','padding-top','0','5342','','.w-multi-cart-cart-switcher'),(935075,'printshop','.w-multi-cart-save-cart .btn','padding-top','8','5363','','.w-multi-cart-save-cart'),(935076,'printshop','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-top','0','','','.b-products-listing'),(935077,'printshop','.b-products-listing .products-listing.list-productlisting .item','padding-top','10','5363','','.b-products-listing'),(935078,'printshop','.w-filters .filter-widget','padding-top','10','5342','','.w-filters'),(935079,'printshop','.w-tabs > .block','padding-top','10','5363','','.w-tabs'),(935080,'printshop','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-top','10','5363','','.b-products-listing'),(935081,'printshop','.w-login-returning .middle-form','padding-top','0','5333','','.w-login-returning'),(935082,'printshop','.w-account-personal-catalog .buy-box','padding-top','0','5363','','.w-account-personal-catalog'),(935083,'printshop','.b-bottom .confirm-popup .buttons','padding-top','5','','','.b-bottom'),(935084,'printshop','.trade_form > .type-1 > .block','padding-top','0','','',''),(935085,'printshop','.p-payer-order-pay .order-summary .heading-2','padding-top','0','','','.p-payer-order-pay'),(935086,'printshop','.p-payer-order-pay .price-row','padding-top','5','','','.p-payer-order-pay'),(935087,'printshop','.p-payer-order-pay .payer > .type-1 > .block','padding-top','0','','','.p-payer-order-pay'),(935088,'printshop','.p-payer-order-confirmation .order-summary .heading-2','padding-top','0','','','.p-payer-order-confirmation'),(935089,'printshop','.p-payer-order-confirmation .payer > .type-1 > .block','padding-top','0','','','.p-payer-order-confirmation'),(935090,'printshop','.p-payer-order-confirmation .price-row','padding-top','5','','','.p-payer-order-confirmation'),(935091,'printshop','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','padding-top','8','','','.w-product-buttons'),(935092,'printshop','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','padding-top','14','5363','','.w-product-buttons'),(935093,'printshop','.b-products-listing .products-listing.list-productlisting .compare','padding-top','10','','','.b-products-listing'),(935094,'printshop','.w-cart-listing .remove-btn','padding-top','20','','','.w-cart-listing'),(935095,'printshop','.w-cart-listing .remove-btn','padding-top','0','5342','','.w-cart-listing'),(935096,'printshop','.topBanner .content .btn','padding-top','1','','','.topBanner'),(935097,'printshop','.topBanner .ourPick .bottom','padding-top','0.25','','','.topBanner'),(935098,'printshop','.topBanner .ourPick .top','padding-top','0','','','.topBanner'),(935099,'printshop','.topBanner .content .btn','padding-top','16','5410','','.topBanner'),(935100,'printshop','.topBanner .content .btn','padding-top','11','5342','','.topBanner'),(935101,'printshop','.topBanner .ourPick .top','padding-top','0','5342','','.topBanner'),(935102,'printshop','.topBanner .content','padding-top','0','5333','','.topBanner'),(935103,'printshop','.topBanner .content .btn','padding-top','6','5363','','.topBanner'),(935104,'printshop','.bottomBanner .btn-1','padding-top','6','5363','','.bottomBanner'),(935105,'printshop','.bottomBanner .wrapper','padding-top','15','5363','','.bottomBanner'),(935106,'printshop','.middleBanner .btn-1','padding-top','5','5363','','.middleBanner'),(935107,'printshop','.w-promotions-widgets-promotion-icons-desc .w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','padding-top','5','','','.w-promotions-widgets-promotion-icons-desc'),(935108,'printshop','.order-summary ','padding-top','10','','','.order-summary'),(935109,'printshop','.order-summary .checkout-cart-listing.summary-listing','padding-top','20','','','.order-summary'),(935110,'printshop','.order-summary .w-cart-listing .item > div ~ div','padding-top','0','','','.order-summary'),(935111,'printshop','.order-summary ','padding-top','10','5333','','.order-summary'),(935112,'printshop','.w-cart-discount-coupon .discount-box','padding-top','5','','','.w-cart-discount-coupon'),(935113,'printshop','.p-quote-checkout-index .dob-hide label','padding-top','5','','','.p-quote-checkout-index'),(935114,'printshop','.p-quote-checkout-index .edit-address-popup','padding-top','20','','','.p-quote-checkout-index'),(935115,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons a, .p-quote-checkout-index .btn-cancel','padding-top','7','','','.p-quote-checkout-index'),(935116,'printshop','.p-quote-checkout-index .order-summary .heading-2','padding-top','0','','','.p-quote-checkout-index'),(935117,'printshop','.w-quote-products ','padding-top','10','','','.w-quote-products'),(935119,'printshop','.account-address-book .address_book','padding-top','0','','','.account-address-book'),(935120,'printshop','.account-address-book .address_book h1','padding-top','0','','','.account-address-book'),(935121,'printshop','.account-address-book .address_book h2','padding-top','15','','','.account-address-book'),(935122,'printshop','.account-address-book .address_book, .account-address-book .account_history_info','padding-top','10','','','.account-address-book'),(935123,'printshop','.account-address-book .buttonBox','padding-top','15','','','.account-address-book'),(935124,'printshop','.account-address-book .rightMes ul','padding-top','22','','','.account-address-book'),(935125,'printshop','.account-address-book .topButtons','padding-top','0','','','.account-address-book'),(935160,'printshop','.account-order-pay .contentColumn','padding-top','10','','','.account-order-pay'),(935161,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-top','5','','','.account-order-pay'),(935162,'printshop','.account-order-pay .history_attr','padding-top','5','','','.account-order-pay'),(935163,'printshop','.account-order-pay .history_info > div + div','padding-top','0','','','.account-order-pay'),(935164,'printshop','.account-order-pay .history_info > div','padding-top','0','5342','','.account-order-pay'),(935165,'printshop','.account-order-pay .history_info > div + div','padding-top','0','5342','','.account-order-pay'),(935166,'printshop','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-top','10','','','.account-samples'),(935167,'printshop','.account-samples .orders-table th','padding-top','2','','','.account-samples'),(935168,'printshop','.account-samples .order_history_table th','padding-top','10','','','.account-samples'),(935169,'printshop','.account-samples .view_link','padding-top','0','','','.account-samples'),(935170,'printshop','.account-samples .orders-table .td-alignright','padding-top','5','5342','','.account-samples'),(935171,'printshop','.account-samples .orders-table td','padding-top','5','5342','','.account-samples'),(935172,'printshop','.account-sample-info .contentColumn','padding-top','10','','','.account-sample-info'),(935173,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-top','5','','','.account-sample-info'),(935174,'printshop','.account-sample-info .history_attr','padding-top','5','','','.account-sample-info'),(935175,'printshop','.account-sample-info .history_info > div + div','padding-top','0','','','.account-sample-info'),(935176,'printshop','.account-sample-info .popup-tracking-number','padding-top','10','','','.account-sample-info'),(935177,'printshop','.account-sample-info .history_info > div','padding-top','0','5342','','.account-sample-info'),(935178,'printshop','.account-sample-info .history_info > div + div','padding-top','0','5342','','.account-sample-info'),(935179,'printshop','.catalog-product-wrap .next-product','padding-top','20','','','.catalog-product-wrap'),(935180,'printshop','.catalog-product-wrap .pn-direction','padding-top','0','','','.catalog-product-wrap'),(935181,'printshop','.catalog-product-wrap .pn-image','padding-top','20','','','.catalog-product-wrap'),(935182,'printshop','.catalog-product-wrap .pn-name','padding-top','15','','','.catalog-product-wrap'),(935183,'printshop','.catalog-product-wrap .prev-product','padding-top','20','','','.catalog-product-wrap'),(935184,'printshop','.catalog-product-wrap .next-product','padding-top','20','5342','','.catalog-product-wrap'),(935185,'printshop','.catalog-product-wrap .pn-direction','padding-top','0','5342','','.catalog-product-wrap'),(935186,'printshop','.catalog-product-wrap .prev-product','padding-top','20','5342','','.catalog-product-wrap'),(935187,'printshop','.shopping-cart-index .btn-3','padding-top','11','','','.shopping-cart-index'),(935188,'printshop','.shopping-cart-index .cart-page .empty','padding-top','100','','','.shopping-cart-index'),(935189,'printshop','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-top','0','','','.shopping-cart-index'),(935190,'printshop','.checkout-index-wrap .closeable-heading + .closeable-content','padding-top','10','','','.checkout-index-wrap'),(935191,'printshop','.checkout-index-wrap .datepicker-inline','padding-top','10','','','.checkout-index-wrap'),(935192,'printshop','.checkout-index-wrap .dob-hide label','padding-top','5','','','.checkout-index-wrap'),(935193,'printshop','.checkout-index-wrap .edit-address-popup','padding-top','20','','','.checkout-index-wrap'),(935194,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-top','7','','','.checkout-index-wrap'),(935195,'printshop','.checkout-index-wrap .hiding-box .checkout-cart-listing','padding-top','30','','','.checkout-index-wrap'),(935196,'printshop','.checkout-index-wrap .order-summary .heading-2','padding-top','0','','','.checkout-index-wrap'),(935197,'printshop','.checkout-order-confirmation .order-summary .heading-2','padding-top','0','','','.checkout-order-confirmation'),(935198,'printshop','.checkout-order-confirmation .price-row','padding-top','5','','','.checkout-order-confirmation'),(935199,'printshop','.checkout-success-wrap .page-success .text-1','padding-top','40','','','.checkout-success-wrap'),(935200,'printshop','.checkout-success-wrap .page-success .text-1','padding-top','5','5333','','.checkout-success-wrap'),(935201,'printshop','.checkout-login-wrap .password-forgotten-link','padding-top','0','','','.checkout-login-wrap'),(935202,'printshop','.b-bottom .pop-up-content','padding-top','20','','','.b-bottom'),(935203,'printshop','.b-bottom .pop-up-content .buttons','padding-top','15','','','.b-bottom'),(935204,'printshop','.b-form .columns .col-2','padding-top','0','','','.b-form'),(935205,'printshop','.b-slick .slick-dots li','padding-top','5','','','.b-slick'),(935206,'printshop','.success-page .check-ico-block','padding-top','20','','','.success-page'),(935207,'printshop','.success-page .order_totals .price-row','padding-top','5','','','.success-page'),(935208,'printshop','.success-page .page-success .text-1','padding-top','5','5333','','.success-page'),(935209,'printshop','.success-page .price-row','padding-top','5','','','.success-page'),(935210,'printshop','.success-page .totals-line','padding-top','10','','','.success-page'),(935211,'printshop','.success-page .w-cart-listing .qty','padding-top','0','','','.success-page'),(935212,'printshop','.b-multi-page-checkout .multi-page-checkout','padding-top','20','','','.b-multi-page-checkout'),(935213,'printshop','.b-multi-page-checkout .multi-page-checkout .buttons','padding-top','0','','','.b-multi-page-checkout'),(935214,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-top','20','','','.b-multi-page-checkout'),(935215,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-top','8','','','.b-multi-page-checkout'),(935216,'printshop','.tripleLine .banner-text','padding-top','0','','','.tripleLine'),(935217,'printshop','.doubleBanner .w-banner .banner-holder','padding-top','30','','','.doubleBanner'),(935218,'printshop','.doubleBanner .w-banner .banner-item','padding-top','0','','','.doubleBanner'),(935219,'printshop','.doubleBanner .w-banner .banner-text','padding-top','0','','','.doubleBanner'),(935220,'printshop','.middleBanner .banner-text-holder','padding-top','15','5363','','.middleBanner'),(935221,'printshop','.middleBanner div.banner-text-holder','padding-top','20','','','.middleBanner'),(935222,'printshop','.middleBanner div.banner-text','padding-top','0','','','.middleBanner'),(935223,'printshop','.bottomBanner .w-banner .banner-text','padding-top','0','','','.bottomBanner'),(935224,'printshop','.bottomDoubleBanner .w-banner .banner-holder','padding-top','30','','','.bottomDoubleBanner'),(935225,'printshop','.bottomDoubleBanner .w-banner .banner-text-holder','padding-top','0','','','.bottomDoubleBanner'),(935226,'printshop','.bottomDoubleBanner .w-banner .banner-text','padding-top','0','','','.bottomDoubleBanner'),(935227,'printshop','.bottomDoubleBanner .w-banner .banner-holder','padding-top','0','5363','','.bottomDoubleBanner'),(935228,'printshop','.bottomDoubleBanner .w-banner .banner-item','padding-top','0','','','.bottomDoubleBanner'),(935233,'printshop','.footer-menu .level-1 > li > .no-link','padding-top','10','5342','','.footer-menu'),(935234,'printshop','.w-bestsellers .heading-3','padding-top','7','','','.w-bestsellers'),(935235,'printshop','.w-banner .banner-text','padding-top','20','','','.w-banner'),(935236,'printshop','.w-banner .carousel-text > span','padding-top','20','','','.w-banner'),(935237,'printshop','.w-catalog-paging .paging-item','padding-top','0','','','.w-catalog-paging'),(935241,'printshop','.w-sale .holder-1','padding-top','20','','','.w-sale'),(935242,'printshop','.w-sale .holder-2','padding-top','20','','','.w-sale'),(935243,'printshop','.w-sale .left-count','padding-top','5','','','.w-sale'),(935244,'printshop','.w-sale .left-text-left','padding-top','24','','','.w-sale'),(935245,'printshop','.w-sale .left-text-right','padding-top','24','','','.w-sale'),(935246,'printshop','.w-sale .text','padding-top','10','','','.w-sale'),(935247,'printshop','.w-social-links a','padding-top','4','','','.w-social-links'),(935248,'printshop','.b-data-table table.dataTable tbody td','padding-top_important','important','','','.b-data-table'),(935249,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top_important','important','','','.b-data-table'),(935250,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top_important','important','','','.b-data-table'),(935251,'printshop','.b-data-table table.dataTable thead td','padding-top_important','important','','','.b-data-table'),(935252,'printshop','.w-cart-listing .points','padding-top_important','important','5333','','.w-cart-listing'),(935253,'printshop','.preFooter .w-banner .single_banner picture','padding-top_important','important','','','.preFooter'),(935254,'printshop','.w-account-personal-catalog .buy-box','padding-top_important','important','5333','','.w-account-personal-catalog'),(935255,'printshop','.tripleLine picture[id], .tripleLine picture[style]','padding-top_important','important','','','.tripleLine'),(935256,'printshop','.topBanner > .block','padding-top_important','important','','','.topBanner'),(935258,'printshop','.w-account-personal-catalog .buy-box','padding-top_important','important','5363','','.w-account-personal-catalog'),(935260,'printshop','.success-page .totals-line','padding-top_important','important','','','.success-page'),(935261,'printshop','.w-categories .image','padding_bottom_measure','%','','','.w-categories'),(935262,'printshop','.w-top-categories .image','padding_bottom_measure','%','','','.w-top-categories'),(935263,'printshop','.topBanner .content .btn','padding_bottom_measure','rem','','','.topBanner'),(935264,'printshop','.topBanner .ourPick .bottom','padding_bottom_measure','rem','','','.topBanner'),(935265,'printshop','.b-upload-file .upload-file-template','padding_left_measure','%','','','.b-upload-file'),(935266,'printshop','.w-cart-give-away .ga_img','padding_left_measure','%','','','.w-cart-give-away'),(935267,'printshop','.b-product-images .media-popup .mp-content','padding_left_measure','%','','','.b-product-images'),(935268,'printshop','.w-product-collection .right-area','padding_left_measure','%','','','.w-product-collection'),(935269,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding_left_measure','%','','','.w-delivery-location-featured-list'),(935270,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding_left_measure','%','5363','','.w-delivery-location-featured-list'),(935271,'printshop','.bottomBanner .icon-box > div','padding_left_measure','%','','','.bottomBanner'),(935272,'printshop','.bottomBanner .icon-box > div','padding_left_measure','%','5347','','.bottomBanner'),(935273,'printshop','.topBanner .content .btn','padding_left_measure','rem','','','.topBanner'),(935276,'printshop','.account-order-pay .history_info > div + div','padding_left_measure','%','','','.account-order-pay'),(935277,'printshop','.account-sample-info .history_info > div + div','padding_left_measure','%','','','.account-sample-info'),(935278,'printshop','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(935279,'printshop','.b-upload-file .upload-file-template','padding_right_measure','%','','','.b-upload-file'),(935280,'printshop','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(935281,'printshop','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(935282,'printshop','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(935283,'printshop','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(935284,'printshop','.w-cart-give-away .ga_img','padding_right_measure','%','','','.w-cart-give-away'),(935285,'printshop','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(935286,'printshop','.b-product-images .media-popup .mp-content','padding_right_measure','%','','','.b-product-images'),(935287,'printshop','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(935288,'printshop','.w-product-in-bundles .attributes-item','padding_right_measure','%','','','.w-product-in-bundles'),(935289,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding_right_measure','%','','','.w-delivery-location-featured-list'),(935290,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding_right_measure','%','5363','','.w-delivery-location-featured-list'),(935291,'printshop','.bottomBanner .icon-box > div','padding_right_measure','%','','','.bottomBanner'),(935292,'printshop','.bottomBanner .icon-box > div','padding_right_measure','%','5347','','.bottomBanner'),(935293,'printshop','.topBanner .content .btn','padding_right_measure','rem','','','.topBanner'),(935295,'printshop','.price .old','padding_top_measure','em','','',''),(935296,'printshop','.topBanner .content .btn','padding_top_measure','rem','','','.topBanner'),(935297,'printshop','.topBanner .ourPick .bottom','padding_top_measure','rem','','','.topBanner'),(935298,'printshop','.b-slick .slick-slide.dragging img','pointer-events','none','','','.b-slick'),(935299,'printshop','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(935300,'printshop','.w-checkout-shipping-address .addresses .address-item label','position','relative','','','.w-checkout-shipping-address'),(935301,'printshop','.b-form .radio-buttons .radio-button','position','relative','','','.b-form'),(935302,'printshop','.w-checkout-billing-address .addresses .address-item label','position','relative','','','.w-checkout-billing-address'),(935303,'printshop','.b-info .info','position','relative','3','','.b-info'),(935304,'printshop','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position','absolute','','','.b-switch'),(935305,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','position','relative','3','','.b-switch'),(935306,'printshop','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(935307,'printshop','.b-fancybox .filter-listing-preloader','position','absolute','','','.b-fancybox'),(935308,'printshop','.b-fancybox .filter-listing-loader','position','absolute','','','.b-fancybox'),(935309,'printshop','.w-promotions .prom-multi-discount > .heading','position','relative','3','','.w-promotions'),(935310,'printshop','.w-promotions .prom-multi-discount .promo-range','position','relative','','','.w-promotions'),(935311,'printshop','.w-promotions .promo-date','position','relative','','','.w-promotions'),(935316,'printshop','.p-sample-checkout-success .page-success > div','position','relative','','','.p-sample-checkout-success'),(935317,'printshop','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(935318,'printshop','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(935319,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(935320,'printshop','.testimonials .reviews-list span','position','relative','','',''),(935321,'printshop','.testimonials .heading-3','position','relative','','',''),(935322,'printshop','.testimonials .review','position','absolute','3','',''),(935323,'printshop','.testimonials .review','position','relative','','',''),(935324,'printshop','.testimonials .rating','position','relative','','',''),(935325,'printshop','.testimonials .heading-3','position','absolute','3','',''),(935326,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(935327,'printshop','.w-promotions .prom-multi-discount .products','position','relative','','','.w-promotions'),(935328,'printshop','.w-promotions .icon','position','relative','','','.w-promotions'),(935329,'printshop','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','position','relative','3','','.w-promotions'),(935330,'printshop','.w-promotions .promo-salemaker .discount','position','relative','','','.w-promotions'),(935331,'printshop','.w-promotions .promo-cart-discount .slave .content','position','relative','','','.w-promotions'),(935332,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','position','relative','','','.w-promotions'),(935333,'printshop','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','position','relative','3','','.w-promotions'),(935334,'printshop','.b-preloader .preloader','position','absolute','3','','.b-preloader'),(935335,'printshop','.b-preloader .preloader','position','absolute','','','.b-preloader'),(935336,'printshop','.w-checkout-create-account .account-benefits strong','position','relative','3','','.w-checkout-create-account'),(935337,'printshop','.w-cart-compare .cart-cell > div','position','relative','','','.w-cart-compare'),(935339,'printshop','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(935340,'printshop','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(935341,'printshop','.closeable-heading','position','absolute','3','',''),(935342,'printshop','.closeable-heading','position','relative','','',''),(935343,'printshop','.b-messages .messBtnMenuDelete','position','relative','3','','.b-messages'),(935344,'printshop','.b-messages .messMenuButton span','position','relative','','','.b-messages'),(935345,'printshop','.b-messages .messBtnMenuStarred','position','relative','3','','.b-messages'),(935346,'printshop','.b-messages span.starred::before','position','relative','','','.b-messages'),(935347,'printshop','.b-messages .messBtnMenuUnread','position','relative','3','','.b-messages'),(935348,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-messages'),(935349,'printshop','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(935350,'printshop','.b-info-popup .info-popup div','position','absolute','3','','.b-info-popup'),(935351,'printshop','.b-info .info','position','relative','','','.b-info'),(935352,'printshop','.p-payer-order-confirmation .discount-ico','position','relative','3','','.p-payer-order-confirmation'),(935353,'printshop','.w-checkout-terms .terms-box','position','relative','','','.w-checkout-terms'),(935354,'printshop','.p-payer-order-pay .discount-ico','position','relative','3','','.p-payer-order-pay'),(935355,'printshop','.w-checkout-terms .required-message-wrap','position','static','','','.w-checkout-terms'),(935356,'printshop','.w-checkout-terms input[type=\"checkbox\"]','position','relative','','','.w-checkout-terms'),(935357,'printshop','.w-checkout-shipping-address .genders-title input','position','relative','','','.w-checkout-shipping-address'),(935358,'printshop','.b-fancybox #fancybox-loading','position','fixed','','','.b-fancybox'),(935359,'printshop','.b-form .radio-button input[type=\"radio\"]','position','relative','','','.b-form'),(935360,'printshop','.b-fancybox .fancybox-wrap','position','absolute','','','.b-fancybox'),(935361,'printshop','.b-upload-file .snapshot','position','absolute','','','.b-upload-file'),(935363,'printshop','.b-rating .glyphicon','position','relative','','','.b-rating'),(935364,'printshop','.w-checkout-shipping-choice input:checked + span:before','position','absolute','','','.w-checkout-shipping-choice'),(935365,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(935366,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(935367,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-remove','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(935368,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-details','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(935369,'printshop','.b-switch .bootstrap-switch','position','relative','','','.b-switch'),(935370,'printshop','.b-info .info','position','relative','','','.b-info'),(935371,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(935372,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(935373,'printshop','.w-coupons-and-vauchers-checkout .btn-remove','position','relative','','','.w-coupons-and-vauchers-checkout'),(935374,'printshop','.b-products-listing .products-listing .radio-attributes input','position','relative','','','.b-products-listing'),(935375,'printshop','.w-checkout-bonus-points .btn-remove','position','relative','','','.w-checkout-bonus-points'),(935376,'printshop','.b-form .col-3','position','relative','','','.b-form'),(935379,'printshop','.w-menu-horizontal li','position','relative','','','.w-menu-horizontal'),(935380,'printshop','.b-info .info','position','relative','','','.b-info'),(935381,'printshop','.b-form .billing-address','position','relative','','','.b-form'),(935382,'printshop','.w-quote .cart-box-link','position','relative','','','.w-quote'),(935383,'printshop','.b-form .form-buttons','position','relative','','','.b-form'),(935384,'printshop','.b-fancybox .fancybox-title-over-wrap','position','absolute','','','.b-fancybox'),(935385,'printshop','.b-fancybox .fancybox-title-outside-wrap','position','relative','','','.b-fancybox'),(935388,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','position','absolute','','','.b-switch'),(935389,'printshop','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(935395,'printshop','.w-cart-compare .atr-col','position','relative','','','.w-cart-compare'),(935397,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','position','relative','','','.b-switch'),(935398,'printshop','.b-switch .candlestick-wrapper','position','relative','','','.b-switch'),(935399,'printshop','.b-bottom .footerTitle','position','absolute','5333,4','','.b-bottom'),(935400,'printshop','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(935401,'printshop','.b-select-suggest .select2-measure-scrollbar','position','absolute','','','.b-select-suggest'),(935402,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position','absolute','','','.b-select-suggest'),(935404,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(935405,'printshop','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(935406,'printshop','.w-reviews .review','position','relative','','','.w-reviews'),(935407,'printshop','.w-reviews .heading-3','position','relative','','','.w-reviews'),(935408,'printshop','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(935410,'printshop','.b-info-popup .info-popup div','position','absolute','','','.b-info-popup'),(935411,'printshop','.bell-ico .heading-2','position','relative','3','','.bell-ico'),(935414,'printshop','.b-select-suggest .select2-search-choice-close','position','absolute','','','.b-select-suggest'),(935415,'printshop','.view-all','position','absolute','3','',''),(935416,'printshop','.view-all','position','relative','','',''),(935417,'printshop','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(935418,'printshop','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(935419,'printshop','.view-all .btn','position','relative','','',''),(935422,'printshop','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(935424,'printshop','.b-form .checkbox-style','position','absolute','','','.b-form'),(935426,'printshop','.edit-link','position','relative','','',''),(935427,'printshop','.message.success','position','relative','3','',''),(935429,'printshop','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(935430,'printshop','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(935431,'printshop','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(935432,'printshop','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(935433,'printshop','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(935434,'printshop','.b-upload-file .upload-remove','position','absolute','','','.b-upload-file'),(935436,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','position','absolute','','','.b-switch'),(935437,'printshop','.b-info .info','position','relative','3','','.b-info'),(935439,'printshop','.w-cart-bonus-points .btn-remove','position','relative','','','.w-cart-bonus-points'),(935440,'printshop','.savings-ico .heading-2','position','relative','3','','.savings-ico'),(935441,'printshop','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(935442,'printshop','.w-multi-cart-actions .cart-actions','position','relative','','','.w-multi-cart-actions'),(935443,'printshop','.w-reviews .review','position','absolute','3','','.w-reviews'),(935444,'printshop','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(935446,'printshop','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(935447,'printshop','.b-form .addresses .address-item input[type=\"radio\"]','position','relative','','','.b-form'),(935448,'printshop','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(935449,'printshop','.w-product-reviews .reviews-list .review','position','relative','','','.w-product-reviews'),(935450,'printshop','.b-fancybox .fancybox-skin','position','relative','','','.b-fancybox'),(935451,'printshop','.b-fancybox .fancybox-overlay-fixed','position','fixed','','','.b-fancybox'),(935452,'printshop','.b-fancybox .fancybox-overlay','position','absolute','','','.b-fancybox'),(935453,'printshop','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(935456,'printshop','.b-pass-strength .pass-strength span','position','absolute','','','.b-pass-strength'),(935458,'printshop','.b-fancybox .fancybox-nav','position','absolute','','','.b-fancybox'),(935459,'printshop','.b-info .info','position','relative','3','','.b-info'),(935460,'printshop','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(935461,'printshop','.w-promo-code .holder','position','relative','','','.w-promo-code'),(935462,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(935463,'printshop','.b-form .shipping-method .input input','position','relative','','','.b-form'),(935464,'printshop','.w-reviews .heading-3','position','absolute','3','','.w-reviews'),(935465,'printshop','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(935466,'printshop','.b-select-suggest .select2-container .select2-choice','position','relative','','','.b-select-suggest'),(935467,'printshop','.b-select-suggest .select2-container','position','relative','','','.b-select-suggest'),(935468,'printshop','.b-info .info','position','relative','3','','.b-info'),(935469,'printshop','.b-info .info','position','relative','','','.b-info'),(935470,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','position','relative','3','','.b-switch'),(935471,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','position','relative','3','','.b-switch'),(935473,'printshop','.b-form .hide-billing-address','position','absolute','','','.b-form'),(935474,'printshop','.b-form .radio-button input[type=\"radio\"].no','position','absolute','','','.b-form'),(935475,'printshop','.b-form .payment-method .item-radio input','position','relative','','','.b-form'),(935476,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(935477,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(935478,'printshop','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(935479,'printshop','.w-reviews-content .review','position','absolute','3','','.w-reviews-content'),(935481,'printshop','.p-quick-order-index .all-scroll-div','position','fixed','','','.p-quick-order-index'),(935482,'printshop','.w-checkout-billing-address .genders-title input','position','relative','','','.w-checkout-billing-address'),(935483,'printshop','.b-form .required-message-wrap','position','relative','','','.b-form'),(935484,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','position','relative','3','','.b-form'),(935485,'printshop','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(935486,'printshop','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(935487,'printshop','.w-promotions .promo-cart-discount .slave .condition','position','relative','','','.w-promotions'),(935488,'printshop','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(935489,'printshop','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(935491,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(935492,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','position','static','','','.w-contact-contacts'),(935493,'printshop','.w-checkout-credit-amount .btn-remove','position','relative','','','.w-checkout-credit-amount'),(935495,'printshop','.w-promo-code .holder','position','relative','','','.w-promo-code'),(935496,'printshop','.b-info-popup .info-popup','position','relative','3','','.b-info-popup'),(935497,'printshop','.b-autocomplete .ui-autocomplete','position','absolute','','','.b-autocomplete'),(935498,'printshop','.b-info .info','position','relative','','','.b-info'),(935499,'printshop','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(935500,'printshop','.b-bottom .footerTitle','position','relative','5333','','.b-bottom'),(935501,'printshop','.b-info-popup .info-popup','position','relative','','','.b-info-popup'),(935502,'printshop','.b-upload-files .attach-active-holder .attach-file','position','absolute','','','.b-upload-files'),(935504,'printshop','.w-cart-credit-amount .btn-remove','position','relative','','','.w-cart-credit-amount'),(935505,'printshop','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(935506,'printshop','.b-fancybox .fancybox-close','position','absolute','','','.b-fancybox'),(935507,'printshop','.b-form .required-message','position','absolute','','','.b-form'),(935508,'printshop','.b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner','position','relative','','','.b-fancybox'),(935509,'printshop','.w-product-customers-activity .customers-activity','position','fixed','','','.w-product-customers-activity'),(935510,'printshop','.w-product-customers-activity .close','position','absolute','','','.w-product-customers-activity'),(935513,'printshop','.w-cart-compare .remove-cart','position','absolute','','','.w-cart-compare'),(935514,'printshop','.w-promo-code .holder','position','relative','','','.w-promo-code'),(935515,'printshop','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(935517,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(935518,'printshop','.w-checkout-billing-address .addresses .address-item label input','position','absolute','','','.w-checkout-billing-address'),(935519,'printshop','.w-checkout-shipping-choice input:checked + span','position','relative','','','.w-checkout-shipping-choice'),(935520,'printshop','.w-checkout-shipping-choice input','position','absolute','','','.w-checkout-shipping-choice'),(935522,'printshop','.w-quote .cart-box','position','relative','','','.w-quote'),(935523,'printshop','.w-product-reviews .reviews-list span','position','relative','','','.w-product-reviews'),(935524,'printshop','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(935525,'printshop','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(935526,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-select-suggest'),(935527,'printshop','.b-select-suggest .select2-container-multi .select2-choices','position','relative','','','.b-select-suggest'),(935528,'printshop','.b-select-suggest .select2-results','position','relative','','','.b-select-suggest'),(935529,'printshop','.w-image-maps .svg-wrap svg','position','absolute','','','.w-image-maps'),(935530,'printshop','.w-checkout-shipping-address .addresses .address-item label input','position','absolute','','','.w-checkout-shipping-address'),(935531,'printshop','.w-neighbour-checkout .bootstrap-switch','position','relative','','','.w-neighbour-checkout'),(935532,'printshop','.b-select-suggest .select2-search','position','relative','','','.b-select-suggest'),(935533,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow','position','absolute','','','.b-select-suggest'),(935534,'printshop','.b-select-suggest .select2-drop','position','absolute','','','.b-select-suggest'),(935535,'printshop','.b-select-suggest .select2-drop-mask','position','fixed','','','.b-select-suggest'),(935536,'printshop','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(935542,'printshop','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(935544,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','position','absolute','','','.b-switch'),(935545,'printshop','.b-pass-strength .pass-strength','position','relative','','','.b-pass-strength'),(935546,'printshop','.p-sample-checkout-success .page-success','position','relative','','','.p-sample-checkout-success'),(935547,'printshop','.w-menu-big li','position','static','','','.w-menu-big'),(935548,'printshop','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(935549,'printshop','.w-promo-code .holder','position','relative','','','.w-promo-code'),(935550,'printshop','.w-account-addresses-list .address-fields input[type=\"radio\"]','position','relative','','','.w-account-addresses-list'),(935551,'printshop','.b-products-listing .products-listing .promos-info','position','absolute','','','.b-products-listing'),(935552,'printshop','.b-products-listing .products-listing .image','position','relative','','','.b-products-listing'),(935553,'printshop','.b-products-listing .hover-box-content','position','absolute','3','','.b-products-listing'),(935554,'printshop','.b-products-listing .hover-box','position','relative','','','.b-products-listing'),(935555,'printshop','.b-products-listing .hover-box-content','position','absolute','','','.b-products-listing'),(935556,'printshop','.b-products-listing .loader','position','absolute','4','','.b-products-listing'),(935557,'printshop','.b-products-listing .loader','position','absolute','3','','.b-products-listing'),(935558,'printshop','.b-products-listing .loader','position','relative','','','.b-products-listing'),(935559,'printshop','.w-catalog-b2b-add-button ','position','fixed','','','.w-catalog-b2b-add-button'),(935560,'printshop','.b-products-listing .products-listing .qty-input.hidden','position','absolute','3','','.b-products-listing'),(935561,'printshop','.b-products-listing .promo','position','absolute','','','.b-products-listing'),(935562,'printshop','.b-products-listing .promo-icon','position','relative','','','.b-products-listing'),(935563,'printshop','.b-products-listing .promos-info','position','relative','','','.b-products-listing'),(935564,'printshop','.checkbox input:not(checked) + span:before','position','absolute','','',''),(935565,'printshop','.checkbox input','position','ablolute','','',''),(935570,'printshop','.w-promo-code .holder','position','relative','','','.w-promo-code'),(935571,'printshop','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(935572,'printshop','.b-form .hide-box','position','relative','','','.b-form'),(935573,'printshop','.b-info .info','position','relative','','','.b-info'),(935574,'printshop','.b-fancybox .fancybox-title','position','relative','','','.b-fancybox'),(935575,'printshop','.b-fancybox .fancybox-title-float-wrap','position','absolute','','','.b-fancybox'),(935577,'printshop','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(935578,'printshop','.w-taxable input[type=\"radio\"]','position','relative','','','.w-taxable'),(935579,'printshop','.b-form .eye-password-wrap','position','relative','','','.b-form'),(935580,'printshop','.b-form .eye-password','position','absolute','','','.b-form'),(935581,'printshop','.w-taxable input[type=\"checkbox\"]','position','relative','','','.w-taxable'),(935582,'printshop','.b-info .info','position','relative','3','','.b-info'),(935583,'printshop','.b-fancybox .fancybox-tmp','position','absolute','','','.b-fancybox'),(935584,'printshop','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(935585,'printshop','.b-datepicker .datepicker-dropdown','position','absolute','','','.b-datepicker'),(935588,'printshop','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(935589,'printshop','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(935590,'printshop','.b-info .info','position','relative','3','','.b-info'),(935591,'printshop','.b-form .columns .col-2','position','relative','','','.b-form'),(935592,'printshop','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','position','relative','3','','.order-summary'),(935593,'printshop','.w-cart-compare .atr-col','position','absolute','3','','.w-cart-compare'),(935594,'printshop','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(935595,'printshop','.w-promo-code .holder','position','relative','','','.w-promo-code'),(935596,'printshop','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(935597,'printshop','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(935598,'printshop','.w-menu-horizontal ul ul','position','absolute','','','.w-menu-horizontal'),(935599,'printshop','.w-cart-listing .item .gift-wrap label','position','relative','','','.w-cart-listing'),(935600,'printshop','.w-cart-discount-coupon .btn-remove','position','relative','','','.w-cart-discount-coupon'),(935605,'printshop','.w-image-maps .svg-wrap','position','relative','','','.w-image-maps'),(935606,'printshop','.b-fancybox .fancybox-nav span','position','absolute','','','.b-fancybox'),(935607,'printshop','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(935609,'printshop','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(935610,'printshop','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(935612,'printshop','.w-product-reviews .reviews-list .review','position','absolute','3','','.w-product-reviews'),(935613,'printshop','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(935614,'printshop','.w-filters .input-checkbox','position','absolute','','','.w-filters'),(935615,'printshop','.w-filters .head-filter-widget','position','relative','','','.w-filters'),(935616,'printshop','.b-bottom .pop-up-close','position','absolute','','','.b-bottom'),(935617,'printshop','.w-reviews-content .review','position','relative','','','.w-reviews-content'),(935619,'printshop','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(935620,'printshop','.b-form .same-address','position','relative','','','.b-form'),(935623,'printshop','.w-menu-big ','position','relative','','','.w-menu-big'),(935624,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','position','relative','3','','.w-contact-contacts'),(935628,'printshop','.w-menu-big > ul > li > ul','position','absolute','','','.w-menu-big'),(935629,'printshop','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(935630,'printshop','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(935631,'printshop','.b-select-suggest .select2-container .select2-choice abbr','position','absolute','','','.b-select-suggest'),(935632,'printshop','.w-filters .mobileCollapse','position','absolute','','','.w-filters'),(935633,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','position','fixed','','','.w-image-maps'),(935634,'printshop','.b-product-images .media-popup .mp-close','position','absolute','','','.b-product-images'),(935635,'printshop','.b-product-images .mp-shadow, .b-product-images .media-popup','position','fixed','','','.b-product-images'),(935636,'printshop','.b-menu-burger_icon .menu-style[data-burger_icon]','position','relative','','','.b-menu-burger_icon'),(935637,'printshop','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-1 > li','position','relative','','','.b-menu-lev_display-down'),(935638,'printshop','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','position','absolute','','','.b-menu-lev_display-down'),(935639,'printshop','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-2 > li','position','relative','','','.b-menu-lev_display-down'),(935640,'printshop','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','position','absolute','','','.b-menu-lev_display-down'),(935641,'printshop','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-3 > li','position','relative','','','.b-menu-lev_display-down'),(935642,'printshop','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','position','absolute','','','.b-menu-lev_display-down'),(935643,'printshop','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-4 > li','position','relative','','','.b-menu-lev_display-down'),(935644,'printshop','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','position','absolute','','','.b-menu-lev_display-down'),(935645,'printshop','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-5 > li','position','relative','','','.b-menu-lev_display-down'),(935646,'printshop','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','position','absolute','','','.b-menu-lev_display-down'),(935647,'printshop','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-1 > li','position','relative','','','.b-menu-lev_display-left'),(935648,'printshop','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','position','absolute','','','.b-menu-lev_display-left'),(935649,'printshop','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-2 > li','position','relative','','','.b-menu-lev_display-left'),(935650,'printshop','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','position','absolute','','','.b-menu-lev_display-left'),(935651,'printshop','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-3 > li','position','relative','','','.b-menu-lev_display-left'),(935652,'printshop','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','position','absolute','','','.b-menu-lev_display-left'),(935653,'printshop','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-4 > li','position','relative','','','.b-menu-lev_display-left'),(935654,'printshop','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','position','absolute','','','.b-menu-lev_display-left'),(935655,'printshop','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-5 > li','position','relative','','','.b-menu-lev_display-left'),(935656,'printshop','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','position','absolute','','','.b-menu-lev_display-left'),(935657,'printshop','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-1 > li','position','relative','','','.b-menu-lev_display-lra'),(935658,'printshop','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','position','absolute','','','.b-menu-lev_display-lra'),(935659,'printshop','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-2 > li','position','relative','','','.b-menu-lev_display-lra'),(935660,'printshop','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','position','absolute','','','.b-menu-lev_display-lra'),(935661,'printshop','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-3 > li','position','relative','','','.b-menu-lev_display-lra'),(935662,'printshop','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','position','absolute','','','.b-menu-lev_display-lra'),(935663,'printshop','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-4 > li','position','relative','','','.b-menu-lev_display-lra'),(935664,'printshop','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','position','absolute','','','.b-menu-lev_display-lra'),(935665,'printshop','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-5 > li','position','relative','','','.b-menu-lev_display-lra'),(935666,'printshop','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','position','absolute','','','.b-menu-lev_display-lra'),(935667,'printshop','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right'),(935668,'printshop','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','position','absolute','','','.b-menu-lev_display-right'),(935669,'printshop','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right'),(935670,'printshop','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','position','absolute','','','.b-menu-lev_display-right'),(935671,'printshop','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right'),(935672,'printshop','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','position','absolute','','','.b-menu-lev_display-right'),(935673,'printshop','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right'),(935674,'printshop','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','position','absolute','','','.b-menu-lev_display-right'),(935675,'printshop','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right'),(935676,'printshop','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','position','absolute','','','.b-menu-lev_display-right'),(935677,'printshop','.b-menu-lev_display-right_top .menu-style[data-lev2_display=\"right_top\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right_top'),(935678,'printshop','.b-menu-lev_display-right_top .menu-style[data-lev3_display=\"right_top\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right_top'),(935679,'printshop','.b-menu-lev_display-right_top .menu-style[data-lev4_display=\"right_top\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right_top'),(935680,'printshop','.b-menu-lev_display-right_top .menu-style[data-lev5_display=\"right_top\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right_top'),(935681,'printshop','.b-menu-lev_display-right_top .menu-style[data-lev6_display=\"right_top\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right_top'),(935682,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .level-1','position','relative','','','.b-menu-lev_display-slide'),(935683,'printshop','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] .level-2','position','relative','','','.b-menu-lev_display-slide'),(935684,'printshop','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','position','absolute','','','.b-menu-lev_display-slide'),(935685,'printshop','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] .level-3','position','relative','','','.b-menu-lev_display-slide'),(935686,'printshop','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','position','absolute','','','.b-menu-lev_display-slide'),(935687,'printshop','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] .level-4','position','relative','','','.b-menu-lev_display-slide'),(935688,'printshop','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','position','absolute','','','.b-menu-lev_display-slide'),(935689,'printshop','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] .level-5','position','relative','','','.b-menu-lev_display-slide'),(935690,'printshop','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','position','absolute','','','.b-menu-lev_display-slide'),(935691,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','position','absolute','','','.b-menu-lev_display-slide'),(935692,'printshop','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width'),(935693,'printshop','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','position','absolute','','','.b-menu-lev_display-width'),(935694,'printshop','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width'),(935695,'printshop','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','position','absolute','','','.b-menu-lev_display-width'),(935696,'printshop','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width'),(935697,'printshop','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','position','absolute','','','.b-menu-lev_display-width'),(935698,'printshop','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width'),(935699,'printshop','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','position','absolute','','','.b-menu-lev_display-width'),(935700,'printshop','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width'),(935701,'printshop','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','position','absolute','','','.b-menu-lev_display-width'),(935702,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width_cont'),(935703,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','position','absolute','','','.b-menu-lev_display-width_cont'),(935704,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width_cont'),(935705,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','position','absolute','','','.b-menu-lev_display-width_cont'),(935706,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width_cont'),(935707,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','position','absolute','','','.b-menu-lev_display-width_cont'),(935708,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width_cont'),(935709,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','position','absolute','','','.b-menu-lev_display-width_cont'),(935710,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width_cont'),(935711,'printshop','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','position','absolute','','','.b-menu-lev_display-width_cont'),(935712,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(935713,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(935714,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(935715,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(935716,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(935717,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','position','fixed','','','.b-menu-open_from-left'),(935718,'printshop','.w-catalog-compare .compare .checkbox span','position','relative','','','.w-catalog-compare'),(935719,'printshop','.tripleBanner .w-html_box','position','relative','','','.tripleBanner'),(935720,'printshop','.tripleBanner .w-html_box','position','absolute','3','','.tripleBanner'),(935721,'printshop','.preFooter .w-banner .single_banner picture img','position','static','','','.preFooter'),(935722,'printshop','.b-slick .slick-list','position','relative','','','.b-slick'),(935723,'printshop','.b-slick .slick-slider','position','relative','','','.b-slick'),(935724,'printshop','.b-slick .slick-track','position','relative','','','.b-slick'),(935725,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','position','absolute','','','.b-slick'),(935726,'printshop','.menu-header ','position','relative','5342','','.menu-header'),(935727,'printshop','.menu-header .w-menu','position','absolute','5342','','.menu-header'),(935729,'printshop','.header','position','fixed','5342','',''),(935730,'printshop','.b-products-listing .products-listing .compare .checkbox input:not(checked) + span:before','position','static','','','.b-products-listing'),(935731,'printshop','.w-quote .multicart .item','position','relative','','','.w-quote'),(935732,'printshop','.w-quote .multicart .switch-cart','position','absolute','','','.w-quote'),(935734,'printshop','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(935735,'printshop','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(935736,'printshop','.warrantyProduct .warranty, .warrantyProduct .delivery','position','relative','','','.warrantyProduct'),(935737,'printshop','.warrantyProduct .warranty','position','absolute','3','','.warrantyProduct'),(935738,'printshop','.warrantyProduct .delivery','position','absolute','3','','.warrantyProduct'),(935739,'printshop','.w-compare ','position','fixed','','','.w-compare'),(935740,'printshop','.w-compare .item-holder','position','relative','','','.w-compare'),(935741,'printshop','.w-compare .remove','position','absolute','','','.w-compare'),(935742,'printshop','.w-files-catalog-widgets-files-list .file','position','relative','3','','.w-files-catalog-widgets-files-list'),(935743,'printshop','.w-sample .cart-box','position','relative','','','.w-sample'),(935744,'printshop','.w-sample .cart-box-link','position','relative','','','.w-sample'),(935745,'printshop','.w-sample .multicart .item','position','relative','','','.w-sample'),(935746,'printshop','.w-sample .multicart .switch-cart','position','absolute','','','.w-sample'),(935747,'printshop','.w-sample .qty','position','relative','4','','.w-sample'),(935748,'printshop','.w-quote .cart-box.hover-box .cart-content','position','absolute','','','.w-quote'),(935749,'printshop','.w-sample .cart-box .cart-content','position','absolute','','','.w-sample'),(935750,'printshop','.w-cart-listing .points-earn','position','relative','','','.w-cart-listing'),(935751,'printshop','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(935752,'printshop','.w-product-inventory input[type=\"radio\"]','position','relative','','','.w-product-inventory'),(935754,'printshop','.w-product-properties-filters-widgets-chosen-filters .remove','position','relative','3','','.w-product-properties-filters-widgets-chosen-filters'),(935755,'printshop','.p-sample-checkout-index .order-summary .heading-2','position','relative','3','','.p-sample-checkout-index'),(935756,'printshop','.p-sample-checkout-index .order-summary .heading-2','position','relative','4','','.p-sample-checkout-index'),(935757,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','position','relative','','','.w-account-personal-catalog'),(935758,'printshop','.w-account-personal-catalog .list-row-action ul','position','relative','','','.w-account-personal-catalog'),(935759,'printshop','.w-account-personal-catalog .list-row-action ul','position','absolute','4','','.w-account-personal-catalog'),(935760,'printshop','.w-account-personal-catalog .checkbox input:not(checked) + span:before','position','static','','','.w-account-personal-catalog'),(935761,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input','position','absolute','','','.w-questionnaire-widgets-questionnaire'),(935762,'printshop','.w-product-groups .radioBox label','position','relative','','','.w-product-groups'),(935763,'printshop','.w-product-groups .radioBox label input','position','absolute','','','.w-product-groups'),(935764,'printshop','.w-sale-category .badge','position','absolute','','','.w-sale-category'),(935765,'printshop','.w-sale-category .sale-holder','position','relative','','','.w-sale-category'),(935766,'printshop','.w-product-bonus-points .bonus-points-cost','position','relative','','','.w-product-bonus-points'),(935767,'printshop','.w-product-bonus-points > div > div','position','absolute','3','','.w-product-bonus-points'),(935768,'printshop','.w-product-designer-designer .prodDesignerType label','position','relative','','','.w-product-designer-designer'),(935769,'printshop','.w-product-designer-designer .productDesignerBox input','position','absolute','','','.w-product-designer-designer'),(935770,'printshop','.w-press-reviews-widgets-press-reviews .review','position','relative','','','.w-press-reviews-widgets-press-reviews'),(935771,'printshop','.w-support-system-listing .support-head','position','relative','','','.w-support-system-listing'),(935772,'printshop','.w-product-configurator .pc-item label','position','relative','','','.w-product-configurator'),(935773,'printshop','.w-product-configurator .pc-item label input','position','absolute','','','.w-product-configurator'),(935774,'printshop','.b-products-listing .products-listing .bonus-points-cost','position','absolute','3','','.b-products-listing'),(935775,'printshop','.b-products-listing .products-listing .bonus-points-cost','position','relative','','','.b-products-listing'),(935776,'printshop','.w-predefined-promotion .icon','position','relative','','','.w-predefined-promotion'),(935777,'printshop','.w-predefined-promotion .prom-multi-discount .products','position','relative','','','.w-predefined-promotion'),(935778,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','position','relative','','','.w-predefined-promotion'),(935779,'printshop','.w-predefined-promotion .prom-multi-discount > .heading','position','relative','3','','.w-predefined-promotion'),(935780,'printshop','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','position','relative','3','','.w-predefined-promotion'),(935781,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','position','relative','','','.w-predefined-promotion'),(935782,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition','position','relative','','','.w-predefined-promotion'),(935783,'printshop','.w-predefined-promotion .promo-cart-discount .slave .content','position','relative','','','.w-predefined-promotion'),(935784,'printshop','.w-predefined-promotion .promo-date','position','relative','','','.w-predefined-promotion'),(935785,'printshop','.w-predefined-promotion .promo-salemaker .discount','position','relative','','','.w-predefined-promotion'),(935786,'printshop','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','position','relative','3','','.w-predefined-promotion'),(935790,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','position','absolute','','','.w-filters'),(935791,'printshop','.w-cart-listing .headings','position','relative','','','.w-cart-listing'),(935792,'printshop','.w-cart-listing .item','position','relative','','','.w-cart-listing'),(935793,'printshop','.tripleLine picture[id] > img, .tripleLine picture[style] > img','position','static','','','.tripleLine'),(935794,'printshop','.cartTitle >div','position','relative','','','.cartTitle'),(935795,'printshop','.p-wedding-registry-view h1','position','relative','3','','.p-wedding-registry-view'),(935796,'printshop','.p-wedding-registry-view h1','position','relative','4','','.p-wedding-registry-view'),(935797,'printshop','.tripleLine .w-banner .image-text-banner .text-banner','position','static','','','.tripleLine'),(935798,'printshop','.b-menu-open_from-top .menu-style[data-open_from=\"top\"] .menu-content','position','fixed','','','.b-menu-open_from-top'),(935799,'printshop','.topBanner .ourPick','position','absolute','3','','.topBanner'),(935800,'printshop','.topBanner .ourPick','position','absolute','4','','.topBanner'),(935801,'printshop','.topBanner .ourPick','position','relative','','','.topBanner'),(935802,'printshop','.topBanner .ourPick','position','absolute','5347,4','','.topBanner'),(935803,'printshop','.topBanner .w-banner .banner-item','position','relative','','','.topBanner'),(935804,'printshop','.topBanner .w-banner .banner-item .banner-text','position','absolute','','','.topBanner'),(935805,'printshop','.order-summary .icon','position','relative','','','.order-summary'),(935806,'printshop','.order-summary .icon','position','absolute','3','','.order-summary'),(935807,'printshop','.w-cart-discount-coupon .title','position','relative','','','.w-cart-discount-coupon'),(935836,'printshop','.account-order-pay .account_history_info.account_history_info_due','position','relative','','','.account-order-pay'),(935837,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','position','relative','','','.account-order-pay'),(935838,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','position','absolute','3','','.account-order-pay'),(935839,'printshop','.account-order-pay .not_fully_paid_td','position','absolute','','','.account-order-pay'),(935840,'printshop','.account-samples .moduleRowDue td','position','relative','','','.account-samples'),(935841,'printshop','.account-samples .not_fully_paid_td','position','absolute','','','.account-samples'),(935842,'printshop','.account-samples .view_link','position','relative','','','.account-samples'),(935843,'printshop','.account-samples .view_link','position','absolute','4','','.account-samples'),(935844,'printshop','.account-samples .orders-table .item','position','relative','5342','','.account-samples'),(935845,'printshop','.account-samples .orders-table .order-total','position','absolute','5342','','.account-samples'),(935846,'printshop','.account-samples .orders-table .status-name','position','absolute','5342','','.account-samples'),(935847,'printshop','.account-samples .orders-table .td-alignright','position','absolute','5342','','.account-samples'),(935848,'printshop','.account-sample-info .account_history_info.account_history_info_due','position','relative','','','.account-sample-info'),(935849,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','position','relative','','','.account-sample-info'),(935850,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','position','absolute','3','','.account-sample-info'),(935851,'printshop','.account-sample-info .not_fully_paid_td','position','absolute','','','.account-sample-info'),(935852,'printshop','.catalog-product-wrap .pn-image','position','absolute','3','','.catalog-product-wrap'),(935853,'printshop','.catalog-product-wrap .prev-next-product','position','fixed','','','.catalog-product-wrap'),(935854,'printshop','.shopping-cart-index .gift-code .heading-4','position','absolute','4','','.shopping-cart-index'),(935855,'printshop','.shopping-cart-index .gift-code .heading-4','position','relative','5333','','.shopping-cart-index'),(935856,'printshop','.checkout-order-confirmation .discount-ico','position','relative','3','','.checkout-order-confirmation'),(935857,'printshop','.checkout-success-wrap .page-success','position','relative','','','.checkout-success-wrap'),(935858,'printshop','.checkout-success-wrap .page-success > div','position','relative','','','.checkout-success-wrap'),(935859,'printshop','.b-form .addresses .address-item','position','relative','','','.b-form'),(935860,'printshop','.hide-page','position','fixed','','',''),(935861,'printshop','.success-page .comment-ico','position','relative','3','','.success-page'),(935862,'printshop','.success-page .discount-ico','position','relative','3','','.success-page'),(935863,'printshop','.success-page .order-ico','position','relative','3','','.success-page'),(935864,'printshop','.success-page .page-success','position','relative','','','.success-page'),(935865,'printshop','.success-page .page-success .text-1','position','relative','','','.success-page'),(935866,'printshop','.success-page .page-success > div','position','relative','','','.success-page'),(935867,'printshop','.success-page .w-cart-listing .qty','position','relative','','','.success-page'),(935868,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','position','relative','4','','.b-multi-page-checkout'),(935871,'printshop','.footer-menu .level-1 > li','position','relative','5342','','.footer-menu'),(935872,'printshop','.footer-menu .level-1 > li','position','absolute','5342,3','','.footer-menu'),(935873,'printshop','.w-bestsellers .counter','position','relative','','','.w-bestsellers'),(935874,'printshop','.w-bestsellers .heading-3','position','absolute','3','','.w-bestsellers'),(935875,'printshop','.w-bestsellers .heading-3','position','relative','','','.w-bestsellers'),(935876,'printshop','.w-bestsellers .item','position','absolute','3','','.w-bestsellers'),(935877,'printshop','.w-bestsellers .item','position','relative','','','.w-bestsellers'),(935878,'printshop','.w-banner .banner','position','relative','','','.w-banner'),(935879,'printshop','.w-banner .banner img + img','position','absolute','','','.w-banner'),(935880,'printshop','.w-banner .carousel .item','position','relative','','','.w-banner'),(935881,'printshop','.w-banner .carousel-text','position','absolute','','','.w-banner'),(935882,'printshop','.w-banner .image-text-banner','position','relative','','','.w-banner'),(935883,'printshop','.w-banner .image-text-banner .text-banner','position','absolute','','','.w-banner'),(935884,'printshop','.w-catalog-paging .paging-holder','position','relative','','','.w-catalog-paging'),(935885,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','position','static','','','.w-catalog-paging'),(935890,'printshop','.w-sale .badge','position','absolute','','','.w-sale'),(935891,'printshop','.w-sale .sale-holder','position','relative','','','.w-sale'),(935892,'printshop','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position_important','important','','','.b-switch'),(935894,'printshop','.b-autocomplete .ui-autocomplete','position_important','important','','','.b-autocomplete'),(935897,'printshop','.w-checkout-billing-address .addresses .address-item label input','position_important','important','','','.w-checkout-billing-address'),(935898,'printshop','.w-checkout-shipping-address .addresses .address-item label input','position_important','important','','','.w-checkout-shipping-address'),(935900,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position_important','important','','','.b-select-suggest'),(935903,'printshop','.w-socials .post_item > div','right','10','3','','.w-socials'),(935905,'printshop','.b-upload-file .snapshot','right','5','','','.b-upload-file'),(935906,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-remove','right','5','','','.w-upload-customer-id-upload-customer-id-form'),(935907,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','right','0','','','.b-switch'),(935908,'printshop','.w-cart-compare .dropdown .dropdown-menu','right','0','','','.w-cart-compare'),(935909,'printshop','.closeable-heading','right','0','3','',''),(935910,'printshop','.b-bottom .footerTitle','right','0','5333,4','','.b-bottom'),(935911,'printshop','.w-socials .post_item > div','right','10','3','','.w-socials'),(935912,'printshop','.b-info-popup .info-popup.top-left div','right','13','3','','.b-info-popup'),(935914,'printshop','.w-socials .post_item > div','right','10','3','','.w-socials'),(935915,'printshop','.w-socials .post_item > div','right','10','3','','.w-socials'),(935916,'printshop','.w-cart-compare .atr-col','right','0','3','','.w-cart-compare'),(935917,'printshop','.w-multi-cart-actions .dropdown .dropdown-menu','right','auto','','','.w-multi-cart-actions'),(935918,'printshop','.w-socials .post_item > div','right','10','3','','.w-socials'),(935919,'printshop','.b-pass-strength .pass-strength span','right','25','','','.b-pass-strength'),(935920,'printshop','.b-info-popup .info-popup.top-left div','right','-10','','','.b-info-popup'),(935921,'printshop','.b-fancybox .fancybox-overlay-fixed','right','0','','','.b-fancybox'),(935922,'printshop','.w-cart-compare .remove-cart','right','0','','','.w-cart-compare'),(935923,'printshop','.b-fancybox .fancybox-close','right','10','','','.b-fancybox'),(935924,'printshop','.b-fancybox .fancybox-next','right','0','','','.b-fancybox'),(935925,'printshop','.b-fancybox .fancybox-next span','right','10','','','.b-fancybox'),(935926,'printshop','.w-product-customers-activity .customers-activity','right','20','','','.w-product-customers-activity'),(935927,'printshop','.w-product-customers-activity .close','right','5','','','.w-product-customers-activity'),(935928,'printshop','.b-select-suggest .select2-search-choice-close','right','3','','','.b-select-suggest'),(935929,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow','right','0','','','.b-select-suggest'),(935931,'printshop','.b-fancybox .fancybox-title-float-wrap','right','50','','','.b-fancybox'),(935932,'printshop','.b-form .eye-password','right','5','','','.b-form'),(935934,'printshop','.b-upload-file .upload-remove','right','10','','','.b-upload-file'),(935935,'printshop','.w-socials .post_item > div','right','10','3','','.w-socials'),(935936,'printshop','.b-bottom .pop-up-close','right','6','','','.b-bottom'),(935937,'printshop','.w-menu-big > ul > li > ul','right','0','','','.w-menu-big'),(935938,'printshop','.b-select-suggest .select2-container .select2-choice abbr','right','24','','','.b-select-suggest'),(935939,'printshop','.w-filters .mobileCollapse','right','12','','','.w-filters'),(935940,'printshop','.b-product-images .media-popup .mp-close','right','20','','','.b-product-images'),(935941,'printshop','.b-product-images .mp-shadow, .b-product-images .media-popup','right','0','','','.b-product-images'),(935942,'printshop','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right','100','','','.b-menu-lev_display-left'),(935943,'printshop','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right','100','','','.b-menu-lev_display-left'),(935944,'printshop','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right','100','','','.b-menu-lev_display-left'),(935945,'printshop','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right','100','','','.b-menu-lev_display-left'),(935946,'printshop','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right','100','','','.b-menu-lev_display-left'),(935947,'printshop','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right','100','','','.b-menu-lev_display-lra'),(935948,'printshop','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right','100','','','.b-menu-lev_display-lra'),(935949,'printshop','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right','100','','','.b-menu-lev_display-lra'),(935950,'printshop','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right','100','','','.b-menu-lev_display-lra'),(935951,'printshop','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right','100','','','.b-menu-lev_display-lra'),(935952,'printshop','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','right','auto','','','.b-slick'),(935953,'printshop','.b-slick button.slick-next','right','0','','','.b-slick'),(935954,'printshop','.b-slick button.slick-prev','right','auto','','','.b-slick'),(935955,'printshop','.menu-header .w-menu','right','10','5342','','.menu-header'),(935956,'printshop','.header','right','0','5342','',''),(935957,'printshop','.w-compare ','right','0','','','.w-compare'),(935958,'printshop','.w-compare .remove','right','20','','','.w-compare'),(935959,'printshop','.p-sample-checkout-index .order-summary .heading-2','right','-14','4','','.p-sample-checkout-index'),(935960,'printshop','.w-account-personal-catalog .list-row-action ul','right','7','4','','.w-account-personal-catalog'),(935961,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','right','-100','','','.w-product-properties-icons'),(935962,'printshop','.w-product-bonus-points .bonus-points-cost','right','-14','5363,4','','.w-product-bonus-points'),(935964,'printshop','.p-wedding-registry-view h1','right','-10','4','','.p-wedding-registry-view'),(935965,'printshop','.topBanner .ourPick','right','-18','4','','.topBanner'),(935966,'printshop','.topBanner .ourPick','right','-14','5347,4','','.topBanner'),(935967,'printshop','.topBanner .ourPick','right','-9','5363,4','','.topBanner'),(935968,'printshop','.order-summary .icon','right','0','3','','.order-summary'),(935971,'printshop','.account-samples .orders-table .order-total','right','0','5342','','.account-samples'),(935972,'printshop','.catalog-product-wrap .next-product','right','0','','','.catalog-product-wrap'),(935973,'printshop','.catalog-product-wrap .next-product .pn-image','right','20','3','','.catalog-product-wrap'),(935974,'printshop','.catalog-product-wrap button.slick-next','right','-10','','','.catalog-product-wrap'),(935975,'printshop','.shopping-cart-index .gift-code .heading-4','right','0','4','','.shopping-cart-index'),(935976,'printshop','.footer-menu .level-1 > li','right','10','5342,3','','.footer-menu'),(935977,'printshop','.w-banner .image-text-banner.bottom-right .text-banner','right','0','','','.w-banner'),(935978,'printshop','.w-banner .image-text-banner.middle-right .text-banner','right','0','','','.w-banner'),(935979,'printshop','.w-banner .image-text-banner.top-right .text-banner','right','0','','','.w-banner'),(935982,'printshop','.b-fancybox .fancybox-title-float-wrap','right_measure','%','','','.b-fancybox'),(935983,'printshop','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right_measure','%','','','.b-menu-lev_display-left'),(935984,'printshop','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right_measure','%','','','.b-menu-lev_display-left'),(935985,'printshop','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right_measure','%','','','.b-menu-lev_display-left'),(935986,'printshop','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right_measure','%','','','.b-menu-lev_display-left'),(935987,'printshop','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right_measure','%','','','.b-menu-lev_display-left'),(935988,'printshop','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right_measure','%','','','.b-menu-lev_display-lra'),(935989,'printshop','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right_measure','%','','','.b-menu-lev_display-lra'),(935990,'printshop','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right_measure','%','','','.b-menu-lev_display-lra'),(935991,'printshop','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right_measure','%','','','.b-menu-lev_display-lra'),(935992,'printshop','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right_measure','%','','','.b-menu-lev_display-lra'),(935993,'printshop','.b-info-popup .info-popup.top-left div','rotate','-135','3','','.b-info-popup'),(935994,'printshop','.w-checkout-shipping-choice input:checked + span:before','rotate','45','','','.w-checkout-shipping-choice'),(935995,'printshop','.b-info-popup .info-popup div','rotate','-45','3','','.b-info-popup'),(935996,'printshop','.w-sample .cart-box-link','rotate','45','4','','.w-sample'),(935998,'printshop','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','stroke-width','0','','','.w-image-maps'),(935999,'printshop','.w-image-maps rect:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(936000,'printshop','.w-image-maps circle:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(936001,'printshop','.w-image-maps polygon:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(936002,'printshop','.w-tabs .tab-navigation','table-layout','fixed','','','.w-tabs'),(936003,'printshop','.w-communication-new-topic .orders-id','text-align','center','','','.w-communication-new-topic'),(936004,'printshop','.w-communication-new-topic .model','text-align','center','','','.w-communication-new-topic'),(936005,'printshop','.w-communication-new-topic .date-purchased','text-align','right','','','.w-communication-new-topic'),(936006,'printshop','.w-communication-new-topic .quantity','text-align','center','','','.w-communication-new-topic'),(936007,'printshop','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(936008,'printshop','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(936009,'printshop','.w-product-wishlist-button .btn','text-align','center','5333','','.w-product-wishlist-button'),(936010,'printshop','.b-email .price','text-align','right','','','.b-email'),(936011,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.p-quick-order-index'),(936012,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.p-quick-order-index'),(936013,'printshop','.w-promotions .promo-date','text-align','center','','','.w-promotions'),(936014,'printshop','.w-promotions .promo-item','text-align','center','','','.w-promotions'),(936016,'printshop','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(936018,'printshop','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(936019,'printshop','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(936020,'printshop','.b-email .heading-model','text-align','center','','','.b-email'),(936021,'printshop','.w-categories .item','text-align','center','','','.w-categories'),(936022,'printshop','.w-promotions .prom-multi-discount .heading','text-align','center','','','.w-promotions'),(936023,'printshop','.b-products-listing .products-listing .btn-preloader','text-align','center','','','.b-products-listing'),(936024,'printshop','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(936025,'printshop','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(936026,'printshop','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(936027,'printshop','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(936028,'printshop','.b-messages .development-content','text-align','left','','','.b-messages'),(936029,'printshop','.b-messages .msv_to_cc, .b-messages .msv_btn','text-align','left','','','.b-messages'),(936030,'printshop','.b-messages .msv_content','text-align','left','','','.b-messages'),(936031,'printshop','.b-messages .msv_history','text-align','left','','','.b-messages'),(936032,'printshop','.b-messages .attach-view','text-align','left','','','.b-messages'),(936033,'printshop','.b-messages .messages-sidebar .heading-2','text-align','center','','','.b-messages'),(936034,'printshop','.b-messages .messages-sidebar .btn-2','text-align','center','','','.b-messages'),(936035,'printshop','.b-messages .emailBtn','text-align','right','','','.b-messages'),(936036,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','text-align','left','','','.b-messages'),(936037,'printshop','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(936038,'printshop','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align','left','','','.p-quick-order-index'),(936039,'printshop','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(936040,'printshop','.w-checkout-terms .terms-box','text-align','left','','','.w-checkout-terms'),(936041,'printshop','.w-checkout-terms .required-message','text-align','left','','','.w-checkout-terms'),(936042,'printshop','.w-cart-listing .price','text-align','right','5333','','.w-cart-listing'),(936043,'printshop','.b-email .heading-model','text-align','center','','','.b-email'),(936044,'printshop','.b-email .heading-qty','text-align','center','','','.b-email'),(936045,'printshop','.b-email .heading-price','text-align','right','','','.b-email'),(936046,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','text-align','center','','','.b-switch'),(936047,'printshop','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(936048,'printshop','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(936049,'printshop','.order-summary .price-box .title','text-align','left','','','.order-summary'),(936050,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','text-align','center','','','.w-upload-customer-id-upload-customer-id-form'),(936051,'printshop','.b-switch .bootstrap-switch','text-align','left','','','.b-switch'),(936052,'printshop','.b-page-name .page-name','text-align','center','','','.b-page-name'),(936053,'printshop','.b-email .totals-label','text-align','right','','','.b-email'),(936054,'printshop','.w-coupons-and-vauchers-checkout .btn-remove','text-align','center','','','.w-coupons-and-vauchers-checkout'),(936055,'printshop','.w-checkout-bonus-points .btn-remove','text-align','center','','','.w-checkout-bonus-points'),(936056,'printshop','.w-login-block .buttons','text-align','right','','','.w-login-block'),(936057,'printshop','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(936058,'printshop','.b-email .heading-qty','text-align','center','','','.b-email'),(936059,'printshop','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(936060,'printshop','.b-email .totals-value','text-align','right','','','.b-email'),(936061,'printshop','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(936062,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','text-align','center','','','.b-switch'),(936063,'printshop','.b-email .totals-value','text-align','right','','','.b-email'),(936064,'printshop','.b-email .qty','text-align','center','','','.b-email'),(936065,'printshop','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(936066,'printshop','.no-found','text-align','center','','',''),(936067,'printshop','.w-login-block .buttons','text-align','right','','','.w-login-block'),(936068,'printshop','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(936069,'printshop','.p-quick-order-index .all-scroll-div td + td','text-align','right','','','.p-quick-order-index'),(936070,'printshop','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(936071,'printshop','.b-email-editor .price','text-align','center','','','.b-email-editor'),(936072,'printshop','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(936073,'printshop','.b-email .model','text-align','center','','','.b-email'),(936074,'printshop','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(936075,'printshop','.b-form .wedding-form .heading-2','text-align','left','','','.b-form'),(936076,'printshop','.b-email .heading-price','text-align','right','','','.b-email'),(936077,'printshop','.b-email .price','text-align','right','','','.b-email'),(936078,'printshop','.w-top-categories .categories','text-align','center','','','.w-top-categories'),(936079,'printshop','.w-success-continue-btn','text-align','center','5342','','.w-success-continue-btn'),(936080,'printshop','.b-page-name .page-name','text-align','center','','','.b-page-name'),(936081,'printshop','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(936082,'printshop','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(936083,'printshop','.b-page-name .page-name','text-align','center','','','.b-page-name'),(936084,'printshop','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(936085,'printshop','.b-email .heading-qty','text-align','center','','','.b-email'),(936086,'printshop','.w-tabs .tab-a','text-align','center','','','.w-tabs'),(936087,'printshop','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(936088,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','text-align','center','','','.b-switch'),(936089,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-label','text-align','center','','','.b-switch'),(936090,'printshop','.b-social-login .social-login','text-align','center','','','.b-social-login'),(936091,'printshop','.b-page-name .page-name','text-align','center','','','.b-page-name'),(936092,'printshop','.b-email .price','text-align','right','','','.b-email'),(936093,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','text-align','center','','','.b-switch'),(936094,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','text-align','center','','','.b-switch'),(936095,'printshop','.b-email .totals-title','text-align','right','','','.b-email'),(936096,'printshop','.b-email .heading-model','text-align','center','','','.b-email'),(936097,'printshop','.b-email .totals-label','text-align','right','','','.b-email'),(936098,'printshop','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(936099,'printshop','.b-email .totals-value','text-align','right','','','.b-email'),(936100,'printshop','.w-cart-bonus-points .bonus_points_amount','text-align','center','','','.w-cart-bonus-points'),(936101,'printshop','.w-cart-bonus-points .btn-remove','text-align','center','','','.w-cart-bonus-points'),(936102,'printshop','.w-cart-credit-amount input','text-align','center','','','.w-cart-credit-amount'),(936103,'printshop','.b-email .heading-qty','text-align','center','','','.b-email'),(936104,'printshop','.w-reviews .date','text-align','right','','','.w-reviews'),(936105,'printshop','.w-success-continue-btn','text-align','center','5342','','.w-success-continue-btn'),(936106,'printshop','.w-top-categories .item','text-align','center','','','.w-top-categories'),(936107,'printshop','.w-reviews-content .product-image','text-align','center','','','.w-reviews-content'),(936108,'printshop','.b-email .model','text-align','center','','','.b-email'),(936109,'printshop','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(936110,'printshop','.b-email .heading-price','text-align','right','','','.b-email'),(936111,'printshop','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(936112,'printshop','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(936113,'printshop','.b-email .heading-price','text-align','right','','','.b-email'),(936114,'printshop','.b-email .price','text-align','right','','','.b-email'),(936115,'printshop','.b-email .totals-title','text-align','right','','','.b-email'),(936116,'printshop','.b-email .totals-value','text-align','right','','','.b-email'),(936117,'printshop','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(936118,'printshop','.b-email .heading-model','text-align','center','','','.b-email'),(936119,'printshop','.b-email .qty','text-align','center','','','.b-email'),(936120,'printshop','.b-email .model','text-align','center','','','.b-email'),(936121,'printshop','.b-email .totals-label','text-align','right','','','.b-email'),(936122,'printshop','.b-email .heading-qty','text-align','center','','','.b-email'),(936123,'printshop','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(936124,'printshop','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(936125,'printshop','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(936126,'printshop','.b-form .center-buttons','text-align','center','','','.b-form'),(936127,'printshop','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(936128,'printshop','.w-reviews .product-image','text-align','center','','','.w-reviews'),(936129,'printshop','.b-sub-totals .historyTotal table td','text-align','right','','','.b-sub-totals'),(936130,'printshop','.b-social-login .social-login','text-align','center','','','.b-social-login'),(936131,'printshop','.w-success-continue-btn','text-align','center','5342','','.w-success-continue-btn'),(936132,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','text-align','center','3','','.b-switch'),(936134,'printshop','.b-social-login .social-login','text-align','center','','','.b-social-login'),(936135,'printshop','.w-login-block .buttons','text-align','right','','','.w-login-block'),(936136,'printshop','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(936137,'printshop','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','text-align','center','','','.p-quick-order-index'),(936138,'printshop','.w-cart-checkout-btn a','text-align','center','5333','','.w-cart-checkout-btn'),(936139,'printshop','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(936140,'printshop','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(936141,'printshop','.w-login-block .buttons','text-align','right','','','.w-login-block'),(936142,'printshop','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(936143,'printshop','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(936144,'printshop','.view-all','text-align','center','','',''),(936145,'printshop','.b-page-name .page-name','text-align','center','','','.b-page-name'),(936146,'printshop','.b-form .message.error','text-align','center','','','.b-form'),(936147,'printshop','.b-email .qty','text-align','center','','','.b-email'),(936148,'printshop','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','text-align','center','3','','.w-checkout-contact-information'),(936149,'printshop','.b-email .model','text-align','center','','','.b-email'),(936150,'printshop','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','text-align','center','3','','.w-checkout-contact-information'),(936151,'printshop','.p-wedding-registry-search .result-table td:nth-child(4)','text-align','right','','','.p-wedding-registry-search'),(936152,'printshop','.w-product-wishlist-button .btn','text-align','center','5333','','.w-product-wishlist-button'),(936153,'printshop','.b-email .heading-qty','text-align','center','','','.b-email'),(936154,'printshop','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(936155,'printshop','.b-email .totals-value','text-align','right','','','.b-email'),(936156,'printshop','.w-product-wishlist-button .btn','text-align','center','5333','','.w-product-wishlist-button'),(936157,'printshop','.b-bottom .cart-options .js-carts','text-align','center','','','.b-bottom'),(936158,'printshop','.b-bottom .cart-options .heading-4','text-align','center','','','.b-bottom'),(936159,'printshop','.b-bottom .cart-options .heading-3','text-align','center','','','.b-bottom'),(936160,'printshop','.b-bottom .cart-options .buttons','text-align','center','','','.b-bottom'),(936161,'printshop','.b-bottom .alert-message','text-align','center','','','.b-bottom'),(936162,'printshop','.w-checkout-credit-amount .btn-remove','text-align','center','','','.w-checkout-credit-amount'),(936163,'printshop','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(936164,'printshop','.b-products-listing .btn-choose-options','text-align','center','','','.b-products-listing'),(936165,'printshop','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(936166,'printshop','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(936167,'printshop','.w-product-wishlist-button .btn','text-align','center','5333','','.w-product-wishlist-button'),(936168,'printshop','.b-email-editor .price','text-align','center','','','.b-email-editor'),(936169,'printshop','.b-email .qty','text-align','center','','','.b-email'),(936170,'printshop','.b-email-editor .price','text-align','center','','','.b-email-editor'),(936172,'printshop','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(936173,'printshop','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(936174,'printshop','.order-summary .price-row.ot_gv .title','text-align','center','3','','.order-summary'),(936175,'printshop','.w-cart-credit-amount .btn-remove','text-align','center','','','.w-cart-credit-amount'),(936176,'printshop','.b-email .qty','text-align','center','','','.b-email'),(936177,'printshop','.b-email-editor .price','text-align','center','','','.b-email-editor'),(936178,'printshop','.b-fancybox .fancybox-close','text-align','center','','','.b-fancybox'),(936179,'printshop','.w-product-customers-activity .customers-activity','text-align','center','','','.w-product-customers-activity'),(936180,'printshop','.w-product-customers-activity .close','text-align','center','','','.w-product-customers-activity'),(936181,'printshop','.b-bottom .confirm-popup .buttons','text-align','center','','','.b-bottom'),(936182,'printshop','.b-bottom .confirm-popup .confirm-text','text-align','center','','','.b-bottom'),(936183,'printshop','.b-email .totals-title','text-align','right','','','.b-email'),(936184,'printshop','.b-email .totals-label','text-align','right','','','.b-email'),(936185,'printshop','.b-email .price','text-align','right','','','.b-email'),(936186,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','text-align','center','3','','.b-switch'),(936187,'printshop','.w-quote-products .empty','text-align','center','','','.w-quote-products'),(936188,'printshop','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(936189,'printshop','.w-menu-horizontal .menu-ico','text-align','center','','','.w-menu-horizontal'),(936190,'printshop','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(936191,'printshop','.w-checkout-credit-amount .cot_gv_amount','text-align','center','','','.w-checkout-credit-amount'),(936192,'printshop','.w-checkout-bonus-points .bonus_points_amount','text-align','center','','','.w-checkout-bonus-points'),(936193,'printshop','.w-product-wishlist-button .btn','text-align','center','5333','','.w-product-wishlist-button'),(936194,'printshop','.w-success-continue-btn','text-align','center','5342','','.w-success-continue-btn'),(936195,'printshop','.p-wedding-registry-search #searchform-status label','text-align','right','','','.p-wedding-registry-search'),(936196,'printshop','.b-page-name .page-name','text-align','center','','','.b-page-name'),(936197,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-align','left','','','.b-switch'),(936198,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-align','right','','','.b-switch'),(936199,'printshop','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(936200,'printshop','.b-social-login .social-login','text-align','center','','','.b-social-login'),(936201,'printshop','.b-products-listing .products-listing .buyButton .btn','text-align','center','','','.b-products-listing'),(936203,'printshop','.w-menu-big li li li','text-align','left','','','.w-menu-big'),(936204,'printshop','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(936205,'printshop','.w-menu-horizontal .box','text-align','center','','','.w-menu-horizontal'),(936206,'printshop','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(936207,'printshop','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(936208,'printshop','.b-social-login .social-login','text-align','center','','','.b-social-login'),(936209,'printshop','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(936210,'printshop','.w-login-block .buttons','text-align','right','','','.w-login-block'),(936211,'printshop','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(936212,'printshop','.w-cart-listing .links','text-align','center','','','.w-cart-listing'),(936213,'printshop','.w-product-wishlist-button .btn','text-align','center','5333','','.w-product-wishlist-button'),(936214,'printshop','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(936215,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.b-data-table'),(936216,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.b-data-table'),(936217,'printshop','.w-communication-post .communication-post-attach','text-align','right','','','.w-communication-post'),(936218,'printshop','.b-products-listing .products-listing .image','text-align','center','','','.b-products-listing'),(936219,'printshop','.w-catalog-b2b-add-button .b2b-add-box-wrap','text-align','right','','','.w-catalog-b2b-add-button'),(936220,'printshop','.b-products-listing .products-listing .properties','text-align','left','','','.b-products-listing'),(936221,'printshop','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','text-align','left','','','.b-products-listing'),(936222,'printshop','.b-products-listing .show-ofstock-products','text-align','center','','','.b-products-listing'),(936223,'printshop','.checkbox input:checked + span:before','text-align','center','','',''),(936224,'printshop','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(936225,'printshop','.p-sample-checkout-success .page-success','text-align','center','','','.p-sample-checkout-success'),(936226,'printshop','.b-products-listing .products-listing .in-cart','text-align','center','','','.b-products-listing'),(936227,'printshop','.b-email-editor .price','text-align','center','','','.b-email-editor'),(936228,'printshop','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(936229,'printshop','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','text-align','center','3','','.w-checkout-contact-information'),(936230,'printshop','.b-fancybox .fancybox-title-float-wrap','text-align','center','','','.b-fancybox'),(936231,'printshop','.b-email .model','text-align','center','','','.b-email'),(936233,'printshop','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(936234,'printshop','.order-summary .price-row.ot_coupon .title','text-align','center','3','','.order-summary'),(936235,'printshop','h1, .heading-1','text-align','center','','',''),(936236,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','text-align','center','','','.w-communication-new-topic'),(936237,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','text-align','center','','','.w-communication-new-topic'),(936238,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(5), .w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(7)','text-align','center','','','.w-communication-new-topic'),(936239,'printshop','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(936240,'printshop','.b-email .heading-model','text-align','center','','','.b-email'),(936242,'printshop','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(936243,'printshop','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(936244,'printshop','.b-email .model','text-align','center','','','.b-email'),(936245,'printshop','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(936246,'printshop','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(936247,'printshop','.b-email .totals-title','text-align','right','','','.b-email'),(936248,'printshop','.b-email .heading-price','text-align','right','','','.b-email'),(936249,'printshop','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(936251,'printshop','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(936252,'printshop','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(936253,'printshop','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(936254,'printshop','.b-email .totals-label','text-align','right','','','.b-email'),(936255,'printshop','.b-email .totals-title','text-align','right','','','.b-email'),(936256,'printshop','.b-email .price','text-align','right','','','.b-email'),(936257,'printshop','.b-email .heading-price','text-align','right','','','.b-email'),(936258,'printshop','.b-compare .compare-head','text-align','left','','','.b-compare'),(936259,'printshop','.w-menu-horizontal ul ul li','text-align','left','','','.w-menu-horizontal'),(936261,'printshop','.b-email .heading-model','text-align','center','','','.b-email'),(936262,'printshop','.w-catalog-listing-look .grid','text-align','center','','','.w-catalog-listing-look'),(936263,'printshop','.w-catalog-listing-look .b2b','text-align','center','','','.w-catalog-listing-look'),(936264,'printshop','.w-catalog-listing-look .list','text-align','center','','','.w-catalog-listing-look'),(936265,'printshop','.w-cart-listing .image','text-align','center','','','.w-cart-listing'),(936266,'printshop','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(936267,'printshop','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','text-align','left','','','.w-cart-listing'),(936268,'printshop','.w-cart-listing .points-earn','text-align','right','','','.w-cart-listing'),(936269,'printshop','.w-cart-listing .points-redeem','text-align','left','','','.w-cart-listing'),(936270,'printshop','.w-cart-listing .no-price .qty','text-align','right','','','.w-cart-listing'),(936271,'printshop','.w-cart-listing .remove-btn','text-align','center','','','.w-cart-listing'),(936272,'printshop','.w-cart-listing .price','text-align','right','','','.w-cart-listing'),(936273,'printshop','.w-cart-listing .remove','text-align','center','','','.w-cart-listing'),(936274,'printshop','.w-cart-listing .item .qty','text-align','right','5342','','.w-cart-listing'),(936275,'printshop','.w-cart-give-away .ga_img','text-align','center','','','.w-cart-give-away'),(936276,'printshop','.w-cart-discount-coupon .btn-remove','text-align','center','','','.w-cart-discount-coupon'),(936278,'printshop','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(936279,'printshop','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(936280,'printshop','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(936281,'printshop','.b-fancybox .fancybox-nav span','text-align','center','','','.b-fancybox'),(936282,'printshop','.w-success-continue-btn','text-align','center','5342','','.w-success-continue-btn'),(936283,'printshop','.w-tabs .accordion-heading','text-align','center','','','.w-tabs'),(936284,'printshop','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(936285,'printshop','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(936286,'printshop','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','text-align','center','','','.p-quick-order-index'),(936287,'printshop','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(936288,'printshop','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(936289,'printshop','.w-login-block .buttons','text-align','right','','','.w-login-block'),(936290,'printshop','.w-filters .handle-to','text-align','right','','','.w-filters'),(936291,'printshop','.order-summary .box','text-align','center','','','.order-summary'),(936292,'printshop','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(936293,'printshop','.b-bottom .pop-up-close','text-align','center','','','.b-bottom'),(936294,'printshop','.order-summary .price-row.ot_bonus_points .title','text-align','center','3','','.order-summary'),(936295,'printshop','.w-success-continue-btn','text-align','center','5342','','.w-success-continue-btn'),(936296,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','text-align','center','3','','.b-form'),(936297,'printshop','.b-social-login .social-login','text-align','center','','','.b-social-login'),(936298,'printshop','.w-reviews-content .date','text-align','right','','','.w-reviews-content'),(936299,'printshop','.b-data-table table.dataTable tbody td:last-child','text-align','right','','','.b-data-table'),(936300,'printshop','.b-data-table .dt-body-center','text-align','center','','','.b-data-table'),(936301,'printshop','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(936302,'printshop','.w-menu-big li a, .w-menu-big li .no-link','text-align','left','','','.w-menu-big'),(936303,'printshop','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(936304,'printshop','.b-upload-file .upload-file-template','text-align','center','','','.b-upload-file'),(936305,'printshop','.b-email-editor .price','text-align','center','','','.b-email-editor'),(936306,'printshop','.b-email .totals-value','text-align','right','','','.b-email'),(936307,'printshop','.b-email .totals-label','text-align','right','','','.b-email'),(936308,'printshop','.b-email .totals-title','text-align','right','','','.b-email'),(936309,'printshop','.b-email .qty','text-align','center','','','.b-email'),(936310,'printshop','.b-upload-file .snapshot','text-align','center','','','.b-upload-file'),(936311,'printshop','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(936312,'printshop','.b-product-images .media-popup .mp-close','text-align','center','','','.b-product-images'),(936313,'printshop','.b-product-images .media-popup .mp-small-images','text-align','center','','','.b-product-images'),(936314,'printshop','.b-product-images .media-popup .mp-small-images .item','text-align','center','','','.b-product-images'),(936315,'printshop','.b-product-images .media-popup .slick-dots','text-align','center','','','.b-product-images'),(936316,'printshop','.b-product-images .media-popup .slick-dots li','text-align','center','','','.b-product-images'),(936317,'printshop','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','text-align','center','','','.b-menu-burger_icon'),(936318,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(936319,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(936320,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(936321,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(936322,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(936323,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(936324,'printshop','.b-personal-catalog-popup #personal_catalog_popup','text-align','left','','','.b-personal-catalog-popup'),(936325,'printshop','.b-trade-approval .steps-bar li','text-align','center','','','.b-trade-approval'),(936326,'printshop','.b-trade-approval .steps-bar li a','text-align','center','','','.b-trade-approval'),(936327,'printshop','.b-trade-approval .orders-table td:nth-child(1), .b-trade-approval .orders-table th:nth-child(1)','text-align','left','','','.b-trade-approval'),(936328,'printshop','.b-trade-approval .orders-table td:nth-child(2)','text-align','right','','','.b-trade-approval'),(936329,'printshop','.b-trade-approval .w-login-block label','text-align','left','','','.b-trade-approval'),(936330,'printshop','.b-trade-approval .steps-bar','text-align','left','','','.b-trade-approval'),(936331,'printshop','.b-trade-approval .center-buttons','text-align','center','','','.b-trade-approval'),(936332,'printshop','.b-trade-approval .comments','text-align','left','','','.b-trade-approval'),(936333,'printshop','.w-account-personal-catalog .list-switcher a','text-align','center','','','.w-account-personal-catalog'),(936334,'printshop','.w-catalog-additional-images ul, .w-catalog-additional-images li','text-align','center','','','.w-catalog-additional-images'),(936335,'printshop','.w-catalog-compare .cross-box .different-all > div','text-align','center','','','.w-catalog-compare'),(936336,'printshop','.w-delivery-day .time-left','text-align','center','','','.w-delivery-day'),(936337,'printshop','.w-top-text .top-text','text-align','center','','','.w-top-text'),(936338,'printshop','.b-cookie-notice .cookie-notice','text-align','center','','','.b-cookie-notice'),(936342,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','text-align','center','','','.b-slick'),(936343,'printshop','.menu-header .burger-icon','text-align','center','5342','','.menu-header'),(936344,'printshop','.b-products-listing .item-nav > div','text-align','center','','','.b-products-listing'),(936345,'printshop','.w-quote .cart-box-link','text-align','center','3','','.w-quote'),(936346,'printshop','.w-quote .price','text-align','right','','','.w-quote'),(936347,'printshop','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(936348,'printshop','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(936349,'printshop','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(936350,'printshop','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(936351,'printshop','.w-product-sale-ends .ends','text-align','center','','','.w-product-sale-ends'),(936352,'printshop','.w-product-sale-ends .left','text-align','center','','','.w-product-sale-ends'),(936353,'printshop','.heading-2, h2, .h-block h2','text-align','center','','',''),(936354,'printshop','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','text-align','center','','','.w-product-buttons'),(936355,'printshop','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(936356,'printshop','.w-product-quantity .qty-input','text-align','right','','','.w-product-quantity'),(936357,'printshop','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(936358,'printshop','.w-files-catalog-widgets-files-catalog .item','text-align','center','','','.w-files-catalog-widgets-files-catalog'),(936359,'printshop','.w-sample .cart-box-link','text-align','center','3','','.w-sample'),(936360,'printshop','.w-sample .price','text-align','right','','','.w-sample'),(936361,'printshop','.w-cart-listing .item > div.points','text-align','right','','','.w-cart-listing'),(936362,'printshop','.w-filters-simple .integrate-price-holder','text-align','right','','','.w-filters-simple'),(936363,'printshop','.w-cart-sub-total .price','text-align','right','','','.w-cart-sub-total'),(936364,'printshop','.w-product-images .additional-horizontal .item','text-align','center','','','.w-product-images'),(936365,'printshop','.w-product-video .frame-video','text-align','center','','','.w-product-video'),(936366,'printshop','.w-product-video .item','text-align','center','','','.w-product-video'),(936367,'printshop','.w-product-bundle .bundle-total-price','text-align','right','','','.w-product-bundle'),(936368,'printshop','.w-product-in-bundles .bundle-total-price','text-align','right','','','.w-product-in-bundles'),(936369,'printshop','.b-bottom .cart-options .cart-item','text-align','center','','','.b-bottom'),(936370,'printshop','.w-cart-listing .item div.price','text-align','right','5342','','.w-cart-listing'),(936371,'printshop','.w-sample-products .w-cart-listing .item .qty','text-align','right','5333','','.w-sample-products'),(936373,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','text-align','inherit','','','.b-products-listing'),(936374,'printshop','.b-pagination .pagination .next-pages','text-align','center','','','.b-pagination'),(936375,'printshop','.b-pagination .pagination .p-blog-index','text-align','right','','','.b-pagination'),(936376,'printshop','.b-pagination .pagination .page-number','text-align','center','','','.b-pagination'),(936377,'printshop','.b-pagination .pagination .prev-pages','text-align','center','','','.b-pagination'),(936378,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','text-align','center','','','.b-pagination'),(936379,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','text-align','center','','','.b-pagination'),(936380,'printshop','.b-pagination .pagination span','text-align','center','2','','.b-pagination'),(936381,'printshop','.p-quote-checkout-index .heading-2','text-align','left','','','.p-quote-checkout-index'),(936382,'printshop','.p-sample-checkout-index .heading-2','text-align','left','','','.p-sample-checkout-index'),(936383,'printshop','.p-quote-checkout-index .order-summary .heading-2','text-align','center','','','.p-quote-checkout-index'),(936384,'printshop','.w-sample-products .w-cart-listing .qty','text-align','center','','','.w-sample-products'),(936385,'printshop','.p-sample-checkout-index .order-summary .heading-2','text-align','center','','','.p-sample-checkout-index'),(936387,'printshop','.w-quote-products .cart-listing .qty','text-align','right','','','.w-quote-products'),(936388,'printshop','.w-product-multi-inventory .radio-attributes .option-item','text-align','center','','','.w-product-multi-inventory'),(936389,'printshop','.w-account-personal-catalog .check-box','text-align','right','','','.w-account-personal-catalog'),(936390,'printshop','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','text-align','center','','','.w-account-personal-catalog'),(936391,'printshop','.w-account-personal-catalog .w-cart-listing .item .remove','text-align','center','5342','','.w-account-personal-catalog'),(936392,'printshop','.b-products-listing .products-listing.list-rows .qtyInput','text-align','center','','','.b-products-listing'),(936393,'printshop','.b-products-listing .products-listing .radio-attributes .option','text-align','center','','','.b-products-listing'),(936394,'printshop','.b-products-listing .products-listing.list-b2b .qtyInput','text-align','center','','','.b-products-listing'),(936395,'printshop','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(936396,'printshop','.w-product-collection .item','text-align','center','','','.w-product-collection'),(936397,'printshop','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(936398,'printshop','.w-product-collection .choose-products .heading-3','text-align','center','','','.w-product-collection'),(936399,'printshop','.w-product-attributes .radio-attributes .option-item','text-align','center','','','.w-product-attributes'),(936400,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','text-align','center','','','.w-questionnaire-widgets-questionnaire'),(936401,'printshop','.w-product-groups .val1','text-align','center','','','.w-product-groups'),(936402,'printshop','.w-product-groups .prop-group-swatch','text-align','center','','','.w-product-groups'),(936403,'printshop','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img + .val2','text-align','center','','','.w-product-groups'),(936404,'printshop','.b-products-listing .products-listing .attribute-qty-block > span','text-align','center','','','.b-products-listing'),(936405,'printshop','.w-product-custom-bundle .heading-3','text-align','center','','','.w-product-custom-bundle'),(936406,'printshop','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(936407,'printshop','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(936408,'printshop','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(936409,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','text-align','center','','','.w-catalog-pages-category-pages-last-list'),(936410,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','text-align','center','','','.w-catalog-pages-category-pages-last-list-block'),(936411,'printshop','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(936412,'printshop','.w-delivery-location-location-list .deliveryList li','text-align','center','','','.w-delivery-location-location-list'),(936413,'printshop','.w-sale-category .badge','text-align','center','','','.w-sale-category'),(936414,'printshop','.w-sale-category .btn','text-align','center','','','.w-sale-category'),(936415,'printshop','.w-sale-category .image','text-align','center','','','.w-sale-category'),(936416,'printshop','.w-sale-category .left','text-align','center','','','.w-sale-category'),(936417,'printshop','.w-success-download table','text-align','center','','','.w-success-download'),(936418,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-img','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(936419,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-name','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(936420,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(936421,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-img','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(936422,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-name','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(936423,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(936424,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description + div','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(936425,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(936426,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(936427,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description + div','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(936428,'printshop','.w-product-properties-icons .hover-box-content','text-align','center','','','.w-product-properties-icons'),(936429,'printshop','.w-delivery-location-product-categories .item.category-link','text-align','center','','','.w-delivery-location-product-categories'),(936430,'printshop','.w-product-bonus-points .bonus-points-cost','text-align','left','','','.w-product-bonus-points'),(936431,'printshop','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','text-align','right','','','.w-press-reviews-widgets-press-reviews-small'),(936432,'printshop','.w-press-reviews-widgets-press-reviews .date','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(936433,'printshop','.w-press-reviews-widgets-press-reviews .heading-3','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(936434,'printshop','.w-press-reviews-widgets-press-reviews .image','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(936435,'printshop','.w-press-reviews-widgets-press-reviews .item','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(936436,'printshop','.w-press-reviews-widgets-press-reviews .press-reviews-button','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(936437,'printshop','.w-press-reviews-widgets-press-reviews .sub-box','text-align','left','','','.w-press-reviews-widgets-press-reviews'),(936438,'printshop','.w-press-reviews-widgets-press-reviews .author','text-align','center','5333','','.w-press-reviews-widgets-press-reviews'),(936439,'printshop','.w-press-reviews-widgets-press-reviews .date','text-align','center','5333','','.w-press-reviews-widgets-press-reviews'),(936440,'printshop','.w-press-reviews-widgets-press-reviews .image','text-align','center','5333','','.w-press-reviews-widgets-press-reviews'),(936441,'printshop','.w-press-reviews-widgets-press-reviews .rating','text-align','center','5333','','.w-press-reviews-widgets-press-reviews'),(936442,'printshop','.w-press-reviews-widgets-press-reviews .review','text-align','center','5333','','.w-press-reviews-widgets-press-reviews'),(936443,'printshop','.w-press-reviews-widgets-press-reviews .title','text-align','center','5333','','.w-press-reviews-widgets-press-reviews'),(936444,'printshop','.w-press-reviews-widgets-press-reviews-list .review-box ul li','text-align','left','','','.w-press-reviews-widgets-press-reviews-list'),(936445,'printshop','.w-support-system-listing .product_icon','text-align','center','','','.w-support-system-listing'),(936446,'printshop','.w-rma-returns-history .btn','text-align','center','','','.w-rma-returns-history'),(936447,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','text-align','center','','','.w-rma-returns-history'),(936448,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(936449,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(936450,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(936451,'printshop','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(936452,'printshop','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(936453,'printshop','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(936454,'printshop','.w-product-configurator .pc_qty','text-align','left','5333','','.w-product-configurator'),(936455,'printshop','.b-products-listing .products-listing .bonus-points-cost','text-align','left','','','.b-products-listing'),(936456,'printshop','.b-products-listing .promo-icon','text-align','center','','','.b-products-listing'),(936457,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','text-align','center','','','.w-catalog-pages-category-pages-list'),(936458,'printshop','.w-predefined-promotion .prom-multi-discount .heading','text-align','center','','','.w-predefined-promotion'),(936459,'printshop','.w-predefined-promotion .promo-date','text-align','center','','','.w-predefined-promotion'),(936460,'printshop','.w-predefined-promotion .promo-item','text-align','center','','','.w-predefined-promotion'),(936461,'printshop','.w-supplier-purchase-supplier-products .active .select_item > div','text-align','center','','','.w-supplier-purchase-supplier-products'),(936464,'printshop','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','text-align','right','','','.b-products-listing'),(936465,'printshop','.w-product-name h1','text-align','left','','','.w-product-name'),(936466,'printshop','.b-quantity .qty-box input[type=\"text\"]','text-align','center','','','.b-quantity'),(936467,'printshop','.w-cart-listing .qty','text-align','center','','','.w-cart-listing'),(936468,'printshop','.bottomBanner .wrapper','text-align','center','','','.bottomBanner'),(936469,'printshop','.btn','text-align','center','','',''),(936470,'printshop','.btn-1','text-align','center','','',''),(936471,'printshop','.btn-2','text-align','center','','',''),(936472,'printshop','.btn-3','text-align','center','','',''),(936473,'printshop','.w-product-quantity .qty-input','text-align','center','5363','','.w-product-quantity'),(936474,'printshop','.pop-up-content .buttons .btn','text-align','center','5333','',''),(936475,'printshop','.pop-up-content .buttons .btn-2','text-align','center','5333','',''),(936476,'printshop','.w-cart-listing .item .qty','text-align','left','5333','','.w-cart-listing'),(936477,'printshop','.b-products-listing .products-listing .compare','text-align','center','','','.b-products-listing'),(936478,'printshop','.w-account-personal-catalog .w-cart-listing .remove','text-align','center','','','.w-account-personal-catalog'),(936479,'printshop','.w-account-personal-catalog .w-cart-listing .price','text-align','center','','','.w-account-personal-catalog'),(936480,'printshop','.w-account-personal-catalog .qty-input','text-align','left','5333','','.w-account-personal-catalog'),(936481,'printshop','.w-account-personal-catalog .check-box','text-align','center','5333','','.w-account-personal-catalog'),(936482,'printshop','.w-account-personal-catalog .qty-input','text-align','left','5363','','.w-account-personal-catalog'),(936483,'printshop','.w-account-personal-catalog .w-cart-listing .price','text-align','center','5363','','.w-account-personal-catalog'),(936484,'printshop','.p-payer-order-pay .heading-2','text-align','left','','','.p-payer-order-pay'),(936485,'printshop','.p-payer-order-pay .heading-2.prod-ico','text-align','left','','','.p-payer-order-pay'),(936486,'printshop','.p-payer-order-pay .order-summary .heading-2','text-align','center','','','.p-payer-order-pay'),(936487,'printshop','.p-payer-order-pay .price-box .title','text-align','left','','','.p-payer-order-pay'),(936488,'printshop','.p-payer-order-confirmation .heading-2','text-align','left','','','.p-payer-order-confirmation'),(936489,'printshop','.p-payer-order-confirmation .heading-2.prod-ico','text-align','left','','','.p-payer-order-confirmation'),(936490,'printshop','.p-payer-order-confirmation .order-summary .heading-2','text-align','center','','','.p-payer-order-confirmation'),(936491,'printshop','.p-payer-order-confirmation .price-box .title','text-align','left','','','.p-payer-order-confirmation'),(936492,'printshop','.w-catalog-counts-items ','text-align','center','5363','','.w-catalog-counts-items'),(936493,'printshop','.topBanner .content','text-align','center','','','.topBanner'),(936494,'printshop','.bottomBanner .descr + div','text-align','left','5363','','.bottomBanner'),(936495,'printshop','.order-summary .w-cart-listing .item .name','text-align','left','','','.order-summary'),(936496,'printshop','.order-summary .w-cart-listing.type-2 .image','text-align','left','','','.order-summary'),(936497,'printshop','.w-cart-discount-coupon .title','text-align','left','','','.w-cart-discount-coupon'),(936498,'printshop','.account-address-book .address_book h2','text-align','right','','','.account-address-book'),(936517,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-align','left','','','.account-order-pay'),(936518,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-align','left','3','','.account-order-pay'),(936519,'printshop','.account-order-pay .tableForm th','text-align','left','','','.account-order-pay'),(936520,'printshop','.account-samples .orders-table td.td-alignright','text-align','right','','','.account-samples'),(936521,'printshop','.account-samples .orders-table th','text-align','left','','','.account-samples'),(936522,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-align','left','','','.account-sample-info'),(936523,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-align','left','3','','.account-sample-info'),(936524,'printshop','.account-sample-info .popup-tracking-number','text-align','center','','','.account-sample-info'),(936525,'printshop','.account-sample-info .tableForm th','text-align','left','','','.account-sample-info'),(936526,'printshop','.account-sample-info .trackings-nambers','text-align','center','','','.account-sample-info'),(936527,'printshop','.catalog-product-wrap .prev-next-product','text-align','center','','','.catalog-product-wrap'),(936528,'printshop','.shopping-cart-index .cart-page .empty','text-align','center','','','.shopping-cart-index'),(936529,'printshop','.checkout-index-wrap .heading-2','text-align','left','','','.checkout-index-wrap'),(936530,'printshop','.checkout-index-wrap .order-summary .heading-2','text-align','center','','','.checkout-index-wrap'),(936531,'printshop','.checkout-order-confirmation .heading-2','text-align','left','','','.checkout-order-confirmation'),(936532,'printshop','.checkout-order-confirmation .heading-2.prod-ico','text-align','left','','','.checkout-order-confirmation'),(936533,'printshop','.checkout-order-confirmation .order-summary .heading-2','text-align','center','','','.checkout-order-confirmation'),(936534,'printshop','.checkout-order-confirmation .price-box .title','text-align','left','','','.checkout-order-confirmation'),(936535,'printshop','.checkout-success-wrap .page-success','text-align','center','','','.checkout-success-wrap'),(936536,'printshop','.checkout-success-wrap .w-success-print-btn','text-align','center','5363','','.checkout-success-wrap'),(936537,'printshop','.success-page .page-success .text-1','text-align','center','','','.success-page'),(936538,'printshop','.success-page .price-box .title','text-align','left','','','.success-page'),(936539,'printshop','.success-page .w-cart-listing .qty','text-align','center','','','.success-page'),(936540,'printshop','.b-multi-page-checkout .messageBox .info','text-align','left','','','.b-multi-page-checkout'),(936541,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','text-align','center','','','.b-multi-page-checkout'),(936542,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','text-align','center','3','','.b-multi-page-checkout'),(936543,'printshop','.tripleLine .w-banner .banner-item','text-align','center','','','.tripleLine'),(936544,'printshop','.tripleLine .text-banner','text-align','center','','','.tripleLine'),(936545,'printshop','.doubleBanner .w-banner .text-top-center .banner-text-holder, .doubleBanner .w-banner .text-middle-center .banner-text-holder','text-align','center','','','.doubleBanner'),(936546,'printshop','.middleBanner div.banner-text-holder','text-align','center','','','.middleBanner'),(936547,'printshop','.bottomDoubleBanner .w-banner .banner-text','text-align','center','','','.bottomDoubleBanner'),(936548,'printshop','.w-bestsellers .counter','text-align','center','','','.w-bestsellers'),(936549,'printshop','.w-bestsellers .item','text-align','center','3','','.w-bestsellers'),(936550,'printshop','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','text-align','center','','','.w-banner'),(936551,'printshop','.w-banner .single_banner','text-align','center','','','.w-banner'),(936552,'printshop','.w-catalog-paging ','text-align','center','2','','.w-catalog-paging'),(936553,'printshop','.w-catalog-paging .next','text-align','center','','','.w-catalog-paging'),(936554,'printshop','.w-catalog-paging .next-pages','text-align','center','','','.w-catalog-paging'),(936555,'printshop','.w-catalog-paging .p-blog-index','text-align','right','','','.w-catalog-paging'),(936556,'printshop','.w-catalog-paging .page-number','text-align','center','','','.w-catalog-paging'),(936557,'printshop','.w-catalog-paging .prev','text-align','center','','','.w-catalog-paging'),(936558,'printshop','.w-catalog-paging .prev-pages','text-align','center','','','.w-catalog-paging'),(936559,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align','center','','','.w-catalog-paging'),(936560,'printshop','.w-sale .badge','text-align','center','','','.w-sale'),(936561,'printshop','.w-sale .btn','text-align','center','','','.w-sale'),(936562,'printshop','.w-sale .image','text-align','center','','','.w-sale'),(936563,'printshop','.w-sale .left','text-align','center','','','.w-sale'),(936564,'printshop','.w-success-continue-btn','text-align_important','important','5342','','.w-success-continue-btn'),(936565,'printshop','.w-success-continue-btn','text-align_important','important','5342','','.w-success-continue-btn'),(936566,'printshop','.w-success-continue-btn','text-align_important','important','5342','','.w-success-continue-btn'),(936567,'printshop','.w-success-continue-btn','text-align_important','important','5342','','.w-success-continue-btn'),(936568,'printshop','.w-success-continue-btn','text-align_important','important','5342','','.w-success-continue-btn'),(936569,'printshop','.w-success-continue-btn','text-align_important','important','5342','','.w-success-continue-btn'),(936570,'printshop','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align_important','important','','','.p-quick-order-index'),(936571,'printshop','.w-catalog-counts-items ','text-align_important','important','5363','','.w-catalog-counts-items'),(936575,'printshop','.checkout-success-wrap .w-success-print-btn','text-align_important','important','5363','','.checkout-success-wrap'),(936576,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align_important','important','','','.w-catalog-paging'),(936577,'printshop','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(936578,'printshop','.b-fancybox a.fancybox-close','text-decoration','none','1','','.b-fancybox'),(936579,'printshop','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(936582,'printshop','.w-socials > li a','text-decoration','none','','','.w-socials'),(936583,'printshop','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(936584,'printshop','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(936585,'printshop','.price .old','text-decoration','line-through','','',''),(936586,'printshop','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(936587,'printshop','.b-select-suggest .select2-result-selectable .select2-match, .b-select-suggest .select2-result-unselectable .select2-match','text-decoration','underline','','','.b-select-suggest'),(936588,'printshop','.w-socials > li a','text-decoration','none','','','.w-socials'),(936589,'printshop','.w-tabs .tab-a','text-decoration','none','','','.w-tabs'),(936590,'printshop','.w-socials > li a','text-decoration','none','','','.w-socials'),(936591,'printshop','.btn-edit','text-decoration','none','1','',''),(936592,'printshop','.w-socials > li a','text-decoration','none','','','.w-socials'),(936593,'printshop','.heading-3 .right-text, h3 .right-text','text-decoration','none','','',''),(936594,'printshop','.w-socials > li a','text-decoration','none','','','.w-socials'),(936595,'printshop','.w-image-maps .categories-items .item a','text-decoration','none','1','','.w-image-maps'),(936596,'printshop','.w-social-links a','text-decoration','none','1','','.w-social-links'),(936598,'printshop','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(936599,'printshop','.w-socials > li a','text-decoration','none','','','.w-socials'),(936600,'printshop','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(936601,'printshop','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(936602,'printshop','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(936603,'printshop','.b-select-suggest .select2-container .select2-choice','text-decoration','none','','','.b-select-suggest'),(936604,'printshop','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(936605,'printshop','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(936606,'printshop','.w-cart-listing .remove-btn','text-decoration','none','','','.w-cart-listing'),(936609,'printshop','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(936610,'printshop','.w-image-maps .float-items .item a','text-decoration','none','1','','.w-image-maps'),(936611,'printshop','.b-fancybox .fancybox-nav','text-decoration','none','','','.b-fancybox'),(936612,'printshop','.w-tabs .accordion-heading','text-decoration','none','','','.w-tabs'),(936613,'printshop','.b-select-suggest .select2-container .select2-choice abbr','text-decoration','none','','','.b-select-suggest'),(936614,'printshop','.w-filters .mobileCollapse','text-decoration','none','1','','.w-filters'),(936615,'printshop','.w-account-personal-catalog .list-switcher a','text-decoration','none','','','.w-account-personal-catalog'),(936618,'printshop','.LeftCategories ul li a','text-decoration','none','1','','.LeftCategories'),(936619,'printshop','.w-quote .multicart a.name','text-decoration','none','1','','.w-quote'),(936620,'printshop','.w-quote .multicart a.switch-cart','text-decoration','none','1','','.w-quote'),(936621,'printshop','.w-quote a.cart-box-link','text-decoration','none','1','','.w-quote'),(936622,'printshop','.w-quote a.item','text-decoration','none','1','','.w-quote'),(936623,'printshop','.w-sample .multicart a.name','text-decoration','none','1','','.w-sample'),(936624,'printshop','.w-sample .multicart a.switch-cart','text-decoration','none','1','','.w-sample'),(936625,'printshop','.w-sample a.cart-box-link','text-decoration','none','1','','.w-sample'),(936626,'printshop','.w-sample a.item','text-decoration','none','1','','.w-sample'),(936627,'printshop','.w-product-bundle .bundle_price .old','text-decoration','line-through','','','.w-product-bundle'),(936628,'printshop','.w-product-in-bundles .bundle_price .old','text-decoration','line-through','','','.w-product-in-bundles'),(936629,'printshop','.b-pagination .pagination a','text-decoration','none','1','','.b-pagination'),(936630,'printshop','.b-pagination .pagination span','text-decoration','none','1','','.b-pagination'),(936631,'printshop','.w-delivery-location-location-list .deliveryList li a','text-decoration','none','1','','.w-delivery-location-location-list'),(936632,'printshop','.w-sale-category .old','text-decoration','line-through','','','.w-sale-category'),(936633,'printshop','.w-checkout-shipping-address .change-ab','text-decoration','underline','','','.w-checkout-shipping-address'),(936634,'printshop','.w-checkout-shipping-address .change-ab','text-decoration','none','1','','.w-checkout-shipping-address'),(936635,'printshop','.w-checkout-shipping-address .edit-ab','text-decoration','underline','','','.w-checkout-shipping-address'),(936636,'printshop','.w-checkout-shipping-address .edit-ab','text-decoration','none','1','','.w-checkout-shipping-address'),(936637,'printshop','.w-checkout-contact-information .btn-edit1','text-decoration','underline','','','.w-checkout-contact-information'),(936638,'printshop','.w-checkout-contact-information .btn-edit1','text-decoration','none','1','','.w-checkout-contact-information'),(936639,'printshop','.p-quote-checkout-index .edit-address-popup .edit-ab','text-decoration','underline','','','.p-quote-checkout-index'),(936640,'printshop','.p-quote-checkout-index .edit-address-popup .edit-ab','text-decoration','none','1','','.p-quote-checkout-index'),(936647,'printshop','.account-samples .orders-table a, .account-samples .order-info a','text-decoration','none','1','','.account-samples'),(936648,'printshop','.account-samples .view_link','text-decoration','underline','','','.account-samples'),(936649,'printshop','.catalog-product-wrap a.prev-next-product','text-decoration','none','1','','.catalog-product-wrap'),(936650,'printshop','.checkout-index-wrap .edit-address-popup .edit-ab','text-decoration','underline','','','.checkout-index-wrap'),(936651,'printshop','.checkout-index-wrap .edit-address-popup .edit-ab','text-decoration','none','1','','.checkout-index-wrap'),(936652,'printshop','.b-form .addresses .address-item .edit-ab','text-decoration','underline','','','.b-form'),(936653,'printshop','.w-catalog-paging a','text-decoration','none','1','','.w-catalog-paging'),(936654,'printshop','.w-catalog-paging span','text-decoration','none','1','','.w-catalog-paging'),(936655,'printshop','.w-sale .old','text-decoration','line-through','','','.w-sale'),(936656,'printshop','.b-select-suggest .select2-container .select2-choice > .select2-chosen','text-overflow','ellipsis','','','.b-select-suggest'),(936657,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(936658,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(936659,'printshop','.b-fancybox .fancybox-skin','text-shadow','none','','','.b-fancybox'),(936660,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(936661,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(936662,'printshop','.b-fancybox .fancybox-title','text-shadow','none','','','.b-fancybox'),(936663,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(936664,'printshop','.w-contact-contacts h1, .w-contact-contacts h2, .w-contact-contacts h3, .w-contact-contacts h4','text-shadow','inherit','','','.w-contact-contacts'),(936665,'printshop','.topBanner .content .btn','text-shadow','0 0 10px $main-banner-color-1','5342','','.topBanner'),(936666,'printshop','.heading-4 .right-text, h4 .right-text','text-transform','none','','',''),(936667,'printshop','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(936668,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-transform','uppercase','','','.b-switch'),(936669,'printshop','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(936670,'printshop','.p-sample-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-sample-checkout-success'),(936671,'printshop','.p-sample-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-sample-checkout-success'),(936672,'printshop','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(936673,'printshop','.w-promotions .heading-3','text-transform','uppercase','','','.w-promotions'),(936674,'printshop','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(936675,'printshop','.b-messages .content-messages .heading-2','text-transform','none','','','.b-messages'),(936676,'printshop','.heading-4 .edit, h4 .edit','text-transform','none','','',''),(936677,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','text-transform','uppercase','4','','.b-switch'),(936678,'printshop','.w-personal-gift-status-bar .end-date','text-transform','uppercase','','','.w-personal-gift-status-bar'),(936679,'printshop','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(936680,'printshop','.b-info .info strong','text-transform','uppercase','','','.b-info'),(936681,'printshop','.b-info .info strong','text-transform','uppercase','','','.b-info'),(936682,'printshop','.w-checkout-shipping-choice span','text-transform','uppercase','','','.w-checkout-shipping-choice'),(936683,'printshop','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(936684,'printshop','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(936686,'printshop','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(936687,'printshop','.w-cart-compare .cart-name a','text-transform','uppercase','','','.w-cart-compare'),(936688,'printshop','.heading-3 .edit, h3 .edit','text-transform','none','','',''),(936689,'printshop','.b-info .info strong','text-transform','uppercase','','','.b-info'),(936690,'printshop','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(936691,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','text-transform','uppercase','4','','.b-switch'),(936692,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','text-transform','uppercase','4','','.b-switch'),(936693,'printshop','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(936694,'printshop','.w-top-categories .categories h2','text-transform','inherit','','','.w-top-categories'),(936695,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-transform','uppercase','','','.b-switch'),(936696,'printshop','.b-info .info strong','text-transform','uppercase','','','.b-info'),(936697,'printshop','.b-bottom .cart-options .heading-4','text-transform','none','','','.b-bottom'),(936698,'printshop','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(936699,'printshop','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(936700,'printshop','.b-info .info strong','text-transform','uppercase','','','.b-info'),(936701,'printshop','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(936702,'printshop','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(936703,'printshop','.w-personal-gift-status-bar .inform','text-transform','uppercase','','','.w-personal-gift-status-bar'),(936704,'printshop','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(936705,'printshop','.w-top-categories h2.name','text-transform','uppercase','','','.w-top-categories'),(936706,'printshop','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','text-transform','inherit','','',''),(936707,'printshop','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','text-transform','inherit','','','.b-h-inline'),(936708,'printshop','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(936709,'printshop','.b-info .info strong','text-transform','uppercase','','','.b-info'),(936710,'printshop','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','text-transform','uppercase','','','.w-cart-listing'),(936712,'printshop','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(936713,'printshop','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(936714,'printshop','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','text-transform','none','','','.b-products-listing'),(936715,'printshop','.w-quote .multicart .title','text-transform','uppercase','','','.w-quote'),(936716,'printshop','.w-product-personal-catalog-button .btn','text-transform','none','','','.w-product-personal-catalog-button'),(936717,'printshop','.w-files-catalog-widgets-files-catalog .name','text-transform','uppercase','','','.w-files-catalog-widgets-files-catalog'),(936718,'printshop','.w-files-catalog-widgets-files-list .name','text-transform','uppercase','','','.w-files-catalog-widgets-files-list'),(936719,'printshop','.w-sample .multicart .title','text-transform','uppercase','','','.w-sample'),(936720,'printshop','.w-cart-up-sell .products-listing .name a','text-transform','none','','','.w-cart-up-sell'),(936721,'printshop','.w-cart-order-reference .btn','text-transform','none','','','.w-cart-order-reference'),(936722,'printshop','.w-cart-gift-certificate .btn','text-transform','none','','','.w-cart-gift-certificate'),(936723,'printshop','.w-cart-shipping-estimator .btn','text-transform','none','','','.w-cart-shipping-estimator'),(936724,'printshop','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','text-transform','inherit','','','.b-products-listing'),(936725,'printshop','.w-rma-returns-history .column .title','text-transform','uppercase','','','.w-rma-returns-history'),(936726,'printshop','.w-rma-returns-history .tableTitle','text-transform','uppercase','','','.w-rma-returns-history'),(936727,'printshop','.w-predefined-promotion .heading-3','text-transform','uppercase','','','.w-predefined-promotion'),(936728,'printshop','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','text-transform','uppercase','','','.w-multi-cart-cart-switcher'),(936729,'printshop','.bottomBanner .icon-box > div','text-transform','uppercase','','','.bottomBanner'),(936730,'printshop','.topBanner .ourPick .top','text-transform','uppercase','','','.topBanner'),(936731,'printshop','.account-address-book .address_book h2','text-transform','uppercase','','','.account-address-book'),(936732,'printshop','.account-address-book .address_book_row h2 a','text-transform','none','','','.account-address-book'),(936733,'printshop','.account-address-book .leftMes div','text-transform','uppercase','','','.account-address-book'),(936742,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-transform','uppercase','','','.account-order-pay'),(936743,'printshop','.account-order-pay .not_fully_paid_td','text-transform','uppercase','','','.account-order-pay'),(936744,'printshop','.account-samples .not_fully_paid_td','text-transform','uppercase','','','.account-samples'),(936745,'printshop','.account-samples .order_history_table h2','text-transform','uppercase','','','.account-samples'),(936746,'printshop','.account-samples .order_history_table th','text-transform','none','','','.account-samples'),(936747,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-transform','uppercase','','','.account-sample-info'),(936748,'printshop','.account-sample-info .not_fully_paid_td','text-transform','uppercase','','','.account-sample-info'),(936749,'printshop','.catalog-product-wrap .pn-direction','text-transform','uppercase','','','.catalog-product-wrap'),(936750,'printshop','.checkout-success-wrap .page-success .text-1','text-transform','uppercase','','','.checkout-success-wrap'),(936751,'printshop','.success-page .page-success .text-1','text-transform','uppercase','','','.success-page'),(936752,'printshop','.success-page .page-success .text-2','text-transform','uppercase','','','.success-page'),(936753,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading','text-transform','uppercase','','','.b-multi-page-checkout'),(936754,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','text-transform','none','','','.b-multi-page-checkout'),(936756,'printshop','.footer-menu .level-1 > li > a, .footer-menu .level-1 > li > .no-link','text-transform','uppercase','','','.footer-menu'),(936757,'printshop','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_color','#222','','','.b-fancybox'),(936758,'printshop','.middleBanner .btn-1','text_shadow_color','#263238','5342','','.middleBanner'),(936759,'printshop','.middleBanner .title','text_shadow_color','#263238','5342','','.middleBanner'),(936760,'printshop','.middleBanner .descr','text_shadow_color','#263238','5342','','.middleBanner'),(936761,'printshop','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left','0','','','.b-fancybox'),(936762,'printshop','.middleBanner .btn-1','text_shadow_left','0','5342','','.middleBanner'),(936763,'printshop','.middleBanner .title','text_shadow_left','0','5342','','.middleBanner'),(936764,'printshop','.middleBanner .descr','text_shadow_left','0','5342','','.middleBanner'),(936765,'printshop','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left_measure','','','','.b-fancybox'),(936766,'printshop','.middleBanner .btn-1','text_shadow_left_measure','','5342','','.middleBanner'),(936767,'printshop','.middleBanner .title','text_shadow_left_measure','','5342','','.middleBanner'),(936768,'printshop','.middleBanner .descr','text_shadow_left_measure','','5342','','.middleBanner'),(936769,'printshop','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size','2','','','.b-fancybox'),(936770,'printshop','.middleBanner .btn-1','text_shadow_size','10','5342','','.middleBanner'),(936771,'printshop','.middleBanner .title','text_shadow_size','10','5342','','.middleBanner'),(936772,'printshop','.middleBanner .descr','text_shadow_size','10','5342','','.middleBanner'),(936773,'printshop','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size_measure','px','','','.b-fancybox'),(936774,'printshop','.middleBanner .btn-1','text_shadow_size_measure','px','5342','','.middleBanner'),(936775,'printshop','.middleBanner .title','text_shadow_size_measure','px','5342','','.middleBanner'),(936776,'printshop','.middleBanner .descr','text_shadow_size_measure','px','5342','','.middleBanner'),(936777,'printshop','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top','1','','','.b-fancybox'),(936778,'printshop','.middleBanner .btn-1','text_shadow_top','0','5342','','.middleBanner'),(936779,'printshop','.middleBanner .title','text_shadow_top','0','5342','','.middleBanner'),(936780,'printshop','.middleBanner .descr','text_shadow_top','0','5342','','.middleBanner'),(936781,'printshop','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top_measure','px','','','.b-fancybox'),(936782,'printshop','.middleBanner .btn-1','text_shadow_top_measure','','5342','','.middleBanner'),(936783,'printshop','.middleBanner .title','text_shadow_top_measure','','5342','','.middleBanner'),(936784,'printshop','.middleBanner .descr','text_shadow_top_measure','','5342','','.middleBanner'),(936785,'printshop','.b-pass-strength .pass-strength span','top','6','','','.b-pass-strength'),(936786,'printshop','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(936787,'printshop','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','top','0','','','.b-switch'),(936788,'printshop','.w-promotions .prom-multi-discount > .heading','top','2','3','','.w-promotions'),(936789,'printshop','.w-promotions .promo-date','top','-10','','','.w-promotions'),(936791,'printshop','.w-promo-code .holder','top','2','5363,3','','.w-promo-code'),(936792,'printshop','.testimonials .rating','top','2','','',''),(936793,'printshop','.testimonials .heading-3','top','0','3','',''),(936794,'printshop','.testimonials .reviews-list span','top','2','','',''),(936795,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(936796,'printshop','.w-promotions .prom-multi-discount .products','top','-13','','','.w-promotions'),(936797,'printshop','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','top','2','3','','.w-promotions'),(936798,'printshop','.w-promotions .promo-cart-discount .slave .content','top','-17','','','.w-promotions'),(936799,'printshop','.w-promotions .promo-cart-discount .promo-min-qty','top','-19','','','.w-promotions'),(936800,'printshop','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','top','2','3','','.w-promotions'),(936801,'printshop','.b-preloader .preloader','top','calc(50% - 20px)','3','','.b-preloader'),(936802,'printshop','.b-preloader .preloader','top','0','','','.b-preloader'),(936803,'printshop','.b-messages .messBtnMenuDelete','top','3','3','','.b-messages'),(936804,'printshop','.b-messages span.starred::before','top','3','','','.b-messages'),(936805,'printshop','.b-messages .messBtnMenuStarred','top','3','3','','.b-messages'),(936806,'printshop','.b-messages .messBtnMenuUnread','top','3','3','','.b-messages'),(936807,'printshop','.b-messages .select2-container-multi .select2-choices .select2-search-choice','top','5','','','.b-messages'),(936810,'printshop','.p-payer-order-confirmation .discount-ico','top','3','3','','.p-payer-order-confirmation'),(936811,'printshop','.p-payer-order-pay .discount-ico','top','3','3','','.p-payer-order-pay'),(936812,'printshop','.w-checkout-terms .required-message','top','40','','','.w-checkout-terms'),(936813,'printshop','.w-checkout-terms input[type=\"checkbox\"]','top','2','','','.w-checkout-terms'),(936814,'printshop','.b-info .info','top','3','3','','.b-info'),(936815,'printshop','.w-checkout-shipping-address .genders-title input','top','2','','','.w-checkout-shipping-address'),(936816,'printshop','.b-fancybox #fancybox-loading','top','50','','','.b-fancybox'),(936817,'printshop','.b-form .form-buttons','top','10','','','.b-form'),(936818,'printshop','.b-rating .glyphicon','top','1','','','.b-rating'),(936819,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(936820,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-remove','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(936821,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-details','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(936822,'printshop','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(936823,'printshop','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(936824,'printshop','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(936826,'printshop','.b-info .info','top','3','3','','.b-info'),(936827,'printshop','.b-form .shipping-method .input input','top','2','','','.b-form'),(936829,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','top','8','','','.b-switch'),(936830,'printshop','.b-fancybox .fancybox-tmp','top','-99999','','','.b-fancybox'),(936831,'printshop','.w-filters .ui-slider-handle','top','-5','','','.w-filters'),(936832,'printshop','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','top','-1','3','','.order-summary'),(936833,'printshop','.view-all','top','50','3','',''),(936834,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','top','-2','','','.b-switch'),(936835,'printshop','.b-switch .candlestick-wrapper','top','-2','','','.b-switch'),(936836,'printshop','.closeable-heading','top','0','3','',''),(936837,'printshop','.b-bottom .footerTitle','top','8','5333,4','','.b-bottom'),(936838,'printshop','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(936839,'printshop','.b-info-popup .info-popup div','top','15','3','','.b-info-popup'),(936840,'printshop','.b-form .form-inputs div.required-message','top','-15','','','.b-form'),(936841,'printshop','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(936842,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top','0','','','.b-select-suggest'),(936843,'printshop','.b-form .hide-billing-address','top','0','','','.b-form'),(936844,'printshop','.b-select-suggest .select2-measure-scrollbar','top','-10000','','','.b-select-suggest'),(936845,'printshop','.w-socials .post_item > div','top','10','3','','.w-socials'),(936846,'printshop','.w-cart-compare .atr-col','top','0','3','','.w-cart-compare'),(936847,'printshop','.b-info-popup .info-popup.top-left div','top','auto','3','','.b-info-popup'),(936848,'printshop','.b-info-popup .info-popup div','top','-12','','','.b-info-popup'),(936849,'printshop','.bell-ico .heading-2','top','5','3','','.bell-ico'),(936851,'printshop','.w-socials .post_item > div','top','10','3','','.w-socials'),(936852,'printshop','.w-socials .post_item > div','top','10','3','','.w-socials'),(936853,'printshop','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(936855,'printshop','.w-socials .post_item > div','top','10','3','','.w-socials'),(936856,'printshop','.message.success','top','3','3','',''),(936857,'printshop','.b-form .middle-form .required-message','top','-15','','','.b-form'),(936858,'printshop','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(936859,'printshop','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(936860,'printshop','.w-socials .post_item > div','top','10','3','','.w-socials'),(936861,'printshop','.b-info-popup .info-popup.top-left div','top','auto','','','.b-info-popup'),(936862,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(936863,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','top','8','','','.b-switch'),(936864,'printshop','.b-form .radio-button input[type=\"radio\"]','top','2','','','.b-form'),(936865,'printshop','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(936866,'printshop','.savings-ico .heading-2','top','5','3','','.savings-ico'),(936868,'printshop','.w-multi-cart-actions .cart-actions','top','-3','','','.w-multi-cart-actions'),(936869,'printshop','.b-fancybox .fancybox-overlay','top','0','','','.b-fancybox'),(936870,'printshop','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(936871,'printshop','.b-info .info','top','3','3','','.b-info'),(936872,'printshop','.w-promo-code .holder','top','19','3','','.w-promo-code'),(936873,'printshop','.w-promo-code .holder','top','2','5363,3','','.w-promo-code'),(936874,'printshop','.w-reviews .review','top','-16','3','','.w-reviews'),(936875,'printshop','.w-reviews .heading-3','top','0','3','','.w-reviews'),(936876,'printshop','.b-info .info','top','3','3','','.b-info'),(936877,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','top','4','3','','.b-switch'),(936878,'printshop','.w-menu-horizontal ul ul ul','top','0','','','.w-menu-horizontal'),(936881,'printshop','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(936882,'printshop','.b-form .payment-method .item-radio input','top','5','','','.b-form'),(936883,'printshop','.w-checkout-billing-address .genders-title input','top','2','','','.w-checkout-billing-address'),(936884,'printshop','.w-promo-code .holder','top','2','5363,3','','.w-promo-code'),(936885,'printshop','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(936886,'printshop','.w-menu-horizontal > ul > li > ul','top','100','','','.w-menu-horizontal'),(936887,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(936888,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(936889,'printshop','.b-info-popup .info-popup','top','4','3','','.b-info-popup'),(936890,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','top','1','3','','.b-form'),(936891,'printshop','.w-promo-code .holder','top','2','5363,3','','.w-promo-code'),(936892,'printshop','.b-upload-files .attach-active-holder .attach-file','top','-200','','','.b-upload-files'),(936893,'printshop','.w-promo-code .holder','top','2','5363,3','','.w-promo-code'),(936894,'printshop','.b-fancybox .fancybox-close','top','10','','','.b-fancybox'),(936895,'printshop','.w-product-customers-activity .close','top','5','','','.w-product-customers-activity'),(936896,'printshop','.w-reviews-content .review','top','-16','3','','.w-reviews-content'),(936898,'printshop','.w-cart-compare .remove-cart','top','0','','','.w-cart-compare'),(936899,'printshop','.w-promo-code .holder','top','19','3','','.w-promo-code'),(936900,'printshop','.w-promo-code .holder','top','19','3','','.w-promo-code'),(936901,'printshop','.w-promo-code .holder','top','2','5363,3','','.w-promo-code'),(936902,'printshop','.w-checkout-shipping-choice input','top','-200','','','.w-checkout-shipping-choice'),(936904,'printshop','.w-socials .post_item > div','top','10','3','','.w-socials'),(936905,'printshop','.w-product-reviews .reviews-list span','top','2','','','.w-product-reviews'),(936906,'printshop','.b-select-suggest .select2-search-choice-close','top','4','','','.b-select-suggest'),(936907,'printshop','.w-image-maps .svg-wrap svg','top','0','','','.w-image-maps'),(936908,'printshop','.w-neighbour-checkout .bootstrap-switch','top','-2','','','.w-neighbour-checkout'),(936909,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow','top','0','','','.b-select-suggest'),(936910,'printshop','.b-select-suggest .select2-drop-mask','top','0','','','.b-select-suggest'),(936911,'printshop','.b-select-suggest .select2-drop','top','100','','','.b-select-suggest'),(936913,'printshop','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(936915,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','top','4','3','','.b-switch'),(936916,'printshop','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(936917,'printshop','.w-checkout-create-account .account-benefits strong','top','3','3','','.w-checkout-create-account'),(936918,'printshop','.w-promo-code .holder','top','19','3','','.w-promo-code'),(936919,'printshop','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(936920,'printshop','.w-account-addresses-list .address-fields input[type=\"radio\"]','top','4','','','.w-account-addresses-list'),(936921,'printshop','.b-products-listing .products-listing .promos-info','top','0','','','.b-products-listing'),(936922,'printshop','.b-products-listing .hover-box-content','top','-10','3','','.b-products-listing'),(936923,'printshop','.b-products-listing .hover-box-content','top','40','','','.b-products-listing'),(936924,'printshop','.b-products-listing .loader','top','calc(50% - 15px)','4','','.b-products-listing'),(936925,'printshop','.b-products-listing .loader','top','0','3','','.b-products-listing'),(936926,'printshop','.b-products-listing .products-listing .qty-input.hidden','top','0','3','','.b-products-listing'),(936927,'printshop','.b-products-listing .promo','top','0','','','.b-products-listing'),(936932,'printshop','.w-promo-code .holder','top','19','3','','.w-promo-code'),(936933,'printshop','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(936934,'printshop','.w-checkout-gdpr .candlestick-wrapper','top','0','','','.w-checkout-gdpr'),(936935,'printshop','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(936936,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(936937,'printshop','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(936938,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','top','0','','','.b-switch'),(936939,'printshop','.b-form .eye-password','top','5','','','.b-form'),(936940,'printshop','.w-taxable input[type=\"radio\"]','top','2','','','.w-taxable'),(936941,'printshop','.w-taxable input[type=\"checkbox\"]','top','2','','','.w-taxable'),(936942,'printshop','.b-form .radio-button + .required-message-wrap .required-message','top','-5','','','.b-form'),(936943,'printshop','.b-info .info','top','3','3','','.b-info'),(936944,'printshop','.b-products-listing .products-listing .radio-attributes input','top','2','','','.b-products-listing'),(936947,'printshop','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(936948,'printshop','.w-promo-code .holder','top','19','3','','.w-promo-code'),(936949,'printshop','.b-info .info','top','3','3','','.b-info'),(936950,'printshop','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(936952,'printshop','.b-upload-file .upload-remove','top','5','','','.b-upload-file'),(936953,'printshop','.b-fancybox .fancybox-nav span','top','50','','','.b-fancybox'),(936954,'printshop','.b-fancybox .fancybox-nav','top','0','','','.b-fancybox'),(936955,'printshop','.b-form .addresses .address-item input[type=\"radio\"]','top','3','','','.b-form'),(936956,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','top','1','3','','.w-contact-contacts'),(936957,'printshop','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(936958,'printshop','.b-bottom .pop-up-close','top','7','','','.b-bottom'),(936959,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-container','top','0','','','.b-switch'),(936960,'printshop','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(936961,'printshop','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(936962,'printshop','.b-fancybox .fancybox-wrap','top','0','','','.b-fancybox'),(936963,'printshop','.w-menu-big > ul > li > ul','top','100','','','.w-menu-big'),(936964,'printshop','.b-select-suggest .select2-container .select2-choice abbr','top','8','','','.b-select-suggest'),(936965,'printshop','.w-filters .mobileCollapse','top','1','','','.w-filters'),(936966,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','top','0','','','.w-image-maps'),(936967,'printshop','.b-product-images .media-popup .mp-close','top','20','','','.b-product-images'),(936968,'printshop','.b-product-images .mp-shadow, .b-product-images .media-popup','top','0','','','.b-product-images'),(936969,'printshop','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top','100','','','.b-menu-lev_display-down'),(936970,'printshop','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top','100','','','.b-menu-lev_display-down'),(936971,'printshop','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top','100','','','.b-menu-lev_display-down'),(936972,'printshop','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top','100','','','.b-menu-lev_display-down'),(936973,'printshop','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top','100','','','.b-menu-lev_display-down'),(936974,'printshop','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','top','0','','','.b-menu-lev_display-left'),(936975,'printshop','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','top','0','','','.b-menu-lev_display-left'),(936976,'printshop','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','top','0','','','.b-menu-lev_display-left'),(936977,'printshop','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','top','0','','','.b-menu-lev_display-left'),(936978,'printshop','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','top','0','','','.b-menu-lev_display-left'),(936979,'printshop','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','top','0','','','.b-menu-lev_display-lra'),(936980,'printshop','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','top','0','','','.b-menu-lev_display-lra'),(936981,'printshop','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','top','0','','','.b-menu-lev_display-lra'),(936982,'printshop','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','top','0','','','.b-menu-lev_display-lra'),(936983,'printshop','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','top','0','','','.b-menu-lev_display-lra'),(936984,'printshop','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','top','0','','','.b-menu-lev_display-right'),(936985,'printshop','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','top','0','','','.b-menu-lev_display-right'),(936986,'printshop','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','top','0','','','.b-menu-lev_display-right'),(936987,'printshop','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','top','0','','','.b-menu-lev_display-right'),(936988,'printshop','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','top','0','','','.b-menu-lev_display-right'),(936989,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','top','0','','','.b-menu-lev_display-slide'),(936990,'printshop','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','top','0','','','.b-menu-lev_display-slide'),(936991,'printshop','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','top','0','','','.b-menu-lev_display-slide'),(936992,'printshop','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','top','0','','','.b-menu-lev_display-slide'),(936993,'printshop','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','top','0','','','.b-menu-lev_display-slide'),(936994,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','top','0','','','.b-menu-open_from-left'),(936995,'printshop','.tripleBanner .w-html_box','top','0','3','','.tripleBanner'),(936996,'printshop','.b-slick .slick-track','top','0','','','.b-slick'),(936997,'printshop','.b-slick .slick-vertical button.slick-next','top','auto','','','.b-slick'),(936998,'printshop','.b-slick .slick-vertical button.slick-prev','top','0','','','.b-slick'),(936999,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','top','50','','','.b-slick'),(937000,'printshop','.menu-header .w-menu','top','-48','5342','','.menu-header'),(937001,'printshop','.header','top','0','5342','',''),(937002,'printshop','.w-quote .multicart .switch-cart','top','14','','','.w-quote'),(937004,'printshop','.warrantyProduct .warranty','top','50','3','','.warrantyProduct'),(937005,'printshop','.warrantyProduct .delivery','top','50','3','','.warrantyProduct'),(937006,'printshop','.w-files-catalog-widgets-files-list .file','top','-1','3','','.w-files-catalog-widgets-files-list'),(937007,'printshop','.w-sample .multicart .switch-cart','top','14','','','.w-sample'),(937008,'printshop','.w-sample .qty','top','-1','4','','.w-sample'),(937009,'printshop','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(937010,'printshop','.w-product-inventory input[type=\"radio\"]','top','1','','','.w-product-inventory'),(937012,'printshop','.w-product-properties-filters-widgets-chosen-filters .remove','top','2','3','','.w-product-properties-filters-widgets-chosen-filters'),(937013,'printshop','.p-sample-checkout-index .order-summary .heading-2','top','-10','3','','.p-sample-checkout-index'),(937014,'printshop','.p-sample-checkout-index .order-summary .heading-2','top','-10','4','','.p-sample-checkout-index'),(937015,'printshop','.w-account-personal-catalog .list-row-action ul','top','5','4','','.w-account-personal-catalog'),(937016,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input','top','-50','','','.w-questionnaire-widgets-questionnaire'),(937017,'printshop','.w-sale-category .badge','top','10','','','.w-sale-category'),(937018,'printshop','.w-product-properties-icons .hover-box-content','top','50','','','.w-product-properties-icons'),(937019,'printshop','.w-product-designer-designer .productDesignerBox input','top','0','','','.w-product-designer-designer'),(937020,'printshop','.w-product-configurator .pc-item label input','top','5','','','.w-product-configurator'),(937021,'printshop','.w-predefined-promotion .prom-multi-discount .products','top','-13','','','.w-predefined-promotion'),(937022,'printshop','.w-predefined-promotion .prom-multi-discount > .heading','top','2','3','','.w-predefined-promotion'),(937023,'printshop','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','top','2','3','','.w-predefined-promotion'),(937024,'printshop','.w-predefined-promotion .promo-cart-discount .promo-min-qty','top','-19','','','.w-predefined-promotion'),(937025,'printshop','.w-predefined-promotion .promo-cart-discount .slave .content','top','-17','','','.w-predefined-promotion'),(937026,'printshop','.w-predefined-promotion .promo-date','top','-10','','','.w-predefined-promotion'),(937027,'printshop','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','top','2','3','','.w-predefined-promotion'),(937030,'printshop','.p-wedding-registry-view h1','top','-4','3','','.p-wedding-registry-view'),(937031,'printshop','.p-wedding-registry-view h1','top','-4','4','','.p-wedding-registry-view'),(937032,'printshop','.b-menu-open_from-top .menu-style[data-open_from=\"top\"] .menu-content','top','140','','','.b-menu-open_from-top'),(937033,'printshop','.b-menu-open_from-top .menu-style[data-open_from=\"top\"] .menu-content','top','70','5342','','.b-menu-open_from-top'),(937034,'printshop','.topBanner .ourPick','top','50','3','','.topBanner'),(937035,'printshop','.topBanner .ourPick','top','50','4','','.topBanner'),(937036,'printshop','.topBanner .ourPick','top','50','5347,4','','.topBanner'),(937037,'printshop','.topBanner .w-banner .banner-item .banner-text','top','0','','','.topBanner'),(937038,'printshop','.topBanner .w-banner .text-middle-left .banner-text','top','2','5333','','.topBanner'),(937039,'printshop','.order-summary .icon','top','0','3','','.order-summary'),(937049,'printshop','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','top','2','3','','.account-order-pay'),(937050,'printshop','.account-order-pay .not_fully_paid_td','top','19','','','.account-order-pay'),(937051,'printshop','.account-samples .not_fully_paid_td','top','19','','','.account-samples'),(937052,'printshop','.account-samples .view_link','top','4','4','','.account-samples'),(937053,'printshop','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','top','2','3','','.account-sample-info'),(937054,'printshop','.account-sample-info .not_fully_paid_td','top','19','','','.account-sample-info'),(937055,'printshop','.catalog-product-wrap .pn-image','top','120','3','','.catalog-product-wrap'),(937056,'printshop','.catalog-product-wrap .prev-next-product','top','calc(50% - 200px)','','','.catalog-product-wrap'),(937057,'printshop','.shopping-cart-index .gift-code .heading-4','top','0','4','','.shopping-cart-index'),(937058,'printshop','.checkout-order-confirmation .discount-ico','top','3','3','','.checkout-order-confirmation'),(937059,'printshop','.hide-page','top','0','','',''),(937060,'printshop','.success-page .comment-ico','top','7','3','','.success-page'),(937061,'printshop','.success-page .discount-ico','top','3','3','','.success-page'),(937062,'printshop','.success-page .order-ico','top','7','3','','.success-page'),(937063,'printshop','.success-page .page-success .text-1','top','7','3','','.success-page'),(937064,'printshop','.success-page .w-cart-listing .qty','top','10','','','.success-page'),(937065,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','top','-2','4','','.b-multi-page-checkout'),(937067,'printshop','.footer-menu .level-1 > li','top','16','5342,3','','.footer-menu'),(937068,'printshop','.w-bestsellers .heading-3','top','0','3','','.w-bestsellers'),(937069,'printshop','.w-banner .banner img + img','top','0','','','.w-banner'),(937070,'printshop','.w-banner .carousel-text','top','0','','','.w-banner'),(937071,'printshop','.w-banner .image-text-banner.bottom-center .text-banner','top','auto','','','.w-banner'),(937072,'printshop','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','top','0','','','.w-banner'),(937073,'printshop','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','top','0','','','.w-banner'),(937074,'printshop','.w-banner .image-text-banner.top-left .text-banner','top','0','','','.w-banner'),(937075,'printshop','.w-banner .image-text-banner.top-right .text-banner','top','0','','','.w-banner'),(937076,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top','0','','','.w-catalog-paging'),(937079,'printshop','.w-sale .badge','top','10','','','.w-sale'),(937080,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top_important','important','','','.b-select-suggest'),(937081,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top_important','important','','','.w-catalog-paging'),(937082,'printshop','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(937084,'printshop','.b-fancybox #fancybox-loading','top_measure','%','','','.b-fancybox'),(937085,'printshop','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(937086,'printshop','.view-all','top_measure','%','3','',''),(937087,'printshop','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(937088,'printshop','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(937089,'printshop','.w-menu-horizontal > ul > li > ul','top_measure','%','','','.w-menu-horizontal'),(937090,'printshop','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(937091,'printshop','.b-select-suggest .select2-drop','top_measure','%','','','.b-select-suggest'),(937092,'printshop','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(937093,'printshop','.b-fancybox .fancybox-nav span','top_measure','%','','','.b-fancybox'),(937094,'printshop','.w-menu-big > ul > li > ul','top_measure','%','','','.w-menu-big'),(937095,'printshop','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top_measure','%','','','.b-menu-lev_display-down'),(937096,'printshop','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top_measure','%','','','.b-menu-lev_display-down'),(937097,'printshop','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top_measure','%','','','.b-menu-lev_display-down'),(937098,'printshop','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top_measure','%','','','.b-menu-lev_display-down'),(937099,'printshop','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top_measure','%','','','.b-menu-lev_display-down'),(937100,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','top_measure','%','','','.b-slick'),(937101,'printshop','.warrantyProduct .warranty','top_measure','%','3','','.warrantyProduct'),(937102,'printshop','.warrantyProduct .delivery','top_measure','%','3','','.warrantyProduct'),(937103,'printshop','.w-product-properties-icons .hover-box-content','top_measure','%','','','.w-product-properties-icons'),(937106,'printshop','.topBanner .ourPick','top_measure','%','3','','.topBanner'),(937107,'printshop','.topBanner .ourPick','top_measure','%','4','','.topBanner'),(937108,'printshop','.topBanner .ourPick','top_measure','%','5347,4','','.topBanner'),(937109,'printshop','.topBanner .w-banner .text-middle-left .banner-text','top_measure','%','5333','','.topBanner'),(937112,'printshop','.b-slick .slick-slider','touch-action','pan-y','','','.b-slick'),(937113,'printshop','.b-products-listing .hover-box-content','transform','rotate( 45deg )','3','','.b-products-listing'),(937114,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-container','transform','translate3d(0, 0, 0)','','','.b-switch'),(937115,'printshop','.b-product-images .media-popup .mp-close','transform','scale(1.5)','1','','.b-product-images'),(937116,'printshop','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','transform','scale(1.2)','1','','.b-product-images'),(937117,'printshop','.b-product-images .media-popup .slick-list:first-child .slick-track','transform','none','','','.b-product-images'),(937118,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','transform','scale(1.5)','1','','.b-product-images'),(937119,'printshop','.b-menu-lev_display-slide .menu-style .slide-parent','transform','translateX(-100vw)','','','.b-menu-lev_display-slide'),(937120,'printshop','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','transform','translate3d(0, 0, 0)','','','.b-slick'),(937122,'printshop','.b-product-images .media-popup .slick-list:first-child .slick-track','transform_important','important','','','.b-product-images'),(937123,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','transition','0.3s','','','.b-switch'),(937124,'printshop','.b-switch .bootstrap-switch','transition','border-color ease-in-out .15s, box-shadow ease-in-out .15s','','','.b-switch'),(937125,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-animate .bootstrap-switch-container','transition','margin-left 0.5s','','','.b-switch'),(937126,'printshop','.b-product-images .media-popup .mp-close','transition','transform 0.3s, color 0.3s','','','.b-product-images'),(937127,'printshop','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','transition','transform 0.3s','','','.b-product-images'),(937128,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','transition','transform 0.3s, color 0.3s','','','.b-product-images'),(937129,'printshop','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','transition','max-height 1s','','','.b-menu-burger_icon'),(937130,'printshop','.b-menu-lev_display-slide .menu-style ul','transition','visibility 300ms, transform 300ms','','','.b-menu-lev_display-slide'),(937131,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','transition','left 300ms','','','.b-menu-open_from-left'),(937132,'printshop','.b-menu-open_from-top .menu-style[data-open_from=\"top\"] .menu-content','transition','left 300ms','','','.b-menu-open_from-top'),(937134,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','user-select','none','','','.b-select-suggest'),(937135,'printshop','.b-select-suggest .select2-results .select2-result-label','user-select','none','','','.b-select-suggest'),(937136,'printshop','.b-select-suggest .select2-container .select2-choice','user-select','none','','','.b-select-suggest'),(937137,'printshop','.b-slick .slick-slider','user-select','none','','','.b-slick'),(937138,'printshop','.b-email .name','vertical-align','top','','','.b-email'),(937139,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.p-quick-order-index'),(937140,'printshop','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.p-quick-order-index'),(937141,'printshop','.b-email .model','vertical-align','top','','','.b-email'),(937142,'printshop','.w-categories .item','vertical-align','top','','','.w-categories'),(937143,'printshop','.w-promotions .heading-3','vertical-align','top','','','.w-promotions'),(937144,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','vertical-align','top','','','.b-warehouses-popup'),(937145,'printshop','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(937146,'printshop','.b-upload-file .upload-file-template','vertical-align','top','','','.b-upload-file'),(937147,'printshop','.b-messages .msv_to_cc div span','vertical-align','middle','','','.b-messages'),(937148,'printshop','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(937149,'printshop','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(937150,'printshop','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(937151,'printshop','.b-email .price','vertical-align','top','','','.b-email'),(937152,'printshop','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(937153,'printshop','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(937154,'printshop','.b-switch .bootstrap-switch','vertical-align','middle','','','.b-switch'),(937155,'printshop','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','vertical-align','middle','','','.w-menu-horizontal'),(937156,'printshop','.w-filters .input-checkbox:checked + .checkbox-span','vertical-align','middle','','','.w-filters'),(937157,'printshop','.b-email .name','vertical-align','top','','','.b-email'),(937158,'printshop','.b-email .qty','vertical-align','top','','','.b-email'),(937159,'printshop','.b-email .image','vertical-align','top','','','.b-email'),(937160,'printshop','.b-form .checkbox-style:checked + .checkbox-span','vertical-align','middle','','','.b-form'),(937161,'printshop','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','vertical-align','middle','','','.b-form'),(937162,'printshop','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(937163,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','vertical-align','top','','','.b-switch'),(937164,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','vertical-align','middle','','','.b-switch'),(937165,'printshop','.b-switch .candlestick-wrapper','vertical-align','middle','','','.b-switch'),(937166,'printshop','.order-summary .price-row.ot_gv .title','vertical-align','top','3','','.order-summary'),(937167,'printshop','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(937168,'printshop','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(937169,'printshop','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(937170,'printshop','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(937171,'printshop','.w-tabs .tab-li','vertical-align','bottom','','','.w-tabs'),(937172,'printshop','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(937173,'printshop','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(937174,'printshop','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(937175,'printshop','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(937176,'printshop','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(937177,'printshop','.b-email .image','vertical-align','top','','','.b-email'),(937178,'printshop','.w-checkout-billing-address .genders-title > div','vertical-align','top','','','.w-checkout-billing-address'),(937179,'printshop','.w-checkout-shipping-address .genders-title > div','vertical-align','top','','','.w-checkout-shipping-address'),(937180,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span','vertical-align','middle','','','.b-form'),(937181,'printshop','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(937182,'printshop','.b-email .qty','vertical-align','top','','','.b-email'),(937183,'printshop','.b-email .price','vertical-align','top','','','.b-email'),(937184,'printshop','.b-email .price','vertical-align','top','','','.b-email'),(937185,'printshop','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(937186,'printshop','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(937187,'printshop','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(937188,'printshop','.w-top-categories .item','vertical-align','top','','','.w-top-categories'),(937189,'printshop','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(937190,'printshop','.b-email .qty','vertical-align','top','','','.b-email'),(937191,'printshop','.b-email .name','vertical-align','top','','','.b-email'),(937192,'printshop','.b-email .model','vertical-align','top','','','.b-email'),(937193,'printshop','.b-email .price','vertical-align','top','','','.b-email'),(937194,'printshop','.b-email .image','vertical-align','top','','','.b-email'),(937195,'printshop','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(937196,'printshop','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(937197,'printshop','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(937198,'printshop','.b-email .price','vertical-align','top','','','.b-email'),(937199,'printshop','.b-email .model','vertical-align','top','','','.b-email'),(937200,'printshop','.b-email .model','vertical-align','top','','','.b-email'),(937201,'printshop','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(937202,'printshop','.b-email .model','vertical-align','top','','','.b-email'),(937203,'printshop','.b-compare .compare_select_items','vertical-align','middle','','','.b-compare'),(937204,'printshop','.b-email .name','vertical-align','top','','','.b-email'),(937205,'printshop','.b-email .image','vertical-align','top','','','.b-email'),(937206,'printshop','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(937207,'printshop','.b-email .price','vertical-align','top','','','.b-email'),(937208,'printshop','.w-cart-compare .product-label','vertical-align','bottom','','','.w-cart-compare'),(937209,'printshop','.w-product-available-in-warehouses .warehouse-item','vertical-align','top','','','.w-product-available-in-warehouses'),(937210,'printshop','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(937211,'printshop','.w-cart-compare .product-actions .dropdown-toggle','vertical-align','middle','3','','.w-cart-compare'),(937212,'printshop','.w-menu-big li li','vertical-align','top','','','.w-menu-big'),(937213,'printshop','.w-cart-compare .product-cell','vertical-align','top','','','.w-cart-compare'),(937214,'printshop','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(937215,'printshop','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(937216,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.b-data-table'),(937217,'printshop','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.b-data-table'),(937218,'printshop','.b-products-listing .products-listing .item','vertical-align','top','','','.b-products-listing'),(937219,'printshop','.checkbox input + span','vertical-align','middle','','',''),(937220,'printshop','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(937221,'printshop','.b-email .name','vertical-align','top','','','.b-email'),(937222,'printshop','.b-email .image','vertical-align','top','','','.b-email'),(937223,'printshop','.b-email .qty','vertical-align','top','','','.b-email'),(937224,'printshop','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(937225,'printshop','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(937226,'printshop','.order-summary .price-row.ot_coupon .title','vertical-align','top','3','','.order-summary'),(937227,'printshop','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(937228,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','','','.w-communication-new-topic'),(937229,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','3','','.w-communication-new-topic'),(937230,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','vertical-align','top','','','.w-communication-new-topic'),(937231,'printshop','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','vertical-align','bottom','','','.w-communication-new-topic'),(937232,'printshop','.w-quote .no-text','vertical-align','top','','','.w-quote'),(937233,'printshop','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(937234,'printshop','.b-email .qty','vertical-align','top','','','.b-email'),(937235,'printshop','.b-email .name','vertical-align','top','','','.b-email'),(937236,'printshop','.b-email .image','vertical-align','top','','','.b-email'),(937237,'printshop','.w-catalog-listing-look .grid','vertical-align','top','','','.w-catalog-listing-look'),(937238,'printshop','.w-catalog-listing-look .b2b','vertical-align','top','','','.w-catalog-listing-look'),(937239,'printshop','.w-catalog-listing-look .list','vertical-align','top','','','.w-catalog-listing-look'),(937240,'printshop','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(937242,'printshop','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','vertical-align','top','','','.b-fancybox'),(937243,'printshop','.b-email .model','vertical-align','top','','','.b-email'),(937244,'printshop','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(937245,'printshop','.order-summary .price-row.ot_bonus_points .title','vertical-align','top','3','','.order-summary'),(937246,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align','top','','','.b-switch'),(937247,'printshop','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','vertical-align','top','','','.b-fancybox'),(937248,'printshop','.w-menu-big li a, .w-menu-big li .no-link','vertical-align','middle','','','.w-menu-big'),(937249,'printshop','.b-email .qty','vertical-align','top','','','.b-email'),(937250,'printshop','.w-filters .input-checkbox:not(checked) + .checkbox-span','vertical-align','middle','','','.w-filters'),(937251,'printshop','.b-product-images .media-popup .mp-small-images .item','vertical-align','top','','','.b-product-images'),(937252,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','vertical-align','middle','3','','.w-catalog-compare'),(937253,'printshop','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','vertical-align','middle','','','.b-cookie-notice'),(937254,'printshop','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(937255,'printshop','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(937256,'printshop','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(937257,'printshop','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(937258,'printshop','.w-sample .no-text','vertical-align','top','','','.w-sample'),(937259,'printshop','.w-cart-order-reference .btn','vertical-align','top','','','.w-cart-order-reference'),(937260,'printshop','.w-cart-gift-certificate .btn','vertical-align','top','','','.w-cart-gift-certificate'),(937261,'printshop','.w-cart-shipping-estimator .btn','vertical-align','top','','','.w-cart-shipping-estimator'),(937263,'printshop','.b-pagination .pagination .next-pages','vertical-align','top','','','.b-pagination'),(937264,'printshop','.b-pagination .pagination .page-number','vertical-align','top','','','.b-pagination'),(937265,'printshop','.b-pagination .pagination .prev-pages','vertical-align','top','','','.b-pagination'),(937266,'printshop','.b-pagination .pagination a.next, .b-pagination .pagination span.next','vertical-align','top','','','.b-pagination'),(937267,'printshop','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','vertical-align','top','','','.b-pagination'),(937268,'printshop','.b-pagination .pagination span','vertical-align','top','2','','.b-pagination'),(937269,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','vertical-align','top','','','.w-rma-returns-history'),(937270,'printshop','.w-product-configurator .item-content > div','vertical-align','top','','','.w-product-configurator'),(937271,'printshop','.w-predefined-promotion .heading-3','vertical-align','top','','','.w-predefined-promotion'),(937272,'printshop','.b-quantity .qty-box input[type=\"text\"]','vertical-align','top','','','.b-quantity'),(937273,'printshop','.w-cart-listing .remove-btn','vertical-align','middle','3','','.w-cart-listing'),(937274,'printshop','.w-cart-listing .remove-btn span','vertical-align','middle','','','.w-cart-listing'),(937275,'printshop','.tripleLine .text-banner-2 > div a','vertical-align','middle','4','','.tripleLine'),(937276,'printshop','.middleBanner .btn-1','vertical-align','middle','4','','.middleBanner'),(937277,'printshop','.bottomBanner .btn-1','vertical-align','middle','4','','.bottomBanner'),(937280,'printshop','.p-payer-order-pay .comment-ico','vertical-align','middle','3','','.p-payer-order-pay'),(937281,'printshop','.p-payer-order-confirmation .comment-ico','vertical-align','middle','3','','.p-payer-order-confirmation'),(937282,'printshop','.topBanner .content .btn','vertical-align','middle','4','','.topBanner'),(937283,'printshop','.topBanner .ourPick','vertical-align','middle','3','','.topBanner'),(937284,'printshop','.topBanner .ourPick','vertical-align','middle','4','','.topBanner'),(937285,'printshop','.topBanner .ourPick','vertical-align','middle','','','.topBanner'),(937286,'printshop','.topBanner .ourPick','vertical-align','middle','5347,4','','.topBanner'),(937287,'printshop','.topBanner .content','vertical-align','middle','','','.topBanner'),(937288,'printshop','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','vertical-align','top','','','.w-promotions-widgets-promotion-icons-desc'),(937289,'printshop','.w-promotions-widgets-promotion-icons-desc .promo-icon','vertical-align','top','','','.w-promotions-widgets-promotion-icons-desc'),(937290,'printshop','.tripleLine .banner-text-holder > div a','vertical-align','middle','4','','.tripleLine'),(937291,'printshop','.w-cart-discount-coupon .title','vertical-align','middle','4','','.w-cart-discount-coupon'),(937292,'printshop','.w-cart-checkout-btn .with-card','vertical-align','middle','4','','.w-cart-checkout-btn'),(937293,'printshop','.p-quote-checkout-index .comment-ico','vertical-align','middle','3','','.p-quote-checkout-index'),(937297,'printshop','.account-samples .view_link','vertical-align','middle','4','','.account-samples'),(937298,'printshop','.checkout-index-wrap .comment-ico','vertical-align','middle','3','','.checkout-index-wrap'),(937299,'printshop','.checkout-order-confirmation .comment-ico','vertical-align','middle','3','','.checkout-order-confirmation'),(937300,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','vertical-align','middle','3','','.b-multi-page-checkout'),(937301,'printshop','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','vertical-align','middle','','','.w-banner'),(937302,'printshop','.w-catalog-paging ','vertical-align','top','2','','.w-catalog-paging'),(937303,'printshop','.w-catalog-paging .next','vertical-align','top','','','.w-catalog-paging'),(937304,'printshop','.w-catalog-paging .next-pages','vertical-align','top','','','.w-catalog-paging'),(937305,'printshop','.w-catalog-paging .page-number','vertical-align','top','','','.w-catalog-paging'),(937306,'printshop','.w-catalog-paging .prev','vertical-align','top','','','.w-catalog-paging'),(937307,'printshop','.w-catalog-paging .prev-pages','vertical-align','top','','','.w-catalog-paging'),(937308,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','vertical-align','top','','','.w-catalog-paging'),(937309,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align_important','important','','','.b-switch'),(937310,'printshop','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(937311,'printshop','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(937312,'printshop','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(937313,'printshop','.b-fancybox .fancybox-tmp','visibility','hidden','','','.b-fancybox'),(937314,'printshop','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(937315,'printshop','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(937316,'printshop','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(937317,'printshop','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(937318,'printshop','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(937319,'printshop','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(937320,'printshop','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(937321,'printshop','.b-upload-files .attach-active-holder .attach-file','visibility','hidden','','','.b-upload-files'),(937322,'printshop','.b-fancybox .fancybox-nav:hover span','visibility','visible','','','.b-fancybox'),(937323,'printshop','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(937324,'printshop','.b-fancybox .fancybox-opened .fancybox-title','visibility','visible','','','.b-fancybox'),(937325,'printshop','.checkbox input','visibility','hidden','','',''),(937326,'printshop','.b-fancybox .fancybox-title','visibility','hidden','','','.b-fancybox'),(937327,'printshop','.b-fancybox .fancybox-nav span','visibility','hidden','','','.b-fancybox'),(937328,'printshop','.b-form .radio-button input[type=\"radio\"].no','visibility','hidden','','','.b-form'),(937329,'printshop','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(937330,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','visibility','hidden','','','.b-menu-lev_display-slide'),(937331,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-1 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(937332,'printshop','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','visibility','hidden','','','.b-menu-lev_display-slide'),(937333,'printshop','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','visibility','hidden','','','.b-menu-lev_display-slide'),(937334,'printshop','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','visibility','hidden','','','.b-menu-lev_display-slide'),(937335,'printshop','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','visibility','hidden','','','.b-menu-lev_display-slide'),(937336,'printshop','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-2 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(937337,'printshop','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-4 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(937338,'printshop','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-5 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(937339,'printshop','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-3 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(937340,'printshop','.b-slick .slick-loading .slick-slide','visibility','hidden','','','.b-slick'),(937341,'printshop','.b-slick .slick-loading .slick-track','visibility','hidden','','','.b-slick'),(937342,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no input','visibility','hidden','','','.w-questionnaire-widgets-questionnaire'),(937343,'printshop','.b-fancybox .fancybox-title-float-wrap .child','white-space','nowrap','','','.b-fancybox'),(937344,'printshop','.w-checkout-shipping-choice span','white-space','nowrap','5363','','.w-checkout-shipping-choice'),(937345,'printshop','.b-select-suggest .select2-container .select2-choice > .select2-chosen','white-space','nowrap','','','.b-select-suggest'),(937346,'printshop','.w-menu-horizontal > ul','white-space','nowrap','','','.w-menu-horizontal'),(937347,'printshop','.w-menu-horizontal > ul','white-space','normal','5342','','.w-menu-horizontal'),(937348,'printshop','.b-fancybox .fancybox-error','white-space','nowrap','','','.b-fancybox'),(937349,'printshop','.w-catalog-sorting .before','white-space','nowrap','','','.w-catalog-sorting'),(937350,'printshop','.b-select-suggest .select2-search','white-space','nowrap','','','.b-select-suggest'),(937351,'printshop','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','white-space','nowrap','','','.b-select-suggest'),(937352,'printshop','.b-select-suggest .select2-container .select2-choice','white-space','nowrap','','','.b-select-suggest'),(937353,'printshop','.w-cart-listing .remove-btn','white-space','nowrap','5342','','.w-cart-listing'),(937354,'printshop','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(937355,'printshop','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','white-space','nowrap','','','.w-cart-listing'),(937357,'printshop','.account-samples .view_link','white-space','nowrap','','','.account-samples'),(937358,'printshop','.w-communication-new-topic .model','width','100','','','.w-communication-new-topic'),(937359,'printshop','.w-communication-new-topic .date-purchased','width','130','','','.w-communication-new-topic'),(937360,'printshop','.w-communication-new-topic .request-type','width','150','','','.w-communication-new-topic'),(937361,'printshop','.w-communication-new-topic .return-reason','width','150','','','.w-communication-new-topic'),(937362,'printshop','.b-form .col-left','width','48','','','.b-form'),(937363,'printshop','.b-email img','width','60','','','.b-email'),(937364,'printshop','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(937365,'printshop','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(937366,'printshop','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(937367,'printshop','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(937368,'printshop','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(937369,'printshop','.w-product-images-additional .item','width','80','5363','','.w-product-images-additional'),(937371,'printshop','.b-email .totals-value','width','30','','','.b-email'),(937372,'printshop','.w-promotions .prom-multi-discount .image img','width','auto','','','.w-promotions'),(937373,'printshop','.w-promotions .promo-salemaker > div','width','50','','','.w-promotions'),(937374,'printshop','.w-promotions .promo-cart-discount > div','width','50','','','.w-promotions'),(937379,'printshop','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width','100','','','.p-sample-checkout-login'),(937380,'printshop','.b-email .image','width','100','','','.b-email'),(937381,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(937382,'printshop','.w-categories .item','width','20','','','.w-categories'),(937383,'printshop','.w-promotions .prom-multi-discount .list','width','100','','','.w-promotions'),(937384,'printshop','.w-promotions .nextdiscount .item-holder .image','width','40','','','.w-promotions'),(937385,'printshop','.w-promotions .nextdiscount .item-holder .name','width','60','','','.w-promotions'),(937386,'printshop','.w-promotions .icon','width','45','','','.w-promotions'),(937387,'printshop','.w-promotions .promo-salemaker .image img','width','auto','','','.w-promotions'),(937388,'printshop','.w-promotions .promo-salemaker .item','width','50','','','.w-promotions'),(937389,'printshop','.w-promotions .promo-cart-discount .slave .item','width','calc(50% - 4px)','','','.w-promotions'),(937390,'printshop','.w-promotions .promo-cart-discount .image img','width','auto','','','.w-promotions'),(937391,'printshop','.b-warehouses-popup .warehouses-popup','width','570','','','.b-warehouses-popup'),(937392,'printshop','.b-warehouses-popup .warehouses-popup .warehouse-item','width','230','','','.b-warehouses-popup'),(937393,'printshop','.b-preloader .preloader','width','40','3','','.b-preloader'),(937394,'printshop','.b-preloader .preloader','width','100','','','.b-preloader'),(937395,'printshop','.b-products-listing .products-listing .attribute-qty-block','width','47','','','.b-products-listing'),(937396,'printshop','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(937397,'printshop','.w-brands .brands-listing > div','width','16','','','.w-brands'),(937398,'printshop','.w-cart-continue-btn a','width','100','5333','','.w-cart-continue-btn'),(937399,'printshop','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(937400,'printshop','.order-summary .price-row.ot_gv .title','width','32','3','','.order-summary'),(937401,'printshop','.w-brands .brands-listing > div','width','16','','','.w-brands'),(937402,'printshop','.w-login-block .returning','width','50','','','.w-login-block'),(937403,'printshop','.w-product-images-additional .item','width','80','5363','','.w-product-images-additional'),(937404,'printshop','.w-product-images-additional .additional-images','width','80','5363','','.w-product-images-additional'),(937405,'printshop','.b-products-listing .select-attributes select','width','66','','','.b-products-listing'),(937406,'printshop','.b-messages .box-block.type-6 > .block:nth-child(1)','width','25','','','.b-messages'),(937407,'printshop','.b-messages .msv_to_cc div span.msv_to_cc_bold','width','100','','','.b-messages'),(937408,'printshop','.b-messages .messages-sidebar .btn-2','width','100','','','.b-messages'),(937409,'printshop','.b-messages .pre_upload','width','auto','','','.b-messages'),(937410,'printshop','.b-messages .email-line input','width','100','','','.b-messages'),(937411,'printshop','.b-messages .email-line label','width','150','','','.b-messages'),(937412,'printshop','.b-messages #DataTables_Table_0_wrapper table.dataTable thead td:last-child, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td:last-child','width','200','','','.b-messages'),(937413,'printshop','.w-sitemap-delivery-location > ul > li > ul > li','width','25','','','.w-sitemap-delivery-location'),(937414,'printshop','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(937415,'printshop','.b-bottom .terms-info-popup','width','1000','','','.b-bottom'),(937416,'printshop','.b-form .col-right','width','100','5342','','.b-form'),(937417,'printshop','.p-payer-order-confirmation .order-summary2 .btn-2','width','100','','','.p-payer-order-confirmation'),(937418,'printshop','.p-payer-order-pay .order-summary2 .btn-2','width','100','','','.p-payer-order-pay'),(937419,'printshop','.w-checkout-terms .required-message','width','100','','','.w-checkout-terms'),(937420,'printshop','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(937421,'printshop','.w-checkout-create-btn .btn-2','width','260','','','.w-checkout-create-btn'),(937422,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','width','15','','','.b-switch'),(937423,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-toggle','width','40','','','.b-switch'),(937424,'printshop','.b-fancybox #fancybox-loading div','width','44','','','.b-fancybox'),(937425,'printshop','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','width','79','','','.b-datepicker'),(937426,'printshop','.b-email .image','width','100','','','.b-email'),(937427,'printshop','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','width','25','3','','.w-checkout-contact-information'),(937428,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','width','100','','','.b-switch'),(937429,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','width','15','','','.b-switch'),(937430,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width','20','3','','.b-switch'),(937431,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','width','150','','','.w-upload-customer-id-upload-customer-id-form'),(937432,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(937433,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-details','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(937434,'printshop','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(937435,'printshop','.b-email .image','width','100','','','.b-email'),(937436,'printshop','.w-checkout-bonus-points .btn-remove','width','25','','','.w-checkout-bonus-points'),(937437,'printshop','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(937438,'printshop','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(937439,'printshop','.w-login-block .input','width','100','','','.w-login-block'),(937440,'printshop','.w-login-block .guest','width','50','','','.w-login-block'),(937441,'printshop','.w-login-block .new','width','50','','','.w-login-block'),(937442,'printshop','.w-menu-horizontal li','width','auto','','','.w-menu-horizontal'),(937443,'printshop','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(937444,'printshop','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(937445,'printshop','.w-login-block .input','width','100','','','.w-login-block'),(937446,'printshop','.b-form .checkbox-style:checked + .checkbox-span','width','15','','','.b-form'),(937447,'printshop','.w-delayed-despatch-checkout #delivery_date','width','150','','','.w-delayed-despatch-checkout'),(937448,'printshop','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(937449,'printshop','.w-product-images-additional .item-div','width','80','5363','','.w-product-images-additional'),(937450,'printshop','.w-product-wishlist-button .btn','width','100','5333','','.w-product-wishlist-button'),(937451,'printshop','.b-fancybox .fancybox-lock','width','auto','','','.b-fancybox'),(937452,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','width','15','','','.b-switch'),(937453,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','width','10','','','.b-switch'),(937454,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','width','10','','','.b-switch'),(937455,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs','width','30','','','.b-switch'),(937456,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-toggle','width','15','','','.b-switch'),(937458,'printshop','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(937459,'printshop','.w-promo-code .promo-code-form','width','100','5342','','.w-promo-code'),(937460,'printshop','.b-email .totals-value','width','30','','','.b-email'),(937461,'printshop','.b-email .totals-title','width','70','','','.b-email'),(937462,'printshop','.w-filters .ui-slider-handle','width','15','','','.w-filters'),(937464,'printshop','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(937465,'printshop','.w-login-block .returning','width','50','','','.w-login-block'),(937467,'printshop','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(937469,'printshop','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(937470,'printshop','.b-products-listing .btn-choose-options','width','100','','','.b-products-listing'),(937471,'printshop','.w-filters .input-checkbox:checked + .checkbox-span','width','24','','','.w-filters'),(937472,'printshop','.w-filters .ui-slider','width','100','','','.w-filters'),(937473,'printshop','.w-checkout-shipping-choice input:checked + span:before','width','10','','','.w-checkout-shipping-choice'),(937474,'printshop','.b-switch .candlestick-wrapper','width','60','','','.b-switch'),(937475,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','width','20','3','','.b-switch'),(937476,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(937477,'printshop','.b-email .image','width','100','','','.b-email'),(937478,'printshop','.b-email .totals-value','width','30','','','.b-email'),(937479,'printshop','.b-email .heading-image','width','100','','','.b-email'),(937480,'printshop','.b-email .products-table','width','100','','','.b-email'),(937481,'printshop','.b-form .login-col-1','width','25','','','.b-form'),(937482,'printshop','.b-select-suggest .select2-container','width','100','','','.b-select-suggest'),(937483,'printshop','.b-select-suggest .select2-measure-scrollbar','width','100','','','.b-select-suggest'),(937484,'printshop','.b-email-editor img','width','auto','','','.b-email-editor'),(937485,'printshop','.b-form .middle-form .dob-input input[type=\"text\"]','width','48','','','.b-form'),(937486,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width','1','','','.b-select-suggest'),(937487,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(937488,'printshop','.w-brands .brands-listing > div','width','16','','','.w-brands'),(937489,'printshop','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(937490,'printshop','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(937491,'printshop','.w-socials .post_item_img','width','100','','','.w-socials'),(937493,'printshop','.b-info-popup .info-popup div','width','250','','','.b-info-popup'),(937494,'printshop','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5342','','.w-promo-code'),(937495,'printshop','.w-brands .brands-listing > div','width','16','','','.w-brands'),(937496,'printshop','.w-cart-listing .right-area','width','100','5342','','.w-cart-listing'),(937497,'printshop','.w-product-images-additional .additional-images','width','80','5363','','.w-product-images-additional'),(937498,'printshop','.w-promo-code .promo-text','width','100','5342','','.w-promo-code'),(937499,'printshop','.w-product-wishlist-button .btn','width','100','5333','','.w-product-wishlist-button'),(937500,'printshop','.w-cart-continue-btn a','width','100','5333','','.w-cart-continue-btn'),(937501,'printshop','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(937502,'printshop','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(937503,'printshop','.w-cart-order-total.box','width','100','5333','','.w-cart-order-total'),(937504,'printshop','.b-info-popup .info-popup div','width','20','3','','.b-info-popup'),(937505,'printshop','.b-email .totals-value','width','30','','','.b-email'),(937506,'printshop','.b-email .heading-image','width','100','','','.b-email'),(937507,'printshop','.b-email .heading-image','width','100','','','.b-email'),(937508,'printshop','.view-all','width','100','3','',''),(937509,'printshop','.w-promo-code .promo-code-form','width','100','5342','','.w-promo-code'),(937510,'printshop','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5342','','.w-promo-code'),(937512,'printshop','.b-form .columns .col-2','width','50','','','.b-form'),(937513,'printshop','.b-bottom .popup-box.popupCompare','width','80','','','.b-bottom'),(937514,'printshop','.w-promo-code .promo-code-form','width','100','5342','','.w-promo-code'),(937515,'printshop','.w-cart-continue-btn a','width','100','5333','','.w-cart-continue-btn'),(937516,'printshop','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(937517,'printshop','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(937518,'printshop','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(937519,'printshop','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(937520,'printshop','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(937521,'printshop','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(937522,'printshop','.w-checkout-guest-btn .btn-2','width','260','','','.w-checkout-guest-btn'),(937523,'printshop','textarea','width','100','','',''),(937524,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(937525,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','width','100','','','.b-switch'),(937526,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','width','100','','','.b-switch'),(937527,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-label','width','30','','','.b-switch'),(937529,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(937530,'printshop','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(937531,'printshop','.b-email-editor img','width','auto','','','.b-email-editor'),(937532,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','width','100','','','.b-switch'),(937533,'printshop','.b-form .checkbox-style','width','0','','','.b-form'),(937534,'printshop','.b-email .image','width','100','','','.b-email'),(937535,'printshop','.b-email .totals-title','width','70','','','.b-email'),(937536,'printshop','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','width','25','3','','.w-checkout-contact-information'),(937537,'printshop','.b-form .addresses .address-item','width','48','','','.b-form'),(937538,'printshop','.w-categories .item','width','50','5333','','.w-categories'),(937539,'printshop','.order-summary .btn-2, .order-summary .btn-3','width','100','','','.order-summary'),(937540,'printshop','.w-cart-bonus-points .bonus_points_amount','width','150','','','.w-cart-bonus-points'),(937541,'printshop','.w-cart-bonus-points .btn-remove','width','25','','','.w-cart-bonus-points'),(937542,'printshop','.order-summary .price-box .price','width','auto','','','.order-summary'),(937543,'printshop','.b-email .totals-table','width','100','','','.b-email'),(937544,'printshop','.w-socials .post_item_img','width','100','','','.w-socials'),(937545,'printshop','.w-list-b2b .select-attributes','width','47','','','.w-list-b2b'),(937546,'printshop','.w-promo-code .promo-text','width','100','5342','','.w-promo-code'),(937547,'printshop','.w-checkout-shipping-choice label','width','50','','','.w-checkout-shipping-choice'),(937548,'printshop','.b-switch .candlestick-wrapper.candlestick-contents','width','306','','','.b-switch'),(937549,'printshop','.b-email .products-table','width','100','','','.b-email'),(937550,'printshop','.w-checkout-shipping-choice label','width','auto','5363','','.w-checkout-shipping-choice'),(937551,'printshop','.w-checkout-create-account .col-2','width','100','5342','','.w-checkout-create-account'),(937552,'printshop','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(937553,'printshop','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(937554,'printshop','.w-top-categories .item','width','25','','','.w-top-categories'),(937555,'printshop','.w-checkout-billing-address .addresses .address-item','width','50','','','.w-checkout-billing-address'),(937556,'printshop','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(937557,'printshop','.w-cart-give-away .ga_attributes select','width','100','','','.w-cart-give-away'),(937558,'printshop','.w-cart-checkout-btn a','width','100','5333','','.w-cart-checkout-btn'),(937559,'printshop','.b-autocomplete .ui-autocomplete','width','200','','','.b-autocomplete'),(937560,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(937561,'printshop','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(937562,'printshop','.w-socials .post_item_img','width','100','','','.w-socials'),(937564,'printshop','.b-email .totals-value','width','30','','','.b-email'),(937565,'printshop','.b-email .totals-table','width','100','','','.b-email'),(937566,'printshop','.b-email .totals-title','width','70','','','.b-email'),(937567,'printshop','.b-email .heading-image','width','100','','','.b-email'),(937568,'printshop','.b-email img','width','60','','','.b-email'),(937569,'printshop','.b-email .products-table','width','100','','','.b-email'),(937570,'printshop','.b-email .image','width','100','','','.b-email'),(937571,'printshop','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width','100','','','.p-quote-checkout-login'),(937572,'printshop','.b-form .col-right','width','48','','','.b-form'),(937573,'printshop','.b-email img','width','60','','','.b-email'),(937574,'printshop','.w-cart-continue-btn a','width','100','5333','','.w-cart-continue-btn'),(937575,'printshop','.w-product-wishlist-button .btn','width','100','5333','','.w-product-wishlist-button'),(937576,'printshop','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5342','','.w-promo-code'),(937577,'printshop','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(937578,'printshop','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(937579,'printshop','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(937580,'printshop','.w-promo-code .promo-code-form','width','100','5342','','.w-promo-code'),(937581,'printshop','.w-promo-code .promo-text','width','100','5342','','.w-promo-code'),(937582,'printshop','.b-form .columns .col-2','width','100','5363','','.b-form'),(937583,'printshop','.b-select-suggest .select2-container .select2-choice abbr','width','12','','','.b-select-suggest'),(937584,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(937585,'printshop','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(937586,'printshop','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(937587,'printshop','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(937588,'printshop','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(937589,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','width','20','','','.b-switch'),(937590,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','width','28','','','.b-switch'),(937591,'printshop','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(937592,'printshop','.w-login-block .new','width','50','','','.w-login-block'),(937593,'printshop','.w-login-block .guest','width','50','','','.w-login-block'),(937594,'printshop','.w-login-block .input','width','100','','','.w-login-block'),(937595,'printshop','.w-login-block .returning','width','50','','','.w-login-block'),(937596,'printshop','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(937597,'printshop','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(937598,'printshop','div.cart-popup','width','1000','','',''),(937599,'printshop','.w-cart-give-away .ga_column','width','46','','','.w-cart-give-away'),(937600,'printshop','.w-cart-give-away .ga_attributes > div','width','48','','','.w-cart-give-away'),(937601,'printshop','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width','100','','','.b-form'),(937602,'printshop','.b-products-listing .products-listing .buyButton .btn','width','100','','','.b-products-listing'),(937603,'printshop','.w-image-maps .svg-wrap svg','width','100','','','.w-image-maps'),(937604,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(937605,'printshop','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(937606,'printshop','.w-login-block .guest','width','50','','','.w-login-block'),(937607,'printshop','.w-login-block .new','width','50','','','.w-login-block'),(937608,'printshop','.w-cart-shipping-estimator .right-area','width','48','','','.w-cart-shipping-estimator'),(937609,'printshop','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(937610,'printshop','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(937612,'printshop','.w-checkout-credit-amount .btn-remove','width','25','','','.w-checkout-credit-amount'),(937613,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(937614,'printshop','.w-checkout-credit-amount .cot_gv_amount','width','150','','','.w-checkout-credit-amount'),(937615,'printshop','.p-quick-order-index .all-scroll-div','width','100','','','.p-quick-order-index'),(937616,'printshop','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(937617,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(937618,'printshop','.b-email-editor img','width','auto','','','.b-email-editor'),(937619,'printshop','.b-form .col-left','width','100','5342','','.b-form'),(937620,'printshop','.b-email .totals-title','width','70','','','.b-email'),(937621,'printshop','.b-email .totals-table','width','100','','','.b-email'),(937622,'printshop','.w-product-images-additional .additional-images','width','80','5363','','.w-product-images-additional'),(937623,'printshop','.w-product-images-additional .item','width','80','5363','','.w-product-images-additional'),(937624,'printshop','.b-bottom .cart-options .option-item','width','50','','','.b-bottom'),(937625,'printshop','.w-promotions .promo-cart-discount .master .item','width','calc(50% - 24px)','','','.w-promotions'),(937626,'printshop','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(937627,'printshop','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(937628,'printshop','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(937629,'printshop','.b-bottom .cart-options .cart-item','width','100','','','.b-bottom'),(937630,'printshop','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(937631,'printshop','.w-cart-shipping-estimator .left-area','width','48','','','.w-cart-shipping-estimator'),(937633,'printshop','.w-login-block .returning','width','50','','','.w-login-block'),(937634,'printshop','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(937635,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(937636,'printshop','.b-email img','width','60','','','.b-email'),(937637,'printshop','.b-form .col-3','width','31.33','','','.b-form'),(937638,'printshop','.b-email .products-table','width','100','','','.b-email'),(937639,'printshop','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(937640,'printshop','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width','100','','','.b-form'),(937641,'printshop','.w-login-block .input','width','100','','','.w-login-block'),(937642,'printshop','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','width','35','','','.b-products-listing'),(937643,'printshop','.w-login-block .guest','width','50','','','.w-login-block'),(937644,'printshop','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(937645,'printshop','.w-product-wishlist-button .btn','width','100','5333','','.w-product-wishlist-button'),(937646,'printshop','.w-product-images-additional .item-div','width','80','5363','','.w-product-images-additional'),(937647,'printshop','.b-bottom .popup-box','width','530','','','.b-bottom'),(937648,'printshop','.b-email .totals-table','width','100','','','.b-email'),(937649,'printshop','.b-email img','width','60','','','.b-email'),(937650,'printshop','.b-form .login-col-2','width','50','','','.b-form'),(937651,'printshop','.b-fancybox .fancybox-close','width','40','','','.b-fancybox'),(937652,'printshop','.w-cart-compare .product .image','width','50','','','.w-cart-compare'),(937653,'printshop','.w-product-customers-activity .customers-activity','width','255','','','.w-product-customers-activity'),(937654,'printshop','.w-product-customers-activity .close','width','30','','','.w-product-customers-activity'),(937655,'printshop','.b-form .hide-billing-address','width','100','','','.b-form'),(937656,'printshop','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(937657,'printshop','.b-email-editor img','width','auto','','','.b-email-editor'),(937658,'printshop','.w-top-categories .item','width','50','5333','','.w-top-categories'),(937659,'printshop','.w-personal-gift-status-bar .progress-bar','width','230','','','.w-personal-gift-status-bar'),(937660,'printshop','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(937661,'printshop','.w-checkout-billing-address .addresses.address-main .address-item','width','100','','','.w-checkout-billing-address'),(937662,'printshop','.w-checkout-bonus-points .bonus_points_amount','width','150','','','.w-checkout-bonus-points'),(937663,'printshop','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width','150','','','.w-coupons-and-vauchers-checkout'),(937664,'printshop','.w-checkout-shipping-address .addresses.address-main .address-item','width','100','','','.w-checkout-shipping-address'),(937665,'printshop','.w-checkout-shipping-choice #shippingchoice-choice','width','430','','','.w-checkout-shipping-choice'),(937666,'printshop','.w-product-images-additional .item-div','width','80','5363','','.w-product-images-additional'),(937667,'printshop','.w-product-images-additional .item','width','80','5363','','.w-product-images-additional'),(937668,'printshop','.w-product-images-additional .additional-images','width','80','5363','','.w-product-images-additional'),(937669,'printshop','.w-cart-order-total.box','width','100','5333','','.w-cart-order-total'),(937670,'printshop','.w-product-wishlist-button .btn','width','100','5333','','.w-product-wishlist-button'),(937671,'printshop','.w-promo-code .promo-code-form','width','100','5342','','.w-promo-code'),(937672,'printshop','.w-cart-checkout-btn ','width','100','5333','','.w-cart-checkout-btn'),(937673,'printshop','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5342','','.w-promo-code'),(937674,'printshop','.w-cart-continue-btn a','width','100','5333','','.w-cart-continue-btn'),(937675,'printshop','.w-promo-code .promo-text','width','100','5342','','.w-promo-code'),(937676,'printshop','.w-cart-order-total.box','width','100','5333','','.w-cart-order-total'),(937677,'printshop','.w-product-images-additional .item-div','width','80','5363','','.w-product-images-additional'),(937678,'printshop','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(937679,'printshop','.b-select-suggest .select2-search-choice-close','width','12','','','.b-select-suggest'),(937680,'printshop','.b-select-suggest .select2-search input','width','100','','','.b-select-suggest'),(937681,'printshop','.b-select-suggest .select2-search','width','100','','','.b-select-suggest'),(937682,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow','width','18','','','.b-select-suggest'),(937683,'printshop','.b-select-suggest .select2-drop-auto-width','width','auto','','','.b-select-suggest'),(937684,'printshop','.b-select-suggest .select2-drop','width','100','','','.b-select-suggest'),(937685,'printshop','.b-select-suggest .select2-drop-mask','width','auto','','','.b-select-suggest'),(937686,'printshop','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(937687,'printshop','.w-socials .post_item_img','width','100','','','.w-socials'),(937688,'printshop','.w-tabs .tab-navigation','width','100','','','.w-tabs'),(937690,'printshop','.w-login-block .returning','width','50','','','.w-login-block'),(937692,'printshop','.w-categories .item','width','100','5363','','.w-categories'),(937693,'printshop','.b-email-editor img','width','auto','','','.b-email-editor'),(937694,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width','20','3','','.b-switch'),(937695,'printshop','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(937696,'printshop','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(937697,'printshop','.w-socials .post_item_img','width','100','','','.w-socials'),(937699,'printshop','.w-login-block .guest','width','50','','','.w-login-block'),(937700,'printshop','.w-login-block .returning','width','50','','','.w-login-block'),(937701,'printshop','.w-menu-big li','width','auto','','','.w-menu-big'),(937702,'printshop','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(937703,'printshop','.w-cart-listing .links','width','19','','','.w-cart-listing'),(937704,'printshop','.w-cart-order-total.box','width','100','5333','','.w-cart-order-total'),(937705,'printshop','.w-account-addresses-list .addsess-suggestion-item','width','50','','','.w-account-addresses-list'),(937706,'printshop','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width','80','','','.b-products-listing'),(937707,'printshop','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width','60','','','.b-products-listing'),(937708,'printshop','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width','40','','','.b-products-listing'),(937709,'printshop','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width','20','','','.b-products-listing'),(937710,'printshop','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width','40','','','.b-products-listing'),(937711,'printshop','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width','20','','','.b-products-listing'),(937712,'printshop','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width','60','','','.b-products-listing'),(937713,'printshop','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width','60','','','.b-products-listing'),(937714,'printshop','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width','20','','','.b-products-listing'),(937715,'printshop','.b-products-listing .BlockBox.type-14 > .col','width','25','','','.b-products-listing'),(937716,'printshop','.b-products-listing .BlockBox.type-15 > .col','width','20','','','.b-products-listing'),(937717,'printshop','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width','50','','','.b-products-listing'),(937718,'printshop','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(937719,'printshop','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(937720,'printshop','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width','33.33','','','.b-products-listing'),(937721,'printshop','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width','50','','','.b-products-listing'),(937722,'printshop','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(937723,'printshop','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width','66.66','','','.b-products-listing'),(937724,'printshop','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width','66.66','','','.b-products-listing'),(937725,'printshop','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(937726,'printshop','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width','25','','','.b-products-listing'),(937727,'printshop','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width','25','','','.b-products-listing'),(937728,'printshop','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width','75','','','.b-products-listing'),(937729,'printshop','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width','75','','','.b-products-listing'),(937730,'printshop','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width','25','','','.b-products-listing'),(937731,'printshop','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width','50','','','.b-products-listing'),(937732,'printshop','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width','25','','','.b-products-listing'),(937733,'printshop','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width','20','','','.b-products-listing'),(937734,'printshop','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width','80','','','.b-products-listing'),(937735,'printshop','.b-products-listing .btn-preloader','width','24','3','','.b-products-listing'),(937736,'printshop','.b-products-listing .hover-box-content','width','20','3','','.b-products-listing'),(937737,'printshop','.b-products-listing .loader','width','30','4','','.b-products-listing'),(937738,'printshop','.b-products-listing .loader','width','100','3','','.b-products-listing'),(937739,'printshop','.b-products-listing .products-listing .attribute-qty-block > span','width','100','','','.b-products-listing'),(937740,'printshop','.b-products-listing .products-listing .attributes select','width','100','','','.b-products-listing'),(937741,'printshop','.w-catalog-b2b-add-button ','width','100','','','.w-catalog-b2b-add-button'),(937742,'printshop','.b-products-listing .products-listing .item','width','25','','','.b-products-listing'),(937743,'printshop','.b-products-listing .products-listing .qty-input.hidden','width','100','3','','.b-products-listing'),(937744,'printshop','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','width','auto','','','.b-products-listing'),(937745,'printshop','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width','100','','','.b-products-listing'),(937746,'printshop','.checkbox input:not(checked) + span:before','width','22','','',''),(937747,'printshop','.checkbox input + span','width','24','','',''),(937749,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width','100','','','.b-select-suggest'),(937750,'printshop','.b-products-listing .products-listing .in-cart','width','100','','','.b-products-listing'),(937751,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-toggle','width','10','','','.b-switch'),(937752,'printshop','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','width','10','','','.b-switch'),(937753,'printshop','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','width','25','3','','.w-checkout-contact-information'),(937754,'printshop','.b-form .radio-button input[type=\"radio\"].no + span','width','30','3','','.b-form'),(937755,'printshop','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width','100','','','.b-fancybox'),(937756,'printshop','.b-email .heading-image','width','100','','','.b-email'),(937757,'printshop','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(937758,'printshop','.w-product-images-additional .additional-images','width','80','5363','','.w-product-images-additional'),(937759,'printshop','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5342','','.w-promo-code'),(937760,'printshop','.w-socials .post_item_img','width','100','','','.w-socials'),(937761,'printshop','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(937762,'printshop','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(937763,'printshop','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(937764,'printshop','.w-cart-credit-amount .btn-remove','width','25','','','.w-cart-credit-amount'),(937765,'printshop','.w-coupons-and-vauchers-checkout .btn-remove','width','25','','','.w-coupons-and-vauchers-checkout'),(937766,'printshop','.p-wedding-registry-search .search-list input','width','100','','','.p-wedding-registry-search'),(937767,'printshop','.order-summary .price-row.ot_coupon .title','width','32','3','','.order-summary'),(937768,'printshop','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterSku\"]','width','60','','','.w-communication-new-topic'),(937769,'printshop','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterOrderId\"]','width','60','','','.w-communication-new-topic'),(937770,'printshop','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterName\"]','width','100','','','.w-communication-new-topic'),(937771,'printshop','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateFrom\"]','width','60','','','.w-communication-new-topic'),(937772,'printshop','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateTo\"]','width','60','','','.w-communication-new-topic'),(937773,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','width','36','','','.w-communication-new-topic'),(937774,'printshop','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','width','36','','','.w-communication-new-topic'),(937775,'printshop','.w-communication-new-topic .middle-form select','width','100','','','.w-communication-new-topic'),(937776,'printshop','.w-login-block .input','width','100','','','.w-login-block'),(937777,'printshop','.w-checkout-shipping-address .addresses .address-item','width','50','','','.w-checkout-shipping-address'),(937778,'printshop','.b-form .checkbox-style:not(checked) + .checkbox-span','width','15','','','.b-form'),(937779,'printshop','.w-checkout-shipping-choice #shippingchoice-choice','width','auto','5363','','.w-checkout-shipping-choice'),(937780,'printshop','.b-email img','width','60','','','.b-email'),(937781,'printshop','.w-cart-continue-btn a','width','100','5333','','.w-cart-continue-btn'),(937782,'printshop','.b-bottom .popup-credit-amount .popup-box','width','100','','','.b-bottom'),(937783,'printshop','.w-product-images-additional .item','width','80','5363','','.w-product-images-additional'),(937784,'printshop','.w-promo-code .promo-code-form','width','100','5342','','.w-promo-code'),(937785,'printshop','.b-email .products-table','width','100','','','.b-email'),(937786,'printshop','.b-email .totals-title','width','70','','','.b-email'),(937787,'printshop','.w-login-block .new','width','50','','','.w-login-block'),(937788,'printshop','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(937789,'printshop','.b-email-editor img','width','auto','','','.b-email-editor'),(937790,'printshop','.b-email .heading-image','width','100','','','.b-email'),(937791,'printshop','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(937792,'printshop','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(937793,'printshop','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(937794,'printshop','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(937795,'printshop','.b-compare .col-two label','width','20','','','.b-compare'),(937796,'printshop','.w-cart-order-total.box','width','100','5333','','.w-cart-order-total'),(937797,'printshop','.w-promo-code .promo-text','width','100','5342','','.w-promo-code'),(937798,'printshop','.w-menu-horizontal .menu-ico','width','54','','','.w-menu-horizontal'),(937799,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(937800,'printshop','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(937801,'printshop','.w-catalog-listing-look .grid','width','35','','','.w-catalog-listing-look'),(937802,'printshop','.w-catalog-listing-look .b2b','width','35','','','.w-catalog-listing-look'),(937803,'printshop','.w-catalog-listing-look .list','width','35','','','.w-catalog-listing-look'),(937804,'printshop','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','width','130','','','.w-cart-listing'),(937805,'printshop','.w-cart-listing .right-area','width','35','','','.w-cart-listing'),(937806,'printshop','.w-cart-listing .item .image','width','80','5342','','.w-cart-listing'),(937807,'printshop','.w-cart-listing .item .remove','width','100','5342','','.w-cart-listing'),(937808,'printshop','.w-cart-give-away .ga_img','width','30','','','.w-cart-give-away'),(937809,'printshop','.w-cart-give-away .ga_column','width','100','5333','','.w-cart-give-away'),(937810,'printshop','.w-cart-discount-coupon input[type=\"text\"]','width','100','','','.w-cart-discount-coupon'),(937811,'printshop','.w-cart-discount-coupon .btn-remove','width','25','','','.w-cart-discount-coupon'),(937813,'printshop','.w-brands .brands-listing > div','width','16','','','.w-brands'),(937814,'printshop','.b-upload-file .snapshot','width','38','','','.b-upload-file'),(937815,'printshop','.b-fancybox .fancybox-nav span','width','40','','','.b-fancybox'),(937816,'printshop','.b-fancybox .fancybox-nav','width','40','','','.b-fancybox'),(937817,'printshop','.b-email .totals-table','width','100','','','.b-email'),(937818,'printshop','.w-product-images-additional .item','width','80','5363','','.w-product-images-additional'),(937819,'printshop','.b-upload-file .upload-file-template','width','150','','','.b-upload-file'),(937820,'printshop','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(937821,'printshop','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(937822,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(937823,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(937824,'printshop','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(937825,'printshop','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(937826,'printshop','.b-switch .candlestick-wrapper.candlestick-size-sm','width','45','','','.b-switch'),(937827,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','width','40','','','.b-switch'),(937828,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(937829,'printshop','.w-contact-contacts .contacts-icons .phone, .w-contact-contacts .contacts-icons .email, .w-contact-contacts .contacts-icons .hours, .w-contact-contacts .contacts-icons .reg-number, .w-contact-contacts .contacts-icons .company-vat','width','30','3','','.w-contact-contacts'),(937831,'printshop','.w-login-block .new','width','50','','','.w-login-block'),(937832,'printshop','.w-filters .handle-to','width','50','','','.w-filters'),(937833,'printshop','.w-filters .handle-from','width','50','','','.w-filters'),(937834,'printshop','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5342','','.w-promo-code'),(937835,'printshop','.order-summary .price-row.ot_bonus_points .title','width','32','3','','.order-summary'),(937836,'printshop','.w-filters .input-checkbox','width','0','','','.w-filters'),(937837,'printshop','.b-bottom .pop-up-close','width','31','','','.b-bottom'),(937838,'printshop','.w-product-images-additional .item-div','width','80','5363','','.w-product-images-additional'),(937839,'printshop','.w-promo-code .promo-text','width','100','5342','','.w-promo-code'),(937840,'printshop','.w-product-images-additional .additional-images','width','80','5363','','.w-product-images-additional'),(937841,'printshop','.w-product-images-additional .item-div','width','80','5363','','.w-product-images-additional'),(937842,'printshop','.w-cart-order-total.box','width','100','5333','','.w-cart-order-total'),(937843,'printshop','.b-compare .col-two select','width','80','','','.b-compare'),(937844,'printshop','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(937845,'printshop','.w-product-wishlist-button .btn','width','100','5333','','.w-product-wishlist-button'),(937846,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(937847,'printshop','.w-login-block .new','width','50','','','.w-login-block'),(937848,'printshop','.w-login-block .input','width','100','','','.w-login-block'),(937849,'printshop','.w-login-block .guest','width','50','','','.w-login-block'),(937850,'printshop','.b-products-listing .products-listing .btn-preloader','width','100','','','.b-products-listing'),(937851,'printshop','.w-communication-new-topic .btn-submit','width','200','','','.w-communication-new-topic'),(937852,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(937854,'printshop','.w-cart-credit-amount input[type=\"text\"]','width','150','','','.w-cart-credit-amount'),(937856,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg','width','120','','','.b-switch'),(937857,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','width','40','','','.b-switch'),(937858,'printshop','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','width','40','','','.b-switch'),(937859,'printshop','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(937860,'printshop','.b-email .products-table','width','100','','','.b-email'),(937861,'printshop','.b-email .totals-value','width','30','','','.b-email'),(937862,'printshop','.b-email .totals-title','width','70','','','.b-email'),(937863,'printshop','.b-email .totals-table','width','100','','','.b-email'),(937864,'printshop','.w-filters .mobileCollapse','width','17','','','.w-filters'),(937865,'printshop','.w-filters .input-txt-keywords','width','100','','','.w-filters'),(937866,'printshop','.w-filters .input-txt','width','60','','','.w-filters'),(937867,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','width','250','','','.w-image-maps'),(937868,'printshop','.w-filters .input-checkbox:not(checked) + .checkbox-span','width','24','','','.w-filters'),(937869,'printshop','.w-brands .brands-listing > div','width','16','','','.w-brands'),(937870,'printshop','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','width','auto','','','.b-product-images'),(937871,'printshop','.b-product-images .media-popup .mp-close','width','100','','','.b-product-images'),(937872,'printshop','.b-product-images .media-popup .mp-small-images .item','width','150','','','.b-product-images'),(937873,'printshop','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','width','100','','','.b-product-images'),(937874,'printshop','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','width','30','','','.b-menu-burger_icon'),(937875,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width','100','','','.b-menu-lev_display-slide'),(937876,'printshop','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width','100','','','.b-menu-lev_display-slide'),(937877,'printshop','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width','100','','','.b-menu-lev_display-slide'),(937878,'printshop','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width','100','','','.b-menu-lev_display-slide'),(937879,'printshop','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width','100','','','.b-menu-lev_display-slide'),(937880,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(937881,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(937882,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(937883,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(937884,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(937885,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width','100','','','.b-menu-open_from-left'),(937886,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(937887,'printshop','.b-trade-approval .steps-bar','width','100','','','.b-trade-approval'),(937888,'printshop','.b-trade-approval .col-right','width','48','','','.b-trade-approval'),(937889,'printshop','.b-trade-approval .col-left','width','48','','','.b-trade-approval'),(937890,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width','100','','','.b-trade-approval'),(937891,'printshop','.b-trade-approval .col-3','width','31.33','','','.b-trade-approval'),(937892,'printshop','.w-account-personal-catalog .list-switcher','width','100','','','.w-account-personal-catalog'),(937893,'printshop','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','width','auto','','','.w-catalog-compare'),(937894,'printshop','.w-catalog-compare .cross-box .different-all > div','width','50','','','.w-catalog-compare'),(937895,'printshop','.w-product-images .additional-vertical .produst-image','width','calc(100% - 100px)','','','.w-product-images'),(937896,'printshop','.w-product-images .additional-vertical .additional-images','width','100','','','.w-product-images'),(937901,'printshop','.tripleBanner .w-html_box','width','80','3','','.tripleBanner'),(937902,'printshop','.shopByCollectionBox .w-banner .single_banner','width','33.333','','','.shopByCollectionBox'),(937903,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','width','40','','','.b-slick'),(937904,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','width','50','5342','','.b-slick'),(937907,'printshop','.menu-header .burger-icon','width','40','5342','','.menu-header'),(937908,'printshop','.tripleBanner > .block','width','100','5342','','.tripleBanner'),(937909,'printshop','.b-products-listing .item-nav > div','width','33.333','','','.b-products-listing'),(937910,'printshop','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','width','13','','','.w-filters'),(937911,'printshop','.w-quote .cart-box-link','width','48','3','','.w-quote'),(937912,'printshop','.w-quote .image','width','70','','','.w-quote'),(937913,'printshop','.w-quote .cart-box-link','width','40','5342,3','','.w-quote'),(937914,'printshop','.b-quantity .qty-box .bigger','width','32','','','.b-quantity'),(937915,'printshop','.b-quantity .qty-box .smaller','width','32','','','.b-quantity'),(937916,'printshop','.b-quantity .qty-input input','width','40','','','.b-quantity'),(937917,'printshop','.w-product-sale-ends .left-count','width','23','','','.w-product-sale-ends'),(937918,'printshop','.w-product-sale-ends .left-text-left','width','24','','','.w-product-sale-ends'),(937919,'printshop','.w-product-sale-ends .left-text-right','width','24','','','.w-product-sale-ends'),(937920,'printshop','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(937921,'printshop','.w-product-bonus-points > div > div','width','100','','','.w-product-bonus-points'),(937922,'printshop','.warrantyProduct .warranty','width','35','3','','.warrantyProduct'),(937923,'printshop','.warrantyProduct .delivery','width','37','3','','.warrantyProduct'),(937924,'printshop','.w-compare .image','width','70','','','.w-compare'),(937925,'printshop','.w-files-catalog-widgets-files-catalog .item','width','18','','','.w-files-catalog-widgets-files-catalog'),(937926,'printshop','.w-files-catalog-widgets-files-catalog .item','width','23','5347','','.w-files-catalog-widgets-files-catalog'),(937927,'printshop','.w-files-catalog-widgets-files-catalog .item','width','31','5342','','.w-files-catalog-widgets-files-catalog'),(937928,'printshop','.w-files-catalog-widgets-files-catalog .item','width','48','5333','','.w-files-catalog-widgets-files-catalog'),(937929,'printshop','.w-sample .cart-box-link','width','10','4','','.w-sample'),(937930,'printshop','.w-sample .cart-box-link','width','48','3','','.w-sample'),(937931,'printshop','.w-sample .image','width','70','','','.w-sample'),(937932,'printshop','.w-sample .cart-box-link','width','40','5342,3','','.w-sample'),(937933,'printshop','.w-quote .cart-box.hover-box .cart-content','width','410','','','.w-quote'),(937934,'printshop','.w-sample .cart-box .cart-content','width','410','','','.w-sample'),(937935,'printshop','.w-cart-listing .points-earn','width','80','','','.w-cart-listing'),(937936,'printshop','.w-cart-sub-total .price-row','width','100','','','.w-cart-sub-total'),(937937,'printshop','.w-cart-sub-total .price-row > div','width','50','','','.w-cart-sub-total'),(937938,'printshop','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(937939,'printshop','.w-cart-gift-certificate .input-apple','width','100','','','.w-cart-gift-certificate'),(937940,'printshop','.w-cart-gift-certificate .input-apple div','width','100','','','.w-cart-gift-certificate'),(937941,'printshop','.w-cart-order-reference .input-apple','width','100','','','.w-cart-order-reference'),(937942,'printshop','.w-cart-order-reference .input-apple div','width','100','','','.w-cart-order-reference'),(937943,'printshop','.w-cart-order-reference .input-apple div input','width','100','','','.w-cart-order-reference'),(937944,'printshop','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(937945,'printshop','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(937946,'printshop','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(937947,'printshop','.w-product-bundle .bundle_item','width','30','','','.w-product-bundle'),(937948,'printshop','.w-product-bundle .bundle_item','width','48','5342','','.w-product-bundle'),(937949,'printshop','.w-product-bundle .bundle_item','width','100','5333','','.w-product-bundle'),(937950,'printshop','.w-product-in-bundles .attributes-item','width','48','','','.w-product-in-bundles'),(937951,'printshop','.w-product-in-bundles .attributes-select','width','100','','','.w-product-in-bundles'),(937952,'printshop','.w-product-in-bundles .bundle_item','width','48','5342','','.w-product-in-bundles'),(937953,'printshop','.w-product-in-bundles .bundle_item','width','100','5333','','.w-product-in-bundles'),(937954,'printshop','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(937955,'printshop','.w-product-in-bundles .bundle_item','width','30','','','.w-product-in-bundles'),(937956,'printshop','.w-product-quantity-discounts .count','width','80','','','.w-product-quantity-discounts'),(937957,'printshop','.w-catalog-additional-images img','width','auto','','','.w-catalog-additional-images'),(937958,'printshop','.w-catalog-additional-images picture','width','150','','','.w-catalog-additional-images'),(937959,'printshop','.w-product-quantity-discounts .item','width','48','','','.w-product-quantity-discounts'),(937960,'printshop','.w-product-quantity-discounts .item','width','100','5342','','.w-product-quantity-discounts'),(937961,'printshop','.w-product-multi-inventory .select-box:nth-child(2n)','width','48','','','.w-product-multi-inventory'),(937962,'printshop','.w-product-multi-inventory .select-box:nth-child(2n+1)','width','48','','','.w-product-multi-inventory'),(937963,'printshop','.p-quote-checkout-index .datepicker-inline','width','280','','','.p-quote-checkout-index'),(937964,'printshop','.p-sample-checkout-index .datepicker-inline','width','280','','','.p-sample-checkout-index'),(937965,'printshop','.p-sample-checkout-index .order-summary .heading-2','width','100','3','','.p-sample-checkout-index'),(937966,'printshop','.p-sample-checkout-index .order-summary .heading-2','width','100','4','','.p-sample-checkout-index'),(937968,'printshop','.w-product-multi-inventory .radio-attributes > label','width','33.3333','','','.w-product-multi-inventory'),(937969,'printshop','.w-product-multi-inventory .radio-attributes .option-item','width','100','','','.w-product-multi-inventory'),(937970,'printshop','.w-product-multi-inventory .radio-attributes > label','width','50','5347','','.w-product-multi-inventory'),(937971,'printshop','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','width','100','','','.w-account-personal-catalog'),(937972,'printshop','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width','65','5347','','.b-products-listing'),(937973,'printshop','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width','35','5347','','.b-products-listing'),(937974,'printshop','.b-products-listing .products-listing .radio-attributes .option','width','100','','','.b-products-listing'),(937975,'printshop','.b-products-listing .products-listing .radio-attributes > label','width','50','','','.b-products-listing'),(937976,'printshop','.w-product-collection .chosen-products','width','48','','','.w-product-collection'),(937977,'printshop','.w-product-collection .current-product','width','25','','','.w-product-collection'),(937978,'printshop','.w-product-collection .right-area','width','25','','','.w-product-collection'),(937979,'printshop','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(937980,'printshop','.w-product-collection .current-product, .w-product-collection .chosen-products','width','100','5342','','.w-product-collection'),(937981,'printshop','.w-product-collection .right-area','width','100','5342','','.w-product-collection'),(937982,'printshop','.w-product-attributes .radio-attributes .option-item','width','100','','','.w-product-attributes'),(937983,'printshop','.w-product-attributes .radio-attributes > label','width','33.3333','','','.w-product-attributes'),(937984,'printshop','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(937985,'printshop','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(937986,'printshop','.w-product-attributes .radio-attributes > label','width','50','5347','','.w-product-attributes'),(937987,'printshop','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(937988,'printshop','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(937989,'printshop','.w-product-properties li','width','50','','','.w-product-properties'),(937990,'printshop','.w-questionnaire-widgets-questionnaire .answer-yes-no span','width','40','','','.w-questionnaire-widgets-questionnaire'),(937991,'printshop','.w-product-groups .radioBox label','width','50','','','.w-product-groups'),(937992,'printshop','.w-product-groups .radioBox label','width','100','5363','','.w-product-groups'),(937993,'printshop','.b-products-listing .mix-attributes .mult-qty-input .qty-box > span','width','35','','','.b-products-listing'),(937994,'printshop','.b-products-listing .mix-attributes .mult-qty-input .qty-box > input','width','60','','','.b-products-listing'),(937995,'printshop','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(937996,'printshop','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(937997,'printshop','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(937998,'printshop','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(937999,'printshop','.w-product-custom-bundle .chosen-products','width','100','5342','','.w-product-custom-bundle'),(938000,'printshop','.w-product-custom-bundle .right-area','width','100','5342','','.w-product-custom-bundle'),(938001,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width','25','','','.w-catalog-pages-category-pages-last-list'),(938002,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width','33.33','5342','','.w-catalog-pages-category-pages-last-list'),(938003,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width','50','5333','','.w-catalog-pages-category-pages-last-list'),(938004,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width','25','','','.w-catalog-pages-category-pages-last-list-block'),(938005,'printshop','.w-delivery-location-top-location-list .deliveryList li','width','48','','','.w-delivery-location-top-location-list'),(938006,'printshop','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(938007,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width','33.33','5342','','.w-catalog-pages-category-pages-last-list-block'),(938008,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width','50','5333','','.w-catalog-pages-category-pages-last-list-block'),(938009,'printshop','.w-delivery-location-location-list .deliveryList li','width','31.333','5342','','.w-delivery-location-location-list'),(938010,'printshop','.w-delivery-location-location-list .deliveryList li','width','48','5333','','.w-delivery-location-location-list'),(938011,'printshop','.w-delivery-location-top-location-list .deliveryList li','width','100','5333','','.w-delivery-location-top-location-list'),(938012,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li','width','48','','','.w-delivery-location-featured-list'),(938013,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li','width','100','5363','','.w-delivery-location-featured-list'),(938014,'printshop','.w-sale-category .badge','width','80','','','.w-sale-category'),(938015,'printshop','.w-sale-category .holder-1','width','25','','','.w-sale-category'),(938016,'printshop','.w-sale-category .holder-2','width','25','','','.w-sale-category'),(938017,'printshop','.w-sale-category .image','width','50','','','.w-sale-category'),(938018,'printshop','.w-sale-category .left-count','width','23','','','.w-sale-category'),(938019,'printshop','.w-sale-category .left-text-left','width','24','','','.w-sale-category'),(938020,'printshop','.w-sale-category .left-text-right','width','24','','','.w-sale-category'),(938021,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width','25','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(938022,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width','50','5333','','.w-catalog-pages-category-pages-last-list-by-catalog'),(938023,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width','25','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(938024,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width','50','5333','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(938025,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width','33.33','5342','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(938026,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width','33.33','5342','','.w-catalog-pages-category-pages-last-list-by-catalog'),(938027,'printshop','.w-delivery-location-list-by-page .item','width','31.333','','','.w-delivery-location-list-by-page'),(938028,'printshop','.w-delivery-location-list-by-page .item','width','48','5342','','.w-delivery-location-list-by-page'),(938029,'printshop','.w-delivery-location-list-by-page .item','width','100','5363','','.w-delivery-location-list-by-page'),(938030,'printshop','.w-product-properties-icons .hover-box-content','width','100','','','.w-product-properties-icons'),(938031,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','width','200','','','.w-product-properties-icons'),(938032,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','width','100','5363','','.w-product-properties-icons'),(938033,'printshop','.w-delivery-location-cross-pages .item','width','31.333','','','.w-delivery-location-cross-pages'),(938034,'printshop','.w-delivery-location-cross-pages .item','width','48','5342','','.w-delivery-location-cross-pages'),(938035,'printshop','.w-delivery-location-cross-pages .item','width','100','5363','','.w-delivery-location-cross-pages'),(938036,'printshop','.w-delivery-location-product-categories .item.category-link','width','25','','','.w-delivery-location-product-categories'),(938037,'printshop','.w-delivery-location-product-categories .item.category-link','width','33.3333','5342','','.w-delivery-location-product-categories'),(938038,'printshop','.w-delivery-location-product-categories .item.category-link','width','100','5363','','.w-delivery-location-product-categories'),(938039,'printshop','.w-delivery-location-product-categories .item.category-link','width','50','5333','','.w-delivery-location-product-categories'),(938040,'printshop','.w-catalog-delivery-locations .item','width','48','','','.w-catalog-delivery-locations'),(938041,'printshop','.w-catalog-delivery-locations .item','width','100','5333','','.w-catalog-delivery-locations'),(938042,'printshop','.delivery-options-popup .datepicker-inline','width','220','','',''),(938043,'printshop','.w-product-bonus-points .bonus-points-cost','width','100','','','.w-product-bonus-points'),(938044,'printshop','.w-product-designer-designer .productDesignerBox input','width','100','','','.w-product-designer-designer'),(938045,'printshop','.w-product-designer-designer .prodDesignerType label','width','82','','','.w-product-designer-designer'),(938046,'printshop','.w-product-designer-designer .prodDesignerType','width','100','','','.w-product-designer-designer'),(938047,'printshop','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','width','30','','','.w-press-reviews-widgets-press-reviews-small'),(938048,'printshop','.w-press-reviews-widgets-press-reviews-small .small-press-review','width','70','','','.w-press-reviews-widgets-press-reviews-small'),(938049,'printshop','.w-press-reviews-widgets-press-reviews .sub-box','width','300','','','.w-press-reviews-widgets-press-reviews'),(938050,'printshop','.w-gift-wrap-message-checkout .text','width','calc(100$ - 100px)','','','.w-gift-wrap-message-checkout'),(938051,'printshop','.w-support-system-listing .product_icon','width','40','','','.w-support-system-listing'),(938052,'printshop','.w-rma-returns-history .content-messages .messages-table .bottom select','width','auto','','','.w-rma-returns-history'),(938053,'printshop','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','width','35','','','.w-rma-returns-history'),(938054,'printshop','.w-rma-returns-history input[type=\'text\'], .w-rma-returns-history input[type=\'password\'], .w-rma-returns-history input[type=\'number\'], .w-rma-returns-history input[type=\'email\'], .w-rma-returns-history input[type=\'search\'], .w-rma-returns-history select','width','100','','','.w-rma-returns-history'),(938055,'printshop','.w-rma-returns-history thead tr td:first-child','width','300','','','.w-rma-returns-history'),(938056,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(938057,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(938058,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(938059,'printshop','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(938060,'printshop','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(938061,'printshop','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(938062,'printshop','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(938063,'printshop','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(938064,'printshop','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(938065,'printshop','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(938066,'printshop','.w-product-configurator .item-content','width','100','5342','','.w-product-configurator'),(938067,'printshop','.w-product-configurator .pc_item','width','100','5342','','.w-product-configurator'),(938068,'printshop','.b-products-listing .products-listing .bonus-points-cost','width','100','','','.b-products-listing'),(938069,'printshop','.b-products-listing .promo-icon','width','60','','','.b-products-listing'),(938070,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width','25','','','.w-catalog-pages-category-pages-list'),(938071,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width','33.33','5342','','.w-catalog-pages-category-pages-list'),(938072,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width','50','5333','','.w-catalog-pages-category-pages-list'),(938073,'printshop','.w-predefined-promotion .icon','width','45','','','.w-predefined-promotion'),(938074,'printshop','.w-predefined-promotion .nextdiscount .item-holder .image','width','40','','','.w-predefined-promotion'),(938075,'printshop','.w-predefined-promotion .nextdiscount .item-holder .name','width','60','','','.w-predefined-promotion'),(938076,'printshop','.w-predefined-promotion .prom-multi-discount .image img','width','auto','','','.w-predefined-promotion'),(938077,'printshop','.w-predefined-promotion .prom-multi-discount .list','width','100','','','.w-predefined-promotion'),(938078,'printshop','.w-predefined-promotion .promo-cart-discount .image img','width','auto','','','.w-predefined-promotion'),(938079,'printshop','.w-predefined-promotion .promo-cart-discount .master .item','width','calc(50% - 24px)','','','.w-predefined-promotion'),(938080,'printshop','.w-predefined-promotion .promo-cart-discount .slave .item','width','calc(50% - 4px)','','','.w-predefined-promotion'),(938081,'printshop','.w-predefined-promotion .promo-cart-discount > div','width','50','','','.w-predefined-promotion'),(938082,'printshop','.w-predefined-promotion .promo-salemaker .image img','width','auto','','','.w-predefined-promotion'),(938083,'printshop','.w-predefined-promotion .promo-salemaker .item','width','50','','','.w-predefined-promotion'),(938084,'printshop','.w-predefined-promotion .promo-salemaker > div','width','50','','','.w-predefined-promotion'),(938087,'printshop','.heading-1','width','92','4','',''),(938088,'printshop','h1','width','92','4','',''),(938089,'printshop','.b-quantity .qty-box input[type=\"text\"]','width','60','','','.b-quantity'),(938090,'printshop','.tripleLine picture[id] > img, .tripleLine picture[style] > img','width','auto','','','.tripleLine'),(938091,'printshop','.cartTitle >div','width','92','4','','.cartTitle'),(938092,'printshop','.tripleLine .w-banner .image-text-banner.bottom-center','width','33.3333','','','.tripleLine'),(938093,'printshop','.bottomBanner .icon-box > div','width','25','','','.bottomBanner'),(938094,'printshop','.bottomBanner .icon-box > div','width','97','3','','.bottomBanner'),(938095,'printshop','.b-menu-open_from-top .menu-style[data-open_from=\"top\"] .menu-content','width','100','','','.b-menu-open_from-top'),(938096,'printshop','.bottomBanner .icon-box > div','width','auto','5347','','.bottomBanner'),(938097,'printshop','.bottomBanner .icon-box > div','width','80','5347,3','','.bottomBanner'),(938098,'printshop','.tripleLine .w-banner .image-text-banner.bottom-center','width','100','5363','','.tripleLine'),(938099,'printshop','.pop-up-content .buttons .btn','width','100','5333','',''),(938100,'printshop','.pop-up-content .buttons .btn-2','width','100','5333','',''),(938101,'printshop','.pop-up-content .buttons .left-buttons','width','100','5333','',''),(938102,'printshop','.pop-up-content .buttons .right-buttons','width','100','5333','',''),(938103,'printshop','.b-quantity .qty-box input[type=\"text\"]','width','45','5333','','.b-quantity'),(938104,'printshop','.w-categories .item','width','25','5347','','.w-categories'),(938105,'printshop','.w-product-multi-inventory .select-box:nth-child(2n+1)','width','100','5363','','.w-product-multi-inventory'),(938106,'printshop','.w-product-multi-inventory .radio-attributes > label','width','100','5363','','.w-product-multi-inventory'),(938107,'printshop','.w-product-attributes .radio-attributes > label','width','100','5363','','.w-product-attributes'),(938108,'printshop','.w-product-attributes .select-box:nth-child(2n+1)','width','100','5363','','.w-product-attributes'),(938110,'printshop','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','width','100','5363','','.w-product-buttons'),(938111,'printshop','.topBanner .ourPick','width','100','','','.topBanner'),(938112,'printshop','.topBanner .w-banner .image-text-banner.middle-left .text-banner-1','width','100','5333','','.topBanner'),(938113,'printshop','.topBanner .w-banner .text-middle-left .banner-text','width','100','5333','','.topBanner'),(938114,'printshop','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','width','75','','','.w-promotions-widgets-promotion-icons-desc'),(938115,'printshop','.w-promotions-widgets-promotion-icons-desc .promo-icon','width','20','','','.w-promotions-widgets-promotion-icons-desc'),(938116,'printshop','.tripleLine .w-banner .banner-item.text-bottom-center','width','100','5363','','.tripleLine'),(938117,'printshop','.w-cart-shipping-estimator .left-area','width','100','5363','','.w-cart-shipping-estimator'),(938118,'printshop','.w-cart-shipping-estimator .right-area','width','100','5363','','.w-cart-shipping-estimator'),(938119,'printshop','.p-quote-checkout-index .dob-hide > div','width','48','','','.p-quote-checkout-index'),(938120,'printshop','.p-quote-checkout-index .edit-address-popup','width','1000','','','.p-quote-checkout-index'),(938121,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons','width','100','','','.p-quote-checkout-index'),(938122,'printshop','.p-quote-checkout-index .order-summary2 .btn-2','width','100','','','.p-quote-checkout-index'),(938129,'printshop','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','width','48','','','.account-address-book'),(938130,'printshop','.account-address-book .address_book_row .column','width','100','5333','','.account-address-book'),(938131,'printshop','.account-address-book .address_book_row .column + .column','width','100','5333','','.account-address-book'),(938132,'printshop','.account-address-book .topInfo > div','width','100','5333','','.account-address-book'),(938133,'printshop','.account-address-book .topInfo > div + div','width','100','5333','','.account-address-book'),(938151,'printshop','.account-order-pay .history_info > div','width','33.3','','','.account-order-pay'),(938152,'printshop','.account-order-pay .not_fully_paid_td','width','300','','','.account-order-pay'),(938153,'printshop','.account-order-pay .history_info > div','width','100','5342','','.account-order-pay'),(938154,'printshop','.account-samples .not_fully_paid_td','width','300','','','.account-samples'),(938155,'printshop','.account-samples .orders-table .hidden','width','130','5342','','.account-samples'),(938156,'printshop','.account-samples .orders-table .td-alignright','width','100','5342','','.account-samples'),(938157,'printshop','.account-sample-info .history_info > div','width','33.3','','','.account-sample-info'),(938158,'printshop','.account-sample-info .not_fully_paid_td','width','300','','','.account-sample-info'),(938159,'printshop','.account-sample-info .history_info > div','width','100','5342','','.account-sample-info'),(938160,'printshop','.catalog-product-wrap .pn-image','width','24','3','','.catalog-product-wrap'),(938161,'printshop','.catalog-product-wrap .prev-next-product','width','190','','','.catalog-product-wrap'),(938162,'printshop','.catalog-product-wrap .next-product','width','60','5342','','.catalog-product-wrap'),(938163,'printshop','.catalog-product-wrap .prev-product','width','60','5342','','.catalog-product-wrap'),(938164,'printshop','.checkout-index-wrap .datepicker-inline','width','280','','','.checkout-index-wrap'),(938165,'printshop','.checkout-index-wrap .dob-hide > div','width','48','','','.checkout-index-wrap'),(938166,'printshop','.checkout-index-wrap .edit-address-popup','width','1000','','','.checkout-index-wrap'),(938167,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons','width','100','','','.checkout-index-wrap'),(938168,'printshop','.checkout-index-wrap .order-summary2 .btn-2','width','100','','','.checkout-index-wrap'),(938169,'printshop','.checkout-order-confirmation .order-summary2 .btn-2','width','100','','','.checkout-order-confirmation'),(938170,'printshop','.checkout-login-wrap .col-left, .checkout-login-wrap .col-right','width','100','','','.checkout-login-wrap'),(938171,'printshop','.checkout-login-wrap .middle-form .btn-2','width','100','','','.checkout-login-wrap'),(938172,'printshop','.index-wrap .heading-2','width','92','4','','.index-wrap'),(938173,'printshop','.index-wrap h2','width','92','4','','.index-wrap'),(938174,'printshop','.b-form .password-row','width','100','','','.b-form'),(938175,'printshop','.b-form .center-buttons','width','100','','','.b-form'),(938176,'printshop','.b-form .col-gender','width','100','','','.b-form'),(938177,'printshop','.b-slick .slick-dots li','width','10','3','','.b-slick'),(938178,'printshop','.hide-page','width','100','','',''),(938179,'printshop','.success-page .w-cart-listing .qty','width','24','','','.success-page'),(938180,'printshop','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','width','33','','','.b-multi-page-checkout'),(938181,'printshop','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','width','35','3','','.b-multi-page-checkout'),(938182,'printshop','.tripleLine .w-banner .banner-item','width','33.3333','','','.tripleLine'),(938183,'printshop','.middleBanner div.banner-text-holder','width','50','5342','','.middleBanner'),(938187,'printshop','.footer-menu .level-2 > li','width','100','','','.footer-menu'),(938188,'printshop','.footer-menu .level-2 > li','width','100','5347','','.footer-menu'),(938189,'printshop','.w-bestsellers .counter','width','31','','','.w-bestsellers'),(938190,'printshop','.w-bestsellers .item','width','31','3','','.w-bestsellers'),(938191,'printshop','.accout-box select[data-type=\"vat_number\"]','width','40','','','.accout-box'),(938192,'printshop','.w-account-customer-additional-field .field-type-checkbox label','width','40','','','.w-account-customer-additional-field'),(938193,'printshop','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width','60','','','.w-account-customer-additional-field'),(938194,'printshop','.w-account-customer-additional-field .field-type-text label','width','40','','','.w-account-customer-additional-field'),(938195,'printshop','.w-banner .banner-text-holder','width','100','','','.w-banner'),(938196,'printshop','.w-banner .carousel-text','width','100','','','.w-banner'),(938197,'printshop','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width','100','','','.w-banner'),(938198,'printshop','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width','100','','','.w-banner'),(938199,'printshop','.w-catalog-paging .paging-holder','width','150','','','.w-catalog-paging'),(938200,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width','30','','','.w-catalog-paging'),(938202,'printshop','.w-sale .badge','width','80','','','.w-sale'),(938203,'printshop','.w-sale .holder-1','width','25','','','.w-sale'),(938204,'printshop','.w-sale .holder-2','width','25','','','.w-sale'),(938205,'printshop','.w-sale .image','width','50','','','.w-sale'),(938206,'printshop','.w-sale .left-count','width','23','','','.w-sale'),(938207,'printshop','.w-sale .left-text-left','width','24','','','.w-sale'),(938208,'printshop','.w-sale .left-text-right','width','24','','','.w-sale'),(938209,'printshop','.b-warehouses-popup .warehouses-popup','width_important','important','','','.b-warehouses-popup'),(938212,'printshop','.b-messages .pre_upload','width_important','important','','','.b-messages'),(938213,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width_important','important','3','','.b-switch'),(938214,'printshop','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width_important','important','3','','.b-switch'),(938217,'printshop','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width_important','important','','','.b-select-suggest'),(938218,'printshop','.w-checkout-credit-amount .cot_gv_amount','width_important','important','','','.w-checkout-credit-amount'),(938221,'printshop','.w-checkout-bonus-points .bonus_points_amount','width_important','important','','','.w-checkout-bonus-points'),(938222,'printshop','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width_important','important','','','.w-coupons-and-vauchers-checkout'),(938227,'printshop','.w-cart-discount-coupon input[type=\"text\"]','width_important','important','','','.w-cart-discount-coupon'),(938228,'printshop','.w-cart-credit-amount input[type=\"text\"]','width_important','important','','','.w-cart-credit-amount'),(938231,'printshop','.menu-header .burger-icon','width_important','important','5342','','.menu-header'),(938232,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_important','important','','','.b-menu-open_from-left'),(938233,'printshop','.tripleBanner > .block','width_important','important','5342','','.tripleBanner'),(938234,'printshop','.w-cart-bonus-points .bonus_points_amount','width_important','important','','','.w-cart-bonus-points'),(938235,'printshop','.w-rma-returns-history thead tr td:first-child','width_important','important','','','.w-rma-returns-history'),(938236,'printshop','.b-menu-open_from-top .menu-style[data-open_from=\"top\"] .menu-content','width_important','important','','','.b-menu-open_from-top'),(938237,'printshop','.p-quote-checkout-index .edit-address-popup','width_important','important','','','.p-quote-checkout-index'),(938238,'printshop','.checkout-index-wrap .edit-address-popup','width_important','important','','','.checkout-index-wrap'),(938239,'printshop','.footer-menu .level-2 > li','width_important','important','5347','','.footer-menu'),(938240,'printshop','.accout-box select[data-type=\"vat_number\"]','width_important','important','','','.accout-box'),(938241,'printshop','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width_important','important','','','.w-catalog-paging'),(938242,'printshop','.b-form .col-right','width_measure','%','5342','','.b-form'),(938243,'printshop','.b-form .login-col-2','width_measure','%','','','.b-form'),(938244,'printshop','.order-summary .btn-2, .order-summary .btn-3','width_measure','%','','','.order-summary'),(938245,'printshop','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(938246,'printshop','.w-promotions .promo-salemaker > div','width_measure','%','','','.w-promotions'),(938247,'printshop','.w-promotions .promo-cart-discount > div','width_measure','%','','','.w-promotions'),(938250,'printshop','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width_measure','%','','','.p-sample-checkout-login'),(938251,'printshop','.w-promotions .prom-multi-discount .list','width_measure','%','','','.w-promotions'),(938252,'printshop','.w-promotions .nextdiscount .item-holder .name','width_measure','%','','','.w-promotions'),(938253,'printshop','.w-promotions .nextdiscount .item-holder .image','width_measure','%','','','.w-promotions'),(938254,'printshop','.w-promotions .promo-salemaker .item','width_measure','%','','','.w-promotions'),(938255,'printshop','.b-preloader .preloader','width_measure','%','','','.b-preloader'),(938256,'printshop','.b-products-listing .products-listing .attribute-qty-block','width_measure','%','','','.b-products-listing'),(938257,'printshop','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(938258,'printshop','.w-cart-continue-btn a','width_measure','%','5333','','.w-cart-continue-btn'),(938259,'printshop','.w-cart-checkout-btn ','width_measure','%','5333','','.w-cart-checkout-btn'),(938260,'printshop','.b-messages .box-block.type-6 > .block:nth-child(1)','width_measure','%','','','.b-messages'),(938261,'printshop','.b-messages .messages-sidebar .btn-2','width_measure','%','','','.b-messages'),(938262,'printshop','.b-messages .email-line input','width_measure','%','','','.b-messages'),(938263,'printshop','.w-sitemap-delivery-location > ul > li > ul > li','width_measure','%','','','.w-sitemap-delivery-location'),(938264,'printshop','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(938265,'printshop','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(938266,'printshop','.p-payer-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-confirmation'),(938267,'printshop','.p-payer-order-pay .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-pay'),(938268,'printshop','.w-checkout-terms .required-message','width_measure','%','','','.w-checkout-terms'),(938269,'printshop','.b-form .checkbox-style:checked + .checkbox-span','width_measure','x','','','.b-form'),(938270,'printshop','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(938271,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(938272,'printshop','.w-upload-customer-id-upload-customer-id-form .dz-details','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(938273,'printshop','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(938274,'printshop','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(938275,'printshop','.w-login-block .input','width_measure','%','','','.w-login-block'),(938276,'printshop','.w-login-block .guest','width_measure','%','','','.w-login-block'),(938277,'printshop','.w-login-block .new','width_measure','%','','','.w-login-block'),(938278,'printshop','.w-login-block .returning','width_measure','%','','','.w-login-block'),(938279,'printshop','.w-product-wishlist-button .btn','width_measure','%','5333','','.w-product-wishlist-button'),(938280,'printshop','.w-cart-order-total.box','width_measure','%','5333','','.w-cart-order-total'),(938281,'printshop','.w-cart-give-away .ga_attributes select','width_measure','%','','','.w-cart-give-away'),(938282,'printshop','.w-categories .item','width_measure','%','5333','','.w-categories'),(938283,'printshop','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(938284,'printshop','.b-email .totals-title','width_measure','%','','','.b-email'),(938285,'printshop','.b-email .totals-table','width_measure','%','','','.b-email'),(938286,'printshop','.w-login-block .input','width_measure','%','','','.w-login-block'),(938287,'printshop','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(938288,'printshop','.w-cart-order-total.box','width_measure','%','5333','','.w-cart-order-total'),(938289,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(938290,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(938291,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(938292,'printshop','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(938293,'printshop','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(938294,'printshop','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(938295,'printshop','.w-login-block .input','width_measure','%','','','.w-login-block'),(938296,'printshop','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(938297,'printshop','.w-filters .ui-slider','width_measure','%','','','.w-filters'),(938298,'printshop','.w-cart-give-away .ga_column','width_measure','%','','','.w-cart-give-away'),(938299,'printshop','.w-product-wishlist-button .btn','width_measure','%','5333','','.w-product-wishlist-button'),(938301,'printshop','.w-promo-code .promo-text','width_measure','%','5342','','.w-promo-code'),(938302,'printshop','.w-tabs .tab-navigation','width_measure','%','','','.w-tabs'),(938303,'printshop','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width_measure','%','','','.p-quote-checkout-login'),(938304,'printshop','.b-products-listing .select-attributes select','width_measure','%','','','.b-products-listing'),(938305,'printshop','.w-cart-listing .right-area','width_measure','%','5342','','.w-cart-listing'),(938306,'printshop','.p-quick-order-index .all-scroll-div','width_measure','%','','','.p-quick-order-index'),(938307,'printshop','.w-cart-order-total.box','width_measure','%','5333','','.w-cart-order-total'),(938308,'printshop','.view-all','width_measure','%','3','',''),(938309,'printshop','.b-form .columns .col-2','width_measure','%','','','.b-form'),(938310,'printshop','.b-email .totals-title','width_measure','%','','','.b-email'),(938311,'printshop','.w-cart-checkout-btn a','width_measure','%','5333','','.w-cart-checkout-btn'),(938312,'printshop','.w-cart-order-total.box','width_measure','%','5333','','.w-cart-order-total'),(938313,'printshop','.w-top-categories .item','width_measure','%','','','.w-top-categories'),(938315,'printshop','.b-bottom .popup-box.popupCompare','width_measure','%','','','.b-bottom'),(938316,'printshop','.w-cart-order-total.box','width_measure','%','5333','','.w-cart-order-total'),(938317,'printshop','.w-promo-code .promo-text','width_measure','%','5342','','.w-promo-code'),(938318,'printshop','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(938319,'printshop','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(938320,'printshop','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(938321,'printshop','.b-form .login-col-1','width_measure','%','','','.b-form'),(938322,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(938323,'printshop','.b-email .products-table','width_measure','%','','','.b-email'),(938324,'printshop','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(938325,'printshop','.w-list-b2b .select-attributes','width_measure','%','','','.w-list-b2b'),(938326,'printshop','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(938327,'printshop','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(938328,'printshop','.w-checkout-shipping-choice label','width_measure','%','','','.w-checkout-shipping-choice'),(938329,'printshop','.b-products-listing .btn-choose-options','width_measure','%','','','.b-products-listing'),(938330,'printshop','.b-email .products-table','width_measure','%','','','.b-email'),(938331,'printshop','.w-checkout-create-account .col-2','width_measure','%','5342','','.w-checkout-create-account'),(938332,'printshop','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(938333,'printshop','.w-product-wishlist-button .btn','width_measure','%','5333','','.w-product-wishlist-button'),(938334,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(938335,'printshop','.b-email .products-table','width_measure','%','','','.b-email'),(938336,'printshop','.b-email .totals-title','width_measure','%','','','.b-email'),(938337,'printshop','.b-email .totals-value','width_measure','%','','','.b-email'),(938338,'printshop','.b-email .totals-table','width_measure','%','','','.b-email'),(938339,'printshop','.b-email .products-table','width_measure','%','','','.b-email'),(938340,'printshop','.w-cart-continue-btn a','width_measure','%','5333','','.w-cart-continue-btn'),(938341,'printshop','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(938342,'printshop','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(938343,'printshop','.w-promo-code .promo-code-form','width_measure','%','5342','','.w-promo-code'),(938344,'printshop','.w-promo-code .promo-text','width_measure','%','5342','','.w-promo-code'),(938345,'printshop','.b-form .columns .col-2','width_measure','%','5363','','.b-form'),(938346,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(938347,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(938348,'printshop','.w-login-block .input','width_measure','%','','','.w-login-block'),(938349,'printshop','.w-login-block .returning','width_measure','%','','','.w-login-block'),(938350,'printshop','.w-login-block .new','width_measure','%','','','.w-login-block'),(938351,'printshop','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(938352,'printshop','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(938353,'printshop','.w-login-block .guest','width_measure','%','','','.w-login-block'),(938354,'printshop','.b-form .col-left','width_measure','%','','','.b-form'),(938355,'printshop','.w-cart-give-away .ga_attributes > div','width_measure','%','','','.w-cart-give-away'),(938356,'printshop','.w-image-maps .svg-wrap svg','width_measure','%','','','.w-image-maps'),(938357,'printshop','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width_measure','%','','','.b-form'),(938358,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(938359,'printshop','.w-cart-listing .links','width_measure','%','','','.w-cart-listing'),(938360,'printshop','.w-login-block .returning','width_measure','%','','','.w-login-block'),(938361,'printshop','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(938362,'printshop','.w-login-block .guest','width_measure','%','','','.w-login-block'),(938363,'printshop','.w-login-block .new','width_measure','%','','','.w-login-block'),(938364,'printshop','.w-cart-shipping-estimator .left-area','width_measure','%','','','.w-cart-shipping-estimator'),(938365,'printshop','.b-form .col-right','width_measure','%','','','.b-form'),(938366,'printshop','.b-email .totals-title','width_measure','%','','','.b-email'),(938367,'printshop','.b-email .products-table','width_measure','%','','','.b-email'),(938368,'printshop','.b-bottom .cart-options .option-item','width_measure','%','','','.b-bottom'),(938369,'printshop','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(938370,'printshop','.b-bottom .cart-options .cart-item','width_measure','%','','','.b-bottom'),(938371,'printshop','.w-login-block .guest','width_measure','%','','','.w-login-block'),(938372,'printshop','.b-email .totals-table','width_measure','%','','','.b-email'),(938373,'printshop','.b-email .totals-value','width_measure','%','','','.b-email'),(938374,'printshop','.w-promo-code .promo-text','width_measure','%','5342','','.w-promo-code'),(938375,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(938376,'printshop','.w-login-block .returning','width_measure','%','','','.w-login-block'),(938377,'printshop','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(938378,'printshop','.w-cart-continue-btn a','width_measure','%','5333','','.w-cart-continue-btn'),(938379,'printshop','.b-email .totals-value','width_measure','%','','','.b-email'),(938380,'printshop','.b-form .col-left','width_measure','%','5342','','.b-form'),(938381,'printshop','.b-form .middle-form .dob-input input[type=\"text\"]','width_measure','%','','','.b-form'),(938382,'printshop','.w-top-categories .item','width_measure','%','5333','','.w-top-categories'),(938383,'printshop','.w-categories .item','width_measure','%','5363','','.w-categories'),(938384,'printshop','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(938385,'printshop','.w-checkout-billing-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-billing-address'),(938386,'printshop','.w-checkout-shipping-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-shipping-address'),(938387,'printshop','.w-cart-order-total.box','width_measure','%','5333','','.w-cart-order-total'),(938388,'printshop','.w-product-wishlist-button .btn','width_measure','%','5333','','.w-product-wishlist-button'),(938389,'printshop','.w-cart-continue-btn a','width_measure','%','5333','','.w-cart-continue-btn'),(938390,'printshop','.w-promo-code .promo-text','width_measure','%','5342','','.w-promo-code'),(938391,'printshop','.w-promo-code .promo-code-form','width_measure','%','5342','','.w-promo-code'),(938392,'printshop','.w-promo-code .promo-text','width_measure','%','5342','','.w-promo-code'),(938393,'printshop','.w-checkout-billing-address .addresses .address-item','width_measure','%','','','.w-checkout-billing-address'),(938394,'printshop','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(938395,'printshop','.b-products-listing .products-listing .buyButton .btn','width_measure','%','','','.b-products-listing'),(938396,'printshop','.b-select-suggest .select2-search input','width_measure','%','','','.b-select-suggest'),(938397,'printshop','.b-select-suggest .select2-search','width_measure','%','','','.b-select-suggest'),(938398,'printshop','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width_measure','%','','','.b-select-suggest'),(938399,'printshop','.b-select-suggest .select2-drop','width_measure','%','','','.b-select-suggest'),(938400,'printshop','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(938401,'printshop','.w-login-block .input','width_measure','%','','','.w-login-block'),(938402,'printshop','.w-login-block .new','width_measure','%','','','.w-login-block'),(938403,'printshop','.w-login-block .returning','width_measure','%','','','.w-login-block'),(938404,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(938406,'printshop','.w-login-block .returning','width_measure','%','','','.w-login-block'),(938407,'printshop','.w-cart-continue-btn a','width_measure','%','5333','','.w-cart-continue-btn'),(938408,'printshop','.w-product-wishlist-button .btn','width_measure','%','5333','','.w-product-wishlist-button'),(938409,'printshop','.w-account-addresses-list .addsess-suggestion-item','width_measure','%','','','.w-account-addresses-list'),(938410,'printshop','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(938411,'printshop','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(938412,'printshop','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(938413,'printshop','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(938414,'printshop','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(938415,'printshop','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(938416,'printshop','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(938417,'printshop','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(938418,'printshop','.b-products-listing .BlockBox.type-14 > .col','width_measure','%','','','.b-products-listing'),(938419,'printshop','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(938420,'printshop','.b-products-listing .BlockBox.type-15 > .col','width_measure','%','','','.b-products-listing'),(938421,'printshop','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(938422,'printshop','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(938423,'printshop','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(938424,'printshop','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(938425,'printshop','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(938426,'printshop','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(938427,'printshop','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(938428,'printshop','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(938429,'printshop','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(938430,'printshop','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(938431,'printshop','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(938432,'printshop','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(938433,'printshop','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(938434,'printshop','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(938435,'printshop','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(938436,'printshop','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(938437,'printshop','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(938438,'printshop','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(938439,'printshop','.b-products-listing .loader','width_measure','%','3','','.b-products-listing'),(938440,'printshop','.b-products-listing .products-listing .attribute-qty-block > span','width_measure','%','','','.b-products-listing');
INSERT INTO `themes_styles` VALUES (938441,'printshop','.b-products-listing .products-listing .attributes select','width_measure','%','','','.b-products-listing'),(938442,'printshop','.b-products-listing .products-listing .item','width_measure','%','','','.b-products-listing'),(938443,'printshop','.w-catalog-b2b-add-button ','width_measure','%','','','.w-catalog-b2b-add-button'),(938444,'printshop','.b-products-listing .products-listing .qty-input.hidden','width_measure','%','3','','.b-products-listing'),(938445,'printshop','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width_measure','%','','','.b-products-listing'),(938447,'printshop','.b-products-listing .products-listing .in-cart','width_measure','%','','','.b-products-listing'),(938448,'printshop','.b-select-suggest .select2-container','width_measure','%','','','.b-select-suggest'),(938449,'printshop','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(938450,'printshop','.b-email .totals-table','width_measure','%','','','.b-email'),(938451,'printshop','.b-email .totals-value','width_measure','%','','','.b-email'),(938452,'printshop','.b-email .totals-title','width_measure','%','','','.b-email'),(938453,'printshop','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width_measure','%','','','.b-fancybox'),(938454,'printshop','.w-promo-code .promo-code-form','width_measure','%','5342','','.w-promo-code'),(938455,'printshop','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(938456,'printshop','.w-communication-new-topic .middle-form select','width_measure','%','','','.w-communication-new-topic'),(938457,'printshop','.b-form .hide-billing-address','width_measure','%','','','.b-form'),(938458,'printshop','.b-email .totals-value','width_measure','%','','','.b-email'),(938459,'printshop','.b-email .products-table','width_measure','%','','','.b-email'),(938460,'printshop','.b-bottom .popup-credit-amount .popup-box','width_measure','%','','','.b-bottom'),(938461,'printshop','.w-promo-code .promo-code-form','width_measure','%','5342','','.w-promo-code'),(938462,'printshop','.w-login-block .new','width_measure','%','','','.w-login-block'),(938463,'printshop','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(938464,'printshop','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(938465,'printshop','.b-compare .col-two label','width_measure','%','','','.b-compare'),(938466,'printshop','.b-form .addresses .address-item','width_measure','%','','','.b-form'),(938467,'printshop','.w-cart-continue-btn a','width_measure','%','5333','','.w-cart-continue-btn'),(938468,'printshop','.w-cart-shipping-estimator .right-area','width_measure','%','','','.w-cart-shipping-estimator'),(938469,'printshop','.w-cart-listing .right-area','width_measure','%','','','.w-cart-listing'),(938470,'printshop','.w-cart-listing .item .remove','width_measure','%','5342','','.w-cart-listing'),(938471,'printshop','.w-cart-give-away .ga_img','width_measure','%','','','.w-cart-give-away'),(938472,'printshop','.w-cart-give-away .ga_column','width_measure','%','5333','','.w-cart-give-away'),(938473,'printshop','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(938474,'printshop','.b-fancybox .fancybox-nav','width_measure','%','','','.b-fancybox'),(938475,'printshop','.w-promo-code .promo-code-form','width_measure','%','5342','','.w-promo-code'),(938476,'printshop','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(938477,'printshop','.w-login-block .input','width_measure','%','','','.w-login-block'),(938478,'printshop','.w-login-block .new','width_measure','%','','','.w-login-block'),(938479,'printshop','.w-login-block .guest','width_measure','%','','','.w-login-block'),(938480,'printshop','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(938481,'printshop','.w-checkout-shipping-address .addresses .address-item','width_measure','%','','','.w-checkout-shipping-address'),(938482,'printshop','.w-login-block .guest','width_measure','%','','','.w-login-block'),(938483,'printshop','.w-filters .handle-from','width_measure','%','','','.w-filters'),(938484,'printshop','.w-promo-code .promo-code-form','width_measure','%','5342','','.w-promo-code'),(938485,'printshop','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(938486,'printshop','.w-filters .handle-to','width_measure','%','','','.w-filters'),(938487,'printshop','.w-categories .item','width_measure','%','','','.w-categories'),(938488,'printshop','.p-wedding-registry-search .search-list input','width_measure','%','','','.p-wedding-registry-search'),(938489,'printshop','.b-compare .col-two select','width_measure','%','','','.b-compare'),(938490,'printshop','.b-email .totals-table','width_measure','%','','','.b-email'),(938491,'printshop','.b-form .col-3','width_measure','%','','','.b-form'),(938492,'printshop','textarea','width_measure','%','','',''),(938493,'printshop','.w-product-wishlist-button .btn','width_measure','%','5333','','.w-product-wishlist-button'),(938494,'printshop','.b-products-listing .products-listing .btn-preloader','width_measure','%','','','.b-products-listing'),(938495,'printshop','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width_measure','%','','','.b-form'),(938496,'printshop','.b-email .totals-title','width_measure','%','','','.b-email'),(938497,'printshop','.b-email .totals-value','width_measure','%','','','.b-email'),(938498,'printshop','.b-email .totals-table','width_measure','%','','','.b-email'),(938499,'printshop','.w-filters .input-txt-keywords','width_measure','%','','','.w-filters'),(938500,'printshop','.w-filters .input-txt','width_measure','%','','','.w-filters'),(938501,'printshop','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width_measure','vw','','','.b-menu-lev_display-slide'),(938502,'printshop','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width_measure','vw','','','.b-menu-lev_display-slide'),(938503,'printshop','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width_measure','vw','','','.b-menu-lev_display-slide'),(938504,'printshop','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width_measure','vw','','','.b-menu-lev_display-slide'),(938505,'printshop','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width_measure','vw','','','.b-menu-lev_display-slide'),(938506,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_measure','vw','','','.b-menu-open_from-left'),(938507,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(938508,'printshop','.b-trade-approval .steps-bar','width_measure','%','','','.b-trade-approval'),(938509,'printshop','.b-trade-approval .col-right','width_measure','%','','','.b-trade-approval'),(938510,'printshop','.b-trade-approval .col-left','width_measure','%','','','.b-trade-approval'),(938511,'printshop','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width_measure','%','','','.b-trade-approval'),(938512,'printshop','.b-trade-approval .col-3','width_measure','%','','','.b-trade-approval'),(938513,'printshop','.w-account-personal-catalog .list-switcher','width_measure','%','','','.w-account-personal-catalog'),(938514,'printshop','.w-catalog-compare .cross-box .different-all > div','width_measure','%','','','.w-catalog-compare'),(938516,'printshop','.shopByCollectionBox .w-banner .single_banner','width_measure','%','','','.shopByCollectionBox'),(938517,'printshop','.tripleBanner > .block','width_measure','%','5342','','.tripleBanner'),(938518,'printshop','.b-products-listing .item-nav > div','width_measure','%','','','.b-products-listing'),(938519,'printshop','.w-product-sale-ends .left-count','width_measure','%','','','.w-product-sale-ends'),(938520,'printshop','.w-product-sale-ends .left-text-left','width_measure','%','','','.w-product-sale-ends'),(938521,'printshop','.w-product-sale-ends .left-text-right','width_measure','%','','','.w-product-sale-ends'),(938522,'printshop','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(938523,'printshop','.w-product-bonus-points > div > div','width_measure','%','','','.w-product-bonus-points'),(938524,'printshop','.w-files-catalog-widgets-files-catalog .item','width_measure','%','','','.w-files-catalog-widgets-files-catalog'),(938525,'printshop','.w-files-catalog-widgets-files-catalog .item','width_measure','%','5347','','.w-files-catalog-widgets-files-catalog'),(938526,'printshop','.w-files-catalog-widgets-files-catalog .item','width_measure','%','5342','','.w-files-catalog-widgets-files-catalog'),(938527,'printshop','.w-files-catalog-widgets-files-catalog .item','width_measure','%','5333','','.w-files-catalog-widgets-files-catalog'),(938528,'printshop','.w-cart-discount-coupon input[type=\"text\"]','width_measure','%','','','.w-cart-discount-coupon'),(938529,'printshop','.w-cart-sub-total .price-row','width_measure','%','','','.w-cart-sub-total'),(938530,'printshop','.w-cart-sub-total .price-row > div','width_measure','%','','','.w-cart-sub-total'),(938531,'printshop','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(938532,'printshop','.w-cart-gift-certificate .input-apple','width_measure','%','','','.w-cart-gift-certificate'),(938533,'printshop','.w-cart-gift-certificate .input-apple div','width_measure','%','','','.w-cart-gift-certificate'),(938534,'printshop','.w-cart-order-reference .input-apple','width_measure','%','','','.w-cart-order-reference'),(938535,'printshop','.w-cart-order-reference .input-apple div','width_measure','%','','','.w-cart-order-reference'),(938536,'printshop','.w-cart-order-reference .input-apple div input','width_measure','%','','','.w-cart-order-reference'),(938537,'printshop','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(938538,'printshop','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(938539,'printshop','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(938540,'printshop','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(938541,'printshop','.w-product-bundle .bundle_item','width_measure','%','5342','','.w-product-bundle'),(938542,'printshop','.w-product-bundle .bundle_item','width_measure','%','5333','','.w-product-bundle'),(938543,'printshop','.w-product-in-bundles .attributes-item','width_measure','%','','','.w-product-in-bundles'),(938544,'printshop','.w-product-in-bundles .attributes-select','width_measure','%','','','.w-product-in-bundles'),(938545,'printshop','.w-product-in-bundles .bundle_item','width_measure','%','5342','','.w-product-in-bundles'),(938546,'printshop','.w-product-in-bundles .bundle_item','width_measure','%','5333','','.w-product-in-bundles'),(938547,'printshop','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(938548,'printshop','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(938549,'printshop','.w-product-quantity-discounts .item','width_measure','%','','','.w-product-quantity-discounts'),(938550,'printshop','.w-product-quantity-discounts .item','width_measure','%','5342','','.w-product-quantity-discounts'),(938551,'printshop','.w-product-multi-inventory .select-box:nth-child(2n)','width_measure','%','','','.w-product-multi-inventory'),(938552,'printshop','.w-product-multi-inventory .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-multi-inventory'),(938553,'printshop','.p-sample-checkout-index .order-summary .heading-2','width_measure','%','3','','.p-sample-checkout-index'),(938554,'printshop','.p-sample-checkout-index .order-summary .heading-2','width_measure','%','4','','.p-sample-checkout-index'),(938556,'printshop','.w-product-multi-inventory .radio-attributes > label','width_measure','%','','','.w-product-multi-inventory'),(938557,'printshop','.w-product-multi-inventory .radio-attributes .option-item','width_measure','%','','','.w-product-multi-inventory'),(938558,'printshop','.w-product-multi-inventory .radio-attributes > label','width_measure','%','5347','','.w-product-multi-inventory'),(938559,'printshop','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','width_measure','%','','','.w-account-personal-catalog'),(938560,'printshop','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width_measure','%','5347','','.b-products-listing'),(938561,'printshop','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width_measure','%','5347','','.b-products-listing'),(938562,'printshop','.b-products-listing .products-listing .radio-attributes .option','width_measure','%','','','.b-products-listing'),(938563,'printshop','.b-products-listing .products-listing .radio-attributes > label','width_measure','%','','','.b-products-listing'),(938564,'printshop','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(938565,'printshop','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(938566,'printshop','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(938567,'printshop','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(938568,'printshop','.w-product-collection .current-product, .w-product-collection .chosen-products','width_measure','%','5342','','.w-product-collection'),(938569,'printshop','.w-product-collection .right-area','width_measure','%','5342','','.w-product-collection'),(938570,'printshop','.w-product-attributes .radio-attributes .option-item','width_measure','%','','','.w-product-attributes'),(938571,'printshop','.w-product-attributes .radio-attributes > label','width_measure','%','','','.w-product-attributes'),(938572,'printshop','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(938573,'printshop','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(938574,'printshop','.w-product-attributes .radio-attributes > label','width_measure','%','5347','','.w-product-attributes'),(938575,'printshop','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(938576,'printshop','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(938577,'printshop','.w-product-properties li','width_measure','%','','','.w-product-properties'),(938578,'printshop','.w-product-groups .radioBox label','width_measure','%','','','.w-product-groups'),(938579,'printshop','.w-product-groups .radioBox label','width_measure','%','5363','','.w-product-groups'),(938580,'printshop','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(938581,'printshop','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(938582,'printshop','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(938583,'printshop','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(938584,'printshop','.w-product-custom-bundle .chosen-products','width_measure','%','5342','','.w-product-custom-bundle'),(938585,'printshop','.w-product-custom-bundle .right-area','width_measure','%','5342','','.w-product-custom-bundle'),(938586,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width_measure','%','','','.w-catalog-pages-category-pages-last-list'),(938587,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width_measure','%','5342','','.w-catalog-pages-category-pages-last-list'),(938588,'printshop','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width_measure','%','5333','','.w-catalog-pages-category-pages-last-list'),(938589,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width_measure','%','','','.w-catalog-pages-category-pages-last-list-block'),(938590,'printshop','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(938591,'printshop','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(938592,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width_measure','%','5342','','.w-catalog-pages-category-pages-last-list-block'),(938593,'printshop','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width_measure','%','5333','','.w-catalog-pages-category-pages-last-list-block'),(938594,'printshop','.w-delivery-location-location-list .deliveryList li','width_measure','%','5342','','.w-delivery-location-location-list'),(938595,'printshop','.w-delivery-location-location-list .deliveryList li','width_measure','%','5333','','.w-delivery-location-location-list'),(938596,'printshop','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','5333','','.w-delivery-location-top-location-list'),(938597,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li','width_measure','%','','','.w-delivery-location-featured-list'),(938598,'printshop','.w-delivery-location-featured-list .deliveryList > ul > li','width_measure','%','5363','','.w-delivery-location-featured-list'),(938599,'printshop','.w-sale-category .holder-1','width_measure','%','','','.w-sale-category'),(938600,'printshop','.w-sale-category .holder-2','width_measure','%','','','.w-sale-category'),(938601,'printshop','.w-sale-category .image','width_measure','%','','','.w-sale-category'),(938602,'printshop','.w-sale-category .left-count','width_measure','%','','','.w-sale-category'),(938603,'printshop','.w-sale-category .left-text-left','width_measure','%','','','.w-sale-category'),(938604,'printshop','.w-sale-category .left-text-right','width_measure','%','','','.w-sale-category'),(938605,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width_measure','%','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(938606,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width_measure','%','5333','','.w-catalog-pages-category-pages-last-list-by-catalog'),(938607,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width_measure','%','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(938608,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width_measure','%','5333','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(938609,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width_measure','%','5342','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(938610,'printshop','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width_measure','%','5342','','.w-catalog-pages-category-pages-last-list-by-catalog'),(938611,'printshop','.w-delivery-location-list-by-page .item','width_measure','%','','','.w-delivery-location-list-by-page'),(938612,'printshop','.w-delivery-location-list-by-page .item','width_measure','%','5342','','.w-delivery-location-list-by-page'),(938613,'printshop','.w-delivery-location-list-by-page .item','width_measure','%','5363','','.w-delivery-location-list-by-page'),(938614,'printshop','.w-product-properties-icons .hover-box-content','width_measure','%','','','.w-product-properties-icons'),(938615,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','width_measure','%','5363','','.w-product-properties-icons'),(938616,'printshop','.w-delivery-location-cross-pages .item','width_measure','%','','','.w-delivery-location-cross-pages'),(938617,'printshop','.w-delivery-location-cross-pages .item','width_measure','%','5342','','.w-delivery-location-cross-pages'),(938618,'printshop','.w-delivery-location-cross-pages .item','width_measure','%','5363','','.w-delivery-location-cross-pages'),(938619,'printshop','.w-delivery-location-product-categories .item.category-link','width_measure','%','','','.w-delivery-location-product-categories'),(938620,'printshop','.w-delivery-location-product-categories .item.category-link','width_measure','%','5342','','.w-delivery-location-product-categories'),(938621,'printshop','.w-delivery-location-product-categories .item.category-link','width_measure','%','5363','','.w-delivery-location-product-categories'),(938622,'printshop','.w-delivery-location-product-categories .item.category-link','width_measure','%','5333','','.w-delivery-location-product-categories'),(938623,'printshop','.w-catalog-delivery-locations .item','width_measure','%','','','.w-catalog-delivery-locations'),(938624,'printshop','.w-catalog-delivery-locations .item','width_measure','%','5333','','.w-catalog-delivery-locations'),(938625,'printshop','.w-product-bonus-points .bonus-points-cost','width_measure','%','','','.w-product-bonus-points'),(938626,'printshop','.w-product-designer-designer .prodDesignerType','width_measure','%','','','.w-product-designer-designer'),(938627,'printshop','.w-product-designer-designer .productDesignerBox input','width_measure','%','','','.w-product-designer-designer'),(938628,'printshop','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','width_measure','%','','','.w-press-reviews-widgets-press-reviews-small'),(938629,'printshop','.w-press-reviews-widgets-press-reviews-small .small-press-review','width_measure','%','','','.w-press-reviews-widgets-press-reviews-small'),(938630,'printshop','.w-support-system-listing .product_icon','width_measure','%','','','.w-support-system-listing'),(938631,'printshop','.w-rma-returns-history input[type=\'text\'], .w-rma-returns-history input[type=\'password\'], .w-rma-returns-history input[type=\'number\'], .w-rma-returns-history input[type=\'email\'], .w-rma-returns-history input[type=\'search\'], .w-rma-returns-history select','width_measure','%','','','.w-rma-returns-history'),(938632,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(938633,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(938634,'printshop','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(938635,'printshop','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(938636,'printshop','.w-product-configurator .item-content','width_measure','%','5342','','.w-product-configurator'),(938637,'printshop','.w-product-configurator .pc_item','width_measure','%','5342','','.w-product-configurator'),(938638,'printshop','.b-products-listing .products-listing .bonus-points-cost','width_measure','%','','','.b-products-listing'),(938639,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width_measure','%','','','.w-catalog-pages-category-pages-list'),(938640,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width_measure','%','5342','','.w-catalog-pages-category-pages-list'),(938641,'printshop','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width_measure','%','5333','','.w-catalog-pages-category-pages-list'),(938642,'printshop','.w-predefined-promotion .nextdiscount .item-holder .image','width_measure','%','','','.w-predefined-promotion'),(938643,'printshop','.w-predefined-promotion .nextdiscount .item-holder .name','width_measure','%','','','.w-predefined-promotion'),(938644,'printshop','.w-predefined-promotion .prom-multi-discount .list','width_measure','%','','','.w-predefined-promotion'),(938645,'printshop','.w-predefined-promotion .promo-cart-discount > div','width_measure','%','','','.w-predefined-promotion'),(938646,'printshop','.w-predefined-promotion .promo-salemaker .item','width_measure','%','','','.w-predefined-promotion'),(938647,'printshop','.w-predefined-promotion .promo-salemaker > div','width_measure','%','','','.w-predefined-promotion'),(938649,'printshop','.tripleLine .w-banner .image-text-banner.bottom-center','width_measure','%','','','.tripleLine'),(938650,'printshop','.bottomBanner .icon-box > div','width_measure','%','','','.bottomBanner'),(938651,'printshop','.b-menu-open_from-top .menu-style[data-open_from=\"top\"] .menu-content','width_measure','vw','','','.b-menu-open_from-top'),(938652,'printshop','.tripleLine .w-banner .image-text-banner.bottom-center','width_measure','%','5363','','.tripleLine'),(938653,'printshop','.pop-up-content .buttons .btn','width_measure','%','5333','',''),(938654,'printshop','.pop-up-content .buttons .btn-2','width_measure','%','5333','',''),(938655,'printshop','.pop-up-content .buttons .left-buttons','width_measure','%','5333','',''),(938656,'printshop','.pop-up-content .buttons .right-buttons','width_measure','%','5333','',''),(938657,'printshop','.w-categories .item','width_measure','%','5347','','.w-categories'),(938658,'printshop','.w-product-multi-inventory .select-box:nth-child(2n+1)','width_measure','%','5363','','.w-product-multi-inventory'),(938659,'printshop','.w-product-multi-inventory .radio-attributes > label','width_measure','%','5363','','.w-product-multi-inventory'),(938660,'printshop','.w-product-attributes .radio-attributes > label','width_measure','%','5363','','.w-product-attributes'),(938661,'printshop','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','5363','','.w-product-attributes'),(938663,'printshop','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','width_measure','%','5363','','.w-product-buttons'),(938664,'printshop','.topBanner .ourPick','width_measure','%','','','.topBanner'),(938665,'printshop','.topBanner .w-banner .image-text-banner.middle-left .text-banner-1','width_measure','%','5333','','.topBanner'),(938666,'printshop','.topBanner .w-banner .text-middle-left .banner-text','width_measure','%','5333','','.topBanner'),(938667,'printshop','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','width_measure','%','','','.w-promotions-widgets-promotion-icons-desc'),(938668,'printshop','.w-promotions-widgets-promotion-icons-desc .promo-icon','width_measure','%','','','.w-promotions-widgets-promotion-icons-desc'),(938669,'printshop','.tripleLine .w-banner .banner-item.text-bottom-center','width_measure','%','5363','','.tripleLine'),(938670,'printshop','.w-cart-shipping-estimator .left-area','width_measure','%','5363','','.w-cart-shipping-estimator'),(938671,'printshop','.w-cart-shipping-estimator .right-area','width_measure','%','5363','','.w-cart-shipping-estimator'),(938672,'printshop','.p-quote-checkout-index .dob-hide > div','width_measure','%','','','.p-quote-checkout-index'),(938673,'printshop','.p-quote-checkout-index .edit-address-popup .addresses .buttons','width_measure','%','','','.p-quote-checkout-index'),(938674,'printshop','.p-quote-checkout-index .order-summary2 .btn-2','width_measure','%','','','.p-quote-checkout-index'),(938679,'printshop','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','width_measure','%','','','.account-address-book'),(938680,'printshop','.account-address-book .address_book_row .column','width_measure','%','5333','','.account-address-book'),(938681,'printshop','.account-address-book .address_book_row .column + .column','width_measure','%','5333','','.account-address-book'),(938682,'printshop','.account-address-book .topInfo > div','width_measure','%','5333','','.account-address-book'),(938683,'printshop','.account-address-book .topInfo > div + div','width_measure','%','5333','','.account-address-book'),(938695,'printshop','.account-order-pay .history_info > div','width_measure','%','','','.account-order-pay'),(938696,'printshop','.account-order-pay .history_info > div','width_measure','%','5342','','.account-order-pay'),(938697,'printshop','.account-samples .orders-table .td-alignright','width_measure','%','5342','','.account-samples'),(938698,'printshop','.account-sample-info .history_info > div','width_measure','%','','','.account-sample-info'),(938699,'printshop','.account-sample-info .history_info > div','width_measure','%','5342','','.account-sample-info'),(938700,'printshop','.checkout-index-wrap .dob-hide > div','width_measure','%','','','.checkout-index-wrap'),(938701,'printshop','.checkout-index-wrap .edit-address-popup .addresses .buttons','width_measure','%','','','.checkout-index-wrap'),(938702,'printshop','.checkout-index-wrap .order-summary2 .btn-2','width_measure','%','','','.checkout-index-wrap'),(938703,'printshop','.checkout-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.checkout-order-confirmation'),(938704,'printshop','.checkout-login-wrap .col-left, .checkout-login-wrap .col-right','width_measure','%','','','.checkout-login-wrap'),(938705,'printshop','.checkout-login-wrap .middle-form .btn-2','width_measure','%','','','.checkout-login-wrap'),(938706,'printshop','.b-form .password-row','width_measure','%','','','.b-form'),(938707,'printshop','.b-form .center-buttons','width_measure','%','','','.b-form'),(938708,'printshop','.b-form .col-gender','width_measure','%','','','.b-form'),(938709,'printshop','.hide-page','width_measure','%','','',''),(938710,'printshop','.tripleLine .w-banner .banner-item','width_measure','%','','','.tripleLine'),(938711,'printshop','.middleBanner div.banner-text-holder','width_measure','%','5342','','.middleBanner'),(938714,'printshop','.footer-menu .level-2 > li','width_measure','%','','','.footer-menu'),(938715,'printshop','.footer-menu .level-2 > li','width_measure','%','5347','','.footer-menu'),(938716,'printshop','.w-account-customer-additional-field .field-type-checkbox label','width_measure','%','','','.w-account-customer-additional-field'),(938717,'printshop','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width_measure','%','','','.w-account-customer-additional-field'),(938718,'printshop','.w-account-customer-additional-field .field-type-text label','width_measure','%','','','.w-account-customer-additional-field'),(938719,'printshop','.w-banner .banner-text-holder','width_measure','%','','','.w-banner'),(938720,'printshop','.w-banner .carousel-text','width_measure','%','','','.w-banner'),(938721,'printshop','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width_measure','%','','','.w-banner'),(938722,'printshop','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width_measure','%','','','.w-banner'),(938723,'printshop','.w-sale .holder-1','width_measure','%','','','.w-sale'),(938724,'printshop','.w-sale .holder-2','width_measure','%','','','.w-sale'),(938725,'printshop','.w-sale .image','width_measure','%','','','.w-sale'),(938726,'printshop','.w-sale .left-count','width_measure','%','','','.w-sale'),(938727,'printshop','.w-sale .left-text-left','width_measure','%','','','.w-sale'),(938728,'printshop','.w-sale .left-text-right','width_measure','%','','','.w-sale'),(938729,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_measure_important','important','','','.b-menu-open_from-left'),(938730,'printshop','.tripleBanner > .block','width_measure_important','important','5342','','.tripleBanner'),(938731,'printshop','.w-cart-discount-coupon input[type=\"text\"]','width_measure_important','important','','','.w-cart-discount-coupon'),(938732,'printshop','.b-menu-open_from-top .menu-style[data-open_from=\"top\"] .menu-content','width_measure_important','important','','','.b-menu-open_from-top'),(938733,'printshop','.footer-menu .level-2 > li','width_measure_important','important','5347','','.footer-menu'),(938734,'printshop','.b-form .same-address','z-index','80','','','.b-form'),(938735,'printshop','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','z-index','-1','','','.b-switch'),(938736,'printshop','.b-fancybox .filter-listing-loader','z-index','100000','','','.b-fancybox'),(938737,'printshop','.b-fancybox .filter-listing-preloader','z-index','100001','','','.b-fancybox'),(938738,'printshop','.w-promotions .prom-multi-discount .promo-range','z-index','1','','','.w-promotions'),(938739,'printshop','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(938742,'printshop','.p-sample-checkout-success .page-success > div','z-index','1','','','.p-sample-checkout-success'),(938743,'printshop','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(938744,'printshop','.b-preloader .preloader','z-index','10','','','.b-preloader'),(938745,'printshop','.b-messages .messMenuButton span','z-index','1','','','.b-messages'),(938746,'printshop','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(938747,'printshop','.b-fancybox #fancybox-loading','z-index','8060','','','.b-fancybox'),(938748,'printshop','.b-fancybox .fancybox-wrap','z-index','8020','','','.b-fancybox'),(938749,'printshop','.w-upload-customer-id-upload-customer-id-form .upload-file','z-index','10','','','.w-upload-customer-id-upload-customer-id-form'),(938750,'printshop','.w-menu-horizontal > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-horizontal'),(938751,'printshop','.w-menu-horizontal > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-horizontal'),(938752,'printshop','.w-menu-horizontal > ul > li > ul > li > ul','z-index','23','','','.w-menu-horizontal'),(938753,'printshop','.w-quote .cart-box-link','z-index','1','','','.w-quote'),(938754,'printshop','.b-switch .bootstrap-switch','z-index','0','','','.b-switch'),(938756,'printshop','.b-info-popup .info-popup div','z-index','1000','','','.b-info-popup'),(938757,'printshop','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(938758,'printshop','.edit-link','z-index','1','','',''),(938759,'printshop','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(938760,'printshop','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(938761,'printshop','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','z-index','0','','','.b-switch'),(938762,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-label','z-index','100','','','.b-switch'),(938763,'printshop','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(938764,'printshop','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(938765,'printshop','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(938766,'printshop','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(938767,'printshop','.b-fancybox .fancybox-overlay','z-index','8010','','','.b-fancybox'),(938768,'printshop','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(938769,'printshop','.w-menu-horizontal > ul','z-index','21','','','.w-menu-horizontal'),(938770,'printshop','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','z-index','1','','','.b-switch'),(938773,'printshop','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(938774,'printshop','.w-promotions .promo-cart-discount .slave .condition','z-index','1','','','.w-promotions'),(938775,'printshop','.w-menu-horizontal > ul > li > ul','z-index','22','','','.w-menu-horizontal'),(938778,'printshop','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(938779,'printshop','.b-fancybox .fancybox-close','z-index','8040','','','.b-fancybox'),(938780,'printshop','.b-fancybox .fancybox-opened','z-index','8030','','','.b-fancybox'),(938781,'printshop','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(938782,'printshop','.b-datepicker .datepicker-dropdown','z-index','1000','','','.b-datepicker'),(938783,'printshop','.w-quote .cart-box','z-index','100','','','.w-quote'),(938784,'printshop','.p-sample-checkout-success .page-success','z-index','-1','','','.p-sample-checkout-success'),(938785,'printshop','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','z-index','1','','','.b-switch'),(938786,'printshop','.b-select-suggest .select2-search','z-index','10000','','','.b-select-suggest'),(938787,'printshop','.b-select-suggest .select2-drop-mask','z-index','9998','','','.b-select-suggest'),(938788,'printshop','.b-select-suggest .select2-drop','z-index','9999','','','.b-select-suggest'),(938791,'printshop','.w-menu-big li','z-index','20','','','.w-menu-big'),(938792,'printshop','.b-bottom .pop-up-close','z-index','1','','','.b-bottom'),(938793,'printshop','.w-catalog-b2b-add-button ','z-index','1','','','.w-catalog-b2b-add-button'),(938794,'printshop','.b-products-listing .promos-info','z-index','1','','','.b-products-listing'),(938795,'printshop','.b-autocomplete .ui-autocomplete','z-index','1000','','','.b-autocomplete'),(938797,'printshop','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(938798,'printshop','.b-form .form-inputs div.required-message','z-index','1','','','.b-form'),(938799,'printshop','.b-fancybox .fancybox-title','z-index','8050','','','.b-fancybox'),(938800,'printshop','.b-fancybox .fancybox-title-float-wrap','z-index','8050','','','.b-fancybox'),(938801,'printshop','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(938802,'printshop','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(938803,'printshop','.b-form .eye-password-wrap','z-index','1','','','.b-form'),(938804,'printshop','.b-form .eye-password','z-index','1','','','.b-form'),(938805,'printshop','.b-form .hide-billing-address','z-index','70','','','.b-form'),(938806,'printshop','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(938809,'printshop','.b-fancybox .fancybox-nav span','z-index','8040','','','.b-fancybox'),(938810,'printshop','.b-fancybox .fancybox-nav','z-index','8040','','','.b-fancybox'),(938812,'printshop','.w-menu-big > ul > li > ul','z-index','100','','','.w-menu-big'),(938813,'printshop','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','z-index','1000','','','.w-image-maps'),(938814,'printshop','.b-product-images .media-popup .mp-close','z-index','1','','','.b-product-images'),(938815,'printshop','.b-product-images .mp-shadow, .b-product-images .media-popup','z-index','1000','','','.b-product-images'),(938816,'printshop','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(938817,'printshop','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(938818,'printshop','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(938819,'printshop','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(938820,'printshop','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(938821,'printshop','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(938822,'printshop','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(938823,'printshop','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(938824,'printshop','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(938825,'printshop','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(938826,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(938827,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(938828,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(938829,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(938830,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(938831,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(938832,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(938833,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(938834,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(938835,'printshop','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(938836,'printshop','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','z-index','1000','','','.b-menu-open_from-left'),(938837,'printshop','.b-slick button.slick-prev, .b-slick button.slick-next','z-index','1','','','.b-slick'),(938838,'printshop','.header','z-index','100','5342','',''),(938839,'printshop','.w-compare ','z-index','100','','','.w-compare'),(938840,'printshop','.w-sample .cart-box','z-index','100','','','.w-sample'),(938841,'printshop','.w-sample .cart-box-link','z-index','1','','','.w-sample'),(938842,'printshop','.w-account-personal-catalog .list-row-action ul','z-index','1','','','.w-account-personal-catalog'),(938843,'printshop','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','z-index','1','','','.w-account-personal-catalog'),(938844,'printshop','.w-product-properties-icons .hover-box:hover .hover-box-content','z-index','9','','','.w-product-properties-icons'),(938845,'printshop','.w-product-designer-designer .productDesignerBox input','z-index','1','','','.w-product-designer-designer'),(938846,'printshop','.w-predefined-promotion .prom-multi-discount .promo-range','z-index','1','','','.w-predefined-promotion'),(938847,'printshop','.w-predefined-promotion .promo-cart-discount .slave .condition','z-index','1','','','.w-predefined-promotion'),(938849,'printshop','.w-filters .filter-widget-horizontal .filter-box-content','z-index','9999','','','.w-filters'),(938850,'printshop','.b-menu-open_from-top .menu-style[data-open_from=\"top\"] .menu-content','z-index','1000','','','.b-menu-open_from-top'),(938855,'printshop','.checkout-success-wrap .page-success > div','z-index','1','','','.checkout-success-wrap'),(938856,'printshop','.hide-page','z-index','100000','','',''),(938857,'printshop','.success-page .page-success > div','z-index','1','','','.success-page'),(938858,'printshop','.w-banner .banner img + img','z-index','-1','','','.w-banner'),(938859,'printshop','.w-banner .banner-text','z-index','1','','','.w-banner'),(938860,'printshop','.doubleBanner .w-banner .banner-item','width','50','','','.doubleBanner'),(938861,'printshop','.doubleBanner .w-banner .banner-item','width_measure','%','','','.doubleBanner'),(938862,'printshop','.bottomDoubleBanner .w-banner .banner-item','width','50','','','.bottomDoubleBanner'),(938863,'printshop','.bottomDoubleBanner .w-banner .banner-item','width_measure','%','','','.bottomDoubleBanner'),(938864,'printshop','.bottomDoubleBanner .w-banner .banner-item','width','100','5363','','.bottomDoubleBanner'),(938865,'printshop','.bottomDoubleBanner .w-banner .banner-item','width_measure','%','5363','','.bottomDoubleBanner'),(938866,'printshop','.doubleBanner .w-banner .banner-item','width','100','5363','','.doubleBanner'),(938867,'printshop','.doubleBanner .w-banner .banner-item','width_measure','%','5363','','.doubleBanner'),(974838,'deals','.b-slick .slick-slider','-khtml-user-select','none','','','.b-slick'),(974839,'deals','.b-fancybox .fancybox-skin','-moz-border-radius','4px','','','.b-fancybox'),(974840,'deals','.b-fancybox .fancybox-title-float-wrap .child','-moz-border-radius','15px','','','.b-fancybox'),(974841,'deals','.b-fancybox .fancybox-opened .fancybox-skin','-moz-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(974842,'deals','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-moz-box-sizing','border-box','','','.b-select-suggest'),(974843,'deals','.b-rating .glyphicon','-moz-osx-font-smoothing','grayscale','','','.b-rating'),(974844,'deals','.b-products-listing .hover-box-content','-moz-transform','rotate( 45deg )','3','','.b-products-listing'),(974845,'deals','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-moz-transform','translate3d(0, 0, 0)','','','.b-slick'),(974846,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-moz-user-select','none','','','.b-select-suggest'),(974847,'deals','.b-select-suggest .select2-container .select2-choice','-moz-user-select','none','','','.b-select-suggest'),(974848,'deals','.b-select-suggest .select2-results .select2-result-label','-moz-user-select','none','','','.b-select-suggest'),(974849,'deals','.b-slick .slick-slider','-moz-user-select','none','','','.b-slick'),(974850,'deals','.b-slick .slick-slider','-ms-touch-action','pan-y','','','.b-slick'),(974851,'deals','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(974852,'deals','.b-info-popup .info-popup div','-ms-transform','rotate(-45deg)','3','','.b-info-popup'),(974853,'deals','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(974854,'deals','.b-info-popup .info-popup.top-left div','-ms-transform','rotate(-135deg)','3','','.b-info-popup'),(974855,'deals','.b-products-listing .hover-box-content','-ms-transform','rotate( 45deg )','3','','.b-products-listing'),(974856,'deals','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-ms-transform','translate3d(0, 0, 0)','','','.b-slick'),(974857,'deals','.w-sample .cart-box-link','-ms-transform','rotate(45deg)','4','','.w-sample'),(974858,'deals','.b-select-suggest .select2-container .select2-choice','-ms-user-select','none','','','.b-select-suggest'),(974859,'deals','.b-select-suggest .select2-results .select2-result-label','-ms-user-select','none','','','.b-select-suggest'),(974860,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-ms-user-select','none','','','.b-select-suggest'),(974861,'deals','.b-slick .slick-slider','-ms-user-select','none','','','.b-slick'),(974862,'deals','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-o-transform','translate3d(0, 0, 0)','','','.b-slick'),(974863,'deals','.b-fancybox .fancybox-title-float-wrap .child','-webkit-border-radius','15px','','','.b-fancybox'),(974864,'deals','.b-fancybox .fancybox-skin','-webkit-border-radius','4px','','','.b-fancybox'),(974865,'deals','.b-fancybox .fancybox-opened .fancybox-skin','-webkit-box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(974866,'deals','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','-webkit-box-sizing','border-box','','','.b-select-suggest'),(974867,'deals','.b-rating .glyphicon','-webkit-font-smoothing','antialiased','','','.b-rating'),(974868,'deals','.b-fancybox .fancybox-type-iframe .fancybox-inner','-webkit-overflow-scrolling','touch','','','.b-fancybox'),(974869,'deals','.b-fancybox .fancybox-nav','-webkit-tap-highlight-color','rgba(0,0,0,0)','','','.b-fancybox'),(974870,'deals','.b-select-suggest .select2-results','-webkit-tap-highlight-color','rgba(0, 0, 0, 0)','','','.b-select-suggest'),(974871,'deals','.b-slick .slick-slider','-webkit-tap-highlight-color','transparent','','','.b-slick'),(974872,'deals','.b-select-suggest .select2-container .select2-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(974873,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-touch-callout','none','','','.b-select-suggest'),(974874,'deals','.b-select-suggest .select2-results .select2-result-label','-webkit-touch-callout','none','','','.b-select-suggest'),(974875,'deals','.b-slick .slick-slider','-webkit-touch-callout','none','','','.b-slick'),(974876,'deals','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(974877,'deals','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(974878,'deals','.b-info-popup .info-popup.top-left div','-webkit-transform','rotate(-135deg)','3','','.b-info-popup'),(974879,'deals','.b-info-popup .info-popup div','-webkit-transform','rotate(-45deg)','3','','.b-info-popup'),(974880,'deals','.b-products-listing .hover-box-content','-webkit-transform','rotate( 45deg )','3','','.b-products-listing'),(974881,'deals','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','-webkit-transform','translate3d(0, 0, 0)','','','.b-slick'),(974882,'deals','.w-sample .cart-box-link','-webkit-transform','rotate(45deg)','4','','.w-sample'),(974883,'deals','.b-select-suggest .select2-container .select2-choice','-webkit-user-select','none','','','.b-select-suggest'),(974884,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','-webkit-user-select','none','','','.b-select-suggest'),(974885,'deals','.b-select-suggest .select2-results .select2-result-label','-webkit-user-select','none','','','.b-select-suggest'),(974886,'deals','.b-slick .slick-slider','-webkit-user-select','none','','','.b-slick'),(974887,'deals','.p-wedding-registry-search .search-form','align-items','center','','','.p-wedding-registry-search'),(974888,'deals','.w-promotions .promo-cart-discount','align-items','flex-start','','','.w-promotions'),(974889,'deals','.b-messages .email-line','align-items','center','','','.b-messages'),(974890,'deals','.p-quick-order-index .quick-order-total','align-items','center','','','.p-quick-order-index'),(974891,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(974892,'deals','.b-products-listing .select-attributes','align-items','center','','','.b-products-listing'),(974893,'deals','.order-summary .price-row','align-items','baseline','','','.order-summary'),(974894,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(974895,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(974896,'deals','.w-personal-gift-status-bar .timeline','align-items','center','','','.w-personal-gift-status-bar'),(974897,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(974898,'deals','.b-products-listing .products-listing .attribute-qty-block','align-items','center','','','.b-products-listing'),(974899,'deals','.b-products-listing .promos-info .promo-item','align-items','center','','','.b-products-listing'),(974900,'deals','.w-taxable form','align-items','center','','','.w-taxable'),(974901,'deals','.w-cart-listing .item .gift-wrap label','align-items','center','','','.w-cart-listing'),(974902,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(974903,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','align-items','center','','','.b-tracking-numbers'),(974904,'deals','.b-product-images .media-popup .mp-big-images .item','align-items','center','','','.b-product-images'),(974905,'deals','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(974906,'deals','.w-account-subscription .subscription-variant','align-items','center','','','.w-account-subscription'),(974907,'deals','.w-catalog-compare .cross-box .different-all','align-items','flex-end','','','.w-catalog-compare'),(974908,'deals','.w-product-images .img-holder','align-items','center','','','.w-product-images'),(974909,'deals','.w-quote .cart-box-link','align-items','center','','','.w-quote'),(974910,'deals','.w-product-images .additional-vertical','align-items','stretch','','','.w-product-images'),(974911,'deals','.w-files-catalog-widgets-files-catalog .image','align-items','center','','','.w-files-catalog-widgets-files-catalog'),(974912,'deals','.w-sample .cart-box-link','align-items','center','','','.w-sample'),(974913,'deals','.w-filters-simple .filter-row','align-items','flex-end','','','.w-filters-simple'),(974914,'deals','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(974915,'deals','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(974916,'deals','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','align-items','center','','','.b-menu-position'),(974917,'deals','.w-predefined-promotion .promo-cart-discount','align-items','flex-start','','','.w-predefined-promotion'),(974918,'deals','.w-supplier-purchase-supplier-products .item','align-items','center','','','.w-supplier-purchase-supplier-products'),(974919,'deals','.w-supplier-purchase-supplier-products .qty_col','align-items','center','','','.w-supplier-purchase-supplier-products'),(974920,'deals','.headerWrap .accountMenu >.block','align-items','center','','','.headerWrap'),(974921,'deals','.headerWrap .menuBox >.block','align-items','center','','','.headerWrap'),(974922,'deals','.headerWrap .RightBox>.block','align-items','flex-start','','','.headerWrap'),(974923,'deals','.w-subscribers .subscribe_box','align-items','center','','','.w-subscribers'),(974924,'deals','.w-top-categories picture','align-items','center','','','.w-top-categories'),(974925,'deals','.w-categories picture','align-items','center','','','.w-categories'),(974926,'deals','.filterLine > .block','align-items','center','','','.filterLine'),(974928,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','align-items','center','5630','','.headerWrap'),(974931,'deals','.checkout-order-confirmation .price-row','align-items','baseline','','','.checkout-order-confirmation'),(974932,'deals','.hide-page','align-items','center','','',''),(974933,'deals','.success-page .order_totals .price-row','align-items','baseline','','','.success-page'),(974934,'deals','.success-page .price-row','align-items','baseline','','','.success-page'),(974935,'deals','.w-checkout-totals .price-row','align-items','center','','','.w-checkout-totals'),(974936,'deals','.bannersWrap .rightBanner .banner-text-holder','align-items','center','','','.bannersWrap'),(974938,'deals','.w-account-customer-additional-field .field-type-text','align-items','center','','','.w-account-customer-additional-field'),(974939,'deals','.w-banner .banner-item.text-bottom-center .banner-text','align-items','end','','','.w-banner'),(974940,'deals','.w-banner .banner-item.text-bottom-left .banner-text','align-items','end','','','.w-banner'),(974941,'deals','.w-banner .banner-item.text-bottom-right .banner-text','align-items','end','','','.w-banner'),(974942,'deals','.w-banner .banner-item.text-middle-center .banner-text','align-items','center','','','.w-banner'),(974943,'deals','.w-banner .banner-item.text-middle-left .banner-text','align-items','center','','','.w-banner'),(974944,'deals','.w-banner .banner-item.text-middle-right .banner-text','align-items','center','','','.w-banner'),(974945,'deals','.w-banner .banner-item.text-top-center .banner-text','align-items','start','','','.w-banner'),(974946,'deals','.w-banner .banner-item.text-top-left .banner-text','align-items','start','','','.w-banner'),(974947,'deals','.w-banner .banner-item.text-top-right .banner-text','align-items','start','','','.w-banner'),(974948,'deals','.w-banner .carousel .bottom-center','align-items','flex-end','','','.w-banner'),(974949,'deals','.w-banner .carousel .bottom-left','align-items','flex-end','','','.w-banner'),(974950,'deals','.w-banner .carousel .bottom-right','align-items','flex-end','','','.w-banner'),(974951,'deals','.w-banner .carousel .middle-center','align-items','center','','','.w-banner'),(974952,'deals','.w-banner .carousel .middle-left','align-items','center','','','.w-banner'),(974953,'deals','.w-banner .carousel .middle-right','align-items','center','','','.w-banner'),(974954,'deals','.w-banner .carousel .top-center','align-items','flex-start','','','.w-banner'),(974955,'deals','.w-banner .carousel .top-left','align-items','flex-start','','','.w-banner'),(974956,'deals','.w-banner .carousel .top-right','align-items','flex-start','','','.w-banner'),(974959,'deals','.w-cart-listing .remove','align-self','center','','','.w-cart-listing'),(974960,'deals','.b-preloader .preloader','animation','load8 1.5s infinite linear','3','','.b-preloader'),(974961,'deals','.w-product-customers-activity .customers-activity','animation','customers-activity-show 4s ease-in-out','','','.w-product-customers-activity'),(974962,'deals','.w-product-customers-activity .customers-activity.closed','animation','customers-activity-hide 2s ease-in-out','','','.w-product-customers-activity'),(974963,'deals','.b-products-listing .btn-preloader','animation','load8 1.5s infinite linear','3','','.b-products-listing'),(974964,'deals','.b-products-listing .loader','animation','load8 1.5s infinite linear','4','','.b-products-listing'),(974965,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.p-quick-order-index'),(974966,'deals','.b-fancybox .fancybox-title-float-wrap .child','background','transparent','','','.b-fancybox'),(974967,'deals','.w-filters .ui-slider','background','none','','','.w-filters'),(974968,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','background','none','','','.b-select-suggest'),(974969,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.p-quick-order-index'),(974970,'deals','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','background','none','','','.b-products-listing'),(974971,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background','transparent','','','.b-select-suggest'),(974972,'deals','.b-select-suggest .select2-results .select2-highlighted em','background','transparent','','','.b-select-suggest'),(974973,'deals','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','background','transparent','','','.b-select-suggest'),(974974,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background','none','','','.b-data-table'),(974975,'deals','.w-filters .ui-slider-range','background','none','','','.w-filters'),(974976,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background','none','1','','.b-data-table'),(974977,'deals','.w-top-categories .categories h2','background','none','','','.w-top-categories'),(974978,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','background','none','','','.b-product-images'),(974979,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','background','none','','','.w-catalog-compare'),(974980,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','background','none','','','.b-products-listing'),(974981,'deals','.w-product-designer-designer .prodDesignerType','background','none','','','.w-product-designer-designer'),(974982,'deals','.w-communication-post .btn.refresh','background','none','','','.w-communication-post'),(974983,'deals','.w-rma-returns-history .column:last-child .title','background','transparent','','','.w-rma-returns-history'),(974984,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','background','none','','','.w-rma-returns-history'),(974985,'deals','.w-categories .categories h2','background','none','','','.w-categories'),(974986,'deals','.w-support-system-listing .topic-title','background','none','','','.w-support-system-listing'),(974987,'deals','.homeBanner .carousel .bottom-center > span','background','radial-gradient(65% 100% at 50% 0, transparent, 80%, $highlight-box-bg-2 0%) bottom','3','','.homeBanner'),(974988,'deals','.preFooter .menu-style[data-style=\"3\"] .level-2 > li','background','none','5644','','.preFooter'),(974989,'deals','.homeBanner .text-bottom-center .banner-text-holder','background','radial-gradient(65% 100% at 50% 0, transparent, 80%, $highlight-box-bg-2 0%) bottom','3','','.homeBanner'),(974990,'deals','.homeBanner .text-bottom-left .banner-text-holder','background','radial-gradient(65% 100% at 50% 0, transparent, 80%, $highlight-box-bg-2 0%) bottom','3','','.homeBanner'),(974991,'deals','.homeBanner .text-bottom-right .banner-text-holder','background','radial-gradient(65% 100% at 50% 0, transparent, 80%, $highlight-box-bg-2 0%) bottom','3','','.homeBanner'),(974992,'deals','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','background','none','','','.w-promotions-widgets-promotion-icons-desc'),(974993,'deals','.b-select-suggest .select2-container .select2-choice','background-clip','padding-box','','','.b-select-suggest'),(974994,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','background-clip','padding-box','','','.b-select-suggest'),(974995,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow','background-clip','padding-box','','','.b-select-suggest'),(974996,'deals','.b-fancybox .filter-listing-loader','background-color','$fancybox-bg-1','','','.b-fancybox'),(974997,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','$content-bg-2','','','.p-quick-order-index'),(974998,'deals','.w-promotions .promo-item','background-color','$content-bg-2','','','.w-promotions'),(975000,'deals','.testimonials .review','background-color','$content-bg-2','','',''),(975001,'deals','.w-chat .w-chat-box','background-color','$highlight-box-bg-1','','','.w-chat'),(975002,'deals','.w-promotions .prom-multi-discount .promo-range','background-color','$content-bg-1','','','.w-promotions'),(975003,'deals','.w-promotions .prom-multi-discount .promo-product','background-color','$content-bg-1','','','.w-promotions'),(975004,'deals','.w-promotions .nextdiscount .promo-for-each','background-color','$content-bg-2','','','.w-promotions'),(975005,'deals','.w-promotions .nextdiscount .content > div','background-color','$content-bg-1','','','.w-promotions'),(975006,'deals','.w-promotions .promo-salemaker .item','background-color','$content-bg-1','','','.w-promotions'),(975007,'deals','.w-promotions .promo-salemaker .discount','background-color','$content-bg-1','','','.w-promotions'),(975008,'deals','.w-promotions .promo-cart-discount .slave .item','background-color','$content-bg-1','','','.w-promotions'),(975009,'deals','.w-promotions .promo-cart-discount .promo-min-qty','background-color','$content-bg-1','','','.w-promotions'),(975010,'deals','.b-preloader .preloader','background-color','$shadow-bg-2','','','.b-preloader'),(975011,'deals','.w-cart-compare .attributes-cell','background-color','$content-bg-2','','','.w-cart-compare'),(975012,'deals','.w-cart-checkout-btn + .w-image','background-color','$content-bg-2','','','.w-cart-checkout-btn'),(975013,'deals','.b-messages .msv_history','background-color','$content-bg-2','','','.b-messages'),(975014,'deals','.b-messages .email-heading','background-color','$content-bg-2','','','.b-messages'),(975015,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','background-color','$content-bg-2','','','.b-messages'),(975016,'deals','.w-reviews .author','background-color','$content-bg-1','','','.w-reviews'),(975017,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.p-quick-order-index'),(975018,'deals','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','background-color','$content-bg-2','','','.order-summary'),(975019,'deals','.b-fancybox .fancybox-close','background-color','$fancybox-bg-1','','','.b-fancybox'),(975020,'deals','.b-messages .msv_to_cc','background-color','$content-bg-2','','','.b-messages'),(975021,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','background-color','$transparent','3','','.b-switch'),(975022,'deals','.w-checkout-shipping-choice input:checked + span:before','background-color','$highlight-box-bg-1','','','.w-checkout-shipping-choice'),(975023,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','background-color','$content-bg-2','','','.w-upload-customer-id-upload-customer-id-form'),(975024,'deals','.w-upload-customer-id-upload-customer-id-form .dz-details','background-color','$content-bg-1','','','.w-upload-customer-id-upload-customer-id-form'),(975025,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','background-color','$switch-nc-bg-1','3','','.b-switch'),(975027,'deals','.w-menu-horizontal > ul > li > ul > li > ul','background-color','$content-bg-1','','','.w-menu-horizontal'),(975028,'deals','.b-fancybox .fancybox-title-float-wrap .child','background-color','$fancybox-bg-1','','','.b-fancybox'),(975029,'deals','.b-info-popup .info-popup div','background-color','$content-bg-1','','','.b-info-popup'),(975031,'deals','.w-filters .ui-slider','background-color','$highlight-box-bg-1','','','.w-filters'),(975032,'deals','.b-switch .candlestick-wrapper .candlestick-bg','background-color','$switch-nc-bg-1','','','.b-switch'),(975033,'deals','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(975034,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-color','$content-bg-2','','','.b-select-suggest'),(975035,'deals','.w-reviews .review','background-color','$content-bg-1','','','.w-reviews'),(975036,'deals','.p-quick-order-index .all-scroll-div','background-color','$highlight-box-bg-1','','','.p-quick-order-index'),(975038,'deals','.btn-1','background-color','$btn-bg-2','','',''),(975039,'deals','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(975040,'deals','.order-summary > div','background-color','$content-bg-1','','','.order-summary'),(975041,'deals','.b-fancybox .fancybox-overlay','background-color','$fancybox-bg-1','','','.b-fancybox'),(975042,'deals','.b-bottom .popup-box.popupCompare','background-color','$content-bg-2','','','.b-bottom'),(975044,'deals','.w-checkout-billing-address .same-address','background-color','$content-bg-2','','','.w-checkout-billing-address'),(975045,'deals','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(975046,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','background-color','$switch-off-bg-2','','','.b-switch'),(975047,'deals','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(975048,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','background-color','$transparent','4','','.b-switch'),(975049,'deals','.b-form .required-message','background-color','$attention-background','','','.b-form'),(975050,'deals','.b-switch .candlestick-wrapper .candlestick-bg.off','background-color','$switch-off-bg-2','','','.b-switch'),(975051,'deals','.b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-off','background-color','$switch-off-bg-2','3','','.b-switch'),(975052,'deals','.b-switch .candlestick-wrapper .candlestick-bg.on','background-color','$switch-on-bg-1','','','.b-switch'),(975053,'deals','.b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-on','background-color','$switch-off-bg-2','4','','.b-switch'),(975054,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','background-color','$switch-handle-bg-3','','','.b-switch'),(975055,'deals','.b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-on','background-color','$switch-on-bg-1','4','','.b-switch'),(975056,'deals','.b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-off','background-color','$switch-on-bg-1','3','','.b-switch'),(975057,'deals','.w-product-reviews .reviews-list .review','background-color','$content-bg-2','','','.w-product-reviews'),(975058,'deals','.b-fancybox .fancybox-skin','background-color','$fancybox-bg-1','','','.b-fancybox'),(975059,'deals','.b-info-popup .info-popup div','background-color','$content-bg-1','3','','.b-info-popup'),(975060,'deals','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(975061,'deals','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(975062,'deals','.btn','background-color','$btn-bg-1','','',''),(975063,'deals','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(975064,'deals','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','background-color','$content-bg-2','','','.b-select-suggest'),(975065,'deals','.w-personal-gift-status-bar .timeline','background-color','$highlight-box-bg-2','','','.w-personal-gift-status-bar'),(975066,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','background-color','$switch-off-bg-2','','','.b-switch'),(975067,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label','background-color','$switch-handle-bg-3','3','','.b-switch'),(975068,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','background-color','$switch-nc-bg-1','4','','.b-switch'),(975069,'deals','.b-form .hide-billing-address','background-color','$content-bg-1','','','.b-form'),(975070,'deals','.w-reviews-content .author','background-color','$content-bg-2','','','.w-reviews-content'),(975072,'deals','.w-personal-gift-status-bar .progress-bar-content','background-color','$highlight-box-bg-1','','','.w-personal-gift-status-bar'),(975073,'deals','.w-cart-compare .price-cell','background-color','$content-bg-2','','','.w-cart-compare'),(975074,'deals','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(975075,'deals','.b-compare .popupCompare .pop-up-content','background-color','$content-bg-2','','','.b-compare'),(975076,'deals','.w-promotions .promo-cart-discount .master .item','background-color','$content-bg-1','','','.w-promotions'),(975077,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','background-color','$content-bg-1','','','.w-promotions'),(975078,'deals','.b-bottom .around-pop-up','background-color','$shadow-bg-1','','','.b-bottom'),(975079,'deals','.w-cart-compare .price-block + .attributes-block .attributes-cell','background-color','$content-bg-1','','','.w-cart-compare'),(975080,'deals','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(975081,'deals','.b-bottom .pop-up-content','background-color','$content-bg-1','','','.b-bottom'),(975083,'deals','.b-bottom .popup-box','background-color','$content-bg-1','','','.b-bottom'),(975084,'deals','.b-dropdown .dropdown .dropdown-menu','background-color','$content-bg-1','','','.b-dropdown'),(975085,'deals','.w-product-customers-activity .customers-activity','background-color','$content-bg-2','','','.w-product-customers-activity'),(975087,'deals','.w-checkout-shipping-choice input:checked + span','background-color','$highlight-box-bg-1','','','.w-checkout-shipping-choice'),(975088,'deals','.b-autocomplete .ui-autocomplete li','background-color','$content-bg-2','1','','.b-autocomplete'),(975089,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label','background-color','$switch-handle-bg-3','3','','.b-switch'),(975090,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','background-color','$switch-on-bg-1','','','.b-switch'),(975091,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-color','$content-bg-2','','','.b-select-suggest'),(975092,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus','background-color','$content-bg-2','','','.b-select-suggest'),(975093,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color','$content-bg-1','','','.b-select-suggest'),(975094,'deals','.b-select-suggest .select2-container-multi .select2-choices','background-color','$content-bg-1','','','.b-select-suggest'),(975095,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-color','$content-bg-2','','','.b-select-suggest'),(975096,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-color','$content-bg-2','','','.b-select-suggest'),(975097,'deals','.b-select-suggest .select2-results .select2-highlighted ul','background-color','$content-bg-1','','','.b-select-suggest'),(975098,'deals','.b-select-suggest .select2-more-results','background-color','$content-bg-2','','','.b-select-suggest'),(975099,'deals','.b-select-suggest .select2-more-results.select2-active','background-color','$content-bg-2','','','.b-select-suggest'),(975100,'deals','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','background-color','$content-bg-2','','','.b-select-suggest'),(975101,'deals','.b-select-suggest .select2-results .select2-highlighted','background-color','$content-bg-2','','','.b-select-suggest'),(975102,'deals','.b-select-suggest .select2-results .select2-disabled','background-color','$content-bg-2','','','.b-select-suggest'),(975103,'deals','.b-select-suggest .select2-results li em','background-color','$content-bg-2','','','.b-select-suggest'),(975104,'deals','.w-menu-horizontal > ul > li > ul','background-color','$content-bg-1','','','.w-menu-horizontal'),(975105,'deals','.b-select-suggest .select2-search input','background-color','$content-bg-1','','','.b-select-suggest'),(975106,'deals','.b-select-suggest .select2-search input.select2-active','background-color','$content-bg-1','','','.b-select-suggest'),(975107,'deals','.b-select-suggest .select2-drop-mask','background-color','$content-bg-1','','','.b-select-suggest'),(975108,'deals','.b-select-suggest .select2-drop','background-color','$content-bg-1','','','.b-select-suggest'),(975111,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color','$content-bg-2','','','.b-data-table'),(975112,'deals','.b-products-listing .loader','background-color','$shadow-bg-2','3','','.b-products-listing'),(975113,'deals','.w-catalog-b2b-add-button ','background-color','$highlight-box-bg-1','','','.w-catalog-b2b-add-button'),(975114,'deals','.b-products-listing .products-listing .qty-input.hidden','background-color','$content-bg-1','3','','.b-products-listing'),(975115,'deals','.checkbox input:checked + span','background-color','$checkbox-bg-1','','',''),(975116,'deals','.checkbox input + span','background-color','$checkbox-bg-1','','',''),(975117,'deals','.b-autocomplete .ui-autocomplete','background-color','$content-bg-1','','','.b-autocomplete'),(975119,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','background-color','$switch-handle-bg-3','3','','.b-switch'),(975120,'deals','.b-compare .compare-box-item','background-color','$content-bg-2','','','.b-compare'),(975122,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','background-color','$content-bg-2','','','.w-communication-new-topic'),(975123,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','background-color','$content-bg-2','','','.w-communication-new-topic'),(975124,'deals','.b-datepicker .datepicker-dropdown','background-color','$content-bg-1','','','.b-datepicker'),(975125,'deals','.b-bottom .popup-heading','background-color','$content-bg-2','','','.b-bottom'),(975126,'deals','.w-personal-gift-status-bar .progress-bar','background-color','$content-bg-1','','','.w-personal-gift-status-bar'),(975128,'deals','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(975129,'deals','.b-email .heading-products','background-color','$content-bg-2','','','.b-email'),(975130,'deals','.b-compare .vary td','background-color','$content-bg-2','','','.b-compare'),(975132,'deals','.b-fancybox .fancybox-nav span','background-color','$fancybox-bg-1','','','.b-fancybox'),(975135,'deals','.w-filters .ui-slider-range','background-color','$highlight-box-bg-1','','','.w-filters'),(975136,'deals','body','background-color','$content-bg-1','','',''),(975137,'deals','.w-reviews-content .review','background-color','$content-bg-2','','','.w-reviews-content'),(975138,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','background-color','none','1','','.b-data-table'),(975139,'deals','.b-compare .popupCompare table','background-color','$content-bg-1','','','.b-compare'),(975141,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','background-color','$content-bg-1','','','.w-image-maps'),(975142,'deals','.b-product-images .mp-shadow','background-color','$image-popup-bg-1','','','.b-product-images'),(975143,'deals','.b-trade-approval .steps-bar','background-color','$content-bg-2','','','.b-trade-approval'),(975144,'deals','.b-trade-approval .steps-bar li.current a','background-color','$highlight-box-bg-1','','','.b-trade-approval'),(975145,'deals','.w-account-personal-catalog .list-switcher a','background-color','$content-bg-1','2','','.w-account-personal-catalog'),(975146,'deals','.w-catalog-compare tr','background-color','$content-bg-2','1','','.w-catalog-compare'),(975147,'deals','.w-catalog-compare .compare .checkbox input:checked + span','background-color','$content-bg-1','','','.w-catalog-compare'),(975148,'deals','.w-catalog-compare .compare-fix-bar','background-color','$content-bg-1','','','.w-catalog-compare'),(975149,'deals','.w-catalog-compare .cross-box .different-all > div','background-color','$content-bg-1','2','','.w-catalog-compare'),(975150,'deals','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','background-color','$content-bg-1','','','.w-delivery-day'),(975151,'deals','.w-delivery-day .left-count','background-color','$highlight-box-bg-1','','','.w-delivery-day'),(975152,'deals','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','background-color','$warning-color','','','.b-cookie-notice'),(975154,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','background-color','$shadow-bg-1','','','.b-slick'),(975155,'deals','.btn-2','background-color','$btn-bg-3','','',''),(975156,'deals','.w-catalog-listing-look .b2b','background-color','$highlight-box-bg-1','2','','.w-catalog-listing-look'),(975157,'deals','.w-catalog-listing-look .grid','background-color','$highlight-box-bg-1','2','','.w-catalog-listing-look'),(975158,'deals','.w-catalog-listing-look .list','background-color','$highlight-box-bg-1','2','','.w-catalog-listing-look'),(975159,'deals','.LeftCategories ul li a','background-color','$content-bg-2','1','','.LeftCategories'),(975160,'deals','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','background-color','$content-bg-2','','','.w-filters'),(975161,'deals','.w-quote .cart-box-link','background-color','$highlight-box-bg-2','3','','.w-quote'),(975162,'deals','.w-quote .cart-content','background-color','$content-bg-1','','','.w-quote'),(975163,'deals','.w-quote .current-multi-cart.item','background-color','$content-bg-2','','','.w-quote'),(975164,'deals','.w-quote .multicart a.name','background-color','$content-bg-2','1','','.w-quote'),(975165,'deals','.w-product-sale-ends .left-count','background-color','$highlight-box-bg-2','','','.w-product-sale-ends'),(975166,'deals','.w-product-sale-ends .left-count-days','background-color','$content-bg-1','','','.w-product-sale-ends'),(975167,'deals','.w-product-sale-ends .left-count-hours','background-color','$content-bg-1','','','.w-product-sale-ends'),(975168,'deals','.w-compare ','background-color','$content-bg-1','','','.w-compare'),(975169,'deals','.w-files-catalog-widgets-files-catalog .name','background-color','$highlight-box-bg-1','','','.w-files-catalog-widgets-files-catalog'),(975170,'deals','.w-sample .cart-box-link','background-color','$highlight-box-bg-2','3','','.w-sample'),(975171,'deals','.w-sample .cart-content','background-color','$content-bg-1','','','.w-sample'),(975172,'deals','.w-sample .current-multi-cart.item','background-color','$content-bg-2','','','.w-sample'),(975173,'deals','.w-sample .multicart a.name','background-color','$content-bg-2','1','','.w-sample'),(975174,'deals','.b-pagination .pagination span','background-color','$highlight-box-bg-1','2','','.b-pagination'),(975175,'deals','.w-product-properties-filters-widgets-chosen-filters .item','background-color','$highlight-box-bg-2','','','.w-product-properties-filters-widgets-chosen-filters'),(975176,'deals','.p-sample-checkout-index .order-summary .heading-2','background-color','$content-border-1','3','','.p-sample-checkout-index'),(975177,'deals','.p-sample-checkout-index .order-summary .heading-2','background-color','$content-border-1','4','','.p-sample-checkout-index'),(975178,'deals','.w-delivery-location-location-list .deliveryListParrent a','background-color','$btn-bg-2','','','.w-delivery-location-location-list'),(975179,'deals','.w-sale-category .badge','background-color','$highlight-box-bg-1','','','.w-sale-category'),(975180,'deals','.w-sale-category .left-count','background-color','$highlight-box-bg-1','','','.w-sale-category'),(975181,'deals','.w-sale-category .left-count-days','background-color','$content-bg-1','','','.w-sale-category'),(975182,'deals','.w-sale-category .left-count-hours','background-color','$content-bg-1','','','.w-sale-category'),(975183,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','background-color','$content-bg-1','','','.w-product-properties-icons'),(975184,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content:before','background-color','$content-bg-1','','','.w-product-properties-icons'),(975185,'deals','.w-delivery-location-product-categories .name','background-color','$highlight-box-bg-2','','','.w-delivery-location-product-categories'),(975186,'deals','.w-product-designer-designer .grnamebox .title-sortable','background-color','$highlight-box-bg-2','','','.w-product-designer-designer'),(975187,'deals','.w-press-reviews-widgets-press-reviews ','background-color','$content-bg-1','','','.w-press-reviews-widgets-press-reviews'),(975188,'deals','.w-press-reviews-widgets-press-reviews-list .item','background-color','$content-bg-1','','','.w-press-reviews-widgets-press-reviews-list'),(975189,'deals','.w-support-system-listing .support-head','background-color','$content-bg-2','','','.w-support-system-listing'),(975190,'deals','.w-support-system-listing .product_icon','background-color','$content-bg-1','','','.w-support-system-listing'),(975191,'deals','.w-rma-returns-history table.dataTable tbody tr.odd, .w-rma-returns-history table.dataTable.display tbody tr.odd','background-color','$content-bg-2','','','.w-rma-returns-history'),(975192,'deals','.b-products-listing .promos-info .promo-name-span','background-color','$highlight-box-bg-2','','','.b-products-listing'),(975193,'deals','.w-predefined-promotion .nextdiscount .content > div','background-color','$content-bg-1','','','.w-predefined-promotion'),(975194,'deals','.w-predefined-promotion .nextdiscount .promo-for-each','background-color','$content-bg-2','','','.w-predefined-promotion'),(975195,'deals','.w-predefined-promotion .prom-multi-discount .promo-product','background-color','$content-bg-1','','','.w-predefined-promotion'),(975196,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','background-color','$content-bg-1','','','.w-predefined-promotion'),(975197,'deals','.w-predefined-promotion .promo-cart-discount .master .item','background-color','$content-bg-1','','','.w-predefined-promotion'),(975198,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','background-color','$content-bg-1','','','.w-predefined-promotion'),(975199,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','background-color','$content-bg-1','','','.w-predefined-promotion'),(975200,'deals','.w-predefined-promotion .promo-cart-discount .slave .item','background-color','$content-bg-1','','','.w-predefined-promotion'),(975201,'deals','.w-predefined-promotion .promo-item','background-color','$content-bg-2','','','.w-predefined-promotion'),(975202,'deals','.w-predefined-promotion .promo-salemaker .discount','background-color','$content-bg-1','','','.w-predefined-promotion'),(975203,'deals','.w-predefined-promotion .promo-salemaker .item','background-color','$content-bg-1','','','.w-predefined-promotion'),(975205,'deals','.w-top-categories .item','background-color','$content-bg-1','','','.w-top-categories'),(975206,'deals','.headerWrap .menu-style[data-style=\"1\"] li.back-button','background-color','$content-bg-2','1','','.headerWrap'),(975207,'deals','.w-categories .item','background-color','$content-bg-1','','','.w-categories'),(975208,'deals','.filterLine .choose-filters li .btn-clear','background-color','$content-bg-2','','','.filterLine'),(975209,'deals','.w-filters .filter-widget-horizontal .filter-box-content','background-color','$content-bg-1','','','.w-filters'),(975210,'deals','.w-filters .choose-filters > li > *','background-color','$highlight-box-bg-2','','','.w-filters'),(975211,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','background-color','$content-bg-1','','','.b-products-listing'),(975212,'deals','.b-quantity .qty-box input[type=\'text\']','background-color','$content-bg-2','','','.b-quantity'),(975213,'deals','.w-product-groups .property-category-heading','background-color','$content-bg-2','','','.w-product-groups'),(975214,'deals','.w-support-system-listing .support-item-body','background-color','$content-bg-1','','','.w-support-system-listing'),(975215,'deals','.b-table .table .headings td','background-color','$content-bg-2','','','.b-table'),(975216,'deals','.homeBanner .carousel .bottom-center > span','background-color','$highlight-box-bg-2','','','.homeBanner'),(975217,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','background-color','$content-bg-1','5639','','.w-filters'),(975218,'deals','.b-products-listing .pr-groups.active a','background-color','$highlight-box-bg-1','','','.b-products-listing'),(975219,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','background-color','$content-bg-1','5630','','.headerWrap'),(975220,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li:hover > a','background-color','$content-bg-2','5630','','.headerWrap'),(975221,'deals','.w-product-personal-catalog-button .btn','background-color','$content-bg-1','','','.w-product-personal-catalog-button'),(975222,'deals','.w-account-personal-catalog .list-row-action ul','background-color','$content-bg-1','','','.w-account-personal-catalog'),(975223,'deals','.homeBanner .banner-item .banner-text-holder','background-color','$highlight-box-bg-2','','','.homeBanner'),(975224,'deals','.w-cart-discount-coupon .discount-box','background-color','$content-bg-2','','','.w-cart-discount-coupon'),(975225,'deals','.breadcrumb-box ','background-color','$header-bg-2','','','.breadcrumb-box'),(975233,'deals','.account-samples .orders-table th','background-color','$content-bg-2','','','.account-samples'),(975234,'deals','.account-samples .order_history_table th','background-color','$content-bg-2','','','.account-samples'),(975235,'deals','.catalog-product-wrap .prev-next-product','background-color','$shadow-bg-2','','','.catalog-product-wrap'),(975236,'deals','.checkout-index-wrap .checkout-cart-listing.main-listing','background-color','$content-bg-1','','','.checkout-index-wrap'),(975237,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','background-color','$btn-bg-2','','','.checkout-index-wrap'),(975238,'deals','.b-slick .slick-dots li','background-color','$content-bg-2','3','','.b-slick'),(975239,'deals','.b-slick .slick-dots li.slick-active','background-color','$highlight-box-bg-1','3','','.b-slick'),(975240,'deals','.hide-page','background-color','$shadow-bg-2','','',''),(975242,'deals','.success-page .w-cart-listing .qty','background-color','$highlight-box-bg-2','','','.success-page'),(975243,'deals','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','background-color','$highlight-box-bg-2','','','.b-multi-page-checkout'),(975244,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','background-color','$content-bg-2','3','','.b-multi-page-checkout'),(975245,'deals','.bannersWrap .leftBanner .banner-text','background-color','$highlight-box-bg-3','','','.bannersWrap'),(975246,'deals','.bannersWrap .rightBanner .banner-text','background-color','$highlight-box-bg-3','','','.bannersWrap'),(975256,'deals','.w-catalog-paging ','background-color','$highlight-box-bg-2','2','','.w-catalog-paging'),(975271,'deals','.w-menu-slider .menu-ico','background-color','$highlight-box-bg-1','','','.w-menu-slider'),(975272,'deals','.w-menu-slider > ul','background-color','$highlight-box-bg-1','','','.w-menu-slider'),(975273,'deals','.w-menu-slider > ul > li > ul','background-color','$highlight-box-bg-1','','','.w-menu-slider'),(975274,'deals','.w-menu-slider > ul > li.active > ul','background-color','$highlight-box-bg-1','','','.w-menu-slider'),(975275,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.p-quick-order-index'),(975276,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-color_important','important','','','.b-select-suggest'),(975277,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background-color_important','important','','','.b-data-table'),(975278,'deals','.b-select-suggest .select2-container .select2-choice abbr','background-image','url(\'\')','','','.b-select-suggest'),(975279,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','background-image','none','','','.b-select-suggest'),(975280,'deals','.b-select-suggest .select2-search input','background-image','url(\'\')','','','.b-select-suggest'),(975281,'deals','.b-select-suggest .select2-more-results.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(975282,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(975283,'deals','.b-select-suggest .select2-search input.select2-active','background-image','url(\'\')','','','.b-select-suggest'),(975284,'deals','.b-select-suggest .select2-search-choice-close','background-image','url(\'\')','','','.b-select-suggest'),(975285,'deals','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-image','url(\'\')','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(975286,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','background-image','none','','','.b-select-suggest'),(975287,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','background-image','none','','','.b-select-suggest'),(975288,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','background-image','none','','','.b-select-suggest'),(975289,'deals','.b-select-suggest .select2-results li','background-image','none','','','.b-select-suggest'),(975290,'deals','.p-wedding-registry-search .main-content','background-image','url(\'\')','','','.p-wedding-registry-search'),(975294,'deals','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.account-order-pay'),(975295,'deals','.account-samples .moduleRowDue td','background-image','url(themes/basic/img/pattern.png)','','','.account-samples'),(975296,'deals','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','background-image','url(\'\')','','','.account-sample-info'),(975297,'deals','.b-select-suggest .select2-search input','background-position','100% -21px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(975298,'deals','.b-select-suggest .select2-container .select2-choice abbr','background-position','right -11px','1','','.b-select-suggest'),(975299,'deals','.w-top-categories .image','background-position','50% 50%','','','.w-top-categories'),(975300,'deals','.p-wedding-registry-search .main-content','background-position','50% 0','','','.p-wedding-registry-search'),(975301,'deals','.b-select-suggest .select2-container .select2-choice abbr','background-position','top right','','','.b-select-suggest'),(975302,'deals','.w-categories .image','background-position','50% 50%','','','.w-categories'),(975303,'deals','.b-select-suggest .select2-search input','background-position','100% -22px','','','.b-select-suggest'),(975304,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice-focus .select2-search-choice-close','background-position','right -11px','','','.b-select-suggest'),(975305,'deals','.b-select-suggest .select2-search-choice-close','background-position','top right','','','.b-select-suggest'),(975306,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-search-choice-close','background-position','right -11px','1','','.b-select-suggest'),(975307,'deals','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow b','background-position','-18px 1px','','','.b-select-suggest'),(975308,'deals','.b-select-suggest .select2-search input','background-position_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(975309,'deals','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(975310,'deals','.p-wedding-registry-search .main-content','background-repeat','no-repeat','','','.p-wedding-registry-search'),(975311,'deals','.b-select-suggest .select2-container .select2-choice abbr','background-repeat','no-repeat','','','.b-select-suggest'),(975312,'deals','.b-select-suggest .select2-search-choice-close','background-repeat','no-repeat','','','.b-select-suggest'),(975313,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(975314,'deals','.b-select-suggest .select2-more-results.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(975315,'deals','.b-select-suggest .select2-search input','background-repeat','no-repeat','','','.b-select-suggest'),(975316,'deals','.b-select-suggest .select2-search input.select2-active','background-repeat','no-repeat','','','.b-select-suggest'),(975317,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat','no-repeat','','','.b-select-suggest'),(975318,'deals','.homeBanner .carousel .bottom-center > span','background-repeat','no-repeat','3','','.homeBanner'),(975319,'deals','.homeBanner .text-bottom-center .banner-text-holder','background-repeat','no-repeat','3','','.homeBanner'),(975320,'deals','.homeBanner .text-bottom-left .banner-text-holder','background-repeat','no-repeat','3','','.homeBanner'),(975321,'deals','.homeBanner .text-bottom-right .banner-text-holder','background-repeat','no-repeat','3','','.homeBanner'),(975322,'deals','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-repeat_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(975323,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input.select2-active','background-repeat_important','important','','','.b-select-suggest'),(975324,'deals','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size','60px 40px','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(975325,'deals','.w-top-categories .image','background-size','cover','','','.w-top-categories'),(975326,'deals','.w-categories .image','background-size','cover','','','.w-categories'),(975327,'deals','.homeBanner .carousel .bottom-center > span','background-size','100% 100%, 100% 0px','3','','.homeBanner'),(975328,'deals','.homeBanner .text-bottom-center .banner-text-holder','background-size','100% 100%, 100% 0','3','','.homeBanner'),(975329,'deals','.homeBanner .text-bottom-left .banner-text-holder','background-size','100% 100%, 100% 0','3','','.homeBanner'),(975330,'deals','.homeBanner .text-bottom-right .banner-text-holder','background-size','100% 100%, 100% 0','3','','.homeBanner'),(975331,'deals','.b-select-suggest .select2-search input, .b-select-suggest .select2-search-choice-close, .b-select-suggest .select2-container .select2-choice abbr, .b-select-suggest .select2-container .select2-choice .select2-arrow b','background-size_important','important','','only screen and (-webkit-min-device-pixel-ratio: 1.5), only screen and (min-resolution: 144dpi)','.b-select-suggest'),(975332,'deals','.warrantyProduct .warranty','background_image','themes/deals/img/themes/deals/img/calendar.webp','3','','.warrantyProduct'),(975333,'deals','.warrantyProduct .delivery','background_image','themes/deals/img/themes/deals/img/wallet.webp','3','','.warrantyProduct'),(975334,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.p-quick-order-index'),(975335,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','background_important','important','','','.b-select-suggest'),(975336,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','background_important','important','','','.b-data-table'),(975337,'deals','.w-product-designer-designer .prodDesignerType','background_important','important','','','.w-product-designer-designer'),(975338,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','background_important','important','','','.w-rma-returns-history'),(975339,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','1','','.p-quick-order-index'),(975340,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.p-quick-order-index'),(975341,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.p-quick-order-index'),(975342,'deals','.b-messages .select2-container-multi input.select2-input','border','none','','','.b-messages'),(975343,'deals','.b-messages .emailLineTextArea textarea','border','none','','','.b-messages'),(975344,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border','none','3','','.b-switch'),(975345,'deals','.b-switch .candlestick-wrapper .candlestick-bg','border','none','','','.b-switch'),(975346,'deals','.b-autocomplete .ui-autocomplete li','border','none','','','.b-autocomplete'),(975347,'deals','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(975348,'deals','.w-cart-cart-tabs .w-tabs > .block','border','none','','','.w-cart-cart-tabs'),(975349,'deals','.b-bottom .popup-box.popupCompare','border','none','','','.b-bottom'),(975350,'deals','.w-top-categories .categories h2','border','none','','','.w-top-categories'),(975351,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border','none','4','','.b-switch'),(975352,'deals','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(975353,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border','none','','','.b-switch'),(975354,'deals','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(975355,'deals','.b-form .checkbox-style','border','none','','','.b-form'),(975356,'deals','.b-sub-totals .historyTotal table','border','none','','','.b-sub-totals'),(975357,'deals','.b-bottom .cart-options .heading-4','border','none','','','.b-bottom'),(975358,'deals','.b-products-listing .products-listing .wishlistButton .checkbox input + span','border','none','','','.b-products-listing'),(975359,'deals','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span','border','none','','','.b-products-listing'),(975360,'deals','.b-compare .compare-head','border','none','','','.b-compare'),(975361,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.p-quick-order-index'),(975362,'deals','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(975363,'deals','.b-sub-totals .historyTotal td','border','none','','','.b-sub-totals'),(975364,'deals','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(975365,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border','none','','','.b-data-table'),(975366,'deals','.w-checkout-gdpr .privacy-row','border','none','','','.w-checkout-gdpr'),(975367,'deals','.b-autocomplete .ui-autocomplete li','border','none','1','','.b-autocomplete'),(975368,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','border','none','','','.w-communication-new-topic'),(975369,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','border','none','','','.w-communication-new-topic'),(975370,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','border','none','','','.w-communication-new-topic'),(975371,'deals','.w-promo-code .heading-4','border','none','','','.w-promo-code'),(975372,'deals','.w-filters .input-checkbox','border','none','','','.w-filters'),(975373,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','border','none','','',''),(975374,'deals','.b-data-table table.dataTable thead td','border','none','','','.b-data-table'),(975375,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','1','','.b-data-table'),(975376,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border','none','','','.b-data-table'),(975377,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border','none','','','.b-product-images'),(975378,'deals','.b-trade-approval .w-login-block .heading-3','border','none','','','.b-trade-approval'),(975379,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','border','none','','','.w-catalog-compare'),(975380,'deals','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','border','none','','','.b-cookie-notice'),(975381,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','border','none','','','.b-slick'),(975382,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','border','none','','','.b-products-listing'),(975383,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','border','none','','','.w-rma-returns-history'),(975384,'deals','.w-categories .categories h2','border','none','','','.w-categories'),(975385,'deals','.filterLine .w-catalog-sorting .sort-select','border','none','','','.filterLine'),(975386,'deals','.b-quantity .qty-box input[type=\'text\']','border','none','','','.b-quantity'),(975387,'deals','.w-product-wishlist-button .btn','border','none','','','.w-product-wishlist-button'),(975388,'deals','.order-summary .w-cart-listing .headings','border','none','','','.order-summary'),(975389,'deals','.order-summary .w-cart-listing .item','border','none','','','.order-summary'),(975393,'deals','.account-samples .orders-table tr:first-child','border','none','','','.account-samples'),(975394,'deals','.b-bottom div + .info','border','none','','','.b-bottom'),(975395,'deals','.w-promotions .heading-3','border-bottom','none','','','.w-promotions'),(975396,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable.no-footer','border-bottom','none','','','.b-messages'),(975397,'deals','.w-cart-shipping-estimator .addresses','border-bottom','none','','','.w-cart-shipping-estimator'),(975398,'deals','.w-account-personal-catalog .list-switcher a','border-bottom','none','2','','.w-account-personal-catalog'),(975399,'deals','.w-catalog-compare .cross-box .different-all > div','border-bottom','none','2','','.w-catalog-compare'),(975400,'deals','.w-predefined-promotion .heading-3','border-bottom','none','','','.w-predefined-promotion'),(975401,'deals','.w-tabs .tab-a','border-bottom','none','2','','.w-tabs'),(975403,'deals','.b-upload-file .upload-file-template','border-bottom-color','$content-border-1','','','.b-upload-file'),(975404,'deals','.w-promotions .prom-multi-discount .promo-range','border-bottom-color','$highlight-box-border-2','','','.w-promotions'),(975405,'deals','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(975407,'deals','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(975408,'deals','.testimonials .review','border-bottom-color','transparent','3','',''),(975409,'deals','.w-promotions .promo-salemaker .discount','border-bottom-color','$warning-border','','','.w-promotions'),(975410,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-color','$highlight-box-border-2','','','.w-promotions'),(975411,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-color','$highlight-box-border-2','','','.w-promotions'),(975412,'deals','.w-cart-give-away .ga_column','border-bottom-color','$content-border-1','','','.w-cart-give-away'),(975413,'deals','.w-cart-compare .cart-cell > div','border-bottom-color','$content-border-1','','','.w-cart-compare'),(975414,'deals','.b-messages .msv_btn','border-bottom-color','$content-border-1','','','.b-messages'),(975415,'deals','.b-messages .content_management_attach button','border-bottom-color','$highlight-box-border-1','','','.b-messages'),(975416,'deals','.b-messages .content_management_attach','border-bottom-color','$content-border-1','','','.b-messages'),(975417,'deals','.b-messages .email-heading','border-bottom-color','$content-border-1','','','.b-messages'),(975418,'deals','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-color','$content-border-1','','','.b-messages'),(975419,'deals','.b-messages .msv_to_cc','border-bottom-color','$content-border-1','','','.b-messages'),(975420,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-color','$content-border-1','','','.b-messages'),(975421,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-bottom-color','$content-border-1','','',''),(975422,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-color','$content-border-1','','','.b-messages'),(975423,'deals','.b-messages .dataTables_wrapper > .bottom','border-bottom-color','$content-border-1','','','.b-messages'),(975424,'deals','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(975425,'deals','.w-product-reviews .reviews-list .review','border-bottom-color','$transparent','3','','.w-product-reviews'),(975426,'deals','.b-form .required-error','border-bottom-color','$attention-border','','','.b-form'),(975427,'deals','.p-payer-order-confirmation .input-wrapper','border-bottom-color','$content-border-1','','','.p-payer-order-confirmation'),(975428,'deals','.p-payer-order-pay .input-wrapper','border-bottom-color','$content-border-1','','','.p-payer-order-pay'),(975429,'deals','.b-upload-file .snapshot','border-bottom-color','$content-border-1','','','.b-upload-file'),(975430,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-color','$switch-nc-border-1','','','.b-switch'),(975431,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(975432,'deals','.w-filters .filter-box-head','border-bottom-color','$content-border-1','','','.w-filters'),(975433,'deals','.b-upload-file .upload-file-template div','border-bottom-color','$content-border-1','','','.b-upload-file'),(975434,'deals','.w-checkout-shipping-choice span','border-bottom-color','$highlight-box-border-1','','','.w-checkout-shipping-choice'),(975435,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(975436,'deals','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(975437,'deals','.b-info-popup .info-popup div','border-bottom-color','$content-border-1','','','.b-info-popup'),(975438,'deals','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(975439,'deals','.w-tabs .accordion-heading','border-bottom-color','$tab-nav-border-1','2','','.w-tabs'),(975440,'deals','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(975441,'deals','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(975442,'deals','.w-cart-compare .compare-table','border-bottom-color','$content-border-1','','','.w-cart-compare'),(975443,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-color','$switch-handle-bg-3','','','.b-switch'),(975444,'deals','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(975445,'deals','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(975446,'deals','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(975447,'deals','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(975448,'deals','.w-reviews-content .review','border-bottom-color','$content-border-1','3','','.w-reviews-content'),(975449,'deals','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(975450,'deals','.b-select-suggest .select2-container.select2-drop-above .select2-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(975451,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-color','$switch-nc-border-1','4','','.b-switch'),(975453,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-color','$checkbox-border-1','3','','.b-form'),(975454,'deals','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-bottom-color','$content-border-1','','','.b-bottom'),(975455,'deals','.w-socials > li','border-bottom-color','$content-border-1','','','.w-socials'),(975456,'deals','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-bottom-color','$content-bg-1','','','.b-bottom'),(975457,'deals','textarea','border-bottom-color','$content-border-1','','',''),(975458,'deals','.b-bottom .popup-box','border-bottom-color','$content-border-1','','','.b-bottom'),(975459,'deals','.w-product-customers-activity .customers-activity','border-bottom-color','$content-border-1','','','.w-product-customers-activity'),(975460,'deals','.w-tabs .accordion-heading','border-bottom-color','$tab-nav-border-2','','','.w-tabs'),(975461,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-color','$content-border-1','','','.b-select-suggest'),(975462,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(975463,'deals','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-color','$content-border-1','','','.b-select-suggest'),(975464,'deals','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-color','$content-border-1','','','.b-select-suggest'),(975465,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(975466,'deals','.b-select-suggest .select2-dropdown-open .select2-choice','border-bottom-color','$transparent','','','.b-select-suggest'),(975467,'deals','.b-select-suggest .select2-drop-active','border-bottom-color','$content-border-1','','','.b-select-suggest'),(975468,'deals','.b-select-suggest .select2-drop','border-bottom-color','$content-border-1','','','.b-select-suggest'),(975469,'deals','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(975470,'deals','.b-form input.required-error','border-bottom-color','$attention-border','','','.b-form'),(975471,'deals','.w-communication-post .communication-post','border-bottom-color','$content-border-1','','','.w-communication-post'),(975472,'deals','.checkbox input + span','border-bottom-color','$checkbox-border-1','','',''),(975473,'deals','.checkbox input:checked + span','border-bottom-color','$checkbox-border-1','','',''),(975474,'deals','.b-autocomplete .ui-autocomplete','border-bottom-color','$content-border-1','','','.b-autocomplete'),(975477,'deals','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(975478,'deals','.b-select-suggest .select2-container .select2-choice','border-bottom-color','$content-border-1','','','.b-select-suggest'),(975479,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-color','$switch-nc-border-1','3','','.b-switch'),(975480,'deals','.w-reviews .review','border-bottom-color','$content-bg-1','3','','.w-reviews'),(975481,'deals','.w-reviews-content .item','border-bottom-color','$content-border-1','','','.w-reviews-content'),(975482,'deals','.b-upload-files .upload-files','border-bottom-color','$content-border-1','','','.b-upload-files'),(975483,'deals','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(975484,'deals','.w-reviews .item','border-bottom-color','$content-border-1','','','.w-reviews'),(975485,'deals','.w-promo-code .holder','border-bottom-color','$content-border-1','','','.w-promo-code'),(975486,'deals','.b-dropdown .dropdown .dropdown-menu','border-bottom-color','$content-border-1','','','.b-dropdown'),(975487,'deals','.b-select-suggest .select2-search input','border-bottom-color','$content-border-1','','','.b-select-suggest'),(975488,'deals','.w-cart-listing .item .gift-wrap label','border-bottom-color','$content-border-1','','','.w-cart-listing'),(975489,'deals','.w-cart-listing .item','border-bottom-color','$content-border-1','5639','','.w-cart-listing'),(975491,'deals','.b-data-table table.dataTable.no-footer','border-bottom-color','$content-border-1','','','.b-data-table'),(975492,'deals','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-color','$content-border-1','','','.b-compare'),(975493,'deals','.b-compare .compare_pagination','border-bottom-color','$content-border-1','','','.b-compare'),(975494,'deals','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-bottom-color','$image-popup-border-1','','','.b-product-images'),(975495,'deals','.b-trade-approval .orders-table th','border-bottom-color','$content-border-1','','','.b-trade-approval'),(975496,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-color','$content-border-1','','','.b-trade-approval'),(975497,'deals','.w-account-personal-catalog .list-switcher a','border-bottom-color','$content-border-1','','','.w-account-personal-catalog'),(975498,'deals','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-color','$content-bg-1','','','.w-catalog-compare'),(975499,'deals','.w-catalog-compare .cross-box .different-all > div','border-bottom-color','$content-border-1','','','.w-catalog-compare'),(975500,'deals','.w-delivery-day .left-text-left','border-bottom-color','$content-border-1','','','.w-delivery-day'),(975501,'deals','.w-delivery-day .left-text-right','border-bottom-color','$content-border-1','','','.w-delivery-day'),(975503,'deals','.b-products-listing .products-listing .compare input + span','border-bottom-color','$highlight-box-border-2','','','.b-products-listing'),(975504,'deals','.w-quote .cart-content','border-bottom-color','$content-border-1','','','.w-quote'),(975505,'deals','.w-quote .cart-total','border-bottom-color','$content-border-1','','','.w-quote'),(975506,'deals','.w-quote .multicart .item','border-bottom-color','$content-border-1','','','.w-quote'),(975507,'deals','.b-product-images .additional-images .active img','border-bottom-color','$image-popup-border-2','','','.b-product-images'),(975508,'deals','.b-product-images .additional-images img','border-bottom-color','$image-popup-border-1','','','.b-product-images'),(975509,'deals','.b-quantity .qty-box .bigger','border-bottom-color','$content-border-1','','','.b-quantity'),(975510,'deals','.b-quantity .qty-box .smaller','border-bottom-color','$content-border-1','','','.b-quantity'),(975511,'deals','.w-product-sale-ends .left-text-left','border-bottom-color','$content-border-1','','','.w-product-sale-ends'),(975512,'deals','.w-product-sale-ends .left-text-right','border-bottom-color','$content-border-1','','','.w-product-sale-ends'),(975513,'deals','.w-product-quantity .qty_packs .qty-input','border-bottom-color','$content-border-1','','','.w-product-quantity'),(975514,'deals','.warrantyProduct .warranty, .warrantyProduct .delivery','border-bottom-color','$content-border-1','','','.warrantyProduct'),(975515,'deals','.w-sample .cart-box-link','border-bottom-color','$highlight-box-border-1','4','','.w-sample'),(975516,'deals','.w-sample .cart-content','border-bottom-color','$content-border-1','','','.w-sample'),(975517,'deals','.w-sample .cart-total','border-bottom-color','$content-border-1','','','.w-sample'),(975518,'deals','.w-sample .multicart .item','border-bottom-color','$content-border-1','','','.w-sample'),(975519,'deals','.w-product-video .item img, .w-product-video .item video','border-bottom-color','$content-border-1','','','.w-product-video'),(975520,'deals','.w-product-video .item.active img, .w-product-video .item.active video','border-bottom-color','$highlight-box-border-2','','','.w-product-video'),(975521,'deals','.shipping-ico .heading-3','border-bottom-color','$content-border-1','','','.shipping-ico'),(975523,'deals','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-bottom-color','$highlight-box-border-2','','','.b-pagination'),(975524,'deals','.b-pagination .pagination .next-pages','border-bottom-color','$content-border-1','','','.b-pagination'),(975525,'deals','.b-pagination .pagination .page-number','border-bottom-color','$content-border-1','','','.b-pagination'),(975526,'deals','.b-pagination .pagination .prev-pages','border-bottom-color','$content-border-1','','','.b-pagination'),(975527,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-bottom-color','$content-border-1','','','.b-pagination'),(975528,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-bottom-color','$content-border-1','','','.b-pagination'),(975529,'deals','.b-pagination .pagination span','border-bottom-color','$content-border-1','2','','.b-pagination'),(975530,'deals','.w-product-multi-inventory .radio-attributes','border-bottom-color','$content-border-1','','','.w-product-multi-inventory'),(975531,'deals','.w-product-multi-inventory .radio-attributes .option-item','border-bottom-color','$content-border-1','','','.w-product-multi-inventory'),(975532,'deals','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-bottom-color','$highlight-box-border-1','','','.w-product-multi-inventory'),(975533,'deals','.b-products-listing .products-listing .radio-attributes','border-bottom-color','$content-border-1','','','.b-products-listing'),(975534,'deals','.b-products-listing .products-listing .radio-attributes .option','border-bottom-color','$content-border-1','','','.b-products-listing'),(975535,'deals','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-bottom-color','$highlight-box-border-1','','','.b-products-listing'),(975536,'deals','.w-product-attributes .radio-attributes','border-bottom-color','$content-border-1','','','.w-product-attributes'),(975537,'deals','.w-product-attributes .radio-attributes .option-item','border-bottom-color','$content-border-1','','','.w-product-attributes'),(975538,'deals','.w-product-attributes .radio-attributes input:checked + .option-item','border-bottom-color','$highlight-box-border-1','','','.w-product-attributes'),(975539,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(975540,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-bottom-color','$highlight-box-border-2','','','.w-questionnaire-widgets-questionnaire'),(975541,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-bottom-color','$message-border','','','.w-questionnaire-widgets-questionnaire'),(975542,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-bottom-color','$highlight-box-border-2','1','','.w-questionnaire-widgets-questionnaire'),(975543,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-bottom-color','$message-border','1','','.w-questionnaire-widgets-questionnaire'),(975544,'deals','.w-product-groups .radioBox label .containerBlock','border-bottom-color','$content-border-1','','','.w-product-groups'),(975545,'deals','.w-product-groups .radioBox label .containerBlock.selected','border-bottom-color','$highlight-box-border-2','','','.w-product-groups'),(975546,'deals','.w-product-groups .radioBox label input:checked + .containerBlock','border-bottom-color','$highlight-box-border-2','','','.w-product-groups'),(975547,'deals','.w-delivery-location-top-location-list .deliveryName','border-bottom-color','$content-border-1','','','.w-delivery-location-top-location-list'),(975548,'deals','.w-delivery-location-location-list .deliveryName','border-bottom-color','$content-border-1','','','.w-delivery-location-location-list'),(975549,'deals','.w-delivery-location-location-list .deliveryList li a','border-bottom-color','$content-border-1','','','.w-delivery-location-location-list'),(975550,'deals','.w-delivery-location-location-list .deliveryList li a','border-bottom-color','$highlight-box-border-1','1','','.w-delivery-location-location-list'),(975551,'deals','.w-sale-category .left-text-left','border-bottom-color','$content-border-1','','','.w-sale-category'),(975552,'deals','.w-sale-category .left-text-right','border-bottom-color','$content-border-1','','','.w-sale-category'),(975553,'deals','.w-sale-category .sale-holder','border-bottom-color','$content-border-1','','','.w-sale-category'),(975554,'deals','.w-catalog-delivery-locations .name','border-bottom-color','$content-border-1','','','.w-catalog-delivery-locations'),(975555,'deals','.w-product-designer-designer .prodDesignerType label','border-bottom-color','$content-border-1','','','.w-product-designer-designer'),(975556,'deals','.w-press-reviews-widgets-press-reviews-small ','border-bottom-color','$content-border-1','','','.w-press-reviews-widgets-press-reviews-small'),(975557,'deals','.b-products-listing .productGroup label a','border-bottom-color','$highlight-box-border-1','','','.b-products-listing'),(975558,'deals','.w-rma-returns-history .topRow','border-bottom-color','$content-border-1','','','.w-rma-returns-history'),(975559,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-color','$highlight-box-border-2','','','.w-predefined-promotion'),(975560,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-color','$highlight-box-border-2','','','.w-predefined-promotion'),(975561,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-color','$highlight-box-border-2','','','.w-predefined-promotion'),(975562,'deals','.w-predefined-promotion .promo-salemaker .discount','border-bottom-color','$warning-border','','','.w-predefined-promotion'),(975563,'deals','.w-supplier-purchase-supplier-products .item','border-bottom-color','$content-border-1','','','.w-supplier-purchase-supplier-products'),(975564,'deals','.w-filters .filter-widget-horizontal .filter-box-content','border-bottom-color','$content-border-1','','','.w-filters'),(975565,'deals','.filterLine ','border-bottom-color','$content-border-1','','','.filterLine'),(975566,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-bottom-color','$highlight-box-border-2','','','.b-products-listing'),(975567,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span','border-bottom-color','$content-border-1','','','.w-product-quantity-discounts'),(975568,'deals','.w-product-groups .property-category-heading + .property-category-content','border-bottom-color','$content-border-1','','','.w-product-groups'),(975569,'deals','.btn-3','border-bottom-color','$btn-border-4','','',''),(975570,'deals','.w-product-quantity-discounts .quantity-discounts-content .item','border-bottom-color','$content-border-1','','','.w-product-quantity-discounts'),(975571,'deals','.w-cart-listing .item','border-bottom-color','$content-border-1','','','.w-cart-listing'),(975572,'deals','.w-product-groups .radioBox label .containerBlock','border-bottom-color','$highlight-box-border-2','1','','.w-product-groups'),(975573,'deals','.w-tabs .tab-navigation','border-bottom-color','$tab-nav-border-2','','','.w-tabs'),(975574,'deals','.savings-ico .heading-3','border-bottom-color','$content-border-1','','','.savings-ico'),(975575,'deals','.order-summary > div','border-bottom-color','$content-border-1','','','.order-summary'),(975576,'deals','.btn','border-bottom-color','$btn-border-1','','',''),(975577,'deals','.w-support-system-listing .product_icon','border-bottom-color','$content-border-1','','','.w-support-system-listing'),(975578,'deals','.w-support-system-listing .support-head','border-bottom-color','$content-border-1','','','.w-support-system-listing'),(975579,'deals','.w-support-system-listing .support-item-body-content','border-bottom-color','$content-border-1','','','.w-support-system-listing'),(975580,'deals','.w-support-system-listing .support-item-body .support-item-body-image','border-bottom-color','$content-border-1','','','.w-support-system-listing'),(975582,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','border-bottom-color','$content-border-1','5639','','.w-filters'),(975583,'deals','.filterLine .w-filters','border-bottom-color','$content-border-1','5660','','.filterLine'),(975584,'deals','.b-products-listing .pr-groups.active a','border-bottom-color','$highlight-box-border-1','','','.b-products-listing'),(975585,'deals','.w-product-personal-catalog-button .btn','border-bottom-color','$highlight-box-border-2','','','.w-product-personal-catalog-button'),(975586,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-bottom-color','$content-border-1','','','.w-account-personal-catalog'),(975587,'deals','.w-account-personal-catalog .list-row-action ul','border-bottom-color','$content-border-1','','','.w-account-personal-catalog'),(975588,'deals','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','border-bottom-color','$content-border-1','','','.w-catalog-compare'),(975589,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li','border-bottom-color','$highlight-box-border-1','5630','','.preFooter'),(975590,'deals','.order-summary .checkout-cart-listing','border-bottom-color','$content-border-1','','','.order-summary'),(975594,'deals','.account-samples .orders-table .item','border-bottom-color','$content-border-1','5639','','.account-samples'),(975595,'deals','.catalog-product-wrap .pn-image','border-bottom-color','$content-border-1','3','','.catalog-product-wrap'),(975596,'deals','.checkout-index-wrap .input-wrapper','border-bottom-color','$content-border-1','','','.checkout-index-wrap'),(975597,'deals','.w-cart-products .checkout-attention-message','border-bottom-color','$highlight-box-border-2','','','.w-cart-products'),(975598,'deals','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-color','$highlight-box-border-2','','','.b-multi-page-checkout'),(975599,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-color','$content-border-1','','','.b-multi-page-checkout'),(975600,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-color','$content-border-1','','','.b-multi-page-checkout'),(975601,'deals','.w-catalog-paging ','border-bottom-color','#CCCCCC','2','','.w-catalog-paging'),(975602,'deals','.w-catalog-paging .next','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(975603,'deals','.w-catalog-paging .next-pages','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(975604,'deals','.w-catalog-paging .page-number','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(975605,'deals','.w-catalog-paging .prev','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(975606,'deals','.w-catalog-paging .prev-pages','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(975607,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-color','#CCCCCC','','','.w-catalog-paging'),(975608,'deals','.b-data-table table.dataTable.no-footer','border-bottom-color_important','important','','','.b-data-table'),(975609,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-left-radius','15','4','','.b-switch'),(975610,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.p-quick-order-index'),(975611,'deals','.w-promotions .prom-multi-discount .promo-range','border-bottom-left-radius','12','','','.w-promotions'),(975612,'deals','.w-promotions .promo-salemaker .discount','border-bottom-left-radius','12','','','.w-promotions'),(975613,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-left-radius','12','','','.w-promotions'),(975614,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-left-radius','12','','','.w-promotions'),(975615,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.p-quick-order-index'),(975616,'deals','.w-personal-gift-status-bar .progress-bar','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(975617,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-left-radius','5','','','.b-messages'),(975618,'deals','.b-fancybox .fancybox-close','border-bottom-left-radius','50','','','.b-fancybox'),(975619,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-left-radius','25','','','.b-switch'),(975620,'deals','.b-upload-file .snapshot','border-bottom-left-radius','50','','','.b-upload-file'),(975621,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-left-radius','15','3','','.b-switch'),(975622,'deals','.b-switch .candlestick-wrapper .candlestick-bg','border-bottom-left-radius','15','','','.b-switch'),(975623,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(975624,'deals','.w-checkout-shipping-choice label:last-child span','border-bottom-left-radius','0','','','.w-checkout-shipping-choice'),(975625,'deals','.w-checkout-shipping-choice label:first-child span','border-bottom-left-radius','16','','','.w-checkout-shipping-choice'),(975626,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-bottom-left-radius','0','4','','.b-switch'),(975627,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-bottom-left-radius','0','3','','.b-switch'),(975628,'deals','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-left-radius','15','','','.b-fancybox'),(975629,'deals','.b-fancybox .fancybox-skin','border-bottom-left-radius','4','','','.b-fancybox'),(975630,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-bottom-left-radius','50','3','','.b-switch'),(975631,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-left-radius','50','3','','.b-form'),(975632,'deals','.b-fancybox .fancybox-nav span','border-bottom-left-radius','50','','','.b-fancybox'),(975633,'deals','.w-product-customers-activity .customers-activity','border-bottom-left-radius','0','','','.w-product-customers-activity'),(975634,'deals','.w-product-customers-activity .close','border-bottom-left-radius','50','','','.w-product-customers-activity'),(975635,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-left-radius','10','3','','.b-switch'),(975636,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-left-radius','0','','','.b-data-table'),(975637,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-left-radius','0','','','.b-data-table'),(975638,'deals','.b-products-listing .promos-info .promo-name','border-bottom-left-radius','0','','','.b-products-listing'),(975639,'deals','.w-personal-gift-status-bar .progress-bar-content','border-bottom-left-radius','4','','','.w-personal-gift-status-bar'),(975640,'deals','.b-switch .bootstrap-switch','border-bottom-left-radius','14','','','.b-switch'),(975641,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-left-radius','25','','','.b-switch'),(975642,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-bottom-left-radius','0','','','.b-product-images'),(975643,'deals','.b-trade-approval .steps-bar','border-bottom-left-radius','18','','','.b-trade-approval'),(975644,'deals','.w-delivery-day .left-count','border-bottom-left-radius','3','','','.w-delivery-day'),(975645,'deals','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-left-radius','3','','','.w-delivery-day'),(975648,'deals','.w-quote .cart-box-link','border-bottom-left-radius','50','3','','.w-quote'),(975649,'deals','.w-product-sale-ends .left-count','border-bottom-left-radius','3','','','.w-product-sale-ends'),(975650,'deals','.w-product-sale-ends .left-count-days','border-bottom-left-radius','3','','','.w-product-sale-ends'),(975651,'deals','.w-product-sale-ends .left-count-hours','border-bottom-left-radius','3','','','.w-product-sale-ends'),(975652,'deals','.w-sample .cart-box-link','border-bottom-left-radius','50','3','','.w-sample'),(975653,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-left-radius','50','','','.w-questionnaire-widgets-questionnaire'),(975654,'deals','.w-sale-category .badge','border-bottom-left-radius','50','','','.w-sale-category'),(975655,'deals','.w-sale-category .left-count','border-bottom-left-radius','3','','','.w-sale-category'),(975656,'deals','.w-sale-category .left-count-days','border-bottom-left-radius','3','','','.w-sale-category'),(975657,'deals','.w-sale-category .left-count-hours','border-bottom-left-radius','3','','','.w-sale-category'),(975658,'deals','.b-products-listing .productGroup label a','border-bottom-left-radius','3','','','.b-products-listing'),(975659,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-left-radius','12','','','.w-predefined-promotion'),(975660,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-left-radius','12','','','.w-predefined-promotion'),(975661,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-left-radius','12','','','.w-predefined-promotion'),(975662,'deals','.w-predefined-promotion .promo-salemaker .discount','border-bottom-left-radius','12','','','.w-predefined-promotion'),(975666,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-left-radius','50','','','.b-slick'),(975667,'deals','.w-product-groups .radioBox label .containerBlock','border-bottom-left-radius','5','','','.w-product-groups'),(975669,'deals','.catalog-product-wrap .pn-image','border-bottom-left-radius','50','3','','.catalog-product-wrap'),(975670,'deals','.b-slick .slick-dots li','border-bottom-left-radius','50','3','','.b-slick'),(975671,'deals','.success-page .w-cart-listing .qty','border-bottom-left-radius','50','','','.success-page'),(975672,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-left-radius','50','','','.b-multi-page-checkout'),(975673,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-left-radius','50','3','','.b-multi-page-checkout'),(975674,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-left-radius','0','','','.w-catalog-paging'),(975675,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-bottom-right-radius','0','4','','.b-switch'),(975676,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-right-radius','15','4','','.b-switch'),(975677,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.p-quick-order-index'),(975678,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.p-quick-order-index'),(975679,'deals','.w-promotions .prom-multi-discount .promo-range','border-bottom-right-radius','12','','','.w-promotions'),(975680,'deals','.w-promotions .promo-salemaker .discount','border-bottom-right-radius','12','','','.w-promotions'),(975681,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-right-radius','12','','','.w-promotions'),(975682,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-right-radius','12','','','.w-promotions'),(975683,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-bottom-right-radius','5','','','.b-messages'),(975684,'deals','.b-fancybox .fancybox-close','border-bottom-right-radius','50','','','.b-fancybox'),(975685,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-right-radius','25','','','.b-switch'),(975686,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-bottom-right-radius','0','3','','.b-switch'),(975687,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-right-radius','15','3','','.b-switch'),(975688,'deals','.b-switch .candlestick-wrapper .candlestick-bg','border-bottom-right-radius','15','','','.b-switch'),(975689,'deals','.w-checkout-shipping-choice label:last-child span','border-bottom-right-radius','16','','','.w-checkout-shipping-choice'),(975690,'deals','.w-checkout-shipping-choice label:first-child span','border-bottom-right-radius','0','','','.w-checkout-shipping-choice'),(975691,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(975692,'deals','.b-fancybox .fancybox-title-float-wrap .child','border-bottom-right-radius','15','','','.b-fancybox'),(975693,'deals','.b-fancybox .fancybox-skin','border-bottom-right-radius','4','','','.b-fancybox'),(975694,'deals','.b-upload-file .snapshot','border-bottom-right-radius','50','','','.b-upload-file'),(975695,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-bottom-right-radius','50','3','','.b-switch'),(975696,'deals','.b-fancybox .fancybox-nav span','border-bottom-right-radius','50','','','.b-fancybox'),(975697,'deals','.w-product-customers-activity .close','border-bottom-right-radius','50','','','.w-product-customers-activity'),(975698,'deals','.w-product-customers-activity .customers-activity','border-bottom-right-radius','0','','','.w-product-customers-activity'),(975699,'deals','.w-personal-gift-status-bar .progress-bar','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(975700,'deals','.b-switch .bootstrap-switch','border-bottom-right-radius','14','','','.b-switch'),(975701,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-bottom-right-radius','0','','','.b-data-table'),(975702,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-bottom-right-radius','0','','','.b-data-table'),(975703,'deals','.b-products-listing .promos-info .promo-name','border-bottom-right-radius','8','','','.b-products-listing'),(975704,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-bottom-right-radius','10','3','','.b-switch'),(975705,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-right-radius','50','3','','.b-form'),(975706,'deals','.w-personal-gift-status-bar .progress-bar-content','border-bottom-right-radius','4','','','.w-personal-gift-status-bar'),(975707,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-right-radius','25','','','.b-switch'),(975708,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-bottom-right-radius','0','','','.b-product-images'),(975709,'deals','.b-trade-approval .steps-bar','border-bottom-right-radius','18','','','.b-trade-approval'),(975710,'deals','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-bottom-right-radius','3','','','.w-delivery-day'),(975711,'deals','.w-delivery-day .left-count','border-bottom-right-radius','3','','','.w-delivery-day'),(975714,'deals','.w-quote .cart-box-link','border-bottom-right-radius','50','3','','.w-quote'),(975715,'deals','.w-product-sale-ends .left-count','border-bottom-right-radius','3','','','.w-product-sale-ends'),(975716,'deals','.w-product-sale-ends .left-count-days','border-bottom-right-radius','3','','','.w-product-sale-ends'),(975717,'deals','.w-product-sale-ends .left-count-hours','border-bottom-right-radius','3','','','.w-product-sale-ends'),(975718,'deals','.w-sample .cart-box-link','border-bottom-right-radius','50','3','','.w-sample'),(975719,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-right-radius','50','','','.w-questionnaire-widgets-questionnaire'),(975720,'deals','.w-sale-category .badge','border-bottom-right-radius','50','','','.w-sale-category'),(975721,'deals','.w-sale-category .left-count','border-bottom-right-radius','3','','','.w-sale-category'),(975722,'deals','.w-sale-category .left-count-days','border-bottom-right-radius','3','','','.w-sale-category'),(975723,'deals','.w-sale-category .left-count-hours','border-bottom-right-radius','3','','','.w-sale-category'),(975724,'deals','.b-products-listing .productGroup label a','border-bottom-right-radius','3','','','.b-products-listing'),(975725,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-right-radius','12','','','.w-predefined-promotion'),(975726,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-right-radius','12','','','.w-predefined-promotion'),(975727,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-right-radius','12','','','.w-predefined-promotion'),(975728,'deals','.w-predefined-promotion .promo-salemaker .discount','border-bottom-right-radius','12','','','.w-predefined-promotion'),(975732,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','border-bottom-right-radius','50','','','.b-slick'),(975733,'deals','.w-product-groups .radioBox label .containerBlock','border-bottom-right-radius','5','','','.w-product-groups'),(975735,'deals','.catalog-product-wrap .pn-image','border-bottom-right-radius','50','3','','.catalog-product-wrap'),(975736,'deals','.b-slick .slick-dots li','border-bottom-right-radius','50','3','','.b-slick'),(975737,'deals','.success-page .w-cart-listing .qty','border-bottom-right-radius','50','','','.success-page'),(975738,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-right-radius','50','','','.b-multi-page-checkout'),(975739,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-bottom-right-radius','50','3','','.b-multi-page-checkout'),(975740,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-right-radius','0','','','.w-catalog-paging'),(975741,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(975742,'deals','.b-upload-file .upload-file-template div','border-bottom-style','dotted','','','.b-upload-file'),(975743,'deals','.w-promotions .prom-multi-discount .promo-range','border-bottom-width','1','','','.w-promotions'),(975745,'deals','.testimonials .review','border-bottom-width','7','3','',''),(975746,'deals','.w-promotions .promo-salemaker .discount','border-bottom-width','1','','','.w-promotions'),(975747,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border-bottom-width','1','','','.w-promotions'),(975748,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border-bottom-width','1','','','.w-promotions'),(975749,'deals','.b-upload-file .upload-file-template div','border-bottom-width','1','','','.b-upload-file'),(975750,'deals','.w-cart-compare .cart-cell > div','border-bottom-width','1','','','.w-cart-compare'),(975751,'deals','.w-filters .filter-box-head','border-bottom-width','1','','','.w-filters'),(975752,'deals','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-bottom-width','1','','','.b-bottom'),(975753,'deals','.b-messages .msv_btn','border-bottom-width','1','','','.b-messages'),(975754,'deals','.b-messages .email-heading','border-bottom-width','1','','','.b-messages'),(975755,'deals','.b-messages .content_management_attach button','border-bottom-width','1','','','.b-messages'),(975756,'deals','.b-messages .content_management_attach','border-bottom-width','1','','','.b-messages'),(975757,'deals','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-bottom-width','2','','','.b-messages'),(975758,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','border-bottom-width','1','','','.b-messages'),(975759,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','border-bottom-width','1','','','.b-messages'),(975760,'deals','.b-messages .dataTables_wrapper > .bottom','border-bottom-width','1','','','.b-messages'),(975761,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-bottom-width','1','','',''),(975762,'deals','.p-payer-order-confirmation .input-wrapper','border-bottom-width','2','','','.p-payer-order-confirmation'),(975763,'deals','.p-payer-order-pay .input-wrapper','border-bottom-width','2','','','.p-payer-order-pay'),(975764,'deals','.b-messages .msv_to_cc','border-bottom-width','1','','','.b-messages'),(975765,'deals','.w-product-reviews .reviews-list .review','border-bottom-width','7','3','','.w-product-reviews'),(975766,'deals','.w-reviews .review','border-bottom-width','8','3','','.w-reviews'),(975767,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-bottom-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(975768,'deals','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(975769,'deals','.w-tabs .accordion-heading','border-bottom-width','1','','','.w-tabs'),(975770,'deals','.b-form .required-error','border-bottom-width','1','','','.b-form'),(975771,'deals','.w-socials > li','border-bottom-width','1','','','.w-socials'),(975772,'deals','.b-bottom .popup-heading','border-bottom-width','1','','','.b-bottom'),(975773,'deals','.w-checkout-shipping-choice span','border-bottom-width','2','','','.w-checkout-shipping-choice'),(975774,'deals','.w-socials > li','border-bottom-width','1','','','.w-socials'),(975777,'deals','.b-info-popup .info-popup div','border-bottom-width','1','','','.b-info-popup'),(975778,'deals','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(975779,'deals','.w-tabs .accordion-heading','border-bottom-width','3','2','','.w-tabs'),(975780,'deals','.w-socials > li','border-bottom-width','1','','','.w-socials'),(975781,'deals','.w-cart-give-away .ga_column','border-bottom-width','1','','','.w-cart-give-away'),(975782,'deals','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(975783,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-bottom-width','4','','','.b-switch'),(975784,'deals','.w-filters .ui-slider-handle','border-bottom-width','0','','','.w-filters'),(975785,'deals','.w-filters .ui-slider','border-bottom-width','0','','','.w-filters'),(975786,'deals','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(975787,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border-bottom-width','2','3','','.b-form'),(975788,'deals','.b-upload-file .upload-file-template','border-bottom-width','1','','','.b-upload-file'),(975789,'deals','.w-socials > li','border-bottom-width','1','','','.w-socials'),(975790,'deals','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(975791,'deals','.w-reviews .item','border-bottom-width','1','','','.w-reviews'),(975792,'deals','.b-select-suggest .select2-container .select2-choice','border-bottom-width','1','','','.b-select-suggest'),(975793,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-bottom-width','2','4','','.b-switch'),(975795,'deals','.b-compare .popupCompare td, .b-compare .popupCompare th','border-bottom-width','1','','','.b-compare'),(975796,'deals','.w-cart-compare .compare-table','border-bottom-width','1','','','.w-cart-compare'),(975797,'deals','.w-reviews-content .review','border-bottom-width','8','3','','.w-reviews-content'),(975798,'deals','textarea','border-bottom-width','1','','',''),(975799,'deals','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-bottom-width','1','','','.b-bottom'),(975800,'deals','.b-bottom .footerTitle','border-bottom-width','1','5630','','.b-bottom'),(975801,'deals','.w-socials > li','border-bottom-width','1','','','.w-socials'),(975802,'deals','.b-bottom .popup-box','border-bottom-width','1','','','.b-bottom'),(975803,'deals','.w-product-customers-activity .customers-activity','border-bottom-width','1','','','.w-product-customers-activity'),(975804,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(975805,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(975806,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-bottom-width','1','','','.b-select-suggest'),(975807,'deals','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(975808,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-bottom-width','1','','','.b-select-suggest'),(975809,'deals','.b-select-suggest .select2-container-multi .select2-choices','border-bottom-width','1','','','.b-select-suggest'),(975810,'deals','.b-select-suggest .select2-search input','border-bottom-width','1','','','.b-select-suggest'),(975811,'deals','.b-select-suggest .select2-drop-active','border-bottom-width','1','','','.b-select-suggest'),(975812,'deals','.b-select-suggest .select2-drop','border-bottom-width','1','','','.b-select-suggest'),(975813,'deals','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(975814,'deals','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(975815,'deals','.w-communication-post .communication-post','border-bottom-width','1','','','.w-communication-post'),(975816,'deals','.checkbox input:checked + span','border-bottom-width','1','','',''),(975817,'deals','.checkbox input + span','border-bottom-width','1','','',''),(975818,'deals','.b-autocomplete .ui-autocomplete','border-bottom-width','1','','','.b-autocomplete'),(975821,'deals','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(975822,'deals','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(975823,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-bottom-width','2','3','','.b-switch'),(975824,'deals','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(975825,'deals','.b-dropdown .dropdown .dropdown-menu','border-bottom-width','1','','','.b-dropdown'),(975826,'deals','.w-promo-code .holder','border-bottom-width','1','','','.w-promo-code'),(975827,'deals','.w-cart-listing .item .gift-wrap label','border-bottom-width','1','','','.w-cart-listing'),(975828,'deals','.w-cart-listing .item','border-bottom-width','1','5639','','.w-cart-listing'),(975831,'deals','.w-socials > li','border-bottom-width','1','','','.w-socials'),(975833,'deals','.w-reviews-content .item','border-bottom-width','1','','','.w-reviews-content'),(975834,'deals','.w-filters .ui-slider-range','border-bottom-width','0','','','.w-filters'),(975835,'deals','.b-upload-files .upload-files','border-bottom-width','1','','','.b-upload-files'),(975836,'deals','.b-compare .compare_pagination','border-bottom-width','1','','','.b-compare'),(975837,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-bottom-width','3','','','.b-switch'),(975838,'deals','.b-upload-file .snapshot','border-bottom-width','1','','','.b-upload-file'),(975839,'deals','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-bottom-width','2','','','.b-product-images'),(975840,'deals','.b-trade-approval .orders-table th','border-bottom-width','1','','','.b-trade-approval'),(975841,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-bottom-width','2','','','.b-trade-approval'),(975842,'deals','.w-account-personal-catalog .list-switcher a','border-bottom-width','1','','','.w-account-personal-catalog'),(975843,'deals','.w-catalog-compare .compare .checkbox input:checked + span','border-bottom-width','1','','','.w-catalog-compare'),(975844,'deals','.w-catalog-compare .cross-box .different-all > div','border-bottom-width','1','','','.w-catalog-compare'),(975845,'deals','.w-delivery-day .left-text-right','border-bottom-width','2','','','.w-delivery-day'),(975846,'deals','.w-delivery-day .left-text-left','border-bottom-width','2','','','.w-delivery-day'),(975847,'deals','.b-slick .slick-vertical .slick-slide','border-bottom-width','1','','','.b-slick'),(975848,'deals','.b-products-listing .products-listing .compare input + span','border-bottom-width','1','','','.b-products-listing'),(975849,'deals','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-bottom-width','0','','','.w-filters'),(975850,'deals','.w-quote .cart-content','border-bottom-width','1','','','.w-quote'),(975851,'deals','.w-quote .cart-total','border-bottom-width','1','','','.w-quote'),(975852,'deals','.w-quote .multicart .item','border-bottom-width','1','','','.w-quote'),(975853,'deals','.b-product-images .additional-images .active img','border-bottom-width','2','','','.b-product-images'),(975854,'deals','.b-product-images .additional-images img','border-bottom-width','2','','','.b-product-images'),(975855,'deals','.b-quantity .qty-box .bigger','border-bottom-width','1','','','.b-quantity'),(975856,'deals','.b-quantity .qty-box .smaller','border-bottom-width','1','','','.b-quantity'),(975857,'deals','.w-product-sale-ends .left-text-left','border-bottom-width','2','','','.w-product-sale-ends'),(975858,'deals','.w-product-sale-ends .left-text-right','border-bottom-width','2','','','.w-product-sale-ends'),(975859,'deals','.w-product-quantity .qty_packs .qty-input','border-bottom-width','1','','','.w-product-quantity'),(975860,'deals','.warrantyProduct .warranty, .warrantyProduct .delivery','border-bottom-width','1','','','.warrantyProduct'),(975861,'deals','.w-sample .cart-box-link','border-bottom-width','1','4','','.w-sample'),(975862,'deals','.w-sample .cart-content','border-bottom-width','1','','','.w-sample'),(975863,'deals','.w-sample .cart-total','border-bottom-width','1','','','.w-sample'),(975864,'deals','.w-sample .multicart .item','border-bottom-width','1','','','.w-sample'),(975865,'deals','.w-product-video .item img, .w-product-video .item video','border-bottom-width','2','','','.w-product-video'),(975866,'deals','.w-product-video .item.active img, .w-product-video .item.active video','border-bottom-width','2','','','.w-product-video'),(975867,'deals','.shipping-ico .heading-3','border-bottom-width','1','','','.shipping-ico'),(975869,'deals','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-bottom-width','1','','','.b-pagination'),(975870,'deals','.b-pagination .pagination .next-pages','border-bottom-width','1','','','.b-pagination'),(975871,'deals','.b-pagination .pagination .page-number','border-bottom-width','1','','','.b-pagination'),(975872,'deals','.b-pagination .pagination .prev-pages','border-bottom-width','1','','','.b-pagination'),(975873,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-bottom-width','1','','','.b-pagination'),(975874,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-bottom-width','1','','','.b-pagination'),(975875,'deals','.b-pagination .pagination span','border-bottom-width','1','2','','.b-pagination'),(975876,'deals','.w-product-multi-inventory .radio-attributes','border-bottom-width','1','','','.w-product-multi-inventory'),(975877,'deals','.w-product-multi-inventory .radio-attributes .option-item','border-bottom-width','2','','','.w-product-multi-inventory'),(975878,'deals','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-bottom-width','2','','','.w-product-multi-inventory'),(975879,'deals','.b-products-listing .products-listing .radio-attributes','border-bottom-width','1','','','.b-products-listing'),(975880,'deals','.b-products-listing .products-listing .radio-attributes .option','border-bottom-width','2','','','.b-products-listing'),(975881,'deals','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-bottom-width','2','','','.b-products-listing'),(975882,'deals','.w-product-attributes .radio-attributes','border-bottom-width','1','','','.w-product-attributes'),(975883,'deals','.w-product-attributes .radio-attributes .option-item','border-bottom-width','2','','','.w-product-attributes'),(975884,'deals','.w-product-attributes .radio-attributes input:checked + .option-item','border-bottom-width','2','','','.w-product-attributes'),(975885,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-bottom-width','2','','','.w-questionnaire-widgets-questionnaire'),(975886,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-bottom-width','2','','','.w-questionnaire-widgets-questionnaire'),(975887,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-bottom-width','2','','','.w-questionnaire-widgets-questionnaire'),(975888,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-bottom-width','2','1','','.w-questionnaire-widgets-questionnaire'),(975889,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-bottom-width','2','1','','.w-questionnaire-widgets-questionnaire'),(975890,'deals','.w-product-groups .radioBox label .containerBlock','border-bottom-width','2','','','.w-product-groups'),(975891,'deals','.w-product-groups .radioBox label .containerBlock.selected','border-bottom-width','2','','','.w-product-groups'),(975892,'deals','.w-product-groups .radioBox label input:checked + .containerBlock','border-bottom-width','2','','','.w-product-groups'),(975893,'deals','.w-delivery-location-top-location-list .deliveryName','border-bottom-width','1','','','.w-delivery-location-top-location-list'),(975894,'deals','.w-delivery-location-location-list .deliveryName','border-bottom-width','1','','','.w-delivery-location-location-list'),(975895,'deals','.w-delivery-location-location-list .deliveryList li a','border-bottom-width','2','','','.w-delivery-location-location-list'),(975896,'deals','.w-delivery-location-location-list .deliveryList li a','border-bottom-width','2','1','','.w-delivery-location-location-list'),(975897,'deals','.w-sale-category .left-text-left','border-bottom-width','2','','','.w-sale-category'),(975898,'deals','.w-sale-category .left-text-right','border-bottom-width','2','','','.w-sale-category'),(975899,'deals','.w-sale-category .sale-holder','border-bottom-width','2','','','.w-sale-category'),(975900,'deals','.w-catalog-delivery-locations .name','border-bottom-width','1','','','.w-catalog-delivery-locations'),(975901,'deals','.w-product-designer-designer .prodDesignerType label','border-bottom-width','1','','','.w-product-designer-designer'),(975902,'deals','.w-press-reviews-widgets-press-reviews-small ','border-bottom-width','1','','','.w-press-reviews-widgets-press-reviews-small'),(975903,'deals','.b-products-listing .productGroup label a','border-bottom-width','1','','','.b-products-listing'),(975904,'deals','.w-rma-returns-history .topRow','border-bottom-width','1','','','.w-rma-returns-history'),(975905,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border-bottom-width','1','','','.w-predefined-promotion'),(975906,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-bottom-width','1','','','.w-predefined-promotion'),(975907,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-bottom-width','1','','','.w-predefined-promotion'),(975908,'deals','.w-predefined-promotion .promo-salemaker .discount','border-bottom-width','1','','','.w-predefined-promotion'),(975909,'deals','.w-supplier-purchase-supplier-products .item','border-bottom-width','1','','','.w-supplier-purchase-supplier-products'),(975910,'deals','.headerWrap .menu-style[data-style=\"1\"] li.back-button','border-bottom-width','1','','','.headerWrap'),(975911,'deals','.w-filters .filter-widget-horizontal .filter-box-head','border-bottom-width','0','','','.w-filters'),(975912,'deals','.w-filters .filter-widget-horizontal .filter-box-content','border-bottom-width','1','','','.w-filters'),(975913,'deals','.filterLine ','border-bottom-width','1','','','.filterLine'),(975914,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-bottom-width','2','','','.b-products-listing'),(975915,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span','border-bottom-width','1','','','.w-product-quantity-discounts'),(975916,'deals','.w-product-groups .property-category-heading + .property-category-content','border-bottom-width','1','','','.w-product-groups'),(975917,'deals','.btn-3','border-bottom-width','2','','',''),(975918,'deals','.w-product-quantity-discounts .quantity-discounts-content .item','border-bottom-width','1','','','.w-product-quantity-discounts'),(975919,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span:last-of-type','border-bottom-width','0','','','.w-product-quantity-discounts'),(975920,'deals','.w-cart-listing .item','border-bottom-width','1','','','.w-cart-listing'),(975921,'deals','.w-product-groups .radioBox label .containerBlock','border-bottom-width','2','1','','.w-product-groups'),(975922,'deals','.w-tabs .tab-navigation','border-bottom-width','1','','','.w-tabs'),(975923,'deals','.savings-ico .heading-3','border-bottom-width','1','','','.savings-ico'),(975924,'deals','.order-summary > div','border-bottom-width','1','','','.order-summary'),(975925,'deals','.btn','border-bottom-width','2','','',''),(975926,'deals','.w-support-system-listing .product_icon','border-bottom-width','1','','','.w-support-system-listing'),(975927,'deals','.w-support-system-listing .support-head','border-bottom-width','1','','','.w-support-system-listing'),(975928,'deals','.w-support-system-listing .support-item-body-content','border-bottom-width','1','','','.w-support-system-listing'),(975929,'deals','.w-support-system-listing .support-item-body .support-item-body-image','border-bottom-width','1','','','.w-support-system-listing'),(975931,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','border-bottom-width','1','5639','','.w-filters'),(975932,'deals','.filterLine .w-filters','border-bottom-width','1','5660','','.filterLine'),(975933,'deals','.b-products-listing .pr-groups.active a','border-bottom-width','1','','','.b-products-listing'),(975934,'deals','.w-product-personal-catalog-button .btn','border-bottom-width','2','','','.w-product-personal-catalog-button'),(975935,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-bottom-width','1','','','.w-account-personal-catalog'),(975936,'deals','.w-account-personal-catalog .list-row-action ul','border-bottom-width','1','','','.w-account-personal-catalog'),(975937,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li','border-bottom-width','1','5630','','.preFooter'),(975938,'deals','.w-catalog-compare .list-compareproduct .BlockBox.item-holder','border-bottom-width','1','','','.w-catalog-compare'),(975939,'deals','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item:last-of-type','border-bottom-width','0','','','.w-promotions-widgets-promotion-icons-desc'),(975940,'deals','.order-summary .checkout-cart-listing','border-bottom-width','1','','','.order-summary'),(975943,'deals','.account-address-book .address_book h1','border-bottom-width','1','','','.account-address-book'),(975944,'deals','.account-address-book .address_book h2','border-bottom-width','1','','','.account-address-book'),(975947,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','border-bottom-width','1','','','.account-order-pay'),(975948,'deals','.account-samples .orders-table .item','border-bottom-width','1','5639','','.account-samples'),(975949,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','border-bottom-width','1','','','.account-sample-info'),(975950,'deals','.catalog-product-wrap .pn-image','border-bottom-width','2','3','','.catalog-product-wrap'),(975951,'deals','.catalog-product-wrap .prev-next-product','border-bottom-width','1','','','.catalog-product-wrap'),(975952,'deals','.shopping-cart-index .closeable-heading','border-bottom-width','1','','','.shopping-cart-index'),(975953,'deals','.shopping-cart-index .closeable-heading .heading-3','border-bottom-width','0','','','.shopping-cart-index'),(975954,'deals','.checkout-index-wrap .input-wrapper','border-bottom-width','2','','','.checkout-index-wrap'),(975955,'deals','.w-cart-products .checkout-attention-message','border-bottom-width','1','','','.w-cart-products'),(975956,'deals','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(975957,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-bottom-width','2','','','.b-multi-page-checkout'),(975958,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-bottom-width','1','','','.b-multi-page-checkout'),(975959,'deals','.w-catalog-paging ','border-bottom-width','1','2','','.w-catalog-paging'),(975960,'deals','.w-catalog-paging .next','border-bottom-width','1','','','.w-catalog-paging'),(975961,'deals','.w-catalog-paging .next-pages','border-bottom-width','1','','','.w-catalog-paging'),(975962,'deals','.w-catalog-paging .page-number','border-bottom-width','1','','','.w-catalog-paging'),(975963,'deals','.w-catalog-paging .prev','border-bottom-width','1','','','.w-catalog-paging'),(975964,'deals','.w-catalog-paging .prev-pages','border-bottom-width','1','','','.w-catalog-paging'),(975965,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-bottom-width','1','','','.w-catalog-paging'),(975967,'deals','.b-compare .popupCompare table','border-collapse','collapse','','','.b-compare'),(975968,'deals','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','border-left','none','','','.b-select-suggest'),(975969,'deals','.w-promotions .prom-multi-discount .promo-range','border-left-color','$highlight-box-border-2','','','.w-promotions'),(975970,'deals','.w-cart-compare .attributes-block td:nth-child(1)','border-left-color','$content-border-1','','','.w-cart-compare'),(975972,'deals','.w-promotions .promo-salemaker .discount','border-left-color','$warning-border','','','.w-promotions'),(975973,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-color','$highlight-box-border-2','','','.w-promotions'),(975974,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border-left-color','$highlight-box-border-2','','','.w-promotions'),(975975,'deals','.w-cart-compare .cart-cell > div','border-left-color','$content-border-1','','','.w-cart-compare'),(975976,'deals','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(975977,'deals','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-left-color','$content-border-1','','','.b-bottom'),(975978,'deals','.b-messages .content_management_attach button','border-left-color','$highlight-box-border-1','','','.b-messages'),(975979,'deals','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-color','$content-border-1','','','.b-messages'),(975980,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-left-color','$content-border-1','','',''),(975981,'deals','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(975982,'deals','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(975983,'deals','.p-payer-order-confirmation .input-wrapper','border-left-color','$content-border-1','','','.p-payer-order-confirmation'),(975984,'deals','.p-payer-order-pay .input-wrapper','border-left-color','$content-border-1','','','.p-payer-order-pay'),(975985,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-left-color','$switch-nc-border-1','','','.b-switch'),(975986,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(975987,'deals','.b-info-popup .info-popup div','border-left-color','$content-border-1','3','','.b-info-popup'),(975988,'deals','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-color','$content-border-1','','','.b-compare'),(975989,'deals','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(975990,'deals','.b-form .required-error','border-left-color','$attention-border','','','.b-form'),(975991,'deals','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(975992,'deals','.b-info-popup .info-popup div','border-left-color','$content-border-1','','','.b-info-popup'),(975993,'deals','.w-checkout-shipping-choice label:first-child span','border-left-color','$highlight-box-border-1','','','.w-checkout-shipping-choice'),(975994,'deals','.w-product-reviews .reviews-list .review','border-left-color','$content-border-1','3','','.w-product-reviews'),(975995,'deals','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(975996,'deals','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(975997,'deals','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(975998,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-left-color','$switch-handle-bg-3','','','.b-switch'),(975999,'deals','.w-reviews .review','border-left-color','$content-bg-1','3','','.w-reviews'),(976000,'deals','.w-reviews-content .review','border-left-color','$content-border-1','3','','.w-reviews-content'),(976001,'deals','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(976002,'deals','.b-select-suggest .select2-container .select2-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(976003,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-left-color','$switch-nc-border-1','4','','.b-switch'),(976005,'deals','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(976006,'deals','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-left-color','$content-bg-1','','','.b-bottom'),(976007,'deals','textarea','border-left-color','$content-border-1','','',''),(976008,'deals','.b-bottom .popup-box','border-left-color','$content-border-1','','','.b-bottom'),(976009,'deals','.w-product-customers-activity .customers-activity','border-left-color','$content-border-1','','','.w-product-customers-activity'),(976010,'deals','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(976011,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border-left-color','$checkbox-border-1','3','','.b-form'),(976012,'deals','.w-cart-compare .price-block td:nth-child(1)','border-left-color','$content-border-1','','','.w-cart-compare'),(976013,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(976014,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-color','$content-border-1','','','.b-select-suggest'),(976015,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(976016,'deals','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-color','$content-border-1','','','.b-select-suggest'),(976017,'deals','.b-select-suggest .select2-container-multi .select2-choices','border-left-color','$content-border-1','','','.b-select-suggest'),(976018,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-color','$content-border-1','','','.b-select-suggest'),(976019,'deals','.b-select-suggest .select2-search input','border-left-color','$content-border-1','','','.b-select-suggest'),(976020,'deals','.b-select-suggest .select2-drop','border-left-color','$content-border-1','','','.b-select-suggest'),(976021,'deals','.b-select-suggest .select2-drop-active','border-left-color','$content-border-1','','','.b-select-suggest'),(976022,'deals','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(976023,'deals','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(976024,'deals','.b-form input.required-error','border-left-color','$attention-border','','','.b-form'),(976025,'deals','.checkbox input:checked + span','border-left-color','$checkbox-border-1','','',''),(976026,'deals','.checkbox input + span','border-left-color','$checkbox-border-1','','',''),(976027,'deals','.b-autocomplete .ui-autocomplete','border-left-color','$content-border-1','','','.b-autocomplete'),(976030,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-left-color','$switch-nc-border-1','3','','.b-switch'),(976031,'deals','.b-upload-file .snapshot','border-left-color','$content-border-1','','','.b-upload-file'),(976032,'deals','.w-socials > li','border-left-color','$content-border-1','','','.w-socials'),(976033,'deals','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(976034,'deals','.b-upload-files .upload-files','border-left-color','$content-border-1','','','.b-upload-files'),(976035,'deals','.b-upload-file .upload-file-template','border-left-color','$content-border-1','','','.b-upload-file'),(976036,'deals','.w-promo-code .holder','border-left-color','$content-border-1','','','.w-promo-code'),(976037,'deals','.w-cart-listing .item .gift-wrap label','border-left-color','$content-border-1','','','.w-cart-listing'),(976038,'deals','.w-cart-listing .item','border-left-color','$content-border-1','5639','','.w-cart-listing'),(976040,'deals','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(976041,'deals','.b-dropdown .dropdown .dropdown-menu','border-left-color','$content-border-1','','','.b-dropdown'),(976042,'deals','.w-cart-compare .product-block td:nth-child(1)','border-left-color','$content-border-1','','','.w-cart-compare'),(976043,'deals','.b-data-table table.dataTable.no-footer','border-left-color','$content-border-1','','','.b-data-table'),(976044,'deals','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-left-color','$image-popup-border-1','','','.b-product-images'),(976045,'deals','.b-trade-approval .steps-bar li ~ li a','border-left-color','$content-border-1','','','.b-trade-approval'),(976046,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-color','$content-border-1','','','.b-trade-approval'),(976047,'deals','.w-account-personal-catalog .list-switcher a','border-left-color','$content-border-1','2','','.w-account-personal-catalog'),(976048,'deals','.w-catalog-compare .compare .checkbox input:checked + span','border-left-color','$content-bg-1','','','.w-catalog-compare'),(976049,'deals','.w-catalog-compare .cross-box .different-all > div','border-left-color','$content-border-1','2','','.w-catalog-compare'),(976051,'deals','.b-products-listing .products-listing .compare input + span','border-left-color','$highlight-box-border-2','','','.b-products-listing'),(976052,'deals','.w-quote .cart-content','border-left-color','$content-border-1','','','.w-quote'),(976053,'deals','.b-product-images .additional-images .active img','border-left-color','$image-popup-border-2','','','.b-product-images'),(976054,'deals','.b-product-images .additional-images img','border-left-color','$image-popup-border-1','','','.b-product-images'),(976055,'deals','.b-quantity .qty-box .bigger','border-left-color','$content-border-1','','','.b-quantity'),(976056,'deals','.b-quantity .qty-box .smaller','border-left-color','$content-border-1','','','.b-quantity'),(976057,'deals','.w-sample .cart-content','border-left-color','$content-border-1','','','.w-sample'),(976058,'deals','.w-product-video .item img, .w-product-video .item video','border-left-color','$content-border-1','','','.w-product-video'),(976059,'deals','.w-product-video .item.active img, .w-product-video .item.active video','border-left-color','$highlight-box-border-2','','','.w-product-video'),(976061,'deals','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-left-color','$highlight-box-border-2','','','.b-pagination'),(976062,'deals','.b-pagination .pagination .next-pages','border-left-color','$content-border-1','','','.b-pagination'),(976063,'deals','.b-pagination .pagination .page-number','border-left-color','$content-border-1','','','.b-pagination'),(976064,'deals','.b-pagination .pagination .prev-pages','border-left-color','$content-border-1','','','.b-pagination'),(976065,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-left-color','$content-border-1','','','.b-pagination'),(976066,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-left-color','$content-border-1','','','.b-pagination'),(976067,'deals','.b-pagination .pagination span','border-left-color','$content-border-1','2','','.b-pagination'),(976068,'deals','.w-product-multi-inventory .radio-attributes .option-item','border-left-color','$content-border-1','','','.w-product-multi-inventory'),(976069,'deals','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-left-color','$highlight-box-border-1','','','.w-product-multi-inventory'),(976070,'deals','.b-products-listing .products-listing .radio-attributes .option','border-left-color','$content-border-1','','','.b-products-listing'),(976071,'deals','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-left-color','$highlight-box-border-1','','','.b-products-listing'),(976072,'deals','.w-product-attributes .radio-attributes .option-item','border-left-color','$content-border-1','','','.w-product-attributes'),(976073,'deals','.w-product-attributes .radio-attributes input:checked + .option-item','border-left-color','$highlight-box-border-1','','','.w-product-attributes'),(976074,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-left-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(976075,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-left-color','$highlight-box-border-2','','','.w-questionnaire-widgets-questionnaire'),(976076,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-left-color','$message-border','','','.w-questionnaire-widgets-questionnaire'),(976077,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-left-color','$highlight-box-border-2','1','','.w-questionnaire-widgets-questionnaire'),(976078,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-left-color','$message-border','1','','.w-questionnaire-widgets-questionnaire'),(976079,'deals','.w-product-groups .radioBox label .containerBlock','border-left-color','$content-border-1','','','.w-product-groups'),(976080,'deals','.w-product-groups .radioBox label .containerBlock.selected','border-left-color','$highlight-box-border-2','','','.w-product-groups'),(976081,'deals','.w-product-groups .radioBox label input:checked + .containerBlock','border-left-color','$highlight-box-border-2','','','.w-product-groups'),(976082,'deals','.w-delivery-location-location-list .deliveryList li a','border-left-color','$content-border-1','','','.w-delivery-location-location-list'),(976083,'deals','.w-delivery-location-location-list .deliveryList li a','border-left-color','$highlight-box-border-1','1','','.w-delivery-location-location-list'),(976084,'deals','.w-sale-category .sale-holder','border-left-color','$content-border-1','','','.w-sale-category'),(976085,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-left-color','$content-border-1','','','.w-product-properties-icons'),(976086,'deals','.w-product-designer-designer .prodDesignerType label','border-left-color','$content-border-1','','','.w-product-designer-designer'),(976087,'deals','.b-products-listing .productGroup label a','border-left-color','$highlight-box-border-1','','','.b-products-listing'),(976088,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border-left-color','$highlight-box-border-2','','','.w-predefined-promotion'),(976089,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-left-color','$highlight-box-border-2','','','.w-predefined-promotion'),(976090,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-left-color','$highlight-box-border-2','','','.w-predefined-promotion'),(976091,'deals','.w-predefined-promotion .promo-salemaker .discount','border-left-color','$warning-border','','','.w-predefined-promotion'),(976092,'deals','.w-supplier-purchase-supplier-products .item','border-left-color','$content-border-1','','','.w-supplier-purchase-supplier-products'),(976093,'deals','.w-filters .filter-widget-horizontal .filter-box-content','border-left-color','$content-border-1','','','.w-filters'),(976094,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-left-color','$highlight-box-border-2','','','.b-products-listing'),(976095,'deals','.w-product-groups .property-category-heading + .property-category-content','border-left-color','$content-border-1','','','.w-product-groups'),(976096,'deals','.btn-3','border-left-color','$btn-border-4','','',''),(976097,'deals','.w-product-quantity-discounts .quantity-discounts-content .item','border-left-color','$content-border-1','','','.w-product-quantity-discounts'),(976098,'deals','.w-product-groups .radioBox label .containerBlock','border-left-color','$highlight-box-border-2','1','','.w-product-groups'),(976099,'deals','.order-summary > div','border-left-color','$content-border-1','','','.order-summary'),(976100,'deals','.btn','border-left-color','$btn-border-1','','',''),(976101,'deals','.w-support-system-listing .product_icon','border-left-color','$content-border-1','','','.w-support-system-listing'),(976102,'deals','.w-support-system-listing .support-head','border-left-color','$content-border-1','','','.w-support-system-listing'),(976103,'deals','.w-support-system-listing .support-item-body-content','border-left-color','$content-border-1','','','.w-support-system-listing'),(976104,'deals','.w-support-system-listing .support-item-body .support-item-body-image','border-left-color','$content-border-1','','','.w-support-system-listing'),(976105,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','border-left-color','$content-border-1','5639','','.w-filters'),(976106,'deals','.b-products-listing .pr-groups.active a','border-left-color','$highlight-box-border-1','','','.b-products-listing'),(976107,'deals','.w-product-personal-catalog-button .btn','border-left-color','$highlight-box-border-2','','','.w-product-personal-catalog-button'),(976108,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-left-color','$content-border-1','','','.w-account-personal-catalog'),(976109,'deals','.w-account-personal-catalog .list-row-action ul','border-left-color','$content-border-1','','','.w-account-personal-catalog'),(976112,'deals','.account-samples .orders-table .item','border-left-color','$content-border-1','5639','','.account-samples'),(976113,'deals','.catalog-product-wrap .pn-image','border-left-color','$content-border-1','3','','.catalog-product-wrap'),(976114,'deals','.checkout-index-wrap .input-wrapper','border-left-color','$content-border-1','','','.checkout-index-wrap'),(976115,'deals','.catalog-product-wrap .next-product','border-left-color','$content-border-1','','','.catalog-product-wrap'),(976116,'deals','.w-cart-products .checkout-attention-message','border-left-color','$highlight-box-border-2','','','.w-cart-products'),(976117,'deals','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-color','$highlight-box-border-2','','','.b-multi-page-checkout'),(976118,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-color','$content-border-1','','','.b-multi-page-checkout'),(976119,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-color','$content-border-1','','','.b-multi-page-checkout'),(976120,'deals','.w-catalog-paging ','border-left-color','#CCCCCC','2','','.w-catalog-paging'),(976121,'deals','.w-catalog-paging .next','border-left-color','#CCCCCC','','','.w-catalog-paging'),(976122,'deals','.w-catalog-paging .next-pages','border-left-color','#CCCCCC','','','.w-catalog-paging'),(976123,'deals','.w-catalog-paging .page-number','border-left-color','#CCCCCC','','','.w-catalog-paging'),(976124,'deals','.w-catalog-paging .prev','border-left-color','#CCCCCC','','','.w-catalog-paging'),(976125,'deals','.w-catalog-paging .prev-pages','border-left-color','#CCCCCC','','','.w-catalog-paging'),(976126,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-color','#CCCCCC','','','.w-catalog-paging'),(976127,'deals','.b-data-table table.dataTable.no-footer','border-left-color_important','important','','','.b-data-table'),(976128,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(976129,'deals','.w-promotions .prom-multi-discount .promo-range','border-left-width','1','','','.w-promotions'),(976130,'deals','.w-cart-compare .attributes-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(976133,'deals','.testimonials .review','border-left-width','10','3','',''),(976134,'deals','.w-promotions .promo-salemaker .discount','border-left-width','1','','','.w-promotions'),(976135,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border-left-width','1','','','.w-promotions'),(976136,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border-left-width','1','','','.w-promotions'),(976137,'deals','.b-messages .content_management_attach button','border-left-width','1','','','.b-messages'),(976138,'deals','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-left-width','2','','','.b-messages'),(976139,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-left-width','1','','',''),(976140,'deals','.p-payer-order-confirmation .input-wrapper','border-left-width','2','','','.p-payer-order-confirmation'),(976141,'deals','.p-payer-order-pay .input-wrapper','border-left-width','2','','','.p-payer-order-pay'),(976142,'deals','.w-product-reviews .reviews-list .review','border-left-width','10','3','','.w-product-reviews'),(976143,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-left-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(976144,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border-left-width','2','3','','.b-form'),(976145,'deals','.b-info-popup .info-popup div','border-left-width','1','3','','.b-info-popup'),(976146,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-left-width','2','3','','.b-switch'),(976147,'deals','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(976148,'deals','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-left-width','1','','','.b-bottom'),(976149,'deals','.w-socials > li','border-left-width','1','','','.w-socials'),(976151,'deals','.w-cart-compare .cart-cell > div','border-left-width','1','','','.w-cart-compare'),(976152,'deals','.b-info-popup .info-popup div','border-left-width','1','','','.b-info-popup'),(976153,'deals','.w-socials > li','border-left-width','1','','','.w-socials'),(976154,'deals','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(976155,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-left-width','4','','','.b-switch'),(976156,'deals','.w-filters .ui-slider-handle','border-left-width','0','','','.w-filters'),(976157,'deals','.w-filters .ui-slider','border-left-width','0','','','.w-filters'),(976158,'deals','.w-socials > li','border-left-width','1','','','.w-socials'),(976159,'deals','.w-reviews .review','border-left-width','12','3','','.w-reviews'),(976161,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-left-width','3','','','.b-switch'),(976162,'deals','.w-reviews-content .review','border-left-width','12','3','','.w-reviews-content'),(976163,'deals','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(976164,'deals','.w-socials > li','border-left-width','1','','','.w-socials'),(976165,'deals','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(976166,'deals','.b-select-suggest .select2-container .select2-choice','border-left-width','1','','','.b-select-suggest'),(976167,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-left-width','2','4','','.b-switch'),(976169,'deals','.b-form .required-error','border-left-width','1','','','.b-form'),(976170,'deals','textarea','border-left-width','1','','',''),(976171,'deals','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(976172,'deals','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-left-width','1','','','.b-bottom'),(976173,'deals','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(976174,'deals','.w-cart-compare .product-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(976175,'deals','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(976176,'deals','.b-bottom .popup-box','border-left-width','1','','','.b-bottom'),(976177,'deals','.w-product-customers-activity .customers-activity','border-left-width','1','','','.w-product-customers-activity'),(976178,'deals','.w-cart-compare .price-block td:nth-child(1)','border-left-width','1','','','.w-cart-compare'),(976179,'deals','.w-socials > li','border-left-width','1','','','.w-socials'),(976180,'deals','.w-socials > li','border-left-width','1','','','.w-socials'),(976181,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(976182,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-left-width','1','','','.b-select-suggest'),(976183,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-left-width','1','','','.b-select-suggest'),(976184,'deals','.b-select-suggest .select2-container-multi .select2-choices','border-left-width','1','','','.b-select-suggest'),(976185,'deals','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-left-width','1','','','.b-select-suggest'),(976186,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice .select2-arrow','border-left-width','0','','','.b-select-suggest'),(976187,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-left-width','1','','','.b-select-suggest'),(976188,'deals','.b-select-suggest .select2-search input','border-left-width','1','','','.b-select-suggest'),(976189,'deals','.b-select-suggest .select2-drop-active','border-left-width','1','','','.b-select-suggest'),(976190,'deals','.b-select-suggest .select2-drop','border-left-width','1','','','.b-select-suggest'),(976191,'deals','.b-upload-file .upload-file-template','border-left-width','1','','','.b-upload-file'),(976192,'deals','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(976193,'deals','.checkbox input:checked + span','border-left-width','1','','',''),(976194,'deals','.checkbox input + span','border-left-width','1','','',''),(976195,'deals','.b-autocomplete .ui-autocomplete','border-left-width','1','','','.b-autocomplete'),(976198,'deals','.w-checkout-shipping-choice label:first-child span','border-left-width','2','','','.w-checkout-shipping-choice'),(976199,'deals','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(976200,'deals','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(976201,'deals','.w-cart-listing .item .gift-wrap label','border-left-width','1','','','.w-cart-listing'),(976202,'deals','.w-cart-listing .item','border-left-width','1','5639','','.w-cart-listing'),(976204,'deals','.w-promo-code .holder','border-left-width','1','','','.w-promo-code'),(976205,'deals','.w-filters .ui-slider-range','border-left-width','0','','','.w-filters'),(976206,'deals','.b-dropdown .dropdown .dropdown-menu','border-left-width','1','','','.b-dropdown'),(976207,'deals','.b-upload-files .upload-files','border-left-width','1','','','.b-upload-files'),(976208,'deals','.b-compare .popupCompare td, .b-compare .popupCompare th','border-left-width','1','','','.b-compare'),(976209,'deals','.b-upload-file .snapshot','border-left-width','1','','','.b-upload-file'),(976210,'deals','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-left-width','2','','','.b-product-images'),(976211,'deals','.b-trade-approval .steps-bar li ~ li a','border-left-width','1','','','.b-trade-approval'),(976212,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-left-width','2','','','.b-trade-approval'),(976213,'deals','.w-account-personal-catalog .list-switcher a','border-left-width','1','2','','.w-account-personal-catalog'),(976214,'deals','.w-catalog-compare .compare .checkbox input:checked + span','border-left-width','1','','','.w-catalog-compare'),(976215,'deals','.w-catalog-compare .cross-box .different-all > div','border-left-width','1','2','','.w-catalog-compare'),(976216,'deals','.b-slick .slick-vertical .slick-slide','border-left-width','1','','','.b-slick'),(976217,'deals','.b-products-listing .products-listing .compare input + span','border-left-width','1','','','.b-products-listing'),(976218,'deals','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-left-width','0','','','.w-filters'),(976219,'deals','.w-quote .cart-content','border-left-width','1','','','.w-quote'),(976220,'deals','.b-product-images .additional-images .active img','border-left-width','2','','','.b-product-images'),(976221,'deals','.b-product-images .additional-images img','border-left-width','2','','','.b-product-images'),(976222,'deals','.b-quantity .qty-box .bigger','border-left-width','1','','','.b-quantity'),(976223,'deals','.b-quantity .qty-box .smaller','border-left-width','1','','','.b-quantity'),(976224,'deals','.w-sample .cart-content','border-left-width','1','','','.w-sample'),(976225,'deals','.w-product-video .item img, .w-product-video .item video','border-left-width','2','','','.w-product-video'),(976226,'deals','.w-product-video .item.active img, .w-product-video .item.active video','border-left-width','2','','','.w-product-video'),(976228,'deals','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-left-width','1','','','.b-pagination'),(976229,'deals','.b-pagination .pagination .next-pages','border-left-width','1','','','.b-pagination'),(976230,'deals','.b-pagination .pagination .page-number','border-left-width','1','','','.b-pagination'),(976231,'deals','.b-pagination .pagination .prev-pages','border-left-width','1','','','.b-pagination'),(976232,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-left-width','1','','','.b-pagination'),(976233,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-left-width','1','','','.b-pagination'),(976234,'deals','.b-pagination .pagination span','border-left-width','1','2','','.b-pagination'),(976235,'deals','.w-product-multi-inventory .radio-attributes .option-item','border-left-width','2','','','.w-product-multi-inventory'),(976236,'deals','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-left-width','2','','','.w-product-multi-inventory'),(976237,'deals','.b-products-listing .products-listing .radio-attributes .option','border-left-width','2','','','.b-products-listing'),(976238,'deals','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-left-width','2','','','.b-products-listing'),(976239,'deals','.w-product-attributes .radio-attributes .option-item','border-left-width','2','','','.w-product-attributes'),(976240,'deals','.w-product-attributes .radio-attributes input:checked + .option-item','border-left-width','2','','','.w-product-attributes'),(976241,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-left-width','2','','','.w-questionnaire-widgets-questionnaire'),(976242,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-left-width','2','','','.w-questionnaire-widgets-questionnaire'),(976243,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-left-width','2','','','.w-questionnaire-widgets-questionnaire'),(976244,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-left-width','2','1','','.w-questionnaire-widgets-questionnaire'),(976245,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-left-width','2','1','','.w-questionnaire-widgets-questionnaire'),(976246,'deals','.w-product-groups .radioBox label .containerBlock','border-left-width','2','','','.w-product-groups'),(976247,'deals','.w-product-groups .radioBox label .containerBlock.selected','border-left-width','2','','','.w-product-groups'),(976248,'deals','.w-product-groups .radioBox label input:checked + .containerBlock','border-left-width','2','','','.w-product-groups'),(976249,'deals','.w-delivery-location-location-list .deliveryList li a','border-left-width','2','','','.w-delivery-location-location-list'),(976250,'deals','.w-delivery-location-location-list .deliveryList li a','border-left-width','2','1','','.w-delivery-location-location-list'),(976251,'deals','.w-sale-category .sale-holder','border-left-width','2','','','.w-sale-category'),(976252,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-left-width','1','','','.w-product-properties-icons'),(976253,'deals','.w-product-designer-designer .prodDesignerType label','border-left-width','1','','','.w-product-designer-designer'),(976254,'deals','.b-products-listing .productGroup label a','border-left-width','1','','','.b-products-listing'),(976255,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border-left-width','1','','','.w-predefined-promotion'),(976256,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-left-width','1','','','.w-predefined-promotion'),(976257,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-left-width','1','','','.w-predefined-promotion'),(976258,'deals','.w-predefined-promotion .promo-salemaker .discount','border-left-width','1','','','.w-predefined-promotion'),(976259,'deals','.w-supplier-purchase-supplier-products .item','border-left-width','1','','','.w-supplier-purchase-supplier-products'),(976261,'deals','.headerWrap .searchIcon','border-left-width','1','','','.headerWrap'),(976262,'deals','.w-filters .filter-widget-horizontal .filter-box-content','border-left-width','1','','','.w-filters'),(976263,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-left-width','2','','','.b-products-listing'),(976264,'deals','.w-product-groups .property-category-heading + .property-category-content','border-left-width','1','','','.w-product-groups'),(976265,'deals','.btn-3','border-left-width','2','','',''),(976266,'deals','.w-product-quantity-discounts .quantity-discounts-content .item','border-left-width','1','','','.w-product-quantity-discounts'),(976267,'deals','.w-product-groups .radioBox label .containerBlock','border-left-width','2','1','','.w-product-groups'),(976268,'deals','.order-summary > div','border-left-width','1','','','.order-summary'),(976269,'deals','.btn','border-left-width','2','','',''),(976270,'deals','.w-support-system-listing .product_icon','border-left-width','1','','','.w-support-system-listing'),(976271,'deals','.w-support-system-listing .support-head','border-left-width','1','','','.w-support-system-listing'),(976272,'deals','.w-support-system-listing .support-item-body-content','border-left-width','1','','','.w-support-system-listing'),(976273,'deals','.w-support-system-listing .support-item-body .support-item-body-image','border-left-width','1','','','.w-support-system-listing'),(976274,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','border-left-width','1','5639','','.w-filters'),(976275,'deals','.b-products-listing .pr-groups.active a','border-left-width','1','','','.b-products-listing'),(976276,'deals','.w-product-personal-catalog-button .btn','border-left-width','2','','','.w-product-personal-catalog-button'),(976277,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-left-width','1','','','.w-account-personal-catalog'),(976278,'deals','.w-account-personal-catalog .list-row-action ul','border-left-width','1','','','.w-account-personal-catalog'),(976281,'deals','.account-samples .orders-table .item','border-left-width','1','5639','','.account-samples'),(976282,'deals','.catalog-product-wrap .next-product','border-left-width','1','','','.catalog-product-wrap'),(976283,'deals','.catalog-product-wrap .pn-image','border-left-width','2','3','','.catalog-product-wrap'),(976284,'deals','.checkout-index-wrap .input-wrapper','border-left-width','2','','','.checkout-index-wrap'),(976285,'deals','.w-cart-products .checkout-attention-message','border-left-width','1','','','.w-cart-products'),(976286,'deals','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(976287,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-left-width','2','','','.b-multi-page-checkout'),(976288,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-left-width','1','','','.b-multi-page-checkout'),(976289,'deals','.w-catalog-paging ','border-left-width','1','2','','.w-catalog-paging'),(976290,'deals','.w-catalog-paging .next','border-left-width','1','','','.w-catalog-paging'),(976291,'deals','.w-catalog-paging .next-pages','border-left-width','1','','','.w-catalog-paging'),(976292,'deals','.w-catalog-paging .page-number','border-left-width','1','','','.w-catalog-paging'),(976293,'deals','.w-catalog-paging .prev','border-left-width','1','','','.w-catalog-paging'),(976294,'deals','.w-catalog-paging .prev-pages','border-left-width','1','','','.w-catalog-paging'),(976295,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-left-width','1','','','.w-catalog-paging'),(976296,'deals','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(976297,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border-right-color','$checkbox-border-1','3','','.b-form'),(976298,'deals','.w-promotions .prom-multi-discount .promo-range','border-right-color','$highlight-box-border-2','','','.w-promotions'),(976299,'deals','.w-cart-compare .attributes-block td','border-right-color','$content-border-1','','','.w-cart-compare'),(976301,'deals','.testimonials .review','border-right-color','transparent','3','',''),(976302,'deals','.w-promotions .promo-salemaker .discount','border-right-color','$warning-border','','','.w-promotions'),(976303,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-color','$highlight-box-border-2','','','.w-promotions'),(976304,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border-right-color','$highlight-box-border-2','','','.w-promotions'),(976305,'deals','.w-cart-compare .cart-cell > div','border-right-color','$content-border-1','','','.w-cart-compare'),(976306,'deals','.w-cart-compare .price-block td','border-right-color','$content-border-1','','','.w-cart-compare'),(976307,'deals','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-right-color','$content-border-1','','','.b-bottom'),(976308,'deals','.b-messages .content_management_attach button','border-right-color','$highlight-box-border-1','','','.b-messages'),(976309,'deals','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-color','$content-border-1','','','.b-messages'),(976310,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-right-color','$content-border-1','','',''),(976311,'deals','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(976312,'deals','.p-payer-order-confirmation .input-wrapper','border-right-color','$content-border-1','','','.p-payer-order-confirmation'),(976313,'deals','.p-payer-order-pay .input-wrapper','border-right-color','$content-border-1','','','.p-payer-order-pay'),(976314,'deals','.b-upload-file .upload-file-template','border-right-color','$content-border-1','','','.b-upload-file'),(976315,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-right-color','$switch-nc-border-1','','','.b-switch'),(976316,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(976317,'deals','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(976318,'deals','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-color','$content-border-1','','','.b-compare'),(976319,'deals','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(976320,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(976321,'deals','.w-checkout-shipping-choice label:last-child span','border-right-color','$highlight-box-border-1','','','.w-checkout-shipping-choice'),(976322,'deals','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(976323,'deals','.b-info-popup .info-popup div','border-right-color','$content-border-1','','','.b-info-popup'),(976324,'deals','.w-cart-compare .product-block td','border-right-color','$content-border-1','','','.w-cart-compare'),(976325,'deals','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(976326,'deals','.w-reviews .review','border-right-color','$transparent','3','','.w-reviews'),(976327,'deals','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(976328,'deals','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(976329,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-right-color','$switch-handle-bg-3','','','.b-switch'),(976330,'deals','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(976331,'deals','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(976332,'deals','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(976333,'deals','.w-reviews-content .review','border-right-color','$transparent','3','','.w-reviews-content'),(976334,'deals','.b-select-suggest .select2-container .select2-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(976335,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-right-color','$switch-nc-border-1','4','','.b-switch'),(976337,'deals','.w-socials > li','border-right-color','$content-border-1','','','.w-socials'),(976338,'deals','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-right-color','$content-bg-1','','','.b-bottom'),(976339,'deals','textarea','border-right-color','$content-border-1','','',''),(976340,'deals','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(976341,'deals','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(976342,'deals','.b-bottom .popup-box','border-right-color','$content-border-1','','','.b-bottom'),(976343,'deals','.w-product-customers-activity .customers-activity','border-right-color','$content-border-1','','','.w-product-customers-activity'),(976344,'deals','.w-product-reviews .reviews-list .review','border-right-color','$transparent','3','','.w-product-reviews'),(976345,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-color','$content-border-1','','','.b-select-suggest'),(976346,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(976347,'deals','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-color','$content-border-1','','','.b-select-suggest'),(976348,'deals','.b-select-suggest .select2-container-multi .select2-choices','border-right-color','$content-border-1','','','.b-select-suggest'),(976349,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-color','$content-border-1','','','.b-select-suggest'),(976350,'deals','.b-select-suggest .select2-search input','border-right-color','$content-border-1','','','.b-select-suggest'),(976351,'deals','.b-select-suggest .select2-drop-active','border-right-color','$content-border-1','','','.b-select-suggest'),(976352,'deals','.b-select-suggest .select2-drop','border-right-color','$content-border-1','','','.b-select-suggest'),(976353,'deals','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(976354,'deals','.b-form input.required-error','border-right-color','$attention-border','','','.b-form'),(976355,'deals','.checkbox input:checked + span','border-right-color','$checkbox-border-1','','',''),(976356,'deals','.checkbox input + span','border-right-color','$checkbox-border-1','','',''),(976357,'deals','.b-autocomplete .ui-autocomplete','border-right-color','$content-border-1','','','.b-autocomplete'),(976360,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-right-color','$switch-nc-border-1','3','','.b-switch'),(976361,'deals','.b-upload-file .snapshot','border-right-color','$content-border-1','','','.b-upload-file'),(976362,'deals','.b-dropdown .dropdown .dropdown-menu','border-right-color','$content-border-1','','','.b-dropdown'),(976363,'deals','.b-upload-files .upload-files','border-right-color','$content-border-1','','','.b-upload-files'),(976364,'deals','.b-form .required-error','border-right-color','$attention-border','','','.b-form'),(976365,'deals','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(976366,'deals','.w-cart-listing .item .gift-wrap label','border-right-color','$content-border-1','','','.w-cart-listing'),(976367,'deals','.w-cart-listing .item','border-right-color','$content-border-1','5639','','.w-cart-listing'),(976368,'deals','.w-promo-code .holder','border-right-color','$content-border-1','','','.w-promo-code'),(976370,'deals','.b-data-table table.dataTable.no-footer','border-right-color','$content-border-1','','','.b-data-table'),(976371,'deals','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-right-color','$image-popup-border-1','','','.b-product-images'),(976372,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-color','$content-border-1','','','.b-trade-approval'),(976373,'deals','.w-account-personal-catalog .list-switcher a','border-right-color','$content-border-1','2','','.w-account-personal-catalog'),(976374,'deals','.w-catalog-compare .compare .checkbox input:checked + span','border-right-color','$content-bg-1','','','.w-catalog-compare'),(976375,'deals','.w-catalog-compare .cross-box .different-all > div','border-right-color','$content-border-1','2','','.w-catalog-compare'),(976376,'deals','.w-catalog-compare td:first-child','border-right-color','$content-border-1','','','.w-catalog-compare'),(976378,'deals','.b-products-listing .products-listing .compare input + span','border-right-color','$highlight-box-border-2','','','.b-products-listing'),(976379,'deals','.w-quote .cart-content','border-right-color','$content-border-1','','','.w-quote'),(976380,'deals','.b-product-images .additional-images .active img','border-right-color','$image-popup-border-2','','','.b-product-images'),(976381,'deals','.b-product-images .additional-images img','border-right-color','$image-popup-border-1','','','.b-product-images'),(976382,'deals','.b-quantity .qty-box .bigger','border-right-color','$content-border-1','','','.b-quantity'),(976383,'deals','.b-quantity .qty-box .smaller','border-right-color','$content-border-1','','','.b-quantity'),(976384,'deals','.w-sample .cart-box-link','border-right-color','$highlight-box-border-1','4','','.w-sample'),(976385,'deals','.w-sample .cart-content','border-right-color','$content-border-1','','','.w-sample'),(976386,'deals','.w-product-video .item img, .w-product-video .item video','border-right-color','$content-border-1','','','.w-product-video'),(976387,'deals','.w-product-video .item.active img, .w-product-video .item.active video','border-right-color','$highlight-box-border-2','','','.w-product-video'),(976389,'deals','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-right-color','$highlight-box-border-2','','','.b-pagination'),(976390,'deals','.b-pagination .pagination .next-pages','border-right-color','$content-border-1','','','.b-pagination'),(976391,'deals','.b-pagination .pagination .page-number','border-right-color','$content-border-1','','','.b-pagination'),(976392,'deals','.b-pagination .pagination .prev-pages','border-right-color','$content-border-1','','','.b-pagination'),(976393,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-right-color','$content-border-1','','','.b-pagination'),(976394,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-right-color','$content-border-1','','','.b-pagination'),(976395,'deals','.b-pagination .pagination span','border-right-color','$content-border-1','2','','.b-pagination'),(976396,'deals','.w-product-multi-inventory .radio-attributes .option-item','border-right-color','$content-border-1','','','.w-product-multi-inventory'),(976397,'deals','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-right-color','$highlight-box-border-1','','','.w-product-multi-inventory'),(976398,'deals','.b-products-listing .products-listing .radio-attributes .option','border-right-color','$content-border-1','','','.b-products-listing'),(976399,'deals','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-right-color','$highlight-box-border-1','','','.b-products-listing'),(976400,'deals','.w-product-attributes .radio-attributes .option-item','border-right-color','$content-border-1','','','.w-product-attributes'),(976401,'deals','.w-product-attributes .radio-attributes input:checked + .option-item','border-right-color','$highlight-box-border-1','','','.w-product-attributes'),(976402,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-right-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(976403,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-right-color','$highlight-box-border-2','','','.w-questionnaire-widgets-questionnaire'),(976404,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-right-color','$message-border','','','.w-questionnaire-widgets-questionnaire'),(976405,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-right-color','$highlight-box-border-2','1','','.w-questionnaire-widgets-questionnaire'),(976406,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-right-color','$message-border','1','','.w-questionnaire-widgets-questionnaire'),(976407,'deals','.w-product-groups .radioBox label .containerBlock','border-right-color','$content-border-1','','','.w-product-groups'),(976408,'deals','.w-product-groups .radioBox label .containerBlock.selected','border-right-color','$highlight-box-border-2','','','.w-product-groups'),(976409,'deals','.w-product-groups .radioBox label input:checked + .containerBlock','border-right-color','$highlight-box-border-2','','','.w-product-groups'),(976410,'deals','.w-delivery-location-location-list .deliveryList li a','border-right-color','$content-border-1','','','.w-delivery-location-location-list'),(976411,'deals','.w-delivery-location-location-list .deliveryList li a','border-right-color','$highlight-box-border-1','1','','.w-delivery-location-location-list'),(976412,'deals','.w-sale-category .sale-holder','border-right-color','$content-border-1','','','.w-sale-category'),(976413,'deals','.w-product-designer-designer .prodDesignerType label','border-right-color','$content-border-1','','','.w-product-designer-designer'),(976414,'deals','.b-products-listing .productGroup label a','border-right-color','$highlight-box-border-1','','','.b-products-listing'),(976415,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border-right-color','$highlight-box-border-2','','','.w-predefined-promotion'),(976416,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-right-color','$highlight-box-border-2','','','.w-predefined-promotion'),(976417,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-right-color','$highlight-box-border-2','','','.w-predefined-promotion'),(976418,'deals','.w-predefined-promotion .promo-salemaker .discount','border-right-color','$warning-border','','','.w-predefined-promotion'),(976419,'deals','.w-supplier-purchase-supplier-products .item','border-right-color','$content-border-1','','','.w-supplier-purchase-supplier-products'),(976420,'deals','.w-filters .filter-widget-horizontal .filter-box-content','border-right-color','$content-border-1','','','.w-filters'),(976421,'deals','.filterLine .w-filters','border-right-color','$content-border-1','','','.filterLine'),(976422,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-right-color','$highlight-box-border-2','','','.b-products-listing'),(976423,'deals','.w-product-groups .property-category-heading + .property-category-content','border-right-color','$content-border-1','','','.w-product-groups'),(976424,'deals','.btn-3','border-right-color','$btn-border-4','','',''),(976425,'deals','.w-product-quantity-discounts .quantity-discounts-content .item','border-right-color','$content-border-1','','','.w-product-quantity-discounts'),(976426,'deals','.w-product-groups .radioBox label .containerBlock','border-right-color','$highlight-box-border-2','1','','.w-product-groups'),(976427,'deals','.order-summary > div','border-right-color','$content-border-1','','','.order-summary'),(976428,'deals','.btn','border-right-color','$btn-border-1','','',''),(976429,'deals','.w-support-system-listing .product_icon','border-right-color','$content-border-1','','','.w-support-system-listing'),(976430,'deals','.w-support-system-listing .support-head','border-right-color','$content-border-1','','','.w-support-system-listing'),(976431,'deals','.w-support-system-listing .support-item-body-content','border-right-color','$content-border-1','','','.w-support-system-listing'),(976432,'deals','.w-support-system-listing .support-item-body .support-item-body-image','border-right-color','$content-border-1','','','.w-support-system-listing'),(976433,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','border-right-color','$content-border-1','5639','','.w-filters'),(976434,'deals','.b-products-listing .pr-groups.active a','border-right-color','$highlight-box-border-1','','','.b-products-listing'),(976435,'deals','.w-product-personal-catalog-button .btn','border-right-color','$highlight-box-border-2','','','.w-product-personal-catalog-button'),(976436,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-right-color','$content-border-1','','','.w-account-personal-catalog'),(976437,'deals','.w-account-personal-catalog .list-row-action ul','border-right-color','$content-border-1','','','.w-account-personal-catalog'),(976440,'deals','.account-samples .orders-table .item','border-right-color','$content-border-1','5639','','.account-samples'),(976441,'deals','.catalog-product-wrap .pn-image','border-right-color','$content-border-1','3','','.catalog-product-wrap'),(976442,'deals','.checkout-index-wrap .input-wrapper','border-right-color','$content-border-1','','','.checkout-index-wrap'),(976443,'deals','.w-cart-products .checkout-attention-message','border-right-color','$highlight-box-border-2','','','.w-cart-products'),(976444,'deals','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-color','$highlight-box-border-2','','','.b-multi-page-checkout'),(976445,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-color','$content-border-1','','','.b-multi-page-checkout'),(976446,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-color','$content-border-1','','','.b-multi-page-checkout'),(976447,'deals','.w-catalog-paging ','border-right-color','#CCCCCC','2','','.w-catalog-paging'),(976448,'deals','.w-catalog-paging .next','border-right-color','#CCCCCC','','','.w-catalog-paging'),(976449,'deals','.w-catalog-paging .next-pages','border-right-color','#CCCCCC','','','.w-catalog-paging'),(976450,'deals','.w-catalog-paging .page-number','border-right-color','#CCCCCC','','','.w-catalog-paging'),(976451,'deals','.w-catalog-paging .prev','border-right-color','#CCCCCC','','','.w-catalog-paging'),(976452,'deals','.w-catalog-paging .prev-pages','border-right-color','#CCCCCC','','','.w-catalog-paging'),(976453,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-color','#CCCCCC','','','.w-catalog-paging'),(976454,'deals','.b-data-table table.dataTable.no-footer','border-right-color_important','important','','','.b-data-table'),(976455,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(976456,'deals','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(976457,'deals','.w-promotions .prom-multi-discount .promo-range','border-right-width','1','','','.w-promotions'),(976458,'deals','.w-cart-compare .attributes-block td','border-right-width','1','','','.w-cart-compare'),(976460,'deals','.testimonials .review','border-right-width','10','3','',''),(976461,'deals','.w-promotions .promo-salemaker .discount','border-right-width','1','','','.w-promotions'),(976462,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border-right-width','1','','','.w-promotions'),(976463,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border-right-width','1','','','.w-promotions'),(976464,'deals','.w-cart-compare .cart-cell > div','border-right-width','1','','','.w-cart-compare'),(976465,'deals','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-right-width','1','','','.b-bottom'),(976466,'deals','.b-messages .content_management_attach button','border-right-width','1','','','.b-messages'),(976467,'deals','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-right-width','2','','','.b-messages'),(976468,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-right-width','1','','',''),(976469,'deals','.w-socials > li','border-right-width','1','','','.w-socials'),(976470,'deals','.p-payer-order-confirmation .input-wrapper','border-right-width','2','','','.p-payer-order-confirmation'),(976471,'deals','.p-payer-order-pay .input-wrapper','border-right-width','2','','','.p-payer-order-pay'),(976472,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-right-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(976473,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border-right-width','2','3','','.b-form'),(976474,'deals','.w-socials > li','border-right-width','1','','','.w-socials'),(976475,'deals','.w-socials > li','border-right-width','1','','','.w-socials'),(976478,'deals','.b-info-popup .info-popup div','border-right-width','1','','','.b-info-popup'),(976479,'deals','.w-checkout-shipping-choice label:last-child span','border-right-width','2','','','.w-checkout-shipping-choice'),(976480,'deals','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(976481,'deals','.w-socials > li','border-right-width','1','','','.w-socials'),(976482,'deals','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(976483,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-right-width','4','','','.b-switch'),(976484,'deals','.w-filters .ui-slider-handle','border-right-width','0','','','.w-filters'),(976485,'deals','.w-filters .ui-slider','border-right-width','0','','','.w-filters'),(976486,'deals','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(976487,'deals','.w-socials > li','border-right-width','1','','','.w-socials'),(976488,'deals','.w-reviews .review','border-right-width','12','3','','.w-reviews'),(976489,'deals','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(976490,'deals','.w-product-reviews .reviews-list .review','border-right-width','10','3','','.w-product-reviews'),(976491,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-right-width','3','','','.b-switch'),(976492,'deals','.w-reviews-content .review','border-right-width','12','3','','.w-reviews-content'),(976493,'deals','.w-socials > li','border-right-width','1','','','.w-socials'),(976494,'deals','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(976495,'deals','.b-select-suggest .select2-container .select2-choice','border-right-width','1','','','.b-select-suggest'),(976496,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-right-width','2','4','','.b-switch'),(976498,'deals','.w-cart-compare .product-block td','border-right-width','1','','','.w-cart-compare'),(976499,'deals','.b-form .required-error','border-right-width','1','','','.b-form'),(976500,'deals','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(976501,'deals','textarea','border-right-width','1','','',''),(976502,'deals','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-right-width','1','','','.b-bottom'),(976503,'deals','.b-bottom .popup-box','border-right-width','1','','','.b-bottom'),(976504,'deals','.w-product-customers-activity .customers-activity','border-right-width','1','','','.w-product-customers-activity'),(976505,'deals','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(976506,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(976507,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-right-width','1','','','.b-select-suggest'),(976508,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-right-width','1','','','.b-select-suggest'),(976509,'deals','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-right-width','1','','','.b-select-suggest'),(976510,'deals','.b-select-suggest .select2-container-multi .select2-choices','border-right-width','1','','','.b-select-suggest'),(976511,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-right-width','1','','','.b-select-suggest'),(976512,'deals','.b-select-suggest .select2-search input','border-right-width','1','','','.b-select-suggest'),(976513,'deals','.b-select-suggest .select2-drop','border-right-width','1','','','.b-select-suggest'),(976514,'deals','.b-select-suggest .select2-drop-active','border-right-width','1','','','.b-select-suggest'),(976515,'deals','.w-cart-compare .price-block td','border-right-width','1','','','.w-cart-compare'),(976516,'deals','.b-compare .popupCompare td, .b-compare .popupCompare th','border-right-width','1','','','.b-compare'),(976517,'deals','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(976518,'deals','.checkbox input:checked + span','border-right-width','1','','',''),(976519,'deals','.checkbox input + span','border-right-width','1','','',''),(976520,'deals','.b-autocomplete .ui-autocomplete','border-right-width','1','','','.b-autocomplete'),(976523,'deals','.b-upload-file .upload-file-template','border-right-width','1','','','.b-upload-file'),(976524,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-right-width','2','3','','.b-switch'),(976525,'deals','.b-dropdown .dropdown .dropdown-menu','border-right-width','1','','','.b-dropdown'),(976526,'deals','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(976527,'deals','.w-cart-listing .item .gift-wrap label','border-right-width','1','','','.w-cart-listing'),(976528,'deals','.w-cart-listing .item','border-right-width','1','5639','','.w-cart-listing'),(976530,'deals','.w-promo-code .holder','border-right-width','1','','','.w-promo-code'),(976531,'deals','.w-filters .ui-slider-range','border-right-width','0','','','.w-filters'),(976532,'deals','.b-upload-files .upload-files','border-right-width','1','','','.b-upload-files'),(976533,'deals','.b-upload-file .snapshot','border-right-width','1','','','.b-upload-file'),(976534,'deals','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-right-width','2','','','.b-product-images'),(976535,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-right-width','2','','','.b-trade-approval'),(976536,'deals','.w-account-personal-catalog .list-switcher a','border-right-width','1','2','','.w-account-personal-catalog'),(976537,'deals','.w-catalog-compare .compare .checkbox input:checked + span','border-right-width','1','','','.w-catalog-compare'),(976538,'deals','.w-catalog-compare td:first-child','border-right-width','1','','','.w-catalog-compare'),(976539,'deals','.w-catalog-compare .cross-box .different-all > div','border-right-width','1','2','','.w-catalog-compare'),(976540,'deals','.b-slick .slick-vertical .slick-slide','border-right-width','1','','','.b-slick'),(976541,'deals','.b-products-listing .products-listing .compare input + span','border-right-width','1','','','.b-products-listing'),(976542,'deals','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-right-width','0','','','.w-filters'),(976543,'deals','.w-quote .cart-content','border-right-width','1','','','.w-quote'),(976544,'deals','.b-product-images .additional-images .active img','border-right-width','2','','','.b-product-images'),(976545,'deals','.b-product-images .additional-images img','border-right-width','2','','','.b-product-images'),(976546,'deals','.b-quantity .qty-box .bigger','border-right-width','1','','','.b-quantity'),(976547,'deals','.b-quantity .qty-box .smaller','border-right-width','1','','','.b-quantity'),(976548,'deals','.w-sample .cart-box-link','border-right-width','1','4','','.w-sample'),(976549,'deals','.w-sample .cart-content','border-right-width','1','','','.w-sample'),(976550,'deals','.w-product-video .item img, .w-product-video .item video','border-right-width','2','','','.w-product-video'),(976551,'deals','.w-product-video .item.active img, .w-product-video .item.active video','border-right-width','2','','','.w-product-video'),(976553,'deals','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-right-width','1','','','.b-pagination'),(976554,'deals','.b-pagination .pagination .next-pages','border-right-width','1','','','.b-pagination'),(976555,'deals','.b-pagination .pagination .page-number','border-right-width','1','','','.b-pagination'),(976556,'deals','.b-pagination .pagination .prev-pages','border-right-width','1','','','.b-pagination'),(976557,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-right-width','1','','','.b-pagination'),(976558,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-right-width','1','','','.b-pagination'),(976559,'deals','.b-pagination .pagination span','border-right-width','1','2','','.b-pagination'),(976560,'deals','.w-product-multi-inventory .radio-attributes .option-item','border-right-width','2','','','.w-product-multi-inventory'),(976561,'deals','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-right-width','2','','','.w-product-multi-inventory'),(976562,'deals','.b-products-listing .products-listing .radio-attributes .option','border-right-width','2','','','.b-products-listing'),(976563,'deals','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-right-width','2','','','.b-products-listing'),(976564,'deals','.w-product-attributes .radio-attributes .option-item','border-right-width','2','','','.w-product-attributes'),(976565,'deals','.w-product-attributes .radio-attributes input:checked + .option-item','border-right-width','2','','','.w-product-attributes'),(976566,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-right-width','2','','','.w-questionnaire-widgets-questionnaire'),(976567,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-right-width','2','','','.w-questionnaire-widgets-questionnaire'),(976568,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-right-width','2','','','.w-questionnaire-widgets-questionnaire'),(976569,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-right-width','2','1','','.w-questionnaire-widgets-questionnaire'),(976570,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-right-width','2','1','','.w-questionnaire-widgets-questionnaire'),(976571,'deals','.w-product-groups .radioBox label .containerBlock','border-right-width','2','','','.w-product-groups'),(976572,'deals','.w-product-groups .radioBox label .containerBlock.selected','border-right-width','2','','','.w-product-groups'),(976573,'deals','.w-product-groups .radioBox label input:checked + .containerBlock','border-right-width','2','','','.w-product-groups'),(976574,'deals','.w-delivery-location-location-list .deliveryList li a','border-right-width','2','','','.w-delivery-location-location-list'),(976575,'deals','.w-delivery-location-location-list .deliveryList li a','border-right-width','2','1','','.w-delivery-location-location-list'),(976576,'deals','.w-sale-category .sale-holder','border-right-width','2','','','.w-sale-category'),(976577,'deals','.w-product-designer-designer .prodDesignerType label','border-right-width','1','','','.w-product-designer-designer'),(976578,'deals','.b-products-listing .productGroup label a','border-right-width','1','','','.b-products-listing'),(976579,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border-right-width','1','','','.w-predefined-promotion'),(976580,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-right-width','1','','','.w-predefined-promotion'),(976581,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-right-width','1','','','.w-predefined-promotion'),(976582,'deals','.w-predefined-promotion .promo-salemaker .discount','border-right-width','1','','','.w-predefined-promotion'),(976583,'deals','.w-supplier-purchase-supplier-products .item','border-right-width','1','','','.w-supplier-purchase-supplier-products'),(976585,'deals','.w-filters .filter-widget-horizontal .filter-box-content','border-right-width','1','','','.w-filters'),(976586,'deals','.filterLine .w-filters','border-right-width','1','','','.filterLine'),(976587,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-right-width','2','','','.b-products-listing'),(976588,'deals','.w-product-groups .property-category-heading + .property-category-content','border-right-width','1','','','.w-product-groups'),(976589,'deals','.btn-3','border-right-width','2','','',''),(976590,'deals','.w-product-quantity-discounts .quantity-discounts-content .item','border-right-width','1','','','.w-product-quantity-discounts'),(976591,'deals','.w-product-groups .radioBox label .containerBlock','border-right-width','2','1','','.w-product-groups'),(976592,'deals','.order-summary > div','border-right-width','1','','','.order-summary'),(976593,'deals','.btn','border-right-width','2','','',''),(976594,'deals','.w-support-system-listing .product_icon','border-right-width','1','','','.w-support-system-listing'),(976595,'deals','.w-support-system-listing .support-head','border-right-width','1','','','.w-support-system-listing'),(976596,'deals','.w-support-system-listing .support-item-body-content','border-right-width','1','','','.w-support-system-listing'),(976597,'deals','.w-support-system-listing .support-item-body .support-item-body-image','border-right-width','1','','','.w-support-system-listing'),(976598,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','border-right-width','1','5639','','.w-filters'),(976599,'deals','.filterLine .w-filters','border-right-width','0','5660','','.filterLine'),(976600,'deals','.b-products-listing .pr-groups.active a','border-right-width','1','','','.b-products-listing'),(976601,'deals','.w-product-personal-catalog-button .btn','border-right-width','2','','','.w-product-personal-catalog-button'),(976602,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-right-width','1','','','.w-account-personal-catalog'),(976603,'deals','.w-account-personal-catalog .list-row-action ul','border-right-width','1','','','.w-account-personal-catalog'),(976604,'deals','.headerWrap .w-logo .logo','border-right-width','1','','','.headerWrap'),(976607,'deals','.account-samples .orders-table .item','border-right-width','1','5639','','.account-samples'),(976608,'deals','.catalog-product-wrap .pn-image','border-right-width','2','3','','.catalog-product-wrap'),(976609,'deals','.catalog-product-wrap .prev-product','border-right-width','1','','','.catalog-product-wrap'),(976610,'deals','.checkout-index-wrap .input-wrapper','border-right-width','2','','','.checkout-index-wrap'),(976611,'deals','.w-cart-products .checkout-attention-message','border-right-width','1','','','.w-cart-products'),(976612,'deals','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(976613,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-right-width','2','','','.b-multi-page-checkout'),(976614,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-right-width','1','','','.b-multi-page-checkout'),(976615,'deals','.w-catalog-paging ','border-right-width','1','2','','.w-catalog-paging'),(976616,'deals','.w-catalog-paging .next','border-right-width','1','','','.w-catalog-paging'),(976617,'deals','.w-catalog-paging .next-pages','border-right-width','1','','','.w-catalog-paging'),(976618,'deals','.w-catalog-paging .page-number','border-right-width','1','','','.w-catalog-paging'),(976619,'deals','.w-catalog-paging .prev','border-right-width','1','','','.w-catalog-paging'),(976620,'deals','.w-catalog-paging .prev-pages','border-right-width','1','','','.w-catalog-paging'),(976621,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-right-width','1','','','.w-catalog-paging'),(976622,'deals','.b-select-suggest .select2-drop-active','border-top','none','','','.b-select-suggest'),(976623,'deals','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','border-top','none','','','.order-summary'),(976624,'deals','.order-summary .price-row.ot_gv + .price-row, .order-summary .price-row.ot_coupon + .price-row, .order-summary .price-row.ot_bonus_points + .price-row','border-top','none','','','.order-summary'),(976627,'deals','.account-samples .orders-table','border-top','none','','','.account-samples'),(976628,'deals','.catalog-product-wrap .pn-image','border-top','none','5639','','.catalog-product-wrap'),(976629,'deals','.w-communication-new-topic td','border-top-color','$content-border-1','','','.w-communication-new-topic'),(976630,'deals','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(976631,'deals','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(976632,'deals','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(976633,'deals','.w-promotions .prom-multi-discount .promo-range','border-top-color','$highlight-box-border-2','','','.w-promotions'),(976634,'deals','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(976635,'deals','.w-cart-compare .attributes-block td','border-top-color','$content-border-1','','','.w-cart-compare'),(976637,'deals','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(976638,'deals','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(976639,'deals','.w-promotions .promo-salemaker .discount','border-top-color','$warning-border','','','.w-promotions'),(976640,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-color','$highlight-box-border-2','','','.w-promotions'),(976641,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border-top-color','$highlight-box-border-2','','','.w-promotions'),(976642,'deals','.w-cart-compare .cart-cell > div','border-top-color','$content-border-1','','','.w-cart-compare'),(976643,'deals','.b-upload-file .upload-file-template','border-top-color','$content-border-1','','','.b-upload-file'),(976644,'deals','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-top-color','$content-border-1','','','.b-bottom'),(976645,'deals','.b-messages .messMenuButtonTop','border-top-color','$content-border-1','','','.b-messages'),(976646,'deals','.b-messages .msv_btn','border-top-color','$content-border-1','','','.b-messages'),(976647,'deals','.b-messages .email-heading','border-top-color','$content-border-1','','','.b-messages'),(976648,'deals','.b-messages .dataTable','border-top-color','$content-border-1','','','.b-messages'),(976649,'deals','.b-messages .messages-menu li + li','border-top-color','$content-border-1','','','.b-messages'),(976650,'deals','.b-messages .content_management_attach button','border-top-color','$highlight-box-border-1','','','.b-messages'),(976651,'deals','.b-messages .content_management_attach','border-top-color','$content-border-1','','','.b-messages'),(976652,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-top-color','$content-border-1','','',''),(976653,'deals','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(976654,'deals','.p-payer-order-confirmation .input-wrapper','border-top-color','$content-border-1','','','.p-payer-order-confirmation'),(976655,'deals','.p-payer-order-pay .input-wrapper','border-top-color','$content-border-1','','','.p-payer-order-pay'),(976656,'deals','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(976657,'deals','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(976658,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-color','$switch-nc-border-1','','','.b-switch'),(976659,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-color','$content-border-1','','','.w-upload-customer-id-upload-customer-id-form'),(976660,'deals','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(976661,'deals','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-color','$content-border-1','','','.b-compare'),(976662,'deals','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(976663,'deals','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(976664,'deals','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(976665,'deals','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(976666,'deals','.w-checkout-shipping-choice span','border-top-color','$highlight-box-border-1','','','.w-checkout-shipping-choice'),(976667,'deals','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(976668,'deals','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(976669,'deals','.b-info-popup .info-popup div','border-top-color','$content-border-1','','','.b-info-popup'),(976670,'deals','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(976671,'deals','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(976672,'deals','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(976673,'deals','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(976674,'deals','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(976676,'deals','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(976678,'deals','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(976679,'deals','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(976680,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-color','$switch-handle-bg-3','','','.b-switch'),(976681,'deals','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-color','$content-border-1','','','.b-messages'),(976682,'deals','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(976683,'deals','.w-reviews .review','border-top-color','$transparent','3','','.w-reviews'),(976684,'deals','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(976685,'deals','.w-reviews-content .review','border-top-color','$transparent','3','','.w-reviews-content'),(976687,'deals','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(976688,'deals','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(976689,'deals','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(976690,'deals','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(976691,'deals','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(976692,'deals','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(976693,'deals','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(976694,'deals','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(976695,'deals','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(976696,'deals','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(976697,'deals','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(976698,'deals','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(976699,'deals','.w-checkout-shipping .sub-item + .sub-item','border-top-color','$content-border-1','','','.w-checkout-shipping'),(976700,'deals','.b-form .required-error','border-top-color','$attention-border','','','.b-form'),(976701,'deals','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(976702,'deals','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(976703,'deals','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(976704,'deals','.b-select-suggest .select2-container .select2-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(976706,'deals','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(976707,'deals','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(976708,'deals','textarea','border-top-color','$content-border-1','','',''),(976709,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-color','$switch-nc-border-1','4','','.b-switch'),(976710,'deals','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(976711,'deals','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(976713,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border-top-color','$checkbox-border-1','3','','.b-form'),(976714,'deals','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(976715,'deals','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(976716,'deals','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(976717,'deals','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(976718,'deals','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-top-color','$content-bg-1','','','.b-bottom'),(976720,'deals','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(976721,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(976722,'deals','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(976723,'deals','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(976724,'deals','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(976725,'deals','.w-cart-compare .product-block td','border-top-color','$content-border-1','','','.w-cart-compare'),(976726,'deals','.b-bottom .popup-box','border-top-color','$content-border-1','','','.b-bottom'),(976727,'deals','.b-dropdown .dropdown .dropdown-menu','border-top-color','$content-border-1','','','.b-dropdown'),(976728,'deals','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(976729,'deals','.w-product-customers-activity .customers-activity','border-top-color','$content-border-1','','','.w-product-customers-activity'),(976730,'deals','.b-email .model','border-top-color','$content-border-1','','','.b-email'),(976731,'deals','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(976732,'deals','.w-cart-compare .price-block td','border-top-color','$content-border-1','','','.w-cart-compare'),(976733,'deals','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(976734,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-color','$content-border-1','','','.b-select-suggest'),(976735,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(976736,'deals','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-color','$content-border-1','','','.b-select-suggest'),(976737,'deals','.b-select-suggest .select2-container-multi .select2-choices','border-top-color','$content-border-1','','','.b-select-suggest'),(976738,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-color','$content-border-1','','','.b-select-suggest'),(976740,'deals','.b-select-suggest .select2-search input','border-top-color','$content-border-1','','','.b-select-suggest'),(976741,'deals','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-color','$content-border-1','','','.b-select-suggest'),(976742,'deals','.b-select-suggest .select2-drop.select2-drop-above','border-top-color','$content-border-1','','','.b-select-suggest'),(976743,'deals','.b-select-suggest .select2-drop-active','border-top-color','$content-border-1','','','.b-select-suggest'),(976744,'deals','.b-select-suggest .select2-drop','border-top-color','$content-border-1','','','.b-select-suggest'),(976745,'deals','.b-select-suggest .select2-drop-auto-width','border-top-color','$content-border-1','','','.b-select-suggest'),(976746,'deals','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(976747,'deals','.b-form input.required-error','border-top-color','$attention-border','','','.b-form'),(976748,'deals','.w-communication-post .communication-post','border-top-color','$content-border-1','','','.w-communication-post'),(976749,'deals','.checkbox input:checked + span','border-top-color','$checkbox-border-1','','',''),(976750,'deals','.checkbox input + span','border-top-color','$checkbox-border-1','','',''),(976751,'deals','.b-autocomplete .ui-autocomplete','border-top-color','$content-border-1','','','.b-autocomplete'),(976754,'deals','.b-info-popup .info-popup div','border-top-color','$content-border-1','3','','.b-info-popup'),(976755,'deals','.w-socials > li','border-top-color','$content-border-1','','','.w-socials'),(976756,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-color','$switch-nc-border-1','3','','.b-switch'),(976757,'deals','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(976758,'deals','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(976759,'deals','.b-email .name','border-top-color','$content-border-1','','','.b-email'),(976760,'deals','.w-product-reviews .reviews-list .review','border-top-color','$content-border-1','3','','.w-product-reviews'),(976761,'deals','.b-email .price','border-top-color','$content-border-1','','','.b-email'),(976762,'deals','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(976763,'deals','.w-promo-code .holder','border-top-color','$content-border-1','','','.w-promo-code'),(976764,'deals','.b-email .image','border-top-color','$content-border-1','','','.b-email'),(976765,'deals','.w-cart-listing .item .gift-wrap label','border-top-color','$content-border-1','','','.w-cart-listing'),(976766,'deals','.w-cart-listing .item','border-top-color','$content-border-1','5639','','.w-cart-listing'),(976768,'deals','.b-social-login .social-login-text-2','border-top-color','$content-border-1','4','','.b-social-login'),(976769,'deals','.b-tracking-numbers .tracking-numbers td','border-top-color','$content-border-1','','','.b-tracking-numbers'),(976770,'deals','.b-upload-files .added-file','border-top-color','$content-border-1','','','.b-upload-files'),(976771,'deals','.b-data-table table.dataTable.no-footer','border-top-color','$content-border-1','','','.b-data-table'),(976772,'deals','.b-data-table table.dataTable tbody td','border-top-color','$content-border-1','','','.b-data-table'),(976773,'deals','.b-upload-files .upload-files','border-top-color','$content-border-1','','','.b-upload-files'),(976774,'deals','.b-social-login .social-login-text-2','border-top-color','$content-border-1','3','','.b-social-login'),(976775,'deals','.b-email .totals-table','border-top-color','$content-border-1','','','.b-email'),(976776,'deals','.b-email .qty','border-top-color','$content-border-1','','','.b-email'),(976777,'deals','.b-upload-file .snapshot','border-top-color','$content-border-1','','','.b-upload-file'),(976778,'deals','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-top-color','$image-popup-border-1','','','.b-product-images'),(976779,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-color','$content-border-1','','','.b-trade-approval'),(976780,'deals','.w-account-personal-catalog .list-switcher a','border-top-color','$highlight-box-border-1','2','','.w-account-personal-catalog'),(976781,'deals','.w-account-subscription .subscription-variant + .subscription-variant','border-top-color','$content-border-1','','','.w-account-subscription'),(976782,'deals','.w-catalog-compare .compare .checkbox input:checked + span','border-top-color','$content-bg-1','','','.w-catalog-compare'),(976783,'deals','.w-catalog-compare .cross-box .different-all > div','border-top-color','$highlight-box-border-1','2','','.w-catalog-compare'),(976784,'deals','.w-delivery-day .left-text-left','border-top-color','$content-border-1','','','.w-delivery-day'),(976785,'deals','.w-delivery-day .left-text-right','border-top-color','$content-border-1','','','.w-delivery-day'),(976787,'deals','.b-products-listing .products-listing .compare input + span','border-top-color','$highlight-box-border-2','','','.b-products-listing'),(976788,'deals','.w-quote .cart-content','border-top-color','$content-border-1','','','.w-quote'),(976789,'deals','.b-product-images .additional-images .active img','border-top-color','$image-popup-border-2','','','.b-product-images'),(976790,'deals','.b-product-images .additional-images img','border-top-color','$image-popup-border-1','','','.b-product-images'),(976791,'deals','.b-quantity .qty-box .bigger','border-top-color','$content-border-1','','','.b-quantity'),(976792,'deals','.b-quantity .qty-box .smaller','border-top-color','$content-border-1','','','.b-quantity'),(976793,'deals','.w-product-sale-ends .left-text-left','border-top-color','$content-border-1','','','.w-product-sale-ends'),(976794,'deals','.w-product-sale-ends .left-text-right','border-top-color','$content-border-1','','','.w-product-sale-ends'),(976795,'deals','.w-files-catalog-widgets-files-list .item + .item','border-top-color','$content-border-1','','','.w-files-catalog-widgets-files-list'),(976796,'deals','.w-sample .cart-content','border-top-color','$content-border-1','','','.w-sample'),(976797,'deals','.w-product-video .item img, .w-product-video .item video','border-top-color','$content-border-1','','','.w-product-video'),(976798,'deals','.w-product-video .item.active img, .w-product-video .item.active video','border-top-color','$highlight-box-border-2','','','.w-product-video'),(976799,'deals','.w-product-bundle .bundle_item:nth-child(3) ~ .bundle_item','border-top-color','$content-border-1','','','.w-product-bundle'),(976800,'deals','.w-product-bundle .bundle-total-price','border-top-color','$content-border-1','','','.w-product-bundle'),(976801,'deals','.w-product-bundle .bundle_item:nth-child(2) ~ .bundle_item','border-top-color','$content-border-1','5639','','.w-product-bundle'),(976802,'deals','.w-product-bundle .bundle_item:nth-child(1) ~ .bundle_item','border-top-color','$content-border-1','5630','','.w-product-bundle'),(976803,'deals','.w-product-in-bundles .bundle-total-price','border-top-color','$content-border-1','','','.w-product-in-bundles'),(976804,'deals','.w-product-in-bundles .bundle_item:nth-child(3) ~ .bundle_item','border-top-color','$content-border-1','','','.w-product-in-bundles'),(976805,'deals','.w-product-in-bundles .bundle_item:nth-child(2) ~ .bundle_item','border-top-color','$content-border-1','5639','','.w-product-in-bundles'),(976806,'deals','.w-product-in-bundles .bundle_item:nth-child(1) ~ .bundle_item','border-top-color','$content-border-1','5630','','.w-product-in-bundles'),(976808,'deals','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-top-color','$highlight-box-border-2','','','.b-pagination'),(976809,'deals','.b-pagination .pagination .next-pages','border-top-color','$content-border-1','','','.b-pagination'),(976810,'deals','.b-pagination .pagination .page-number','border-top-color','$content-border-1','','','.b-pagination'),(976811,'deals','.b-pagination .pagination .prev-pages','border-top-color','$content-border-1','','','.b-pagination'),(976812,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-top-color','$content-border-1','','','.b-pagination'),(976813,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-top-color','$content-border-1','','','.b-pagination'),(976814,'deals','.b-pagination .pagination span','border-top-color','$content-border-1','2','','.b-pagination'),(976816,'deals','.w-product-multi-inventory .radio-attributes .option-item','border-top-color','$content-border-1','','','.w-product-multi-inventory'),(976817,'deals','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-top-color','$highlight-box-border-1','','','.w-product-multi-inventory'),(976818,'deals','.b-products-listing .products-listing .radio-attributes .option','border-top-color','$content-border-1','','','.b-products-listing'),(976819,'deals','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-top-color','$highlight-box-border-1','','','.b-products-listing'),(976820,'deals','.w-product-collection .choose-products','border-top-color','$content-border-1','','','.w-product-collection'),(976821,'deals','.w-product-attributes .radio-attributes .option-item','border-top-color','$content-border-1','','','.w-product-attributes'),(976822,'deals','.w-product-attributes .radio-attributes input:checked + .option-item','border-top-color','$highlight-box-border-1','','','.w-product-attributes'),(976823,'deals','.w-questionnaire-widgets-questionnaire .question + .question','border-top-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(976824,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-color','$content-border-1','','','.w-questionnaire-widgets-questionnaire'),(976825,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-top-color','$highlight-box-border-2','','','.w-questionnaire-widgets-questionnaire'),(976826,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-top-color','$message-border','','','.w-questionnaire-widgets-questionnaire'),(976827,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-top-color','$highlight-box-border-2','1','','.w-questionnaire-widgets-questionnaire'),(976828,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-top-color','$message-border','1','','.w-questionnaire-widgets-questionnaire'),(976829,'deals','.w-product-groups .radioBox label .containerBlock','border-top-color','$content-border-1','','','.w-product-groups'),(976830,'deals','.w-product-groups .radioBox label .containerBlock.selected','border-top-color','$highlight-box-border-2','','','.w-product-groups'),(976831,'deals','.w-product-groups .radioBox label input:checked + .containerBlock','border-top-color','$highlight-box-border-2','','','.w-product-groups'),(976832,'deals','.w-product-custom-bundle .choose-products','border-top-color','$content-border-1','','','.w-product-custom-bundle'),(976833,'deals','.w-product-custom-bundle .right-area .price','border-top-color','$content-border-1','5639','','.w-product-custom-bundle'),(976834,'deals','.w-delivery-location-location-list .deliveryList li a','border-top-color','$content-border-1','','','.w-delivery-location-location-list'),(976835,'deals','.w-delivery-location-location-list .deliveryList li a','border-top-color','$highlight-box-border-1','1','','.w-delivery-location-location-list'),(976836,'deals','.w-sale-category .left-text-left','border-top-color','$content-border-1','','','.w-sale-category'),(976837,'deals','.w-sale-category .left-text-right','border-top-color','$content-border-1','','','.w-sale-category'),(976838,'deals','.w-sale-category .sale-holder','border-top-color','$content-border-1','','','.w-sale-category'),(976839,'deals','.w-delivery-location-list-by-page .item','border-top-color','$content-border-1','','','.w-delivery-location-list-by-page'),(976840,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-top-color','$content-border-1','','','.w-product-properties-icons'),(976841,'deals','.w-delivery-location-cross-pages .item','border-top-color','$content-border-1','','','.w-delivery-location-cross-pages'),(976842,'deals','.w-product-designer-designer .prodDesignerType label','border-top-color','$content-border-1','','','.w-product-designer-designer'),(976843,'deals','.w-press-reviews-widgets-press-reviews .press-reviews-button','border-top-color','$content-border-1','','','.w-press-reviews-widgets-press-reviews'),(976844,'deals','.b-products-listing .productGroup label a','border-top-color','$highlight-box-border-1','','','.b-products-listing'),(976845,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-color','$highlight-box-border-2','','','.w-predefined-promotion'),(976846,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-color','$highlight-box-border-2','','','.w-predefined-promotion'),(976847,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-color','$highlight-box-border-2','','','.w-predefined-promotion'),(976848,'deals','.w-predefined-promotion .promo-salemaker .discount','border-top-color','$warning-border','','','.w-predefined-promotion'),(976849,'deals','.w-supplier-purchase-supplier-products .item','border-top-color','$content-border-1','','','.w-supplier-purchase-supplier-products'),(976850,'deals','.filterLine ','border-top-color','$content-border-1','','','.filterLine'),(976851,'deals','.w-filters .filter-widget-horizontal .filter-box-content','border-top-color','$content-border-1','','','.w-filters'),(976852,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-top-color','$highlight-box-border-2','','','.b-products-listing'),(976853,'deals','.w-product-groups .property-category-heading + .property-category-content','border-top-color','$content-border-1','','','.w-product-groups'),(976854,'deals','.btn-3','border-top-color','$btn-border-4','','',''),(976855,'deals','.w-product-quantity-discounts .quantity-discounts-content .item','border-top-color','$content-border-1','','','.w-product-quantity-discounts'),(976856,'deals','.w-product-groups .radioBox label .containerBlock','border-top-color','$highlight-box-border-2','1','','.w-product-groups'),(976857,'deals','.order-summary > div','border-top-color','$content-border-1','','','.order-summary'),(976858,'deals','.btn','border-top-color','$btn-border-1','','',''),(976859,'deals','.w-support-system-listing .product_icon','border-top-color','$content-border-1','','','.w-support-system-listing'),(976860,'deals','.w-support-system-listing .support-head','border-top-color','$content-border-1','','','.w-support-system-listing'),(976861,'deals','.w-support-system-listing .support-item-body-content','border-top-color','$content-border-1','','','.w-support-system-listing'),(976862,'deals','.w-support-system-listing .support-item-body .support-item-body-image','border-top-color','$content-border-1','','','.w-support-system-listing'),(976863,'deals','.b-table-list .table-list td','border-top-color','$content-border-1','','','.b-table-list'),(976864,'deals','.b-table .table .headings + tr ~ tr td','border-top-color','$content-border-1','','','.b-table'),(976865,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','border-top-color','$content-border-1','5639','','.w-filters'),(976866,'deals','.w-filters .filter-widget-horizontal .filter-box-head','border-top-color','$content-border-1','5639','','.w-filters'),(976867,'deals','.b-products-listing .products-listing.list-b2b .item .BlockBox.item-holder, .b-products-listing .products-listing.list-rows .BlockBox.item-holder','border-top-color','$content-border-1','','','.b-products-listing'),(976868,'deals','.b-products-listing .pr-groups.active a','border-top-color','$highlight-box-border-1','','','.b-products-listing'),(976869,'deals','.b-info div + .info','border-top-color','$content-border-1','','','.b-info'),(976870,'deals','.w-product-personal-catalog-button .btn','border-top-color','$highlight-box-border-2','','','.w-product-personal-catalog-button'),(976871,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-top-color','$content-border-1','','','.w-account-personal-catalog'),(976872,'deals','.w-account-personal-catalog .list-row-action ul','border-top-color','$content-border-1','','','.w-account-personal-catalog'),(976873,'deals','.order-summary .price-row + .price-row','border-top-color','$content-border-1','','','.order-summary'),(976876,'deals','.account-samples .orders-table .item','border-top-color','$content-border-1','5639','','.account-samples'),(976877,'deals','.catalog-product-wrap .pn-image','border-top-color','$content-border-1','3','','.catalog-product-wrap'),(976878,'deals','.checkout-index-wrap .input-wrapper','border-top-color','$content-border-1','','','.checkout-index-wrap'),(976879,'deals','.w-cart-products .checkout-attention-message','border-top-color','$highlight-box-border-2','','','.w-cart-products'),(976880,'deals','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-color','$highlight-box-border-2','','','.b-multi-page-checkout'),(976881,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-color','$content-border-1','','','.b-multi-page-checkout'),(976882,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-color','$content-border-1','','','.b-multi-page-checkout'),(976883,'deals','.w-catalog-paging ','border-top-color','#CCCCCC','2','','.w-catalog-paging'),(976884,'deals','.w-catalog-paging .next','border-top-color','#CCCCCC','','','.w-catalog-paging'),(976885,'deals','.w-catalog-paging .next-pages','border-top-color','#CCCCCC','','','.w-catalog-paging'),(976886,'deals','.w-catalog-paging .page-number','border-top-color','#CCCCCC','','','.w-catalog-paging'),(976887,'deals','.w-catalog-paging .prev','border-top-color','#CCCCCC','','','.w-catalog-paging'),(976888,'deals','.w-catalog-paging .prev-pages','border-top-color','#CCCCCC','','','.w-catalog-paging'),(976889,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-color','#CCCCCC','','','.w-catalog-paging'),(976891,'deals','.w-menu-slider > ul > li > ul','border-top-color','$content-border-1','','','.w-menu-slider'),(976892,'deals','.b-data-table table.dataTable.no-footer','border-top-color_important','important','','','.b-data-table'),(976893,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-top-left-radius','0','4','','.b-switch'),(976894,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.p-quick-order-index'),(976895,'deals','.w-promotions .prom-multi-discount .promo-range','border-top-left-radius','12','','','.w-promotions'),(976896,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.p-quick-order-index'),(976897,'deals','.w-promotions .promo-salemaker .discount','border-top-left-radius','12','','','.w-promotions'),(976898,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-left-radius','12','','','.w-promotions'),(976899,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border-top-left-radius','12','','','.w-promotions'),(976900,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-left-radius','5','','','.b-messages'),(976901,'deals','.b-fancybox .fancybox-close','border-top-left-radius','50','','','.b-fancybox'),(976902,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-left-radius','25','','','.b-switch'),(976903,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-top-left-radius','0','3','','.b-switch'),(976904,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-left-radius','15','3','','.b-switch'),(976905,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(976906,'deals','.b-switch .bootstrap-switch','border-top-left-radius','14','','','.b-switch'),(976907,'deals','.b-switch .candlestick-wrapper .candlestick-bg','border-top-left-radius','15','','','.b-switch'),(976908,'deals','.w-checkout-shipping-choice label:first-child span','border-top-left-radius','16','','','.w-checkout-shipping-choice'),(976909,'deals','.w-checkout-shipping-choice label:last-child span','border-top-left-radius','0','','','.w-checkout-shipping-choice'),(976910,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-left-radius','25','','','.b-switch'),(976911,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border-top-left-radius','50','3','','.b-form'),(976912,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-top-left-radius','50','3','','.b-switch'),(976913,'deals','.b-fancybox .fancybox-title-float-wrap .child','border-top-left-radius','15','','','.b-fancybox'),(976914,'deals','.b-fancybox .fancybox-skin','border-top-left-radius','4','','','.b-fancybox'),(976915,'deals','.w-personal-gift-status-bar .progress-bar','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(976916,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-left-radius','15','4','','.b-switch'),(976917,'deals','.w-personal-gift-status-bar .progress-bar-content','border-top-left-radius','4','','','.w-personal-gift-status-bar'),(976918,'deals','.b-fancybox .fancybox-nav span','border-top-left-radius','50','','','.b-fancybox'),(976919,'deals','.w-product-customers-activity .close','border-top-left-radius','50','','','.w-product-customers-activity'),(976920,'deals','.w-product-customers-activity .customers-activity','border-top-left-radius','10','','','.w-product-customers-activity'),(976921,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-left-radius','0','','','.b-data-table'),(976922,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-left-radius','0','','','.b-data-table'),(976923,'deals','.b-products-listing .promos-info .promo-name','border-top-left-radius','0','','','.b-products-listing'),(976924,'deals','.b-upload-file .snapshot','border-top-left-radius','50','','','.b-upload-file'),(976925,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-left-radius','10','3','','.b-switch'),(976926,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-top-left-radius','0','','','.b-product-images'),(976927,'deals','.b-trade-approval .steps-bar','border-top-left-radius','18','','','.b-trade-approval'),(976928,'deals','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-left-radius','3','','','.w-delivery-day'),(976929,'deals','.w-delivery-day .left-count','border-top-left-radius','3','','','.w-delivery-day'),(976932,'deals','.w-quote .cart-box-link','border-top-left-radius','50','3','','.w-quote'),(976933,'deals','.w-product-sale-ends .left-count','border-top-left-radius','3','','','.w-product-sale-ends'),(976934,'deals','.w-product-sale-ends .left-count-days','border-top-left-radius','3','','','.w-product-sale-ends'),(976935,'deals','.w-product-sale-ends .left-count-hours','border-top-left-radius','3','','','.w-product-sale-ends'),(976936,'deals','.w-sample .cart-box-link','border-top-left-radius','50','3','','.w-sample'),(976937,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-left-radius','50','','','.w-questionnaire-widgets-questionnaire'),(976938,'deals','.w-sale-category .badge','border-top-left-radius','50','','','.w-sale-category'),(976939,'deals','.w-sale-category .left-count','border-top-left-radius','3','','','.w-sale-category'),(976940,'deals','.w-sale-category .left-count-days','border-top-left-radius','3','','','.w-sale-category'),(976941,'deals','.w-sale-category .left-count-hours','border-top-left-radius','3','','','.w-sale-category'),(976942,'deals','.b-products-listing .productGroup label a','border-top-left-radius','3','','','.b-products-listing'),(976943,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-left-radius','12','','','.w-predefined-promotion'),(976944,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-left-radius','12','','','.w-predefined-promotion'),(976945,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-left-radius','12','','','.w-predefined-promotion'),(976946,'deals','.w-predefined-promotion .promo-salemaker .discount','border-top-left-radius','12','','','.w-predefined-promotion'),(976950,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-left-radius','50','','','.b-slick'),(976951,'deals','.w-product-groups .radioBox label .containerBlock','border-top-left-radius','5','','','.w-product-groups'),(976953,'deals','.catalog-product-wrap .pn-image','border-top-left-radius','50','3','','.catalog-product-wrap'),(976954,'deals','.b-slick .slick-dots li','border-top-left-radius','50','3','','.b-slick'),(976955,'deals','.success-page .w-cart-listing .qty','border-top-left-radius','50','','','.success-page'),(976956,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-left-radius','50','','','.b-multi-page-checkout'),(976957,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-left-radius','50','3','','.b-multi-page-checkout'),(976958,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-left-radius','0','','','.w-catalog-paging'),(976959,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border-top-right-radius','0','4','','.b-switch'),(976960,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.p-quick-order-index'),(976961,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.p-quick-order-index'),(976962,'deals','.w-promotions .prom-multi-discount .promo-range','border-top-right-radius','12','','','.w-promotions'),(976963,'deals','.w-promotions .promo-salemaker .discount','border-top-right-radius','12','','','.w-promotions'),(976964,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-right-radius','12','','','.w-promotions'),(976965,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border-top-right-radius','12','','','.w-promotions'),(976966,'deals','.b-upload-file .snapshot','border-top-right-radius','50','','','.b-upload-file'),(976967,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border-top-right-radius','5','','','.b-messages'),(976968,'deals','.w-personal-gift-status-bar .progress-bar','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(976969,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border-top-right-radius','50','3','','.b-form'),(976970,'deals','.b-fancybox .fancybox-close','border-top-right-radius','50','','','.b-fancybox'),(976971,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-right-radius','25','','','.b-switch'),(976972,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border-top-right-radius','0','3','','.b-switch'),(976973,'deals','.b-switch .bootstrap-switch','border-top-right-radius','14','','','.b-switch'),(976974,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-right-radius','15','3','','.b-switch'),(976975,'deals','.b-switch .candlestick-wrapper .candlestick-bg','border-top-right-radius','15','','','.b-switch'),(976976,'deals','.w-checkout-shipping-choice label:last-child span','border-top-right-radius','16','','','.w-checkout-shipping-choice'),(976977,'deals','.w-checkout-shipping-choice label:first-child span','border-top-right-radius','0','','','.w-checkout-shipping-choice'),(976978,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-right-radius','25','','','.b-switch'),(976979,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border-top-right-radius','50','3','','.b-switch'),(976980,'deals','.b-fancybox .fancybox-title-float-wrap .child','border-top-right-radius','15','','','.b-fancybox'),(976981,'deals','.b-fancybox .fancybox-skin','border-top-right-radius','4','','','.b-fancybox'),(976982,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-right-radius','15','4','','.b-switch'),(976983,'deals','.b-fancybox .fancybox-nav span','border-top-right-radius','50','','','.b-fancybox'),(976984,'deals','.w-product-customers-activity .close','border-top-right-radius','50','','','.w-product-customers-activity'),(976985,'deals','.w-product-customers-activity .customers-activity','border-top-right-radius','10','','','.w-product-customers-activity'),(976986,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border-top-right-radius','0','','','.b-data-table'),(976987,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border-top-right-radius','0','','','.b-data-table'),(976988,'deals','.b-products-listing .promos-info .promo-name','border-top-right-radius','8','','','.b-products-listing'),(976989,'deals','.w-personal-gift-status-bar .progress-bar-content','border-top-right-radius','4','','','.w-personal-gift-status-bar'),(976990,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(976991,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border-top-right-radius','10','3','','.b-switch'),(976992,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border-top-right-radius','0','','','.b-product-images'),(976993,'deals','.b-trade-approval .steps-bar','border-top-right-radius','18','','','.b-trade-approval'),(976994,'deals','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border-top-right-radius','3','','','.w-delivery-day'),(976995,'deals','.w-delivery-day .left-count','border-top-right-radius','3','','','.w-delivery-day'),(976998,'deals','.w-quote .cart-box-link','border-top-right-radius','50','3','','.w-quote'),(976999,'deals','.w-product-sale-ends .left-count','border-top-right-radius','3','','','.w-product-sale-ends'),(977000,'deals','.w-product-sale-ends .left-count-days','border-top-right-radius','3','','','.w-product-sale-ends'),(977001,'deals','.w-product-sale-ends .left-count-hours','border-top-right-radius','3','','','.w-product-sale-ends'),(977002,'deals','.w-sample .cart-box-link','border-top-right-radius','50','3','','.w-sample'),(977003,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-right-radius','50','','','.w-questionnaire-widgets-questionnaire'),(977004,'deals','.w-sale-category .badge','border-top-right-radius','50','','','.w-sale-category'),(977005,'deals','.w-sale-category .left-count','border-top-right-radius','3','','','.w-sale-category'),(977006,'deals','.w-sale-category .left-count-days','border-top-right-radius','3','','','.w-sale-category'),(977007,'deals','.w-sale-category .left-count-hours','border-top-right-radius','3','','','.w-sale-category'),(977008,'deals','.b-products-listing .productGroup label a','border-top-right-radius','3','','','.b-products-listing'),(977009,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-right-radius','12','','','.w-predefined-promotion'),(977010,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-right-radius','12','','','.w-predefined-promotion'),(977011,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-right-radius','12','','','.w-predefined-promotion'),(977012,'deals','.w-predefined-promotion .promo-salemaker .discount','border-top-right-radius','12','','','.w-predefined-promotion'),(977016,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','border-top-right-radius','50','','','.b-slick'),(977017,'deals','.w-product-groups .radioBox label .containerBlock','border-top-right-radius','5','','','.w-product-groups'),(977019,'deals','.catalog-product-wrap .pn-image','border-top-right-radius','50','3','','.catalog-product-wrap'),(977020,'deals','.b-slick .slick-dots li','border-top-right-radius','50','3','','.b-slick'),(977021,'deals','.success-page .w-cart-listing .qty','border-top-right-radius','50','','','.success-page'),(977022,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-right-radius','50','','','.b-multi-page-checkout'),(977023,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border-top-right-radius','50','3','','.b-multi-page-checkout'),(977024,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-right-radius','0','','','.w-catalog-paging'),(977025,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-style','dashed','','','.w-upload-customer-id-upload-customer-id-form'),(977026,'deals','.w-communication-new-topic td','border-top-width','1','','','.w-communication-new-topic'),(977027,'deals','.w-promotions .prom-multi-discount .promo-range','border-top-width','1','','','.w-promotions'),(977030,'deals','.w-cart-compare .attributes-block td','border-top-width','1','','','.w-cart-compare'),(977032,'deals','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(977033,'deals','.b-email .qty','border-top-width','1','','','.b-email'),(977034,'deals','.b-email .name','border-top-width','1','','','.b-email'),(977035,'deals','.b-email .totals-table','border-top-width','1','','','.b-email'),(977036,'deals','.testimonials .review','border-top-width','7','3','',''),(977037,'deals','.w-promotions .promo-salemaker .discount','border-top-width','1','','','.w-promotions'),(977038,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border-top-width','1','','','.w-promotions'),(977039,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border-top-width','1','','','.w-promotions'),(977040,'deals','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(977041,'deals','.b-messages .messMenuButtonTop','border-top-width','1','','','.b-messages'),(977042,'deals','.b-messages .msv_btn','border-top-width','1','','','.b-messages'),(977043,'deals','.b-messages .email-heading','border-top-width','1','','','.b-messages'),(977044,'deals','.b-messages .dataTable','border-top-width','1','','','.b-messages'),(977045,'deals','.b-messages .messages-menu li + li','border-top-width','1','','','.b-messages'),(977046,'deals','.b-messages .content_management_attach button','border-top-width','1','','','.b-messages'),(977047,'deals','.b-messages .content_management_attach','border-top-width','1','','','.b-messages'),(977048,'deals','.b-messages div.select2-container-multi ul.select2-choices, .b-messages div.select2-container-multi.select2-container-active ul.select2-choices','border-top-width','2','','','.b-messages'),(977049,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','border-top-width','1','','',''),(977050,'deals','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(977051,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border-top-width','2','3','','.b-form'),(977052,'deals','.w-socials > li','border-top-width','1','','','.w-socials'),(977053,'deals','.p-payer-order-confirmation .input-wrapper','border-top-width','2','','','.p-payer-order-confirmation'),(977054,'deals','.p-payer-order-pay .input-wrapper','border-top-width','2','','','.p-payer-order-pay'),(977055,'deals','.b-email .price','border-top-width','1','','','.b-email'),(977056,'deals','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(977057,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','border-top-width','2','','','.w-upload-customer-id-upload-customer-id-form'),(977058,'deals','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(977059,'deals','.b-email .model','border-top-width','1','','','.b-email'),(977060,'deals','.b-email .model','border-top-width','1','','','.b-email'),(977061,'deals','.b-email .price','border-top-width','1','','','.b-email'),(977062,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border-top-width','2','3','','.b-switch'),(977063,'deals','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(977064,'deals','.w-filters .ui-slider','border-top-width','0','','','.w-filters'),(977065,'deals','.w-filters .ui-slider-handle','border-top-width','0','','','.w-filters'),(977066,'deals','.b-email .name','border-top-width','1','','','.b-email'),(977067,'deals','.b-email .qty','border-top-width','1','','','.b-email'),(977068,'deals','.b-email .totals-table','border-top-width','1','','','.b-email'),(977069,'deals','.w-checkout-shipping-choice span','border-top-width','2','','','.w-checkout-shipping-choice'),(977070,'deals','.w-socials > li','border-top-width','1','','','.w-socials'),(977072,'deals','.w-cart-compare .product-block td','border-top-width','1','','','.w-cart-compare'),(977073,'deals','.b-info-popup .info-popup div','border-top-width','1','','','.b-info-popup'),(977074,'deals','.b-email .qty','border-top-width','1','','','.b-email'),(977075,'deals','.w-socials > li','border-top-width','1','','','.w-socials'),(977076,'deals','.b-bottom .popup-buttons','border-top-width','1','','','.b-bottom'),(977077,'deals','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(977078,'deals','.totals-line','border-top-width','1','','',''),(977079,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border-top-width','4','','','.b-switch'),(977080,'deals','.b-email .name','border-top-width','1','','','.b-email'),(977081,'deals','.b-email .totals-table','border-top-width','1','','','.b-email'),(977082,'deals','.b-email .name','border-top-width','1','','','.b-email'),(977083,'deals','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(977085,'deals','.w-reviews .review','border-top-width','8','3','','.w-reviews'),(977087,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border-top-width','3','','','.b-switch'),(977088,'deals','.b-email .image','border-top-width','1','','','.b-email'),(977089,'deals','.b-email .image','border-top-width','1','','','.b-email'),(977090,'deals','.b-email .model','border-top-width','1','','','.b-email'),(977091,'deals','.w-socials > li','border-top-width','1','','','.w-socials'),(977092,'deals','.b-email .image','border-top-width','1','','','.b-email'),(977093,'deals','.b-email .price','border-top-width','1','','','.b-email'),(977094,'deals','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(977095,'deals','.b-email .name','border-top-width','1','','','.b-email'),(977096,'deals','.b-email .qty','border-top-width','1','','','.b-email'),(977097,'deals','.b-email .model','border-top-width','1','','','.b-email'),(977098,'deals','.b-email .totals-table','border-top-width','1','','','.b-email'),(977099,'deals','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(977100,'deals','.b-form .shipping-method .item + .item','border-top-width','1','','','.b-form'),(977101,'deals','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(977102,'deals','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(977103,'deals','.b-select-suggest .select2-container .select2-choice','border-top-width','1','','','.b-select-suggest'),(977104,'deals','.view-all','border-top-width','1','3','',''),(977105,'deals','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(977106,'deals','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(977107,'deals','textarea','border-top-width','1','','',''),(977108,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border-top-width','2','4','','.b-switch'),(977109,'deals','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(977110,'deals','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(977112,'deals','.w-cart-compare .cart-cell > div','border-top-width','1','','','.w-cart-compare'),(977114,'deals','.b-form .form-buttons','border-top-width','1','','','.b-form'),(977115,'deals','.b-form .required-error','border-top-width','1','','','.b-form'),(977116,'deals','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(977117,'deals','.b-email .totals-table','border-top-width','1','','','.b-email'),(977119,'deals','.b-email .model','border-top-width','1','','','.b-email'),(977120,'deals','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','border-top-width','1','','','.b-bottom'),(977121,'deals','.b-email .model','border-top-width','1','','','.b-email'),(977122,'deals','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(977123,'deals','.b-upload-files .upload-files','border-top-width','1','','','.b-upload-files'),(977124,'deals','.b-upload-files .added-file','border-top-width','1','','','.b-upload-files'),(977125,'deals','.b-bottom .popup-box','border-top-width','1','','','.b-bottom'),(977126,'deals','.b-email .image','border-top-width','1','','','.b-email'),(977127,'deals','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(977128,'deals','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(977129,'deals','.w-product-customers-activity .customers-activity','border-top-width','1','','','.w-product-customers-activity'),(977130,'deals','.b-form .privacy-row','border-top-width','1','','','.b-form'),(977131,'deals','.w-reviews-content .review','border-top-width','8','3','','.w-reviews-content'),(977132,'deals','.w-cart-compare .price-block td','border-top-width','1','','','.w-cart-compare'),(977133,'deals','.w-socials > li','border-top-width','1','','','.w-socials'),(977134,'deals','.w-product-reviews .reviews-list .review','border-top-width','7','3','','.w-product-reviews'),(977135,'deals','.b-upload-file .upload-file-template','border-top-width','1','','','.b-upload-file'),(977136,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(977137,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','border-top-width','1','','','.b-select-suggest'),(977138,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','border-top-width','1','','','.b-select-suggest'),(977139,'deals','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','border-top-width','1','','','.b-select-suggest'),(977140,'deals','.b-select-suggest .select2-container-multi .select2-choices','border-top-width','1','','','.b-select-suggest'),(977141,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','border-top-width','1','','','.b-select-suggest'),(977142,'deals','.b-select-suggest .select2-search input','border-top-width','1','','','.b-select-suggest'),(977143,'deals','.b-select-suggest .select2-drop.select2-drop-above.select2-drop-active','border-top-width','1','','','.b-select-suggest'),(977144,'deals','.b-select-suggest .select2-drop.select2-drop-above','border-top-width','1','','','.b-select-suggest'),(977145,'deals','.b-select-suggest .select2-drop-active','border-top-width','1','','','.b-select-suggest'),(977146,'deals','.b-select-suggest .select2-drop-auto-width','border-top-width','1','','','.b-select-suggest'),(977147,'deals','.w-socials > li','border-top-width','1','','','.w-socials'),(977149,'deals','.b-form .payment-method .item + .item','border-top-width','1','','','.b-form'),(977150,'deals','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(977152,'deals','.b-bottom .cart-options .cart-item input[type=\"text\"]','border-top-width','1','','','.b-bottom'),(977153,'deals','.w-communication-post .communication-post','border-top-width','1','','','.w-communication-post'),(977154,'deals','.checkbox input:checked + span','border-top-width','1','','',''),(977155,'deals','.checkbox input + span','border-top-width','1','','',''),(977156,'deals','.b-autocomplete .ui-autocomplete','border-top-width','1','','','.b-autocomplete'),(977159,'deals','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(977160,'deals','.b-info-popup .info-popup div','border-top-width','1','3','','.b-info-popup'),(977161,'deals','.b-email .price','border-top-width','1','','','.b-email'),(977162,'deals','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(977163,'deals','.b-social-login .social-login-text-2','border-top-width','1','3','','.b-social-login'),(977164,'deals','.b-email .image','border-top-width','1','','','.b-email'),(977165,'deals','.b-social-login .social-login-text-2','border-top-width','1','4','','.b-social-login'),(977166,'deals','.b-email .price','border-top-width','1','','','.b-email'),(977167,'deals','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(977169,'deals','.w-promo-code .holder','border-top-width','1','','','.w-promo-code'),(977170,'deals','.w-checkout-shipping .sub-item + .sub-item','border-top-width','1','','','.w-checkout-shipping'),(977171,'deals','.w-cart-listing .item .gift-wrap label','border-top-width','1','','','.w-cart-listing'),(977172,'deals','.w-cart-listing .item','border-top-width','1','5639','','.w-cart-listing'),(977174,'deals','.b-email .image','border-top-width','1','','','.b-email'),(977175,'deals','.b-email .price','border-top-width','1','','','.b-email'),(977176,'deals','.b-dropdown .dropdown .dropdown-menu','border-top-width','1','','','.b-dropdown'),(977177,'deals','.w-filters .ui-slider-range','border-top-width','0','','','.w-filters'),(977178,'deals','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(977179,'deals','.b-email .qty','border-top-width','1','','','.b-email'),(977180,'deals','.b-email .name','border-top-width','1','','','.b-email'),(977181,'deals','.b-data-table table.dataTable tbody td','border-top-width','1','','','.b-data-table'),(977182,'deals','.b-compare .popupCompare td, .b-compare .popupCompare th','border-top-width','1','','','.b-compare'),(977183,'deals','.b-tracking-numbers .tracking-numbers td','border-top-width','1','','','.b-tracking-numbers'),(977184,'deals','.b-email .totals-table','border-top-width','1','','','.b-email'),(977185,'deals','.b-email .qty','border-top-width','1','','','.b-email'),(977186,'deals','.b-upload-file .snapshot','border-top-width','1','','','.b-upload-file'),(977187,'deals','.b-product-images .media-popup .mp-small-images .slick-current video, .b-product-images .media-popup .mp-small-images .slick-current iframe, .b-product-images .media-popup .mp-small-images .slick-current img','border-top-width','2','','','.b-product-images'),(977188,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','border-top-width','2','','','.b-trade-approval'),(977189,'deals','.w-account-personal-catalog .list-switcher a','border-top-width','3','2','','.w-account-personal-catalog'),(977190,'deals','.w-account-subscription .subscription-variant + .subscription-variant','border-top-width','1','','','.w-account-subscription'),(977191,'deals','.w-catalog-compare .compare .checkbox input:checked + span','border-top-width','1','','','.w-catalog-compare'),(977192,'deals','.w-catalog-compare .cross-box .different-all > div','border-top-width','3','2','','.w-catalog-compare'),(977193,'deals','.w-delivery-day .left-text-left','border-top-width','2','','','.w-delivery-day'),(977194,'deals','.w-delivery-day .left-text-right','border-top-width','2','','','.w-delivery-day'),(977195,'deals','.b-slick .slick-vertical .slick-slide','border-top-width','1','','','.b-slick'),(977196,'deals','.b-products-listing .products-listing .compare input + span','border-top-width','1','','','.b-products-listing'),(977197,'deals','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','border-top-width','0','','','.w-filters'),(977198,'deals','.b-products-listing .products-listing.list-rows .item:first-of-type .BlockBox.item-holder','border-top-width','0','','','.b-products-listing'),(977199,'deals','.w-quote .cart-content','border-top-width','1','','','.w-quote'),(977200,'deals','.b-product-images .additional-images .active img','border-top-width','2','','','.b-product-images'),(977201,'deals','.b-product-images .additional-images img','border-top-width','2','','','.b-product-images'),(977202,'deals','.b-quantity .qty-box .bigger','border-top-width','1','','','.b-quantity'),(977203,'deals','.b-quantity .qty-box .smaller','border-top-width','1','','','.b-quantity'),(977204,'deals','.w-product-sale-ends .left-text-left','border-top-width','2','','','.w-product-sale-ends'),(977205,'deals','.w-product-sale-ends .left-text-right','border-top-width','2','','','.w-product-sale-ends'),(977206,'deals','.w-files-catalog-widgets-files-list .item + .item','border-top-width','1','','','.w-files-catalog-widgets-files-list'),(977207,'deals','.w-sample .cart-content','border-top-width','1','','','.w-sample'),(977208,'deals','.w-product-video .item img, .w-product-video .item video','border-top-width','2','','','.w-product-video'),(977209,'deals','.w-product-video .item.active img, .w-product-video .item.active video','border-top-width','2','','','.w-product-video'),(977210,'deals','.w-product-bundle .bundle_item:nth-child(3) ~ .bundle_item','border-top-width','1','','','.w-product-bundle'),(977211,'deals','.w-product-bundle .bundle-total-price','border-top-width','1','','','.w-product-bundle'),(977212,'deals','.w-product-bundle .bundle_item:nth-child(2) ~ .bundle_item','border-top-width','1','5639','','.w-product-bundle'),(977213,'deals','.w-product-bundle .bundle_item:nth-child(1) ~ .bundle_item','border-top-width','1','5630','','.w-product-bundle'),(977214,'deals','.w-product-in-bundles .bundle-total-price','border-top-width','1','','','.w-product-in-bundles'),(977215,'deals','.w-product-in-bundles .bundle_item:nth-child(3) ~ .bundle_item','border-top-width','1','','','.w-product-in-bundles'),(977216,'deals','.w-product-in-bundles .bundle_item:nth-child(2) ~ .bundle_item','border-top-width','1','5639','','.w-product-in-bundles'),(977217,'deals','.w-product-in-bundles .bundle_item:nth-child(1) ~ .bundle_item','border-top-width','1','5630','','.w-product-in-bundles'),(977219,'deals','.b-pagination .pagination .active a, .b-pagination .pagination .active span','border-top-width','1','','','.b-pagination'),(977220,'deals','.b-pagination .pagination .next-pages','border-top-width','1','','','.b-pagination'),(977221,'deals','.b-pagination .pagination .page-number','border-top-width','1','','','.b-pagination'),(977222,'deals','.b-pagination .pagination .prev-pages','border-top-width','1','','','.b-pagination'),(977223,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','border-top-width','1','','','.b-pagination'),(977224,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','border-top-width','1','','','.b-pagination'),(977225,'deals','.b-pagination .pagination span','border-top-width','1','2','','.b-pagination'),(977227,'deals','.w-product-multi-inventory .radio-attributes .option-item','border-top-width','2','','','.w-product-multi-inventory'),(977228,'deals','.w-product-multi-inventory .radio-attributes input:checked + .option-item','border-top-width','2','','','.w-product-multi-inventory'),(977229,'deals','.b-products-listing .products-listing .radio-attributes .option','border-top-width','2','','','.b-products-listing'),(977230,'deals','.b-products-listing .products-listing .radio-attributes input:checked + .option','border-top-width','2','','','.b-products-listing'),(977231,'deals','.w-product-collection .choose-products','border-top-width','1','','','.w-product-collection'),(977232,'deals','.w-product-attributes .radio-attributes .option-item','border-top-width','2','','','.w-product-attributes'),(977233,'deals','.w-product-attributes .radio-attributes input:checked + .option-item','border-top-width','2','','','.w-product-attributes'),(977234,'deals','.w-questionnaire-widgets-questionnaire .question + .question','border-top-width','1','','','.w-questionnaire-widgets-questionnaire'),(977235,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border-top-width','2','','','.w-questionnaire-widgets-questionnaire'),(977236,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','border-top-width','2','','','.w-questionnaire-widgets-questionnaire'),(977237,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','border-top-width','2','','','.w-questionnaire-widgets-questionnaire'),(977238,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','border-top-width','2','1','','.w-questionnaire-widgets-questionnaire'),(977239,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','border-top-width','2','1','','.w-questionnaire-widgets-questionnaire'),(977240,'deals','.w-product-groups .radioBox label .containerBlock','border-top-width','2','','','.w-product-groups'),(977241,'deals','.w-product-groups .radioBox label .containerBlock.selected','border-top-width','2','','','.w-product-groups'),(977242,'deals','.w-product-groups .radioBox label input:checked + .containerBlock','border-top-width','2','','','.w-product-groups'),(977243,'deals','.w-product-custom-bundle .choose-products','border-top-width','1','','','.w-product-custom-bundle'),(977244,'deals','.w-product-custom-bundle .right-area .price','border-top-width','1','5639','','.w-product-custom-bundle'),(977245,'deals','.w-delivery-location-location-list .deliveryList li a','border-top-width','2','','','.w-delivery-location-location-list'),(977246,'deals','.w-delivery-location-location-list .deliveryList li a','border-top-width','2','1','','.w-delivery-location-location-list'),(977247,'deals','.w-sale-category .left-text-left','border-top-width','2','','','.w-sale-category'),(977248,'deals','.w-sale-category .left-text-right','border-top-width','2','','','.w-sale-category'),(977249,'deals','.w-sale-category .sale-holder','border-top-width','2','','','.w-sale-category'),(977250,'deals','.w-delivery-location-list-by-page .item','border-top-width','1','','','.w-delivery-location-list-by-page'),(977251,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content:before','border-top-width','1','','','.w-product-properties-icons'),(977252,'deals','.w-delivery-location-cross-pages .item','border-top-width','1','','','.w-delivery-location-cross-pages'),(977253,'deals','.w-product-designer-designer .prodDesignerType label','border-top-width','1','','','.w-product-designer-designer'),(977254,'deals','.w-press-reviews-widgets-press-reviews .press-reviews-button','border-top-width','1','','','.w-press-reviews-widgets-press-reviews'),(977255,'deals','.b-products-listing .productGroup label a','border-top-width','1','','','.b-products-listing'),(977256,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border-top-width','1','','','.w-predefined-promotion'),(977257,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border-top-width','1','','','.w-predefined-promotion'),(977258,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border-top-width','1','','','.w-predefined-promotion'),(977259,'deals','.w-predefined-promotion .promo-salemaker .discount','border-top-width','1','','','.w-predefined-promotion'),(977260,'deals','.w-supplier-purchase-supplier-products .item','border-top-width','1','','','.w-supplier-purchase-supplier-products'),(977262,'deals','.filterLine ','border-top-width','1','','','.filterLine'),(977263,'deals','.w-filters .filter-widget-horizontal .filter-box-content','border-top-width','1','','','.w-filters'),(977264,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','border-top-width','2','','','.b-products-listing'),(977265,'deals','.w-product-groups .property-category-heading + .property-category-content','border-top-width','1','','','.w-product-groups'),(977266,'deals','.btn-3','border-top-width','2','','',''),(977267,'deals','.w-product-quantity-discounts .quantity-discounts-content .item','border-top-width','1','','','.w-product-quantity-discounts'),(977268,'deals','.w-product-groups .radioBox label .containerBlock','border-top-width','2','1','','.w-product-groups'),(977269,'deals','.order-summary > div','border-top-width','1','','','.order-summary'),(977270,'deals','.btn','border-top-width','2','','',''),(977271,'deals','.w-support-system-listing .product_icon','border-top-width','1','','','.w-support-system-listing'),(977272,'deals','.w-support-system-listing .support-head','border-top-width','1','','','.w-support-system-listing'),(977273,'deals','.w-support-system-listing .support-item-body-content','border-top-width','1','','','.w-support-system-listing'),(977274,'deals','.w-support-system-listing .support-item-body .support-item-body-image','border-top-width','1','','','.w-support-system-listing'),(977275,'deals','.b-table-list .table-list td','border-top-width','1','','','.b-table-list'),(977276,'deals','.b-table .table .headings + tr ~ tr td','border-top-width','1','','','.b-table'),(977277,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','border-top-width','1','5639','','.w-filters'),(977278,'deals','.w-filters .filter-widget-horizontal .filter-box-head','border-top-width','1','5639','','.w-filters'),(977279,'deals','.w-filters .filter-widget-horizontal .filter-box:first-of-type .filter-box-head','border-top-width','0','5639','','.w-filters'),(977280,'deals','.b-products-listing .products-listing.list-b2b .item .BlockBox.item-holder, .b-products-listing .products-listing.list-rows .BlockBox.item-holder','border-top-width','1','','','.b-products-listing'),(977281,'deals','.b-products-listing .products-listing.list-b2b .item:first-of-type .BlockBox.item-holder, .b-products-listing .products-listing.list-rows .item:first-of-type .BlockBox.item-holder','border-top-width','0','','','.b-products-listing'),(977282,'deals','.b-products-listing .pr-groups.active a','border-top-width','1','','','.b-products-listing'),(977283,'deals','.b-info div + .info','border-top-width','1','','','.b-info'),(977284,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','border-top-width','1','5630','','.headerWrap'),(977285,'deals','.w-product-personal-catalog-button .btn','border-top-width','2','','','.w-product-personal-catalog-button'),(977286,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','border-top-width','1','','','.w-account-personal-catalog'),(977287,'deals','.w-account-personal-catalog .list-row-action ul','border-top-width','1','','','.w-account-personal-catalog'),(977288,'deals','.order-summary .price-row + .price-row','border-top-width','1','','','.order-summary'),(977294,'deals','.account-samples .orders-table .item','border-top-width','1','5639','','.account-samples'),(977295,'deals','.account-samples .orders-table .td-alignright','border-top-width','1','5639','','.account-samples'),(977296,'deals','.catalog-product-wrap .pn-image','border-top-width','2','3','','.catalog-product-wrap'),(977297,'deals','.catalog-product-wrap .pn-image','border-top-width','1','','','.catalog-product-wrap'),(977298,'deals','.catalog-product-wrap .pn-name','border-top-width','1','','','.catalog-product-wrap'),(977299,'deals','.catalog-product-wrap .prev-next-product','border-top-width','1','','','.catalog-product-wrap'),(977300,'deals','.checkout-index-wrap .input-wrapper','border-top-width','2','','','.checkout-index-wrap'),(977301,'deals','.w-cart-products .checkout-attention-message','border-top-width','1','','','.w-cart-products'),(977302,'deals','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(977303,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-content','border-top-width','1','','','.b-multi-page-checkout'),(977304,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border-top-width','2','','','.b-multi-page-checkout'),(977305,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-step','border-top-width','1','','','.b-multi-page-checkout'),(977306,'deals','.w-catalog-paging ','border-top-width','1','2','','.w-catalog-paging'),(977307,'deals','.w-catalog-paging .next','border-top-width','1','','','.w-catalog-paging'),(977308,'deals','.w-catalog-paging .next-pages','border-top-width','1','','','.w-catalog-paging'),(977309,'deals','.w-catalog-paging .page-number','border-top-width','1','','','.w-catalog-paging'),(977310,'deals','.w-catalog-paging .prev','border-top-width','1','','','.w-catalog-paging'),(977311,'deals','.w-catalog-paging .prev-pages','border-top-width','1','','','.w-catalog-paging'),(977312,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border-top-width','1','','','.w-catalog-paging'),(977315,'deals','.w-menu-slider > ul > li > ul','border-top-width','1','','','.w-menu-slider'),(977316,'deals','.b-autocomplete .ui-autocomplete li','border_important','important','','','.b-autocomplete'),(977317,'deals','.b-data-table table.dataTable thead td','border_important','important','','','.b-data-table'),(977318,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','border_important','important','','','.w-rma-returns-history'),(977319,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_1_measure','px','4','','.b-switch'),(977320,'deals','.w-personal-gift-status-bar .progress-bar-content','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(977321,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.p-quick-order-index'),(977322,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.p-quick-order-index'),(977323,'deals','.w-promotions .prom-multi-discount .promo-range','border_radius_1_measure','px','','','.w-promotions'),(977324,'deals','.w-promotions .promo-salemaker .discount','border_radius_1_measure','px','','','.w-promotions'),(977325,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_1_measure','px','','','.w-promotions'),(977326,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_1_measure','px','','','.w-promotions'),(977327,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_1_measure','px','','','.b-messages'),(977328,'deals','.b-fancybox .fancybox-close','border_radius_1_measure','%','','','.b-fancybox'),(977329,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_1_measure','px','','','.b-switch'),(977330,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_1_measure','px','3','','.b-switch'),(977331,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_1_measure','px','3','','.b-switch'),(977332,'deals','.b-switch .bootstrap-switch','border_radius_1_measure','px','','','.b-switch'),(977333,'deals','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_1_measure','px','','','.b-switch'),(977334,'deals','.w-checkout-shipping-choice label:last-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(977335,'deals','.w-checkout-shipping-choice label:first-child span','border_radius_1_measure','px','','','.w-checkout-shipping-choice'),(977336,'deals','.w-personal-gift-status-bar .progress-bar','border_radius_1_measure','px','','','.w-personal-gift-status-bar'),(977337,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_1_measure','px','','','.b-switch'),(977338,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_1_measure','%','3','','.b-switch'),(977339,'deals','.b-fancybox .fancybox-title-float-wrap .child','border_radius_1_measure','px','','','.b-fancybox'),(977340,'deals','.b-fancybox .fancybox-skin','border_radius_1_measure','px','','','.b-fancybox'),(977341,'deals','.b-fancybox .fancybox-nav span','border_radius_1_measure','%','','','.b-fancybox'),(977342,'deals','.w-product-customers-activity .close','border_radius_1_measure','%','','','.w-product-customers-activity'),(977343,'deals','.w-product-customers-activity .customers-activity','border_radius_1_measure','px','','','.w-product-customers-activity'),(977344,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_1_measure','px','4','','.b-switch'),(977345,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_1_measure','px','','','.b-data-table'),(977346,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_1_measure','px','','','.b-data-table'),(977347,'deals','.b-products-listing .promos-info .promo-name','border_radius_1_measure','px','','','.b-products-listing'),(977348,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(977349,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_1_measure','%','3','','.b-form'),(977350,'deals','.b-upload-file .snapshot','border_radius_1_measure','%','','','.b-upload-file'),(977351,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_1_measure','px','3','','.b-switch'),(977352,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_1_measure','px','','','.b-product-images'),(977353,'deals','.b-trade-approval .steps-bar','border_radius_1_measure','px','','','.b-trade-approval'),(977354,'deals','.w-delivery-day .left-count','border_radius_1_measure','px','','','.w-delivery-day'),(977355,'deals','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_1_measure','px','','','.w-delivery-day'),(977358,'deals','.w-quote .cart-box-link','border_radius_1_measure','%','3','','.w-quote'),(977359,'deals','.w-product-sale-ends .left-count','border_radius_1_measure','px','','','.w-product-sale-ends'),(977360,'deals','.w-product-sale-ends .left-count-days','border_radius_1_measure','px','','','.w-product-sale-ends'),(977361,'deals','.w-product-sale-ends .left-count-hours','border_radius_1_measure','px','','','.w-product-sale-ends'),(977362,'deals','.w-sample .cart-box-link','border_radius_1_measure','%','3','','.w-sample'),(977363,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_1_measure','%','','','.w-questionnaire-widgets-questionnaire'),(977364,'deals','.w-sale-category .badge','border_radius_1_measure','%','','','.w-sale-category'),(977365,'deals','.w-sale-category .left-count','border_radius_1_measure','px','','','.w-sale-category'),(977366,'deals','.w-sale-category .left-count-days','border_radius_1_measure','px','','','.w-sale-category'),(977367,'deals','.w-sale-category .left-count-hours','border_radius_1_measure','px','','','.w-sale-category'),(977368,'deals','.b-products-listing .productGroup label a','border_radius_1_measure','px','','','.b-products-listing'),(977369,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_1_measure','px','','','.w-predefined-promotion'),(977370,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_1_measure','px','','','.w-predefined-promotion'),(977371,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_1_measure','px','','','.w-predefined-promotion'),(977372,'deals','.w-predefined-promotion .promo-salemaker .discount','border_radius_1_measure','px','','','.w-predefined-promotion'),(977376,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_1_measure','%','','','.b-slick'),(977377,'deals','.w-product-groups .radioBox label .containerBlock','border_radius_1_measure','px','','','.w-product-groups'),(977379,'deals','.catalog-product-wrap .pn-image','border_radius_1_measure','%','3','','.catalog-product-wrap'),(977380,'deals','.b-slick .slick-dots li','border_radius_1_measure','%','3','','.b-slick'),(977381,'deals','.success-page .w-cart-listing .qty','border_radius_1_measure','%','','','.success-page'),(977382,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_1_measure','%','','','.b-multi-page-checkout'),(977383,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_1_measure','%','3','','.b-multi-page-checkout'),(977384,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_1_measure','px','','','.w-catalog-paging'),(977385,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_2_measure','px','4','','.b-switch'),(977386,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_2_measure','px','','','.b-switch'),(977387,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.p-quick-order-index'),(977388,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.p-quick-order-index'),(977389,'deals','.w-promotions .prom-multi-discount .promo-range','border_radius_2_measure','px','','','.w-promotions'),(977390,'deals','.w-promotions .promo-salemaker .discount','border_radius_2_measure','px','','','.w-promotions'),(977391,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_2_measure','px','','','.w-promotions'),(977392,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_2_measure','px','','','.w-promotions'),(977393,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_2_measure','px','4','','.b-switch'),(977394,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_2_measure','px','','','.b-messages'),(977395,'deals','.b-fancybox .fancybox-close','border_radius_2_measure','%','','','.b-fancybox'),(977396,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_2_measure','px','','','.b-switch'),(977397,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_2_measure','px','3','','.b-switch'),(977398,'deals','.b-switch .bootstrap-switch','border_radius_2_measure','px','','','.b-switch'),(977399,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_2_measure','px','3','','.b-switch'),(977400,'deals','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_2_measure','px','','','.b-switch'),(977401,'deals','.w-checkout-shipping-choice label:last-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(977402,'deals','.w-checkout-shipping-choice label:first-child span','border_radius_2_measure','px','','','.w-checkout-shipping-choice'),(977403,'deals','.w-personal-gift-status-bar .progress-bar-content','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(977404,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_2_measure','%','3','','.b-switch'),(977405,'deals','.b-fancybox .fancybox-title-float-wrap .child','border_radius_2_measure','px','','','.b-fancybox'),(977406,'deals','.b-fancybox .fancybox-skin','border_radius_2_measure','px','','','.b-fancybox'),(977407,'deals','.b-upload-file .snapshot','border_radius_2_measure','%','','','.b-upload-file'),(977408,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_2_measure','%','3','','.b-form'),(977409,'deals','.b-fancybox .fancybox-nav span','border_radius_2_measure','%','','','.b-fancybox'),(977410,'deals','.w-product-customers-activity .close','border_radius_2_measure','%','','','.w-product-customers-activity'),(977411,'deals','.w-product-customers-activity .customers-activity','border_radius_2_measure','px','','','.w-product-customers-activity'),(977412,'deals','.w-personal-gift-status-bar .progress-bar','border_radius_2_measure','px','','','.w-personal-gift-status-bar'),(977413,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_2_measure','px','','','.b-data-table'),(977414,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_2_measure','px','','','.b-data-table'),(977415,'deals','.b-products-listing .promos-info .promo-name','border_radius_2_measure','px','','','.b-products-listing'),(977416,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(977417,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_2_measure','px','3','','.b-switch'),(977418,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_2_measure','px','','','.b-product-images'),(977419,'deals','.b-trade-approval .steps-bar','border_radius_2_measure','px','','','.b-trade-approval'),(977420,'deals','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_2_measure','px','','','.w-delivery-day'),(977421,'deals','.w-delivery-day .left-count','border_radius_2_measure','px','','','.w-delivery-day'),(977424,'deals','.w-quote .cart-box-link','border_radius_2_measure','%','3','','.w-quote'),(977425,'deals','.w-product-sale-ends .left-count','border_radius_2_measure','px','','','.w-product-sale-ends'),(977426,'deals','.w-product-sale-ends .left-count-days','border_radius_2_measure','px','','','.w-product-sale-ends'),(977427,'deals','.w-product-sale-ends .left-count-hours','border_radius_2_measure','px','','','.w-product-sale-ends'),(977428,'deals','.w-sample .cart-box-link','border_radius_2_measure','%','3','','.w-sample'),(977429,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_2_measure','%','','','.w-questionnaire-widgets-questionnaire'),(977430,'deals','.w-sale-category .badge','border_radius_2_measure','%','','','.w-sale-category'),(977431,'deals','.w-sale-category .left-count','border_radius_2_measure','px','','','.w-sale-category'),(977432,'deals','.w-sale-category .left-count-days','border_radius_2_measure','px','','','.w-sale-category'),(977433,'deals','.w-sale-category .left-count-hours','border_radius_2_measure','px','','','.w-sale-category'),(977434,'deals','.b-products-listing .productGroup label a','border_radius_2_measure','px','','','.b-products-listing'),(977435,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_2_measure','px','','','.w-predefined-promotion'),(977436,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_2_measure','px','','','.w-predefined-promotion'),(977437,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_2_measure','px','','','.w-predefined-promotion'),(977438,'deals','.w-predefined-promotion .promo-salemaker .discount','border_radius_2_measure','px','','','.w-predefined-promotion'),(977442,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_2_measure','%','','','.b-slick'),(977443,'deals','.w-product-groups .radioBox label .containerBlock','border_radius_2_measure','px','','','.w-product-groups'),(977445,'deals','.catalog-product-wrap .pn-image','border_radius_2_measure','%','3','','.catalog-product-wrap'),(977446,'deals','.b-slick .slick-dots li','border_radius_2_measure','%','3','','.b-slick'),(977447,'deals','.success-page .w-cart-listing .qty','border_radius_2_measure','%','','','.success-page'),(977448,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_2_measure','%','','','.b-multi-page-checkout'),(977449,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_2_measure','%','3','','.b-multi-page-checkout'),(977450,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_2_measure','px','','','.w-catalog-paging'),(977451,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_3_measure','px','4','','.b-switch'),(977452,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_3_measure','px','4','','.b-switch'),(977453,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.p-quick-order-index'),(977454,'deals','.w-promotions .prom-multi-discount .promo-range','border_radius_3_measure','px','','','.w-promotions'),(977455,'deals','.w-promotions .promo-salemaker .discount','border_radius_3_measure','px','','','.w-promotions'),(977456,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_3_measure','px','','','.w-promotions'),(977457,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_3_measure','px','','','.w-promotions'),(977458,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_3_measure','px','','','.b-messages'),(977459,'deals','.b-fancybox .fancybox-close','border_radius_3_measure','%','','','.b-fancybox'),(977460,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_3_measure','px','','','.b-switch'),(977461,'deals','.w-personal-gift-status-bar .progress-bar-content','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(977462,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_3_measure','px','3','','.b-switch'),(977463,'deals','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_3_measure','px','','','.b-switch'),(977464,'deals','.w-personal-gift-status-bar .progress-bar','border_radius_3_measure','px','','','.w-personal-gift-status-bar'),(977465,'deals','.w-checkout-shipping-choice label:last-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(977466,'deals','.w-checkout-shipping-choice label:first-child span','border_radius_3_measure','px','','','.w-checkout-shipping-choice'),(977467,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_3_measure','%','3','','.b-form'),(977468,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_3_measure','px','3','','.b-switch'),(977469,'deals','.b-fancybox .fancybox-title-float-wrap .child','border_radius_3_measure','px','','','.b-fancybox'),(977470,'deals','.b-fancybox .fancybox-skin','border_radius_3_measure','px','','','.b-fancybox'),(977471,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_3_measure','%','3','','.b-switch'),(977472,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.p-quick-order-index'),(977473,'deals','.b-fancybox .fancybox-nav span','border_radius_3_measure','%','','','.b-fancybox'),(977474,'deals','.w-product-customers-activity .close','border_radius_3_measure','%','','','.w-product-customers-activity'),(977475,'deals','.w-product-customers-activity .customers-activity','border_radius_3_measure','px','','','.w-product-customers-activity'),(977476,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(977477,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_3_measure','px','','','.b-data-table'),(977478,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_3_measure','px','','','.b-data-table'),(977479,'deals','.b-products-listing .promos-info .promo-name','border_radius_3_measure','px','','','.b-products-listing'),(977480,'deals','.b-upload-file .snapshot','border_radius_3_measure','%','','','.b-upload-file'),(977481,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_3_measure','px','3','','.b-switch'),(977482,'deals','.b-switch .bootstrap-switch','border_radius_3_measure','px','','','.b-switch'),(977483,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_3_measure','px','','','.b-switch'),(977484,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_3_measure','px','','','.b-product-images'),(977485,'deals','.b-trade-approval .steps-bar','border_radius_3_measure','px','','','.b-trade-approval'),(977486,'deals','.w-delivery-day .left-count','border_radius_3_measure','px','','','.w-delivery-day'),(977487,'deals','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_3_measure','px','','','.w-delivery-day'),(977490,'deals','.w-quote .cart-box-link','border_radius_3_measure','%','3','','.w-quote'),(977491,'deals','.w-product-sale-ends .left-count','border_radius_3_measure','px','','','.w-product-sale-ends'),(977492,'deals','.w-product-sale-ends .left-count-days','border_radius_3_measure','px','','','.w-product-sale-ends'),(977493,'deals','.w-product-sale-ends .left-count-hours','border_radius_3_measure','px','','','.w-product-sale-ends'),(977494,'deals','.w-sample .cart-box-link','border_radius_3_measure','%','3','','.w-sample'),(977495,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_3_measure','%','','','.w-questionnaire-widgets-questionnaire'),(977496,'deals','.w-sale-category .badge','border_radius_3_measure','%','','','.w-sale-category'),(977497,'deals','.w-sale-category .left-count','border_radius_3_measure','px','','','.w-sale-category'),(977498,'deals','.w-sale-category .left-count-days','border_radius_3_measure','px','','','.w-sale-category'),(977499,'deals','.w-sale-category .left-count-hours','border_radius_3_measure','px','','','.w-sale-category'),(977500,'deals','.b-products-listing .productGroup label a','border_radius_3_measure','px','','','.b-products-listing'),(977501,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_3_measure','px','','','.w-predefined-promotion'),(977502,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_3_measure','px','','','.w-predefined-promotion'),(977503,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_3_measure','px','','','.w-predefined-promotion'),(977504,'deals','.w-predefined-promotion .promo-salemaker .discount','border_radius_3_measure','px','','','.w-predefined-promotion'),(977508,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_3_measure','%','','','.b-slick'),(977509,'deals','.w-product-groups .radioBox label .containerBlock','border_radius_3_measure','px','','','.w-product-groups'),(977511,'deals','.catalog-product-wrap .pn-image','border_radius_3_measure','%','3','','.catalog-product-wrap'),(977512,'deals','.b-slick .slick-dots li','border_radius_3_measure','%','3','','.b-slick'),(977513,'deals','.success-page .w-cart-listing .qty','border_radius_3_measure','%','','','.success-page'),(977514,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_3_measure','%','','','.b-multi-page-checkout'),(977515,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_3_measure','%','3','','.b-multi-page-checkout'),(977516,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_3_measure','px','','','.w-catalog-paging'),(977517,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','border_radius_4_measure','px','4','','.b-switch'),(977518,'deals','.b-upload-file .snapshot','border_radius_4_measure','%','','','.b-upload-file'),(977519,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.p-quick-order-index'),(977520,'deals','.w-promotions .prom-multi-discount .promo-range','border_radius_4_measure','px','','','.w-promotions'),(977521,'deals','.w-promotions .promo-salemaker .discount','border_radius_4_measure','px','','','.w-promotions'),(977522,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','border_radius_4_measure','px','','','.w-promotions'),(977523,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.p-quick-order-index'),(977524,'deals','.w-promotions .promo-cart-discount .promo-min-qty','border_radius_4_measure','px','','','.w-promotions'),(977525,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','border_radius_4_measure','px','','','.b-messages'),(977526,'deals','.b-fancybox .fancybox-close','border_radius_4_measure','%','','','.b-fancybox'),(977527,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','border_radius_4_measure','px','','','.b-switch'),(977528,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','border_radius_4_measure','px','3','','.b-switch'),(977529,'deals','.b-switch .candlestick-wrapper .candlestick-bg','border_radius_4_measure','px','','','.b-switch'),(977530,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(977531,'deals','.w-checkout-shipping-choice label:last-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(977532,'deals','.w-checkout-shipping-choice label:first-child span','border_radius_4_measure','px','','','.w-checkout-shipping-choice'),(977533,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','border_radius_4_measure','px','4','','.b-switch'),(977534,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','border_radius_4_measure','px','3','','.b-switch'),(977535,'deals','.b-fancybox .fancybox-title-float-wrap .child','border_radius_4_measure','px','','','.b-fancybox'),(977536,'deals','.b-form .radio-button input[type=\"radio\"].no + span','border_radius_4_measure','%','3','','.b-form'),(977537,'deals','.w-personal-gift-status-bar .progress-bar-content','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(977538,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','border_radius_4_measure','%','3','','.b-switch'),(977539,'deals','.w-personal-gift-status-bar .progress-bar','border_radius_4_measure','px','','','.w-personal-gift-status-bar'),(977540,'deals','.b-fancybox .fancybox-nav span','border_radius_4_measure','%','','','.b-fancybox'),(977541,'deals','.w-product-customers-activity .customers-activity','border_radius_4_measure','px','','','.w-product-customers-activity'),(977542,'deals','.w-product-customers-activity .close','border_radius_4_measure','%','','','.w-product-customers-activity'),(977543,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','border_radius_4_measure','px','3','','.b-switch'),(977544,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','border_radius_4_measure','px','','','.b-data-table'),(977545,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','border_radius_4_measure','px','','','.b-data-table'),(977546,'deals','.b-products-listing .promos-info .promo-name','border_radius_4_measure','px','','','.b-products-listing'),(977547,'deals','.b-fancybox .fancybox-skin','border_radius_4_measure','px','','','.b-fancybox'),(977548,'deals','.b-switch .bootstrap-switch','border_radius_4_measure','px','','','.b-switch'),(977549,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','border_radius_4_measure','px','','','.b-switch'),(977550,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','border_radius_4_measure','px','','','.b-product-images'),(977551,'deals','.b-trade-approval .steps-bar','border_radius_4_measure','px','','','.b-trade-approval'),(977552,'deals','.w-delivery-day .left-count','border_radius_4_measure','px','','','.w-delivery-day'),(977553,'deals','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','border_radius_4_measure','px','','','.w-delivery-day'),(977556,'deals','.w-quote .cart-box-link','border_radius_4_measure','%','3','','.w-quote'),(977557,'deals','.w-product-sale-ends .left-count','border_radius_4_measure','px','','','.w-product-sale-ends'),(977558,'deals','.w-product-sale-ends .left-count-days','border_radius_4_measure','px','','','.w-product-sale-ends'),(977559,'deals','.w-product-sale-ends .left-count-hours','border_radius_4_measure','px','','','.w-product-sale-ends'),(977560,'deals','.w-sample .cart-box-link','border_radius_4_measure','%','3','','.w-sample'),(977561,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','border_radius_4_measure','%','','','.w-questionnaire-widgets-questionnaire'),(977562,'deals','.w-sale-category .badge','border_radius_4_measure','%','','','.w-sale-category'),(977563,'deals','.w-sale-category .left-count','border_radius_4_measure','px','','','.w-sale-category'),(977564,'deals','.w-sale-category .left-count-days','border_radius_4_measure','px','','','.w-sale-category'),(977565,'deals','.w-sale-category .left-count-hours','border_radius_4_measure','px','','','.w-sale-category'),(977566,'deals','.b-products-listing .productGroup label a','border_radius_4_measure','px','','','.b-products-listing'),(977567,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','border_radius_4_measure','px','','','.w-predefined-promotion'),(977568,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','border_radius_4_measure','px','','','.w-predefined-promotion'),(977569,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','border_radius_4_measure','px','','','.w-predefined-promotion'),(977570,'deals','.w-predefined-promotion .promo-salemaker .discount','border_radius_4_measure','px','','','.w-predefined-promotion'),(977574,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','border_radius_4_measure','%','','','.b-slick'),(977575,'deals','.w-product-groups .radioBox label .containerBlock','border_radius_4_measure','px','','','.w-product-groups'),(977577,'deals','.catalog-product-wrap .pn-image','border_radius_4_measure','%','3','','.catalog-product-wrap'),(977578,'deals','.b-slick .slick-dots li','border_radius_4_measure','%','3','','.b-slick'),(977579,'deals','.success-page .w-cart-listing .qty','border_radius_4_measure','%','','','.success-page'),(977580,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','border_radius_4_measure','%','','','.b-multi-page-checkout'),(977581,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','border_radius_4_measure','%','3','','.b-multi-page-checkout'),(977582,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','border_radius_4_measure','px','','','.w-catalog-paging'),(977584,'deals','.testimonials .review','bottom','-13','3','',''),(977585,'deals','.w-checkout-shipping-choice input:checked + span:before','bottom','-7','','','.w-checkout-shipping-choice'),(977586,'deals','.b-fancybox .fancybox-title-over-wrap','bottom','0','','','.b-fancybox'),(977587,'deals','.b-info-popup .info-popup.top-left div','bottom','30','','','.b-info-popup'),(977588,'deals','.b-info-popup .info-popup.top-left div','bottom','-11','3','','.b-info-popup'),(977589,'deals','.b-upload-file .snapshot','bottom','5','','','.b-upload-file'),(977590,'deals','.w-product-reviews .reviews-list .review','bottom','-13','3','','.w-product-reviews'),(977591,'deals','.b-fancybox .fancybox-overlay-fixed','bottom','0','','','.b-fancybox'),(977592,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','bottom','0','','','.b-switch'),(977593,'deals','.w-product-customers-activity .customers-activity','bottom','0','','','.w-product-customers-activity'),(977594,'deals','.w-product-customers-activity .customers-activity.closed','bottom','-1000','','','.w-product-customers-activity'),(977595,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','bottom','0','','','.b-switch'),(977596,'deals','.w-catalog-b2b-add-button ','bottom','0','','','.w-catalog-b2b-add-button'),(977597,'deals','.b-fancybox .fancybox-title-float-wrap','bottom','0','','','.b-fancybox'),(977598,'deals','.p-quick-order-index .all-scroll-div','bottom','0','','','.p-quick-order-index'),(977599,'deals','.w-cart-listing .item .remove','bottom','0','5639','','.w-cart-listing'),(977600,'deals','.b-product-images .mp-shadow, .b-product-images .media-popup','bottom','0','','','.b-product-images'),(977601,'deals','.b-slick .slick-vertical button.slick-next','bottom','0','','','.b-slick'),(977602,'deals','.b-slick .slick-vertical button.slick-prev','bottom','auto','','','.b-slick'),(977603,'deals','.w-compare ','bottom','0','','','.w-compare'),(977604,'deals','.w-compare .remove','bottom','10','','','.w-compare'),(977611,'deals','.account-samples .orders-table .order-total','bottom','45','5639','','.account-samples'),(977612,'deals','.account-samples .orders-table .status-name','bottom','7','5639','','.account-samples'),(977613,'deals','.account-samples .orders-table .td-alignright','bottom','0','5639','','.account-samples'),(977614,'deals','.w-banner .image-text-banner.bottom-center .text-banner','bottom','0','','','.w-banner'),(977615,'deals','.w-banner .image-text-banner.bottom-left .text-banner','bottom','0','','','.w-banner'),(977616,'deals','.w-banner .image-text-banner.bottom-right .text-banner','bottom','0','','','.w-banner'),(977619,'deals','.b-fancybox .fancybox-opened .fancybox-skin','box-shadow','0 10px 25px rgba(0, 0, 0, 0.5)','','','.b-fancybox'),(977622,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','box-shadow','0 0 4px rgba(75,75,75,0.5)','3','','.b-switch'),(977625,'deals','.w-catalog-compare .compare-fix-bar.fix-bar-fix','box-shadow','0 10px 10px -10px #cccccc','','','.w-catalog-compare'),(977626,'deals','.w-top-categories .item','box-shadow','0 3px 13px 0 rgb(50 50 50 / 20%)','','','.w-top-categories'),(977627,'deals','.w-top-categories .item','box-shadow','0 0 24px -2px rgb(50 50 50 / 50%)','1','','.w-top-categories'),(977628,'deals','.headerWrap .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','box-shadow','3px 3px 9px -3px rgb(0 0 0 / 30%)','','','.headerWrap'),(977629,'deals','.w-categories .item','box-shadow','0 3px 13px 0 rgb(50 50 50 / 20%)','','','.w-categories'),(977630,'deals','.w-categories .item','box-shadow','0 0 24px -2px rgb(50 50 50 / 50%)','1','','.w-categories'),(977631,'deals','.preFooter .menu-style[data-style=\"3\"] .level-2 > li','box-shadow','none','5644','','.preFooter'),(977633,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-step','box-shadow','0 2px 9px 0 rgba(0, 0, 0, 0.2)','2','','.b-multi-page-checkout'),(977637,'deals','.footer-menu .level-2 > li','box-shadow','3px 3px 9px -3px rgb(255,255,255)','5644','','.footer-menu'),(977638,'deals','.footer-menu .level-3','box-shadow','3px 3px 9px -3px rgb(0 0 0 / 30%)','5639','','.footer-menu'),(977643,'deals','.b-fancybox .filter-listing-loader','box-sizing','content-box','','','.b-fancybox'),(977644,'deals','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','box-sizing','border-box','','','.b-switch'),(977645,'deals','.b-select-suggest .select2-container, .b-select-suggest .select2-drop, .b-select-suggest .select2-search, .b-select-suggest .select2-search input','box-sizing','border-box','','','.b-select-suggest'),(977646,'deals','.b-slick .slick-slider','box-sizing','border-box','','','.b-slick'),(977647,'deals','.w-product-properties li','box-sizing','border-box','','','.w-product-properties'),(977648,'deals','.w-support-system-listing .support-head','box-sizing','border-box','','','.w-support-system-listing'),(977649,'deals','.b-info-popup .info-popup div','box_shadow_blur','10','','','.b-info-popup'),(977650,'deals','.w-product-customers-activity .customers-activity','box_shadow_blur','20','','','.w-product-customers-activity'),(977651,'deals','.b-datepicker .datepicker-dropdown','box_shadow_blur','10','','','.b-datepicker'),(977652,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur','5','','','.w-image-maps'),(977653,'deals','.w-compare ','box_shadow_blur','20','','','.w-compare'),(977654,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_blur','10','','','.w-product-properties-icons'),(977655,'deals','.b-info-popup .info-popup div','box_shadow_blur_measure','px','','','.b-info-popup'),(977656,'deals','.b-datepicker .datepicker-dropdown','box_shadow_blur_measure','px','','','.b-datepicker'),(977657,'deals','.w-product-customers-activity .customers-activity','box_shadow_blur_measure','px','','','.w-product-customers-activity'),(977658,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_blur_measure','px','','','.w-image-maps'),(977659,'deals','.w-compare ','box_shadow_blur_measure','px','','','.w-compare'),(977660,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_blur_measure','px','','','.w-product-properties-icons'),(977661,'deals','.b-info-popup .info-popup div','box_shadow_color','#ccc','','','.b-info-popup'),(977662,'deals','.b-datepicker .datepicker-dropdown','box_shadow_color','#ccc','','','.b-datepicker'),(977663,'deals','.w-product-customers-activity .customers-activity','box_shadow_color','#eee','','','.w-product-customers-activity'),(977664,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_color','#ccc','','','.w-image-maps'),(977665,'deals','.w-compare ','box_shadow_color','#cccc','','','.w-compare'),(977666,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_color','#bdbdbd','','','.w-product-properties-icons'),(977667,'deals','.b-info-popup .info-popup div','box_shadow_left','0','','','.b-info-popup'),(977668,'deals','.b-datepicker .datepicker-dropdown','box_shadow_left','0','','','.b-datepicker'),(977669,'deals','.w-product-customers-activity .customers-activity','box_shadow_left','0','','','.w-product-customers-activity'),(977670,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left','0','','','.w-image-maps'),(977671,'deals','.w-compare ','box_shadow_left','0','','','.w-compare'),(977672,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_left','1','','','.w-product-properties-icons'),(977673,'deals','.b-info-popup .info-popup div','box_shadow_left_measure','','','','.b-info-popup'),(977674,'deals','.b-datepicker .datepicker-dropdown','box_shadow_left_measure','','','','.b-datepicker'),(977675,'deals','.w-product-customers-activity .customers-activity','box_shadow_left_measure','','','','.w-product-customers-activity'),(977676,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_left_measure','','','','.w-image-maps'),(977677,'deals','.w-compare ','box_shadow_left_measure','','','','.w-compare'),(977678,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_left_measure','px','','','.w-product-properties-icons'),(977679,'deals','.b-info-popup .info-popup div','box_shadow_top','0','','','.b-info-popup'),(977680,'deals','.w-product-customers-activity .customers-activity','box_shadow_top','0','','','.w-product-customers-activity'),(977681,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top','0','','','.w-image-maps'),(977682,'deals','.b-datepicker .datepicker-dropdown','box_shadow_top','0','','','.b-datepicker'),(977683,'deals','.w-compare ','box_shadow_top','0','','','.w-compare'),(977684,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_top','1','','','.w-product-properties-icons'),(977685,'deals','.b-info-popup .info-popup div','box_shadow_top_measure','','','','.b-info-popup'),(977686,'deals','.w-product-customers-activity .customers-activity','box_shadow_top_measure','','','','.w-product-customers-activity'),(977687,'deals','.b-datepicker .datepicker-dropdown','box_shadow_top_measure','','','','.b-datepicker'),(977688,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','box_shadow_top_measure','','','','.w-image-maps'),(977689,'deals','.w-compare ','box_shadow_top_measure','','','','.w-compare'),(977690,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','box_shadow_top_measure','px','','','.w-product-properties-icons'),(977691,'deals','.b-form .addresses .address-item:nth-child(2n + 1)','clear','left','','','.b-form'),(977692,'deals','.w-checkout-billing-address .btn-cancel','clear','both','','','.w-checkout-billing-address'),(977693,'deals','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(977695,'deals','.b-form .col-full','clear','both','','','.b-form'),(977696,'deals','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(977699,'deals','.w-promotions .prom-multi-discount','clear','both','4','','.w-promotions'),(977700,'deals','.w-product-available-in-warehouses .content','clear','both','4','','.w-product-available-in-warehouses'),(977701,'deals','.b-products-listing .products-listing .mix-attributes','clear','bpth','4','','.b-products-listing'),(977702,'deals','.w-cart-compare .product .name','clear','right','','','.w-cart-compare'),(977703,'deals','.b-messages .dataTables_wrapper > .top','clear','both','4','','.b-messages'),(977704,'deals','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(977705,'deals','.b-messages .dataTables_wrapper > .bottom','clear','both','4','','.b-messages'),(977706,'deals','.b-form .columns','clear','both','4','','.b-form'),(977707,'deals','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(977708,'deals','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(977709,'deals','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(977710,'deals','.w-login-block .buttons','clear','none','','','.w-login-block'),(977711,'deals','.w-login-block .cols','clear','both','4','','.w-login-block'),(977712,'deals','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(977713,'deals','.w-login-block .guest','clear','right','','','.w-login-block'),(977714,'deals','.w-menu-horizontal li','clear','none','','','.w-menu-horizontal'),(977715,'deals','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(977716,'deals','.b-form .col-left','clear','left','','','.b-form'),(977717,'deals','.buttons','clear','both','','',''),(977718,'deals','.buttons','clear','both','4','',''),(977719,'deals','.w-cart-give-away .ga_column:nth-child(2n + 1)','clear','both','','','.w-cart-give-away'),(977720,'deals','.w-top-categories .categories','clear','both','4','','.w-top-categories'),(977721,'deals','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(977722,'deals','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(977723,'deals','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(977724,'deals','.w-checkout-billing-address .addresses','clear','both','4','','.w-checkout-billing-address'),(977725,'deals','.w-cart-listing .right-area','clear','both','5639','','.w-cart-listing'),(977726,'deals','.w-checkout-shipping-address .addresses','clear','both','4','','.w-checkout-shipping-address'),(977727,'deals','.w-checkout-shipping-address .btn-cancel','clear','both','','','.w-checkout-shipping-address'),(977728,'deals','.b-form .addresses','clear','both','4','','.b-form'),(977729,'deals','.w-top-categories .item:nth-child(4n + 1)','clear','both','','','.w-top-categories'),(977730,'deals','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(977731,'deals','.b-form .newsletter-row','clear','both','4','','.b-form'),(977732,'deals','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(977733,'deals','.w-login-block .cols','clear','both','4','','.w-login-block'),(977734,'deals','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(977735,'deals','.w-login-block .guest','clear','right','','','.w-login-block'),(977736,'deals','.w-login-block .guest','clear','right','','','.w-login-block'),(977737,'deals','.w-list-b2b .attributes','clear','both','4','','.w-list-b2b'),(977739,'deals','.w-cart-shipping-estimator .item .row: after','clear','both','','','.w-cart-shipping-estimator'),(977740,'deals','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(977741,'deals','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(977742,'deals','.w-login-block .guest','clear','right','','','.w-login-block'),(977743,'deals','.w-login-block .buttons','clear','none','','','.w-login-block'),(977744,'deals','.w-login-block .cols','clear','both','4','','.w-login-block'),(977745,'deals','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(977746,'deals','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(977747,'deals','.b-form .col-right','clear','right','','','.b-form'),(977748,'deals','.w-cart-compare .product','clear','both','4','','.w-cart-compare'),(977749,'deals','.w-login-block .buttons','clear','none','','','.w-login-block'),(977750,'deals','.b-bottom .cart-options .option-item:nth-child(2n + 1)','clear','both','','','.b-bottom'),(977751,'deals','.b-bottom .cart-options .heading-4','clear','both','','','.b-bottom'),(977752,'deals','.b-bottom .cart-options .cart-item:nth-child(2n + 1)','clear','both','','','.b-bottom'),(977753,'deals','.b-bottom .cart-options .options','clear','both','','','.b-bottom'),(977754,'deals','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(977755,'deals','.w-login-block .guest','clear','right','','','.w-login-block'),(977756,'deals','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(977757,'deals','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-billing-address'),(977758,'deals','.b-form .center-buttons','clear','both','','','.b-form'),(977759,'deals','.w-list-b2b .mix-attributes','clear','both','','','.w-list-b2b'),(977760,'deals','.w-cart-shipping-estimator .address-item .lastname','clear','both','4','','.w-cart-shipping-estimator'),(977761,'deals','.w-login-block .buttons','clear','none','','','.w-login-block'),(977762,'deals','.w-cart-compare .product .image','clear','both','','','.w-cart-compare'),(977763,'deals','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(977764,'deals','.w-login-block .cols','clear','both','4','','.w-login-block'),(977765,'deals','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(977766,'deals','.w-product-reviews .reviews-list','clear','right','','','.w-product-reviews'),(977767,'deals','.w-cart-compare .buttons','clear','none','','','.w-cart-compare'),(977768,'deals','.w-menu-big li','clear','none','','','.w-menu-big'),(977769,'deals','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(977770,'deals','.w-login-block .col-2:nth-child(2n + 1)','clear','both','','','.w-login-block'),(977771,'deals','.w-login-block .cols','clear','both','4','','.w-login-block'),(977772,'deals','.w-login-block .guest','clear','right','','','.w-login-block'),(977773,'deals','.w-login-block .buttons','clear','none','','','.w-login-block'),(977774,'deals','.b-products-listing .BlockBox','clear','both','4','','.b-products-listing'),(977775,'deals','.b-products-listing .products-listing','clear','both','4','','.b-products-listing'),(977777,'deals','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(977778,'deals','.w-socials .wrap_socials_posts','clear','both','4','','.w-socials'),(977779,'deals','.w-categories .categories','clear','both','4','','.w-categories'),(977780,'deals','.b-form .password-forgotten-link','clear','both','','','.b-form'),(977781,'deals','.b-form .requiredM','clear','both','','','.b-form'),(977782,'deals','.w-login-block .cols','clear','both','4','','.w-login-block'),(977783,'deals','.w-promo-code .holder','clear','both','4','','.w-promo-code'),(977784,'deals','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','clear','both','','','.w-checkout-shipping-address'),(977785,'deals','.w-categories .item:nth-child(4n + 1)','clear','both','','','.w-categories'),(977786,'deals','.w-cart-give-away .ga_name','clear','both','4','','.w-cart-give-away'),(977787,'deals','.b-form .login_btns','clear','both','','','.b-form'),(977788,'deals','.w-login-block .buttons','clear','none','','','.w-login-block'),(977789,'deals','.w-filters .fsl_handle','clear','both','4','','.w-filters'),(977790,'deals','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(977791,'deals','.w-cart-shipping-estimator .shipping-estimator','clear','both','4','','.w-cart-shipping-estimator'),(977792,'deals','.b-form .col-right + .col-left','clear','both','','','.b-form'),(977793,'deals','.w-login-block .receive-newsletter','clear','both','','','.w-login-block'),(977794,'deals','.w-cart-shipping-estimator .item .row','clear','both','','','.w-cart-shipping-estimator'),(977795,'deals','.b-tracking-numbers .tracking-numbers .item','clear','both','4','','.b-tracking-numbers'),(977796,'deals','.b-form .columns .col-2:nth-child(2n + 1)','clear','left','','','.b-form'),(977797,'deals','.b-trade-approval .col-right','clear','right','','','.b-trade-approval'),(977798,'deals','.b-trade-approval .col-left','clear','left','','','.b-trade-approval'),(977799,'deals','.b-trade-approval .center-buttons','clear','both','','','.b-trade-approval'),(977800,'deals','.b-trade-approval .columns','clear','both','4','','.b-trade-approval'),(977801,'deals','.w-catalog-compare .BlockBox','clear','both','','','.w-catalog-compare'),(977802,'deals','.w-social-links ','clear','both','','','.w-social-links'),(977803,'deals','.b-slick .slick-slide','clear','none','','','.b-slick'),(977804,'deals','.b-slick .slick-track','clear','both','4','','.b-slick'),(977805,'deals','.w-quote a.item','clear','both','4','','.w-quote'),(977806,'deals','.w-product-quantity .qty_packs .qty-input','clear','both','4','','.w-product-quantity'),(977807,'deals','.w-product-bonus-points > div','clear','both','4','','.w-product-bonus-points'),(977808,'deals','.w-compare .compare-button','clear','both','','','.w-compare'),(977809,'deals','.w-sample a.item','clear','both','4','','.w-sample'),(977810,'deals','.w-product-bundle > div','clear','both','4','','.w-product-bundle'),(977811,'deals','.b-products-listing .products-listing .radio-attributes','clear','both','4','','.b-products-listing'),(977812,'deals','.b-pagination .pagination','clear','both','4','','.b-pagination'),(977813,'deals','.w-product-multi-inventory .select-box:nth-child(2n+1)','clear','both','','','.w-product-multi-inventory'),(977814,'deals','.w-product-multi-inventory .select-box:last-of-type:after','clear','both','','','.w-product-multi-inventory'),(977815,'deals','.w-product-multi-inventory .radio-attributes','clear','both','','','.w-product-multi-inventory'),(977816,'deals','.w-product-multi-inventory #product-attributes','clear','both','4','','.w-product-multi-inventory'),(977817,'deals','.w-product-multi-inventory .radio-attributes','clear','both','4','','.w-product-multi-inventory'),(977818,'deals','.w-product-quantity-discounts .quantity-discounts','clear','both','4','','.w-product-quantity-discounts'),(977819,'deals','.b-products-listing .products-listing .radio-attributes','clear','both','','','.b-products-listing'),(977820,'deals','.w-product-collection .choose-products','clear','both','','','.w-product-collection'),(977821,'deals','.w-product-attributes #product-attributes','clear','both','4','','.w-product-attributes'),(977822,'deals','.w-product-attributes .radio-attributes','clear','both','','','.w-product-attributes'),(977823,'deals','.w-product-attributes .radio-attributes','clear','both','4','','.w-product-attributes'),(977824,'deals','.w-product-attributes .select-box:last-of-type:after','clear','both','','','.w-product-attributes'),(977825,'deals','.w-product-attributes .select-box:nth-child(2n+1)','clear','both','','','.w-product-attributes'),(977826,'deals','.w-product-groups .prop-group-swatch','clear','both','4','','.w-product-groups'),(977827,'deals','.w-product-custom-bundle .choose-products','clear','both','','','.w-product-custom-bundle'),(977828,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list'),(977829,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list-block'),(977830,'deals','.w-delivery-location-location-list ul','clear','both','4','','.w-delivery-location-location-list'),(977831,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li:nth-child(2n+1)','clear','both','5630','','.w-catalog-pages-category-pages-last-list'),(977832,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li:nth-child(2n+1)','clear','both','5630','','.w-catalog-pages-category-pages-last-list-block'),(977833,'deals','.w-delivery-location-featured-list .deliveryList ul','clear','both','4','','.w-delivery-location-featured-list'),(977834,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list-by-catalog'),(977835,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(977836,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li:nth-child(2n+1)','clear','both','5630','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(977837,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li:nth-child(2n+1)','clear','both','5630','','.w-catalog-pages-category-pages-last-list-by-catalog'),(977838,'deals','.w-delivery-location-list-by-page .page-list','clear','both','4','','.w-delivery-location-list-by-page'),(977839,'deals','.w-delivery-location-top-location-list .deliveryList','clear','both','4','','.w-delivery-location-top-location-list'),(977840,'deals','.w-delivery-location-list-by-page .item:nth-child(3n+1)','clear','left','','','.w-delivery-location-list-by-page'),(977841,'deals','.w-delivery-location-list-by-page .item:nth-child(3n+1)','clear','none','5639','','.w-delivery-location-list-by-page'),(977842,'deals','.w-delivery-location-list-by-page .item:nth-child(2n+1)','clear','left','5639','','.w-delivery-location-list-by-page'),(977843,'deals','.w-delivery-location-cross-pages .item:nth-child(3n+1)','clear','left','','','.w-delivery-location-cross-pages'),(977844,'deals','.w-delivery-location-cross-pages .page-list','clear','both','4','','.w-delivery-location-cross-pages'),(977845,'deals','.w-delivery-location-cross-pages .item:nth-child(2n+1)','clear','left','5639','','.w-delivery-location-cross-pages'),(977846,'deals','.w-delivery-location-cross-pages .item:nth-child(3n+1)','clear','none','5639','','.w-delivery-location-cross-pages'),(977847,'deals','.w-catalog-delivery-locations .item:nth-child(2n+1)','clear','left','','','.w-catalog-delivery-locations'),(977848,'deals','.delivery-options-popup','clear','both','4','',''),(977849,'deals','.w-gift-wrap-message-checkout .gift_message-comment-box','clear','both','','','.w-gift-wrap-message-checkout'),(977850,'deals','.w-product-configurator .pc_row','clear','both','4','','.w-product-configurator'),(977851,'deals','.w-product-configurator .pc_attr','clear','both','5630','','.w-product-configurator'),(977852,'deals','.w-product-configurator .pc_qty','clear','both','5630','','.w-product-configurator'),(977853,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','clear','both','4','','.w-catalog-pages-category-pages-list'),(977854,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li:nth-child(2n+1)','clear','both','5630','','.w-catalog-pages-category-pages-list'),(977855,'deals','.w-predefined-promotion .prom-multi-discount','clear','both','4','','.w-predefined-promotion'),(977856,'deals','.b-products-listing .select-attributes','clear','both','4','','.b-products-listing'),(977857,'deals','.w-neighbour-checkout .neighbour-box','clear','both','4','','.w-neighbour-checkout'),(977858,'deals','.b-sub-totals .historyTotal','clear','both','4','','.b-sub-totals'),(977859,'deals','.w-cart-shipping-estimator .left-area','clear','both','5630,4','','.w-cart-shipping-estimator'),(977861,'deals','.account-address-book .address_book_row','clear','both','','','.account-address-book'),(977862,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-content','clear','both','4','','.b-multi-page-checkout'),(977863,'deals','.w-menu-horizontal li','clear_important','important','','','.w-menu-horizontal'),(977864,'deals','.w-menu-big li','clear_important','important','','','.w-menu-big'),(977865,'deals','.b-slick .slick-slide','clear_important','important','','','.b-slick'),(977866,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip','rect(0 0 0 0)','','','.b-select-suggest'),(977867,'deals','.bannersWrap .leftBanner .banner-text','clip-path','polygon(0 0, 100% 0%, 85% 100%, 0% 100%)','','','.bannersWrap'),(977868,'deals','.bannersWrap .rightBanner .banner-text','clip-path','circle(55% at 50% 15%)','','','.bannersWrap'),(977869,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','clip_important','important','','','.b-select-suggest'),(977870,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper .candlestick-bg.off .candlestick-on i','color','$switch-off-color-2','','','.b-switch'),(977871,'deals','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(977872,'deals','.b-rating .glyphicon','color','$fade-color-2','','','.b-rating'),(977873,'deals','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(977874,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','$content-color-1','','','.p-quick-order-index'),(977875,'deals','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .specials_category .promo-conditions','color','$warning-color','3','','.w-promotions'),(977876,'deals','.w-promotions .promo-salemaker .content a','color','$content-color-1','','','.w-promotions'),(977877,'deals','.w-promotions .promo-cart-discount .item a','color','$content-color-1','','','.w-promotions'),(977878,'deals','.w-promotions .prom-multi-discount .promo-range','color','$fade-color-2','','','.w-promotions'),(977879,'deals','.w-personal-gift-status-bar .end-label','color','$content-color-1','','','.w-personal-gift-status-bar'),(977880,'deals','.p-sample-checkout-success .page-success .text-3','color','$fade-color-2','','','.p-sample-checkout-success'),(977881,'deals','.p-quote-checkout-success .page-success .text-3','color','$fade-color-2','','','.p-quote-checkout-success'),(977882,'deals','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(977883,'deals','.testimonials .reviews-list .date','color','$content-color-1','','',''),(977884,'deals','.testimonials .heading-3','color','$content-color-1','3','',''),(977885,'deals','.w-chat .w-chat-box a','color','$highlight-box-color-1','3','','.w-chat'),(977886,'deals','.w-promotions .prom-multi-discount .promo-range, .w-promotions .prom-multi-discount > .heading','color','$fade-color-2','3','','.w-promotions'),(977887,'deals','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','color','$content-color-1','','','.w-promotions'),(977888,'deals','.w-promotions .cart_discount .promo-date','color','$warning-color','3','','.w-promotions'),(977889,'deals','.w-promotions .multidiscount .promo-date, .w-promotions .multidiscount .heading-3','color','$fade-color-2','','','.w-promotions'),(977890,'deals','.w-promotions .cart_discount .heading-3','color','$warning-color','','','.w-promotions'),(977891,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','$content-color-1','','','.p-quick-order-index'),(977892,'deals','.w-promotions .specials_category .promo-salemaker .content a, .w-promotions .specials_category .promo-date','color','$warning-color','3','','.w-promotions'),(977893,'deals','.w-promotions .specials_category .heading-3','color','$warning-color','','','.w-promotions'),(977894,'deals','.w-promotions .promo-salemaker .discount','color','$warning-color','','','.w-promotions'),(977895,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','color','$fade-color-2','','','.w-promotions'),(977896,'deals','.w-promotions .promo-cart-discount .promo-min-qty','color','$fade-color-2','','','.w-promotions'),(977897,'deals','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','color','$warning-color','3','','.w-promotions'),(977898,'deals','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','color','$content-color-1','','','.b-warehouses-popup'),(977899,'deals','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','color','$fade-color-2','','','.b-warehouses-popup'),(977900,'deals','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','color','$message-color','','','.b-warehouses-popup'),(977901,'deals','.b-warehouses-popup a.warehouses-popup-link','color','$content-color-1','','','.b-warehouses-popup'),(977902,'deals','.p-quote-checkout-success .page-success .text-3','color','$fade-color-2','','','.p-quote-checkout-success'),(977903,'deals','.p-payer-order-confirmation .ship-ico','color','$content-color-1','3','','.p-payer-order-confirmation'),(977904,'deals','.b-bottom .closeable-heading','color','$content-color-1','3','','.b-bottom'),(977905,'deals','.b-messages .messMenuButton span','color','$content-color-1','','','.b-messages'),(977906,'deals','.b-messages .messages-menu li a','color','$content-color-1','','','.b-messages'),(977907,'deals','.b-messages .content_management_attach','color','$content-color-1','','','.b-messages'),(977908,'deals','.b-messages .content_management_attach button','color','$content-color-1','','','.b-messages'),(977909,'deals','.b-messages .select2-search-choice-close','color','$fade-color-1','3','','.b-messages'),(977911,'deals','.w-socials .post_item > div.tw_post_item','color','$hileght-color-1','3','','.w-socials'),(977912,'deals','.w-promo-code .holder','color','$fade-color-2','3','','.w-promo-code'),(977913,'deals','.w-product-promotions .promotion-full-price-discount','color','$fade-color-2','','','.w-product-promotions'),(977914,'deals','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(977916,'deals','.p-payer-order-confirmation .pay-ico','color','$content-color-1','3','','.p-payer-order-confirmation'),(977917,'deals','.p-payer-order-confirmation .order-ico','color','$content-color-1','3','','.p-payer-order-confirmation'),(977918,'deals','.p-payer-order-confirmation .discount-ico','color','$content-color-1','3','','.p-payer-order-confirmation'),(977919,'deals','.p-payer-order-confirmation .comment-ico','color','$content-color-1','3','','.p-payer-order-confirmation'),(977920,'deals','.p-payer-order-pay .ship-ico','color','$content-color-1','3','','.p-payer-order-pay'),(977921,'deals','.p-payer-order-pay .pay-ico','color','$content-color-1','3','','.p-payer-order-pay'),(977922,'deals','.p-payer-order-pay .order-ico','color','$content-color-1','3','','.p-payer-order-pay'),(977923,'deals','.p-payer-order-pay .discount-ico','color','$content-color-1','3','','.p-payer-order-pay'),(977924,'deals','.p-payer-order-pay .comment-ico','color','$content-color-1','3','','.p-payer-order-pay'),(977925,'deals','.b-form .inputRequirement','color','$attention-color','','','.b-form'),(977926,'deals','.b-fancybox .fancybox-close','color','$fancybox-color-1','','','.b-fancybox'),(977927,'deals','.b-email-editor .special-price','color','$fade-color-2','','','.b-email-editor'),(977928,'deals','.p-quote-checkout-success .page-success .text-3','color','$fade-color-2','','','.p-quote-checkout-success'),(977929,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color','$content-color-1','1','','.p-quick-order-index'),(977930,'deals','.w-upload-customer-id-upload-customer-id-form .upload-remove','color','$fade-color-2','','','.w-upload-customer-id-upload-customer-id-form'),(977931,'deals','.w-menu-horizontal a','color','inherit','','','.w-menu-horizontal'),(977932,'deals','.order-summary .price-row.ot_bonus_points .title','color','$message-color','3','','.order-summary'),(977933,'deals','.b-form .radio-button input[type=\"radio\"].no + span','color','$checkbox-color-1','3','','.b-form'),(977934,'deals','.w-coupons-and-vauchers-checkout #credit_modules_message','color','$message-color','','','.w-coupons-and-vauchers-checkout'),(977935,'deals','.b-fancybox .fancybox-title-outside-wrap','color','$fancybox-color-1','','','.b-fancybox'),(977936,'deals','.b-fancybox .fancybox-title-over-wrap','color','$fancybox-color-1','','','.b-fancybox'),(977937,'deals','.b-email-editor .special-price','color','$fade-color-2','','','.b-email-editor'),(977938,'deals','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(977939,'deals','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(977940,'deals','.w-social-links .twitter','color','$hileght-color-1','3','','.w-social-links'),(977941,'deals','.w-social-links .stumbleupon','color','$fade-color-2','3','','.w-social-links'),(977942,'deals','.w-social-links .facebook','color','$content-color-1','3','','.w-social-links'),(977943,'deals','.w-social-links .pinterest','color','$fade-color-2','3','','.w-social-links'),(977944,'deals','.btn-1','color','$btn-color-2','','',''),(977945,'deals','.price .specials','color','$price-special-1','','',''),(977947,'deals','.w-socials .post_item > div.tw_post_item','color','$hileght-color-1','3','','.w-socials'),(977948,'deals','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(977949,'deals','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(977950,'deals','.w-filters .input-checkbox:checked + .checkbox-span:before','color','$content-color-1','','','.w-filters'),(977951,'deals','.w-cart-compare .product .name a','color','$content-color-1','','','.w-cart-compare'),(977952,'deals','.w-reviews .date','color','$fade-color-2','','','.w-reviews'),(977953,'deals','.w-checkout-shipping-choice span','color','$content-color-1','','','.w-checkout-shipping-choice'),(977954,'deals','.w-socials .post_item > div.insta_post_item','color','$fade-color-2','3','','.w-socials'),(977955,'deals','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(977956,'deals','.w-socials .post_item > div.tw_post_item','color','$hileght-color-1','3','','.w-socials'),(977957,'deals','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(977959,'deals','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(977960,'deals','.b-rating .glyphicon.coloron ~ .glyphicon-star','color','$content-color-1','','','.b-rating'),(977961,'deals','.w-image-maps .default-links .item .description','color','$content-color-1','','','.w-image-maps'),(977962,'deals','.price .special','color','$price-special-1','','',''),(977963,'deals','.w-reviews-content .date','color','$fade-color-2','','','.w-reviews-content'),(977964,'deals','.b-delete-account .delete-box .delete-message','color','$fade-color-2','','','.b-delete-account'),(977965,'deals','.b-form .radio-button input[type=\"radio\"]:checked + span:before','color','$checkbox-color-1','','','.b-form'),(977966,'deals','.w-multi-cart-actions .cart-actions .dropdown-toggle','color','$fade-color-1','3','','.w-multi-cart-actions'),(977969,'deals','.w-tabs .tab-a','color','$tab-nav-color-1','2','','.w-tabs'),(977970,'deals','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(977971,'deals','.w-socials .post_item > div.tw_post_item','color','$hileght-color-1','3','','.w-socials'),(977972,'deals','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(977973,'deals','.w-socials .post_item > div.insta_post_item','color','$fade-color-2','3','','.w-socials'),(977974,'deals','.bell-ico .heading-2','color','$content-color-1','3','','.bell-ico'),(977975,'deals','.w-tabs .tab-li:hover a.tab-a','color','$tab-nav-color-1','','','.w-tabs'),(977976,'deals','.w-cart-credit-amount #credit_modules_message.error','color','$fade-color-2','','','.w-cart-credit-amount'),(977977,'deals','.w-cart-credit-amount #credit_modules_message','color','$message-color','','','.w-cart-credit-amount'),(977978,'deals','.w-cart-listing .attention_mark','color','$fade-color-2','','','.w-cart-listing'),(977979,'deals','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(977980,'deals','.w-product-promotions .promotion-full-price-discount','color','$fade-color-2','','','.w-product-promotions'),(977981,'deals','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(977982,'deals','.w-personal-gift-status-bar .start-label','color','$content-color-1','','','.w-personal-gift-status-bar'),(977983,'deals','.p-quote-checkout-success .page-success .text-3','color','$fade-color-2','','','.p-quote-checkout-success'),(977984,'deals','a.btn-2','color','$btn-color-3','','',''),(977985,'deals','.btn-2','color','$btn-color-3','','',''),(977986,'deals','.heading-4 .edit, h4 .edit','color','$content-color-1','','',''),(977987,'deals','.w-cart-compare .delete-cart','color','$content-color-1','3','','.w-cart-compare'),(977988,'deals','.w-cart-compare .cart-name a','color','$content-color-1','','','.w-cart-compare'),(977989,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','color','$switch-on-color-1','','','.b-switch'),(977990,'deals','.p-sample-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-sample-checkout-success'),(977991,'deals','.w-top-categories .categories h2','color','inherit','','','.w-top-categories'),(977992,'deals','.out-stock','color','$attention-color','','',''),(977993,'deals','.transit','color','$hileght-color-2','','',''),(977994,'deals','.in-stock','color','$message-color','','',''),(977995,'deals','.heading-3 .edit, h3 .edit','color','$content-color-1','','',''),(977996,'deals','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(977997,'deals','.b-bottom .header-error','color','$fade-color-2','','','.b-bottom'),(977998,'deals','.w-socials .post_item > div.insta_post_item','color','$fade-color-2','3','','.w-socials'),(977999,'deals','.w-promo-code .holder','color','$fade-color-2','3','','.w-promo-code'),(978001,'deals','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(978002,'deals','.testimonials .date','color','$content-color-1','','',''),(978003,'deals','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(978004,'deals','.b-fancybox .fancybox-title-float-wrap .child','color','$fancybox-color-1','','','.b-fancybox'),(978005,'deals','.w-reviews-content .product-name a','color','$content-color-1','','','.w-reviews-content'),(978006,'deals','.b-fancybox .fancybox-skin','color','$fancybox-color-1','','','.b-fancybox'),(978007,'deals','.w-product-promotions .promotion-full-price-discount','color','$fade-color-2','','','.w-product-promotions'),(978008,'deals','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(978009,'deals','.w-socials .post_item > div.insta_post_item','color','$fade-color-2','3','','.w-socials'),(978010,'deals','.w-socials .post_item > div.tw_post_item','color','$hileght-color-1','3','','.w-socials'),(978011,'deals','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(978012,'deals','.main-content a','color','$link-color-1','','',''),(978013,'deals','.btn','color','$btn-color-1','','',''),(978016,'deals','.message.success','color','$message-color','','',''),(978017,'deals','.b-form .required-message','color','$attention-color','','','.b-form'),(978018,'deals','.b-email-editor .special-price','color','$fade-color-2','','','.b-email-editor'),(978019,'deals','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(978020,'deals','.w-promo-code .holder','color','$fade-color-2','3','','.w-promo-code'),(978021,'deals','.w-reviews .heading-3','color','$content-color-1','3','','.w-reviews'),(978022,'deals','.w-reviews .product-name a','color','$content-color-1','','','.w-reviews'),(978023,'deals','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','color','$content-color-1','','','.b-select-suggest'),(978024,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span:before','color','$checkbox-color-1','','','.b-form'),(978025,'deals','.w-social-links .linkedin','color','$content-color-1','3','','.w-social-links'),(978026,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','color','$switch-off-color-2','','','.b-switch'),(978027,'deals','a','color','inherit','','',''),(978029,'deals','a.btn','color','$btn-color-1','','',''),(978031,'deals','.b-form .checkbox-style:checked + .checkbox-span:before','color','$checkbox-color-1','','','.b-form'),(978032,'deals','.btn-del','color','$attention-color','4','',''),(978033,'deals','.b-form .required','color','$attention-color','','','.b-form'),(978034,'deals','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(978036,'deals','.b-rating .glyphicon-star.coloron','color','$content-color-1','3','','.b-rating'),(978037,'deals','.w-social-links .instagram','color','$fade-color-2','3','','.w-social-links'),(978038,'deals','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(978039,'deals','.b-pass-strength span.good-pass','color','$message-color','','','.b-pass-strength'),(978040,'deals','.b-pass-strength span.strong-pass, .b-pass-strength span.pass-match','color','$message-color','','','.b-pass-strength'),(978041,'deals','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(978042,'deals','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(978045,'deals','.w-promo-code .holder','color','$fade-color-2','3','','.w-promo-code'),(978046,'deals','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(978047,'deals','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(978049,'deals','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(978050,'deals','.b-bottom .pop-up-close','color','$fade-color-1','1','','.b-bottom'),(978051,'deals','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','color','$fade-color-1','3','','.order-summary'),(978052,'deals','.order-summary .price-row.ot_gv .title','color','$message-color','3','','.order-summary'),(978053,'deals','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','color','$message-color','','','.b-products-listing'),(978054,'deals','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','color','$message-color','','','.b-products-listing'),(978055,'deals','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(978057,'deals','.b-email-editor .special-price','color','$fade-color-2','','','.b-email-editor'),(978058,'deals','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(978059,'deals','.w-social-links .google-plus','color','$fade-color-2','3','','.w-social-links'),(978060,'deals','.b-form .privacy-row a','color','$content-color-1','','','.b-form'),(978063,'deals','.p-quote-checkout-success .page-success .text-3','color','$fade-color-2','','','.p-quote-checkout-success'),(978064,'deals','.w-product-promotions .promotion-full-price-discount','color','$fade-color-2','','','.w-product-promotions'),(978065,'deals','.w-image-maps .categories-items .item .description','color','$content-color-1','','','.w-image-maps'),(978066,'deals','.w-checkout-shipping-choice input:checked + span','color','$highlight-box-color-1','','','.w-checkout-shipping-choice'),(978067,'deals','.w-socials .post_item > div.insta_post_item','color','$fade-color-2','3','','.w-socials'),(978068,'deals','.w-tabs .accordion-heading','color','$tab-nav-color-1','2','','.w-tabs'),(978069,'deals','.w-categories h2.name','color','$content-color-1','','','.w-categories'),(978070,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on i, .b-switch .candlestick-wrapper .candlestick-bg.on .candlestick-off i','color','$switch-on-color-1','','','.b-switch'),(978071,'deals','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(978072,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','color','$content-color-1','','','.b-select-suggest'),(978073,'deals','.b-select-suggest .select2-default','color','$fade-color-1','','','.b-select-suggest'),(978074,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','color','$content-color-1','','','.b-select-suggest'),(978075,'deals','.b-select-suggest .select2-results .select2-highlighted ul','color','$content-color-1','','','.b-select-suggest'),(978076,'deals','.b-select-suggest .select2-results .select2-highlighted','color','$content-color-1','','','.b-select-suggest'),(978077,'deals','.b-select-suggest .select2-drop','color','$content-color-1','','','.b-select-suggest'),(978079,'deals','.w-socials .post_item > div.insta_post_item','color','$fade-color-2','3','','.w-socials'),(978080,'deals','.w-menu-big a','color','inherit','','','.w-menu-big'),(978082,'deals','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(978084,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color','$content-color-1','','','.b-data-table'),(978085,'deals','.b-products-listing .products-listing .bonus-points span:first-child','color','$content-color-1','','','.b-products-listing'),(978086,'deals','.b-products-listing .products-listing .bonus-points-price','color','$content-color-1','3','','.b-products-listing'),(978087,'deals','.b-products-listing .products-listing .bonus-points-cost','color','$content-color-1','3','','.b-products-listing'),(978088,'deals','.w-catalog-b2b-add-button ','color','$highlight-box-color-1','','','.w-catalog-b2b-add-button'),(978092,'deals','.w-promo-code .holder','color','$fade-color-2','3','','.w-promo-code'),(978093,'deals','.b-select-suggest .select2-container .select2-choice','color','$content-color-1','','','.b-select-suggest'),(978094,'deals','.b-upload-file .snapshot','color','$fade-color-1','','','.b-upload-file'),(978095,'deals','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(978096,'deals','.w-top-categories h2.name','color','$content-color-1','','','.w-top-categories'),(978098,'deals','.w-coupons-and-vauchers-checkout #credit_modules_message.error','color','$fade-color-2','','','.w-coupons-and-vauchers-checkout'),(978099,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','color','$content-color-1','','','.w-communication-new-topic'),(978100,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','color','$content-color-1','','','.w-communication-new-topic'),(978101,'deals','.b-form .middle-form label','color','$content-color-1','','','.b-form'),(978102,'deals','.btn-3','color','$btn-color-4','','',''),(978103,'deals','.order-summary .price-row.ot_coupon .title','color','$message-color','3','','.order-summary'),(978104,'deals','.w-product-promotions .promotion-full-price-discount','color','$fade-color-2','','','.w-product-promotions'),(978105,'deals','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(978106,'deals','.w-cart-compare .product-actions .dropdown-toggle','color','$fade-color-1','','','.w-cart-compare'),(978107,'deals','.w-promo-code .holder','color','$fade-color-2','3','','.w-promo-code'),(978108,'deals','.b-email-editor a','color','$content-color-1','','','.b-email-editor'),(978109,'deals','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(978110,'deals','.w-catalog-listing-look .grid','color','$content-color-1','','','.w-catalog-listing-look'),(978111,'deals','.w-catalog-listing-look .b2b','color','$highlight-box-color-1','2','','.w-catalog-listing-look'),(978112,'deals','.w-catalog-listing-look .b2b','color','$content-color-1','','','.w-catalog-listing-look'),(978113,'deals','.w-catalog-listing-look .list','color','$content-color-1','','','.w-catalog-listing-look'),(978114,'deals','.w-catalog-listing-look .grid','color','$highlight-box-color-1','2','','.w-catalog-listing-look'),(978115,'deals','.w-catalog-listing-look .list','color','$highlight-box-color-1','2','','.w-catalog-listing-look'),(978116,'deals','.checkbox input:checked + span:before','color','$checkbox-color-1','','',''),(978117,'deals','.p-quick-order-index .all-scroll-div','color','$highlight-box-color-1','','','.p-quick-order-index'),(978118,'deals','.w-cart-listing .points-redeem','color','$message-color','','','.w-cart-listing'),(978119,'deals','.w-cart-listing .remove-btn','color','$fade-color-2','','','.w-cart-listing'),(978120,'deals','.w-cart-discount-coupon #credit_modules_message.error','color','$fade-color-2','','','.w-cart-discount-coupon'),(978121,'deals','.w-cart-discount-coupon #credit_modules_message','color','$message-color','','','.w-cart-discount-coupon'),(978122,'deals','.b-email-editor .special-price','color','$fade-color-2','','','.b-email-editor'),(978123,'deals','.w-image-maps .float-items .item .description','color','$content-color-1','','','.w-image-maps'),(978124,'deals','.b-fancybox .fancybox-nav span','color','$fancybox-color-1','','','.b-fancybox'),(978125,'deals','.b-email-editor .special-price','color','$fade-color-2','','','.b-email-editor'),(978126,'deals','.b-email-editor .name a','color','$content-color-1','','','.b-email-editor'),(978127,'deals','.w-socials .post_item > div.tw_post_item','color','$hileght-color-1','3','','.w-socials'),(978128,'deals','.w-socials .post_item > div.fb_post_item','color','$content-color-1','3','','.w-socials'),(978129,'deals','.w-socials .post_item_name a','color','$content-color-1','','','.w-socials'),(978130,'deals','.w-product-promotions .promotion-full-price-discount','color','$fade-color-2','','','.w-product-promotions'),(978131,'deals','.w-product-promotions .promotion-data-2 .save','color','$message-color','','','.w-product-promotions'),(978132,'deals','.p-quote-checkout-success .page-success .text-1','color','$content-color-1','3','','.p-quote-checkout-success'),(978133,'deals','.w-filters .open','color','$fade-color-2','3','','.w-filters'),(978134,'deals','.w-filters .filter-box-head','color','$content-color-1','','','.w-filters'),(978135,'deals','.w-filters .view_more','color','$content-color-1','','','.w-filters'),(978136,'deals','.p-quote-checkout-success .page-success .text-3','color','$fade-color-2','','','.p-quote-checkout-success'),(978137,'deals','.b-bottom .pop-up-close','color','$fade-color-1','','','.b-bottom'),(978138,'deals','.b-email-editor .price','color','$content-color-1','','','.b-email-editor'),(978139,'deals','.b-pass-strength span.bad-pass','color','$warning-color','','','.b-pass-strength'),(978140,'deals','.w-product-reviews .reviews-list .date','color','$fade-color-1','','','.w-product-reviews'),(978141,'deals','.b-upload-files .remove-file','color','$fade-color-2','3','','.b-upload-files'),(978142,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','$content-color-1','1','','.b-data-table'),(978143,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color','$content-color-1','','','.b-data-table'),(978145,'deals','a.btn-3','color','$btn-color-4','','',''),(978146,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.off .candlestick-off','color','$switch-handle-bg-3','4','','.b-switch'),(978147,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.on .candlestick-on','color','$switch-handle-bg-3','4','','.b-switch'),(978148,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg.default .candlestick-nc','color','$switch-handle-bg-3','4','','.b-switch'),(978149,'deals','.b-pass-strength .short-pass, .b-pass-strength .pass-strength, .b-pass-strength .pass-no-match','color','$fade-color-2','','','.b-pass-strength'),(978150,'deals','.b-form .message.error','color','$attention-color','','','.b-form'),(978151,'deals','a.btn-1','color','$btn-color-2','','',''),(978152,'deals','.w-filters .mobileCollapse','color','$content-color-1','4','','.w-filters'),(978153,'deals','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','color','$fade-color-2','','','.w-filters'),(978154,'deals','.b-product-images .media-popup .mp-close','color','$image-popup-color-2','','','.b-product-images'),(978155,'deals','.b-product-images .media-popup .mp-close','color','$image-popup-color-1','1','','.b-product-images'),(978156,'deals','.b-product-images .media-popup .slick-dots li','color','$image-popup-color-2','','','.b-product-images'),(978157,'deals','.b-product-images .media-popup .slick-dots li.slick-active','color','$image-popup-color-1','','','.b-product-images'),(978158,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','color','$image-popup-color-2','','','.b-product-images'),(978159,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','color','$image-popup-color-1','1','','.b-product-images'),(978160,'deals','.b-personal-catalog-popup #personal_catalog_popup .show-all-lists','color','$fade-color-2','','','.b-personal-catalog-popup'),(978161,'deals','.b-trade-approval .steps-bar li.current a','color','$highlight-box-color-1','','','.b-trade-approval'),(978162,'deals','.b-trade-approval .middle-form label','color','$content-color-1','','','.b-trade-approval'),(978163,'deals','.w-account-personal-catalog .list-switcher a','color','$content-color-1','2','','.w-account-personal-catalog'),(978164,'deals','.w-catalog-compare .checkbox input:checked + span:before','color','$fade-color-2','','','.w-catalog-compare'),(978165,'deals','.w-catalog-compare span.btn-preloader','color','$content-color-1','3','','.w-catalog-compare'),(978166,'deals','.w-catalog-compare .cross-box .different-all > div','color','$content-color-1','2','','.w-catalog-compare'),(978167,'deals','.w-catalog-compare .cross-box .return','color','$content-color-1','','','.w-catalog-compare'),(978168,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','color','$content-color-1','3','','.w-catalog-compare'),(978169,'deals','.w-delivery-day .ends','color','$fade-color-2','','','.w-delivery-day'),(978170,'deals','.w-delivery-day .left-count-days-text, .w-delivery-day .left-count-hours-text, .w-delivery-day .left-count-minutes-text, .w-delivery-day .left-count-seconds-text','color','$highlight-box-color-1','','','.w-delivery-day'),(978175,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','color','$fade-color-2','','','.b-slick'),(978176,'deals','.price .old','color','$price-old-1','','',''),(978177,'deals','.w-filters .head-filter-widget','color','$content-color-1','','','.w-filters'),(978178,'deals','.w-quote .cart-box-link','color','$highlight-box-color-2','3','','.w-quote'),(978179,'deals','.w-quote .multicart .count','color','$fade-color-1','','','.w-quote'),(978180,'deals','.w-quote .multicart .item.current-multi-cart .switch-cart','color','$content-color-1','3','','.w-quote'),(978181,'deals','.w-quote .multicart .switch-cart','color','$fade-color-2','','','.w-quote'),(978182,'deals','.w-quote .multicart a.switch-cart','color','$fade-color-2','1','','.w-quote'),(978185,'deals','.rating-0, .rating-1, .rating-2, .rating-3, .rating-4, .rating-5','color','$content-color-1','','',''),(978186,'deals','.w-product-sale-ends .ends','color','$fade-color-2','','','.w-product-sale-ends'),(978187,'deals','.w-product-sale-ends .left-count-days-text','color','$content-color-1','','','.w-product-sale-ends'),(978188,'deals','.w-product-sale-ends .left-count-hours-text','color','$content-color-1','','','.w-product-sale-ends'),(978189,'deals','.w-product-quantity .qty_packs .price_1','color','$fade-color-2','4','','.w-product-quantity'),(978190,'deals','.w-product-bonus-points > div > div','color','$content-color-1','','','.w-product-bonus-points'),(978191,'deals','.warrantyProduct div','color','$content-color-1','','','.warrantyProduct'),(978192,'deals','.w-files-catalog-widgets-files-catalog .name a','color','$highlight-box-color-1','','','.w-files-catalog-widgets-files-catalog'),(978193,'deals','.w-files-catalog-widgets-files-list .file','color','$content-color-1','3','','.w-files-catalog-widgets-files-list'),(978194,'deals','.w-sample .cart-box-link','color','$highlight-box-color-2','3','','.w-sample'),(978195,'deals','.w-sample .cart-content','color','$content-color-1','','','.w-sample'),(978196,'deals','.w-sample .multicart .count','color','$fade-color-1','','','.w-sample'),(978197,'deals','.w-sample .multicart .item.current-multi-cart .switch-cart','color','$content-color-1','3','','.w-sample'),(978198,'deals','.w-sample .multicart .switch-cart','color','$fade-color-2','','','.w-sample'),(978199,'deals','.w-sample .multicart a.switch-cart','color','$fade-color-2','1','','.w-sample'),(978200,'deals','.w-cart-gift-certificate .gift-certificate .heading-4','color','$content-color-1','3','','.w-cart-gift-certificate'),(978202,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','color','inherit','','','.b-products-listing'),(978203,'deals','.b-pagination .pagination span','color','$highlight-box-color-1','2','','.b-pagination'),(978204,'deals','.b-products-listing .products-listing.list-rows .stock','color','$message-color','','','.b-products-listing'),(978205,'deals','.b-products-listing .products-listing.list-b2b .stock','color','$message-color','','','.b-products-listing'),(978206,'deals','.w-product-collection .save','color','$message-color','','','.w-product-collection'),(978207,'deals','.w-product-collection .right-area .separate-text, .w-product-collection .right-area .separate','color','$fade-color-1','','','.w-product-collection'),(978208,'deals','.w-product-collection .together','color','$content-color-1','','','.w-product-collection'),(978209,'deals','.w-product-collection .choose-products .heading-3','color','$content-color-1','','','.w-product-collection'),(978210,'deals','.price .special-promote','color','$price-special-1','','',''),(978211,'deals','.w-product-in-bundles .bundle_price .old','color','$fade-color-1','','','.w-product-in-bundles'),(978212,'deals','.w-product-in-bundles .bundle_price .specials','color','$fade-color-2','','','.w-product-in-bundles'),(978213,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','color','$fade-color-2','','','.w-questionnaire-widgets-questionnaire'),(978214,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"]:checked + span','color','$fade-color-2','','','.w-questionnaire-widgets-questionnaire'),(978215,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"]:checked + span','color','$message-color','','','.w-questionnaire-widgets-questionnaire'),(978216,'deals','.w-product-groups .radioBox label input:checked + div .val1','color','$content-color-1','','','.w-product-groups'),(978217,'deals','.w-product-groups .val1','color','$content-color-1','','','.w-product-groups'),(978218,'deals','.w-product-groups .val2','color','$content-color-1','','','.w-product-groups'),(978219,'deals','.w-product-custom-bundle .save','color','$message-color','','','.w-product-custom-bundle'),(978220,'deals','.w-product-custom-bundle .right-area .separate','color','$fade-color-2','','','.w-product-custom-bundle'),(978221,'deals','.w-delivery-location-location-list .deliveryList li a','color','$content-color-1','1','','.w-delivery-location-location-list'),(978222,'deals','.w-sale-category .badge','color','$highlight-box-color-1','','','.w-sale-category'),(978223,'deals','.w-sale-category .ends','color','$fade-color-2','','','.w-sale-category'),(978224,'deals','.w-sale-category .left-count-days-text','color','$highlight-box-color-1','','','.w-sale-category'),(978225,'deals','.w-sale-category .left-count-hours-text','color','$highlight-box-color-1','','','.w-sale-category'),(978226,'deals','.w-sale-category .special-price','color','$fade-color-2','','','.w-sale-category'),(978227,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','color','$content-color-1','','','.w-product-properties-icons'),(978228,'deals','.w-product-properties-icons .hover-box-content','color','$transparent','','','.w-product-properties-icons'),(978229,'deals','.w-delivery-location-product-categories .name','color','$highlight-box-color-2','','','.w-delivery-location-product-categories'),(978230,'deals','.w-product-designer-designer .grnamebox .title-sortable','color','$highlight-box-color-2','','','.w-product-designer-designer'),(978231,'deals','.w-product-designer-designer .prodDesignerType label','color','$content-color-1','','','.w-product-designer-designer'),(978232,'deals','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','color','$hileght-color-1','','','.w-press-reviews-widgets-press-reviews-small'),(978233,'deals','.w-press-reviews-widgets-press-reviews .date','color','$fade-color-1','','','.w-press-reviews-widgets-press-reviews'),(978234,'deals','.w-press-reviews-widgets-press-reviews .full-review a','color','$hileght-color-1','','','.w-press-reviews-widgets-press-reviews'),(978235,'deals','.w-press-reviews-widgets-press-reviews-list .date-added','color','$fade-color-2','','','.w-press-reviews-widgets-press-reviews-list'),(978236,'deals','.w-press-reviews-widgets-press-reviews-list .out-link a','color','$hileght-color-1','','','.w-press-reviews-widgets-press-reviews-list'),(978237,'deals','.b-products-listing .productGroup label a','color','$content-color-1','','','.b-products-listing'),(978238,'deals','.w-gift-wrap-message-checkout .error','color','$fade-color-2','','','.w-gift-wrap-message-checkout'),(978239,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','color','$transparent','','','.w-rma-returns-history'),(978240,'deals','.w-rma-returns-history .icons .excel','color','$message-color','3','','.w-rma-returns-history'),(978241,'deals','.w-rma-returns-history .icons .print','color','$content-color-1','','','.w-rma-returns-history'),(978242,'deals','.w-rma-returns-history .linkButton','color','$hileght-color-1','','','.w-rma-returns-history'),(978243,'deals','.w-rma-returns-history .linkButton','color','$content-color-1','1','','.w-rma-returns-history'),(978244,'deals','.b-products-listing .promos-info .promo-name-span','color','$highlight-box-color-2','','','.b-products-listing'),(978245,'deals','.w-predefined-promotion .cart_discount .heading-3','color','$warning-color','','','.w-predefined-promotion'),(978246,'deals','.w-predefined-promotion .cart_discount .promo-date','color','$warning-color','3','','.w-predefined-promotion'),(978247,'deals','.w-predefined-promotion .multidiscount .promo-date, .w-predefined-promotion .multidiscount .heading-3','color','$fade-color-2','','','.w-predefined-promotion'),(978248,'deals','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','color','$content-color-1','','','.w-predefined-promotion'),(978249,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','color','$fade-color-2','','','.w-predefined-promotion'),(978250,'deals','.w-predefined-promotion .prom-multi-discount .promo-range, .w-predefined-promotion .prom-multi-discount > .heading','color','$fade-color-2','3','','.w-predefined-promotion'),(978251,'deals','.w-predefined-promotion .promo-cart-discount .item a','color','$content-color-1','','','.w-predefined-promotion'),(978252,'deals','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','color','$warning-color','3','','.w-predefined-promotion'),(978253,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','color','$fade-color-2','','','.w-predefined-promotion'),(978254,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','color','$fade-color-2','','','.w-predefined-promotion'),(978255,'deals','.w-predefined-promotion .promo-salemaker .content a','color','$content-color-1','','','.w-predefined-promotion'),(978256,'deals','.w-predefined-promotion .promo-salemaker .discount','color','$warning-color','','','.w-predefined-promotion'),(978257,'deals','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .specials_category .promo-conditions','color','$warning-color','3','','.w-predefined-promotion'),(978258,'deals','.w-predefined-promotion .specials_category .heading-3','color','$warning-color','','','.w-predefined-promotion'),(978259,'deals','.w-predefined-promotion .specials_category .promo-salemaker .content a, .w-predefined-promotion .specials_category .promo-date','color','$warning-color','3','','.w-predefined-promotion'),(978260,'deals','.w-supplier-purchase-supplier-products .active .select_item > div:before','color','$message-color','','','.w-supplier-purchase-supplier-products'),(978264,'deals','.headerWrap .searchIcon','color','$fade-color-1','','','.headerWrap'),(978265,'deals','.headerWrap .w-contacts.phone','color','$fade-color-2','','','.headerWrap'),(978267,'deals','.bannersWrap .text','color','$highlight-box-color-3','','','.bannersWrap'),(978268,'deals','.preFooter .w-contacts > div','color','$content-color-1','','','.preFooter'),(978269,'deals','.w-top-categories .item:hover h2','color','$fade-color-2','','','.w-top-categories'),(978270,'deals','.w-categories .categories h2','color','inherit','','','.w-categories'),(978271,'deals','.w-categories .item:hover h2','color','$fade-color-2','','','.w-categories'),(978272,'deals','.w-filters .choose-filters > li > *','color','$highlight-box-color-2','','','.w-filters'),(978273,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','color','$content-color-1','','','.b-products-listing'),(978274,'deals','body','color','$content-color-1','','',''),(978275,'deals','.w-product-quantity-discounts .quantity-discounts-content .price','color','$fade-color-2','','','.w-product-quantity-discounts'),(978276,'deals','.messageBox .info','color','$message-color','','',''),(978277,'deals','.w-support-system-listing .support-head','color','$fade-color-2','','','.w-support-system-listing'),(978278,'deals','.w-cart-listing .promotion-cart-message','color','$fade-color-2','','','.w-cart-listing'),(978279,'deals','.w-cart-listing .promotion-cart-message a','color','$fade-color-2','','','.w-cart-listing'),(978280,'deals','.headerWrap .menu-style[data-style=\"1\"] .level-1 >li.parent>span.no-link','color','$fade-color-2','5630,3','','.headerWrap'),(978281,'deals','.homeBanner .carousel .bottom-center > span','color','$highlight-box-color-2','','','.homeBanner'),(978282,'deals','.b-products-listing .pr-groups.active a','color','$highlight-box-color-1','','','.b-products-listing'),(978283,'deals','.b-info .info','color','$fade-color-2','','','.b-info'),(978284,'deals','.b-info .info a','color','$content-color-1','','','.b-info'),(978285,'deals','.b-info .info-plus','color','$message-color','','','.b-info'),(978286,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','color','$content-color-1','5630','','.headerWrap'),(978287,'deals','.w-product-personal-catalog-button .btn','color','$content-color-1','','','.w-product-personal-catalog-button'),(978289,'deals','.p-wedding-registry-view h1','color','$fade-color-2','3','','.p-wedding-registry-view'),(978290,'deals','.p-wedding-registry-view h1','color','$fade-color-2','4','','.p-wedding-registry-view'),(978291,'deals','.homeBanner .banner-item .banner-text-holder','color','$highlight-box-color-2','','','.homeBanner'),(978292,'deals','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','color','$content-color-1','','','.w-promotions-widgets-promotion-icons-desc'),(978293,'deals','.w-promotions-widgets-promotions .promotion-data-2 .save','color','$message-color','','','.w-promotions-widgets-promotions'),(978294,'deals','.w-promotions-widgets-promotions .promotion-full-price-discount','color','$fade-color-2','','','.w-promotions-widgets-promotions'),(978307,'deals','.account-address-book .leftMes div','color','$fade-color-2','','','.account-address-book'),(978308,'deals','.account-address-book .leftMes ul','color','$fade-color-2','','','.account-address-book'),(978309,'deals','.account-address-book .rightMes ul','color','$fade-color-2','','','.account-address-book'),(978315,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','color','$content-color-1','3','','.account-order-pay'),(978316,'deals','.account-order-pay .not_fully_paid_td','color','$fade-color-2','','','.account-order-pay'),(978317,'deals','.account-samples .moduleRowDue td','color','$fade-color-2','','','.account-samples'),(978318,'deals','.account-samples .not_fully_paid_td','color','$fade-color-2','','','.account-samples'),(978319,'deals','.account-samples .view_link','color','$content-color-1','','','.account-samples'),(978320,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','color','$content-color-1','3','','.account-sample-info'),(978321,'deals','.account-sample-info .not_fully_paid_td','color','$fade-color-2','','','.account-sample-info'),(978322,'deals','.catalog-product-wrap .pn-direction','color','$content-color-1','','','.catalog-product-wrap'),(978323,'deals','.catalog-product-wrap .pn-image','color','$fade-color-2','3','','.catalog-product-wrap'),(978324,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','color','$btn-color-2','','','.checkout-index-wrap'),(978325,'deals','.checkout-index-wrap .edit-address-popup .edit-ab','color','$content-color-1','','','.checkout-index-wrap'),(978326,'deals','.checkout-index-wrap .order-ico','color','$content-color-1','3','','.checkout-index-wrap'),(978327,'deals','.checkout-index-wrap .pay-ico','color','$content-color-1','3','','.checkout-index-wrap'),(978328,'deals','.checkout-index-wrap .ship-ico','color','$content-color-1','3','','.checkout-index-wrap'),(978329,'deals','.checkout-order-confirmation .comment-ico','color','$content-color-1','3','','.checkout-order-confirmation'),(978330,'deals','.checkout-order-confirmation .discount-ico','color','$content-color-1','3','','.checkout-order-confirmation'),(978331,'deals','.checkout-order-confirmation .order-ico','color','$content-color-1','3','','.checkout-order-confirmation'),(978332,'deals','.checkout-order-confirmation .ship-ico','color','$content-color-1','3','','.checkout-order-confirmation'),(978333,'deals','.checkout-success-wrap .page-success .text-1','color','$content-color-1','3','','.checkout-success-wrap'),(978334,'deals','.checkout-success-wrap .page-success .text-3','color','$fade-color-2','','','.checkout-success-wrap'),(978335,'deals','.b-info .danger-message','color','$attention-color','','','.b-info'),(978336,'deals','.b-info .info-message','color','$message-color','','','.b-info'),(978337,'deals','.b-info .success-message','color','$message-color','','','.b-info'),(978338,'deals','.b-info .warning-message','color','$warning-color','','','.b-info'),(978339,'deals','.success-page .check-ico-block','color','$fade-color-2','3','','.success-page'),(978340,'deals','.success-page .comment-ico','color','$fade-color-2','3','','.success-page'),(978341,'deals','.success-page .discount-ico','color','$fade-color-2','3','','.success-page'),(978342,'deals','.success-page .order-ico','color','$fade-color-2','3','','.success-page'),(978343,'deals','.success-page .page-success .text-1','color','$fade-color-2','3','','.success-page'),(978344,'deals','.success-page .page-success .text-3','color','$attention-color','','','.success-page'),(978345,'deals','.success-page .pay-ico','color','$fade-color-2','3','','.success-page'),(978346,'deals','.success-page .prod-ico','color','$fade-color-2','3','','.success-page'),(978347,'deals','.success-page .ship-ico','color','$fade-color-2','3','','.success-page'),(978349,'deals','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading','color','$fade-color-2','','','.b-multi-page-checkout'),(978350,'deals','.b-multi-page-checkout .multi-page-checkout .active .checkout-heading .count','color','$highlight-box-color-2','','','.b-multi-page-checkout'),(978351,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading','color','$hileght-color-2','','','.b-multi-page-checkout'),(978352,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','$fade-color-1','3','','.b-multi-page-checkout'),(978353,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','color','$fade-color-2','','','.b-multi-page-checkout'),(978354,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','$fade-color-2','','','.b-multi-page-checkout'),(978355,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','color','$fade-color-2','4','','.b-multi-page-checkout'),(978356,'deals','.success-page .w-cart-listing .qty','color','$highlight-box-color-2','','','.success-page'),(978359,'deals','.footer-menu .level-1 > li > a, .footer-menu .level-1 > li > .no-link','color','$footer-menu-color-1','','','.footer-menu'),(978360,'deals','.footer-menu .level-2 > li > a, .footer-menu .level-2 > li > .no-link','color','$footer-menu-color-2','','','.footer-menu'),(978361,'deals','.footer-menu li > a, .footer-menu .no-link','color','$footer-menu-color-1','','','.footer-menu'),(978362,'deals','.price','color','$price-current-1','','',''),(978363,'deals','.w-catalog-paging ','color','$highlight-box-color-2','2','','.w-catalog-paging'),(978367,'deals','.w-menu-slider .menu-ico','color','$highlight-box-color-1','','','.w-menu-slider'),(978368,'deals','.w-menu-slider > ul','color','$highlight-box-color-1','','','.w-menu-slider'),(978369,'deals','.b-cookie-notice .cookie-notice.top, .b-cookie-notice .cookie-notice.bottom','color','$warning-background','','','.b-cookie-notice'),(978370,'deals','.w-delivery-location-location-list .deliveryListParrent a','color','$btn-color-2','','','.w-delivery-location-location-list'),(978371,'deals','.w-product-properties-filters-widgets-chosen-filters .item','color','$highlight-box-color-2','','','.w-product-properties-filters-widgets-chosen-filters'),(978372,'deals','.w-product-sale-ends .left-count','color','$highlight-box-color-2','','','.w-product-sale-ends'),(978373,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.p-quick-order-index'),(978374,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.p-quick-order-index'),(978375,'deals','a.btn-2','color_important','important','','',''),(978376,'deals','a.btn-3','color_important','important','','',''),(978377,'deals','a.btn-1','color_important','important','','',''),(978378,'deals','a.btn','color_important','important','','',''),(978379,'deals','.b-select-suggest .select2-default','color_important','important','','','.b-select-suggest'),(978380,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','color_important','important','','','.b-data-table'),(978381,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','color_important','important','1','','.b-data-table'),(978382,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','color_important','important','','','.w-rma-returns-history'),(978383,'deals','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','content','\\f003','3','','.w-checkout-contact-information'),(978384,'deals','.heading-4 .edit, h4 .edit','content','\\e917','4','',''),(978385,'deals','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(978386,'deals','.message.success','content','\\e918','3','',''),(978388,'deals','.p-quick-order-index .paginate_button.next','content','\\f105','3','','.p-quick-order-index'),(978389,'deals','.p-quick-order-index .paginate_button.previous','content','\\f104','3','','.p-quick-order-index'),(978390,'deals','.w-promotions .prom-multi-discount .promo-range .promo-prod-qty','content',',','4','','.w-promotions'),(978391,'deals','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','content','\\_','3','','.w-promotions'),(978392,'deals','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(978393,'deals','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(978394,'deals','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(978397,'deals','.p-sample-checkout-success .page-success','content','\\_','0,3','','.p-sample-checkout-success'),(978398,'deals','.p-sample-checkout-success .page-success .text-1','content','\\e916','3','','.p-sample-checkout-success'),(978399,'deals','.w-promotions .prom-multi-discount','content','\\_','4','','.w-promotions'),(978400,'deals','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(978401,'deals','.testimonials .review','content','\\_','3','',''),(978402,'deals','.w-promotions .prom-multi-discount > .heading','content','\\_','3','','.w-promotions'),(978403,'deals','.w-promotions .nextdiscount .heading','content','\\f07a','3','','.w-promotions'),(978404,'deals','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','content','\\_','3','','.w-promotions'),(978405,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','content','\\f041','3','','.b-warehouses-popup'),(978406,'deals','.b-warehouses-popup .warehouses-popup-link','content','\\f041','3','','.b-warehouses-popup'),(978407,'deals','.b-preloader .preloader','content','\\f110','3','','.b-preloader'),(978408,'deals','.w-product-available-in-warehouses .content','content','\\_','4','','.w-product-available-in-warehouses'),(978409,'deals','.b-products-listing .products-listing .mix-attributes','content','\\_','4','','.b-products-listing'),(978411,'deals','.order-summary .price-row.ot_gv .title','content','\\e99f','3','','.order-summary'),(978412,'deals','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(978413,'deals','.b-messages .messBtnMenuUnread','content','\\f097','3','','.b-messages'),(978414,'deals','.b-messages .messBtnMenuDelete','content','\\e913','3','','.b-messages'),(978415,'deals','.b-messages span.starred::before','content','\\e90e','','','.b-messages'),(978416,'deals','.b-messages .dataTables_wrapper > .top','content','\\_','4','','.b-messages'),(978417,'deals','.b-messages .messBtnMenuStarred','content','\\e90e','3','','.b-messages'),(978418,'deals','.b-messages .icon-circle-with-cross::before','content','×','','','.b-messages'),(978420,'deals','.b-messages .dataTables_wrapper > .bottom','content','\\_','4','','.b-messages'),(978422,'deals','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(978423,'deals','.p-payer-order-confirmation .ship-ico','content','\\e94e','3','','.p-payer-order-confirmation'),(978424,'deals','.p-payer-order-confirmation .order-ico','content','\\e922','3','','.p-payer-order-confirmation'),(978425,'deals','.p-payer-order-confirmation .pay-ico','content','\\e99e','3','','.p-payer-order-confirmation'),(978426,'deals','.p-payer-order-confirmation .discount-ico','content','\\e95e','3','','.p-payer-order-confirmation'),(978427,'deals','.p-payer-order-confirmation .comment-ico','content','\\e99d','3','','.p-payer-order-confirmation'),(978428,'deals','.p-payer-order-pay .ship-ico','content','\\e94e','3','','.p-payer-order-pay'),(978429,'deals','.p-payer-order-pay .pay-ico','content','\\e99e','3','','.p-payer-order-pay'),(978430,'deals','.p-payer-order-pay .order-ico','content','\\e922','3','','.p-payer-order-pay'),(978431,'deals','.p-payer-order-pay .discount-ico','content','\\e95e','3','','.p-payer-order-pay'),(978432,'deals','.p-payer-order-pay .comment-ico','content','\\e99d','3','','.p-payer-order-pay'),(978433,'deals','.b-fancybox .fancybox-close','content','\\f00d','3','','.b-fancybox'),(978434,'deals','.b-messages .select2-search-choice-close','content','\\e913','3','','.b-messages'),(978435,'deals','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','content','\\f095','3','','.w-checkout-contact-information'),(978436,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','content','ttr(data-content','4','','.b-switch'),(978437,'deals','.b-rating .glyphicon-chevron-left','content','\\f104','3','','.b-rating'),(978438,'deals','.w-product-reviews .reviews-list .review','content','\\_','3','','.w-product-reviews'),(978439,'deals','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(978440,'deals','.bell-ico .heading-2','content','\\e9a7','3','','.bell-ico'),(978441,'deals','.b-rating .glyphicon-chevron-right','content','\\f105','3','','.b-rating'),(978442,'deals','.w-upload-customer-id-upload-customer-id-form .upload-remove','content','\\f1f8','3','','.w-upload-customer-id-upload-customer-id-form'),(978443,'deals','.w-coupons-and-vauchers-checkout .btn-remove','content','\\e913','3','','.w-coupons-and-vauchers-checkout'),(978444,'deals','.w-login-block .cols','content','\\_','4','','.w-login-block'),(978445,'deals','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(978447,'deals','.order-summary .price-row.ot_bonus_points .title','content','\\e9a9','3','','.order-summary'),(978448,'deals','.b-bottom .closeable-heading','content','\\f068','3','','.b-bottom'),(978449,'deals','.b-bottom .closeable-heading.closed','content','\\f067','3','','.b-bottom'),(978450,'deals','.b-form .radio-button input[type=\"radio\"].no + span','content','\\f00c','3','','.b-form'),(978451,'deals','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(978452,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','content',' ','3','','.b-switch'),(978453,'deals','.w-social-links .stumbleupon','content','\\f1a4','3','','.w-social-links'),(978454,'deals','.buttons','content','\\_','4','',''),(978455,'deals','.out-stock-icon','content','\\f10c','3','',''),(978456,'deals','.in-stock-icon','content','\\f058','3','',''),(978457,'deals','.transit-icon','content','\\f133','3','',''),(978460,'deals','.w-cart-compare .atr-col','content','\\f070','3','','.w-cart-compare'),(978461,'deals','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(978462,'deals','.b-rating .glyphicon-chevron-up','content','\\f106','3','','.b-rating'),(978464,'deals','.w-tabs .tab-li.tab-sample a','content','\\e984','3','','.w-tabs'),(978465,'deals','.b-upload-file .upload-file-wrap .upload-remove','content','\\e913','3','','.b-upload-file'),(978466,'deals','.w-chat .w-chat-box a','content','\\f075','3','','.w-chat'),(978467,'deals','.b-bottom .footerTitle','content','\\f067','5630,4','','.b-bottom'),(978468,'deals','.closeable-heading','content','\\f067','3','',''),(978469,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow b','content','\\25be','3','','.b-select-suggest'),(978471,'deals','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(978472,'deals','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(978473,'deals','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(978474,'deals','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(978475,'deals','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(978477,'deals','.w-top-categories .categories','content','\\_','4','','.w-top-categories'),(978478,'deals','.w-checkout-billing-address .addresses','content','\\_','4','','.w-checkout-billing-address'),(978481,'deals','.view-all .btn','content','\\f054','4','',''),(978482,'deals','.view-all','content','\\_','3','',''),(978483,'deals','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(978484,'deals','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(978485,'deals','.b-form .newsletter-row','content','\\_','4','','.b-form'),(978486,'deals','.w-checkout-shipping-address .addresses','content','\\_','4','','.w-checkout-shipping-address'),(978487,'deals','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(978488,'deals','.w-quote .cart-box-link','content','\\e90d','3','','.w-quote'),(978489,'deals','.w-tabs .tab-li.tab-wishlist a','content','\\e992','3','','.w-tabs'),(978490,'deals','.w-multi-cart-actions .cart-actions .dropdown-toggle','content','\\f013','3','','.w-multi-cart-actions'),(978492,'deals','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(978493,'deals','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(978494,'deals','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(978495,'deals','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(978496,'deals','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(978497,'deals','.btn-edit','content','\\e917','3','',''),(978498,'deals','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(978499,'deals','.w-login-block .cols','content','\\_','4','','.w-login-block'),(978500,'deals','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(978501,'deals','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(978502,'deals','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(978503,'deals','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(978504,'deals','.b-rating .glyphicon-time','content','\\f017','3','','.b-rating'),(978505,'deals','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(978507,'deals','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(978508,'deals','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(978509,'deals','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(978510,'deals','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(978513,'deals','.w-checkout-shipping-choice input:checked + span:before','content','\\_','','','.w-checkout-shipping-choice'),(978514,'deals','.w-filters .input-checkbox:checked + .checkbox-span:before','content','\\f058','','','.w-filters'),(978515,'deals','.heading-3 .edit, h3 .edit','content','\\e917','4','',''),(978516,'deals','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(978517,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','content','ttr(data-content','4','','.b-switch'),(978518,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','content',' ','3','','.b-switch'),(978519,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','content','ttr(data-content','4','','.b-switch'),(978520,'deals','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(978521,'deals','.w-cart-bonus-points .btn-remove','content','\\e913','3','','.w-cart-bonus-points'),(978522,'deals','.w-cart-compare .product-actions .dropdown-toggle','content','\\f013','3','','.w-cart-compare'),(978524,'deals','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(978526,'deals','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(978527,'deals','.w-reviews .review','content','\\_','3','','.w-reviews'),(978528,'deals','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(978529,'deals','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(978530,'deals','.js-stock-icon','content','\\f00c','3','',''),(978531,'deals','.testimonials .heading-3','content','\\e908','3','',''),(978532,'deals','.b-switch .candlestick-wrapper .fa-check','content','\\f00c','3','','.b-switch'),(978533,'deals','.b-switch .candlestick-wrapper .fa-times','content','\\f00d','3','','.b-switch'),(978534,'deals','.b-fancybox .fancybox-prev span','content','\\e900','3','','.b-fancybox'),(978535,'deals','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(978536,'deals','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(978537,'deals','.w-list-b2b .attributes','content','\\_','4','','.w-list-b2b'),(978538,'deals','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(978539,'deals','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(978540,'deals','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(978541,'deals','.w-socials .post_item > div.fb_post_item','content','\\f082','3','','.w-socials'),(978542,'deals','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(978543,'deals','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(978544,'deals','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(978545,'deals','.w-reviews .heading-3','content','\\e908','3','','.w-reviews'),(978546,'deals','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(978547,'deals','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(978548,'deals','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(978549,'deals','.w-social-links .instagram','content','\\f16d','3','','.w-social-links'),(978550,'deals','.w-social-links .linkedin','content','\\f0e1','3','','.w-social-links'),(978551,'deals','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(978552,'deals','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(978553,'deals','.w-login-block .cols','content','\\_','4','','.w-login-block'),(978554,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span:before','content','\\f1db','','','.b-form'),(978555,'deals','.w-cart-compare .product','content','\\_','4','','.w-cart-compare'),(978556,'deals','.btn-del','content','\\f1f8','4','',''),(978557,'deals','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(978559,'deals','.w-checkout-bonus-points .btn-remove','content','\\e913','3','','.w-checkout-bonus-points'),(978560,'deals','.b-rating .glyphicon-star.coloron','content','\\f005','3','','.b-rating'),(978561,'deals','.w-cart-compare .delete-cart','content','\\2573','3','','.w-cart-compare'),(978562,'deals','.w-cart-shipping-estimator .shipping-estimator','content','\\_','4','','.w-cart-shipping-estimator'),(978563,'deals','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(978564,'deals','.b-form .checkbox-style:checked + .checkbox-span:before','content','\\f058','','','.b-form'),(978565,'deals','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(978566,'deals','.b-form .addresses','content','\\_','4','','.b-form'),(978567,'deals','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(978568,'deals','.w-cart-credit-amount .btn-remove','content','\\e913','3','','.w-cart-credit-amount'),(978571,'deals','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(978572,'deals','.b-info-popup .info-popup','content','\\e918','3','','.b-info-popup'),(978573,'deals','.w-tabs .tab-li.tab-cart a','content','\\e90d','3','','.w-tabs'),(978574,'deals','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(978575,'deals','.b-upload-file .snapshot','content','\\f030','3','','.b-upload-file'),(978576,'deals','.b-form .columns','content','\\_','4','','.b-form'),(978577,'deals','.b-bottom .footerTitle','content','\\f068','5630,2,4','','.b-bottom'),(978578,'deals','.b-bottom .pop-up-close','content','\\f00d','3','','.b-bottom'),(978579,'deals','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','content','\\f004','','','.b-products-listing'),(978580,'deals','.w-cart-shipping-estimator .address-item .lastname','content','\\_','4','','.w-cart-shipping-estimator'),(978581,'deals','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','content','\\f08a','','','.b-products-listing'),(978582,'deals','.b-upload-files .remove-file','content','\\f014','3','','.b-upload-files'),(978583,'deals','.w-reviews-content .review','content','\\_','3','','.w-reviews-content'),(978584,'deals','.w-socials .post_item > div.tw_post_item','content','\\f081','3','','.w-socials'),(978585,'deals','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(978586,'deals','.w-social-links .facebook','content','\\f09a','3','','.w-social-links'),(978587,'deals','.b-fancybox .fancybox-next span','content','\\e901','3','','.b-fancybox'),(978588,'deals','.w-product-customers-activity .close','content','\\2715','3','','.w-product-customers-activity'),(978589,'deals','.w-categories .categories','content','\\_','4','','.w-categories'),(978590,'deals','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(978591,'deals','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(978592,'deals','.w-login-block .cols','content','\\_','4','','.w-login-block'),(978593,'deals','.w-cart-shipping-estimator .item .row: after','content','\\_','','','.w-cart-shipping-estimator'),(978596,'deals','.w-socials .post_item > div.insta_post_item','content','\\f16d','3','','.w-socials'),(978597,'deals','.w-socials .post_item > div','content','\\f16d','3','','.w-socials'),(978598,'deals','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(978601,'deals','.w-social-links .pinterest','content','\\f0d2','3','','.w-social-links'),(978602,'deals','.w-social-links .google-plus','content','\\f2b3','3','','.w-social-links'),(978603,'deals','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(978604,'deals','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(978605,'deals','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(978606,'deals','.w-product-promotions .promotion-data-2 .save-price','content',')','4','','.w-product-promotions'),(978609,'deals','.w-product-promotions .promotion-data-2 .save-price','content','(','3','','.w-product-promotions'),(978610,'deals','.b-rating .glyphicon-chevron-down','content','\\f107','3','','.b-rating'),(978611,'deals','.w-social-links .twitter','content','\\f099','3','','.w-social-links'),(978612,'deals','.w-checkout-create-account .account-benefits strong','content','\\e918','3','','.w-checkout-create-account'),(978614,'deals','.b-products-listing .products-listing .bonus-points-cost','content','\\f219','3','','.b-products-listing'),(978615,'deals','.b-products-listing .products-listing .bonus-points-price','content','\\f219','3','','.b-products-listing'),(978616,'deals','.b-products-listing .products-listing a.btn.view-button','content','\\e991','3','','.b-products-listing'),(978617,'deals','.b-products-listing .BlockBox','content','\\_','4','','.b-products-listing'),(978618,'deals','.b-products-listing .btn-preloader','content','\\f110','3','','.b-products-listing'),(978619,'deals','.b-products-listing .hover-box-content','content','\\_','3','','.b-products-listing'),(978620,'deals','.b-products-listing .loader','content','\\f110','4','','.b-products-listing'),(978621,'deals','.b-products-listing .products-listing','content','\\_','4','','.b-products-listing'),(978622,'deals','.b-products-listing .loader','content','\\_','3','','.b-products-listing'),(978623,'deals','.b-products-listing .products-listing .btn-buy','content','\\e977','3','','.b-products-listing'),(978624,'deals','.b-products-listing .products-listing .qty-input.hidden','content','\\_','3','','.b-products-listing'),(978625,'deals','.checkbox input:not(checked) + span:before','content','\\_','','',''),(978628,'deals','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(978629,'deals','.b-rating .glyphicon-star','content','\\f006','3','','.b-rating'),(978630,'deals','.b-social-login .social-login-text-2','content','\\_','3','','.b-social-login'),(978631,'deals','.b-form .hide-box','content','\\_','3','','.b-form'),(978632,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','content','\\_','3','','.b-switch'),(978633,'deals','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','content','\\f10b','3','','.w-checkout-contact-information'),(978634,'deals','.b-info-popup .info-popup div','content','\\_','3','','.b-info-popup'),(978635,'deals','.w-socials .wrap_socials_posts','content','\\_','4','','.w-socials'),(978636,'deals','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(978637,'deals','.order-summary .price-row.ot_coupon .title','content','%','3','','.order-summary'),(978638,'deals','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(978639,'deals','.b-form .eye-password.eye-password-showed','content','\\f070','3','','.b-form'),(978640,'deals','.b-form .eye-password','content','\\f06e','3','','.b-form'),(978641,'deals','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(978642,'deals','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(978643,'deals','.w-tabs .tab-li.tab-quote a','content','\\e9aa','3','','.w-tabs'),(978644,'deals','.w-login-block .cols','content','\\_','4','','.w-login-block'),(978646,'deals','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','content','\\e913','3','','.order-summary'),(978647,'deals','.w-promo-code .holder','content','\\_','4','','.w-promo-code'),(978648,'deals','.w-promo-code .holder','content','\\e960','3','','.w-promo-code'),(978649,'deals','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(978650,'deals','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(978651,'deals','.w-product-cross-sell .buy-all-checker','content','\\f14a','3','','.w-product-cross-sell'),(978652,'deals','.w-catalog-listing-look .b2b','content','\\f0c9','3','','.w-catalog-listing-look'),(978653,'deals','.w-catalog-listing-look .grid','content','\\f009','3','','.w-catalog-listing-look'),(978654,'deals','.checkbox input:checked + span:before','content','\\f00c','','',''),(978655,'deals','.w-cart-listing .multi-product-copy','content','\\e922','3','','.w-cart-listing'),(978656,'deals','.w-cart-listing .multi-product-delete','content','\\e913','3','','.w-cart-listing'),(978657,'deals','.w-cart-listing .multi-product-move','content','\\e975','3','','.w-cart-listing'),(978658,'deals','.w-cart-listing .points-redeem','content','\\f219','3','','.w-cart-listing'),(978659,'deals','.w-cart-listing .item .gift-wrap .value','content',')','4','','.w-cart-listing'),(978660,'deals','.w-cart-listing .item .gift-wrap .value','content','(','3','','.w-cart-listing'),(978661,'deals','.w-cart-listing .remove-btn','content','\\f014','3','','.w-cart-listing'),(978662,'deals','.w-cart-give-away .ga_name','content','\\_','4','','.w-cart-give-away'),(978666,'deals','.w-cart-discount-coupon .btn-remove','content','\\e913','3','','.w-cart-discount-coupon'),(978667,'deals','.b-dropdown .dropdown .dropdown-toggle','content','\\f0d7','4','','.b-dropdown'),(978668,'deals','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(978669,'deals','.b-compare .clear_all','content','\\f00d','4','','.b-compare'),(978670,'deals','.w-filters .open','content','\\f106','3','','.w-filters'),(978672,'deals','.w-checkout-credit-amount .btn-remove','content','\\e913','3','','.w-checkout-credit-amount'),(978673,'deals','.w-filters .fsl_handle','content','\\_','4','','.w-filters'),(978674,'deals','.w-filters .view_more','content','\\f061','4','','.w-filters'),(978675,'deals','.w-filters span.close','content','\\f107','3','','.w-filters'),(978676,'deals','.p-quote-checkout-success .page-success .text-1','content','\\e916','3','','.p-quote-checkout-success'),(978677,'deals','.w-catalog-listing-look .list','content','\\f00b','3','','.w-catalog-listing-look'),(978678,'deals','.p-quote-checkout-success .page-success','content','\\_','0,3','','.p-quote-checkout-success'),(978679,'deals','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(978680,'deals','.b-social-login .social-login-text-2','content','\\_','4','','.b-social-login'),(978681,'deals','.w-login-block .cols','content','\\_','4','','.w-login-block'),(978682,'deals','.b-tracking-numbers .tracking-numbers .item','content','\\_','4','','.b-tracking-numbers'),(978686,'deals','.b-rating .glyphicon-calendar','content','\\f073','3','','.b-rating'),(978687,'deals','.w-filters .mobileCollapse','content','\\f056','2,4','','.w-filters'),(978688,'deals','.w-filters .mobileCollapse','content','\\f055','4','','.w-filters'),(978689,'deals','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','content','\\f1db','','','.w-filters'),(978690,'deals','.b-product-images .media-popup .mp-close','content','\\f00d','3','','.b-product-images'),(978691,'deals','.b-product-images .media-popup .slick-dots li','content','\\2022','3','','.b-product-images'),(978692,'deals','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','content','\\f0c9','3','','.b-menu-burger_icon'),(978693,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(978694,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(978695,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(978696,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(978697,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(978698,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(978699,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(978700,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(978701,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','content','+','3','','.b-menu-lev_vis-click_icon'),(978702,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > .open-close-ico','content','-','3','','.b-menu-lev_vis-click_icon'),(978703,'deals','.b-trade-approval .columns','content','\\_','4','','.b-trade-approval'),(978704,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','content','\\e90d','3','','.w-catalog-compare'),(978705,'deals','.w-catalog-compare td span + span','content','| ','3','','.w-catalog-compare'),(978706,'deals','.w-catalog-compare .checkbox input:checked + span:before','content','\\f014','','','.w-catalog-compare'),(978708,'deals','.b-slick .slick-track, .b-slick .slick-track:after','content','\\_','3','','.b-slick'),(978709,'deals','.b-slick .slick-vertical button.slick-next','content','\\f078','3','','.b-slick'),(978710,'deals','.b-slick .slick-vertical button.slick-prev','content','\\f077','3','','.b-slick'),(978711,'deals','.b-slick button.slick-next','content','\\f054','3','','.b-slick'),(978712,'deals','.b-slick button.slick-prev','content','\\f053','3','','.b-slick'),(978713,'deals','.b-products-listing .add-to-personal-catalog','content','\\f08a','3','','.b-products-listing'),(978714,'deals','.b-products-listing .del-from-personal-catalog','content','\\f014','3','','.b-products-listing'),(978715,'deals','.w-bestsellers .products-listing .item','content','\\_','3','','.w-bestsellers'),(978716,'deals','.w-quote .multicart .count','content','(','3','','.w-quote'),(978717,'deals','.w-quote .multicart .count','content',')','4','','.w-quote'),(978718,'deals','.w-quote .multicart .item.current-multi-cart .switch-cart','content','\\f058','3','','.w-quote'),(978719,'deals','.w-quote .multicart .switch-cart','content','\\f111','3','','.w-quote'),(978720,'deals','.w-quote .qty','content','\\274c','4','','.w-quote'),(978721,'deals','.w-quote a.item','content','\\_','4','','.w-quote'),(978722,'deals','.w-product-personal-catalog-button .del_to_personal_catalog','content','\\f004','3','','.w-product-personal-catalog-button'),(978723,'deals','.w-product-personal-catalog-button .add_to_personal_catalog','content','\\f08a','3','','.w-product-personal-catalog-button'),(978724,'deals','.b-quantity .qty-box .bigger','content','+','3','','.b-quantity'),(978725,'deals','.b-quantity .qty-box .smaller','content','-','3','','.b-quantity'),(978726,'deals','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','content','\\e90d','3','','.w-product-buttons'),(978727,'deals','.w-product-quantity .qty_packs .price_1','content','x','4','','.w-product-quantity'),(978728,'deals','.w-product-quantity .qty_packs .qty-input','content','\\_','4','','.w-product-quantity'),(978729,'deals','.w-product-bonus-points > div','content','\\_','4','','.w-product-bonus-points'),(978730,'deals','.w-product-bonus-points > div > div','content','\\f219','3','','.w-product-bonus-points'),(978731,'deals','.warrantyProduct .warranty','content','\\_','3','','.warrantyProduct'),(978732,'deals','.warrantyProduct .delivery','content','\\_','3','','.warrantyProduct'),(978733,'deals','.w-compare .remove','content','\\f014','3','','.w-compare'),(978734,'deals','.w-files-catalog-widgets-files-list .file','content','\\f1c1','3','','.w-files-catalog-widgets-files-list'),(978735,'deals','.w-sample .cart-box-link','content','\\_','4','','.w-sample'),(978736,'deals','.w-sample .cart-box-link','content','\\e90d','3','','.w-sample'),(978737,'deals','.w-sample .multicart .count','content','(','3','','.w-sample'),(978738,'deals','.w-sample .multicart .count','content',')','4','','.w-sample'),(978739,'deals','.w-sample .multicart .item.current-multi-cart .switch-cart','content','\\f058','3','','.w-sample'),(978740,'deals','.w-sample .multicart .switch-cart','content','\\f111','3','','.w-sample'),(978741,'deals','.w-sample .qty','content','\\f00d ','4','','.w-sample'),(978742,'deals','.w-sample a.item','content','\\_','4','','.w-sample'),(978743,'deals','.w-cart-gift-certificate .gift-certificate .heading-4','content','\\e912','3','','.w-cart-gift-certificate'),(978744,'deals','.w-product-bundle > div','content','\\_','4','','.w-product-bundle'),(978746,'deals','.b-products-listing .products-listing .radio-attributes','content','\\_','4','','.b-products-listing'),(978747,'deals','.b-pagination .pagination','content','\\_','4','','.b-pagination'),(978748,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','content','\\f105','3','','.b-pagination'),(978749,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','content','\\f104','3','','.b-pagination'),(978750,'deals','.w-product-multi-inventory .select-box:last-of-type:after','content','\\_','','','.w-product-multi-inventory'),(978751,'deals','.w-product-properties-filters-widgets-chosen-filters .remove','content','\\2716','3','','.w-product-properties-filters-widgets-chosen-filters'),(978752,'deals','.w-product-multi-inventory #product-attributes','content','\\_','4','','.w-product-multi-inventory'),(978753,'deals','.p-sample-checkout-index .order-summary .heading-2','content','\\_','3','','.p-sample-checkout-index'),(978754,'deals','.p-sample-checkout-index .order-summary .heading-2','content','\\_','4','','.p-sample-checkout-index'),(978755,'deals','.w-product-multi-inventory .radio-attributes','content','\\_','4','','.w-product-multi-inventory'),(978756,'deals','.w-product-quantity-discounts .quantity-discounts','content','\\_','4','','.w-product-quantity-discounts'),(978757,'deals','.w-product-collection .right-area .btn','content','\\e90d','3','','.w-product-collection'),(978758,'deals','.w-product-collection .right-area .btn-2','content','\\e90d','3','','.w-product-collection'),(978759,'deals','.w-product-attributes #product-attributes','content','\\_','4','','.w-product-attributes'),(978760,'deals','.w-product-attributes .radio-attributes','content','\\_','4','','.w-product-attributes'),(978761,'deals','.w-product-attributes .select-box:last-of-type:after','content','\\_','','','.w-product-attributes'),(978762,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"1\"] + span','content','\\2714','3','','.w-questionnaire-widgets-questionnaire'),(978763,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input[value=\"0\"] + span','content','\\2718','3','','.w-questionnaire-widgets-questionnaire'),(978764,'deals','.w-product-groups .prop-group-swatch','content','\\_','4','','.w-product-groups'),(978765,'deals','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','content','\\e90d','3','','.w-product-custom-bundle'),(978766,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list'),(978767,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list-block'),(978768,'deals','.w-delivery-location-location-list ul','content','\\_','4','','.w-delivery-location-location-list'),(978769,'deals','.w-delivery-location-featured-list .deliveryList ul','content','\\_','4','','.w-delivery-location-featured-list'),(978770,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list-by-catalog'),(978771,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(978772,'deals','.w-delivery-location-list-by-page .page-list','content','\\_','4','','.w-delivery-location-list-by-page'),(978773,'deals','.w-delivery-location-top-location-list .deliveryList','content','\\_','4','','.w-delivery-location-top-location-list'),(978774,'deals','.w-delivery-location-cross-pages .page-list','content','\\_','4','','.w-delivery-location-cross-pages'),(978775,'deals','.delivery-options-popup','content','\\_','4','',''),(978776,'deals','.w-support-system-filter .dd3-content .collapse_span','content','\\f056','3','','.w-support-system-filter'),(978777,'deals','.w-support-system-filter .dd3-content .collapse_span.clouse','content','\\f055','3','','.w-support-system-filter'),(978778,'deals','.w-communication-post .btn.refresh','content','\\21bb','3','','.w-communication-post'),(978779,'deals','.w-rma-returns-history .icons .excel','content','\\f1c3','3','','.w-rma-returns-history'),(978780,'deals','.w-rma-returns-history .icons .print','content','\\f02f','3','','.w-rma-returns-history'),(978781,'deals','.w-rma-returns-history .linkButton','content','\\f105','4','','.w-rma-returns-history'),(978782,'deals','.w-product-configurator .pc_row','content','\\_','4','','.w-product-configurator'),(978783,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','content','\\_','4','','.w-catalog-pages-category-pages-list'),(978784,'deals','.w-predefined-promotion .nextdiscount .heading','content','\\f07a','3','','.w-predefined-promotion'),(978785,'deals','.w-predefined-promotion .prom-multi-discount','content','\\_','4','','.w-predefined-promotion'),(978786,'deals','.w-predefined-promotion .prom-multi-discount .promo-range .promo-prod-qty','content',',','4','','.w-predefined-promotion'),(978787,'deals','.w-predefined-promotion .prom-multi-discount > .heading','content','\\_','3','','.w-predefined-promotion'),(978788,'deals','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','content','\\_','3','','.w-predefined-promotion'),(978789,'deals','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','content','\\_','3','','.w-predefined-promotion'),(978790,'deals','.w-supplier-purchase-supplier-products .active .select_item > div:before','content','\\f00c','','','.w-supplier-purchase-supplier-products'),(978791,'deals','.headerWrap .searchIcon','content','\\f002','3','','.headerWrap'),(978792,'deals','.headerWrap .searchIcon.open','content','\\f00d','3','','.headerWrap'),(978793,'deals','.headerWrap .w-contacts.phone','content','\\f095','3','','.headerWrap'),(978794,'deals','.headerWrap .menu-style[data-style=\"1\"] li.back-button','content','\\f104','3','','.headerWrap'),(978795,'deals','.filterLine .choose-filters li .btn-clear','content','x','4','','.filterLine'),(978796,'deals','.w-breadcrumb .breadcrumb-li','content','\\f105','4','','.w-breadcrumb'),(978797,'deals','.messageBox .info','content','\\e918','3','',''),(978798,'deals','.homeBanner .carousel .bottom-center > span','content','\\_','3','','.homeBanner'),(978799,'deals','.b-products-listing .select-attributes','content','\\_','4','','.b-products-listing'),(978800,'deals','.b-info .info','content','\\e918','3','','.b-info'),(978801,'deals','.w-neighbour-checkout .neighbour-box','content','\\_','4','','.w-neighbour-checkout'),(978802,'deals','.b-sub-totals .historyTotal','content','\\_','4','','.b-sub-totals'),(978803,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li.parent > a','content','\\f105','5630,4','','.headerWrap'),(978804,'deals','.w-account-personal-catalog .list-row-action ul','content','\\f107','4','','.w-account-personal-catalog'),(978805,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li .no-link','content','+','5630,4','','.preFooter'),(978806,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li.vis-show .no-link','content','-','5630,4','','.preFooter'),(978807,'deals','.p-wedding-registry-view h1','content','\\f004','3','','.p-wedding-registry-view'),(978808,'deals','.p-wedding-registry-view h1','content','\\f004','4','','.p-wedding-registry-view'),(978809,'deals','.w-product-wishlist-button .btn','content','\\e98e','3','','.w-product-wishlist-button'),(978810,'deals','.homeBanner .text-bottom-center .banner-text-holder','content','\\_','3','','.homeBanner'),(978811,'deals','.homeBanner .text-bottom-left .banner-text-holder','content','\\_','3','','.homeBanner'),(978812,'deals','.homeBanner .text-bottom-right .banner-text-holder','content','\\_','3','','.homeBanner'),(978813,'deals','.order-summary ','content','\\f068','','','.order-summary'),(978814,'deals','.order-summary .icon','content','\\f068','','','.order-summary'),(978815,'deals','.order-summary .icon','content','\\f067','3','','.order-summary'),(978816,'deals','.order-summary .icon.opened','content','\\f068','3','','.order-summary'),(978817,'deals','.w-cart-discount-coupon .title','content','\\f106','','','.w-cart-discount-coupon'),(978818,'deals','.w-cart-discount-coupon .title','content','\\f107','4','','.w-cart-discount-coupon'),(978819,'deals','.w-cart-discount-coupon .title.opened','content','\\f106','4','','.w-cart-discount-coupon'),(978820,'deals','.w-cart-shipping-estimator .left-area','content','\\_','5630,4','','.w-cart-shipping-estimator'),(978821,'deals','.w-cart-checkout-btn .with-card','content','\\f283','4','','.w-cart-checkout-btn'),(978822,'deals','.w-promotions-widgets-promotions .promotion-data-2 .save-price','content','(','3','','.w-promotions-widgets-promotions'),(978823,'deals','.w-promotions-widgets-promotions .promotion-data-2 .save-price','content',')','4','','.w-promotions-widgets-promotions'),(978840,'deals','.account-address-book .btn-edit','content','\\e917','4','','.account-address-book'),(978845,'deals','.account-order-pay .historyInfoColumn h2.title-delivery-address, .account-order-pay .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-order-pay'),(978846,'deals','.account-order-pay .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-order-pay'),(978847,'deals','.account-order-pay .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-order-pay'),(978848,'deals','.account-samples .view_link','content','\\e901','4','','.account-samples'),(978849,'deals','.account-sample-info .historyInfoColumn h2.title-delivery-address, .account-sample-info .historyInfoColumn h2.title-billing-address','content','\\e905','3','','.account-sample-info'),(978850,'deals','.account-sample-info .historyInfoColumn h2.title-payment','content','\\e925','3','','.account-sample-info'),(978851,'deals','.account-sample-info .historyInfoColumn h2.title-ship-method','content','\\e91e','3','','.account-sample-info'),(978852,'deals','.catalog-product-wrap .next-product .pn-image','content','\\f054','3','','.catalog-product-wrap'),(978853,'deals','.catalog-product-wrap .prev-product .pn-image','content','\\f053','3','','.catalog-product-wrap'),(978854,'deals','.shopping-cart-index .gift-code .heading-4','content','\\f068','2,4','','.shopping-cart-index'),(978855,'deals','.shopping-cart-index .gift-code .heading-4','content','\\f067','4','','.shopping-cart-index'),(978856,'deals','.checkout-index-wrap .order-ico','content','\\e922','3','','.checkout-index-wrap'),(978857,'deals','.checkout-index-wrap .pay-ico','content','\\e99e','3','','.checkout-index-wrap'),(978858,'deals','.checkout-index-wrap .ship-ico','content','\\e94e','3','','.checkout-index-wrap'),(978859,'deals','.checkout-order-confirmation .comment-ico','content','\\e99d','3','','.checkout-order-confirmation'),(978860,'deals','.checkout-order-confirmation .discount-ico','content','\\e95e','3','','.checkout-order-confirmation'),(978861,'deals','.checkout-order-confirmation .order-ico','content','\\e922','3','','.checkout-order-confirmation'),(978862,'deals','.checkout-order-confirmation .ship-ico','content','\\e94e','3','','.checkout-order-confirmation'),(978863,'deals','.checkout-success-wrap .page-success','content','\\_','3','','.checkout-success-wrap'),(978864,'deals','.checkout-success-wrap .page-success .text-1','content','\\e916','3','','.checkout-success-wrap'),(978865,'deals','.b-slick .slick-dots li','content','\\_','3','','.b-slick'),(978866,'deals','.success-page .check-ico-block','content','\\e916','3','','.success-page'),(978867,'deals','.success-page .comment-ico','content','\\e99d','3','','.success-page'),(978868,'deals','.success-page .discount-ico','content','\\e95e','3','','.success-page'),(978869,'deals','.success-page .order-ico','content','\\e922','3','','.success-page'),(978870,'deals','.success-page .page-success','content','\\_','3','','.success-page'),(978871,'deals','.success-page .page-success .text-1','content','\\e916','3','','.success-page'),(978872,'deals','.success-page .pay-ico','content','\\e99e','3','','.success-page'),(978873,'deals','.success-page .prod-ico','content','\\e99b','3','','.success-page'),(978874,'deals','.success-page .ship-ico','content','\\e94e','3','','.success-page'),(978876,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-content','content','\\_','4','','.b-multi-page-checkout'),(978877,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','content','\\f00c','3','','.b-multi-page-checkout'),(978878,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','content','\\e917','4','','.b-multi-page-checkout'),(978881,'deals','.footer-menu .level-2 > li.component-item','content','\\_','3','','.footer-menu'),(978882,'deals','.footer-menu .level-1 > li .no-link','content','\\f0c9','5639,3','','.footer-menu'),(978883,'deals','.w-catalog-paging .next','content','\\f105','3','','.w-catalog-paging'),(978884,'deals','.w-catalog-paging .prev','content','\\f104','3','','.w-catalog-paging'),(978890,'deals','.w-menu-slider .close','content','\\f00d','3','','.w-menu-slider'),(978891,'deals','.b-rating .glyphicon-chevron-left','content_important','important','3','','.b-rating'),(978892,'deals','.b-rating .glyphicon-chevron-right','content_important','important','3','','.b-rating'),(978893,'deals','.b-rating .glyphicon-chevron-up','content_important','important','3','','.b-rating'),(978894,'deals','.b-rating .glyphicon-chevron-down','content_important','important','3','','.b-rating'),(978895,'deals','.b-rating .glyphicon-calendar','content_important','important','3','','.b-rating'),(978896,'deals','.b-rating .glyphicon-time','content_important','important','3','','.b-rating'),(978897,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor','default','','','.b-switch'),(978898,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','cursor','pointer','','','.b-switch'),(978899,'deals','.p-quick-order-index .filters .clear','cursor','pointer','','','.p-quick-order-index'),(978900,'deals','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','cursor','pointer','3','','.order-summary'),(978901,'deals','.b-messages .messMenuButton span','cursor','pointer','','','.b-messages'),(978902,'deals','.b-fancybox #fancybox-loading','cursor','pointer','','','.b-fancybox'),(978903,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file','cursor','pointer','','','.w-upload-customer-id-upload-customer-id-form'),(978904,'deals','.b-switch .bootstrap-switch','cursor','pointer','','','.b-switch'),(978905,'deals','.w-coupons-and-vauchers-checkout .btn-remove','cursor','pointer','','','.w-coupons-and-vauchers-checkout'),(978906,'deals','.b-autocomplete .ui-autocomplete li','cursor','pointer','','','.b-autocomplete'),(978908,'deals','.w-filters .open, .w-filters .close','cursor','pointer','','','.w-filters'),(978909,'deals','.w-checkout-shipping-choice span','cursor','pointer','','','.w-checkout-shipping-choice'),(978910,'deals','.w-cart-compare .atr-col','cursor','pointer','','','.w-cart-compare'),(978911,'deals','.w-tabs .tab-a','cursor','pointer','','','.w-tabs'),(978912,'deals','.w-tabs .tab-a','cursor','default','2','','.w-tabs'),(978913,'deals','.disabled-area','cursor','not-allowed','','',''),(978914,'deals','.disabled-area *','cursor','not-allowed','','',''),(978916,'deals','.b-form .radio-button input[type=\"radio\"].no + span','cursor','pointer','3','','.b-form'),(978917,'deals','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','cursor','pointer','','','.b-switch'),(978918,'deals','.w-cart-bonus-points .btn-remove','cursor','pointer','','','.w-cart-bonus-points'),(978919,'deals','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','','','.b-select-suggest'),(978920,'deals','.b-select-suggest .select2-container .select2-choice abbr','cursor','pointer','1','','.b-select-suggest'),(978921,'deals','.b-switch .candlestick-wrapper .candlestick-bg.grab:not(.candlestick-disabled ) .candlestick-toggle','cursor','grab','','','.b-switch'),(978922,'deals','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled','cursor','not-allowed','','','.b-switch'),(978923,'deals','.b-fancybox .fancybox-close','cursor','pointer','','','.b-fancybox'),(978924,'deals','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','cursor','default','','','.b-select-suggest'),(978925,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor','default','','','.b-switch'),(978926,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor','default','','','.b-switch'),(978927,'deals','.w-checkout-bonus-points .btn-remove','cursor','pointer','','','.w-checkout-bonus-points'),(978928,'deals','.w-checkout-credit-amount .btn-remove','cursor','pointer','','','.w-checkout-credit-amount'),(978929,'deals','.b-upload-file .snapshot','cursor','pointer','','','.b-upload-file'),(978930,'deals','.b-form .item-radio label','cursor','pointer','','','.b-form'),(978931,'deals','.b-bottom .footerTitle','cursor','pointer','5630','','.b-bottom'),(978932,'deals','.b-products-listing .products-listing .wishlistButton .checkbox','cursor','pointer','','','.b-products-listing'),(978933,'deals','.w-cart-credit-amount .btn-remove','cursor','pointer','','','.w-cart-credit-amount'),(978934,'deals','.w-product-customers-activity .close','cursor','pointer','','','.w-product-customers-activity'),(978935,'deals','.b-form .item-radio.active label','cursor','default','','','.b-form'),(978936,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor','default','','','.b-switch'),(978937,'deals','.b-fancybox .fancybox-nav','cursor','pointer','','','.b-fancybox'),(978939,'deals','.closeable-event','cursor','pointer','','',''),(978940,'deals','.b-form .addresses.address-main .address-item label','cursor','default','','','.b-form'),(978941,'deals','.w-checkout-shipping-choice input:checked + span','cursor','default','','','.w-checkout-shipping-choice'),(978942,'deals','.w-tabs .accordion-heading','cursor','default','2','','.w-tabs'),(978943,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices','cursor','default','','','.b-select-suggest'),(978944,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice .select2-chosen','cursor','default','','','.b-select-suggest'),(978945,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','cursor','default','','','.b-select-suggest'),(978946,'deals','.b-select-suggest .select2-container-multi .select2-choices','cursor','text','','','.b-select-suggest'),(978947,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice','cursor','default','','','.b-select-suggest'),(978948,'deals','.b-select-suggest .select2-results .select2-disabled','cursor','default','','','.b-select-suggest'),(978949,'deals','.b-select-suggest .select2-results .select2-result-label','cursor','pointer','','','.b-select-suggest'),(978952,'deals','.b-form .eye-password','cursor','pointer','','','.b-form'),(978953,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','cursor','pointer','','','.w-communication-new-topic'),(978954,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','cursor','pointer','','','.w-communication-new-topic'),(978955,'deals','.w-filters .ui-slider-handle','cursor','pointer','','','.w-filters'),(978956,'deals','.w-cart-discount-coupon .btn-remove','cursor','pointer','','','.w-cart-discount-coupon'),(978957,'deals','.b-fancybox .fancybox-nav span','cursor','pointer','','','.b-fancybox'),(978958,'deals','.w-tabs .accordion-heading','cursor','pointer','','','.w-tabs'),(978959,'deals','.w-filters .filter-box-content ul li.view_items','cursor','pointer','','','.w-filters'),(978960,'deals','.b-bottom .pop-up-close','cursor','pointer','','','.b-bottom'),(978961,'deals','.b-upload-files .remove-file','cursor','pointer','','','.b-upload-files'),(978963,'deals','.w-menu-big .show-all','cursor','pointer','','','.w-menu-big'),(978964,'deals','.b-form .addresses .address-item label','cursor','pointer','','','.b-form'),(978965,'deals','.w-filters .mobileCollapse','cursor','pointer','4','','.w-filters'),(978966,'deals','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','cursor','pointer','','','.b-product-images'),(978967,'deals','.b-product-images .media-popup .mp-close','cursor','pointer','','','.b-product-images'),(978968,'deals','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','cursor','pointer','','','.b-product-images'),(978969,'deals','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','cursor','pointer','','','.b-menu-burger_icon'),(978970,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(978971,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(978972,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(978973,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(978974,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','cursor','pointer','','','.b-menu-lev_vis-click_icon'),(978975,'deals','.w-account-personal-catalog .list-switcher a','cursor','pointer','','','.w-account-personal-catalog'),(978976,'deals','.w-account-personal-catalog .list-switcher a','cursor','default','2','','.w-account-personal-catalog'),(978977,'deals','.w-catalog-compare .compare label','cursor','pointer','','','.w-catalog-compare'),(978978,'deals','.w-catalog-compare .cross-box .different-all > div','cursor','pointer','','','.w-catalog-compare'),(978979,'deals','.w-catalog-compare .cross-box .different-all > div','cursor','default','2','','.w-catalog-compare'),(978980,'deals','.w-catalog-compare .cross-box .return','cursor','pointer','','','.w-catalog-compare'),(978981,'deals','.b-slick button.slick-disabled','cursor','default','','','.b-slick'),(978982,'deals','.b-quantity .qty-box .bigger','cursor','pointer','','','.b-quantity'),(978983,'deals','.b-quantity .qty-box .disabled','cursor','default','','','.b-quantity'),(978984,'deals','.b-quantity .qty-box .smaller','cursor','pointer','','','.b-quantity'),(978985,'deals','.w-product-buttons #btn-cart-none','cursor','default','','','.w-product-buttons'),(978986,'deals','.w-compare .clear-compare-button','cursor','pointer','','','.w-compare'),(978987,'deals','.w-compare .remove','cursor','pointer','','','.w-compare'),(978988,'deals','.w-product-video .item img, .w-product-video .item video','cursor','pointer','','','.w-product-video'),(978989,'deals','.w-product-properties-filters-widgets-chosen-filters .remove','cursor','pointer','','','.w-product-properties-filters-widgets-chosen-filters'),(978990,'deals','.w-product-multi-inventory .radio-attributes input:checked + .option-item','cursor','default','','','.w-product-multi-inventory'),(978991,'deals','.w-product-multi-inventory .radio-attributes .option-item','cursor','pointer','','','.w-product-multi-inventory'),(978992,'deals','.b-products-listing .products-listing .radio-attributes .option','cursor','pointer','','','.b-products-listing'),(978993,'deals','.b-products-listing .products-listing .radio-attributes input:checked + .option','cursor','default','','','.b-products-listing'),(978994,'deals','.w-product-attributes .radio-attributes .option-item','cursor','pointer','','','.w-product-attributes'),(978995,'deals','.w-product-attributes .radio-attributes input:checked + .option-item','cursor','default','','','.w-product-attributes'),(978996,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','cursor','pointer','','','.w-questionnaire-widgets-questionnaire'),(978997,'deals','.w-product-designer-designer .prodDesignerType label','cursor','pointer','','','.w-product-designer-designer'),(978998,'deals','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','cursor','pointer','','','.w-press-reviews-widgets-press-reviews-small'),(978999,'deals','.w-support-system-filter .dd3-content .collapse_span','cursor','pointer','3','','.w-support-system-filter'),(979000,'deals','.w-support-system-listing .pm-head-2','cursor','pointer','','','.w-support-system-listing'),(979001,'deals','.headerWrap .searchIcon','cursor','pointer','','','.headerWrap'),(979002,'deals','.headerWrap .menu-style[data-style=\"1\"] li.back-button','cursor','pointer','1','','.headerWrap'),(979003,'deals','.headerWrap .menu-style[data-style=\"1\"] .level-1 > .parent','cursor','pointer','1','','.headerWrap'),(979004,'deals','.filterLine .before','cursor','pointer','','','.filterLine'),(979005,'deals','.filterLine .choose-filters li .btn-clear','cursor','pointer','','','.filterLine'),(979006,'deals','.w-product-groups .property-category-heading','cursor','pointer','','','.w-product-groups'),(979007,'deals','.headerWrap .menu-style[data-style=\"1\"] li.back-button','cursor','pointer','5705,1','','.headerWrap'),(979008,'deals','.order-summary .icon','cursor','pointer','','','.order-summary'),(979009,'deals','.w-cart-discount-coupon .title','cursor','pointer','','','.w-cart-discount-coupon'),(979012,'deals','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-order-pay'),(979013,'deals','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-order-pay'),(979014,'deals','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','cursor','not-allowed','','','.account-sample-info'),(979015,'deals','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr .btn, .account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr a','cursor','not-allowed','','','.account-sample-info'),(979016,'deals','.shopping-cart-index .gift-code .heading-4','cursor','pointer','5630','','.shopping-cart-index'),(979017,'deals','.b-slick .slick-dots li','cursor','pointer','','','.b-slick'),(979018,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','cursor','pointer','','','.b-multi-page-checkout'),(979021,'deals','.w-menu-slider .close','cursor','pointer','','','.w-menu-slider'),(979022,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled, .b-switch .bootstrap-switch.bootstrap-switch-readonly, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate','cursor_important','important','','','.b-switch'),(979023,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','cursor_important','important','','','.b-switch'),(979024,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','cursor_important','important','','','.b-switch'),(979025,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','cursor_important','important','','','.b-switch'),(979026,'deals','.b-quantity .qty-box .disabled','cursor_important','important','','','.b-quantity'),(979027,'deals','.b-switch .bootstrap-switch','direction','ltr','','','.b-switch'),(979028,'deals','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(979029,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(979030,'deals','.message.success','display','inline-block','3','',''),(979031,'deals','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(979034,'deals','.w-filters .mobileCollapse','display','inline-block','5639','','.w-filters'),(979035,'deals','.p-quick-order-index ul.token-input-list','display','inline-block','','','.p-quick-order-index'),(979036,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.p-quick-order-index'),(979037,'deals','.w-promotions .promo-salemaker .content a.name','display','block','','','.w-promotions'),(979038,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.p-quick-order-index'),(979039,'deals','.w-promotions .prom-multi-discount .promo-range > div','display','inline-block','','','.w-promotions'),(979040,'deals','.w-promotions .promo-salemaker','display','flex','','','.w-promotions'),(979041,'deals','.w-promotions .promo-cart-discount .promo-min-qty','display','inline-block','','','.w-promotions'),(979042,'deals','.w-promotions .promo-date > div','display','inline-block','','','.w-promotions'),(979043,'deals','.w-promotions .promo-cart-discount','display','flex','','','.w-promotions'),(979052,'deals','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(979053,'deals','.p-sample-checkout-success .page-success .text-1','display','block','3','','.p-sample-checkout-success'),(979054,'deals','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(979055,'deals','.w-promotions .prom-multi-discount','display','block','4','','.w-promotions'),(979056,'deals','.testimonials .review','display','block','3','',''),(979057,'deals','.w-categories .image','display','block','','','.w-categories'),(979058,'deals','.w-promotions .prom-multi-discount .promo-range','display','inline-block','','','.w-promotions'),(979059,'deals','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','display','block','','','.w-promotions'),(979060,'deals','.w-promotions .prom-multi-discount .products','display','grid','','','.w-promotions'),(979061,'deals','.w-promotions .prom-multi-discount .list','display','grid','','','.w-promotions'),(979062,'deals','.w-promotions .nextdiscount .promo-for-each','display','inline-block','','','.w-promotions'),(979063,'deals','.w-promotions .nextdiscount .item-holder','display','flex','','','.w-promotions'),(979064,'deals','.w-promotions .nextdiscount .content','display','grid','','','.w-promotions'),(979065,'deals','.w-promotions .heading-3','display','inline-block','','','.w-promotions'),(979066,'deals','.w-promotions .icon','display','inline-block','','','.w-promotions'),(979067,'deals','.w-promotions .promo-salemaker .discount','display','inline-block','','','.w-promotions'),(979068,'deals','.w-promotions .promo-salemaker .content','display','flex','','','.w-promotions'),(979069,'deals','.w-promotions .promo-content > .personalgift','display','none','','','.w-promotions'),(979070,'deals','.w-promotions .promo-cart-discount .slave','display','flex','','','.w-promotions'),(979071,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','display','inline-block','','','.w-promotions'),(979072,'deals','.w-promotions .promo-cart-discount .item a','display','block','','','.w-promotions'),(979073,'deals','.w-promotions .promo-cart-discount .content','display','flex','','','.w-promotions'),(979074,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','display','inline-block','','','.b-warehouses-popup'),(979075,'deals','.w-product-available-in-warehouses .content','display','block','4','','.w-product-available-in-warehouses'),(979076,'deals','.b-preloader .preloader','display','inline-block','3','','.b-preloader'),(979077,'deals','.w-product-available-in-warehouses .warehouse-item','display','inline-block','','','.w-product-available-in-warehouses'),(979078,'deals','.b-products-listing .products-listing .mix-attributes','display','block','4','','.b-products-listing'),(979079,'deals','.b-products-listing .products-listing .attribute-qty-blocks','display','flex','','','.b-products-listing'),(979081,'deals','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(979082,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(979083,'deals','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(979084,'deals','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(979086,'deals','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(979087,'deals','.b-messages .messBtnMenuDelete','display','inline-block','3','','.b-messages'),(979088,'deals','.b-messages .messMenuButton span','display','inline-block','','','.b-messages'),(979089,'deals','.b-messages .msv_to_cc div span','display','inline-block','','','.b-messages'),(979090,'deals','.b-messages span.starred::before','display','inline-block','','','.b-messages'),(979091,'deals','.b-messages .dataTables_wrapper > .top','display','block','4','','.b-messages'),(979092,'deals','.b-messages .messBtnMenuStarred','display','inline-block','3','','.b-messages'),(979093,'deals','.b-messages .messBtnMenuUnread','display','inline-block','3','','.b-messages'),(979094,'deals','.b-messages .messages-menu li a','display','block','','','.b-messages'),(979095,'deals','.b-messages .content_management_attach button','display','inline-block','','','.b-messages'),(979096,'deals','.b-messages .email-line','display','flex','','','.b-messages'),(979097,'deals','.b-messages .dataTables_wrapper > .bottom','display','block','4','','.b-messages'),(979098,'deals','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(979099,'deals','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(979100,'deals','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(979101,'deals','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(979102,'deals','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(979103,'deals','.order-summary .price-row.ot_gv .title','display','inline-block','3','','.order-summary'),(979104,'deals','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(979105,'deals','.w-sitemap-delivery-location > ul > li > ul','display','flex','','','.w-sitemap-delivery-location'),(979106,'deals','.w-checkout-terms .required-message-wrap','display','inline-block','','','.w-checkout-terms'),(979107,'deals','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(979108,'deals','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(979109,'deals','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(979110,'deals','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(979111,'deals','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(979112,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','display','inline-block','','','.b-switch'),(979113,'deals','.w-product-reviews .reviews-list .review','display','block','3','','.w-product-reviews'),(979114,'deals','.b-info-popup .info-popup','display','inline-block','','','.b-info-popup'),(979115,'deals','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(979116,'deals','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(979117,'deals','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(979118,'deals','.p-quick-order-index .quick-order-total','display','flex','','','.p-quick-order-index'),(979119,'deals','.w-upload-customer-id-upload-customer-id-form .dz-details ~ div','display','none','','','.w-upload-customer-id-upload-customer-id-form'),(979120,'deals','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','display','flex','','','.w-upload-customer-id-upload-customer-id-form'),(979121,'deals','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(979122,'deals','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(979123,'deals','.w-checkout-bonus-points .btn-remove','display','inline-block','','','.w-checkout-bonus-points'),(979124,'deals','.w-login-block .cols','display','block','4','','.w-login-block'),(979125,'deals','.w-login-block .label','display','block','','','.w-login-block'),(979126,'deals','.w-menu-horizontal li','display','inline-block','','','.w-menu-horizontal'),(979127,'deals','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','display','inline-block','','','.w-menu-horizontal'),(979128,'deals','.w-menu-horizontal li li a, .w-menu-horizontal li li .no-link','display','block','','','.w-menu-horizontal'),(979129,'deals','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(979130,'deals','.b-form .payment-method .item-radio label','display','block','','','.b-form'),(979131,'deals','.w-quote .cart-box-link','display','flex','','','.w-quote'),(979132,'deals','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(979135,'deals','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(979136,'deals','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(979137,'deals','.w-promo-code .promo-text-2','display','none','5639','','.w-promo-code'),(979138,'deals','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(979139,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','display','inline-block','3','','.b-switch'),(979140,'deals','.b-switch .bootstrap-switch','display','inline-block','','','.b-switch'),(979141,'deals','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(979142,'deals','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(979143,'deals','.w-social-links .name, .w-social-links .image','display','none','','','.w-social-links'),(979145,'deals','.buttons','display','block','4','',''),(979146,'deals','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(979147,'deals','.w-login-block .label','display','block','','','.w-login-block'),(979149,'deals','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(979150,'deals','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(979151,'deals','.w-login-block .cols','display','block','4','','.w-login-block'),(979154,'deals','.w-filters .input-checkbox:checked + .checkbox-span','display','inline-block','','','.w-filters'),(979155,'deals','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(979156,'deals','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(979157,'deals','.b-switch .candlestick-wrapper','display','inline-block','','','.b-switch'),(979158,'deals','.w-catalog-listing-look .listing-look-title','display','inline-block','','','.w-catalog-listing-look'),(979159,'deals','.b-bottom .footerTitle ~ div','display','none','5630','','.b-bottom'),(979160,'deals','.w-checkout-billing-address .genders-title > div','display','inline-block','','','.w-checkout-billing-address'),(979161,'deals','.b-select-suggest .select2-display-none','display','none','','','.b-select-suggest'),(979162,'deals','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(979163,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','3','','.b-select-suggest'),(979166,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice .select2-search-choice-close','display','none','','','.b-select-suggest'),(979167,'deals','.w-checkout-shipping-choice span','display','flex','','','.w-checkout-shipping-choice'),(979169,'deals','.w-menu-big li a, .w-menu-big li .no-link','display','inline-block','','','.w-menu-big'),(979170,'deals','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(979171,'deals','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(979172,'deals','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(979173,'deals','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(979174,'deals','.w-cart-compare .product','display','block','4','','.w-cart-compare'),(979175,'deals','.w-top-categories .categories','display','block','4','','.w-top-categories'),(979176,'deals','.w-top-categories .categories','display','flex','','','.w-top-categories'),(979177,'deals','.b-info-popup .info-popup div','display','none','','','.b-info-popup'),(979178,'deals','.w-checkout-billing-address .addresses','display','block','4','','.w-checkout-billing-address'),(979179,'deals','.w-promo-code .promo-text-2','display','none','5639','','.w-promo-code'),(979180,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(979182,'deals','.w-image-maps .default-links .item .description','display','block','','','.w-image-maps'),(979183,'deals','.w-image-maps .float-items .item','display','block','1','','.w-image-maps'),(979184,'deals','.w-image-maps .default-links .item .title','display','block','','','.w-image-maps'),(979185,'deals','.b-upload-file .upload-file-template','display','inline-block','','','.b-upload-file'),(979186,'deals','.w-checkout-shipping-address .addresses','display','block','4','','.w-checkout-shipping-address'),(979187,'deals','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(979188,'deals','.w-quote .cart-box-link','display','inline-block','3','','.w-quote'),(979189,'deals','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(979190,'deals','.w-multi-cart-actions .cart-actions .dropdown-toggle','display','inline-block','','','.w-multi-cart-actions'),(979191,'deals','.w-tabs .tab-li.tab-wishlist a','display','block','3','','.w-tabs'),(979192,'deals','.w-top-categories .item','display','inline-block','','','.w-top-categories'),(979194,'deals','.w-tabs .tab-a','display','block','','','.w-tabs'),(979195,'deals','.w-tabs > .block > .box .heading-2, .w-tabs > .block > .box .heading-3, .w-tabs > .block > .box .heading-4','display','none','','','.w-tabs'),(979196,'deals','.w-tabs .tab-li','display','inline-block','','','.w-tabs'),(979197,'deals','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(979198,'deals','.p-wedding-registry-search .search-form','display','flex','','','.p-wedding-registry-search'),(979201,'deals','.b-form .payment-method .item-radio label span','display','block','','','.b-form'),(979202,'deals','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(979203,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','display','block','3','','.b-switch'),(979204,'deals','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(979205,'deals','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(979206,'deals','.w-login-block .cols','display','block','4','','.w-login-block'),(979207,'deals','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(979208,'deals','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(979209,'deals','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(979210,'deals','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(979211,'deals','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(979212,'deals','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(979213,'deals','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(979214,'deals','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(979215,'deals','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(979216,'deals','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(979217,'deals','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(979218,'deals','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(979219,'deals','.w-product-promotions .products img','display','inline-block','','','.w-product-promotions'),(979220,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','display','inline-block','','','.b-switch'),(979221,'deals','.w-login-block .label','display','block','','','.w-login-block'),(979223,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','display','table','','','.w-filters'),(979224,'deals','.w-filters .filter-widget-horizontal .filter-box','display','table-cell','','','.w-filters'),(979225,'deals','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(979226,'deals','.b-products-listing .products-listing .bonus-points','display','flex','','','.b-products-listing'),(979227,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','display','inline-block','','','.b-switch'),(979228,'deals','.w-checkout-shipping-address .genders-title label','display','inline-block','','','.w-checkout-shipping-address'),(979229,'deals','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(979230,'deals','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','display','inline-block','3','','.w-checkout-contact-information'),(979231,'deals','.order-summary .price-row','display','none','','','.order-summary'),(979232,'deals','.w-cart-bonus-points .btn-remove','display','inline-block','','','.w-cart-bonus-points'),(979233,'deals','.w-cart-listing .points-earn','display','inline-block','','','.w-cart-listing'),(979234,'deals','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(979236,'deals','.w-multi-cart-actions .cart-actions','display','inline-block','','','.w-multi-cart-actions'),(979237,'deals','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(979238,'deals','.b-select-suggest .select2-container.select2-allowclear .select2-choice abbr','display','inline-block','','','.b-select-suggest'),(979239,'deals','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(979240,'deals','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(979242,'deals','.w-reviews .item','display','grid','','','.w-reviews'),(979243,'deals','.w-promo-code .holder','display','block','4','','.w-promo-code'),(979244,'deals','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(979245,'deals','.w-image-maps .default-links .item','display','block','1','','.w-image-maps'),(979247,'deals','.w-checkout-shipping-choice input:checked + span:before','display','block','','','.w-checkout-shipping-choice'),(979249,'deals','.w-checkout-create-account .columns .col-2:nth-child(2n)','display','none','5639','','.w-checkout-create-account'),(979250,'deals','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(979251,'deals','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(979252,'deals','.w-product-promotions .products','display','inline-block','','','.w-product-promotions'),(979253,'deals','.w-top-categories .image','display','block','','','.w-top-categories'),(979254,'deals','.w-cart-compare .delete-cart','display','inline-block','','','.w-cart-compare'),(979255,'deals','.b-fancybox .fancybox-overlay','display','none','','','.b-fancybox'),(979256,'deals','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(979257,'deals','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(979258,'deals','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(979259,'deals','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(979260,'deals','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(979261,'deals','.w-list-b2b .attributes','display','block','4','','.w-list-b2b'),(979262,'deals','.w-socials .wrap_socials_posts','display','block','4','','.w-socials'),(979269,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(979270,'deals','.b-form .columns','display','block','4','','.b-form'),(979271,'deals','.w-promo-code .holder','display','block','4','','.w-promo-code'),(979272,'deals','.w-catalog-sorting .sorting','display','flex','','','.w-catalog-sorting'),(979273,'deals','.w-promo-code .promo-text-2','display','none','5639','','.w-promo-code'),(979274,'deals','.b-select-suggest .select2-container .select2-choice abbr','display','none','','','.b-select-suggest'),(979275,'deals','.b-select-suggest .select2-container .select2-choice > .select2-chosen','display','block','','','.b-select-suggest'),(979276,'deals','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(979277,'deals','.b-select-suggest .select2-container .select2-choice','display','block','','','.b-select-suggest'),(979278,'deals','.b-select-suggest .select2-results .select2-disabled.select2-highlighted','display','list-item','','','.b-select-suggest'),(979279,'deals','.b-select-suggest .select2-container','display','inline-block','','','.b-select-suggest'),(979280,'deals','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(979281,'deals','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(979282,'deals','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(979283,'deals','.w-checkout-shipping .sub-item','display','block','','','.w-checkout-shipping'),(979284,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','display','inline-block','','','.b-switch'),(979285,'deals','.b-social-login .social-login-text-2','display','inline-block','4','','.b-social-login'),(979286,'deals','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(979287,'deals','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(979289,'deals','.w-login-block .label','display','block','','','.w-login-block'),(979290,'deals','.w-login-block .cols','display','block','4','','.w-login-block'),(979291,'deals','.w-cart-shipping-estimator .item .row: after','display','block','','','.w-cart-shipping-estimator'),(979292,'deals','.w-categories h2.name','display','block','','','.w-categories'),(979294,'deals','.w-cart-compare .js-cart_totals_container b','display','block','','','.w-cart-compare'),(979295,'deals','.b-form .middle-form .col-gender label','display','inline-block','','','.b-form'),(979296,'deals','.b-form .login-cols','display','flex','','','.b-form'),(979297,'deals','.b-form .payment-method .sub-item span','display','block','','','.b-form'),(979298,'deals','.b-form .checkbox-style:checked + .checkbox-span','display','inline-block','','','.b-form'),(979301,'deals','.w-cart-shipping-estimator .shipping-estimator','display','block','4','','.w-cart-shipping-estimator'),(979302,'deals','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(979303,'deals','.b-fancybox .fancybox-title-float-wrap .child','display','inline-block','','','.b-fancybox'),(979304,'deals','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(979305,'deals','.w-checkout-credit-amount .btn-remove','display','inline-block','','','.w-checkout-credit-amount'),(979306,'deals','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(979307,'deals','.price .old','display','inline-block','','',''),(979308,'deals','.w-tabs .tab-li.tab-cart a','display','block','3','','.w-tabs'),(979309,'deals','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(979310,'deals','.w-checkout-billing-address .genders-title label','display','inline-block','','','.w-checkout-billing-address'),(979311,'deals','.w-top-categories h2.name','display','block','','','.w-top-categories'),(979312,'deals','.w-promo-code .holder','display','block','4','','.w-promo-code'),(979313,'deals','.w-image-maps .categories-items .item .description','display','block','','','.w-image-maps'),(979314,'deals','.w-image-maps .categories-items .item .title','display','block','','','.w-image-maps'),(979315,'deals','.w-quote .no-text','display','none','5639','','.w-quote'),(979316,'deals','.b-info-popup .info-popup','display','inline-block','3','','.b-info-popup'),(979317,'deals','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(979318,'deals','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(979319,'deals','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(979320,'deals','.b-upload-files .attach-active-holder','display','block','','','.b-upload-files'),(979321,'deals','.b-compare .compare_select_items','display','inline-block','','','.b-compare'),(979322,'deals','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display','inline-block','','','.b-switch'),(979323,'deals','.b-form .middle-form label','display','block','','','.b-form'),(979324,'deals','.b-form .form-inputs label > span','display','inline-block','','','.b-form'),(979325,'deals','.w-checkout-shipping-address .edit-ab','display','inline-block','','','.w-checkout-shipping-address'),(979326,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(979327,'deals','.w-cart-shipping-estimator .address-item .lastname','display','block','4','','.w-cart-shipping-estimator'),(979330,'deals','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(979331,'deals','.w-promo-code .promo-text-2','display','none','5639','','.w-promo-code'),(979332,'deals','.b-form .addresses','display','block','4','','.b-form'),(979333,'deals','.b-datepicker .picker-switch','display','none','','','.b-datepicker'),(979334,'deals','.w-personal-gift-status-bar .timeline','display','flex','','','.w-personal-gift-status-bar'),(979335,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','display','block','','','.b-switch'),(979336,'deals','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','display','inline-block','3','','.w-checkout-contact-information'),(979337,'deals','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','display','inline-block','3','','.w-checkout-contact-information'),(979338,'deals','.b-dropdown .dropdown:hover .dropdown-menu','display','block','','','.b-dropdown'),(979339,'deals','.w-checkout-shipping-address .genders-title > div','display','inline-block','','','.w-checkout-shipping-address'),(979340,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span','display','inline-block','','','.b-form'),(979341,'deals','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(979343,'deals','.w-categories .categories','display','block','4','','.w-categories'),(979344,'deals','.w-promo-code .holder','display','block','4','','.w-promo-code'),(979346,'deals','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(979347,'deals','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(979348,'deals','.w-menu-big .hide-more.hide-more-disable, .w-menu-big .hide-more.hide-more-disable ~ li:not(.show-all)','display','block','','','.w-menu-big'),(979350,'deals','.w-image-maps .categories-items .item','display','block','1','','.w-image-maps'),(979351,'deals','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(979352,'deals','.w-delayed-despatch-checkout-confirm .heading','display','block','','','.w-delayed-despatch-checkout-confirm'),(979353,'deals','.w-checkout-billing-address .edit-ab','display','inline-block','','','.w-checkout-billing-address'),(979354,'deals','.w-checkout-billing-address .addresses .address-item label','display','block','','','.w-checkout-billing-address'),(979355,'deals','.w-checkout-shipping-choice #shippingchoice-choice','display','flex','','','.w-checkout-shipping-choice'),(979356,'deals','.w-checkout-shipping-choice input','display','none','','','.w-checkout-shipping-choice'),(979357,'deals','.w-cart-give-away h2','display','none','','','.w-cart-give-away'),(979358,'deals','.w-promo-code .promo-text-2','display','none','5639','','.w-promo-code'),(979360,'deals','.b-pass-strength .pass-strength','display','block','','','.b-pass-strength'),(979361,'deals','.b-social-login .social-login-icons','display','inline-block','','','.b-social-login'),(979362,'deals','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display','inline-block','','','.b-switch'),(979363,'deals','.w-quote .strong','display','block','','','.w-quote'),(979364,'deals','.w-cart-up-sell h3','display','none','','','.w-cart-up-sell'),(979365,'deals','.w-cart-compare .product-actions .dropdown-toggle','display','none','4','','.w-cart-compare'),(979366,'deals','.b-select-suggest .select2-results li','display','list-item','','','.b-select-suggest'),(979367,'deals','.b-select-suggest .select2-search-choice-close','display','block','','','.b-select-suggest'),(979368,'deals','.b-select-suggest .select2-container.select2-container-disabled .select2-choice abbr','display','none','','','.b-select-suggest'),(979369,'deals','.b-select-suggest .select2-more-results','display','list-item','','','.b-select-suggest'),(979370,'deals','.b-select-suggest .select2-results .select2-selected','display','none','','','.b-select-suggest'),(979371,'deals','.b-select-suggest .select2-results .select2-disabled','display','list-item','','','.b-select-suggest'),(979372,'deals','.b-select-suggest .select2-results .select2-no-results, .b-select-suggest .select2-results .select2-searching, .b-select-suggest .select2-results .select2-selection-limit','display','list-item','','','.b-select-suggest'),(979373,'deals','.w-menu-big .hide-more, .w-menu-big .hide-more ~ li:not(.show-all)','display','none','','','.w-menu-big'),(979374,'deals','.w-checkout-shipping-address .change-ab','display','inline-block','','','.w-checkout-shipping-address'),(979375,'deals','.w-checkout-shipping-address .addresses .address-item label','display','block','','','.w-checkout-shipping-address'),(979376,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow b','display','block','','','.b-select-suggest'),(979377,'deals','.b-select-suggest .select2-search','display','inline-block','','','.b-select-suggest'),(979378,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow','display','inline-block','','','.b-select-suggest'),(979379,'deals','.w-neighbour-checkout .text','display','inline-block','','','.w-neighbour-checkout'),(979381,'deals','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(979382,'deals','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(979383,'deals','.w-product-promotions .promotion-full-price-discount','display','block','','','.w-product-promotions'),(979384,'deals','.w-product-promotions .products .item','display','inline-block','','','.w-product-promotions'),(979386,'deals','.w-menu-big > ul > li:hover > ul','display','block','','','.w-menu-big'),(979387,'deals','.w-menu-big li li a, .w-menu-big li li .no-link','display','block','','','.w-menu-big'),(979389,'deals','.w-menu-big li li li','display','block','','','.w-menu-big'),(979395,'deals','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(979396,'deals','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(979397,'deals','.w-product-promotions .promotion-data-2','display','inline-block','','','.w-product-promotions'),(979398,'deals','.w-menu-horizontal ul li:hover > ul','display','block','','','.w-menu-horizontal'),(979399,'deals','.w-menu-big li','display','inline-block','','','.w-menu-big'),(979401,'deals','.w-cart-listing .points-redeem','display','inline-block','','','.w-cart-listing'),(979402,'deals','.w-product-promotions .price .old','display','inline-block','','','.w-product-promotions'),(979403,'deals','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(979404,'deals','.w-product-promotions .promotion-data','display','none','','','.w-product-promotions'),(979405,'deals','.w-product-promotions .promotion-full-price-holder','display','none','','','.w-product-promotions'),(979406,'deals','.w-promo-code .holder','display','block','4','','.w-promo-code'),(979407,'deals','.w-login-block .label','display','block','','','.w-login-block'),(979408,'deals','.w-categories .item','display','inline-block','','','.w-categories'),(979409,'deals','.p-quote-checkout-success .page-success .text-1','display','block','3','','.p-quote-checkout-success'),(979410,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','display','inline-block','','','.b-data-table'),(979411,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','display','inline-block','','','.b-data-table'),(979413,'deals','.w-communication-post .communication-post-author','display','flex','','','.w-communication-post'),(979414,'deals','.b-products-listing .products-listing .compare label','display','inline','','','.b-products-listing'),(979415,'deals','.b-products-listing .products-listing .compare','display','inline-block','','','.b-products-listing'),(979416,'deals','.b-products-listing .BlockBox','display','block','4','','.b-products-listing'),(979417,'deals','.b-products-listing .btn-preloader','display','inline-block','3','','.b-products-listing'),(979418,'deals','.b-products-listing .hide','display','none','','','.b-products-listing'),(979419,'deals','.b-products-listing .hover-box-content','display','none','','','.b-products-listing'),(979420,'deals','.b-products-listing .hover-box:hover .hover-box-content','display','block','','','.b-products-listing'),(979421,'deals','.b-products-listing .loader','display','inline-block','4','','.b-products-listing'),(979422,'deals','.b-products-listing .products-listing .attribute-qty-block','display','flex','','','.b-products-listing'),(979423,'deals','.b-products-listing .products-listing','display','block','4','','.b-products-listing'),(979424,'deals','.b-products-listing .products-listing .btn-buy','display','inline-block','3','','.b-products-listing'),(979425,'deals','.w-catalog-b2b-add-button ','display','none','','','.w-catalog-b2b-add-button'),(979426,'deals','.b-products-listing .products-listing .item','display','inline-block','','','.b-products-listing'),(979427,'deals','.b-products-listing .products-listing.align-left .item','display','block','','','.b-products-listing'),(979428,'deals','.b-products-listing .products-listing.align-right .item','display','block','','','.b-products-listing'),(979429,'deals','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','display','block','','','.b-products-listing'),(979430,'deals','.b-products-listing .show-ofstock-products .headerStock','display','inline-block','','','.b-products-listing'),(979431,'deals','.checkbox input','display','none','','',''),(979432,'deals','.checkbox input + span','display','inline-block','','',''),(979439,'deals','.b-rating .glyphicon','display','inline-block','','','.b-rating'),(979440,'deals','.b-form .newsletter-row','display','block','4','','.b-form'),(979441,'deals','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','display','block','','','.b-fancybox'),(979442,'deals','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(979443,'deals','.w-cart-credit-amount .btn-remove','display','inline-block','','','.w-cart-credit-amount'),(979445,'deals','.w-login-block .label','display','block','','','.w-login-block'),(979446,'deals','.w-coupons-and-vauchers-checkout .btn-remove','display','inline-block','','','.w-coupons-and-vauchers-checkout'),(979447,'deals','.order-summary .price-row.ot_coupon .title','display','inline-block','3','','.order-summary'),(979448,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(979449,'deals','.b-form .eye-password-wrap','display','block','','','.b-form'),(979450,'deals','.w-taxable form','display','flex','','','.w-taxable'),(979451,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','display','inline-block','','',''),(979452,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','','','.w-communication-new-topic'),(979453,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','display','inline-block','3','','.w-communication-new-topic'),(979454,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','display','inline-block','','','.w-communication-new-topic'),(979455,'deals','.w-communication-new-topic .middle-form .col-2 label > span','display','block','','','.w-communication-new-topic'),(979456,'deals','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(979457,'deals','.w-tabs .tab-li.tab-quote a','display','block','3','','.w-tabs'),(979458,'deals','.w-login-block .cols','display','block','4','','.w-login-block'),(979460,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','display','flex','','','.b-tracking-numbers'),(979461,'deals','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','display','inline-block','','','.b-form'),(979462,'deals','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(979463,'deals','.w-promo-code .holder','display','block','4','','.w-promo-code'),(979464,'deals','.b-dropdown .dropdown .dropdown-menu','display','none','','','.b-dropdown'),(979465,'deals','.w-menu-horizontal ul ul','display','none','','','.w-menu-horizontal'),(979466,'deals','.w-menu-horizontal ul ul li','display','block','','','.w-menu-horizontal'),(979467,'deals','.w-catalog-listing-look .grid','display','inline-block','','','.w-catalog-listing-look'),(979468,'deals','.w-catalog-listing-look .b2b','display','inline-block','','','.w-catalog-listing-look'),(979469,'deals','.w-catalog-listing-look .list','display','inline-block','','','.w-catalog-listing-look'),(979470,'deals','.w-catalog-items-on-page .items-on-page','display','flex','','','.w-catalog-items-on-page'),(979471,'deals','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(979472,'deals','.w-cart-listing .item .attributes > div','display','table-row','','','.w-cart-listing'),(979473,'deals','.w-cart-listing .item .attributes span','display','table-cell','','','.w-cart-listing'),(979474,'deals','.w-cart-listing .item .attributes','display','table','','','.w-cart-listing'),(979475,'deals','.w-cart-listing .item .attributes strong','display','table-cell','','','.w-cart-listing'),(979476,'deals','.w-cart-listing .item .gift-wrap label','display','flex','','','.w-cart-listing'),(979477,'deals','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','display','block','','','.w-cart-listing'),(979478,'deals','.w-cart-listing .headings','display','none','5639','','.w-cart-listing'),(979479,'deals','.w-cart-listing .item .price *','display','inline-block','5639','','.w-cart-listing'),(979480,'deals','.w-cart-give-away .ga_name','display','block','4','','.w-cart-give-away'),(979481,'deals','.w-cart-discount-coupon .btn-remove','display','inline-block','','','.w-cart-discount-coupon'),(979494,'deals','.w-image-maps .float-items .item .title','display','block','','','.w-image-maps'),(979495,'deals','.w-image-maps .float-items .item .description','display','block','','','.w-image-maps'),(979496,'deals','.w-image-maps .products-items .item-holder','display','block','1','','.w-image-maps'),(979497,'deals','.w-image-maps .svg-wrap','display','inline-block','','','.w-image-maps'),(979498,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','display','none','','','.w-image-maps'),(979499,'deals','.b-compare .col-gender span, .b-compare .middle-form .col-gender label, .b-compare .col-gender input','display','inline-block','','','.b-compare'),(979500,'deals','.p-wedding-registry-search #searchform-status','display','flex','','','.p-wedding-registry-search'),(979501,'deals','.w-tabs .accordion-heading','display','block','','','.w-tabs'),(979502,'deals','.w-cart-shipping-estimator .item .row','display','block','','','.w-cart-shipping-estimator'),(979505,'deals','.w-login-block .cols','display','block','4','','.w-login-block'),(979507,'deals','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(979509,'deals','.order-summary .price-row.ot_bonus_points .title','display','inline-block','3','','.order-summary'),(979510,'deals','.w-cart-shipping-estimator .shipping-estimator .heading-2','display','none','','','.w-cart-shipping-estimator'),(979511,'deals','.w-catalog-compare-button .compare_button','display','inline-block','','','.w-catalog-compare-button'),(979514,'deals','.w-reviews-content .item','display','grid','','','.w-reviews-content'),(979515,'deals','.b-info-popup .info-popup:hover div','display','block','','','.b-info-popup'),(979516,'deals','.w-filters .content-filter-widget','display','none','5639','','.w-filters'),(979517,'deals','.w-filters .fsl_handle','display','block','4','','.w-filters'),(979518,'deals','.w-filters .filter-box-content ul li.view_items','display','block','','','.w-filters'),(979520,'deals','.w-promo-code .promo-text-2','display','none','5639','','.w-promo-code'),(979521,'deals','.w-taxable select','display','inline-block','','','.w-taxable'),(979522,'deals','.b-switch .bootstrap-switch .bootstrap-switch-container','display','inline-block','','','.b-switch'),(979523,'deals','.b-social-login .social-login-text-2','display','inline-block','3','','.b-social-login'),(979524,'deals','.w-tabs .tab-li.tab-sample a','display','block','3','','.w-tabs'),(979529,'deals','.w-menu-big > ul > li > ul','display','none','','','.w-menu-big'),(979530,'deals','.w-product-promotions .select-box','display','inline-block','','','.w-product-promotions'),(979531,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','display','inline','','','.b-h-inline'),(979532,'deals','.w-quote .no-text','display','inline-block','','','.w-quote'),(979533,'deals','.b-dropdown .dropdown a','display','block','','','.b-dropdown'),(979534,'deals','.p-wedding-registry-update #weddingregistryform-visibility label','display','block','','','.p-wedding-registry-update'),(979536,'deals','.b-tracking-numbers .tracking-numbers .item','display','block','4','','.b-tracking-numbers'),(979537,'deals','.w-filters .mobileCollapse','display','none','','','.w-filters'),(979538,'deals','.w-filters .input-checkbox:not(checked) + .checkbox-span','display','inline-block','','','.w-filters'),(979539,'deals','.b-product-images .media-popup .mp-big-images .item','display','flex','','','.b-product-images'),(979540,'deals','.b-product-images .media-popup .mp-big-images .item + .item:not(.slick-slide)','display','none','','','.b-product-images'),(979541,'deals','.b-product-images .media-popup .mp-small-images .item','display','inline-block','','','.b-product-images'),(979542,'deals','.b-product-images .media-popup .mp-small-images img','display','inline-block','','','.b-product-images'),(979543,'deals','.b-product-images .media-popup .slick-dots button','display','none','','','.b-product-images'),(979544,'deals','.b-product-images .media-popup .slick-dots li','display','inline-block','','','.b-product-images'),(979545,'deals','.b-menu-burger_icon .menu-style[data-burger_icon] .menu-content','display','none','','','.b-menu-burger_icon'),(979546,'deals','.b-menu-burger_icon .bi-opened .menu-style[data-burger_icon] .menu-content','display','block','','','.b-menu-burger_icon'),(979547,'deals','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','display','block','','','.b-menu-burger_icon'),(979548,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','display','block','','','.b-menu-lev_display-slide'),(979549,'deals','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','display','block','','','.b-menu-lev_display-slide'),(979550,'deals','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','display','block','','','.b-menu-lev_display-slide'),(979551,'deals','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','display','block','','','.b-menu-lev_display-slide'),(979552,'deals','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','display','block','','','.b-menu-lev_display-slide'),(979553,'deals','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"1\"] .level-1 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(979554,'deals','.b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture, .b-menu-lev_show_images .menu-style[data-lev1_show_images=\"2\"] .level-2 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(979555,'deals','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"1\"] .level-2 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(979556,'deals','.b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture, .b-menu-lev_show_images .menu-style[data-lev2_show_images=\"2\"] .level-3 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(979557,'deals','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"1\"] .level-3 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(979558,'deals','.b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture, .b-menu-lev_show_images .menu-style[data-lev3_show_images=\"2\"] .level-4 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(979559,'deals','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"1\"] .level-4 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(979560,'deals','.b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture, .b-menu-lev_show_images .menu-style[data-lev4_show_images=\"2\"] .level-5 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(979561,'deals','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"1\"] .level-5 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(979562,'deals','.b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture, .b-menu-lev_show_images .menu-style[data-lev5_show_images=\"2\"] .level-6 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(979563,'deals','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > a picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"1\"] .level-6 > li > .no-link picture','display','inline-block','','','.b-menu-lev_show_images'),(979564,'deals','.b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture, .b-menu-lev_show_images .menu-style[data-lev6_show_images=\"2\"] .level-7 > li > picture','display','inline-block','','','.b-menu-lev_show_images'),(979565,'deals','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-2','display','none','','','.b-menu-lev_vis'),(979566,'deals','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-3','display','none','','','.b-menu-lev_vis'),(979567,'deals','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(979568,'deals','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-4','display','none','','','.b-menu-lev_vis'),(979569,'deals','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(979570,'deals','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-5','display','none','','','.b-menu-lev_vis'),(979571,'deals','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(979572,'deals','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-6','display','none','','','.b-menu-lev_vis'),(979573,'deals','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(979574,'deals','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(979575,'deals','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-2','display','none','','','.b-menu-lev_vis'),(979576,'deals','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(979577,'deals','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-3','display','none','','','.b-menu-lev_vis'),(979578,'deals','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(979579,'deals','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-4','display','none','','','.b-menu-lev_vis'),(979580,'deals','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(979581,'deals','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-5','display','none','','','.b-menu-lev_vis'),(979582,'deals','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis'),(979583,'deals','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-6','display','none','','','.b-menu-lev_vis'),(979584,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(979585,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(979586,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-3','display','none','','','.b-menu-lev_vis-click_icon'),(979587,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(979588,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-4','display','none','','','.b-menu-lev_vis-click_icon'),(979589,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(979590,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-5','display','none','','','.b-menu-lev_vis-click_icon'),(979591,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','display','block','','','.b-menu-lev_vis-click_icon'),(979592,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-6','display','none','','','.b-menu-lev_vis-click_icon'),(979593,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display','block','','','.b-menu-open_from-left'),(979594,'deals','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul','display','flex','','','.b-menu-position'),(979595,'deals','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(979596,'deals','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display','none','','','.b-menu-style'),(979597,'deals','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display','none','','','.b-menu-style'),(979598,'deals','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display','none','','','.b-menu-style'),(979599,'deals','.b-trade-approval .steps-bar','display','table','','','.b-trade-approval'),(979600,'deals','.b-trade-approval .steps-bar li','display','table-cell','','','.b-trade-approval'),(979601,'deals','.b-trade-approval .steps-bar li a','display','block','','','.b-trade-approval'),(979602,'deals','.b-trade-approval .middle-form label','display','block','','','.b-trade-approval'),(979603,'deals','.b-trade-approval .columns','display','block','4','','.b-trade-approval'),(979604,'deals','.w-account-personal-catalog .list-switcher','display','flex','','','.w-account-personal-catalog'),(979605,'deals','.w-account-subscription .send-email','display','block','','','.w-account-subscription'),(979606,'deals','.w-account-subscription .subscription-variant','display','flex','','','.w-account-subscription'),(979607,'deals','.w-catalog-additional-images li','display','inline-block','','','.w-catalog-additional-images'),(979608,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','display','inline-block','3','','.w-catalog-compare'),(979609,'deals','.w-catalog-compare td span','display','inline','','','.w-catalog-compare'),(979610,'deals','.w-catalog-compare .product-listing','display','block','','','.w-catalog-compare'),(979611,'deals','.w-catalog-compare .promos-info','display','none','','','.w-catalog-compare'),(979612,'deals','.w-catalog-compare .item .compare a','display','none','','','.w-catalog-compare'),(979613,'deals','.w-catalog-compare .cross-box .different-all','display','flex','','','.w-catalog-compare'),(979614,'deals','.w-catalog-compare .cross-box','display','flex','','','.w-catalog-compare'),(979615,'deals','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','display','block','','','.w-delivery-day'),(979616,'deals','.w-delivery-day .time-left','display','flex','','','.w-delivery-day'),(979617,'deals','.w-delivery-day .left-count','display','block','','','.w-delivery-day'),(979618,'deals','.w-delivery-day .left-text-left','display','block','','','.w-delivery-day'),(979619,'deals','.w-delivery-day .left-text-right','display','block','','','.w-delivery-day'),(979620,'deals','.w-product-images .img-holder','display','flex','','','.w-product-images'),(979621,'deals','.w-product-images .additional-vertical','display','flex','','','.w-product-images'),(979622,'deals','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','display','inline-block','','','.b-cookie-notice'),(979624,'deals','.lowestPricedBox .w-banner .banner','display','flex','','','.lowestPricedBox'),(979625,'deals','.b-products-listing .products-listing .item picture','display','block','','','.b-products-listing'),(979626,'deals','.shopByCollectionBox .w-banner .banner','display','flex','','','.shopByCollectionBox'),(979627,'deals','.preFooter .w-banner .single_banner','display','inline-block','','','.preFooter'),(979628,'deals','.b-slick .slick-slide','display','none','','','.b-slick'),(979629,'deals','.b-slick .slick-arrow.slick-hidden','display','none','','','.b-slick'),(979630,'deals','.b-slick .slick-initialized .slick-slide','display','block','','','.b-slick'),(979631,'deals','.b-slick .slick-list','display','block','','','.b-slick'),(979632,'deals','.b-slick .slick-slide img','display','block','','','.b-slick'),(979633,'deals','.b-slick .slick-slide.slick-loading img','display','none','','','.b-slick'),(979634,'deals','.b-slick .slick-slider','display','block','','','.b-slick'),(979635,'deals','.b-slick .slick-track','display','block','','','.b-slick'),(979636,'deals','.b-slick .slick-track, .b-slick .slick-track:after','display','table','3','','.b-slick'),(979637,'deals','.b-slick .slick-vertical .slick-slide','display','block','','','.b-slick'),(979643,'deals','.b-products-listing .save-price-box','display','none','','','.b-products-listing'),(979644,'deals','.b-products-listing .products-listing a.btn.view-button','display','inline-block','3','','.b-products-listing'),(979645,'deals','.b-products-listing .add-to-personal-catalog','display','inline-block','3','','.b-products-listing'),(979646,'deals','.b-products-listing .products-listing .compare input + span','display','inline-block','','','.b-products-listing'),(979647,'deals','.b-products-listing .products-listing .item:hover .item-nav','display','block','','','.b-products-listing'),(979648,'deals','.LeftCategories .level-2','display','none','','','.LeftCategories'),(979649,'deals','.LeftCategories .w-menu-simple ul li a','display','block','','','.LeftCategories'),(979650,'deals','.b-products-listing .products-listing.slick-slider .item-nav','display','none','','','.b-products-listing'),(979651,'deals','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','display','none','4','','.b-products-listing'),(979652,'deals','.w-breadcrumb .breadcrumb-li','display','inline-block','','','.w-breadcrumb'),(979653,'deals','.w-breadcrumb .breadcrumb-ul','display','inline-block','','','.w-breadcrumb'),(979654,'deals','.w-subscribers .sb_ta','display','flex','','','.w-subscribers'),(979655,'deals','.w-quote .multicart .current-text','display','block','','','.w-quote'),(979656,'deals','.w-quote .multicart .item','display','block','','','.w-quote'),(979657,'deals','.w-quote .multicart .name','display','block','','','.w-quote'),(979658,'deals','.w-quote .multicart .sub-total-row','display','block','','','.w-quote'),(979659,'deals','.w-quote .multicart .title','display','inline-block','','','.w-quote'),(979660,'deals','.w-quote .name','display','block','','','.w-quote'),(979661,'deals','.w-quote .price','display','block','','','.w-quote'),(979662,'deals','.w-quote a.item','display','block','4','','.w-quote'),(979663,'deals','.w-quote a.item','display','block','','','.w-quote'),(979664,'deals','.w-quote .cart-box-link','display','none','5639,4','','.w-quote'),(979665,'deals','.w-social-links a','display','inline-block','','','.w-social-links'),(979666,'deals','.b-quantity .qty-box .bigger','display','inline-block','','','.b-quantity'),(979667,'deals','.b-quantity .qty-box .smaller','display','inline-block','','','.b-quantity'),(979668,'deals','.b-products-listing .rating, .b-products-listing .ratingCounts','display','inline-block','','','.b-products-listing'),(979669,'deals','.rating, .ratingCounts','display','inline-block','','',''),(979670,'deals','.b-products-listing .promos-info .promo-item','display','flex','','','.b-products-listing'),(979671,'deals','.w-product-sale-ends .left-count','display','block','','','.w-product-sale-ends'),(979672,'deals','.w-product-sale-ends .left-count-days','display','block','','','.w-product-sale-ends'),(979673,'deals','.w-product-sale-ends .left-count-hours','display','block','','','.w-product-sale-ends'),(979674,'deals','.w-product-sale-ends .left-text-left','display','block','','','.w-product-sale-ends'),(979675,'deals','.w-product-sale-ends .left-text-right','display','block','','','.w-product-sale-ends'),(979676,'deals','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','display','inline-block','3','','.w-product-buttons'),(979677,'deals','.w-product-quantity .product-quantity-label','display','none','','','.w-product-quantity'),(979678,'deals','.w-product-quantity .pr_attr','display','block','','','.w-product-quantity'),(979679,'deals','.w-product-quantity .qty_packs .price_1','display','inline-block','4','','.w-product-quantity'),(979680,'deals','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','display','inline-block','','','.w-product-quantity'),(979681,'deals','.w-product-quantity .qty_packs .qty-input','display','block','4','','.w-product-quantity'),(979682,'deals','.w-product-quantity .qty_packs .qty_price','display','inline-block','','','.w-product-quantity'),(979683,'deals','.w-product-quantity .qty_packs .qty_t','display','block','','','.w-product-quantity'),(979684,'deals','.w-product-quantity .qty_t span','display','block','','','.w-product-quantity'),(979685,'deals','.w-product-bonus-points > div','display','block','4','','.w-product-bonus-points'),(979686,'deals','.w-product-personal-catalog-button .btn','display','inline-block','3','','.w-product-personal-catalog-button'),(979687,'deals','.warrantyProduct .warranty','display','inline-block','3','','.warrantyProduct'),(979688,'deals','.warrantyProduct .delivery','display','inline-block','3','','.warrantyProduct'),(979689,'deals','.w-compare .compare-button','display','block','','','.w-compare'),(979690,'deals','.w-files-catalog-widgets-files-catalog ','display','flex','','','.w-files-catalog-widgets-files-catalog'),(979691,'deals','.w-files-catalog-widgets-files-catalog .image','display','flex','','','.w-files-catalog-widgets-files-catalog'),(979692,'deals','.w-files-catalog-widgets-files-catalog .item','display','flex','','','.w-files-catalog-widgets-files-catalog'),(979693,'deals','.w-files-catalog-widgets-files-catalog picture','display','inline-block','','','.w-files-catalog-widgets-files-catalog'),(979694,'deals','.w-sample .cart-box-link','display','inline-block','4','','.w-sample'),(979695,'deals','.w-sample .cart-box-link','display','flex','','','.w-sample'),(979696,'deals','.w-sample .cart-box-link','display','inline-block','3','','.w-sample'),(979697,'deals','.w-sample .cart-box-link .strong','display','none','','','.w-sample'),(979698,'deals','.w-sample .multicart .current-text','display','block','','','.w-sample'),(979699,'deals','.w-sample .multicart .item','display','block','','','.w-sample'),(979700,'deals','.w-sample .multicart .name','display','block','','','.w-sample'),(979701,'deals','.w-sample .multicart .sub-total-row','display','block','','','.w-sample'),(979702,'deals','.w-sample .multicart .title','display','inline-block','','','.w-sample'),(979703,'deals','.w-sample .name','display','block','','','.w-sample'),(979704,'deals','.w-sample .no-text','display','inline-block','','','.w-sample'),(979705,'deals','.w-sample .price','display','block','','','.w-sample'),(979706,'deals','.w-sample .strong','display','block','','','.w-sample'),(979707,'deals','.w-sample a.item','display','block','4','','.w-sample'),(979708,'deals','.w-sample a.item','display','block','','','.w-sample'),(979709,'deals','.w-sample .cart-box-link','display','none','5639,4','','.w-sample'),(979710,'deals','.w-sample .no-text','display','none','5639','','.w-sample'),(979711,'deals','.w-quote .cart-box.hover-box .cart-content','display','none','','','.w-quote'),(979712,'deals','.w-quote .cart-box.hover-box:hover .cart-content','display','block','','','.w-quote'),(979713,'deals','.w-sample .cart-box .cart-content','display','none','','','.w-sample'),(979714,'deals','.w-sample .cart-box:hover .cart-content','display','block','','','.w-sample'),(979715,'deals','.w-filters-simple .filter-row','display','flex','','','.w-filters-simple'),(979716,'deals','.w-filters-simple .integrate-price-holder > div','display','inline-block','','','.w-filters-simple'),(979717,'deals','.w-cart-discount-coupon .inp','display','none','','','.w-cart-discount-coupon'),(979718,'deals','.w-cart-sub-total .price-row','display','flex','','','.w-cart-sub-total'),(979719,'deals','.w-cart-gift-certificate .gift-certificate .heading-4','display','inline-block','3','','.w-cart-gift-certificate'),(979720,'deals','.w-cart-gift-certificate .input-apple','display','flex','','','.w-cart-gift-certificate'),(979721,'deals','.w-cart-order-reference .input-apple','display','flex','','','.w-cart-order-reference'),(979722,'deals','.w-product-attributes .radio-attributes > span','display','block','','','.w-product-attributes'),(979723,'deals','.w-product-bundle > div','display','block','4','','.w-product-bundle'),(979724,'deals','.w-product-bundle .bundle-products','display','flex','','','.w-product-bundle'),(979725,'deals','.w-product-bundle .bundle-total-price .title, .w-product-bundle .bundle-total-price .price','display','inline-block','','','.w-product-bundle'),(979726,'deals','.w-product-in-bundles .bundle-products','display','flex','','','.w-product-in-bundles'),(979727,'deals','.w-product-in-bundles .bundle-total-price .title, .w-product-in-bundles .bundle-total-price .price','display','inline-block','','','.w-product-in-bundles'),(979728,'deals','.w-catalog-additional-images picture','display','flex','','','.w-catalog-additional-images'),(979729,'deals','.w-sample-products .price','display','none','','','.w-sample-products'),(979732,'deals','.b-products-listing .products-listing .radio-attributes','display','block','4','','.b-products-listing'),(979733,'deals','.b-pagination .pagination','display','block','4','','.b-pagination'),(979734,'deals','.b-pagination .pagination .next-pages','display','inline-block','','','.b-pagination'),(979735,'deals','.b-pagination .pagination .page-number','display','inline-block','','','.b-pagination'),(979736,'deals','.b-pagination .pagination .paging','display','inline-block','','','.b-pagination'),(979737,'deals','.b-pagination .pagination .prev-pages','display','inline-block','','','.b-pagination'),(979738,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','display','inline-block','','','.b-pagination'),(979739,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','display','inline-block','','','.b-pagination'),(979740,'deals','.b-pagination .pagination span','display','inline-block','2','','.b-pagination'),(979741,'deals','.b-pagination ul.pagination li','display','inline-block','','','.b-pagination'),(979742,'deals','.w-product-multi-inventory .select-box:last-of-type:after','display','block','','','.w-product-multi-inventory'),(979743,'deals','.w-product-properties-filters-widgets-chosen-filters .item','display','inline-block','','','.w-product-properties-filters-widgets-chosen-filters'),(979744,'deals','.w-product-multi-inventory .radio-attributes > label','display','block','','','.w-product-multi-inventory'),(979745,'deals','.w-cart-listing .no-price .price','display','none','','','.w-cart-listing'),(979746,'deals','.w-product-multi-inventory #product-attributes','display','block','4','','.w-product-multi-inventory'),(979747,'deals','.p-quote-checkout-index .heading-2','display','none','3','','.p-quote-checkout-index'),(979748,'deals','.p-quote-checkout-index .heading-2','display','none','4','','.p-quote-checkout-index'),(979749,'deals','.p-sample-checkout-index .heading-2','display','none','3','','.p-sample-checkout-index'),(979750,'deals','.p-sample-checkout-index .heading-2','display','none','4','','.p-sample-checkout-index'),(979751,'deals','.p-sample-checkout-index .order-summary .heading-2','display','inline-block','3','','.p-sample-checkout-index'),(979752,'deals','.p-sample-checkout-index .order-summary .heading-2','display','inline-block','4','','.p-sample-checkout-index'),(979755,'deals','.w-product-multi-inventory .radio-attributes > span','display','block','','','.w-product-multi-inventory'),(979756,'deals','.w-quote-products .cart-listing .price','display','none','','','.w-quote-products'),(979757,'deals','.w-product-multi-inventory .radio-attributes .option-item','display','inline-block','','','.w-product-multi-inventory'),(979758,'deals','.w-product-multi-inventory .radio-attributes > label input','display','none','','','.w-product-multi-inventory'),(979759,'deals','.w-product-multi-inventory .radio-attributes','display','block','4','','.w-product-multi-inventory'),(979760,'deals','.w-product-quantity-discounts .quantity-discounts','display','block','4','','.w-product-quantity-discounts'),(979761,'deals','h1, .heading-1','display','none','5639,3','',''),(979762,'deals','h1, .heading-1','display','none','5639,4','',''),(979763,'deals','.w-filters .handle_tit','display','block','5644','','.w-filters'),(979764,'deals','.b-products-listing .products-listing .radio-attributes .option','display','inline-block','','','.b-products-listing'),(979765,'deals','.b-products-listing .products-listing .radio-attributes > label','display','block','','','.b-products-listing'),(979766,'deals','.b-products-listing .products-listing .radio-attributes > label input','display','none','','','.b-products-listing'),(979767,'deals','.b-products-listing .products-listing .radio-attributes > span','display','block','','','.b-products-listing'),(979768,'deals','.b-products-listing .products-listing .radio-attributes .item-title','display','block','','','.b-products-listing'),(979769,'deals','.w-product-collection .old, .w-product-collection .specials','display','inline-block','','','.w-product-collection'),(979770,'deals','.w-product-collection .together','display','block','','','.w-product-collection'),(979771,'deals','.w-product-collection .right-area .btn','display','inline-block','3','','.w-product-collection'),(979772,'deals','.w-product-collection .right-area .btn-2','display','inline-block','3','','.w-product-collection'),(979773,'deals','.price .special-promote','display','block','','',''),(979774,'deals','.w-product-attributes #product-attributes','display','block','4','','.w-product-attributes'),(979775,'deals','.w-product-attributes .radio-attributes','display','block','4','','.w-product-attributes'),(979776,'deals','.w-product-attributes .radio-attributes .option-item','display','inline-block','','','.w-product-attributes'),(979777,'deals','.w-product-attributes .radio-attributes > label','display','block','','','.w-product-attributes'),(979778,'deals','.w-product-attributes .radio-attributes > label input','display','none','','','.w-product-attributes'),(979779,'deals','.w-product-attributes .select-box:last-of-type:after','display','block','','','.w-product-attributes'),(979780,'deals','.w-product-properties .properties-table','display','table','','','.w-product-properties'),(979781,'deals','.w-product-properties .property-ul','display','table','','','.w-product-properties'),(979782,'deals','.w-product-properties li','display','table-cell','','','.w-product-properties'),(979783,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','display','block','','','.w-questionnaire-widgets-questionnaire'),(979784,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no label','display','inline','','','.w-questionnaire-widgets-questionnaire'),(979785,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no','display','flex','','','.w-questionnaire-widgets-questionnaire'),(979786,'deals','.w-product-groups .radioBox label','display','block','','','.w-product-groups'),(979787,'deals','.w-product-groups .radioBox label .containerBlock','display','block','','','.w-product-groups'),(979788,'deals','.w-product-groups .prop-group-swatch','display','block','4','','.w-product-groups'),(979789,'deals','.b-products-listing .mix-attributes .mult-qty-input .qty-box','display','block','','','.b-products-listing'),(979790,'deals','.w-product-custom-bundle .old, .w-product-custom-bundle .specials','display','inline-block','','','.w-product-custom-bundle'),(979791,'deals','.w-product-custom-bundle .together','display','block','','','.w-product-custom-bundle'),(979792,'deals','.w-product-custom-bundle .right-area .separate-text','display','block','','','.w-product-custom-bundle'),(979793,'deals','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','display','inline-block','3','','.w-product-custom-bundle'),(979794,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list'),(979795,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list-block'),(979796,'deals','.w-delivery-location-location-list ul','display','block','4','','.w-delivery-location-location-list'),(979797,'deals','.w-delivery-location-location-list .deliveryListParrent a','display','inline-block','','','.w-delivery-location-location-list'),(979798,'deals','.w-delivery-location-location-list .deliveryList li a','display','block','','','.w-delivery-location-location-list'),(979799,'deals','.w-delivery-location-featured-list .deliveryList ul','display','block','4','','.w-delivery-location-featured-list'),(979800,'deals','.w-sale-category .btn','display','block','','','.w-sale-category'),(979801,'deals','.w-sale-category .left-count','display','block','','','.w-sale-category'),(979802,'deals','.w-sale-category .left-count-days','display','block','','','.w-sale-category'),(979803,'deals','.w-sale-category .left-count-hours','display','block','','','.w-sale-category'),(979804,'deals','.w-sale-category .left-text-left','display','block','','','.w-sale-category'),(979805,'deals','.w-sale-category .left-text-right','display','block','','','.w-sale-category'),(979806,'deals','.w-sale-category .special-price','display','block','','','.w-sale-category'),(979807,'deals','.w-sale-category .special-price-text','display','none','','','.w-sale-category'),(979808,'deals','.w-sale-category .text','display','block','','','.w-sale-category'),(979809,'deals','.w-success-download table td','display','block','5660','','.w-success-download'),(979810,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list-by-catalog'),(979811,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(979812,'deals','.w-delivery-location-list-by-page .page-list','display','block','4','','.w-delivery-location-list-by-page'),(979813,'deals','.w-delivery-location-top-location-list .deliveryList','display','block','4','','.w-delivery-location-top-location-list'),(979814,'deals','.w-product-properties-icons ','display','flex','','','.w-product-properties-icons'),(979815,'deals','.w-product-properties-icons .hover-box-content','display','inline-block','','','.w-product-properties-icons'),(979816,'deals','.w-product-properties-icons .hover-box','display','block','','','.w-product-properties-icons'),(979817,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','display','inline-block','','','.w-product-properties-icons'),(979818,'deals','.w-delivery-location-cross-pages .page-list','display','block','4','','.w-delivery-location-cross-pages'),(979819,'deals','.w-cart-listing .price br','display','none','','','.w-cart-listing'),(979820,'deals','.w-delivery-location-product-categories .categories','display','flex','','','.w-delivery-location-product-categories'),(979821,'deals','.w-delivery-location-product-categories .item.category-link','display','block','','','.w-delivery-location-product-categories'),(979822,'deals','.delivery-options-popup','display','block','4','',''),(979823,'deals','.w-product-bonus-points .bonus-points-cost','display','inline-block','','','.w-product-bonus-points'),(979824,'deals','.w-product-designer-designer .groupNamePrDes','display','none','','','.w-product-designer-designer'),(979825,'deals','.w-product-designer-designer .grnamebox .title-sortable','display','block','','','.w-product-designer-designer'),(979826,'deals','.w-product-designer-designer .prodDesignerType','display','flex','','','.w-product-designer-designer'),(979827,'deals','.w-press-reviews-widgets-press-reviews .image a','display','block','','','.w-press-reviews-widgets-press-reviews'),(979828,'deals','.w-press-reviews-widgets-press-reviews .item','display','block','','','.w-press-reviews-widgets-press-reviews'),(979829,'deals','.w-press-reviews-widgets-press-reviews .review-box','display','flex','','','.w-press-reviews-widgets-press-reviews'),(979830,'deals','.w-press-reviews-widgets-press-reviews .title a','display','block','','','.w-press-reviews-widgets-press-reviews'),(979831,'deals','.w-press-reviews-widgets-press-reviews-list .item','display','flex','','','.w-press-reviews-widgets-press-reviews-list'),(979832,'deals','.w-press-reviews-widgets-press-reviews-list .review-box','display','flex','','','.w-press-reviews-widgets-press-reviews-list'),(979833,'deals','.b-products-listing .productGroup label','display','inline-block','','','.b-products-listing'),(979834,'deals','.b-products-listing .productGroup label a','display','block','','','.b-products-listing'),(979835,'deals','.w-gift-wrap-message-checkout .max-counter, .w-gift-wrap-message-checkout .max-words','display','inline-block','','','.w-gift-wrap-message-checkout'),(979836,'deals','.w-communication-post .btn.refresh input','display','none','','','.w-communication-post'),(979837,'deals','.w-rma-returns-history .column','display','flex','','','.w-rma-returns-history'),(979838,'deals','.w-rma-returns-history .column .fromTo','display','flex','','','.w-rma-returns-history'),(979839,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','display','inline-block','','','.w-rma-returns-history'),(979840,'deals','.w-rma-returns-history .filterMessages','display','flex','','','.w-rma-returns-history'),(979841,'deals','.w-rma-returns-history .fromTo label','display','inline-block','','','.w-rma-returns-history'),(979842,'deals','.w-rma-returns-history .fromTo label >span','display','block','','','.w-rma-returns-history'),(979843,'deals','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul','display','flex','','','.b-menu-position'),(979844,'deals','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(979845,'deals','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul','display','flex','','','.b-menu-position'),(979846,'deals','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(979847,'deals','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul','display','flex','','','.b-menu-position'),(979848,'deals','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','display','flex','','','.b-menu-position'),(979849,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > ul','display','none','','','.b-menu-lev_vis-click_icon'),(979850,'deals','.w-show-inactive-show-inactive .out_stock_wrap','display','flex','','','.w-show-inactive-show-inactive'),(979851,'deals','.w-product-configurator .item-content','display','table','','','.w-product-configurator'),(979852,'deals','.w-product-configurator .item-content > div','display','table-cell','','','.w-product-configurator'),(979853,'deals','.w-product-configurator .pc_more','display','block','','','.w-product-configurator'),(979854,'deals','.w-product-configurator .pc_row','display','block','4','','.w-product-configurator'),(979855,'deals','.w-product-configurator .item-content','display','block','5630','','.w-product-configurator'),(979856,'deals','.w-product-configurator .item-content > div','display','block','5630','','.w-product-configurator'),(979857,'deals','.w-product-configurator .pc-item label','display','block','','','.w-product-configurator'),(979858,'deals','.b-products-listing .products-listing .bonus-points-cost','display','inline-block','','','.b-products-listing'),(979859,'deals','.b-products-listing .promo-icon','display','inline-block','','','.b-products-listing'),(979860,'deals','.b-products-listing .promos-info .promo-name','display','inline-block','','','.b-products-listing'),(979861,'deals','.b-products-listing .promos-info .promo-name-span','display','block','','','.b-products-listing'),(979862,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','display','block','4','','.w-catalog-pages-category-pages-list'),(979863,'deals','.w-predefined-promotion .heading-3','display','inline-block','','','.w-predefined-promotion'),(979864,'deals','.w-predefined-promotion .icon','display','inline-block','','','.w-predefined-promotion'),(979865,'deals','.w-predefined-promotion .nextdiscount .content','display','grid','','','.w-predefined-promotion'),(979866,'deals','.w-predefined-promotion .nextdiscount .item-holder','display','flex','','','.w-predefined-promotion'),(979867,'deals','.w-predefined-promotion .nextdiscount .promo-for-each','display','inline-block','','','.w-predefined-promotion'),(979868,'deals','.w-predefined-promotion .prom-multi-discount','display','block','4','','.w-predefined-promotion'),(979869,'deals','.w-predefined-promotion .prom-multi-discount .list','display','grid','','','.w-predefined-promotion'),(979870,'deals','.w-predefined-promotion .prom-multi-discount .products','display','grid','','','.w-predefined-promotion'),(979871,'deals','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','display','block','','','.w-predefined-promotion'),(979872,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','display','inline-block','','','.w-predefined-promotion'),(979873,'deals','.w-predefined-promotion .prom-multi-discount .promo-range > div','display','inline-block','','','.w-predefined-promotion'),(979874,'deals','.w-predefined-promotion .promo-cart-discount','display','flex','','','.w-predefined-promotion'),(979875,'deals','.w-predefined-promotion .promo-cart-discount .content','display','flex','','','.w-predefined-promotion'),(979876,'deals','.w-predefined-promotion .promo-cart-discount .item a','display','block','','','.w-predefined-promotion'),(979877,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','display','inline-block','','','.w-predefined-promotion'),(979878,'deals','.w-predefined-promotion .promo-cart-discount .slave','display','flex','','','.w-predefined-promotion'),(979879,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','display','inline-block','','','.w-predefined-promotion'),(979880,'deals','.w-predefined-promotion .promo-content > .personalgift','display','none','','','.w-predefined-promotion'),(979881,'deals','.w-predefined-promotion .promo-date > div','display','inline-block','','','.w-predefined-promotion'),(979882,'deals','.w-predefined-promotion .promo-salemaker','display','flex','','','.w-predefined-promotion'),(979883,'deals','.w-predefined-promotion .promo-salemaker .content','display','flex','','','.w-predefined-promotion'),(979884,'deals','.w-predefined-promotion .promo-salemaker .content a.name','display','block','','','.w-predefined-promotion'),(979885,'deals','.w-predefined-promotion .promo-salemaker .discount','display','inline-block','','','.w-predefined-promotion'),(979886,'deals','.w-supplier-purchase-supplier-products .item','display','flex','','','.w-supplier-purchase-supplier-products'),(979887,'deals','.w-supplier-purchase-supplier-products .qty_col','display','flex','','','.w-supplier-purchase-supplier-products'),(979889,'deals','.headerWrap .accountMenu >.block','display','flex','','','.headerWrap'),(979890,'deals','.headerWrap .menuBox >.block','display','flex','','','.headerWrap'),(979891,'deals','.headerWrap .RightBox>.block','display','flex','','','.headerWrap'),(979892,'deals','.headerWrap .searchIcon','display','none','','','.headerWrap'),(979893,'deals','.headerWrap .searchIcon','display','inline-block','3','','.headerWrap'),(979894,'deals','.headerWrap .w-search .close, .headerWrap .w-search .closeBackground','display','none','','','.headerWrap'),(979895,'deals','.w-subscribers .left_box p','display','none','','','.w-subscribers'),(979896,'deals','.w-subscribers .stitle','display','none','','','.w-subscribers'),(979897,'deals','.w-subscribers .subscribe_box','display','flex','','','.w-subscribers'),(979898,'deals','.preFooter .w-contacts > div + br','display','none','','','.preFooter'),(979899,'deals','.w-top-categories picture','display','flex','','','.w-top-categories'),(979900,'deals','.w-top-categories picture > img, .w-top-categories picture > img','display','block','','','.w-top-categories'),(979901,'deals','.headerWrap .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','display','block','','','.headerWrap'),(979902,'deals','.w-categories .categories','display','flex','','','.w-categories'),(979903,'deals','.w-categories picture','display','flex','','','.w-categories'),(979904,'deals','.w-categories picture > img, .w-categories picture > img','display','block','','','.w-categories'),(979905,'deals','.filterLine .before','display','inline-block','','','.filterLine'),(979906,'deals','.filterLine .w-catalog-sorting .sorting','display','block','','','.filterLine'),(979907,'deals','.filterLine > .block','display','flex','','','.filterLine'),(979908,'deals','.w-filters .filter-widget-horizontal .head-filter-widget','display','none','','','.w-filters'),(979909,'deals','.w-filters .choose-filters','display','flex','','','.w-filters'),(979910,'deals','.w-filters .choose-filters > li > *','display','inline-block','','','.w-filters'),(979911,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span','display','block','','','.w-product-quantity-discounts'),(979912,'deals','.w-breadcrumb .breadcrumb-li:last-of-type:after','display','none','','','.w-breadcrumb'),(979913,'deals','.messageBox .info','display','inline-block','3','',''),(979914,'deals','.w-cart-listing .headings','display','none','','','.w-cart-listing'),(979915,'deals','.w-cart-listing .item','display','grid','','','.w-cart-listing'),(979916,'deals','.w-support-system-listing .support-item-body .support-item-body-image','display','flex','','','.w-support-system-listing'),(979918,'deals','.headerWrap .w-contacts.phone','display','none','5630','','.headerWrap'),(979919,'deals','.homeBanner .carousel .bottom-center > span','display','block','','','.homeBanner'),(979920,'deals','.w-filters .filter-widget-horizontal .filter-box-head','display','flex','','','.w-filters'),(979921,'deals','.w-filters .filter-widget-horizontal .filter-box-head','display','block','5639','','.w-filters'),(979922,'deals','.w-filters .filter-widget-horizontal .filter-box','display','block','5639','','.w-filters'),(979923,'deals','.w-filters .filter-widget-horizontal .head-filter-widget','display','block','5639','','.w-filters'),(979924,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','display','none','5639','','.w-filters'),(979925,'deals','.b-products-listing .select-attributes','display','block','4','','.b-products-listing'),(979926,'deals','.b-products-listing .products-listing.list-productlisting .radio-attributes > label','display','block','','','.b-products-listing'),(979927,'deals','.b-info .info','display','inline-block','3','','.b-info'),(979928,'deals','.w-neighbour-checkout .neighbour-box','display','block','4','','.w-neighbour-checkout'),(979929,'deals','.b-sub-totals .historyTotal','display','block','4','','.b-sub-totals'),(979930,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','display','flex','5630','','.headerWrap'),(979931,'deals','.w-account-personal-catalog .headings','display','none','','','.w-account-personal-catalog'),(979932,'deals','.w-account-personal-catalog .list-row-action','display','flex','','','.w-account-personal-catalog'),(979933,'deals','.w-account-personal-catalog .list-row-action a','display','block','','','.w-account-personal-catalog'),(979934,'deals','.w-account-personal-catalog .buy-box','display','flex','5630','','.w-account-personal-catalog'),(979935,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li .no-link','display','none','5639,3','','.preFooter'),(979936,'deals','.b-quantity .qty-input label','display','none','','','.b-quantity'),(979937,'deals','.homeBanner .banner-item .banner-text-holder','display','block','','','.homeBanner'),(979938,'deals','.preFooter .w-banner .image-text-banner','display','inline-block','','','.preFooter'),(979939,'deals','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','display','flex','','','.w-promotions-widgets-promotion-icons-desc'),(979940,'deals','.order-summary .checkout-cart-listing.main-listing','display','none','','','.order-summary'),(979941,'deals','.order-summary .icon','display','block','','','.order-summary'),(979942,'deals','.order-summary .price-box .price-row.total','display','flex','','','.order-summary'),(979943,'deals','.order-summary .price-row','display','flex','2','','.order-summary'),(979944,'deals','.order-summary .top-totals .price-box .price-row.total','display','none','','','.order-summary'),(979945,'deals','.order-summary .top-totals .price-row','display','flex','2','','.order-summary'),(979946,'deals','.order-summary .w-cart-listing .item .points','display','none','','','.order-summary'),(979947,'deals','.order-summary .w-cart-listing .item > div.image','display','none','','','.order-summary'),(979948,'deals','.w-cart-discount-coupon .title','display','inline-block','4','','.w-cart-discount-coupon'),(979949,'deals','.w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp','display','flex','','','.w-cart-discount-coupon'),(979950,'deals','.w-cart-shipping-estimator .left-area','display','block','5630,4','','.w-cart-shipping-estimator'),(979951,'deals','.w-cart-shipping-estimator .left-area .col-right > span:nth-child(1)','display','none','5630','','.w-cart-shipping-estimator'),(979952,'deals','.w-cart-shipping-estimator .left-area .col-right > span:nth-child(1) + br','display','none','5630','','.w-cart-shipping-estimator'),(979954,'deals','.w-cart-checkout-btn .with-card','display','inline-block','4','','.w-cart-checkout-btn'),(979955,'deals','.w-checkout-continue-btn .button-hide','display','none','','','.w-checkout-continue-btn'),(979956,'deals','.w-checkout-continue-btn .or-text','display','none','','','.w-checkout-continue-btn'),(979957,'deals','.p-quote-checkout-index .order-summary .icon','display','none','','','.p-quote-checkout-index'),(979958,'deals','.order-summary .w-cart-listing .item .price small','display','block','','','.order-summary'),(979959,'deals','.w-promotions-widgets-promotions .price .old','display','inline-block','','','.w-promotions-widgets-promotions'),(979960,'deals','.w-promotions-widgets-promotions .products','display','inline-block','','','.w-promotions-widgets-promotions'),(979961,'deals','.w-promotions-widgets-promotions .products .item','display','inline-block','','','.w-promotions-widgets-promotions'),(979962,'deals','.w-promotions-widgets-promotions .products img','display','inline-block','','','.w-promotions-widgets-promotions'),(979963,'deals','.w-promotions-widgets-promotions .promotion-data','display','none','','','.w-promotions-widgets-promotions'),(979964,'deals','.w-promotions-widgets-promotions .promotion-data-2','display','inline-block','','','.w-promotions-widgets-promotions'),(979965,'deals','.w-promotions-widgets-promotions .promotion-full-price-discount','display','block','','','.w-promotions-widgets-promotions'),(979966,'deals','.w-promotions-widgets-promotions .promotion-full-price-holder','display','none','','','.w-promotions-widgets-promotions'),(979967,'deals','.w-promotions-widgets-promotions .select-box','display','inline-block','','','.w-promotions-widgets-promotions'),(980003,'deals','.account-order-pay .history_attr','display','table','','','.account-order-pay'),(980004,'deals','.account-order-pay .history_attr div','display','table-row','','','.account-order-pay'),(980005,'deals','.account-order-pay .history_attr div strong, .account-order-pay .history_attr div span','display','table-cell','','','.account-order-pay'),(980006,'deals','.account-samples .orders-table .hidden','display','none','','','.account-samples'),(980007,'deals','.account-samples .short-date','display','none','','','.account-samples'),(980008,'deals','.account-samples .view_link','display','inline-block','4','','.account-samples'),(980009,'deals','.account-samples .orders-table .headings','display','none','5639','','.account-samples'),(980010,'deals','.account-samples .orders-table .hidden','display','inline-block','5639','','.account-samples'),(980011,'deals','.account-samples .orders-table .item','display','block','5639','','.account-samples'),(980012,'deals','.account-samples .orders-table .item td','display','block','5639','','.account-samples'),(980013,'deals','.account-samples .orders-table td.name','display','none','5639','','.account-samples'),(980014,'deals','.account-samples .orders-table, .account-samples .orders-table tbody','display','block','5639','','.account-samples'),(980015,'deals','.account-sample-info .history_attr','display','table','','','.account-sample-info'),(980016,'deals','.account-sample-info .history_attr div','display','table-row','','','.account-sample-info'),(980017,'deals','.account-sample-info .history_attr div strong, .account-sample-info .history_attr div span','display','table-cell','','','.account-sample-info'),(980018,'deals','.account-sample-info .popup-tracking-number a','display','block','','','.account-sample-info'),(980019,'deals','.account-sample-info .popup-tracking-number-link','display','block','','','.account-sample-info'),(980020,'deals','.catalog-product-wrap .pn-image','display','inline-block','3','','.catalog-product-wrap'),(980021,'deals','.catalog-product-wrap .pn-price','display','none','','','.catalog-product-wrap'),(980022,'deals','.catalog-product-wrap .prev-next-product','display','none','','','.catalog-product-wrap'),(980023,'deals','.catalog-product-wrap .prev-next-product > span','display','block','','','.catalog-product-wrap'),(980024,'deals','.catalog-product-wrap .pn-image img','display','none','5639','','.catalog-product-wrap'),(980025,'deals','.catalog-product-wrap .pn-name','display','none','5639','','.catalog-product-wrap'),(980026,'deals','.shopping-cart-index .cart-popup .gift-wrap','display','none','','','.shopping-cart-index'),(980027,'deals','.shopping-cart-index .order-summary .bottom-totals .icon','display','none','','','.shopping-cart-index'),(980028,'deals','.shopping-cart-index .order-summary .bottom-totals .price-box .price-row.total','display','flex','','','.shopping-cart-index'),(980029,'deals','.shopping-cart-index .order-summary .bottom-totals .price-row','display','none','2','','.shopping-cart-index'),(980030,'deals','.shopping-cart-index .gift-code .heading-4 ~ *','display','none','5630','','.shopping-cart-index'),(980031,'deals','.checkout-index-wrap .edit-address-popup .address-item > label','display','block','','','.checkout-index-wrap'),(980032,'deals','.checkout-index-wrap .edit-address-popup .addresses','display','flex','','','.checkout-index-wrap'),(980033,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons','display','flex','','','.checkout-index-wrap'),(980034,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons','display','none','4','','.checkout-index-wrap'),(980035,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','display','inline-block','','','.checkout-index-wrap'),(980036,'deals','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','display','block','','','.checkout-index-wrap'),(980037,'deals','.checkout-index-wrap .heading-2','display','none','3','','.checkout-index-wrap'),(980038,'deals','.checkout-index-wrap .heading-2','display','none','4','','.checkout-index-wrap'),(980039,'deals','.checkout-index-wrap .hiding-box .checkout-cart-listing.summary-listing','display','none','','','.checkout-index-wrap'),(980040,'deals','.checkout-order-confirmation .heading-2.prod-ico','display','none','3','','.checkout-order-confirmation'),(980041,'deals','.checkout-order-confirmation .heading-2.prod-ico','display','none','4','','.checkout-order-confirmation'),(980042,'deals','.checkout-order-confirmation .price-row','display','flex','','','.checkout-order-confirmation'),(980043,'deals','.checkout-success-wrap .page-success .text-1','display','block','3','','.checkout-success-wrap'),(980044,'deals','.b-form .columns','display','flex','','','.b-form'),(980045,'deals','.b-form .middle-form form','display','flex','','','.b-form'),(980046,'deals','.b-bottom .cart-options .buttons','display','block','','','.b-bottom'),(980047,'deals','.b-slick .slick-dots','display','flex','','','.b-slick'),(980048,'deals','.b-slick .slick-dots li','display','block','3','','.b-slick'),(980049,'deals','.b-slick .slick-dots button','display','none','','','.b-slick'),(980050,'deals','.hide-page','display','flex','','',''),(980052,'deals','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','display','block','','','.b-menu-lev_vis'),(980053,'deals','.success-page .check-ico-block','display','block','3','','.success-page'),(980054,'deals','.success-page .order_totals .price-row','display','flex','','','.success-page'),(980055,'deals','.success-page .page-success .text-1','display','inline-block','3','','.success-page'),(980056,'deals','.success-page .price-row','display','flex','','','.success-page'),(980060,'deals','.w-checkout-totals .price-row','display','flex','','','.w-checkout-totals'),(980061,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-content','display','block','4','','.b-multi-page-checkout'),(980062,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','display','inline-block','','','.b-multi-page-checkout'),(980063,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .edit','display','none','','','.b-multi-page-checkout'),(980064,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading > .block','display','inline-block','','','.b-multi-page-checkout'),(980065,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','display','inline-block','3','','.b-multi-page-checkout'),(980066,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .count','display','none','','','.b-multi-page-checkout'),(980067,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','block','','','.b-multi-page-checkout'),(980068,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','display','inline-block','4','','.b-multi-page-checkout'),(980069,'deals','.b-form .formWrapBox','display','flex','','','.b-form'),(980071,'deals','.bannersWrap .rightBanner .banner-text-holder','display','flex','','','.bannersWrap'),(980072,'deals','.w-checkout-totals div.price-row','display','none','','','.w-checkout-totals'),(980073,'deals','.w-checkout-totals div.price-row','display','flex','2','','.w-checkout-totals'),(980074,'deals','.b-form .addresses .address-item .edit-ab','display','block','','','.b-form'),(980075,'deals','.b-form .ui-helper-hidden-accessible','display','none','','','.b-form'),(980076,'deals','.w-login-register .middle-form form','display','flex','','','.w-login-register'),(980077,'deals','.w-login-returning .middle-form form','display','flex','','','.w-login-returning'),(980078,'deals','.w-product-reviews .middle-form form','display','flex','','','.w-product-reviews'),(980082,'deals','.footer-menu .level-1 > li > a, .footer-menu .level-1 > li > .no-link','display','block','','','.footer-menu'),(980083,'deals','.footer-menu .level-3 > li > a','display','block','5639','','.footer-menu'),(980084,'deals','.payment-method-tf label','display','block','','','.payment-method-tf'),(980085,'deals','.w-account-customer-additional-field .field-type-checkbox label','display','inline-block','','','.w-account-customer-additional-field'),(980086,'deals','.w-account-customer-additional-field .field-type-text','display','flex','','','.w-account-customer-additional-field'),(980087,'deals','.w-banner .banner-item','display','grid','','','.w-banner'),(980088,'deals','.w-banner .banner-text','display','flex','','','.w-banner'),(980089,'deals','.w-banner .carousel-text','display','flex','','','.w-banner'),(980090,'deals','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','display','table','','','.w-banner'),(980091,'deals','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','display','table-cell','','','.w-banner'),(980092,'deals','.w-banner .sliderItems a + a, .w-banner .sliderItems a + img, .w-banner .sliderItems img + a, .w-banner .sliderItems img + img','display','none','','','.w-banner'),(980093,'deals','.w-catalog-paging ','display','inline-block','2','','.w-catalog-paging'),(980094,'deals','.w-catalog-paging .next','display','inline-block','','','.w-catalog-paging'),(980095,'deals','.w-catalog-paging .next-pages','display','inline-block','','','.w-catalog-paging'),(980096,'deals','.w-catalog-paging .page-number','display','inline-block','','','.w-catalog-paging'),(980097,'deals','.w-catalog-paging .paging','display','inline-block','','','.w-catalog-paging'),(980098,'deals','.w-catalog-paging .paging-holder','display','inline-block','','','.w-catalog-paging'),(980099,'deals','.w-catalog-paging .paging-item','display','inline-block','','','.w-catalog-paging'),(980100,'deals','.w-catalog-paging .prev','display','inline-block','','','.w-catalog-paging'),(980101,'deals','.w-catalog-paging .prev-pages','display','inline-block','','','.w-catalog-paging'),(980111,'deals','.w-menu-slider > ul > li','display','inline-block','','','.w-menu-slider'),(980112,'deals','.w-menu-slider > ul > li > ul','display','none','','','.w-menu-slider'),(980113,'deals','.w-menu-slider > ul > li > ul > li','display','inline-block','','','.w-menu-slider'),(980114,'deals','.w-menu-slider a, .w-menu-slider .no-link','display','inline-block','','','.w-menu-slider'),(980115,'deals','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','display_important','important','','','.b-switch'),(980116,'deals','.w-menu-horizontal ul ul li','display_important','important','','','.w-menu-horizontal'),(980117,'deals','.b-switch .bootstrap-switch .bootstrap-switch-container > span','display_important','important','','','.b-switch'),(980120,'deals','.w-filters .filter-box-content ul li.view_items','display_important','important','','','.w-filters'),(980121,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','display_important','important','','','.b-menu-open_from-left'),(980122,'deals','.b-menu-style .menu-style[data-limit_levels] ul.limited-level','display_important','important','','','.b-menu-style'),(980123,'deals','.b-menu-style .menu-style[data-limit_level_1] li.limited-item, .b-menu-style .menu-style[data-limit_level_2] li.limited-item, .b-menu-style .menu-style[data-limit_level_3] li.limited-item','display_important','important','','','.b-menu-style'),(980124,'deals','.b-menu-style .menu-style[data-limit_level_4] li.limited-item, .b-menu-style .menu-style[data-limit_level_5] li.limited-item, .b-menu-style .menu-style[data-limit_level_6] li.limited-item','display_important','important','','','.b-menu-style'),(980125,'deals','.b-products-listing .products-listing.slick-slider .item-nav','display_important','important','','','.b-products-listing'),(980126,'deals','.w-quote .cart-box.hover-box:hover .cart-content','display_important','important','','','.w-quote'),(980127,'deals','.w-sample .cart-box:hover .cart-content','display_important','important','','','.w-sample'),(980128,'deals','.order-summary .icon','display_important','important','','','.order-summary'),(980130,'deals','.p-quote-checkout-index .order-summary .icon','display_important','important','','','.p-quote-checkout-index'),(980131,'deals','.catalog-product-wrap .pn-price','display_important','important','','','.catalog-product-wrap'),(980132,'deals','.catalog-product-wrap .pn-name','display_important','important','5639','','.catalog-product-wrap'),(980133,'deals','.shopping-cart-index .order-summary .bottom-totals .icon','display_important','important','','','.shopping-cart-index'),(980134,'deals','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','fill','rgba(255, 255, 255, 0)','','','.w-image-maps'),(980135,'deals','.w-image-maps polygon:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(980136,'deals','.w-image-maps rect:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(980137,'deals','.w-image-maps circle:not(.no-items):hover','fill','rgba(255, 255, 255, 0.3)','','','.w-image-maps'),(980138,'deals','.w-image-maps rect.no-items, .w-image-maps circle.no-items, .w-image-maps polygon.no-items','fill','rgba(150, 150, 150, 0.7)','','','.w-image-maps'),(980139,'deals','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','filter','alpha(opacity=0)','','','.b-switch'),(980140,'deals','.b-select-suggest .select2-container .select2-choice','filter','progid','','','.b-select-suggest'),(980141,'deals','.b-select-suggest .select2-container.select2-drop-above .select2-choice','filter','progid','','','.b-select-suggest'),(980142,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','filter','alpha(opacity=50)','','','.b-switch'),(980143,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','filter','alpha(opacity=50)','','','.b-switch'),(980144,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','filter','progid','','','.b-select-suggest'),(980145,'deals','.b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choice, .b-select-suggest .select2-dropdown-open.select2-drop-above .select2-choices','filter','progid','','','.b-select-suggest'),(980146,'deals','.b-select-suggest .select2-dropdown-open .select2-choice .select2-arrow','filter','none','','','.b-select-suggest'),(980147,'deals','.b-select-suggest .select2-dropdown-open .select2-choice','filter','progid','','','.b-select-suggest'),(980148,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow','filter','progid','','','.b-select-suggest'),(980149,'deals','.b-select-suggest .select2-drop-mask','filter','alpha(opacity=0)','','','.b-select-suggest'),(980150,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','filter','alpha(opacity=50)','','','.b-switch'),(980151,'deals','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-basis','0','','','.b-menu-position'),(980152,'deals','.w-promotions .promo-cart-discount .slave','flex-direction','column','','','.w-promotions'),(980153,'deals','.w-catalog-compare .cross-box','flex-direction','column','','','.w-catalog-compare'),(980154,'deals','.w-files-catalog-widgets-files-catalog .item','flex-direction','column','','','.w-files-catalog-widgets-files-catalog'),(980155,'deals','.b-products-listing .products-listing .attribute-qty-block','flex-direction','column','','','.b-products-listing'),(980156,'deals','.w-product-designer-designer .prodDesignerType','flex-direction','row','','','.w-product-designer-designer'),(980157,'deals','.w-press-reviews-widgets-press-reviews-list .item','flex-direction','column','','','.w-press-reviews-widgets-press-reviews-list'),(980158,'deals','.w-rma-returns-history .column','flex-direction','column','','','.w-rma-returns-history'),(980159,'deals','.w-rma-returns-history .filterMessages','flex-direction','column','','screen and (max-width: 768px)','.w-rma-returns-history'),(980160,'deals','.w-predefined-promotion .promo-cart-discount .slave','flex-direction','column','','','.w-predefined-promotion'),(980161,'deals','.w-subscribers .subscribe_box','flex-direction','column','5630','','.w-subscribers'),(980162,'deals','.w-filters .filter-widget-horizontal .filter-box-head','flex-direction','row-reverse','','','.w-filters'),(980163,'deals','.filterLine > .block','flex-direction','column','5660','','.filterLine'),(980165,'deals','.p-wedding-registry-search .search-form > div','flex-grow','2','','','.p-wedding-registry-search'),(980166,'deals','.b-messages .email-line > div','flex-grow','1','','','.b-messages'),(980167,'deals','.w-promotions .prom-multi-discount .promo-product, .w-promotions .prom-multi-discount .promo-category-item','flex-grow','1','','','.w-promotions'),(980168,'deals','.p-wedding-registry-search #searchform-status label','flex-grow','1','','','.p-wedding-registry-search'),(980169,'deals','.w-cart-listing .item .gift-wrap .value','flex-grow','1','','','.w-cart-listing'),(980170,'deals','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-grow','1','','','.b-menu-position'),(980171,'deals','.w-account-personal-catalog .list-switcher a','flex-grow','1','','','.w-account-personal-catalog'),(980172,'deals','.w-account-subscription .title','flex-grow','1','','','.w-account-subscription'),(980173,'deals','.w-catalog-compare .product-listing > div','flex-grow','1','','','.w-catalog-compare'),(980174,'deals','.w-delivery-day .time-left > span','flex-grow','1','','','.w-delivery-day'),(980175,'deals','.w-files-catalog-widgets-files-catalog .image','flex-grow','1','','','.w-files-catalog-widgets-files-catalog'),(980176,'deals','.w-filters-simple .system-1','flex-grow','1','','','.w-filters-simple'),(980177,'deals','.w-predefined-promotion .prom-multi-discount .promo-product, .w-predefined-promotion .prom-multi-discount .promo-category-item','flex-grow','1','','','.w-predefined-promotion'),(980179,'deals','.footer-menu .level-1 > li','flex-grow','1','','','.footer-menu'),(980180,'deals','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-grow','1','','','.w-account-customer-additional-field'),(980181,'deals','.w-account-customer-additional-field .field-type-text label','flex-grow','1','','','.w-account-customer-additional-field'),(980182,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','flex-shrink','0','','','.w-upload-customer-id-upload-customer-id-form'),(980183,'deals','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li','flex-shrink','1','','','.b-menu-position'),(980184,'deals','.w-catalog-compare .cross-box','flex-shrink','0','','','.w-catalog-compare'),(980185,'deals','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','flex-shrink','0','','','.w-account-customer-additional-field'),(980186,'deals','.w-account-customer-additional-field .field-type-text label','flex-shrink','0','','','.w-account-customer-additional-field'),(980187,'deals','.w-promotions .promo-cart-discount .content','flex-wrap','wrap','','','.w-promotions'),(980188,'deals','.w-promotions .promo-salemaker .content','flex-wrap','wrap','','','.w-promotions'),(980189,'deals','.b-products-listing .products-listing .attribute-qty-blocks','flex-wrap','wrap','','','.b-products-listing'),(980190,'deals','.w-top-categories .categories','flex-wrap','wrap','','','.w-top-categories'),(980191,'deals','.w-files-catalog-widgets-files-catalog ','flex-wrap','wrap','','','.w-files-catalog-widgets-files-catalog'),(980192,'deals','.w-product-bundle .bundle-products','flex-wrap','wrap','','','.w-product-bundle'),(980193,'deals','.w-product-in-bundles .bundle-products','flex-wrap','wrap','','','.w-product-in-bundles'),(980195,'deals','.w-product-properties-icons ','flex-wrap','wrap','','','.w-product-properties-icons'),(980196,'deals','.w-delivery-location-product-categories .categories','flex-wrap','wrap','','','.w-delivery-location-product-categories'),(980197,'deals','.w-product-designer-designer .prodDesignerType','flex-wrap','wrap','','','.w-product-designer-designer'),(980198,'deals','.w-press-reviews-widgets-press-reviews .sub-box','flex-wrap','wrap','','','.w-press-reviews-widgets-press-reviews'),(980199,'deals','.w-press-reviews-widgets-press-reviews-list .review-box > *','flex-wrap','wrap','','','.w-press-reviews-widgets-press-reviews-list'),(980200,'deals','.w-press-reviews-widgets-press-reviews-list .review-box','flex-wrap','wrap','5660','','.w-press-reviews-widgets-press-reviews-list'),(980201,'deals','.w-predefined-promotion .promo-cart-discount .content','flex-wrap','wrap','','','.w-predefined-promotion'),(980202,'deals','.w-predefined-promotion .promo-salemaker .content','flex-wrap','wrap','','','.w-predefined-promotion'),(980203,'deals','.w-categories .categories','flex-wrap','wrap','','','.w-categories'),(980204,'deals','.w-filters .choose-filters','flex-wrap','wrap','','','.w-filters'),(980206,'deals','.checkout-index-wrap .edit-address-popup .addresses','flex-wrap','wrap','','','.checkout-index-wrap'),(980207,'deals','.b-form .columns','flex-wrap','wrap','','','.b-form'),(980208,'deals','.b-form .middle-form form','flex-wrap','wrap','','','.b-form'),(980209,'deals','.b-form .formWrapBox','flex-wrap','wrap','','','.b-form'),(980210,'deals','.w-product-reviews .middle-form form','flex-wrap','wrap','','','.w-product-reviews'),(980211,'deals','.w-login-register .middle-form form','flex-wrap','wrap','','','.w-login-register'),(980212,'deals','.w-login-returning .middle-form form','flex-wrap','wrap','','','.w-login-returning'),(980213,'deals','.heading-4 .right-text, h4 .right-text','float','right','','',''),(980214,'deals','.w-checkout-billing-address .btn-cancel','float','left','','','.w-checkout-billing-address'),(980215,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(980216,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(980218,'deals','.w-socials .post_item_img','float','left','','','.w-socials'),(980221,'deals','.w-brands .brands-listing > div','float','left','','','.w-brands'),(980222,'deals','.w-cart-shipping-estimator .left-area','float','left','','','.w-cart-shipping-estimator'),(980223,'deals','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(980224,'deals','.b-messages .msv_btn .btn','float','right','','','.b-messages'),(980225,'deals','.b-messages .messages-menu li span','float','right','','','.b-messages'),(980226,'deals','.w-checkout-shipping-address .btn-cancel','float','left','','','.w-checkout-shipping-address'),(980227,'deals','.w-login-block .guest','float','right','','','.w-login-block'),(980228,'deals','.p-payer-order-confirmation .dob-hide > div','float','right','','','.p-payer-order-confirmation'),(980229,'deals','.p-payer-order-confirmation .dob-hide label','float','left','','','.p-payer-order-confirmation'),(980230,'deals','.p-payer-order-pay .dob-hide label','float','left','','','.p-payer-order-pay'),(980231,'deals','.p-payer-order-pay .dob-hide > div','float','right','','','.p-payer-order-pay'),(980232,'deals','.b-compare .col-two label, .b-compare .col-two select','float','left','','','.b-compare'),(980233,'deals','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(980234,'deals','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(980235,'deals','.w-login-block .guest','float','right','','','.w-login-block'),(980236,'deals','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(980237,'deals','.w-login-block .returning','float','left','','','.w-login-block'),(980238,'deals','.w-login-block .new','float','right','','','.w-login-block'),(980239,'deals','.w-menu-horizontal li','float','none','','','.w-menu-horizontal'),(980240,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(980241,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(980242,'deals','.b-bottom .closeable-heading','float','right','3','','.b-bottom'),(980243,'deals','.b-form .col-3','float','left','','','.b-form'),(980244,'deals','.w-checkout-contact-information .btn-save','float','right','','','.w-checkout-contact-information'),(980245,'deals','.b-form .terms-login .bootstrap-switch','float','right','','','.b-form'),(980246,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(980249,'deals','.buttons .right-buttons','float','right','','',''),(980250,'deals','.buttons .left-buttons','float','left','','',''),(980251,'deals','.w-login-block .returning','float','left','','','.w-login-block'),(980252,'deals','.w-brands .brands-listing > div','float','left','','','.w-brands'),(980253,'deals','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(980254,'deals','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(980256,'deals','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(980257,'deals','.message.success','float','left','3','',''),(980258,'deals','.w-socials > li','float','left','','','.w-socials'),(980259,'deals','.w-socials .post_item_img','float','left','','','.w-socials'),(980260,'deals','.w-checkout-billing-address .add-ab','float','left','','','.w-checkout-billing-address'),(980261,'deals','.w-cart-listing .right-area','float','none','5639','','.w-cart-listing'),(980262,'deals','.w-checkout-shipping-address .add-ab','float','left','','','.w-checkout-shipping-address'),(980263,'deals','.w-socials > li','float','left','','','.w-socials'),(980264,'deals','.w-socials .post_item_img','float','left','','','.w-socials'),(980265,'deals','.w-socials > li','float','left','','','.w-socials'),(980266,'deals','.b-form .addresses .address-item input[type=\"radio\"]','float','left','','','.b-form'),(980267,'deals','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(980268,'deals','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(980269,'deals','.w-socials > li','float','left','','','.w-socials'),(980270,'deals','.heading-4 .edit, h4 .edit','float','right','','',''),(980271,'deals','.w-login-block .returning','float','left','','','.w-login-block'),(980273,'deals','.b-info-popup .password-info .info-popup','float','right','','','.b-info-popup'),(980274,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(980275,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(980276,'deals','.heading-3 .right-text, h3 .right-text','float','right','','',''),(980277,'deals','.heading-3 .edit, h3 .edit','float','right','','',''),(980278,'deals','.w-socials .post_item_img','float','left','','','.w-socials'),(980280,'deals','.w-checkout-billing-address .addresses .address-item','float','left','','','.w-checkout-billing-address'),(980281,'deals','.w-list-b2b .select-attributes','float','left','','','.w-list-b2b'),(980282,'deals','.w-socials .post_item_img','float','left','','','.w-socials'),(980283,'deals','.edit-link','float','right','','',''),(980286,'deals','.w-socials > li','float','left','','','.w-socials'),(980287,'deals','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(980288,'deals','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(980289,'deals','.w-promo-code .btn','float','right','','','.w-promo-code'),(980290,'deals','.b-form .shipping-method .cost','float','right','','','.b-form'),(980291,'deals','.b-form .shipping-method .input','float','left','','','.b-form'),(980292,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(980293,'deals','.b-sub-totals .historyTotal table','float','right','','','.b-sub-totals'),(980294,'deals','.w-login-block .returning','float','left','','','.w-login-block'),(980295,'deals','.w-login-block .guest','float','right','','','.w-login-block'),(980296,'deals','.w-login-block .new','float','right','','','.w-login-block'),(980297,'deals','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(980298,'deals','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(980299,'deals','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(980300,'deals','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(980301,'deals','.b-form .col-right','float','right','','','.b-form'),(980302,'deals','.b-form .payment-method .item-radio input','float','left','','','.b-form'),(980303,'deals','.w-cart-listing .actions > div','float','left','','','.w-cart-listing'),(980304,'deals','.w-login-block .guest','float','right','','','.w-login-block'),(980305,'deals','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(980306,'deals','.w-login-block .new','float','right','','','.w-login-block'),(980308,'deals','.w-brands .brands-listing > div','float','left','','','.w-brands'),(980310,'deals','.w-cart-shipping-estimator .right-area','float','right','','','.w-cart-shipping-estimator'),(980311,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(980312,'deals','.w-cart-give-away .ga_attributes > div','float','left','','','.w-cart-give-away'),(980313,'deals','.b-bottom .cart-options .option-item','float','left','','','.b-bottom'),(980314,'deals','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(980315,'deals','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(980316,'deals','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(980317,'deals','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(980318,'deals','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(980319,'deals','.w-list-b2b .select-attributes:nth-child(2n)','float','right','','','.w-list-b2b'),(980320,'deals','.b-upload-files .remove-file','float','right','','','.b-upload-files'),(980321,'deals','.w-login-block .new','float','right','','','.w-login-block'),(980322,'deals','.w-cart-compare .product .image','float','left','','','.w-cart-compare'),(980323,'deals','.b-form .col-left','float','left','','','.b-form'),(980324,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','float','left','','','.b-tracking-numbers'),(980325,'deals','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(980326,'deals','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(980327,'deals','.w-login-block .row-password-forgotten','float','left','','','.w-login-block'),(980328,'deals','.b-form .addresses .address-item','float','left','','','.b-form'),(980329,'deals','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(980330,'deals','.w-socials > li','float','left','','','.w-socials'),(980331,'deals','.w-cart-give-away .ga_column','float','left','','','.w-cart-give-away'),(980332,'deals','.b-select-suggest .select2-container-multi .select2-choices li','float','left','','','.b-select-suggest'),(980333,'deals','.w-neighbour-checkout .bootstrap-switch','float','right','','','.w-neighbour-checkout'),(980334,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','float','left','3','','.b-warehouses-popup'),(980335,'deals','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(980341,'deals','.w-menu-horizontal .box','float','none','','','.w-menu-horizontal'),(980343,'deals','.w-login-block .new','float','right','','','.w-login-block'),(980344,'deals','.w-login-block .guest','float','right','','','.w-login-block'),(980345,'deals','.w-brands .brands-listing > div','float','left','','','.w-brands'),(980347,'deals','.w-login-block .guest','float','right','','','.w-login-block'),(980349,'deals','.w-menu-big li','float','none','','','.w-menu-big'),(980350,'deals','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(980351,'deals','.w-promo-code .btn','float','right','','','.w-promo-code'),(980352,'deals','.w-login-block .new','float','right','','','.w-login-block'),(980353,'deals','.w-account-addresses-list .address-fields input[type=\"radio\"]','float','left','','','.w-account-addresses-list'),(980354,'deals','.w-account-addresses-list .addsess-suggestion-item','float','left','','','.w-account-addresses-list'),(980355,'deals','.b-products-listing .products-listing .bonus-points-price','float','left','3','','.b-products-listing'),(980356,'deals','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','float','right','','','.b-products-listing'),(980357,'deals','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','float','right','','','.b-products-listing'),(980358,'deals','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','float','right','','','.b-products-listing'),(980359,'deals','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','float','right','','','.b-products-listing'),(980360,'deals','.b-products-listing .BlockBox.type-7 > .col, .b-products-listing .BlockBox.type-8 > .col, .b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col','float','left','','','.b-products-listing'),(980361,'deals','.b-products-listing .BlockBox.type-2 > .col, .b-products-listing .BlockBox.type-3 > .col, .b-products-listing .BlockBox.type-4 > .col, .b-products-listing .BlockBox.type-5 > .col, .b-products-listing .BlockBox.type-6 > .col','float','left','','','.b-products-listing'),(980362,'deals','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','float','right','','','.b-products-listing'),(980363,'deals','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','float','right','','','.b-products-listing'),(980364,'deals','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','float','right','','','.b-products-listing'),(980365,'deals','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','float','right','','','.b-products-listing'),(980366,'deals','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','float','right','','','.b-products-listing'),(980367,'deals','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','float','right','','','.b-products-listing'),(980368,'deals','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','float','right','','','.b-products-listing'),(980369,'deals','.b-products-listing .BlockBox.type-9 > .col, .b-products-listing .BlockBox.type-10 > .col, .b-products-listing .BlockBox.type-11 > .col, .b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockB','float','left','','','.b-products-listing'),(980370,'deals','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','float','right','','','.b-products-listing'),(980371,'deals','.b-products-listing .products-listing .item','float','none','','','.b-products-listing'),(980372,'deals','.b-products-listing .products-listing.align-left .item','float','left','','','.b-products-listing'),(980373,'deals','.b-products-listing .products-listing.align-right .item','float','right','','','.b-products-listing'),(980374,'deals','.b-products-listing .wedding-registry-count','float','right','','','.b-products-listing'),(980375,'deals','.w-checkout-gdpr .candlestick-wrapper','float','right','','','.w-checkout-gdpr'),(980376,'deals','.b-compare .compare-box-btn','float','right','','','.b-compare'),(980377,'deals','.w-cart-give-away .ga_img','float','left','','','.w-cart-give-away'),(980378,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(980379,'deals','.w-cart-compare .product-actions','float','right','','','.w-cart-compare'),(980380,'deals','.w-socials .post_item_img','float','left','','','.w-socials'),(980381,'deals','.w-promo-code .btn','float','right','','','.w-promo-code'),(980383,'deals','.w-login-block .returning','float','left','','','.w-login-block'),(980384,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','float','right','','','.b-tracking-numbers'),(980385,'deals','.w-checkout-create-account .newsletter-switcher .bootstrap-switch','float','right','','','.w-checkout-create-account'),(980386,'deals','.w-checkout-shipping-address .addresses .address-item','float','left','','','.w-checkout-shipping-address'),(980387,'deals','.w-checkout-create-account .create-account-switcher','float','right','','','.w-checkout-create-account'),(980388,'deals','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(980389,'deals','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(980390,'deals','.w-login-block .returning','float','left','','','.w-login-block'),(980392,'deals','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(980393,'deals','.w-promo-code .btn','float','right','','','.w-promo-code'),(980394,'deals','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(980395,'deals','.w-promo-code .promo-code-form','float','right','','','.w-promo-code'),(980396,'deals','.b-form .columns .col-2','float','left','','','.b-form'),(980397,'deals','.w-product-cross-sell .buy-all-checker','float','left','','','.w-product-cross-sell'),(980398,'deals','.w-cart-listing .item > div','float','left','','','.w-cart-listing'),(980399,'deals','.w-cart-listing .points-redeem','float','left','3','','.w-cart-listing'),(980400,'deals','.w-cart-listing .right-area','float','left','','','.w-cart-listing'),(980401,'deals','.w-cart-listing .links','float','left','','','.w-cart-listing'),(980402,'deals','.w-cart-give-away .ga_price .checkBoxWrap','float','right','','','.w-cart-give-away'),(980405,'deals','.w-brands .brands-listing > div','float','left','','','.w-brands'),(980406,'deals','.order-summary .btn-2','float','none','5639','','.order-summary'),(980407,'deals','.w-promo-code .btn','float','right','','','.w-promo-code'),(980411,'deals','.w-login-block .receive-newsletter','float','left','','','.w-login-block'),(980412,'deals','.w-checkout-billing-address .bootstrap-switch','float','right','','','.w-checkout-billing-address'),(980413,'deals','.w-brands .brands-listing > div','float','left','','','.w-brands'),(980416,'deals','.b-products-listing .BlockBox.type-12 > .col, .b-products-listing .BlockBox.type-13 > .col, .b-products-listing .BlockBox.type-14 > .col, .b-products-listing .BlockBox.type-15 > .col, .b-products-listing .BlockBox.type-16 > .col','float','left','','','.b-products-listing'),(980417,'deals','.w-product-reviews .write-review-button','float','right','','','.w-product-reviews'),(980418,'deals','.w-promo-code .btn','float','right','','','.w-promo-code'),(980419,'deals','.w-filters .handle-to','float','right','','','.w-filters'),(980420,'deals','.w-filters .handle-from','float','left','','','.w-filters'),(980421,'deals','.w-cart-compare .js-cart_totals_container','float','left','','','.w-cart-compare'),(980422,'deals','.w-cart-compare .buttons','float','right','','','.w-cart-compare'),(980423,'deals','.w-login-block .col-2:nth-child(2n + 1)','float','left','','','.w-login-block'),(980424,'deals','.w-login-block .col-2:nth-child(2n)','float','right','','','.w-login-block'),(980428,'deals','.w-promo-code .promo-text','float','left','','','.w-promo-code'),(980429,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(980430,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(980431,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(980432,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(980433,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','float','right','','','.b-menu-lev_vis-click_icon'),(980434,'deals','.b-trade-approval .col-right','float','right','','','.b-trade-approval'),(980435,'deals','.b-trade-approval .col-left','float','left','','','.b-trade-approval'),(980436,'deals','.b-trade-approval .col-3','float','left','','','.b-trade-approval'),(980437,'deals','.w-catalog-compare .compare label','float','right','','','.w-catalog-compare'),(980438,'deals','.w-catalog-compare .buyButton','float','right','','','.w-catalog-compare'),(980439,'deals','.w-delivery-day .left-count','float','left','','','.w-delivery-day'),(980440,'deals','.w-delivery-day .left-text-left','float','left','','','.w-delivery-day'),(980441,'deals','.w-delivery-day .left-text-right','float','left','','','.w-delivery-day'),(980443,'deals','.b-products-listing .products-listing.list-productlisting .stock','float','none','','','.b-products-listing'),(980444,'deals','.b-slick .slick-slide','float','left','','','.b-slick'),(980445,'deals','.b-slick [dir=\'rtl\'] .slick-slide','float','right','','','.b-slick'),(980446,'deals','.w-quote .image','float','left','','','.w-quote'),(980447,'deals','.w-quote .sub-total','float','right','','','.w-quote'),(980448,'deals','.w-quote .sub-total-text','float','left','','','.w-quote'),(980449,'deals','.b-quantity .qty-input label','float','left','','','.b-quantity'),(980450,'deals','.w-product-sale-ends .left-count','float','left','','','.w-product-sale-ends'),(980451,'deals','.w-product-sale-ends .left-text-left','float','left','','','.w-product-sale-ends'),(980452,'deals','.w-product-sale-ends .left-text-right','float','left','','','.w-product-sale-ends'),(980453,'deals','.w-product-quantity .qty_packs .qty_t','float','left','','','.w-product-quantity'),(980454,'deals','.w-product-quantity .total-qty .inps','float','right','','','.w-product-quantity'),(980455,'deals','.w-product-bonus-points > div > div','float','left','','','.w-product-bonus-points'),(980456,'deals','.w-compare .compare-list-buttons','float','right','','','.w-compare'),(980457,'deals','.w-compare .clear-compare-button','float','right','','','.w-compare'),(980458,'deals','.w-compare .image','float','left','','','.w-compare'),(980459,'deals','.w-files-catalog-widgets-files-list .file','float','left','3','','.w-files-catalog-widgets-files-list'),(980460,'deals','.w-sample .image','float','left','','','.w-sample'),(980461,'deals','.w-sample .sub-total','float','right','','','.w-sample'),(980462,'deals','.w-sample .sub-total-text','float','left','','','.w-sample'),(980463,'deals','.w-product-bundle .attributes-item','float','left','','','.w-product-bundle'),(980464,'deals','.w-product-bundle .bundle_image','float','left','','','.w-product-bundle'),(980465,'deals','.w-product-bundle .bundle_qty','float','left','','','.w-product-bundle'),(980466,'deals','.w-product-bundle .bundle_price','float','right','','','.w-product-bundle'),(980467,'deals','.w-product-in-bundles .attributes-item','float','left','','','.w-product-in-bundles'),(980468,'deals','.w-product-in-bundles .bundle_qty','float','left','','','.w-product-in-bundles'),(980469,'deals','.w-product-in-bundles .bundle_image','float','left','','','.w-product-in-bundles'),(980470,'deals','.w-cart-listing .item div.price','float','left','5639','','.w-cart-listing'),(980471,'deals','.b-pagination .pagination .left-area','float','left','','','.b-pagination'),(980472,'deals','.b-pagination .pagination .right-area','float','right','','','.b-pagination'),(980473,'deals','.w-product-quantity-discounts .item','float','left','','','.w-product-quantity-discounts'),(980474,'deals','.w-product-multi-inventory .select-box:nth-child(2n)','float','left','','','.w-product-multi-inventory'),(980475,'deals','.w-product-multi-inventory .select-box:nth-child(2n+1)','float','left','','','.w-product-multi-inventory'),(980476,'deals','.w-product-multi-inventory .radio-attributes > label','float','left','','','.w-product-multi-inventory'),(980477,'deals','.b-products-listing .products-listing .radio-attributes > label','float','left','','','.b-products-listing'),(980478,'deals','.w-product-collection .chosen-products','float','left','','','.w-product-collection'),(980479,'deals','.w-product-collection .current-product','float','left','','','.w-product-collection'),(980480,'deals','.w-product-collection .right-area','float','left','','','.w-product-collection'),(980481,'deals','.w-product-collection .current-product, .w-product-collection .chosen-products','float','none','5639','','.w-product-collection'),(980482,'deals','.w-product-collection .right-area','float','none','5639','','.w-product-collection'),(980483,'deals','.w-product-attributes .radio-attributes > label','float','left','','','.w-product-attributes'),(980484,'deals','.w-product-attributes .select-box:nth-child(2n)','float','left','','','.w-product-attributes'),(980485,'deals','.w-product-attributes .select-box:nth-child(2n+1)','float','left','','','.w-product-attributes'),(980486,'deals','.w-product-groups .radioBox label','float','left','','','.w-product-groups'),(980487,'deals','.w-product-groups .radioBox label .containerBlock img','float','left','','','.w-product-groups'),(980488,'deals','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img','float','none','','','.w-product-groups'),(980489,'deals','.b-products-listing .products-listing .attribute-color','float','left','','','.b-products-listing'),(980490,'deals','.w-product-custom-bundle .chosen-products','float','left','','','.w-product-custom-bundle'),(980491,'deals','.w-product-custom-bundle .current-product','float','left','','','.w-product-custom-bundle'),(980492,'deals','.w-product-custom-bundle .right-area','float','left','','','.w-product-custom-bundle'),(980493,'deals','.w-product-custom-bundle .chosen-products','float','none','5639','','.w-product-custom-bundle'),(980494,'deals','.w-product-custom-bundle .right-area','float','none','5639','','.w-product-custom-bundle'),(980495,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','float','left','','','.w-catalog-pages-category-pages-last-list'),(980496,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','float','left','','','.w-catalog-pages-category-pages-last-list-block'),(980497,'deals','.w-delivery-location-top-location-list .deliveryList li','float','left','','','.w-delivery-location-top-location-list'),(980498,'deals','.w-delivery-location-location-list .deliveryList li','float','left','','','.w-delivery-location-location-list'),(980499,'deals','.w-delivery-location-featured-list .deliveryList > ul > li','float','left','','','.w-delivery-location-featured-list'),(980500,'deals','.w-delivery-location-featured-list .deliveryList > ul > li','float','none','5660','','.w-delivery-location-featured-list'),(980501,'deals','.w-sale-category .holder-1','float','right','','','.w-sale-category'),(980502,'deals','.w-sale-category .holder-2','float','left','','','.w-sale-category'),(980503,'deals','.w-sale-category .image','float','left','','','.w-sale-category'),(980504,'deals','.w-sale-category .left-count','float','left','','','.w-sale-category'),(980505,'deals','.w-sale-category .left-text-left','float','left','','','.w-sale-category'),(980506,'deals','.w-sale-category .left-text-right','float','left','','','.w-sale-category'),(980507,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','float','left','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(980508,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','float','left','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(980509,'deals','.w-delivery-location-list-by-page .item','float','left','','','.w-delivery-location-list-by-page'),(980510,'deals','.w-delivery-location-cross-pages .item','float','left','','','.w-delivery-location-cross-pages'),(980511,'deals','.w-catalog-delivery-locations .item','float','left','','','.w-catalog-delivery-locations'),(980512,'deals','.w-catalog-delivery-locations .item','float','none','5630','','.w-catalog-delivery-locations'),(980513,'deals','.w-product-designer-designer .prodDesignerType label','float','left','','','.w-product-designer-designer'),(980514,'deals','.w-product-designer-designer .prodDesignerType','float','none','','','.w-product-designer-designer'),(980515,'deals','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','float','right','','','.w-press-reviews-widgets-press-reviews-small'),(980516,'deals','.w-gift-wrap-message-checkout .text','float','left','','','.w-gift-wrap-message-checkout'),(980517,'deals','.w-support-system-filter .filter-categories','float','none','','','.w-support-system-filter'),(980518,'deals','.w-support-system-filter .dd3-content .collapse_span','float','right','','','.w-support-system-filter'),(980519,'deals','.w-support-system-listing .product_icon','float','left','','','.w-support-system-listing'),(980520,'deals','.w-rma-returns-history .topRow .icons','float','right','','','.w-rma-returns-history'),(980521,'deals','.w-product-configurator .pc_item','float','left','','','.w-product-configurator'),(980522,'deals','.w-product-configurator .item-content > div','float','left','5630','','.w-product-configurator'),(980523,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','float','left','','','.w-catalog-pages-category-pages-list'),(980524,'deals','.w-filters span.open','float','right','','','.w-filters'),(980525,'deals','.w-product-quantity-discounts .quantity-discounts-content .item','float','left','','','.w-product-quantity-discounts'),(980526,'deals','.messageBox .info','float','left','3','',''),(980527,'deals','.w-communication-new-topic .filterMessages','float','right','','','.w-communication-new-topic'),(980528,'deals','.b-products-listing .products-listing .attributes select','float','left','','','.b-products-listing'),(980529,'deals','.b-products-listing .products-listing.list-productlisting .attributes select','float','none','','','.b-products-listing'),(980530,'deals','.b-products-listing .products-listing.list-productlisting .radio-attributes > label','float','none','','','.b-products-listing'),(980531,'deals','.w-product-reviews .write-review-button','float','none','5660','','.w-product-reviews'),(980532,'deals','.w-cart-listing .item .qty','float','none','5630','','.w-cart-listing'),(980533,'deals','.b-info .info','float','left','3','','.b-info'),(980534,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li','float','left','','','.preFooter'),(980535,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li','float','none','5630','','.preFooter'),(980537,'deals','.w-compare .compare-list-buttons','float','none','5639','','.w-compare'),(980538,'deals','.w-cart-shipping-estimator .left-area','float','none','5630','','.w-cart-shipping-estimator'),(980539,'deals','.w-cart-shipping-estimator .right-area','float','none','5630','','.w-cart-shipping-estimator'),(980540,'deals','.w-quote-products .w-cart-listing .item .qty','float','none','5630','','.w-quote-products'),(980549,'deals','.account-address-book .address_book h2 strong','float','left','','','.account-address-book'),(980550,'deals','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','float','left','','','.account-address-book'),(980551,'deals','.account-address-book .button1','float','right','','','.account-address-book'),(980552,'deals','.account-address-book .button2','float','left','','','.account-address-book'),(980553,'deals','.account-address-book .address_book_row .column','float','none','5630','','.account-address-book'),(980554,'deals','.account-address-book .address_book_row .column + .column','float','none','5630','','.account-address-book'),(980555,'deals','.account-address-book .topInfo > div','float','none','5630','','.account-address-book'),(980556,'deals','.account-address-book .topInfo > div + div','float','none','5630','','.account-address-book'),(980558,'deals','.account-order-pay .history_info > div','float','left','','','.account-order-pay'),(980559,'deals','.account-sample-info .history_info > div','float','left','','','.account-sample-info'),(980560,'deals','.checkout-index-wrap .dob-hide > div','float','right','','','.checkout-index-wrap'),(980561,'deals','.checkout-index-wrap .dob-hide label','float','left','','','.checkout-index-wrap'),(980562,'deals','.b-form .add-ab','float','right','','','.b-form'),(980563,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','float','right','','','.b-multi-page-checkout'),(980564,'deals','.b-slick .slick-slide','float_important','important','','','.b-slick'),(980565,'deals','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-family','$font-1','','','.w-communication-new-topic'),(980566,'deals','.b-upload-file .snapshot','font-family','$font-icons-1','3','','.b-upload-file'),(980567,'deals','.heading-4 .edit, h4 .edit','font-family','trueloaded','4','',''),(980568,'deals','.heading-4 .edit, h4 .edit','font-family','$font-2','','',''),(980569,'deals','.message.success','font-family','trueloaded','3','',''),(980570,'deals','.b-form .checkbox-style:checked + .checkbox-span:before','font-family','$font-icons-1','','','.b-form'),(980571,'deals','.w-filters .filter-box-head','font-family','$font-1','','','.w-filters'),(980572,'deals','.p-quick-order-index .paginate_button.previous','font-family','$font-icons-1','3','','.p-quick-order-index'),(980573,'deals','.p-quick-order-index .paginate_button.next','font-family','$font-icons-1','3','','.p-quick-order-index'),(980574,'deals','.w-cart-compare .cart-name a','font-family','$font-1','','','.w-cart-compare'),(980575,'deals','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(980577,'deals','.p-sample-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-sample-checkout-success'),(980578,'deals','.p-sample-checkout-success .page-success .text-1, .p-sample-checkout-success .page-success .text-2, .p-sample-checkout-success .page-success .text-3','font-family','$font-1','','','.p-sample-checkout-success'),(980579,'deals','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(980580,'deals','.testimonials .heading-3','font-family','trueloaded','3','',''),(980581,'deals','.w-promotions .nextdiscount .heading','font-family','$font-icons-1','3','','.w-promotions'),(980582,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','font-family','$font-icons-1','3','','.b-warehouses-popup'),(980583,'deals','.b-warehouses-popup .warehouses-popup-link','font-family','$font-icons-1','3','','.b-warehouses-popup'),(980584,'deals','.b-preloader .preloader','font-family','$font-icons-1','3','','.b-preloader'),(980585,'deals','.w-social-links a','font-family','$font-icons-1','','','.w-social-links'),(980586,'deals','.b-bottom .closeable-heading','font-family','$font-icons-1','3','','.b-bottom'),(980587,'deals','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(980588,'deals','.b-messages .messBtnMenuUnread','font-family','$font-icons-1','3','','.b-messages'),(980589,'deals','.b-messages .messBtnMenuDelete','font-family','trueloaded','3','','.b-messages'),(980590,'deals','.b-messages span.starred::before','font-family','trueloaded','','','.b-messages'),(980591,'deals','.b-messages .messBtnMenuStarred','font-family','trueloaded','3','','.b-messages'),(980592,'deals','.b-messages .content_management_attach span','font-family','$font-1','','','.b-messages'),(980593,'deals','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(980594,'deals','.p-payer-order-confirmation .ship-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(980595,'deals','.p-payer-order-confirmation .pay-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(980596,'deals','.p-payer-order-confirmation .order-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(980597,'deals','.p-payer-order-confirmation .discount-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(980598,'deals','.p-payer-order-confirmation .comment-ico','font-family','trueloaded','3','','.p-payer-order-confirmation'),(980599,'deals','.p-payer-order-pay .ship-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(980600,'deals','.p-payer-order-pay .order-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(980601,'deals','.p-payer-order-pay .pay-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(980602,'deals','.p-payer-order-pay .discount-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(980603,'deals','.p-payer-order-pay .comment-ico','font-family','trueloaded','3','','.p-payer-order-pay'),(980604,'deals','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(980605,'deals','.b-fancybox .fancybox-close','font-family','FontAwesome','3','','.b-fancybox'),(980606,'deals','.b-messages .select2-search-choice-close','font-family','trueloaded','3','','.b-messages'),(980608,'deals','.bell-ico .heading-2','font-family','trueloaded','3','','.bell-ico'),(980609,'deals','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(980610,'deals','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-family','$font-icons-1','3','','.w-upload-customer-id-upload-customer-id-form'),(980611,'deals','.w-coupons-and-vauchers-checkout .btn-remove','font-family','trueloaded','3','','.w-coupons-and-vauchers-checkout'),(980612,'deals','.w-filters .open','font-family','$font-icons-1','3','','.w-filters'),(980613,'deals','.w-categories h2.name','font-family','$font-1','','','.w-categories'),(980614,'deals','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(980615,'deals','.b-fancybox .fancybox-nav span','font-family','trueloaded','','','.b-fancybox'),(980617,'deals','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','font-family','$font-icons-1','3','','.w-checkout-contact-information'),(980618,'deals','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(980619,'deals','.no-found','font-family','$font-2','','',''),(980620,'deals','.view-all .btn','font-family','$font-icons-1','4','',''),(980621,'deals','.w-catalog-listing-look .list','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(980622,'deals','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(980625,'deals','.w-cart-compare .price-cell','font-family','$font-1','','','.w-cart-compare'),(980626,'deals','.b-bottom .footerTitle','font-family','$font-icons-1','5630,4','','.b-bottom'),(980628,'deals','.b-rating .glyphicon-star','font-family','$font-icons-1','3','','.b-rating'),(980629,'deals','.w-chat .w-chat-box a','font-family','$font-icons-1','3','','.w-chat'),(980630,'deals','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(980632,'deals','.w-cart-compare .product-actions .dropdown-toggle','font-family','$font-icons-1','3','','.w-cart-compare'),(980633,'deals','.w-cart-compare .atr-col','font-family','$font-icons-1','3','','.w-cart-compare'),(980635,'deals','.b-rating .glyphicon','font-family','$font-icons-1','','','.b-rating'),(980636,'deals','.order-summary .price-row.ot_gv .title','font-family','trueloaded','3','','.order-summary'),(980637,'deals','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(980638,'deals','.w-tabs .tab-li.tab-wishlist a','font-family','trueloaded','3','','.w-tabs'),(980639,'deals','.w-multi-cart-actions .cart-actions .dropdown-toggle','font-family','$font-icons-1','3','','.w-multi-cart-actions'),(980640,'deals','.w-top-categories h2.name','font-family','$font-1','','','.w-top-categories'),(980643,'deals','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(980644,'deals','.btn-edit','font-family','trueloaded','3','',''),(980645,'deals','.w-tabs .tab-li.tab-cart a','font-family','trueloaded','3','','.w-tabs'),(980646,'deals','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(980647,'deals','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(980648,'deals','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(980650,'deals','.heading-5, h5, .h-block h5','font-family','$font-2','','',''),(980651,'deals','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(980652,'deals','.w-filters .input-checkbox:checked + .checkbox-span:before','font-family','$font-icons-1','','','.w-filters'),(980653,'deals','.in-stock-icon','font-family','$font-icons-1','3','',''),(980654,'deals','.out-stock-icon','font-family','$font-icons-1','3','',''),(980655,'deals','.transit-icon','font-family','$font-icons-1','3','',''),(980656,'deals','.heading-3 .edit, h3 .edit','font-family','trueloaded','4','',''),(980657,'deals','.heading-3 .edit, h3 .edit','font-family','$font-2','','',''),(980658,'deals','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(980659,'deals','.w-checkout-create-account .account-benefits strong','font-family','trueloaded','3','','.w-checkout-create-account'),(980660,'deals','.w-cart-bonus-points .btn-remove','font-family','trueloaded','3','','.w-cart-bonus-points'),(980663,'deals','.js-stock-icon','font-family','$font-icons-1','3','',''),(980664,'deals','.b-switch .candlestick-wrapper .fa-check','font-family','FontAwesome','3','','.b-switch'),(980665,'deals','.b-switch .candlestick-wrapper .fa-times','font-family','FontAwesome','3','','.b-switch'),(980666,'deals','.w-top-categories .categories h2','font-family','inherit','','','.w-top-categories'),(980667,'deals','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(980668,'deals','.heading-4, h4, .h-block h4','font-family','$font-2','','',''),(980669,'deals','.b-upload-file .upload-file-wrap .upload-remove','font-family','trueloaded','3','','.b-upload-file'),(980670,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-family','$font-icons-1','','','.b-form'),(980671,'deals','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(980672,'deals','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(980673,'deals','.w-reviews .heading-3','font-family','trueloaded','3','','.w-reviews'),(980674,'deals','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(980675,'deals','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(980676,'deals','.btn-del','font-family','$font-icons-1','4','',''),(980677,'deals','.b-rating .glyphicon-star.coloron','font-family','$font-icons-1','3','','.b-rating'),(980679,'deals','.w-cart-credit-amount .btn-remove','font-family','trueloaded','3','','.w-cart-credit-amount'),(980681,'deals','.heading-6, h6, .h-block h6','font-family','$font-2','','',''),(980682,'deals','.closeable-heading','font-family','$font-icons-1','3','',''),(980683,'deals','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(980684,'deals','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(980685,'deals','.b-bottom .pop-up-close','font-family','$font-icons-1','3','','.b-bottom'),(980686,'deals','.b-info-popup .info-popup','font-family','trueloaded','3','','.b-info-popup'),(980687,'deals','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-family','$font-icons-1','','','.b-products-listing'),(980688,'deals','.b-upload-files .remove-file','font-family','$font-icons-1','3','','.b-upload-files'),(980692,'deals','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(980693,'deals','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(980695,'deals','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(980697,'deals','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(980699,'deals','.heading-3, h3, .h-block h3','font-family','$font-2','','',''),(980700,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-family','$font-1','','','.b-select-suggest'),(980701,'deals','.b-select-suggest .select2-search input','font-family','$font-1','','','.b-select-suggest'),(980706,'deals','.w-product-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-product-promotions'),(980709,'deals','.b-social-login .social-login-text-1','font-family','$font-1','','','.b-social-login'),(980711,'deals','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(980712,'deals','.b-products-listing .products-listing .bonus-points-price','font-family','$font-icons-1','3','','.b-products-listing'),(980713,'deals','.b-products-listing .products-listing .bonus-points-cost','font-family','$font-icons-1','3','','.b-products-listing'),(980714,'deals','.b-products-listing .products-listing a.btn.view-button','font-family','trueloaded','3','','.b-products-listing'),(980715,'deals','.b-products-listing .btn-preloader','font-family','$font-icons-1','3','','.b-products-listing'),(980716,'deals','.b-products-listing .loader','font-family','$font-icons-1','4','','.b-products-listing'),(980717,'deals','.b-products-listing .products-listing .btn-buy','font-family','trueloaded','3','','.b-products-listing'),(980719,'deals','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(980720,'deals','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(980721,'deals','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','font-family','$font-icons-1','3','','.w-checkout-contact-information'),(980724,'deals','.b-form .eye-password','font-family','$font-icons-1','3','','.b-form'),(980725,'deals','.heading-4 .right-text, h4 .right-text','font-family','$font-2','','',''),(980726,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-family','inherit','','',''),(980727,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-family','inherit','','','.b-h-inline'),(980728,'deals','h1, .heading-1','font-family','$content-color-1','','',''),(980730,'deals','.b-form .radio-button input[type=\"radio\"].no + span','font-family','$font-icons-1','3','','.b-form'),(980731,'deals','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','font-family','$font-icons-1','3','','.w-checkout-contact-information'),(980732,'deals','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(980733,'deals','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(980734,'deals','.w-tabs .tab-li.tab-quote a','font-family','trueloaded','3','','.w-tabs'),(980736,'deals','.p-quote-checkout-success .page-success .text-1, .p-quote-checkout-success .page-success .text-2, .p-quote-checkout-success .page-success .text-3','font-family','$font-1','','','.p-quote-checkout-success'),(980737,'deals','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','font-family','trueloaded','3','','.order-summary'),(980738,'deals','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(980739,'deals','.w-product-cross-sell .buy-all-checker','font-family','$font-icons-1','3','','.w-product-cross-sell'),(980740,'deals','.w-catalog-listing-look .b2b','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(980741,'deals','.w-catalog-listing-look .grid','font-family','$font-icons-1','3','','.w-catalog-listing-look'),(980742,'deals','.checkbox input:checked + span:before','font-family','$font-icons-1','','',''),(980743,'deals','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-family','trueloaded','3','','.w-cart-listing'),(980744,'deals','.w-cart-listing .points-redeem','font-family','$font-1','','','.w-cart-listing'),(980745,'deals','.w-cart-listing .points-redeem','font-family','$font-icons-1','3','','.w-cart-listing'),(980746,'deals','.w-cart-listing .remove-btn','font-family','$font-icons-1','3','','.w-cart-listing'),(980747,'deals','.w-cart-give-away .ga_qty','font-family','$font-1','','','.w-cart-give-away'),(980748,'deals','.w-cart-discount-coupon .btn-remove','font-family','trueloaded','3','','.w-cart-discount-coupon'),(980752,'deals','.w-tabs .accordion-heading','font-family','$font-1','','','.w-tabs'),(980753,'deals','.b-compare .clear_all','font-family','$font-icons-1','4','','.b-compare'),(980754,'deals','.order-summary .price-row.ot_bonus_points .title','font-family','trueloaded','3','','.order-summary'),(980755,'deals','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(980756,'deals','.w-checkout-credit-amount .btn-remove','font-family','trueloaded','3','','.w-checkout-credit-amount'),(980757,'deals','.w-filters .view_more','font-family','$font-icons-1','4','','.w-filters'),(980758,'deals','.w-filters span.close','font-family','$font-icons-1','3','','.w-filters'),(980759,'deals','.w-filters .head-filter-widget','font-family','$font-1','','','.w-filters'),(980760,'deals','.w-quote .cart-box-link','font-family','trueloaded','3','','.w-quote'),(980761,'deals','.w-socials .post_item > div','font-family','$font-icons-1','3','','.w-socials'),(980762,'deals','.b-dropdown .dropdown .dropdown-toggle','font-family','$font-icons-1','4','','.b-dropdown'),(980763,'deals','.heading-2, h2, .h-block h2','font-family','$font-2','','',''),(980764,'deals','body','font-family','$font-2','','',''),(980765,'deals','.w-tabs .tab-li.tab-sample a','font-family','trueloaded','3','','.w-tabs'),(980766,'deals','.w-checkout-bonus-points .btn-remove','font-family','trueloaded','3','','.w-checkout-bonus-points'),(980767,'deals','.b-data-table table.dataTable thead td','font-family','$font-1','','','.b-data-table'),(980770,'deals','.p-quote-checkout-success .page-success .text-1','font-family','trueloaded','3','','.p-quote-checkout-success'),(980772,'deals','.w-promo-code .holder','font-family','trueloaded','3','','.w-promo-code'),(980774,'deals','.w-filters .mobileCollapse','font-family','$font-icons-1','4','','.w-filters'),(980775,'deals','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-family','$font-icons-1','','','.w-filters'),(980776,'deals','.b-product-images .media-popup .mp-close','font-family','$font-icons-1','3','','.b-product-images'),(980777,'deals','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','font-family','$font-icons-1','3','','.b-menu-burger_icon'),(980778,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-family','trueloaded','3','','.w-catalog-compare'),(980780,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','font-family','$font-icons-1','3','','.b-slick'),(980781,'deals','.b-products-listing .add-to-personal-catalog','font-family','$font-icons-1','3','','.b-products-listing'),(980782,'deals','.b-products-listing .del-from-personal-catalog','font-family','$font-icons-1','3','','.b-products-listing'),(980783,'deals','.w-quote .multicart .switch-cart','font-family','$font-icons-1','3','','.w-quote'),(980784,'deals','.w-quote .multicart .title','font-family','$font-1','','','.w-quote'),(980786,'deals','.w-product-personal-catalog-button .btn','font-family','$font-icons-1','3','','.w-product-personal-catalog-button'),(980787,'deals','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','font-family','trueloaded','3','','.w-product-buttons'),(980788,'deals','.w-product-bonus-points > div > div','font-family','$font-icons-1','3','','.w-product-bonus-points'),(980789,'deals','.w-compare .remove','font-family','$font-icons-1','3','','.w-compare'),(980790,'deals','.w-files-catalog-widgets-files-list .file','font-family','$font-icons-1','3','','.w-files-catalog-widgets-files-list'),(980791,'deals','.w-sample .cart-box-link','font-family','trueloaded','3','','.w-sample'),(980792,'deals','.w-sample .multicart .switch-cart','font-family','$font-icons-1','3','','.w-sample'),(980793,'deals','.w-sample .multicart .title','font-family','$font-1','','','.w-sample'),(980794,'deals','.w-sample .qty','font-family','$font-icons-1','4','','.w-sample'),(980795,'deals','.w-cart-gift-certificate .gift-certificate .heading-4','font-family','trueloaded','3','','.w-cart-gift-certificate'),(980796,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','font-family','inherit','','','.b-products-listing'),(980797,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','font-family','$font-icons-1','3','','.b-pagination'),(980798,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','font-family','$font-icons-1','3','','.b-pagination'),(980799,'deals','.w-product-collection .right-area .btn','font-family','$font-icons-2','3','','.w-product-collection'),(980800,'deals','.w-product-collection .right-area .btn-2','font-family','$font-icons-2','3','','.w-product-collection'),(980801,'deals','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','font-family','$font-icons-2','3','','.w-product-custom-bundle'),(980802,'deals','.w-delivery-location-location-list .deliveryListParrent','font-family','$font-1','','','.w-delivery-location-location-list'),(980803,'deals','.w-support-system-filter .dd3-content .collapse_span','font-family','$font-icons-1','3','','.w-support-system-filter'),(980804,'deals','.w-rma-returns-history .column .title','font-family','inherit','','','.w-rma-returns-history'),(980805,'deals','.w-predefined-promotion .nextdiscount .heading','font-family','$font-icons-1','3','','.w-predefined-promotion'),(980806,'deals','.w-supplier-purchase-supplier-products .active .select_item > div:before','font-family','$font-icons-1','','','.w-supplier-purchase-supplier-products'),(980807,'deals','.headerWrap .w-contacts.phone','font-family','$font-icons-1','3','','.headerWrap'),(980808,'deals','.headerWrap .menu-style[data-style=\"1\"] li.back-button','font-family','$font-icons-1','3','','.headerWrap'),(980809,'deals','.w-categories .categories h2','font-family','inherit','','','.w-categories'),(980810,'deals','.w-breadcrumb .breadcrumb-li','font-family','$font-icons-1','4','','.w-breadcrumb'),(980811,'deals','.btn','font-family','$font-2','','',''),(980812,'deals','.btn-1','font-family','$font-2','','',''),(980813,'deals','.btn-2','font-family','$font-2','','',''),(980814,'deals','.btn-3','font-family','$font-2','','',''),(980815,'deals','.messageBox .info','font-family','trueloaded','3','',''),(980816,'deals','.b-info .info','font-family','trueloaded','3','','.b-info'),(980817,'deals','.b-info .info strong','font-family','$font-1','','','.b-info'),(980818,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li.parent > a','font-family','$font-icons-1','5630,4','','.headerWrap'),(980819,'deals','.w-product-personal-catalog-button .btn','font-family','$font-2','','','.w-product-personal-catalog-button'),(980820,'deals','.w-account-personal-catalog .list-row-action ul','font-family','$font-icons-1','4','','.w-account-personal-catalog'),(980821,'deals','.p-wedding-registry-view h1','font-family','$font-icons-1','3','','.p-wedding-registry-view'),(980822,'deals','.p-wedding-registry-view h1','font-family','$font-icons-1','4','','.p-wedding-registry-view'),(980823,'deals','.w-product-wishlist-button .btn','font-family','trueloaded','3','','.w-product-wishlist-button'),(980824,'deals','.order-summary .icon','font-family','$font-icons-1','3','','.order-summary'),(980825,'deals','.w-cart-discount-coupon .title','font-family','$font-icons-1','4','','.w-cart-discount-coupon'),(980826,'deals','.w-cart-checkout-btn .with-card','font-family','$font-icons-1','4','','.w-cart-checkout-btn'),(980827,'deals','.w-promotions-widgets-promotions .promotion-full-price-discount','font-family','$font-1','','','.w-promotions-widgets-promotions'),(980836,'deals','.account-address-book .btn-edit','font-family','trueloaded','4','','.account-address-book'),(980837,'deals','.account-address-book .leftMes div','font-family','$font-1','','','.account-address-book'),(980841,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-family','trueloaded','3','','.account-order-pay'),(980842,'deals','.account-samples .orders-table th','font-family','$font-1','','','.account-samples'),(980843,'deals','.account-samples .view_link','font-family','trueloaded','4','','.account-samples'),(980844,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-family','trueloaded','3','','.account-sample-info'),(980845,'deals','.catalog-product-wrap .pn-direction','font-family','$font-1','','','.catalog-product-wrap'),(980846,'deals','.catalog-product-wrap .pn-image','font-family','$font-icons-1','3','','.catalog-product-wrap'),(980847,'deals','.shopping-cart-index .gift-code .heading-4','font-family','FontAwesome','4','','.shopping-cart-index'),(980848,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','font-family','$font-1','','','.checkout-index-wrap'),(980849,'deals','.checkout-index-wrap .order-ico','font-family','trueloaded','3','','.checkout-index-wrap'),(980850,'deals','.checkout-index-wrap .pay-ico','font-family','trueloaded','3','','.checkout-index-wrap'),(980851,'deals','.checkout-index-wrap .ship-ico','font-family','trueloaded','3','','.checkout-index-wrap'),(980852,'deals','.checkout-order-confirmation .comment-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(980853,'deals','.checkout-order-confirmation .discount-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(980854,'deals','.checkout-order-confirmation .order-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(980855,'deals','.checkout-order-confirmation .ship-ico','font-family','trueloaded','3','','.checkout-order-confirmation'),(980856,'deals','.checkout-success-wrap .page-success .text-1','font-family','trueloaded','3','','.checkout-success-wrap'),(980857,'deals','.success-page .check-ico-block','font-family','trueloaded','3','','.success-page'),(980858,'deals','.success-page .comment-ico','font-family','trueloaded','3','','.success-page'),(980859,'deals','.success-page .discount-ico','font-family','trueloaded','3','','.success-page'),(980860,'deals','.success-page .order-ico','font-family','trueloaded','3','','.success-page'),(980861,'deals','.success-page .page-success .text-1','font-family','trueloaded','3','','.success-page'),(980862,'deals','.success-page .page-success .text-1, .success-page .page-success .text-2, .success-page .page-success .text-3','font-family','$font-1','','','.success-page'),(980863,'deals','.success-page .pay-ico','font-family','trueloaded','3','','.success-page'),(980864,'deals','.success-page .prod-ico','font-family','trueloaded','3','','.success-page'),(980865,'deals','.success-page .ship-ico','font-family','trueloaded','3','','.success-page'),(980867,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-family','$font-1','','','.b-multi-page-checkout'),(980868,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-family','$font-icons-1','3','','.b-multi-page-checkout'),(980869,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-family','trueloaded','4','','.b-multi-page-checkout'),(980872,'deals','.footer-menu .level-1 > li .no-link','font-family','$font-icons-1','5639,3','','.footer-menu'),(980873,'deals','.w-catalog-paging .next','font-family','FontAwesome','3','','.w-catalog-paging'),(980874,'deals','.w-catalog-paging .prev','font-family','FontAwesome','3','','.w-catalog-paging'),(980880,'deals','.w-menu-slider .close','font-family','$font-icons-1','3','','.w-menu-slider'),(980881,'deals','.b-rating .glyphicon','font-family_important','important','','','.b-rating'),(980882,'deals','.w-communication-new-topic td.date-purchased','font-size','14','','','.w-communication-new-topic'),(980883,'deals','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','font-size','14','','','.w-communication-new-topic'),(980884,'deals','.b-email .price','font-size','14','','','.b-email'),(980885,'deals','.heading-4 .right-text, h4 .right-text','font-size','16','','',''),(980886,'deals','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(980887,'deals','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(980888,'deals','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(980889,'deals','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(980891,'deals','.b-form .middle-form label','font-size','14','','','.b-form'),(980892,'deals','.b-email-editor .price','font-size','18','','','.b-email-editor'),(980893,'deals','.p-quick-order-index .paginate_button.previous','font-size','20','3','','.p-quick-order-index'),(980894,'deals','.b-email .qty','font-size','14','','','.b-email'),(980895,'deals','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','font-size','13','','','.p-quick-order-index'),(980896,'deals','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-size','14','','','.p-quick-order-index'),(980897,'deals','.p-quick-order-index .paginate_button.next','font-size','20','3','','.p-quick-order-index'),(980898,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.next','font-size','0','','','.p-quick-order-index'),(980899,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.previous','font-size','0','','','.p-quick-order-index'),(980900,'deals','.w-promotions .promo-item','font-size','24','','','.w-promotions'),(980902,'deals','.w-promotions .prom-multi-discount .promo-range','font-size','13','','','.w-promotions'),(980905,'deals','.w-cart-compare .attributes-label','font-size','14','','','.w-cart-compare'),(980907,'deals','.w-personal-gift-status-bar .end-label','font-size','14','','','.w-personal-gift-status-bar'),(980908,'deals','.p-sample-checkout-success .page-success .text-1','font-size','60','','','.p-sample-checkout-success'),(980909,'deals','.p-sample-checkout-success .page-success .text-3','font-size','27','','','.p-sample-checkout-success'),(980910,'deals','.p-sample-checkout-success .page-success .text-2','font-size','34','','','.p-sample-checkout-success'),(980911,'deals','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(980912,'deals','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(980913,'deals','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(980914,'deals','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(980915,'deals','.w-promotions .prom-multi-discount .heading','font-size','26','','','.w-promotions'),(980916,'deals','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(980917,'deals','.b-email .heading-name','font-size','14','','','.b-email'),(980918,'deals','.testimonials .reviews-list span','font-size','22','','',''),(980919,'deals','.testimonials .rating','font-size','22','','',''),(980920,'deals','.testimonials .reviews-list .date','font-size','14','','',''),(980921,'deals','.testimonials .date','font-size','14','','',''),(980922,'deals','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','font-size','14','','','.w-promotions'),(980923,'deals','.w-promotions .prom-multi-discount .promo-group','font-size','16','','','.w-promotions'),(980924,'deals','.w-promotions .nextdiscount .heading','font-size','26','','','.w-promotions'),(980925,'deals','.w-promotions .nextdiscount .heading','font-size','18','3','','.w-promotions'),(980926,'deals','.w-promotions .nextdiscount .promo-for-each','font-size','14','','','.w-promotions'),(980927,'deals','.w-promotions .nextdiscount .item-holder .name','font-size','14','','','.w-promotions'),(980928,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.p-quick-order-index'),(980929,'deals','.w-promotions .heading-3','font-size','48','','','.w-promotions'),(980930,'deals','.w-promotions .promo-salemaker .discount','font-size','13','','','.w-promotions'),(980931,'deals','.w-promotions .promo-salemaker .content a','font-size','14','','','.w-promotions'),(980932,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','font-size','16','','','.w-promotions'),(980933,'deals','.w-promotions .promo-cart-discount .promo-min-qty','font-size','13','','','.w-promotions'),(980934,'deals','.b-warehouses-popup .warehouses-popup .warehouse-name','font-size','16','','','.b-warehouses-popup'),(980935,'deals','.w-promotions .promo-cart-discount .item a','font-size','14','','','.w-promotions'),(980936,'deals','.b-warehouses-popup a.warehouses-popup-link','font-size','14','','','.b-warehouses-popup'),(980937,'deals','.b-warehouses-popup .warehouses-popup .heading','font-size','18','','','.b-warehouses-popup'),(980938,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','font-size','14','','','.b-warehouses-popup'),(980939,'deals','.b-preloader .preloader','font-size','40','3','','.b-preloader'),(980940,'deals','.w-chat .w-chat-box a','font-size','20','3','','.w-chat'),(980941,'deals','.w-cart-compare .dropdown li','font-size','14','','','.w-cart-compare'),(980942,'deals','.w-cart-compare .attributes-cell','font-size','14','','','.w-cart-compare'),(980943,'deals','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(980944,'deals','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(980945,'deals','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','font-size','12','3','','.order-summary'),(980946,'deals','.b-compare .compare-head','font-size','22','','','.b-compare'),(980947,'deals','.b-bottom .closeable-heading','font-size','20','3','','.b-bottom'),(980948,'deals','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(980949,'deals','.b-messages .messBtnMenuDelete','font-size','22','3','','.b-messages'),(980950,'deals','.b-messages .content-messages .heading-2','font-size','26','','','.b-messages'),(980951,'deals','.b-messages span.starred::before','font-size','16','','','.b-messages'),(980952,'deals','.b-messages .messBtnMenuStarred','font-size','22','3','','.b-messages'),(980953,'deals','.b-messages .messBtnMenuUnread','font-size','22','3','','.b-messages'),(980954,'deals','.b-messages .messMenuButton span','font-size','14','','','.b-messages'),(980955,'deals','.b-messages .content_management_attach','font-size','14','','','.b-messages'),(980956,'deals','.b-messages .content_management_attach span','font-size','16','','','.b-messages'),(980957,'deals','.b-messages .content_management_attach button','font-size','14','','','.b-messages'),(980958,'deals','.b-messages .select2-search-choice-close','font-size','11','3','','.b-messages'),(980959,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','font-size','14','','',''),(980960,'deals','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(980961,'deals','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(980962,'deals','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(980964,'deals','.p-payer-order-confirmation .ship-ico','font-size','30','3','','.p-payer-order-confirmation'),(980965,'deals','.p-payer-order-confirmation .pay-ico','font-size','30','3','','.p-payer-order-confirmation'),(980966,'deals','.p-payer-order-confirmation .order-ico','font-size','36','3','','.p-payer-order-confirmation'),(980967,'deals','.b-data-table table.dataTable thead td','font-size','16','','','.b-data-table'),(980968,'deals','.p-payer-order-confirmation .discount-ico','font-size','30','3','','.p-payer-order-confirmation'),(980969,'deals','.p-payer-order-pay .ship-ico','font-size','30','3','','.p-payer-order-pay'),(980970,'deals','.p-payer-order-confirmation .comment-ico','font-size','30','3','','.p-payer-order-confirmation'),(980971,'deals','.p-payer-order-pay .pay-ico','font-size','30','3','','.p-payer-order-pay'),(980972,'deals','.p-payer-order-pay .order-ico','font-size','36','3','','.p-payer-order-pay'),(980973,'deals','.p-payer-order-pay .comment-ico','font-size','30','3','','.p-payer-order-pay'),(980974,'deals','.p-payer-order-pay .discount-ico','font-size','30','3','','.p-payer-order-pay'),(980975,'deals','.w-checkout-terms .terms-box','font-size','13','','','.w-checkout-terms'),(980976,'deals','.w-cart-cart-tabs .w-tabs .tab-a','font-size','12','5630','','.w-cart-cart-tabs'),(980977,'deals','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(980978,'deals','.order-summary .price-box .title','font-size','15','','','.order-summary'),(980979,'deals','.b-email .heading-qty','font-size','14','','','.b-email'),(980980,'deals','.b-email .model','font-size','14','','','.b-email'),(980981,'deals','.b-email .heading-name','font-size','14','','','.b-email'),(980982,'deals','.p-quote-checkout-success .page-success .text-2','font-size','30','5630','','.p-quote-checkout-success'),(980983,'deals','.b-page-name .page-name','font-size','20','','','.b-page-name'),(980984,'deals','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(980985,'deals','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(980986,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','font-size','10','','','.b-switch'),(980987,'deals','.p-quick-order-index .value','font-size','20','','','.p-quick-order-index'),(980988,'deals','.w-upload-customer-id-upload-customer-id-form .upload-remove','font-size','20','','','.w-upload-customer-id-upload-customer-id-form'),(980989,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-template','font-size','18','','','.w-upload-customer-id-upload-customer-id-form'),(980990,'deals','.b-switch .bootstrap-switch','font-size','16','','','.b-switch'),(980991,'deals','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(980992,'deals','.b-email .qty','font-size','14','','','.b-email'),(980993,'deals','.w-coupons-and-vauchers-checkout .btn-remove','font-size','12','','','.w-coupons-and-vauchers-checkout'),(980994,'deals','.w-checkout-bonus-points .btn-remove','font-size','12','','','.w-checkout-bonus-points'),(980995,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','font-size','7','','','.b-switch'),(980997,'deals','.b-form .required-message','font-size','14','','','.b-form'),(980998,'deals','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(980999,'deals','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(981002,'deals','.b-email-editor .price','font-size','18','','','.b-email-editor'),(981003,'deals','.b-info-popup .info-popup div','font-size','14','','','.b-info-popup'),(981004,'deals','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-size','24','','','.w-multi-cart-cart-switcher'),(981005,'deals','.p-quote-checkout-success .page-success .text-2','font-size','30','5630','','.p-quote-checkout-success'),(981006,'deals','.w-promo-code .holder','font-size','30','5660,3','','.w-promo-code'),(981007,'deals','.no-found','font-size','1.4','','',''),(981008,'deals','.price','font-size','24','','',''),(981010,'deals','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(981011,'deals','.w-filters .input-checkbox:checked + .checkbox-span:before','font-size','21','','','.w-filters'),(981012,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','font-size','14','','','.b-switch'),(981013,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','font-size','14','','','.b-switch'),(981014,'deals','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(981015,'deals','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(981016,'deals','.b-email .heading-model','font-size','14','','','.b-email'),(981017,'deals','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(981018,'deals','.b-email .totals-label','font-size','18','','','.b-email'),(981019,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span:before','font-size','18','','','.b-form'),(981020,'deals','.w-reviews-content .rating','font-size','18','','','.w-reviews-content'),(981021,'deals','.w-reviews-content .date','font-size','13','','','.w-reviews-content'),(981022,'deals','.w-reviews .date','font-size','13','','','.w-reviews'),(981023,'deals','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(981025,'deals','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(981026,'deals','h1','font-size','24','5639','',''),(981027,'deals','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(981028,'deals','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(981029,'deals','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(981030,'deals','.bell-ico .heading-2','font-size','32','3','','.bell-ico'),(981031,'deals','.w-personal-gift-status-bar .end-date','font-size','14','','','.w-personal-gift-status-bar'),(981032,'deals','.w-cart-compare .price-cell','font-size','18','','','.w-cart-compare'),(981033,'deals','.w-cart-compare .price-label','font-size','14','','','.w-cart-compare'),(981034,'deals','.w-checkout-create-account .account-benefits','font-size','0.8','','','.w-checkout-create-account'),(981035,'deals','.w-cart-listing .price','font-size','16','','','.w-cart-listing'),(981036,'deals','.w-cart-compare .js-cart_totals_container b','font-size','16','','','.w-cart-compare'),(981037,'deals','.p-quote-checkout-success .page-success .text-2','font-size','30','5630','','.p-quote-checkout-success'),(981038,'deals','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(981039,'deals','.view-all .btn','font-size','0.8','4','',''),(981040,'deals','.btn-1','font-size','14','','',''),(981041,'deals','.b-form .privacy-row','font-size','16','','','.b-form'),(981042,'deals','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(981043,'deals','.b-email .name','font-size','14','','','.b-email'),(981044,'deals','.w-tabs .tab-li.tab-quote a','font-size','29','3','','.w-tabs'),(981048,'deals','.w-tabs .tab-a','font-size','16','5639','','.w-tabs'),(981049,'deals','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(981051,'deals','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(981052,'deals','.btn-edit','font-size','0.8','3','',''),(981053,'deals','.w-promo-code .holder','font-size','30','5660,3','','.w-promo-code'),(981054,'deals','.w-tabs .tab-li.tab-wishlist a','font-size','25','3','','.w-tabs'),(981055,'deals','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(981056,'deals','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(981057,'deals','.w-personal-gift-status-bar .start-label','font-size','14','','','.w-personal-gift-status-bar'),(981058,'deals','.heading-4 .edit, h4 .edit','font-size','16','','',''),(981059,'deals','.heading-6, h6, .h-block h6','font-size','16','','',''),(981060,'deals','.btn-2','font-size','14','','',''),(981062,'deals','.w-cart-compare .cart-name a','font-size','17','','','.w-cart-compare'),(981063,'deals','.w-cart-compare .delete-cart','font-size','12','','','.w-cart-compare'),(981064,'deals','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(981065,'deals','.p-sample-checkout-success .page-success .text-2','font-size','30','5630','','.p-sample-checkout-success'),(981066,'deals','.w-top-categories .categories h2','font-size','19','','','.w-top-categories'),(981067,'deals','.out-stock','font-size','14','','',''),(981068,'deals','.transit','font-size','14','','',''),(981069,'deals','.in-stock','font-size','14','','',''),(981070,'deals','.heading-3 .right-text, h3 .right-text','font-size','16','','',''),(981071,'deals','.heading-3 .edit, h3 .edit','font-size','14','4','',''),(981072,'deals','.heading-3 .edit, h3 .edit','font-size','16','','',''),(981073,'deals','.heading-5, h5, .h-block h5','font-size','17','','',''),(981074,'deals','.b-email .heading-model','font-size','14','','','.b-email'),(981075,'deals','.b-email .heading-price','font-size','14','','','.b-email'),(981076,'deals','.b-page-name .page-name','font-size','20','','','.b-page-name'),(981077,'deals','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(981078,'deals','.w-cart-credit-amount .text','font-size','14','','','.w-cart-credit-amount'),(981079,'deals','.w-cart-bonus-points .btn-remove','font-size','12','','','.w-cart-bonus-points'),(981080,'deals','.w-cart-discount-coupon .text','font-size','14','','','.w-cart-discount-coupon'),(981081,'deals','.order-summary .price-box .price-row.total','font-size','22','','','.order-summary'),(981082,'deals','.order-summary .price','font-size','18','','','.order-summary'),(981083,'deals','.w-cart-bonus-points .text','font-size','14','','','.w-cart-bonus-points'),(981084,'deals','.b-email .model','font-size','14','','','.b-email'),(981085,'deals','.b-email .name','font-size','14','','','.b-email'),(981087,'deals','.testimonials .heading-3','font-size','37','3','',''),(981088,'deals','.js-stock','font-size','14','','',''),(981089,'deals','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(981090,'deals','.w-checkout-shipping-choice span','font-size','14','5660','','.w-checkout-shipping-choice'),(981091,'deals','.w-product-reviews .reviews-list .date','font-size','14','','','.w-product-reviews'),(981092,'deals','.b-email-editor .price','font-size','18','','','.b-email-editor'),(981093,'deals','.b-email .model','font-size','14','','','.b-email'),(981095,'deals','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(981096,'deals','.heading-4, h4, .h-block h4','font-size','18','','',''),(981097,'deals','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(981098,'deals','.b-email .price','font-size','14','','','.b-email'),(981100,'deals','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(981101,'deals','.b-email .name','font-size','14','','','.b-email'),(981102,'deals','.btn','font-size','14','','',''),(981103,'deals','.b-email .heading-model','font-size','14','','','.b-email'),(981104,'deals','.b-email .price','font-size','14','','','.b-email'),(981105,'deals','.b-email .heading-qty','font-size','14','','','.b-email'),(981111,'deals','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(981112,'deals','.b-email .qty','font-size','14','','','.b-email'),(981113,'deals','.b-email .heading-qty','font-size','14','','','.b-email'),(981114,'deals','.b-email .heading-name','font-size','14','','','.b-email'),(981115,'deals','.b-email .heading-price','font-size','14','','','.b-email'),(981116,'deals','.b-email .totals-label','font-size','18','','','.b-email'),(981117,'deals','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(981119,'deals','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(981121,'deals','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(981122,'deals','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(981123,'deals','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(981124,'deals','.w-promo-code .holder','font-size','30','5660,3','','.w-promo-code'),(981125,'deals','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(981126,'deals','.message.success','font-size','30','3','',''),(981127,'deals','.w-reviews .heading-3','font-size','37','3','','.w-reviews'),(981128,'deals','.b-sub-totals .historyTotal table td','font-size','18','','','.b-sub-totals'),(981129,'deals','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(981130,'deals','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(981131,'deals','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(981132,'deals','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(981133,'deals','.p-quote-checkout-success .page-success .text-1','font-size','40','5630','','.p-quote-checkout-success'),(981135,'deals','.b-form .checkbox-style:checked + .checkbox-span:before','font-size','18','','','.b-form'),(981137,'deals','.w-social-links a','font-size','30','5630','','.w-social-links'),(981138,'deals','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(981139,'deals','.b-email .name','font-size','14','','','.b-email'),(981140,'deals','.b-email .heading-qty','font-size','14','','','.b-email'),(981141,'deals','.p-quick-order-index .stock','font-size','12','','','.p-quick-order-index'),(981142,'deals','.b-email .price','font-size','14','','','.b-email'),(981143,'deals','.p-quote-checkout-success .page-success .text-1','font-size','40','5630','','.p-quote-checkout-success'),(981144,'deals','.w-cart-compare .js-cart_totals_container','font-size','14','','','.w-cart-compare'),(981145,'deals','.p-quote-checkout-success .page-success .text-1','font-size','40','5630','','.p-quote-checkout-success'),(981146,'deals','.b-bottom .alert-message','font-size','18','','','.b-bottom'),(981147,'deals','.w-cart-compare .product .name a','font-size','14','','','.w-cart-compare'),(981148,'deals','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(981149,'deals','.b-email .totals-label','font-size','18','','','.b-email'),(981150,'deals','.w-checkout-credit-amount .btn-remove','font-size','12','','','.w-checkout-credit-amount'),(981152,'deals','.b-info-popup .info-popup','font-size','20','3','','.b-info-popup'),(981153,'deals','.b-email .name','font-size','14','','','.b-email'),(981154,'deals','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(981155,'deals','.p-quote-checkout-success .page-success .text-1','font-size','40','5630','','.p-quote-checkout-success'),(981156,'deals','.b-social-login .social-login-text-2','font-size','18','','','.b-social-login'),(981157,'deals','.b-email .price','font-size','14','','','.b-email'),(981158,'deals','.b-email .heading-model','font-size','14','','','.b-email'),(981159,'deals','.b-email .heading-name','font-size','14','','','.b-email'),(981160,'deals','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(981161,'deals','.b-email .heading-price','font-size','14','','','.b-email'),(981162,'deals','.b-email .model','font-size','14','','','.b-email'),(981163,'deals','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(981164,'deals','.order-summary .price-row.ot_coupon .title','font-size','18','3','','.order-summary'),(981165,'deals','.w-cart-shipping-estimator .address-item','font-size','14','','','.w-cart-shipping-estimator'),(981166,'deals','.b-products-listing .products-listing .wishlistButton .checkbox input:checked + span:before','font-size','20','','','.b-products-listing'),(981167,'deals','.b-products-listing .products-listing .wishlistButton .checkbox input:not(checked) + span:before','font-size','20','','','.b-products-listing'),(981168,'deals','.b-products-listing .products-listing .attribute-qty-block','font-size','14','','','.b-products-listing'),(981169,'deals','.w-cart-credit-amount .btn-remove','font-size','12','','','.w-cart-credit-amount'),(981170,'deals','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(981171,'deals','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(981172,'deals','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(981174,'deals','.p-quick-order-index .in-stock, .p-quick-order-index .out-stock','font-size','12','','','.p-quick-order-index'),(981175,'deals','.b-email .heading-price','font-size','14','','','.b-email'),(981176,'deals','.b-email .name','font-size','14','','','.b-email'),(981177,'deals','.b-email .heading-name','font-size','14','','','.b-email'),(981178,'deals','.b-form .middle-form .middle-rating span','font-size','26','','','.b-form'),(981180,'deals','.w-product-customers-activity .customers-activity','font-size','16','','','.w-product-customers-activity'),(981181,'deals','.w-product-available-in-warehouses .heading','font-size','18','','','.w-product-available-in-warehouses'),(981182,'deals','.b-bottom .confirm-popup .confirm-text','font-size','20','','','.b-bottom'),(981183,'deals','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(981184,'deals','.b-email .qty','font-size','14','','','.b-email'),(981185,'deals','.b-page-name .page-name','font-size','20','','','.b-page-name'),(981189,'deals','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(981190,'deals','.p-sample-checkout-success .page-success .text-1','font-size','80','3','','.p-sample-checkout-success'),(981191,'deals','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-size','22','','','.order-summary'),(981193,'deals','.p-quote-checkout-success .page-success .text-2','font-size','34','','','.p-quote-checkout-success'),(981194,'deals','.p-quote-checkout-success .page-success .text-1','font-size','80','3','','.p-quote-checkout-success'),(981195,'deals','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(981196,'deals','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(981197,'deals','.w-menu-horizontal .menu-ico','font-size','23','','','.w-menu-horizontal'),(981198,'deals','.w-promo-code .holder','font-size','30','5660,3','','.w-promo-code'),(981199,'deals','.w-categories h2.name','font-size','18','','','.w-categories'),(981200,'deals','.price .old','font-size','0.6','','',''),(981201,'deals','.w-cart-compare .product-actions .dropdown-toggle','font-size','18','3','','.w-cart-compare'),(981202,'deals','.w-social-links a','font-size','20','','','.w-social-links'),(981203,'deals','.b-fancybox .fancybox-close','font-size','26','','','.b-fancybox'),(981204,'deals','.b-select-suggest .select2-search-choice-close','font-size','1','','','.b-select-suggest'),(981205,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font-size','100','','','.b-select-suggest'),(981206,'deals','.b-select-suggest .select2-search input','font-size','1','','','.b-select-suggest'),(981207,'deals','.p-sample-checkout-success .page-success .text-1','font-size','40','5630','','.p-sample-checkout-success'),(981208,'deals','.w-cart-compare .product-actions','font-size','12','','','.w-cart-compare'),(981209,'deals','.w-product-promotions .promotion-full-price-discount','font-size','34','','','.w-product-promotions'),(981210,'deals','.w-personal-gift-status-bar .inform','font-size','14','','','.w-personal-gift-status-bar'),(981211,'deals','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(981212,'deals','.w-quote-products .empty','font-size','24','','','.w-quote-products'),(981213,'deals','.b-bottom .footerTitle','font-size','24','','','.b-bottom'),(981214,'deals','.w-account-addresses-list .addsess-suggestion-item','font-size','14','','','.w-account-addresses-list'),(981215,'deals','.w-communication-post .communication-post-date','font-size','14','','','.w-communication-post'),(981216,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-size','16','','','.b-data-table'),(981217,'deals','.w-communication-post .communication-post-attach','font-size','14','','','.w-communication-post'),(981218,'deals','.b-products-listing .products-listing .bonusPoints','font-size','13','','','.b-products-listing'),(981219,'deals','.b-products-listing .products-listing .model','font-size','14','','','.b-products-listing'),(981220,'deals','.b-products-listing .btn-preloader','font-size','24','3','','.b-products-listing'),(981221,'deals','.b-products-listing .loader','font-size','30','4','','.b-products-listing'),(981222,'deals','.b-products-listing .promos-info .promo-name','font-size','14','','','.b-products-listing'),(981223,'deals','.b-products-listing .wedding-registry-count','font-size','14','','','.b-products-listing'),(981225,'deals','.w-quote .cart-box-link','font-size','30','3','','.w-quote'),(981226,'deals','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(981227,'deals','.p-quote-checkout-success .page-success .text-2','font-size','30','5630','','.p-quote-checkout-success'),(981228,'deals','.p-quote-checkout-success .page-success .text-1','font-size','40','5630','','.p-quote-checkout-success'),(981229,'deals','.b-email-editor .price','font-size','18','','','.b-email-editor'),(981230,'deals','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(981231,'deals','.b-form .cart-popup .price','font-size','18','','','.b-form'),(981232,'deals','.b-email-editor .price','font-size','18','','','.b-email-editor'),(981233,'deals','.b-email .heading-model','font-size','14','','','.b-email'),(981234,'deals','.p-quote-checkout-success .page-success .text-1','font-size','40','5630','','.p-quote-checkout-success'),(981236,'deals','.w-top-categories h2.name','font-size','18','','','.w-top-categories'),(981237,'deals','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(981238,'deals','.w-product-reviews .reviews-list span','font-size','22','','','.w-product-reviews'),(981239,'deals','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(981240,'deals','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(981241,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-size','inherit','','',''),(981242,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-size','inherit','','','.b-h-inline'),(981243,'deals','h1, .heading-1','font-size','32','','',''),(981244,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','font-size','31','','','.w-communication-new-topic'),(981245,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','font-size','31','','','.w-communication-new-topic'),(981246,'deals','.b-page-name .page-name','font-size','20','','','.b-page-name'),(981247,'deals','.b-email .heading-price','font-size','14','','','.b-email'),(981248,'deals','.b-email .totals-label','font-size','18','','','.b-email'),(981249,'deals','.b-email .price','font-size','14','','','.b-email'),(981250,'deals','.b-email .heading-name','font-size','14','','','.b-email'),(981251,'deals','.b-bottom .popup-heading','font-size','16','','','.b-bottom'),(981252,'deals','.w-promo-code .holder','font-size','30','5660,3','','.w-promo-code'),(981253,'deals','.p-quote-checkout-success .page-success .text-2','font-size','30','5630','','.p-quote-checkout-success'),(981254,'deals','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(981255,'deals','.w-tabs .tab-li.tab-sample a','font-size','29','3','','.w-tabs'),(981256,'deals','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(981257,'deals','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(981258,'deals','.b-email .model','font-size','14','','','.b-email'),(981259,'deals','.w-cart-compare .atr-col','font-size','20','3','','.w-cart-compare'),(981260,'deals','.w-quote .cart-box-link','font-size','25','5639,3','','.w-quote'),(981261,'deals','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(981262,'deals','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(981263,'deals','.b-email .qty','font-size','14','','','.b-email'),(981264,'deals','.b-email .model','font-size','14','','','.b-email'),(981265,'deals','.b-email .totals-label','font-size','18','','','.b-email'),(981266,'deals','.checkbox input:checked + span:before','font-size','18','','',''),(981267,'deals','.p-quick-order-index .dataTables_info','font-size','14','','','.p-quick-order-index'),(981268,'deals','.w-cart-listing .item .gift-wrap label','font-size','14','','','.w-cart-listing'),(981269,'deals','.w-cart-listing .item .attributes','font-size','14','','','.w-cart-listing'),(981270,'deals','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-size','12','','','.w-cart-listing'),(981271,'deals','.w-cart-listing .points-earn','font-size','12','','','.w-cart-listing'),(981272,'deals','.w-cart-listing .points-redeem','font-size','14','','','.w-cart-listing'),(981273,'deals','.w-cart-listing .points-redeem','font-size','14','3','','.w-cart-listing'),(981274,'deals','.w-cart-listing .remove-btn','font-size','28','','','.w-cart-listing'),(981275,'deals','.w-cart-listing .remove-btn span','font-size','16','5639','','.w-cart-listing'),(981276,'deals','.w-cart-give-away .ga_name','font-size','16','','','.w-cart-give-away'),(981277,'deals','.w-cart-give-away .ga_qty','font-size','20','','','.w-cart-give-away'),(981278,'deals','.w-cart-give-away .ga_qty','font-size','17','5630','','.w-cart-give-away'),(981279,'deals','.w-cart-discount-coupon .btn-remove','font-size','12','','','.w-cart-discount-coupon'),(981283,'deals','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(981284,'deals','.b-email-editor .special-price','font-size','18','','','.b-email-editor'),(981285,'deals','.b-email-editor .old-price','font-size','16','','','.b-email-editor'),(981286,'deals','.b-upload-file .snapshot','font-size','18','','','.b-upload-file'),(981287,'deals','.b-fancybox .fancybox-nav span','font-size','34','','','.b-fancybox'),(981288,'deals','.b-email-editor .price','font-size','18','','','.b-email-editor'),(981289,'deals','.b-email .heading-qty','font-size','14','','','.b-email'),(981290,'deals','.w-promo-code .holder','font-size','30','5660,3','','.w-promo-code'),(981292,'deals','.w-tabs .accordion-heading','font-size','24','','','.w-tabs'),(981293,'deals','.w-socials .post_item > div','font-size','20','3','','.w-socials'),(981294,'deals','.w-tabs .tab-li.tab-cart a','font-size','29','3','','.w-tabs'),(981295,'deals','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(981296,'deals','.b-compare .clear_all','font-size','16','4','','.b-compare'),(981297,'deals','.w-promo-code .promo-text-2','font-size','14','','','.w-promo-code'),(981298,'deals','.w-promo-code .holder','font-size','70','3','','.w-promo-code'),(981300,'deals','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(981301,'deals','.p-quote-checkout-success .page-success .text-1','font-size','60','','','.p-quote-checkout-success'),(981302,'deals','.b-wedding-list .wedding-list','font-size','0','','','.b-wedding-list'),(981303,'deals','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(981304,'deals','.p-sample-cart-index .empty','font-size','24','','','.p-sample-cart-index'),(981305,'deals','.w-checkout-create-account .account-benefits strong','font-size','18','3','','.w-checkout-create-account'),(981306,'deals','.w-filters .head-filter-widget > span','font-size','18','5639','','.w-filters'),(981307,'deals','.w-filters .head-filter-widget','font-size','21','5644','','.w-filters'),(981308,'deals','.w-filters .filter-box-head','font-size','20','','','.w-filters'),(981309,'deals','.w-filters .view_more','font-size','16','4','','.w-filters'),(981310,'deals','.w-chat .w-chat-box a','font-size','30','5639,3','','.w-chat'),(981311,'deals','.b-products-listing .products-listing .btn-buy','font-size','20','3','','.b-products-listing'),(981312,'deals','.b-bottom .pop-up-close','font-size','25','','','.b-bottom'),(981313,'deals','.w-filters .head-filter-widget','font-size','24','','','.w-filters'),(981314,'deals','.order-summary .price-row.ot_bonus_points .title','font-size','12','3','','.order-summary'),(981315,'deals','.b-form #payment_method .title','font-size','16','','','.b-form'),(981316,'deals','.p-quote-checkout-success .page-success .text-2','font-size','30','5630','','.p-quote-checkout-success'),(981317,'deals','.b-email .heading-model','font-size','14','','','.b-email'),(981318,'deals','.b-email .heading-qty','font-size','14','','','.b-email'),(981319,'deals','.b-page-name .page-name','font-size','20','','','.b-page-name'),(981320,'deals','.b-social-login .social-login-text-1','font-size','26','','','.b-social-login'),(981321,'deals','.b-tracking-numbers .tracking-numbers .tracking-code','font-size','20','','','.b-tracking-numbers'),(981322,'deals','.heading-3, h3, .h-block h3','font-size','20','','',''),(981323,'deals','.heading-2, h2, .h-block h2','font-size','28','','',''),(981324,'deals','.btn-3','font-size','14','','',''),(981325,'deals','.p-quote-checkout-success .page-success .text-3','font-size','27','','','.p-quote-checkout-success'),(981326,'deals','.b-wedding-list .wedding-list .item','font-size','16','','','.b-wedding-list'),(981327,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','font-size','20','','','.b-switch'),(981328,'deals','.b-page-name .page-name','font-size','20','','','.b-page-name'),(981329,'deals','.b-form .middle-form label.slim','font-size','14','','','.b-form'),(981330,'deals','.b-email .heading-price','font-size','14','','','.b-email'),(981331,'deals','.b-select-suggest .select2-container .select2-choice abbr','font-size','1','','','.b-select-suggest'),(981332,'deals','.b-email .qty','font-size','14','','','.b-email'),(981333,'deals','.b-email .totals-label','font-size','18','','','.b-email'),(981334,'deals','.w-filters .mobileCollapse','font-size','20','4','','.w-filters'),(981335,'deals','.w-filters .input-checkbox:not(checked) + .checkbox-span:before','font-size','21','','','.w-filters'),(981336,'deals','.b-product-images .media-popup .mp-close','font-size','50','','','.b-product-images'),(981337,'deals','.b-product-images .media-popup .slick-dots li','font-size','30','','','.b-product-images'),(981338,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','font-size','50','3','','.b-product-images'),(981339,'deals','.w-product-name h1','font-size','23','','','.w-product-name'),(981340,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(981341,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(981342,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(981343,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(981344,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(981345,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(981346,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(981347,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(981348,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','20','','','.b-menu-lev_vis-click_icon'),(981349,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev63_vis=\"click_icon\"] .level-5 > li > .open-close-ico','font-size','24','1','','.b-menu-lev_vis-click_icon'),(981350,'deals','.b-trade-approval .middle-form label','font-size','16','','','.b-trade-approval'),(981351,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','font-size','14','','','.b-trade-approval'),(981352,'deals','.w-account-personal-catalog .list-switcher a','font-size','20','','','.w-account-personal-catalog'),(981353,'deals','.w-catalog-compare .checkbox input:checked + span:before','font-size','24','','','.w-catalog-compare'),(981354,'deals','.w-catalog-compare .model','font-size','14','','','.w-catalog-compare'),(981355,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-size','26','3','','.w-catalog-compare'),(981356,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','font-size','0','','','.w-catalog-compare'),(981357,'deals','.w-catalog-compare .item .compare','font-size','0','','','.w-catalog-compare'),(981358,'deals','.w-catalog-compare .cross-box .different-all > div','font-size','15','','','.w-catalog-compare'),(981359,'deals','.w-catalog-compare .name','font-size','12','','','.w-catalog-compare'),(981360,'deals','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-size','40','','','.w-delivery-day'),(981361,'deals','.w-delivery-day .ends','font-size','26','','','.w-delivery-day'),(981362,'deals','.w-delivery-day .left-text-left','font-size','24','','','.w-delivery-day'),(981363,'deals','.w-delivery-day .left-text-right','font-size','24','','','.w-delivery-day'),(981364,'deals','.w-delivery-day .title','font-size','18','','','.w-delivery-day'),(981366,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','0','','','.b-slick'),(981367,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','font-size','20','3','','.b-slick'),(981370,'deals','.b-products-listing .add-to-personal-catalog','font-size','14','3','','.b-products-listing'),(981371,'deals','.b-products-listing .del-from-personal-catalog','font-size','14','3','','.b-products-listing'),(981372,'deals','.w-cart-listing .headings .head','font-size','14','','','.w-cart-listing'),(981373,'deals','.b-products-listing .products-listing a.btn.view-button','font-size','14','3','','.b-products-listing'),(981374,'deals','.LeftCategories .w-menu-simple ul li a','font-size','18','','','.LeftCategories'),(981375,'deals','.w-quote .buttons .btn','font-size','14','','','.w-quote'),(981376,'deals','.w-quote .cart-box-link','font-size','18','','','.w-quote'),(981377,'deals','.w-quote .cart-total','font-size','1.2','','','.w-quote'),(981378,'deals','.w-quote .multicart .count','font-size','14','','','.w-quote'),(981379,'deals','.w-quote .qty','font-size','0.6','4','','.w-quote'),(981380,'deals','.w-quote .sub-total-row','font-size','18','','','.w-quote'),(981382,'deals','.w-product-personal-catalog-button .btn','font-size','14','','','.w-product-personal-catalog-button'),(981383,'deals','.b-quantity .qty-box .bigger','font-size','27','','','.b-quantity'),(981384,'deals','.b-quantity .qty-box .smaller','font-size','27','','','.b-quantity'),(981385,'deals','.rating, .ratingCounts','font-size','16','','',''),(981386,'deals','.w-product-sale-ends .ends','font-size','24','','','.w-product-sale-ends'),(981387,'deals','.w-product-sale-ends .left-count-days','font-size','30','','','.w-product-sale-ends'),(981388,'deals','.w-product-sale-ends .left-count-hours','font-size','30','','','.w-product-sale-ends'),(981389,'deals','.w-product-sale-ends .left-text-left','font-size','24','','','.w-product-sale-ends'),(981390,'deals','.w-product-sale-ends .left-text-right','font-size','24','','','.w-product-sale-ends'),(981391,'deals','.w-product-quantity .pr_attr','font-size','14','','','.w-product-quantity'),(981392,'deals','.w-product-quantity .qty_packs .price_1','font-size','18','4','','.w-product-quantity'),(981393,'deals','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','font-size','18','','','.w-product-quantity'),(981394,'deals','.w-product-quantity .qty_t span','font-size','14','','','.w-product-quantity'),(981395,'deals','.w-product-quantity .total-qty, .w-product-quantity .total-qty .qty_price','font-size','24','','','.w-product-quantity'),(981396,'deals','.w-product-bonus-points > div','font-size','14','','','.w-product-bonus-points'),(981397,'deals','.warrantyProduct .title','font-size','18','','','.warrantyProduct'),(981398,'deals','.warrantyProduct .seeDetails a','font-size','14','','','.warrantyProduct'),(981399,'deals','.w-compare .price','font-size','18','','','.w-compare'),(981400,'deals','.w-compare .name','font-size','14','','','.w-compare'),(981401,'deals','.w-compare .clear-compare-button','font-size','14','','','.w-compare'),(981402,'deals','.w-files-catalog-widgets-files-catalog .name','font-size','16','','','.w-files-catalog-widgets-files-catalog'),(981403,'deals','.w-files-catalog-widgets-files-list .name','font-size','18','','','.w-files-catalog-widgets-files-list'),(981404,'deals','.w-sample .buttons .btn','font-size','14','','','.w-sample'),(981405,'deals','.w-sample .cart-box-link','font-size','18','','','.w-sample'),(981406,'deals','.w-sample .cart-box-link','font-size','30','3','','.w-sample'),(981407,'deals','.w-sample .cart-total','font-size','1.2','','','.w-sample'),(981408,'deals','.w-sample .multicart .count','font-size','14','','','.w-sample'),(981409,'deals','.w-sample .qty','font-size','0.7','4','','.w-sample'),(981410,'deals','.w-sample .sub-total-row','font-size','18','','','.w-sample'),(981411,'deals','.w-sample .cart-box-link','font-size','25','5639,3','','.w-sample'),(981412,'deals','.w-filters-simple .integrate-price-holder','font-size','20','','','.w-filters-simple'),(981413,'deals','.w-filters-simple .integrate-price','font-size','30','','','.w-filters-simple'),(981414,'deals','.w-cart-discount-coupon .title','font-size','20','','','.w-cart-discount-coupon'),(981415,'deals','.w-cart-sub-total .title','font-size','20','','','.w-cart-sub-total'),(981416,'deals','.w-cart-sub-total .price','font-size','20','','','.w-cart-sub-total'),(981417,'deals','.w-cart-bonus-points .title','font-size','20','','','.w-cart-bonus-points'),(981418,'deals','.shipping-ico .heading-3','font-size','24','','','.shipping-ico'),(981419,'deals','.w-cart-up-sell .products-listing .price','font-size','18','','','.w-cart-up-sell'),(981420,'deals','.w-cart-up-sell .products-listing .name a','font-size','16','','','.w-cart-up-sell'),(981421,'deals','.w-cart-gift-certificate .heading-4','font-size','20','','','.w-cart-gift-certificate'),(981422,'deals','.w-cart-gift-certificate .gift-certificate .heading-4','font-size','22','3','','.w-cart-gift-certificate'),(981423,'deals','.w-cart-gift-certificate .gift-code p','font-size','13','','','.w-cart-gift-certificate'),(981424,'deals','.w-cart-order-reference .heading-4','font-size','20','','','.w-cart-order-reference'),(981425,'deals','.w-product-bundle .bundle_price','font-size','20','','','.w-product-bundle'),(981426,'deals','.w-product-bundle .bundle_price .old','font-size','0.8','','','.w-product-bundle'),(981427,'deals','.w-product-in-bundles .bundle_price .old','font-size','0.6','','','.w-product-in-bundles'),(981428,'deals','.w-product-in-bundles .bundle_price','font-size','20','','','.w-product-in-bundles'),(981430,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','font-size','inherit','','','.b-products-listing'),(981431,'deals','.b-pagination .pagination .next a, .b-pagination .pagination .next span','font-size','0','','','.b-pagination'),(981432,'deals','.b-pagination .pagination .prev a, .b-pagination .pagination .prev span','font-size','0','','','.b-pagination'),(981433,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','font-size','20','3','','.b-pagination'),(981434,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','font-size','20','3','','.b-pagination'),(981435,'deals','.w-catalog-compare .price','font-size','20','','','.w-catalog-compare'),(981436,'deals','.w-catalog-compare .out-stock','font-size','12','','','.w-catalog-compare'),(981437,'deals','.w-product-properties-filters-widgets-chosen-filters .remove','font-size','0','','','.w-product-properties-filters-widgets-chosen-filters'),(981438,'deals','.w-product-properties-filters-widgets-chosen-filters .remove','font-size','20','3','','.w-product-properties-filters-widgets-chosen-filters'),(981439,'deals','.w-product-multi-inventory .radio-attributes > span','font-size','18','','','.w-product-multi-inventory'),(981440,'deals','.w-product-sale-ends .left-text-right, .w-product-sale-ends .left-text-left','font-size','18','5644','','.w-product-sale-ends'),(981441,'deals','.w-product-sale-ends .left-count-days, .w-product-sale-ends .left-count-hours','font-size','24','5644','','.w-product-sale-ends'),(981442,'deals','.w-product-sale-ends .ends','font-size','21','5644','','.w-product-sale-ends'),(981443,'deals','.heading-2, h2, .h-block h2','font-size','21','5639','',''),(981444,'deals','.heading-3, h3, .h-block h3','font-size','19','5639','',''),(981445,'deals','.heading-4, h4, .h-block h4','font-size','17','5639','',''),(981446,'deals','.b-products-listing .products-listing.list-rows .stock','font-size','14','','','.b-products-listing'),(981447,'deals','.b-products-listing .products-listing.list-b2b .stock','font-size','14','','','.b-products-listing'),(981448,'deals','.b-products-listing .products-listing .radio-attributes > span','font-size','18','','','.b-products-listing'),(981449,'deals','.b-products-listing .products-listing .radio-attributes .option','font-size','14','','','.b-products-listing'),(981450,'deals','.w-product-collection .stock > span','font-size','14','','','.w-product-collection'),(981451,'deals','.w-product-collection .current-product .price','font-size','30','','','.w-product-collection'),(981452,'deals','.w-product-collection .right-area .special','font-size','36','','','.w-product-collection'),(981453,'deals','.w-product-collection .right-area .separate-text, .w-product-collection .right-area .separate','font-size','16','','','.w-product-collection'),(981454,'deals','.w-product-collection .together','font-size','16','','','.w-product-collection'),(981455,'deals','.w-product-collection .right-area .btn','font-size','24','','','.w-product-collection'),(981456,'deals','.price .special-promote','font-size','16','','',''),(981457,'deals','.w-breadcrumb .catalog-breadcrumb','font-size','14','5630','','.w-breadcrumb'),(981458,'deals','.w-product-attributes .radio-attributes > span','font-size','18','','','.w-product-attributes'),(981459,'deals','.w-product-properties .level-1','font-size','16','','','.w-product-properties'),(981460,'deals','.w-product-properties .propertiesName','font-size','16','','','.w-product-properties'),(981461,'deals','.w-product-properties .propertiesValue','font-size','16','','','.w-product-properties'),(981462,'deals','.w-product-properties li','font-size','14','','','.w-product-properties'),(981463,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','font-size','0','','','.w-questionnaire-widgets-questionnaire'),(981464,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','font-size','30','3','','.w-questionnaire-widgets-questionnaire'),(981465,'deals','.w-product-groups .radioBoxHead','font-size','14','','','.w-product-groups'),(981466,'deals','.w-product-groups .val1','font-size','14','','','.w-product-groups'),(981467,'deals','.w-product-groups .val2','font-size','14','','','.w-product-groups'),(981468,'deals','.w-product-groups .radioBox label .containerBlock img + .name + .val2','font-size','16','','','.w-product-groups'),(981469,'deals','.b-products-listing .mix-attributes .attribute-qty-block > span','font-size','13','','','.b-products-listing'),(981470,'deals','.w-product-custom-bundle .heading-3','font-size','16','','','.w-product-custom-bundle'),(981471,'deals','.w-product-custom-bundle .current-product .price','font-size','30','','','.w-product-custom-bundle'),(981472,'deals','.w-product-custom-bundle .right-area .special','font-size','30','','','.w-product-custom-bundle'),(981473,'deals','.w-product-custom-bundle .right-area .separate-text','font-size','16','','','.w-product-custom-bundle'),(981474,'deals','.w-product-custom-bundle .right-area .separate','font-size','36','','','.w-product-custom-bundle'),(981475,'deals','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','font-size','24','','','.w-product-custom-bundle'),(981476,'deals','.w-delivery-location-top-location-list .deliveryName','font-size','18','','','.w-delivery-location-top-location-list'),(981477,'deals','.w-delivery-location-location-list .deliveryName','font-size','18','','','.w-delivery-location-location-list'),(981478,'deals','.w-delivery-location-location-list .deliveryListParrent','font-size','22','','','.w-delivery-location-location-list'),(981479,'deals','.w-delivery-location-location-list .deliveryListParrent a','font-size','24','','','.w-delivery-location-location-list'),(981480,'deals','.w-delivery-location-location-list .deliveryListParrent a','font-size','18','5639','','.w-delivery-location-location-list'),(981481,'deals','.w-delivery-location-location-list .deliveryList li','font-size','14','5639','','.w-delivery-location-location-list'),(981482,'deals','.w-delivery-location-featured-list .deliveryName','font-size','18','','','.w-delivery-location-featured-list'),(981483,'deals','.w-sale-category .badge','font-size','20','','','.w-sale-category'),(981484,'deals','.w-sale-category .ends','font-size','26','','','.w-sale-category'),(981485,'deals','.w-sale-category .left-count-days','font-size','40','','','.w-sale-category'),(981486,'deals','.w-sale-category .left-count-hours','font-size','40','','','.w-sale-category'),(981487,'deals','.w-sale-category .left-text-left','font-size','24','','','.w-sale-category'),(981488,'deals','.w-sale-category .left-text-right','font-size','24','','','.w-sale-category'),(981489,'deals','.w-sale-category .name','font-size','20','','','.w-sale-category'),(981490,'deals','.w-sale-category .old','font-size','45','','','.w-sale-category'),(981491,'deals','.w-sale-category .percents','font-size','30','','','.w-sale-category'),(981492,'deals','.w-sale-category .special-price','font-size','70','','','.w-sale-category'),(981493,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-name','font-size','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(981494,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-name','font-size','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(981495,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description + div','font-size','18','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(981496,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description + div','font-size','18','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(981497,'deals','.w-delivery-location-list-by-page .name','font-size','18','','','.w-delivery-location-list-by-page'),(981498,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','font-size','14','','','.w-product-properties-icons'),(981499,'deals','.w-delivery-location-cross-pages .name','font-size','18','','','.w-delivery-location-cross-pages'),(981500,'deals','.w-cart-credit-amount .amount-title','font-size','20','','','.w-cart-credit-amount'),(981501,'deals','.w-catalog-delivery-locations .name','font-size','18','','','.w-catalog-delivery-locations'),(981502,'deals','.w-product-bonus-points .bonus-points-cost','font-size','16','','','.w-product-bonus-points'),(981503,'deals','.w-product-bonus-points .bonus-points-cost','font-size','14','5660','','.w-product-bonus-points'),(981504,'deals','.w-product-designer-designer .grnamebox .title-sortable','font-size','16','','','.w-product-designer-designer'),(981505,'deals','.w-product-designer-designer .prodDesignerType label','font-size','14','','','.w-product-designer-designer'),(981506,'deals','.w-press-reviews-widgets-press-reviews .date','font-size','13','','','.w-press-reviews-widgets-press-reviews'),(981507,'deals','.w-press-reviews-widgets-press-reviews .heading-3','font-size','30','','','.w-press-reviews-widgets-press-reviews'),(981508,'deals','.w-press-reviews-widgets-press-reviews .rating','font-size','18','','','.w-press-reviews-widgets-press-reviews'),(981509,'deals','.w-press-reviews-widgets-press-reviews-list .product-name','font-size','20','','','.w-press-reviews-widgets-press-reviews-list'),(981510,'deals','.b-products-listing .productGroup label a','font-size','12','','','.b-products-listing'),(981511,'deals','.w-support-system-filter .filter_cats.level-0 > li > a','font-size','18','','','.w-support-system-filter'),(981512,'deals','.w-communication-post .btn.refresh','font-size','30','','','.w-communication-post'),(981513,'deals','.w-rma-returns-history .btn','font-size','13','','','.w-rma-returns-history'),(981514,'deals','.w-rma-returns-history .column .title','font-size','14','','','.w-rma-returns-history'),(981515,'deals','.w-rma-returns-history .fromTo label >span','font-size','12','','','.w-rma-returns-history'),(981516,'deals','.w-rma-returns-history .icons .excel','font-size','20','3','','.w-rma-returns-history'),(981517,'deals','.w-rma-returns-history .icons .print','font-size','20','3','','.w-rma-returns-history'),(981518,'deals','.w-rma-returns-history .icons a','font-size','0','','','.w-rma-returns-history'),(981519,'deals','.w-rma-returns-history .sorting_1','font-size','13','','','.w-rma-returns-history'),(981520,'deals','.w-rma-returns-history .tableTitle','font-size','18','','','.w-rma-returns-history'),(981521,'deals','.w-product-configurator .pc-total-price','font-size','18','','','.w-product-configurator'),(981522,'deals','.b-products-listing .products-listing .bonus-points-cost','font-size','13','','','.b-products-listing'),(981523,'deals','.w-catalog-pages-category-pages-list .catalog-pages-name','font-size','20','','','.w-catalog-pages-category-pages-list'),(981524,'deals','.w-predefined-promotion .heading-3','font-size','48','','','.w-predefined-promotion'),(981525,'deals','.w-predefined-promotion .nextdiscount .heading','font-size','18','3','','.w-predefined-promotion'),(981526,'deals','.w-predefined-promotion .nextdiscount .heading','font-size','26','','','.w-predefined-promotion'),(981527,'deals','.w-predefined-promotion .nextdiscount .item-holder .name','font-size','14','','','.w-predefined-promotion'),(981528,'deals','.w-predefined-promotion .nextdiscount .promo-for-each','font-size','14','','','.w-predefined-promotion'),(981529,'deals','.w-predefined-promotion .prom-multi-discount .heading','font-size','26','','','.w-predefined-promotion'),(981530,'deals','.w-predefined-promotion .prom-multi-discount .promo-group','font-size','16','','','.w-predefined-promotion'),(981531,'deals','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','font-size','14','','','.w-predefined-promotion'),(981532,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','font-size','13','','','.w-predefined-promotion'),(981533,'deals','.w-predefined-promotion .promo-cart-discount .item a','font-size','14','','','.w-predefined-promotion'),(981534,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','font-size','13','','','.w-predefined-promotion'),(981535,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','font-size','16','','','.w-predefined-promotion'),(981536,'deals','.w-predefined-promotion .promo-item','font-size','24','','','.w-predefined-promotion'),(981537,'deals','.w-predefined-promotion .promo-salemaker .content a','font-size','14','','','.w-predefined-promotion'),(981538,'deals','.w-predefined-promotion .promo-salemaker .discount','font-size','13','','','.w-predefined-promotion'),(981539,'deals','.w-supplier-purchase-supplier-products .active .select_item > div:before','font-size','20','','','.w-supplier-purchase-supplier-products'),(981542,'deals','.headerWrap .searchIcon','font-size','21','3','','.headerWrap'),(981543,'deals','.headerWrap .w-contacts.phone','font-size','16','','','.headerWrap'),(981544,'deals','.headerWrap .w-contacts.phone','font-size','22','3','','.headerWrap'),(981545,'deals','.parallaxWrap .w-info-page','font-size','20','','','.parallaxWrap'),(981546,'deals','.w-subscribers .heading-3','font-size','23','','','.w-subscribers'),(981547,'deals','.w-subscribers h3','font-size','35','','','.w-subscribers'),(981548,'deals','.bannersWrap .text','font-size','36','','','.bannersWrap'),(981549,'deals','.preFooter .w-contacts > div','font-size','16','','','.preFooter'),(981550,'deals','.w-categories .categories h2','font-size','19','','','.w-categories'),(981551,'deals','.filterLine .before','font-size','20','','','.filterLine'),(981552,'deals','.filterLine .choose-filters li .btn-clear','font-size','13','','','.filterLine'),(981553,'deals','.filterLine .dropdown label >span','font-size','14','5644','','.filterLine'),(981554,'deals','.w-filters .open','font-size','25','3','','.w-filters'),(981555,'deals','.filterLine .w-catalog-sorting .sort-select','font-size','16','','','.filterLine'),(981556,'deals','.w-product-price-from ','font-size','24','','','.w-product-price-from'),(981557,'deals','.w-product-price-from .price-from-text','font-size','16','','','.w-product-price-from'),(981558,'deals','.w-product-quantity-discounts .quantity-discounts .heading-4','font-size','16','','','.w-product-quantity-discounts'),(981559,'deals','.w-product-quantity-discounts .quantity-discounts-content .price','font-size','14','','','.w-product-quantity-discounts'),(981562,'deals','.w-breadcrumb .catalog-breadcrumb','font-size','12','','','.w-breadcrumb'),(981563,'deals','.w-product-description > h3','font-size','24','','','.w-product-description'),(981564,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span','font-size','14','','','.w-product-quantity-discounts'),(981565,'deals','.messageBox .info','font-size','30','3','',''),(981566,'deals','.popup-box h1','font-size','26','','',''),(981567,'deals','.w-cart-listing .qty-box .bigger, .w-cart-listing .qty-box .smaller','font-size','18','','','.w-cart-listing'),(981569,'deals','.savings-ico .heading-3','font-size','24','','','.savings-ico'),(981570,'deals','.w-multi-cart-actions .dropdown-item','font-size','14','','','.w-multi-cart-actions'),(981571,'deals','.b-form .form-inputs label > span','font-size','14','','','.b-form'),(981572,'deals','.b-select-suggest .select2-container .select2-choice','font-size','14','','','.b-select-suggest'),(981573,'deals','.w-delayed-despatch-checkout .heading','font-size','14','','','.w-delayed-despatch-checkout'),(981574,'deals','.headerWrap .w-contacts.phone','font-size','25','5639,3','','.headerWrap'),(981575,'deals','.headerWrap .menu-style[data-style=\"1\"] .level-1 > li.parent > span.no-link','font-size','0','5630','','.headerWrap'),(981576,'deals','.headerWrap .menu-style[data-style=\"1\"] .level-1 >li.parent>span.no-link','font-size','25','5630,3','','.headerWrap'),(981577,'deals','.homeBanner .carousel .bottom-center > span','font-size','66','','','.homeBanner'),(981578,'deals','.homeBanner .carousel .bottom-center > span','font-size','36','5644','','.homeBanner'),(981579,'deals','.homeBanner .carousel .bottom-center > span','font-size','24','5630','','.homeBanner'),(981580,'deals','.bannersWrap .text','font-size','26','5644','','.bannersWrap'),(981581,'deals','.bannersWrap .text','font-size','18','5639','','.bannersWrap'),(981582,'deals','.bannersWrap .text','font-size','14','5660','','.bannersWrap'),(981583,'deals','.parallaxWrap .w-info-page','font-size','16','5639','','.parallaxWrap'),(981584,'deals','.parallaxWrap .w-info-page','font-size','14','5660','','.parallaxWrap'),(981585,'deals','.w-subscribers .heading-3','font-size','18','5630','','.w-subscribers'),(981586,'deals','.w-product-reviews .reviews-list .review','font-size','14','5639','','.w-product-reviews'),(981587,'deals','.b-info .info','font-size','30','3','','.b-info'),(981588,'deals','.b-info .info strong','font-size','18','','','.b-info'),(981589,'deals','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','font-size','21','5639','','.w-multi-cart-cart-switcher'),(981590,'deals','.w-checkout-billing-address .genders-title','font-size','14','','','.w-checkout-billing-address'),(981591,'deals','.w-checkout-shipping-address .genders-title','font-size','14','','','.w-checkout-shipping-address'),(981592,'deals','.w-checkout-create-account label.slim','font-size','14','5639','','.w-checkout-create-account'),(981593,'deals','.order-summary .price','font-size','15','5660','','.order-summary'),(981594,'deals','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-size','18','5660','','.order-summary'),(981595,'deals','.b-table-list .table-list td','font-size','14','5644','','.b-table-list'),(981596,'deals','.b-table-list .table-list th','font-size','14','5644','','.b-table-list'),(981597,'deals','.b-sub-totals .historyTotal table td','font-size','16','5639','','.b-sub-totals'),(981598,'deals','.b-sub-totals .historyTotal table tr:last-child td','font-size','20','5639','','.b-sub-totals'),(981599,'deals','.w-product-description > h3','font-size','21','5639','','.w-product-description'),(981600,'deals','.w-product-description .description','font-size','14','5639','','.w-product-description'),(981601,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','font-size','14','5630','','.headerWrap'),(981602,'deals','.filterLine .before','font-size','18','5639','','.filterLine'),(981603,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li > .no-link','font-size','18','5639','','.preFooter'),(981604,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li .no-link','font-size','26','5630,4','','.preFooter'),(981606,'deals','.w-account-personal-catalog .list-switcher a','font-size','14','5660','','.w-account-personal-catalog'),(981607,'deals','.p-wedding-registry-view h1','font-size','22','3','','.p-wedding-registry-view'),(981608,'deals','.p-wedding-registry-view h1','font-size','22','4','','.p-wedding-registry-view'),(981609,'deals','.w-product-wishlist-button .btn','font-size','14','','','.w-product-wishlist-button'),(981610,'deals','.w-product-wishlist-button .btn','font-size','21','3','','.w-product-wishlist-button'),(981611,'deals','.homeBanner .banner-item .banner-text-holder','font-size','66','','','.homeBanner'),(981612,'deals','.homeBanner .banner-item .banner-text-holder','font-size','36','5644','','.homeBanner'),(981613,'deals','.homeBanner .banner-item .banner-text-holder','font-size','24','5630','','.homeBanner'),(981614,'deals','.order-summary .icon','font-size','18','3','','.order-summary'),(981615,'deals','.order-summary .w-cart-listing .price','font-size','18','','','.order-summary'),(981616,'deals','.w-cart-discount-coupon .title','font-size','24','4','','.w-cart-discount-coupon'),(981617,'deals','.w-cart-checkout-btn .with-card','font-size','18','4','','.w-cart-checkout-btn'),(981618,'deals','.w-promotions-widgets-promotions .promotion-full-price-discount','font-size','34','','','.w-promotions-widgets-promotions'),(981640,'deals','.account-address-book .address_book .btn-edit, .account-address-book .address_book .btn-delete','font-size','16','4','','.account-address-book'),(981641,'deals','.account-address-book .address_book h2','font-size','18','','','.account-address-book'),(981642,'deals','.account-address-book .btn-edit','font-size','16','4','','.account-address-book'),(981643,'deals','.account-address-book .leftMes div','font-size','18','','','.account-address-book'),(981656,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-size','18','','','.account-order-pay'),(981657,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-size','22','3','','.account-order-pay'),(981658,'deals','.account-order-pay .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-order-pay'),(981659,'deals','.account-order-pay .history_attr','font-size','14','','','.account-order-pay'),(981660,'deals','.account-order-pay .not_fully_paid_td','font-size','30','','','.account-order-pay'),(981661,'deals','.account-samples .not_fully_paid_td','font-size','30','','','.account-samples'),(981662,'deals','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','font-size','16','','','.account-samples'),(981663,'deals','.account-samples .order_history_table h2','font-size','24','','','.account-samples'),(981664,'deals','.account-samples .order_history_table th','font-size','16','','','.account-samples'),(981665,'deals','.account-samples .view_link','font-size','18','4','','.account-samples'),(981666,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-size','18','','','.account-sample-info'),(981667,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-size','22','3','','.account-sample-info'),(981668,'deals','.account-sample-info .historyInfoColumn h2.title-ship-method','font-size','28','3','','.account-sample-info'),(981669,'deals','.account-sample-info .history_attr','font-size','14','','','.account-sample-info'),(981670,'deals','.account-sample-info .not_fully_paid_td','font-size','30','','','.account-sample-info'),(981671,'deals','.account-sample-info .popup-tracking-number-link','font-size','18','','','.account-sample-info'),(981672,'deals','.account-sample-info .trackings-nambers-label','font-size','20','','','.account-sample-info'),(981673,'deals','.catalog-product-wrap .pn-direction','font-size','14','','','.catalog-product-wrap'),(981674,'deals','.catalog-product-wrap .pn-image','font-size','14','3','','.catalog-product-wrap'),(981675,'deals','.catalog-product-wrap .pn-name','font-size','14','','','.catalog-product-wrap'),(981676,'deals','.catalog-product-wrap .pn-direction','font-size','10','5639','','.catalog-product-wrap'),(981677,'deals','.shopping-cart-index .cart-page .empty','font-size','24','','','.shopping-cart-index'),(981678,'deals','.shopping-cart-index .closeable-box .price','font-size','18','5630','','.shopping-cart-index'),(981679,'deals','.shopping-cart-index .closeable-box .title','font-size','18','5630','','.shopping-cart-index'),(981680,'deals','.shopping-cart-index .gift-code .heading-4','font-size','20','5630','','.shopping-cart-index'),(981681,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','font-size','16','','','.checkout-index-wrap'),(981682,'deals','.checkout-index-wrap .order-ico','font-size','36','3','','.checkout-index-wrap'),(981683,'deals','.checkout-index-wrap .pay-ico','font-size','30','3','','.checkout-index-wrap'),(981684,'deals','.checkout-index-wrap .ship-ico','font-size','30','3','','.checkout-index-wrap'),(981685,'deals','.checkout-order-confirmation .comment-ico','font-size','30','3','','.checkout-order-confirmation'),(981686,'deals','.checkout-order-confirmation .discount-ico','font-size','30','3','','.checkout-order-confirmation'),(981687,'deals','.checkout-order-confirmation .order-ico','font-size','36','3','','.checkout-order-confirmation'),(981688,'deals','.checkout-order-confirmation .price-box','font-size','16','','','.checkout-order-confirmation'),(981689,'deals','.checkout-order-confirmation .price-box .price','font-size','16','','','.checkout-order-confirmation'),(981690,'deals','.checkout-order-confirmation .price-box .price-row.total','font-size','22','','','.checkout-order-confirmation'),(981691,'deals','.checkout-order-confirmation .ship-ico','font-size','30','3','','.checkout-order-confirmation'),(981692,'deals','.checkout-success-wrap .page-success .text-1','font-size','80','3','','.checkout-success-wrap'),(981693,'deals','.checkout-success-wrap .page-success .text-1','font-size','60','','','.checkout-success-wrap'),(981694,'deals','.checkout-success-wrap .page-success .text-2','font-size','34','','','.checkout-success-wrap'),(981695,'deals','.checkout-success-wrap .page-success .text-3','font-size','27','','','.checkout-success-wrap'),(981696,'deals','.checkout-success-wrap .page-success .text-1','font-size','40','5630','','.checkout-success-wrap'),(981697,'deals','.checkout-success-wrap .page-success .text-1','font-size','60','5630,3','','.checkout-success-wrap'),(981698,'deals','.checkout-success-wrap .page-success .text-2','font-size','24','5630','','.checkout-success-wrap'),(981699,'deals','.checkout-success-wrap .page-success .text-3','font-size','20','5630','','.checkout-success-wrap'),(981700,'deals','.checkout-login-wrap .password-forgotten-link','font-size','14','','','.checkout-login-wrap'),(981702,'deals','.success-page .check-ico-block','font-size','60','3','','.success-page'),(981703,'deals','.success-page .comment-ico','font-size','30','3','','.success-page'),(981704,'deals','.success-page .discount-ico','font-size','30','3','','.success-page'),(981705,'deals','.success-page .order-ico','font-size','36','3','','.success-page'),(981706,'deals','.success-page .order_totals .price','font-size','18','','','.success-page'),(981707,'deals','.success-page .page-success .text-1','font-size','30','','','.success-page'),(981708,'deals','.success-page .page-success .text-1','font-size','36','3','','.success-page'),(981709,'deals','.success-page .page-success .text-1','font-size','40','5630','','.success-page'),(981710,'deals','.success-page .page-success .text-2','font-size','24','','','.success-page'),(981711,'deals','.success-page .page-success .text-2','font-size','30','5630','','.success-page'),(981712,'deals','.success-page .page-success .text-3','font-size','20','','','.success-page'),(981713,'deals','.success-page .pay-ico','font-size','30','3','','.success-page'),(981714,'deals','.success-page .price-box','font-size','16','','','.success-page'),(981715,'deals','.success-page .price-box .price','font-size','16','','','.success-page'),(981716,'deals','.success-page .price-box .price-row.total','font-size','22','','','.success-page'),(981717,'deals','.success-page .price-row.total .price b','font-size','22','','','.success-page'),(981718,'deals','.success-page .prod-ico','font-size','30','3','','.success-page'),(981719,'deals','.success-page .ship-ico','font-size','30','3','','.success-page'),(981720,'deals','.success-page .w-cart-listing .history_attr','font-size','13','','','.success-page'),(981721,'deals','.success-page .w-cart-listing .name a','font-size','14','','','.success-page'),(981722,'deals','.success-page .w-cart-listing .price','font-size','16','','','.success-page'),(981723,'deals','.success-page .w-cart-listing .qty','font-size','14','','','.success-page'),(981725,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading','font-size','24','','','.b-multi-page-checkout'),(981726,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font-size','0.7','4','','.b-multi-page-checkout'),(981728,'deals','.footer-menu .level-1 > li > a, .footer-menu .level-1 > li > .no-link','font-size','18','','','.footer-menu'),(981729,'deals','.footer-menu .level-2 > li > a, .footer-menu .level-2 > li > .no-link','font-size','16','','','.footer-menu'),(981730,'deals','.footer-menu .level-1 > li .no-link','font-size','25','5639,3','','.footer-menu'),(981731,'deals','.footer-menu .level-1 > li > .no-link','font-size','0','5639','','.footer-menu'),(981732,'deals','.footer-menu .level-3 > li > a','font-size','14','5639','','.footer-menu'),(981733,'deals','.footer-menu .level-4 > li > a','font-size','14','5639','','.footer-menu'),(981734,'deals','.w-catalog-paging .next','font-size','20','3','','.w-catalog-paging'),(981735,'deals','.w-catalog-paging .prev','font-size','20','3','','.w-catalog-paging'),(981741,'deals','.w-menu-slider .menu-ico','font-size','23','','','.w-menu-slider'),(981744,'deals','.shopping-cart-index .closeable-box .title','font-size_important','important','5630','','.shopping-cart-index'),(981745,'deals','.b-rating .glyphicon','font-style','normal','','','.b-rating'),(981746,'deals','.b-switch .candlestick-wrapper .fa-times','font-style','normal','3','','.b-switch'),(981747,'deals','.b-switch .candlestick-wrapper .fa-check','font-style','normal','3','','.b-switch'),(981748,'deals','.b-select-suggest .select2-results li em','font-style','normal','','','.b-select-suggest'),(981749,'deals','.heading-4 .right-text, h4 .right-text','font-weight','400','','',''),(981750,'deals','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(981751,'deals','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(981752,'deals','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(981753,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','font-weight','600','','','.b-switch'),(981754,'deals','.p-quick-order-index .filters label','font-weight','700','','','.p-quick-order-index'),(981755,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.p-quick-order-index'),(981756,'deals','.w-promotions .prom-multi-discount .promo-range .value','font-weight','bold','','','.w-promotions'),(981757,'deals','.w-promotions .promo-date','font-weight','500','','','.w-promotions'),(981758,'deals','.w-personal-gift-status-bar .end-label','font-weight','bold','','','.w-personal-gift-status-bar'),(981759,'deals','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(981760,'deals','.testimonials .reviews-list span','font-weight','400','','',''),(981761,'deals','.testimonials .rating','font-weight','400','','',''),(981762,'deals','.testimonials .name','font-weight','700','','',''),(981763,'deals','.testimonials .heading-3','font-weight','400','3','',''),(981764,'deals','.testimonials .reviews-list .name','font-weight','700','','',''),(981765,'deals','.w-promotions .prom-multi-discount .heading','font-weight','300','','','.w-promotions'),(981766,'deals','.w-promotions .heading-3','font-weight','bold','','','.w-promotions'),(981767,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.p-quick-order-index'),(981768,'deals','.w-promotions .promo-salemaker .promo-manufacturers .heading','font-weight','300','','','.w-promotions'),(981769,'deals','.w-promotions .promo-salemaker .promo-conditions','font-weight','300','','','.w-promotions'),(981770,'deals','.w-promotions .promo-salemaker .discount .value','font-weight','700','','','.w-promotions'),(981771,'deals','.w-promotions .promo-cart-discount .slave .condition-holder .value','font-weight','bold','','','.w-promotions'),(981772,'deals','.w-promotions .promo-cart-discount .slave .heading','font-weight','300','','','.w-promotions'),(981773,'deals','.w-promotions .promo-cart-discount .promo-min-qty .value','font-weight','bold','','','.w-promotions'),(981774,'deals','.w-promotions .promo-cart-discount .master .heading','font-weight','300','','','.w-promotions'),(981775,'deals','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-avg','font-weight','bold','','','.b-warehouses-popup'),(981776,'deals','.b-warehouses-popup .warehouses-popup .warehouse-name','font-weight','bold','','','.b-warehouses-popup'),(981777,'deals','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-high, .b-warehouses-popup .warehouses-popup .warehouse-qty-less','font-weight','bold','','','.b-warehouses-popup'),(981778,'deals','.b-warehouses-popup .warehouses-popup .heading','font-weight','bold','','','.b-warehouses-popup'),(981779,'deals','.b-warehouses-popup a.warehouses-popup-link','font-weight','bold','','','.b-warehouses-popup'),(981780,'deals','.w-product-available-in-warehouses .warehouse-name','font-weight','bold','','','.w-product-available-in-warehouses'),(981781,'deals','.w-checkout-create-account .account-benefits strong','font-weight','normal','','','.w-checkout-create-account'),(981782,'deals','.w-cart-listing .name a','font-weight','bold','','','.w-cart-listing'),(981783,'deals','.b-messages .messBtnMenuDelete','font-weight','normal','3','','.b-messages'),(981784,'deals','.b-messages span.starred::before','font-weight','normal','','','.b-messages'),(981785,'deals','.b-messages .messBtnMenuStarred','font-weight','normal','3','','.b-messages'),(981786,'deals','.b-messages .messMenuButton span','font-weight','600','','','.b-messages'),(981787,'deals','.b-messages .messBtnMenuUnread','font-weight','normal','3','','.b-messages'),(981788,'deals','.b-messages .messages-menu li a','font-weight','bold','2','','.b-messages'),(981789,'deals','.b-messages .content_management_attach','font-weight','600','','','.b-messages'),(981790,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','font-weight','600','','','.b-messages'),(981791,'deals','.w-reviews .author','font-weight','bold','','','.w-reviews'),(981792,'deals','.order-summary .price-box .price-row.total','font-weight','600','','','.order-summary'),(981793,'deals','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(981794,'deals','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(981795,'deals','.p-payer-order-confirmation .cardinfo-label','font-weight','bold','','','.p-payer-order-confirmation'),(981796,'deals','.p-payer-order-pay .cardinfo-label','font-weight','bold','','','.p-payer-order-pay'),(981797,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','font-weight','bold','4','','.b-switch'),(981798,'deals','.b-rating .glyphicon','font-weight','400','','','.b-rating'),(981799,'deals','.p-quick-order-index .value','font-weight','bold','','','.p-quick-order-index'),(981800,'deals','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(981801,'deals','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(981802,'deals','.b-form .shipping-method .cost','font-weight','bold','','','.b-form'),(981803,'deals','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','font-weight','600','','','.p-quick-order-index'),(981804,'deals','.btn-1','font-weight','700','','',''),(981805,'deals','.w-checkout-totals .ot_code_ot_subtotal','font-weight','bold','','','.w-checkout-totals'),(981806,'deals','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(981807,'deals','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(981808,'deals','.b-bottom .popup-heading','font-weight','bold','','','.b-bottom'),(981809,'deals','.b-form .middle-form label.slim','font-weight','400','','','.b-form'),(981810,'deals','.w-checkout-shipping-choice span','font-weight','600','','','.w-checkout-shipping-choice'),(981811,'deals','.btn-3','font-weight','700','','',''),(981812,'deals','.w-reviews-content .author','font-weight','bold','','','.w-reviews-content'),(981813,'deals','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(981814,'deals','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(981815,'deals','.w-cart-compare .js-cart_totals_container b','font-weight','600','','','.w-cart-compare'),(981816,'deals','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(981817,'deals','.w-image-maps .default-links .item .title','font-weight','700','','','.w-image-maps'),(981818,'deals','.heading-4 .edit, h4 .edit','font-weight','400','','',''),(981819,'deals','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(981820,'deals','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(981821,'deals','.w-tabs .tab-li.tab-wishlist a','font-weight','normal','3','','.w-tabs'),(981822,'deals','.w-multi-cart-cart-switcher .cart-label','font-weight','600','','','.w-multi-cart-cart-switcher'),(981823,'deals','.w-multi-cart-actions .cart-actions','font-weight','600','','','.w-multi-cart-actions'),(981824,'deals','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(981825,'deals','.b-form .middle-form label','font-weight','600','','','.b-form'),(981826,'deals','.w-cart-credit-amount .amount-title','font-weight','600','','','.w-cart-credit-amount'),(981827,'deals','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(981828,'deals','.w-personal-gift-status-bar .end-date b','font-weight','bold','','','.w-personal-gift-status-bar'),(981829,'deals','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(981830,'deals','.btn-2','font-weight','700','','',''),(981831,'deals','.heading-5, h5, .h-block h5','font-weight','600','','',''),(981832,'deals','.w-cart-compare .cart-name a','font-weight','600','','','.w-cart-compare'),(981833,'deals','.w-product-reviews .reviews-list span','font-weight','400','','','.w-product-reviews'),(981834,'deals','.w-delayed-despatch-checkout .heading','font-weight','600','','','.w-delayed-despatch-checkout'),(981835,'deals','.w-top-categories .categories h2','font-weight','inherit','','','.w-top-categories'),(981836,'deals','.transit','font-weight','700','','',''),(981837,'deals','.out-stock','font-weight','700','','',''),(981838,'deals','.in-stock','font-weight','700','','',''),(981839,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','font-weight','bold','4','','.b-switch'),(981840,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','font-weight','bold','4','','.b-switch'),(981841,'deals','.b-delete-account .delete-box .delete-message','font-weight','normal','','','.b-delete-account'),(981842,'deals','.w-checkout-shipping-address .genders-title > div','font-weight','600','','','.w-checkout-shipping-address'),(981843,'deals','.w-cart-bonus-points .title','font-weight','600','','','.w-cart-bonus-points'),(981844,'deals','.w-checkout-billing-address .btn-cancel','font-weight','500','','','.w-checkout-billing-address'),(981845,'deals','.js-stock','font-weight','700','','',''),(981846,'deals','.b-form #payment_method .title','font-weight','600','','','.b-form'),(981847,'deals','.b-fancybox .fancybox-title-float-wrap .child','font-weight','bold','','','.b-fancybox'),(981848,'deals','.w-reviews-content .product-name a','font-weight','bold','','','.w-reviews-content'),(981849,'deals','.w-product-reviews .reviews-list .name','font-weight','700','','','.w-product-reviews'),(981850,'deals','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(981851,'deals','.w-socials .post_item_name a','font-weight','600','','','.w-socials'),(981852,'deals','.w-tabs .tab-li.tab-cart a','font-weight','normal','3','','.w-tabs'),(981853,'deals','.btn','font-weight','700','','',''),(981854,'deals','.w-personal-gift-status-bar .inform b','font-weight','bold','','','.w-personal-gift-status-bar'),(981855,'deals','.w-reviews .heading-3','font-weight','400','3','','.w-reviews'),(981856,'deals','.w-reviews .product-name a','font-weight','bold','','','.w-reviews'),(981857,'deals','.w-checkout-billing-address .genders-title > div','font-weight','600','','','.w-checkout-billing-address'),(981858,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','font-weight','600','','','.b-switch'),(981859,'deals','.b-social-login .social-login-text-2','font-weight','bold','','','.b-social-login'),(981860,'deals','.w-cart-compare .atr-col','font-weight','600','','','.w-cart-compare'),(981861,'deals','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(981862,'deals','.b-bottom .alert-message','font-weight','bold','','','.b-bottom'),(981863,'deals','.w-image-maps .categories-items .item .title','font-weight','700','','','.w-image-maps'),(981864,'deals','.w-neighbour-checkout .text','font-weight','600','','','.w-neighbour-checkout'),(981865,'deals','.order-summary .price-box .price-row.total .title, .order-summary .price-box .price-row.total .price','font-weight','600','','','.order-summary'),(981866,'deals','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(981867,'deals','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(981868,'deals','.w-cart-compare .atr-col','font-weight','normal','3','','.w-cart-compare'),(981869,'deals','.w-tabs .tab-li.tab-quote a','font-weight','normal','3','','.w-tabs'),(981870,'deals','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(981871,'deals','.w-product-available-in-warehouses .heading','font-weight','bold','','','.w-product-available-in-warehouses'),(981872,'deals','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(981873,'deals','.p-quick-order-index .dataTables_info','font-weight','500','','','.p-quick-order-index'),(981874,'deals','.w-product-promotions .promotion-data-2 .save','font-weight','bold','','','.w-product-promotions'),(981875,'deals','.w-delayed-despatch-checkout-confirm .heading','font-weight','600','','','.w-delayed-despatch-checkout-confirm'),(981876,'deals','.w-delayed-despatch-checkout-confirm .heading','font-weight','bold','','','.w-delayed-despatch-checkout-confirm'),(981877,'deals','.w-checkout-bonus-points .title','font-weight','bold','','','.w-checkout-bonus-points'),(981878,'deals','.w-coupons-and-vauchers-checkout .title','font-weight','600','','','.w-coupons-and-vauchers-checkout'),(981879,'deals','.w-checkout-credit-amount .amount-title','font-weight','bold','','','.w-checkout-credit-amount'),(981880,'deals','.b-pass-strength .pass-strength span','font-weight','bold','','','.b-pass-strength'),(981881,'deals','.w-quote .strong','font-weight','400','','','.w-quote'),(981882,'deals','.b-select-suggest .select2-results li.select2-result-with-children > .select2-result-label','font-weight','bold','','','.b-select-suggest'),(981883,'deals','.b-warehouses-popup .warehouses-popup .warehouse-qty-level-low','font-weight','bold','','','.b-warehouses-popup'),(981884,'deals','.w-quote-products .empty','font-weight','700','','','.w-quote-products'),(981885,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','font-weight','500','','','.b-data-table'),(981886,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','font-weight','500','','','.b-data-table'),(981887,'deals','.w-communication-post .communication-post-author-name','font-weight','bold','','','.w-communication-post'),(981888,'deals','.b-products-listing .products-listing .bonus-points span:first-child','font-weight','bold','','','.b-products-listing'),(981889,'deals','.b-products-listing .products-listing .btn-buy','font-weight','400','3','','.b-products-listing'),(981890,'deals','.b-products-listing .promos-info .promo-name','font-weight','500','','','.b-products-listing'),(981891,'deals','.b-products-listing .wedding-registry-count','font-weight','bold','','','.b-products-listing'),(981894,'deals','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(981895,'deals','.b-form .form-inputs label > span','font-weight','600','','','.b-form'),(981896,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','font-weight','inherit','','',''),(981897,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','font-weight','inherit','','','.b-h-inline'),(981898,'deals','h1, .heading-1','font-weight','400','','',''),(981899,'deals','.w-tabs .tab-li.tab-sample a','font-weight','normal','3','','.w-tabs'),(981900,'deals','.b-form .shipping-method .title','font-weight','bold','','','.b-form'),(981901,'deals','.b-page-name .page-name','font-weight','600','','','.b-page-name'),(981902,'deals','.w-cart-listing .item .gift-wrap label','font-weight','700','','','.w-cart-listing'),(981903,'deals','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-weight','600','','','.w-cart-listing'),(981904,'deals','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','font-weight','normal','3','','.w-cart-listing'),(981905,'deals','.w-cart-listing .remove-btn span','font-weight','bold','5639','','.w-cart-listing'),(981906,'deals','.w-cart-give-away .ga_price','font-weight','700','','','.w-cart-give-away'),(981911,'deals','.w-image-maps .float-items .item .title','font-weight','700','','','.w-image-maps'),(981912,'deals','.b-form .address-item .firstname, .b-form .address-item .lastname','font-weight','600','','','.b-form'),(981915,'deals','.w-checkout-contact-information .contact-info-buttons a','font-weight','500','','','.w-checkout-contact-information'),(981916,'deals','.w-checkout-shipping-address .change-ab','font-weight','500','','','.w-checkout-shipping-address'),(981917,'deals','.w-checkout-billing-address .edit-ab','font-weight','500','','','.w-checkout-billing-address'),(981918,'deals','.w-checkout-billing-address .add-ab','font-weight','500','','','.w-checkout-billing-address'),(981919,'deals','.w-filters .view_more','font-weight','400','4','','.w-filters'),(981920,'deals','.b-bottom .footerTitle','font-weight','700','','','.b-bottom'),(981921,'deals','.heading-2, h2, .h-block h2','font-weight','600','','',''),(981922,'deals','.b-data-table table.dataTable thead td','font-weight','700','','','.b-data-table'),(981923,'deals','.heading-6, h6, .h-block h6','font-weight','600','','',''),(981924,'deals','.p-sample-cart-index .empty','font-weight','700','','','.p-sample-cart-index'),(981925,'deals','.order-summary .price-row.ot_coupon .title','font-weight','bold','3','','.order-summary'),(981926,'deals','.w-personal-gift-status-bar .start-label','font-weight','bold','','','.w-personal-gift-status-bar'),(981927,'deals','.b-personal-catalog-popup #personal_catalog_popup','font-weight','normal','','','.b-personal-catalog-popup'),(981928,'deals','.b-trade-approval .middle-form label','font-weight','600','','','.b-trade-approval'),(981929,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','font-weight','normal','3','','.w-catalog-compare'),(981930,'deals','.w-delivery-day .left-count-days, .w-delivery-day .left-count-hours, .w-delivery-day .left-count-minutes, .w-delivery-day .left-count-seconds','font-weight','600','','','.w-delivery-day'),(981931,'deals','.w-delivery-day .ends-date','font-weight','600','','','.w-delivery-day'),(981932,'deals','.w-delivery-day .title','font-weight','bold','','','.w-delivery-day'),(981933,'deals','.w-delivery-day .left-text-left','font-weight','600','','','.w-delivery-day'),(981934,'deals','.w-delivery-day .left-text-right','font-weight','600','','','.w-delivery-day'),(981937,'deals','.w-cart-listing .item div.price','font-weight','bold','','','.w-cart-listing'),(981938,'deals','.w-filters .head-filter-widget','font-weight','700','','','.w-filters'),(981939,'deals','.w-filters .filter-box-head','font-weight','700','','','.w-filters'),(981940,'deals','.w-quote .cart-box-link','font-weight','bold','','','.w-quote'),(981941,'deals','.w-quote .cart-box-link','font-weight','normal','3','','.w-quote'),(981942,'deals','.w-quote .cart-total','font-weight','600','','','.w-quote'),(981943,'deals','.w-quote .multicart .title','font-weight','600','','','.w-quote'),(981944,'deals','.w-quote .price','font-weight','600','','','.w-quote'),(981945,'deals','.w-quote .sub-total-row','font-weight','600','','','.w-quote'),(981946,'deals','.w-product-personal-catalog-button .btn','font-weight','700','','','.w-product-personal-catalog-button'),(981947,'deals','.w-product-sale-ends .ends-date','font-weight','600','','','.w-product-sale-ends'),(981948,'deals','.w-product-sale-ends .left-count-days','font-weight','600','','','.w-product-sale-ends'),(981949,'deals','.w-product-sale-ends .left-count-hours','font-weight','600','','','.w-product-sale-ends'),(981950,'deals','.w-product-sale-ends .left-text-left','font-weight','600','','','.w-product-sale-ends'),(981951,'deals','.w-product-sale-ends .left-text-right','font-weight','600','','','.w-product-sale-ends'),(981952,'deals','.w-tabs .tab-a','font-weight','600','','','.w-tabs'),(981953,'deals','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','font-weight','400','3','','.w-product-buttons'),(981954,'deals','.warrantyProduct .title','font-weight','700','','','.warrantyProduct'),(981955,'deals','.w-files-catalog-widgets-files-catalog .name','font-weight','600','','','.w-files-catalog-widgets-files-catalog'),(981956,'deals','.w-files-catalog-widgets-files-list .name','font-weight','600','','','.w-files-catalog-widgets-files-list'),(981957,'deals','.w-sample .cart-box-link','font-weight','bold','','','.w-sample'),(981958,'deals','.w-sample .cart-box-link','font-weight','normal','3','','.w-sample'),(981959,'deals','.w-sample .cart-total','font-weight','600','','','.w-sample'),(981960,'deals','.w-sample .multicart .title','font-weight','600','','','.w-sample'),(981961,'deals','.w-sample .price','font-weight','600','','','.w-sample'),(981962,'deals','.w-sample .strong','font-weight','400','','','.w-sample'),(981963,'deals','.w-sample .sub-total-row','font-weight','600','','','.w-sample'),(981964,'deals','.w-filters-simple .integrate-price','font-weight','bold','','','.w-filters-simple'),(981965,'deals','.w-cart-sub-total .title','font-weight','600','','','.w-cart-sub-total'),(981966,'deals','.w-cart-sub-total .price','font-weight','600','','','.w-cart-sub-total'),(981967,'deals','.w-cart-gift-certificate .heading-4','font-weight','400','','','.w-cart-gift-certificate'),(981968,'deals','.w-product-attributes .radio-attributes > span','font-weight','700','','','.w-product-attributes'),(981969,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','font-weight','inherit','','','.b-products-listing'),(981970,'deals','.b-pagination .pagination .active a, .b-pagination .pagination .active span','font-weight','bold','','','.b-pagination'),(981971,'deals','.b-pagination .pagination span','font-weight','700','2','','.b-pagination'),(981972,'deals','.w-product-multi-inventory .radio-attributes > span','font-weight','700','','','.w-product-multi-inventory'),(981973,'deals','.w-product-multi-inventory .radio-attributes .option-item','font-weight','700','','','.w-product-multi-inventory'),(981974,'deals','.b-products-listing .products-listing.list-rows .stock','font-weight','700','','','.b-products-listing'),(981975,'deals','.b-products-listing .products-listing.list-b2b .stock','font-weight','700','','','.b-products-listing'),(981976,'deals','.b-products-listing .products-listing .radio-attributes .option','font-weight','700','','','.b-products-listing'),(981977,'deals','.b-products-listing .products-listing .radio-attributes > span','font-weight','700','','','.b-products-listing'),(981978,'deals','.b-products-listing .products-listing .attributes .item-title','font-weight','600','','','.b-products-listing'),(981979,'deals','.w-product-collection .stock > span','font-weight','700','','','.w-product-collection'),(981980,'deals','.w-product-collection .save','font-weight','600','','','.w-product-collection'),(981981,'deals','.w-product-collection .title','font-weight','bold','','','.w-product-collection'),(981982,'deals','.w-product-collection .together','font-weight','700','','','.w-product-collection'),(981983,'deals','.w-product-collection .right-area .btn','font-weight','400','3','','.w-product-collection'),(981984,'deals','.w-product-collection .right-area .btn-2','font-weight','400','3','','.w-product-collection'),(981985,'deals','.w-product-attributes .radio-attributes .option-item','font-weight','700','','','.w-product-attributes'),(981986,'deals','.w-product-in-bundles .bundle_name','font-weight','700','','','.w-product-in-bundles'),(981987,'deals','.w-product-groups .radioBoxHead','font-weight','700','','','.w-product-groups'),(981988,'deals','.w-product-groups .val1','font-weight','700','','','.w-product-groups'),(981989,'deals','.w-product-groups .radioBox label .containerBlock img + .name + .val2','font-weight','700','','','.w-product-groups'),(981990,'deals','.w-product-custom-bundle .save','font-weight','600','','','.w-product-custom-bundle'),(981991,'deals','.w-product-custom-bundle .together','font-weight','700','','','.w-product-custom-bundle'),(981992,'deals','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','font-weight','400','3','','.w-product-custom-bundle'),(981993,'deals','.w-delivery-location-top-location-list .deliveryName','font-weight','700','','','.w-delivery-location-top-location-list'),(981994,'deals','.w-delivery-location-location-list .deliveryName','font-weight','700','','','.w-delivery-location-location-list'),(981995,'deals','.w-delivery-location-location-list .deliveryListParrent','font-weight','400','','','.w-delivery-location-location-list'),(981996,'deals','.w-delivery-location-location-list .deliveryList li','font-weight','600','','','.w-delivery-location-location-list'),(981997,'deals','.w-delivery-location-featured-list .deliveryName','font-weight','700','','','.w-delivery-location-featured-list'),(981998,'deals','.w-sale-category .ends-date','font-weight','600','','','.w-sale-category'),(981999,'deals','.w-sale-category .left-count-days','font-weight','600','','','.w-sale-category'),(982000,'deals','.w-sale-category .left-count-hours','font-weight','600','','','.w-sale-category'),(982001,'deals','.w-sale-category .left-text-left','font-weight','600','','','.w-sale-category'),(982002,'deals','.w-sale-category .left-text-right','font-weight','600','','','.w-sale-category'),(982003,'deals','.w-sale-category .name','font-weight','bold','','','.w-sale-category'),(982004,'deals','.w-sale-category .special-price','font-weight','600','','','.w-sale-category'),(982005,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description + div','font-weight','700','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(982006,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description + div','font-weight','700','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(982007,'deals','.w-delivery-location-list-by-page .name','font-weight','700','','','.w-delivery-location-list-by-page'),(982008,'deals','.w-delivery-location-cross-pages .name','font-weight','700','','','.w-delivery-location-cross-pages'),(982009,'deals','.w-catalog-delivery-locations .name','font-weight','700','','','.w-catalog-delivery-locations'),(982010,'deals','.w-product-designer-designer .grnamebox .title-sortable','font-weight','700','','','.w-product-designer-designer'),(982011,'deals','.w-press-reviews-widgets-press-reviews .author','font-weight','bold','','','.w-press-reviews-widgets-press-reviews'),(982012,'deals','.w-press-reviews-widgets-press-reviews .title a','font-weight','bold','','','.w-press-reviews-widgets-press-reviews'),(982013,'deals','.w-press-reviews-widgets-press-reviews-list .product-name','font-weight','600','','','.w-press-reviews-widgets-press-reviews-list'),(982014,'deals','.w-press-reviews-widgets-press-reviews-list .short-description','font-weight','700','','','.w-press-reviews-widgets-press-reviews-list'),(982015,'deals','.w-support-system-filter .filter_cats.level-0 > li > a','font-weight','700','','','.w-support-system-filter'),(982016,'deals','.w-rma-returns-history .column .title','font-weight','normal','','','.w-rma-returns-history'),(982017,'deals','.w-predefined-promotion .heading-3','font-weight','bold','','','.w-predefined-promotion'),(982018,'deals','.w-predefined-promotion .prom-multi-discount .heading','font-weight','300','','','.w-predefined-promotion'),(982019,'deals','.w-predefined-promotion .prom-multi-discount .promo-range .value','font-weight','bold','','','.w-predefined-promotion'),(982020,'deals','.w-predefined-promotion .promo-cart-discount .master .heading','font-weight','300','','','.w-predefined-promotion'),(982021,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty .value','font-weight','bold','','','.w-predefined-promotion'),(982022,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder .value','font-weight','bold','','','.w-predefined-promotion'),(982023,'deals','.w-predefined-promotion .promo-cart-discount .slave .heading','font-weight','300','','','.w-predefined-promotion'),(982024,'deals','.w-predefined-promotion .promo-date','font-weight','500','','','.w-predefined-promotion'),(982025,'deals','.w-predefined-promotion .promo-salemaker .discount .value','font-weight','700','','','.w-predefined-promotion'),(982026,'deals','.w-predefined-promotion .promo-salemaker .promo-conditions','font-weight','300','','','.w-predefined-promotion'),(982027,'deals','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading','font-weight','300','','','.w-predefined-promotion'),(982028,'deals','.parallaxWrap .w-info-page','font-weight','500','','','.parallaxWrap'),(982029,'deals','.w-subscribers h3','font-weight','600','','','.w-subscribers'),(982030,'deals','.preFooter .w-contacts > div','font-weight','500','','','.preFooter'),(982031,'deals','.w-categories .categories h2','font-weight','inherit','','','.w-categories'),(982032,'deals','.b-products-listing .products-listing a.btn.view-button','font-weight','400','3','','.b-products-listing'),(982033,'deals','.w-filters span.open','font-weight','400','','','.w-filters'),(982034,'deals','.w-product-price-from ','font-weight','600','','','.w-product-price-from'),(982035,'deals','.w-product-quantity-discounts .quantity-discounts .heading-4','font-weight','600','','','.w-product-quantity-discounts'),(982036,'deals','.w-product-quantity-discounts .quantity-discounts-content .price','font-weight','700','','','.w-product-quantity-discounts'),(982037,'deals','.bannersWrap .text','font-weight','700','','','.bannersWrap'),(982038,'deals','.w-product-groups .property-category-heading','font-weight','600','','','.w-product-groups'),(982039,'deals','.w-product-name h1','font-weight','600','','','.w-product-name'),(982040,'deals','.b-products-listing .add-to-personal-catalog','font-weight','400','3','','.b-products-listing'),(982041,'deals','.b-products-listing .del-from-personal-catalog','font-weight','400','3','','.b-products-listing'),(982042,'deals','.w-product-quantity-discounts .count','font-weight','700','','','.w-product-quantity-discounts'),(982043,'deals','.w-cart-listing .promotion-cart-message a','font-weight','600','','','.w-cart-listing'),(982044,'deals','.b-table .table .headings td','font-weight','600','','','.b-table'),(982046,'deals','.homeBanner .carousel .bottom-center > span','font-weight','700','','','.homeBanner'),(982047,'deals','.b-products-listing .products-listing .name a','font-weight','600','','','.b-products-listing'),(982048,'deals','.b-info .info strong','font-weight','400','','','.b-info'),(982049,'deals','b, strong','font-weight','600','','',''),(982050,'deals','.heading-3, h3, .h-block h3','font-weight','600','','',''),(982051,'deals','.heading-4, h4, .h-block h4','font-weight','600','','',''),(982055,'deals','.b-sub-totals .historyTotal table tr:last-child td','font-weight','600','5639','','.b-sub-totals'),(982056,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','font-weight','600','5630','','.headerWrap'),(982057,'deals','.w-contact-contacts .contacts .phone strong, .w-contact-contacts .contacts .email strong','font-weight','600','','','.w-contact-contacts'),(982058,'deals','.w-product-wishlist-button .btn','font-weight','700','','','.w-product-wishlist-button'),(982059,'deals','.w-product-wishlist-button .btn','font-weight','normal','3','','.w-product-wishlist-button'),(982060,'deals','.homeBanner .banner-item .banner-text-holder','font-weight','700','','','.homeBanner'),(982061,'deals','.w-cart-discount-coupon .title','font-weight','400','4','','.w-cart-discount-coupon'),(982062,'deals','.w-cart-checkout-btn .with-card','font-weight','400','4','','.w-cart-checkout-btn'),(982063,'deals','.w-promotions-widgets-promotions .promotion-data-2 .save','font-weight','bold','','','.w-promotions-widgets-promotions'),(982070,'deals','.account-address-book .address_book h2','font-weight','normal','','','.account-address-book'),(982077,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','font-weight','normal','3','','.account-order-pay'),(982078,'deals','.account-order-pay .not_fully_paid_td','font-weight','700','','','.account-order-pay'),(982079,'deals','.account-samples .not_fully_paid_td','font-weight','700','','','.account-samples'),(982080,'deals','.account-samples .order_history_table h2','font-weight','normal','','','.account-samples'),(982081,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','font-weight','normal','3','','.account-sample-info'),(982082,'deals','.account-sample-info .not_fully_paid_td','font-weight','700','','','.account-sample-info'),(982083,'deals','.account-sample-info .popup-tracking-number-link','font-weight','600','','','.account-sample-info'),(982084,'deals','.account-sample-info .trackings-nambers-label','font-weight','600','','','.account-sample-info'),(982085,'deals','.catalog-product-wrap .pn-direction','font-weight','600','','','.catalog-product-wrap'),(982086,'deals','.shopping-cart-index .cart-page .empty','font-weight','700','','','.shopping-cart-index'),(982087,'deals','.checkout-index-wrap .cardinfo-label','font-weight','bold','','','.checkout-index-wrap'),(982088,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','font-weight','600','','','.checkout-index-wrap'),(982089,'deals','.checkout-index-wrap .edit-address-popup .edit-ab','font-weight','500','','','.checkout-index-wrap'),(982090,'deals','.success-page .price-box .price-row.total','font-weight','500','','','.success-page'),(982091,'deals','.success-page .price-row.total .price b','font-weight','500','','','.success-page'),(982092,'deals','.success-page .w-cart-listing .name a','font-weight','500','','','.success-page'),(982093,'deals','.success-page .w-cart-listing .price','font-weight','normal','','','.success-page'),(982094,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','font-weight','normal','3','','.b-multi-page-checkout'),(982095,'deals','.b-form .addresses .address-item .edit-ab','font-weight','bold','','','.b-form'),(982096,'deals','.b-sub-totals .historyTotal table tr.ot_total td','font-weight','bold','','','.b-sub-totals'),(982098,'deals','.footer-menu .level-1 > li > a, .footer-menu .level-1 > li > .no-link','font-weight','500','','','.footer-menu'),(982099,'deals','.footer-menu .level-1 > li .no-link','font-weight','normal','5639,3','','.footer-menu'),(982100,'deals','.footer-menu .level-3 > li > a','font-weight','600','5639','','.footer-menu'),(982101,'deals','.footer-menu .level-3 > li.back-button','font-weight','500','5639','','.footer-menu'),(982102,'deals','.w-catalog-paging ','font-weight','700','2','','.w-catalog-paging'),(982107,'deals','.w-menu-slider > ul > li > ul > li > a','font-weight','700','','','.w-menu-slider'),(982108,'deals','.no-found','font_size_measure','em','','',''),(982109,'deals','.w-checkout-create-account .account-benefits','font_size_measure','em','','','.w-checkout-create-account'),(982110,'deals','.view-all .btn','font_size_measure','em','4','',''),(982111,'deals','.price .old','font_size_measure','em','','',''),(982112,'deals','.btn-edit','font_size_measure','em','3','',''),(982113,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','font_size_measure','%','','','.b-select-suggest'),(982114,'deals','.b-select-suggest .select2-search input','font_size_measure','em','','','.b-select-suggest'),(982116,'deals','.w-quote .cart-total','font_size_measure','em','','','.w-quote'),(982117,'deals','.w-quote .qty','font_size_measure','em','4','','.w-quote'),(982119,'deals','.w-sample .cart-total','font_size_measure','em','','','.w-sample'),(982120,'deals','.w-sample .qty','font_size_measure','em','4','','.w-sample'),(982121,'deals','.w-product-bundle .bundle_price .old','font_size_measure','em','','','.w-product-bundle'),(982122,'deals','.w-product-in-bundles .bundle_price .old','font_size_measure','em','','','.w-product-in-bundles'),(982123,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','font_size_measure','em','4','','.b-multi-page-checkout'),(982124,'deals','.w-promotions .prom-multi-discount .list','grid-auto-flow','dense','','','.w-promotions'),(982125,'deals','.w-predefined-promotion .prom-multi-discount .list','grid-auto-flow','dense','','','.w-predefined-promotion'),(982126,'deals','.w-promotions .prom-multi-discount .promo-group-4','grid-column','span 4','','','.w-promotions'),(982127,'deals','.w-promotions .prom-multi-discount .promo-group-2','grid-column','span 2','','','.w-promotions'),(982128,'deals','.w-promotions .prom-multi-discount .promo-group-3','grid-column','span 3','','','.w-promotions'),(982129,'deals','.w-cart-listing .points','grid-column','2 / 5','5630','','.w-cart-listing'),(982130,'deals','.w-cart-listing .item .gift-wrap','grid-column','3 / 4','5630','','.w-cart-listing'),(982131,'deals','.w-cart-listing .name','grid-column','2 / 4','5630','','.w-cart-listing'),(982132,'deals','.w-cart-listing .price','grid-column','3 / 5','5630','','.w-cart-listing'),(982133,'deals','.w-reviews .author','grid-column','2/4','','','.w-reviews'),(982134,'deals','.w-cart-listing .promos-info','grid-column','1 / 2','5630','','.w-cart-listing'),(982135,'deals','.w-reviews-content .rating','grid-column','2','','','.w-reviews-content'),(982136,'deals','.w-reviews-content .date','grid-column','3','','','.w-reviews-content'),(982137,'deals','.w-reviews-content .review','grid-column','2/4','','','.w-reviews-content'),(982138,'deals','.w-reviews .date','grid-column','3','','','.w-reviews'),(982139,'deals','.w-reviews-content .author','grid-column','2/4','','','.w-reviews-content'),(982140,'deals','.w-reviews .product-name','grid-column','2/4','','','.w-reviews'),(982141,'deals','.w-reviews .product-image','grid-column','1','','','.w-reviews'),(982142,'deals','.w-reviews .rating','grid-column','2','','','.w-reviews'),(982143,'deals','.w-reviews .review','grid-column','2/4','','','.w-reviews'),(982144,'deals','.w-reviews-content .product-image','grid-column','1','','','.w-reviews-content'),(982145,'deals','.w-cart-listing .promos-info','grid-column','2 / 3','','','.w-cart-listing'),(982146,'deals','.w-cart-listing .qty','grid-column','4 / 5','','','.w-cart-listing'),(982147,'deals','.w-cart-listing .price','grid-column','5 / 6','','','.w-cart-listing'),(982148,'deals','.w-cart-listing .name','grid-column','3 / 4','','','.w-cart-listing'),(982149,'deals','.w-cart-listing .image','grid-column','2 / 3','','','.w-cart-listing'),(982150,'deals','.w-cart-listing .points','grid-column','4 / 6','','','.w-cart-listing'),(982151,'deals','.w-cart-listing .item .gift-wrap','grid-column','4 / 6','','','.w-cart-listing'),(982152,'deals','.w-cart-listing .actions','grid-column','2 / 6','','','.w-cart-listing'),(982153,'deals','.w-cart-listing .no-price .qty','grid-column','4 / 6','','','.w-cart-listing'),(982154,'deals','.w-reviews-content .product-name','grid-column','2/4','','','.w-reviews-content'),(982155,'deals','.w-cart-listing .image','grid-column','1 / 2','5630','','.w-cart-listing'),(982156,'deals','.w-cart-listing .remove','grid-column','1 / 2','','','.w-cart-listing'),(982157,'deals','.w-cart-listing .item > div.actions','grid-column','1 / 4','5630','','.w-cart-listing'),(982158,'deals','.w-cart-listing .no-price .qty','grid-column','2/4','5639','','.w-cart-listing'),(982159,'deals','.w-sample-products .w-cart-listing .item .qty','grid-column','2 / 4','5630','','.w-sample-products'),(982160,'deals','.w-quote-products .cart-listing .qty','grid-column','4 / 6','','','.w-quote-products'),(982161,'deals','.w-press-reviews-widgets-press-reviews .author','grid-column','2/4','','','.w-press-reviews-widgets-press-reviews'),(982162,'deals','.w-press-reviews-widgets-press-reviews .date','grid-column','3','','','.w-press-reviews-widgets-press-reviews'),(982163,'deals','.w-press-reviews-widgets-press-reviews .image','grid-column','1','','','.w-press-reviews-widgets-press-reviews'),(982164,'deals','.w-press-reviews-widgets-press-reviews .rating','grid-column','2','','','.w-press-reviews-widgets-press-reviews'),(982165,'deals','.w-press-reviews-widgets-press-reviews .review','grid-column','2/4','','','.w-press-reviews-widgets-press-reviews'),(982166,'deals','.w-press-reviews-widgets-press-reviews .title','grid-column','2/4','','','.w-press-reviews-widgets-press-reviews'),(982167,'deals','.w-press-reviews-widgets-press-reviews .author','grid-column','1/2','5630','','.w-press-reviews-widgets-press-reviews'),(982168,'deals','.w-press-reviews-widgets-press-reviews .date','grid-column','1/2','5630','','.w-press-reviews-widgets-press-reviews'),(982169,'deals','.w-press-reviews-widgets-press-reviews .image','grid-column','1/2','5630','','.w-press-reviews-widgets-press-reviews'),(982170,'deals','.w-press-reviews-widgets-press-reviews .rating','grid-column','1/2','5630','','.w-press-reviews-widgets-press-reviews'),(982171,'deals','.w-press-reviews-widgets-press-reviews .review','grid-column','1/2','5630','','.w-press-reviews-widgets-press-reviews'),(982172,'deals','.w-press-reviews-widgets-press-reviews .title','grid-column','1/2','5630','','.w-press-reviews-widgets-press-reviews'),(982173,'deals','.w-predefined-promotion .prom-multi-discount .promo-group-2','grid-column','span 2','','','.w-predefined-promotion'),(982174,'deals','.w-predefined-promotion .prom-multi-discount .promo-group-3','grid-column','span 3','','','.w-predefined-promotion'),(982175,'deals','.w-predefined-promotion .prom-multi-discount .promo-group-4','grid-column','span 4','','','.w-predefined-promotion'),(982176,'deals','.w-cart-listing .item .qty','grid-column','1 / 3','5630','','.w-cart-listing'),(982177,'deals','.w-cart-listing .multi-cart .image','grid-column','1 / 1','','','.w-cart-listing'),(982178,'deals','.w-cart-listing .multi-cart .name','grid-column','2 / 4','','','.w-cart-listing'),(982179,'deals','.w-delivery-options-checkout .w-cart-listing .image','grid-column','1 / 2','','','.w-delivery-options-checkout'),(982180,'deals','.w-account-personal-catalog .buy-box','grid-column','5 / 6','','','.w-account-personal-catalog'),(982181,'deals','.w-account-personal-catalog .check-box','grid-column','1 / 2','','','.w-account-personal-catalog'),(982182,'deals','.w-account-personal-catalog .image','grid-column','2 / 3','','','.w-account-personal-catalog'),(982183,'deals','.w-account-personal-catalog .list-row-action','grid-column','3 / 4','','','.w-account-personal-catalog'),(982184,'deals','.w-account-personal-catalog .name','grid-column','3 / 4','','','.w-account-personal-catalog'),(982185,'deals','.w-account-personal-catalog .price','grid-column','4 / 4','','','.w-account-personal-catalog'),(982186,'deals','.w-account-personal-catalog .qty-input','grid-column','4 / 4','','','.w-account-personal-catalog'),(982187,'deals','.w-account-personal-catalog .remove','grid-column','1 / 2','','','.w-account-personal-catalog'),(982188,'deals','.w-account-personal-catalog .w-cart-listing .item .remove','grid-column','1 / 2','5639','','.w-account-personal-catalog'),(982189,'deals','.w-account-personal-catalog .buy-box','grid-column','3 / 5','5630','','.w-account-personal-catalog'),(982190,'deals','.w-account-personal-catalog .image','grid-column','2 / 2','5630','','.w-account-personal-catalog'),(982191,'deals','.w-account-personal-catalog .list-row-action','grid-column','3 / 5','5630','','.w-account-personal-catalog'),(982192,'deals','.w-account-personal-catalog .name','grid-column','3 / 5','5630','','.w-account-personal-catalog'),(982193,'deals','.w-account-personal-catalog .price','grid-column','4 / 5','5630','','.w-account-personal-catalog'),(982194,'deals','.w-account-personal-catalog .qty-input','grid-column','3 / 3','5630','','.w-account-personal-catalog'),(982195,'deals','.w-account-personal-catalog .remove','grid-column','1 / 2','5630','','.w-account-personal-catalog'),(982196,'deals','.w-account-personal-catalog .price','grid-column','5 / 5','5644','','.w-account-personal-catalog'),(982197,'deals','.order-summary .w-cart-listing .item .name','grid-column','1/2','','','.order-summary'),(982198,'deals','.order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price','grid-column','3/4','','','.order-summary'),(982199,'deals','.order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty','grid-column','2/3','','','.order-summary'),(982200,'deals','.order-summary .w-cart-listing.type-2 .image','grid-column','1 / 3','','','.order-summary'),(982201,'deals','.w-quote-products .w-cart-listing .no-price .qty','grid-column','4/6','5639','','.w-quote-products'),(982202,'deals','.w-quote-products .w-cart-listing .item .qty','grid-column','2 / 4','5630','','.w-quote-products'),(982203,'deals','.success-page .w-cart-listing .image','grid-column','1','','','.success-page'),(982204,'deals','.success-page .w-cart-listing .name','grid-column','2','','','.success-page'),(982205,'deals','.success-page .w-cart-listing .price','grid-column','3','','','.success-page'),(982206,'deals','.success-page .w-cart-listing .qty','grid-column','1','','','.success-page'),(982207,'deals','.success-page .w-cart-listing .sub-product .image','grid-column','1','','','.success-page'),(982208,'deals','.w-banner .banner-image','grid-column','1','','','.w-banner'),(982209,'deals','.w-banner .banner-text','grid-column','1','','','.w-banner'),(982210,'deals','.w-promotions .content','grid-column-end','3','','','.w-promotions'),(982211,'deals','.w-predefined-promotion .content','grid-column-end','3','','','.w-predefined-promotion'),(982212,'deals','.w-promotions .heading','grid-column-start','1','','','.w-promotions'),(982213,'deals','.w-promotions .condition','grid-column-start','2','','','.w-promotions'),(982214,'deals','.w-promotions .content','grid-column-start','1','','','.w-promotions'),(982215,'deals','.w-predefined-promotion .condition','grid-column-start','2','','','.w-predefined-promotion'),(982216,'deals','.w-predefined-promotion .content','grid-column-start','1','','','.w-predefined-promotion'),(982217,'deals','.w-predefined-promotion .heading','grid-column-start','1','','','.w-predefined-promotion'),(982218,'deals','.w-account-personal-catalog .remove','grid-column_important','important','5630','','.w-account-personal-catalog'),(982219,'deals','.w-promotions .prom-multi-discount .products','grid-gap','4px','','','.w-promotions'),(982220,'deals','.w-promotions .prom-multi-discount .list','grid-gap','20px','','','.w-promotions'),(982221,'deals','.w-promotions .nextdiscount .content','grid-gap','3px','','','.w-promotions'),(982222,'deals','.w-predefined-promotion .nextdiscount .content','grid-gap','3px','','','.w-predefined-promotion'),(982223,'deals','.w-predefined-promotion .prom-multi-discount .list','grid-gap','20px','','','.w-predefined-promotion'),(982224,'deals','.w-predefined-promotion .prom-multi-discount .products','grid-gap','4px','','','.w-predefined-promotion'),(982225,'deals','.w-cart-listing .name','grid-row','1 / 2','5630','','.w-cart-listing'),(982226,'deals','.w-cart-listing .promos-info','grid-row','1 / 5','5630','','.w-cart-listing'),(982227,'deals','.w-cart-listing .price','grid-row','5 / 6','5630','','.w-cart-listing'),(982228,'deals','.w-reviews-content .product-name','grid-row','2','','','.w-reviews-content'),(982229,'deals','.w-reviews-content .date','grid-row','1','','','.w-reviews-content'),(982230,'deals','.w-reviews .author','grid-row','4','','','.w-reviews'),(982231,'deals','.w-reviews .date','grid-row','1','','','.w-reviews'),(982232,'deals','.w-reviews-content .author','grid-row','4','','','.w-reviews-content'),(982233,'deals','.w-reviews-content .review','grid-row','3','','','.w-reviews-content'),(982234,'deals','.w-reviews .product-image','grid-row','1/6','','','.w-reviews'),(982235,'deals','.w-reviews .product-name','grid-row','2','','','.w-reviews'),(982236,'deals','.w-reviews .rating','grid-row','1','','','.w-reviews'),(982237,'deals','.w-reviews .review','grid-row','3','','','.w-reviews'),(982238,'deals','.w-reviews-content .rating','grid-row','1','','','.w-reviews-content'),(982239,'deals','.w-reviews-content .product-image','grid-row','1/6','','','.w-reviews-content'),(982240,'deals','.w-cart-listing .remove','grid-row','1 / 6','','','.w-cart-listing'),(982241,'deals','.w-cart-listing .promos-info','grid-row','1 / 6','','','.w-cart-listing'),(982242,'deals','.w-cart-listing .image','grid-row','1 / 6','','','.w-cart-listing'),(982243,'deals','.w-cart-listing .name','grid-row','1 / 5','','','.w-cart-listing'),(982244,'deals','.w-cart-listing .price','grid-row','1 / 2','','','.w-cart-listing'),(982245,'deals','.w-cart-listing .actions','grid-row','3 / 3','','','.w-cart-listing'),(982246,'deals','.w-cart-listing .qty','grid-row','1 / 2','','','.w-cart-listing'),(982247,'deals','.w-cart-listing .image','grid-row','1 / 1','5630','','.w-cart-listing'),(982248,'deals','.w-cart-listing .points','grid-row','2 / 3','5630','','.w-cart-listing'),(982249,'deals','.w-cart-listing .item .remove','grid-row','1/3','5639','','.w-cart-listing'),(982250,'deals','.w-cart-listing .item > div.actions','grid-row','6 / 7','5630','','.w-cart-listing'),(982251,'deals','.w-cart-listing .no-price .qty','grid-row','2/3','5639','','.w-cart-listing'),(982252,'deals','.w-sample-products .w-cart-listing .item .qty','grid-row','2 / 3','5630','','.w-sample-products'),(982253,'deals','.w-account-personal-catalog .w-cart-listing .item .remove','grid-row','3 / 4','5639','','.w-account-personal-catalog'),(982254,'deals','.w-press-reviews-widgets-press-reviews .author','grid-row','4','','','.w-press-reviews-widgets-press-reviews'),(982255,'deals','.w-press-reviews-widgets-press-reviews .date','grid-row','1','','','.w-press-reviews-widgets-press-reviews'),(982256,'deals','.w-press-reviews-widgets-press-reviews .image','grid-row','1/6','','','.w-press-reviews-widgets-press-reviews'),(982257,'deals','.w-press-reviews-widgets-press-reviews .rating','grid-row','1','','','.w-press-reviews-widgets-press-reviews'),(982258,'deals','.w-press-reviews-widgets-press-reviews .review','grid-row','3','','','.w-press-reviews-widgets-press-reviews'),(982259,'deals','.w-press-reviews-widgets-press-reviews .title','grid-row','2','','','.w-press-reviews-widgets-press-reviews'),(982260,'deals','.w-press-reviews-widgets-press-reviews .author','grid-row','6/7','5630','','.w-press-reviews-widgets-press-reviews'),(982261,'deals','.w-press-reviews-widgets-press-reviews .date','grid-row','2/3','5630','','.w-press-reviews-widgets-press-reviews'),(982262,'deals','.w-press-reviews-widgets-press-reviews .image','grid-row','1/2','5630','','.w-press-reviews-widgets-press-reviews'),(982263,'deals','.w-press-reviews-widgets-press-reviews .rating','grid-row','3/4','5630','','.w-press-reviews-widgets-press-reviews'),(982264,'deals','.w-press-reviews-widgets-press-reviews .review','grid-row','5/6','5630','','.w-press-reviews-widgets-press-reviews'),(982265,'deals','.w-press-reviews-widgets-press-reviews .title','grid-row','4/5','5630','','.w-press-reviews-widgets-press-reviews'),(982266,'deals','.w-cart-listing .item .remove','grid-row','2 / 3','5630','','.w-cart-listing'),(982267,'deals','.w-cart-listing .item .qty','grid-row','5 / 6','5630','','.w-cart-listing'),(982268,'deals','.w-cart-listing .multi-cart .image','grid-row','1 / 3','','','.w-cart-listing'),(982269,'deals','.w-cart-listing .multi-cart .name','grid-row','1 / 2','','','.w-cart-listing'),(982270,'deals','.w-account-personal-catalog .buy-box','grid-row','1 / 4','','','.w-account-personal-catalog'),(982271,'deals','.w-account-personal-catalog .check-box','grid-row','1 / 2','','','.w-account-personal-catalog'),(982272,'deals','.w-account-personal-catalog .image','grid-row','1 / 4','','','.w-account-personal-catalog'),(982273,'deals','.w-account-personal-catalog .list-row-action','grid-row','3 / 4','','','.w-account-personal-catalog'),(982274,'deals','.w-account-personal-catalog .name','grid-row','1 / 3','','','.w-account-personal-catalog'),(982275,'deals','.w-account-personal-catalog .price','grid-row','1 / 2','','','.w-account-personal-catalog'),(982276,'deals','.w-account-personal-catalog .qty-input','grid-row','1 / 2','','','.w-account-personal-catalog'),(982277,'deals','.w-account-personal-catalog .remove','grid-row','3 / 4','','','.w-account-personal-catalog'),(982278,'deals','.w-account-personal-catalog .buy-box','grid-row','4 / 4','5630','','.w-account-personal-catalog'),(982279,'deals','.w-account-personal-catalog .image','grid-row','1 / 2','5630','','.w-account-personal-catalog'),(982280,'deals','.w-account-personal-catalog .list-row-action','grid-row','3 / 3','5630','','.w-account-personal-catalog'),(982281,'deals','.w-account-personal-catalog .name','grid-row','1 / 2','5630','','.w-account-personal-catalog'),(982282,'deals','.w-account-personal-catalog .price','grid-row','2 / 2','5630','','.w-account-personal-catalog'),(982283,'deals','.w-account-personal-catalog .qty-input','grid-row','2 / 2','5630','','.w-account-personal-catalog'),(982284,'deals','.w-account-personal-catalog .remove','grid-row','4 / 5','5630','','.w-account-personal-catalog'),(982285,'deals','.w-account-personal-catalog .price','grid-row','1 / 2','5644','','.w-account-personal-catalog'),(982286,'deals','.w-account-personal-catalog .buy-box','grid-row','2 / 4','5644','','.w-account-personal-catalog'),(982287,'deals','.order-summary .w-cart-listing .item .price, .order-summary .w-cart-listing .headings .price','grid-row','1/2','','','.order-summary'),(982288,'deals','.order-summary .w-cart-listing .item .qty, .order-summary .w-cart-listing .headings .qty','grid-row','1/2','','','.order-summary'),(982289,'deals','.w-quote-products .w-cart-listing .no-price .qty','grid-row','1/1','5639','','.w-quote-products'),(982290,'deals','.w-quote-products .w-cart-listing .item .qty','grid-row','2 / 2','5630','','.w-quote-products'),(982291,'deals','.success-page .w-cart-listing .item > div','grid-row','1','','','.success-page'),(982292,'deals','.w-banner .banner-image','grid-row','1','','','.w-banner'),(982293,'deals','.w-banner .banner-item.text-bottom-text .banner-text','grid-row','2','','','.w-banner'),(982294,'deals','.w-banner .banner-text','grid-row','1','','','.w-banner'),(982295,'deals','.w-promotions .content','grid-row-start','2','','','.w-promotions'),(982296,'deals','.w-promotions .condition','grid-row-start','1','','','.w-promotions'),(982297,'deals','.w-promotions .heading','grid-row-start','1','','','.w-promotions'),(982298,'deals','.w-predefined-promotion .condition','grid-row-start','1','','','.w-predefined-promotion'),(982299,'deals','.w-predefined-promotion .content','grid-row-start','2','','','.w-predefined-promotion'),(982300,'deals','.w-predefined-promotion .heading','grid-row-start','1','','','.w-predefined-promotion'),(982301,'deals','.w-account-personal-catalog .remove','grid-row_important','important','5630','','.w-account-personal-catalog'),(982302,'deals','.w-promotions .prom-multi-discount .list','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(982303,'deals','.w-promotions .prom-multi-discount .promo-group-4 .products','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(982304,'deals','.w-promotions .prom-multi-discount .promo-group-3 .products','grid-template-columns','1fr 1fr 1fr','','','.w-promotions'),(982305,'deals','.w-promotions .prom-multi-discount .products','grid-template-columns','1fr','','','.w-promotions'),(982306,'deals','.w-promotions .prom-multi-discount .promo-group-2 .products','grid-template-columns','1fr 1fr','','','.w-promotions'),(982307,'deals','.w-promotions .nextdiscount .content','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-promotions'),(982308,'deals','.w-reviews-content .item','grid-template-columns','170px 1fr 1fr','','','.w-reviews-content'),(982309,'deals','.w-reviews .item','grid-template-columns','140px 1fr 1fr','','','.w-reviews'),(982310,'deals','.w-cart-listing .item','grid-template-columns','40px 80px 1fr 150px 130px','5639','','.w-cart-listing'),(982311,'deals','.w-cart-listing .item','grid-template-columns','80px 70px 1fr','5630','','.w-cart-listing'),(982312,'deals','.w-sample-products .w-cart-listing .item, .w-sample-products .w-cart-listing .headings','grid-template-columns','50px 120px 1fr 150px','','','.w-sample-products'),(982313,'deals','.w-sample-products .w-cart-listing .item, .w-sample-products .w-cart-listing .headings','grid-template-columns','80px 70px 1fr','5630','','.w-sample-products'),(982314,'deals','.w-press-reviews-widgets-press-reviews .item','grid-template-columns','170px 1fr 1fr','','','.w-press-reviews-widgets-press-reviews'),(982315,'deals','.w-press-reviews-widgets-press-reviews .item','grid-template-columns','1fr','5630','','.w-press-reviews-widgets-press-reviews'),(982316,'deals','.w-predefined-promotion .nextdiscount .content','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-predefined-promotion'),(982317,'deals','.w-predefined-promotion .prom-multi-discount .list','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-predefined-promotion'),(982318,'deals','.w-predefined-promotion .prom-multi-discount .products','grid-template-columns','1fr','','','.w-predefined-promotion'),(982319,'deals','.w-predefined-promotion .prom-multi-discount .promo-group-2 .products','grid-template-columns','1fr 1fr','','','.w-predefined-promotion'),(982320,'deals','.w-predefined-promotion .prom-multi-discount .promo-group-3 .products','grid-template-columns','1fr 1fr 1fr','','','.w-predefined-promotion'),(982321,'deals','.w-predefined-promotion .prom-multi-discount .promo-group-4 .products','grid-template-columns','1fr 1fr 1fr 1fr','','','.w-predefined-promotion'),(982322,'deals','.w-cart-listing .item','grid-template-columns','50px 120px 1fr 150px 200px','','','.w-cart-listing'),(982323,'deals','.w-cart-listing .multi-cart .item','grid-template-columns','120px 1fr 150px 200px','','','.w-cart-listing'),(982324,'deals','.w-cart-listing .multi-cart .item','grid-template-columns','80px 1fr 150px 200px','5639','','.w-cart-listing'),(982325,'deals','.w-cart-listing .multi-cart .item','grid-template-columns','80px 1fr 1fr','5660','','.w-cart-listing'),(982326,'deals','.w-delivery-options-checkout .w-cart-listing .item','grid-template-columns','120px 1fr 1fr 1fr','','','.w-delivery-options-checkout'),(982327,'deals','.w-account-personal-catalog .w-cart-listing .item','grid-template-columns','50px 120px 1fr','5639','','.w-account-personal-catalog'),(982328,'deals','.w-account-personal-catalog .w-cart-listing .item','grid-template-columns','50px 120px 1fr 1fr','5630','','.w-account-personal-catalog'),(982329,'deals','.w-account-personal-catalog .w-cart-listing .item','grid-template-columns','50px 120px 1fr 1fr 200px','','','.w-account-personal-catalog'),(982330,'deals','.order-summary .w-cart-listing .headings','grid-template-columns','3fr 1fr 1fr','','','.order-summary'),(982331,'deals','.order-summary .w-cart-listing .item','grid-template-columns','3fr 1fr 1fr','','','.order-summary'),(982332,'deals','.order-summary .w-cart-listing .item','grid-template-columns','1fr','5660','','.order-summary'),(982333,'deals','.success-page .w-cart-listing .item','grid-template-columns','80px 1fr 100px','','','.success-page'),(982334,'deals','.checkout-index-wrap .w-cart-listing .multi-cart .item','grid-template-columns','1fr 50px 100px','','','.checkout-index-wrap'),(982335,'deals','.w-cart-listing .item','grid-template-rows','1fr','5630','','.w-cart-listing'),(982336,'deals','.w-cart-listing .item','grid-template-rows','53px 1fr','','','.w-cart-listing'),(982337,'deals','.w-account-personal-catalog .w-cart-listing .item','grid-template-rows','53px 1fr 1fr','','','.w-account-personal-catalog'),(982338,'deals','.w-account-personal-catalog .w-cart-listing .item','grid-template-rows','1fr','5630','','.w-account-personal-catalog'),(982339,'deals','.order-summary .w-cart-listing .item','grid-template-rows','1fr','','','.order-summary'),(982340,'deals','.checkout-index-wrap .w-cart-listing .multi-cart .item','grid-template-rows','1fr','','','.checkout-index-wrap'),(982341,'deals','.success-page .w-cart-listing .item','grid-template-rows','1fr','','','.success-page'),(982342,'deals','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','height','28','','','.b-switch'),(982343,'deals','.w-product-promotions select','height','29','','','.w-product-promotions'),(982344,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','height','20','3','','.b-switch'),(982345,'deals','.b-email-editor img','height','auto','','','.b-email-editor'),(982346,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.p-quick-order-index'),(982347,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.p-quick-order-index'),(982348,'deals','.w-product-images-additional .item-div','height','80','5660','','.w-product-images-additional'),(982349,'deals','.w-promotions .prom-multi-discount .products','height','calc(100% - 25px)','','','.w-promotions'),(982350,'deals','.w-promotions .prom-multi-discount .image img','height','auto','','','.w-promotions'),(982351,'deals','.w-promotions .promo-salemaker .image img','height','auto','','','.w-promotions'),(982352,'deals','.w-promotions .promo-cart-discount .image img','height','auto','','','.w-promotions'),(982353,'deals','.b-preloader .preloader','height','40','3','','.b-preloader'),(982354,'deals','.b-preloader .preloader','height','100','','','.b-preloader'),(982355,'deals','.b-messages .select2-container-multi input.select2-input','height','31','','','.b-messages'),(982356,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','height','35','','',''),(982357,'deals','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(982358,'deals','.w-product-promotions select','height','29','','','.w-product-promotions'),(982359,'deals','.p-payer-order-confirmation .input-wrapper','height','35','','','.p-payer-order-confirmation'),(982360,'deals','.p-payer-order-pay .input-wrapper','height','35','','','.p-payer-order-pay'),(982361,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','height','15','3','','.b-switch'),(982362,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','height','15','','','.b-switch'),(982363,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','height','15','','','.b-switch'),(982364,'deals','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(982365,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','height','15','','','.b-switch'),(982366,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','height','30','4','','.b-switch'),(982367,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg','height','15','','','.b-switch'),(982368,'deals','.b-fancybox #fancybox-loading div','height','44','','','.b-fancybox'),(982369,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','height','60','','','.b-switch'),(982370,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height','100','3','','.b-switch'),(982371,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-toggle','height','40','','','.b-switch'),(982372,'deals','.w-checkout-shipping-choice input:checked + span:before','height','10','','','.w-checkout-shipping-choice'),(982373,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','height','150','','','.w-upload-customer-id-upload-customer-id-form'),(982374,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file','height','100','','','.w-upload-customer-id-upload-customer-id-form'),(982375,'deals','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(982376,'deals','.b-switch .bootstrap-switch','height','28','','','.b-switch'),(982377,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','height','10','3','','.b-switch'),(982378,'deals','.w-personal-gift-status-bar .progress-bar','height','8','','','.w-personal-gift-status-bar'),(982379,'deals','.w-filters .input-checkbox:checked + .checkbox-span','height','24','','','.w-filters'),(982380,'deals','.b-info-popup .info-popup div','height','20','3','','.b-info-popup'),(982381,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','height','10','','','.b-switch'),(982382,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','height','10','','','.b-switch'),(982383,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','height','15','4','','.b-switch'),(982384,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-toggle','height','15','','','.b-switch'),(982385,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg','height','10','','','.b-switch'),(982386,'deals','.b-form .hide-billing-address','height','100','','','.b-form'),(982387,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','height','16','3','','.b-switch'),(982388,'deals','.b-select-suggest .select2-container .select2-choice abbr','height','12','','','.b-select-suggest'),(982389,'deals','.w-filters .ui-slider-handle','height','18','','','.w-filters'),(982391,'deals','.w-filters .ui-slider','height','6','','','.w-filters'),(982392,'deals','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(982393,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','height','16','','','.b-switch'),(982394,'deals','.b-switch .candlestick-wrapper','height','auto','','','.b-switch'),(982395,'deals','.b-switch .candlestick-wrapper .candlestick-bg','height','28','','','.b-switch'),(982396,'deals','.w-product-images-additional .item','height','80','5660','','.w-product-images-additional'),(982397,'deals','.b-bottom .cart-options .cart-item input[type=\"text\"]','height','33','','','.b-bottom'),(982398,'deals','.b-select-suggest .select2-measure-scrollbar','height','100','','','.b-select-suggest'),(982399,'deals','.b-form .radio-button input[type=\"radio\"].no + span','height','30','3','','.b-form'),(982400,'deals','.b-fancybox .fancybox-close','height','40','','','.b-fancybox'),(982401,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height','1','','','.b-select-suggest'),(982402,'deals','.w-product-images-additional .item','height','80','5660','','.w-product-images-additional'),(982403,'deals','.w-product-images-additional .item-div','height','80','5660','','.w-product-images-additional'),(982404,'deals','.w-product-images-additional .item-div','height','80','5660','','.w-product-images-additional'),(982405,'deals','.b-email-editor img','height','auto','','','.b-email-editor'),(982406,'deals','.w-product-images-additional .item-div','height','80','5660','','.w-product-images-additional'),(982407,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','height','20','','','.b-switch'),(982408,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span','height','18','','','.b-form'),(982409,'deals','.w-product-promotions select','height','29','','','.w-product-promotions'),(982410,'deals','.w-product-promotions select','height','29','','','.w-product-promotions'),(982411,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height','60','','','.b-switch'),(982412,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','height','56','','','.b-switch'),(982413,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height','100','4','','.b-switch'),(982414,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','','','.b-switch'),(982415,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height','60','','','.b-switch'),(982416,'deals','.b-email-editor img','height','auto','','','.b-email-editor'),(982417,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','height','100','','','.b-switch'),(982418,'deals','.b-switch .candlestick-wrapper.candlestick-contents','height','56','','','.b-switch'),(982419,'deals','.w-product-promotions select','height','29','','','.w-product-promotions'),(982420,'deals','.b-fancybox .fancybox-nav','height','100','','','.b-fancybox'),(982421,'deals','.b-select-suggest .select2-container .select2-choice','height','35','','','.b-select-suggest'),(982422,'deals','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(982423,'deals','.w-personal-gift-status-bar .progress-bar-content','height','8','','','.w-personal-gift-status-bar'),(982424,'deals','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(982425,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','height','20','3','','.b-switch'),(982426,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','4','','.b-switch'),(982427,'deals','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(982428,'deals','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(982429,'deals','.b-email-editor img','height','auto','','','.b-email-editor'),(982430,'deals','.w-product-images-additional .item-div','height','80','5660','','.w-product-images-additional'),(982431,'deals','.b-autocomplete .ui-autocomplete','height','300','','','.b-autocomplete'),(982432,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','height','16','','','.b-switch'),(982433,'deals','.b-form .checkbox-style:checked + .checkbox-span','height','18','','','.b-form'),(982434,'deals','.b-info-popup .info-popup','height','2','','','.b-info-popup'),(982435,'deals','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(982436,'deals','.w-product-customers-activity .close','height','30','','','.w-product-customers-activity'),(982437,'deals','.b-email-editor img','height','auto','','','.b-email-editor'),(982438,'deals','.b-social-login .social-login-text-2','height','5','4','','.b-social-login'),(982439,'deals','.w-menu-horizontal .menu-ico','height','54','','','.w-menu-horizontal'),(982440,'deals','.w-product-images-additional .item','height','80','5660','','.w-product-images-additional'),(982441,'deals','.w-product-images-additional .item-div','height','80','5660','','.w-product-images-additional'),(982442,'deals','.w-product-images-additional .item','height','80','5660','','.w-product-images-additional'),(982443,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','height','16','','','.b-switch'),(982444,'deals','.b-select-suggest .select2-search-choice-close','height','13','','','.b-select-suggest'),(982445,'deals','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','height','25','','','.b-datepicker'),(982446,'deals','.b-select-suggest .select2-search input','height','auto','','','.b-select-suggest'),(982447,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height','100','','','.b-select-suggest'),(982448,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow','height','100','','','.b-select-suggest'),(982449,'deals','.b-select-suggest .select2-drop-mask','height','auto','','','.b-select-suggest'),(982450,'deals','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(982451,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','height','30','','','.b-data-table'),(982452,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','height','30','','','.b-data-table'),(982453,'deals','.b-products-listing .btn-preloader','height','24','3','','.b-products-listing'),(982454,'deals','.b-products-listing .hover-box-content','height','20','3','','.b-products-listing'),(982455,'deals','.b-products-listing .loader','height','30','4','','.b-products-listing'),(982456,'deals','.b-products-listing .loader','height','100','3','','.b-products-listing'),(982457,'deals','.b-products-listing .products-listing .qty-input.hidden','height','100','3','','.b-products-listing'),(982458,'deals','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','height','auto','','','.b-products-listing'),(982459,'deals','.checkbox input + span','height','24','','',''),(982460,'deals','.checkbox input:not(checked) + span:before','height','22','','',''),(982461,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','height','20','3','','.b-switch'),(982462,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','height','10','4','','.b-switch'),(982463,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-toggle','height','10','','','.b-switch'),(982464,'deals','.b-email-editor img','height','auto','','','.b-email-editor'),(982465,'deals','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height','100','','','.b-fancybox'),(982466,'deals','.w-product-promotions select','height','29','','','.w-product-promotions'),(982467,'deals','.b-social-login .social-login-text-2','height','5','3','','.b-social-login'),(982468,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','height','36','','','.w-communication-new-topic'),(982469,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','height','36','','','.w-communication-new-topic'),(982470,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','height','30','','','.w-communication-new-topic'),(982471,'deals','.w-communication-new-topic #communication_group_holder select','height','35','','','.w-communication-new-topic'),(982472,'deals','.w-catalog-listing-look .grid','height','35','','','.w-catalog-listing-look'),(982473,'deals','.w-catalog-listing-look .b2b','height','35','','','.w-catalog-listing-look'),(982474,'deals','.w-catalog-listing-look .list','height','35','','','.w-catalog-listing-look'),(982475,'deals','.w-cart-listing .remove-btn','height','30','','','.w-cart-listing'),(982476,'deals','.w-cart-listing .item .remove','height','45','5639','','.w-cart-listing'),(982477,'deals','.b-upload-file .snapshot','height','38','','','.b-upload-file'),(982478,'deals','.w-image-maps .svg-wrap svg','height','100','','','.w-image-maps'),(982479,'deals','.b-fancybox .fancybox-nav span','height','40','','','.b-fancybox'),(982480,'deals','.b-upload-file .upload-file-template','height','150','','','.b-upload-file'),(982481,'deals','.w-filters .ui-slider-range','height','6','','','.w-filters'),(982482,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','height','10','','','.b-switch'),(982483,'deals','.b-bottom .pop-up-close','height','31','','','.b-bottom'),(982484,'deals','.w-product-images-additional .item','height','80','5660','','.w-product-images-additional'),(982485,'deals','.w-product-images-additional .item','height','80','5660','','.w-product-images-additional'),(982486,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg','height','30','','','.b-switch'),(982487,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','height','30','','','.b-switch'),(982488,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','height','30','','','.b-switch'),(982489,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','height','30','3','','.b-switch'),(982490,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','height','30','','','.b-switch'),(982491,'deals','.w-filters .input-checkbox:not(checked) + .checkbox-span','height','24','','','.w-filters'),(982492,'deals','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','height','auto','','','.b-product-images'),(982493,'deals','.b-product-images .media-popup .mp-big-images','height','calc(100vh - 150px)','','','.b-product-images'),(982494,'deals','.b-product-images .media-popup .mp-big-images .item','height','calc(100vh - 150px)','','','.b-product-images'),(982495,'deals','.b-product-images .media-popup .mp-close','height','100','','','.b-product-images'),(982496,'deals','.b-product-images .media-popup .mp-content','height','100','','','.b-product-images'),(982497,'deals','.b-product-images .media-popup .mp-small-images','height','100','','','.b-product-images'),(982498,'deals','.b-product-images .media-popup .mp-small-images .item','height','100','','','.b-product-images'),(982499,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','height','100','','','.b-product-images'),(982500,'deals','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','height','30','','','.b-menu-burger_icon'),(982501,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(982502,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(982503,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(982504,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(982505,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','height','40','','','.b-menu-lev_vis-click_icon'),(982506,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height','100','','','.b-menu-open_from-left'),(982507,'deals','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(982508,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','height','35','','','.b-trade-approval'),(982509,'deals','.w-account-subscription .info-popup','height','15','','','.w-account-subscription'),(982510,'deals','.w-catalog-compare span.btn-preloader','height','24','','','.w-catalog-compare'),(982513,'deals','.b-slick .slick-slide','height','100','','','.b-slick'),(982514,'deals','.b-slick .slick-vertical .slick-slide','height','auto','','','.b-slick'),(982515,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','height','50','','','.b-slick'),(982516,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','height','50','5639','','.b-slick'),(982519,'deals','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','height','18','','','.w-filters'),(982520,'deals','.w-quote .cart-box-link','height','48','3','','.w-quote'),(982521,'deals','.w-quote .cart-box-link','height','40','5639,3','','.w-quote'),(982522,'deals','.w-product-images .additional-vertical','height','400','','','.w-product-images'),(982523,'deals','.w-product-images .img-holder','height','100','','','.w-product-images'),(982524,'deals','.b-quantity .qty-box .bigger','height','50','','','.b-quantity'),(982525,'deals','.b-quantity .qty-box .smaller','height','50','','','.b-quantity'),(982526,'deals','.b-quantity .qty-box input','height','35','','','.b-quantity'),(982527,'deals','.w-product-quantity .qty-box .smaller, .w-product-quantity .qty-box .bigger','height','50','','','.w-product-quantity'),(982528,'deals','.w-product-quantity .qty-input input[type=\'text\']','height','50','','','.w-product-quantity'),(982529,'deals','.warrantyProduct .warranty','height','32','3','','.warrantyProduct'),(982530,'deals','.warrantyProduct .delivery','height','30','3','','.warrantyProduct'),(982531,'deals','.w-sample .cart-box-link','height','10','4','','.w-sample'),(982532,'deals','.w-sample .cart-box-link','height','48','3','','.w-sample'),(982533,'deals','.w-sample .cart-box-link','height','40','5639,3','','.w-sample'),(982534,'deals','.w-catalog-additional-images img','height','auto','','','.w-catalog-additional-images'),(982535,'deals','.w-catalog-additional-images picture','height','150','','','.w-catalog-additional-images'),(982536,'deals','.b-pagination .pagination .next-pages','height','30','','','.b-pagination'),(982537,'deals','.b-pagination .pagination .page-number','height','30','','','.b-pagination'),(982538,'deals','.b-pagination .pagination .prev-pages','height','30','','','.b-pagination'),(982539,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','height','30','','','.b-pagination'),(982540,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','height','30','','','.b-pagination'),(982541,'deals','.b-pagination .pagination span','height','30','2','','.b-pagination'),(982542,'deals','.p-sample-checkout-index .order-summary .heading-2','height','1','3','','.p-sample-checkout-index'),(982543,'deals','.p-sample-checkout-index .order-summary .heading-2','height','1','4','','.p-sample-checkout-index'),(982545,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','height','40','','','.w-questionnaire-widgets-questionnaire'),(982546,'deals','.w-sale-category .badge','height','80','','','.w-sale-category'),(982547,'deals','.w-product-designer-designer .prodDesignerType label','height','78','','','.w-product-designer-designer'),(982548,'deals','.w-product-designer-designer .productDesignerBox input','height','100','','','.w-product-designer-designer'),(982549,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','height','35','','','.w-rma-returns-history'),(982550,'deals','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(982551,'deals','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(982552,'deals','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','height','100','','','.b-menu-position'),(982553,'deals','.w-predefined-promotion .prom-multi-discount .image img','height','auto','','','.w-predefined-promotion'),(982554,'deals','.w-predefined-promotion .prom-multi-discount .products','height','calc(100% - 25px)','','','.w-predefined-promotion'),(982555,'deals','.w-predefined-promotion .promo-cart-discount .image img','height','auto','','','.w-predefined-promotion'),(982556,'deals','.w-predefined-promotion .promo-salemaker .image img','height','auto','','','.w-predefined-promotion'),(982558,'deals','.headerWrap .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','height','auto','','','.headerWrap'),(982559,'deals','.filterLine .w-catalog-sorting .sort-select','height','40','','','.filterLine'),(982560,'deals','.b-quantity .qty-box input[type=\'text\']','height','50','','','.b-quantity'),(982561,'deals','.w-cart-listing .qty-box .bigger, .w-cart-listing .qty-box .smaller','height','30','','','.w-cart-listing'),(982562,'deals','.w-cart-listing .qty-box input[type=\'text\']','height','30','','','.w-cart-listing'),(982563,'deals','.w-support-system-listing .tp-head','height','auto','','','.w-support-system-listing'),(982564,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','height','36','','','.w-account-personal-catalog'),(982565,'deals','.order-summary .icon','height','30','','','.order-summary'),(982566,'deals','.w-promotions-widgets-promotions select','height','29','','','.w-promotions-widgets-promotions'),(982570,'deals','.account-samples .orders-table .td-alignright','height','45','5639','','.account-samples'),(982571,'deals','.catalog-product-wrap .pn-image','height','24','3','','.catalog-product-wrap'),(982572,'deals','.checkout-index-wrap .input-wrapper','height','35','','','.checkout-index-wrap'),(982573,'deals','.b-slick .slick-dots li','height','10','3','','.b-slick'),(982574,'deals','.fake-input','height','0','','',''),(982575,'deals','.hide-page','height','100','','',''),(982576,'deals','.success-page .w-cart-listing .qty','height','24','','','.success-page'),(982577,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-content','height','auto','','','.b-multi-page-checkout'),(982578,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','height','33','','','.b-multi-page-checkout'),(982579,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','height','35','3','','.b-multi-page-checkout'),(982580,'deals','.bannersWrap .rightBanner .banner-text','height','60','','','.bannersWrap'),(982581,'deals','.bannersWrap .rightBanner .banner-text-holder','height','calc(100% - 15%)','','','.bannersWrap'),(982582,'deals','.w-banner .carousel-text','height','100','','','.w-banner'),(982583,'deals','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height','100','','','.w-banner'),(982584,'deals','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height','100','','','.w-banner'),(982585,'deals','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height','100','','','.w-banner'),(982586,'deals','.w-catalog-paging ','height','30','2','','.w-catalog-paging'),(982587,'deals','.w-catalog-paging .next','height','30','','','.w-catalog-paging'),(982588,'deals','.w-catalog-paging .next-pages','height','30','','','.w-catalog-paging'),(982589,'deals','.w-catalog-paging .page-number','height','30','','','.w-catalog-paging'),(982590,'deals','.w-catalog-paging .paging-holder','height','30','','','.w-catalog-paging'),(982591,'deals','.w-catalog-paging .prev','height','30','','','.w-catalog-paging'),(982592,'deals','.w-catalog-paging .prev-pages','height','30','','','.w-catalog-paging'),(982593,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height','30','','','.w-catalog-paging'),(982596,'deals','.w-menu-slider .menu-ico','height','54','','','.w-menu-slider'),(982597,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','height_important','important','','','.b-select-suggest'),(982598,'deals','.b-select-suggest .select2-search input','height_important','important','','','.b-select-suggest'),(982599,'deals','.headerWrap .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','height_important','important','','','.headerWrap'),(982600,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-content','height_important','important','','','.b-multi-page-checkout'),(982601,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','height_important','important','','','.w-catalog-paging'),(982602,'deals','.b-preloader .preloader','height_measure','%','','','.b-preloader'),(982603,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','height_measure','%','3','','.b-switch'),(982604,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file','height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(982605,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','height_measure','%','4','','.b-switch'),(982606,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg','height_measure','%','','','.b-switch'),(982607,'deals','.b-fancybox .fancybox-nav','height_measure','%','','','.b-fancybox'),(982608,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow b','height_measure','%','','','.b-select-suggest'),(982609,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow','height_measure','%','','','.b-select-suggest'),(982610,'deals','.b-products-listing .loader','height_measure','%','3','','.b-products-listing'),(982611,'deals','.b-products-listing .products-listing .qty-input.hidden','height_measure','%','3','','.b-products-listing'),(982612,'deals','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','height_measure','%','','','.b-fancybox'),(982613,'deals','.b-form .hide-billing-address','height_measure','%','','','.b-form'),(982614,'deals','.w-image-maps .svg-wrap svg','height_measure','%','','','.w-image-maps'),(982615,'deals','.b-product-images .media-popup .mp-content','height_measure','vh','','','.b-product-images'),(982616,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','height_measure','vh','','','.b-menu-open_from-left'),(982617,'deals','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(982618,'deals','.b-slick .slick-slide','height_measure','%','','','.b-slick'),(982619,'deals','.w-catalog-listing-look .b2b','height_measure','x','','','.w-catalog-listing-look'),(982620,'deals','.w-product-images .img-holder','height_measure','%','','','.w-product-images'),(982621,'deals','.w-product-designer-designer .productDesignerBox input','height_measure','%','','','.w-product-designer-designer'),(982622,'deals','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(982623,'deals','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(982624,'deals','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','height_measure','%','','','.b-menu-position'),(982625,'deals','.hide-page','height_measure','%','','',''),(982626,'deals','.bannersWrap .rightBanner .banner-text','height_measure','%','','','.bannersWrap'),(982627,'deals','.w-banner .carousel-text','height_measure','%','','','.w-banner'),(982628,'deals','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','height_measure','%','','','.w-banner'),(982629,'deals','.w-banner .image-text-banner.middle-left .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-right .text-banner-1','height_measure','%','','','.w-banner'),(982630,'deals','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','height_measure','%','','','.w-banner'),(982631,'deals','.w-promotions .promo-cart-discount .content','justify-content','center','','','.w-promotions'),(982632,'deals','.w-promotions .prom-multi-discount .products','justify-content','space-between','','','.w-promotions'),(982633,'deals','.w-promotions .promo-salemaker .content','justify-content','center','','','.w-promotions'),(982634,'deals','.b-products-listing .products-listing .attribute-qty-blocks','justify-content','space-between','','','.b-products-listing'),(982635,'deals','.p-quick-order-index .quick-order-total','justify-content','space-between','','','.p-quick-order-index'),(982636,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(982637,'deals','.w-personal-gift-status-bar .timeline','justify-content','center','','','.w-personal-gift-status-bar'),(982638,'deals','.w-checkout-shipping-choice span','justify-content','center','','','.w-checkout-shipping-choice'),(982639,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(982640,'deals','.order-summary .price-row','justify-content','space-between','','','.order-summary'),(982641,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(982642,'deals','.w-communication-post .communication-post-author','justify-content','space-between','','','.w-communication-post'),(982643,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(982644,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(982645,'deals','.b-tracking-numbers .tracking-numbers .tracking-code a','justify-content','space-between','','','.b-tracking-numbers'),(982646,'deals','.b-product-images .media-popup .mp-big-images .item','justify-content','center','','','.b-product-images'),(982647,'deals','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(982648,'deals','.w-catalog-compare .cross-box','justify-content','flex-end','','','.w-catalog-compare'),(982649,'deals','.w-product-images .img-holder','justify-content','center','','','.w-product-images'),(982650,'deals','.w-files-catalog-widgets-files-catalog ','justify-content','space-between','','','.w-files-catalog-widgets-files-catalog'),(982651,'deals','.w-files-catalog-widgets-files-catalog .image','justify-content','center','','','.w-files-catalog-widgets-files-catalog'),(982652,'deals','.w-product-bundle .bundle-products','justify-content','space-between','','','.w-product-bundle'),(982653,'deals','.w-product-in-bundles .bundle-products','justify-content','space-between','','','.w-product-in-bundles'),(982655,'deals','.w-delivery-location-product-categories .categories','justify-content','center','','','.w-delivery-location-product-categories'),(982656,'deals','.w-press-reviews-widgets-press-reviews .review-box','justify-content','center','','','.w-press-reviews-widgets-press-reviews'),(982657,'deals','.w-press-reviews-widgets-press-reviews-list .review-box','justify-content','center','','','.w-press-reviews-widgets-press-reviews-list'),(982658,'deals','.w-rma-returns-history .column','justify-content','space-between','','','.w-rma-returns-history'),(982659,'deals','.w-rma-returns-history .filterMessages','justify-content','space-between','','','.w-rma-returns-history'),(982660,'deals','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul','justify-content','flex-start','','','.b-menu-position'),(982661,'deals','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(982662,'deals','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul','justify-content','center','','','.b-menu-position'),(982663,'deals','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(982664,'deals','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul','justify-content','flex-end','','','.b-menu-position'),(982665,'deals','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','justify-content','center','','','.b-menu-position'),(982666,'deals','.w-predefined-promotion .prom-multi-discount .products','justify-content','space-between','','','.w-predefined-promotion'),(982667,'deals','.w-predefined-promotion .promo-cart-discount .content','justify-content','center','','','.w-predefined-promotion'),(982668,'deals','.w-predefined-promotion .promo-salemaker .content','justify-content','center','','','.w-predefined-promotion'),(982669,'deals','.w-supplier-purchase-supplier-products .item','justify-content','space-between','','','.w-supplier-purchase-supplier-products'),(982670,'deals','.headerWrap .accountMenu >.block','justify-content','space-between','','','.headerWrap'),(982671,'deals','.headerWrap .menuBox >.block','justify-content','flex-end','','','.headerWrap'),(982672,'deals','.headerWrap .RightBox>.block','justify-content','flex-end','','','.headerWrap'),(982673,'deals','.w-top-categories picture','justify-content','center','','','.w-top-categories'),(982674,'deals','.w-categories picture','justify-content','center','','','.w-categories'),(982675,'deals','.w-categories .categories','justify-content','center','','','.w-categories'),(982676,'deals','.w-support-system-listing .support-item-body .support-item-body-image','justify-content','center','','','.w-support-system-listing'),(982678,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons','justify-content','space-between','','','.checkout-index-wrap'),(982679,'deals','.checkout-order-confirmation .price-row','justify-content','space-between','','','.checkout-order-confirmation'),(982680,'deals','.b-form .columns','justify-content','space-between','','','.b-form'),(982681,'deals','.b-slick .slick-dots','justify-content','center','','','.b-slick'),(982682,'deals','.hide-page','justify-content','center','','',''),(982683,'deals','.success-page .order_totals .price-row','justify-content','space-between','','','.success-page'),(982684,'deals','.success-page .price-row','justify-content','space-between','','','.success-page'),(982685,'deals','.w-checkout-totals .price-row','justify-content','space-between','','','.w-checkout-totals'),(982686,'deals','.b-form .formWrapBox','justify-content','space-between','','','.b-form'),(982687,'deals','.bannersWrap .rightBanner .banner-text-holder','justify-content','center','','','.bannersWrap'),(982688,'deals','.w-login-register .middle-form form','justify-content','space-between','','','.w-login-register'),(982689,'deals','.w-login-returning .middle-form form','justify-content','space-between','','','.w-login-returning'),(982690,'deals','.w-product-reviews .middle-form form','justify-content','space-between','','','.w-product-reviews'),(982692,'deals','.w-banner .banner-item.text-bottom-center .banner-text','justify-content','center','','','.w-banner'),(982693,'deals','.w-banner .banner-item.text-bottom-left .banner-text','justify-content','start','','','.w-banner'),(982694,'deals','.w-banner .banner-item.text-bottom-right .banner-text','justify-content','end','','','.w-banner'),(982695,'deals','.w-banner .banner-item.text-middle-center .banner-text','justify-content','center','','','.w-banner'),(982696,'deals','.w-banner .banner-item.text-middle-left .banner-text','justify-content','start','','','.w-banner'),(982697,'deals','.w-banner .banner-item.text-middle-right .banner-text','justify-content','end','','','.w-banner'),(982698,'deals','.w-banner .banner-item.text-top-center .banner-text','justify-content','center','','','.w-banner'),(982699,'deals','.w-banner .banner-item.text-top-left .banner-text','justify-content','start','','','.w-banner'),(982700,'deals','.w-banner .banner-item.text-top-right .banner-text','justify-content','end','','','.w-banner'),(982701,'deals','.w-banner .carousel .bottom-center','justify-content','center','','','.w-banner'),(982702,'deals','.w-banner .carousel .bottom-left','justify-content','flex-start','','','.w-banner'),(982703,'deals','.w-banner .carousel .bottom-right','justify-content','flex-end','','','.w-banner'),(982704,'deals','.w-banner .carousel .middle-center','justify-content','center','','','.w-banner'),(982705,'deals','.w-banner .carousel .middle-left','justify-content','flex-start','','','.w-banner'),(982706,'deals','.w-banner .carousel .middle-right','justify-content','flex-end','','','.w-banner'),(982707,'deals','.w-banner .carousel .top-center','justify-content','center','','','.w-banner'),(982708,'deals','.w-banner .carousel .top-left','justify-content','flex-start','','','.w-banner'),(982709,'deals','.w-banner .carousel .top-right','justify-content','flex-end','','','.w-banner'),(982711,'deals','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(982712,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','left','2','3','','.b-switch'),(982713,'deals','.w-promo-code .holder','left','12','5660,3','','.w-promo-code'),(982714,'deals','.p-quick-order-index .all-scroll-div','left','0','','','.p-quick-order-index'),(982715,'deals','.w-promo-code .holder','left','20','3','','.w-promo-code'),(982716,'deals','.testimonials .heading-3','left','0','3','',''),(982717,'deals','.testimonials .review','left','10','3','',''),(982718,'deals','.b-preloader .preloader','left','calc(50% - 20px)','3','','.b-preloader'),(982719,'deals','.b-preloader .preloader','left','0','','','.b-preloader'),(982720,'deals','.w-checkout-terms .required-message','left','0','','','.w-checkout-terms'),(982721,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','left','15','','','.b-switch'),(982722,'deals','.b-fancybox #fancybox-loading','left','50','','','.b-fancybox'),(982723,'deals','.b-fancybox .fancybox-wrap','left','0','','','.b-fancybox'),(982724,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','left','100','','','.b-switch'),(982725,'deals','.w-promo-code .holder','left','20','3','','.w-promo-code'),(982726,'deals','.w-checkout-shipping-choice input:checked + span:before','left','50','','','.w-checkout-shipping-choice'),(982727,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(982728,'deals','.w-upload-customer-id-upload-customer-id-form .dz-details','left','0','','','.w-upload-customer-id-upload-customer-id-form'),(982729,'deals','.b-info-popup .info-popup div','left','-11','3','','.b-info-popup'),(982730,'deals','.b-fancybox .fancybox-title-over-wrap','left','0','','','.b-fancybox'),(982731,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','left','10','','','.b-switch'),(982732,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','left','20','','','.b-switch'),(982733,'deals','.w-cart-compare .dropdown .dropdown-menu','left','auto','','','.w-cart-compare'),(982734,'deals','.b-select-suggest .select2-measure-scrollbar','left','-10000','','','.b-select-suggest'),(982735,'deals','.b-fancybox .fancybox-tmp','left','-99999','','','.b-fancybox'),(982737,'deals','.b-info-popup .info-popup.top-left div','left','auto','','','.b-info-popup'),(982738,'deals','.b-info-popup .info-popup.top-left div','left','auto','3','','.b-info-popup'),(982739,'deals','.w-promo-code .holder','left','12','5660,3','','.w-promo-code'),(982740,'deals','.w-promo-code .holder','left','20','3','','.w-promo-code'),(982741,'deals','.view-all','left','0','3','',''),(982743,'deals','.b-fancybox .fancybox-overlay','left','0','','','.b-fancybox'),(982745,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left','25','','','.b-switch'),(982746,'deals','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(982747,'deals','.w-multi-cart-actions .dropdown .dropdown-menu','left','0','','','.w-multi-cart-actions'),(982748,'deals','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','left','0','','','.b-switch'),(982750,'deals','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(982751,'deals','.b-select-suggest .select2-drop-mask','left','0','','','.b-select-suggest'),(982752,'deals','.w-reviews .review','left','15','3','','.w-reviews'),(982754,'deals','.b-fancybox .fancybox-prev','left','0','','','.b-fancybox'),(982755,'deals','.b-fancybox .fancybox-prev span','left','10','','','.b-fancybox'),(982757,'deals','.w-promo-code .holder','left','12','5660,3','','.w-promo-code'),(982758,'deals','.w-promo-code .holder','left','20','3','','.w-promo-code'),(982759,'deals','.w-reviews .heading-3','left','0','3','','.w-reviews'),(982760,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','left','2','3','','.b-switch'),(982761,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left','4','3','','.b-switch'),(982762,'deals','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(982763,'deals','.w-reviews-content .review','left','15','3','','.w-reviews-content'),(982764,'deals','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(982765,'deals','.w-promo-code .holder','left','12','5660,3','','.w-promo-code'),(982766,'deals','.b-form .radio-button input[type=\"radio\"].no','left','-100','','','.b-form'),(982768,'deals','.w-checkout-billing-address .addresses .address-item label input','left','0','','','.w-checkout-billing-address'),(982769,'deals','.w-promo-code .holder','left','12','5660,3','','.w-promo-code'),(982770,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','left','0','','','.b-switch'),(982771,'deals','.b-select-suggest .select2-container-multi .select2-search-choice-close','left','3','','','.b-select-suggest'),(982772,'deals','.w-menu-horizontal > ul > li > ul','left','0','','','.w-menu-horizontal'),(982773,'deals','.w-checkout-shipping-address .addresses .address-item label input','left','0','','','.w-checkout-shipping-address'),(982775,'deals','.w-image-maps .svg-wrap svg','left','0','','','.w-image-maps'),(982776,'deals','.b-products-listing .products-listing .promos-info','left','0','','','.b-products-listing'),(982777,'deals','.b-products-listing .hover-box-content','left','0','','','.b-products-listing'),(982778,'deals','.b-products-listing .hover-box-content','left','20','3','','.b-products-listing'),(982779,'deals','.b-products-listing .loader','left','calc(50% - 15px)','4','','.b-products-listing'),(982780,'deals','.b-products-listing .loader','left','0','3','','.b-products-listing'),(982781,'deals','.w-catalog-b2b-add-button ','left','0','','','.w-catalog-b2b-add-button'),(982782,'deals','.b-products-listing .products-listing .qty-input.hidden','left','0','3','','.b-products-listing'),(982783,'deals','.b-products-listing .promo','left','0','','','.b-products-listing'),(982784,'deals','.checkbox input','left','-20','','',''),(982786,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left','0','','','.b-select-suggest'),(982787,'deals','.w-promo-code .holder','left','20','3','','.w-promo-code'),(982788,'deals','.w-promo-code .holder','left','20','3','','.w-promo-code'),(982789,'deals','.w-promo-code .holder','left','12','5660,3','','.w-promo-code'),(982790,'deals','.w-cart-listing .item .remove','left','0','5639','','.w-cart-listing'),(982791,'deals','.w-cart-listing .remove-btn','left','10','5639','','.w-cart-listing'),(982792,'deals','.w-cart-listing .remove-btn span','left','5','5639','','.w-cart-listing'),(982794,'deals','.b-info-popup .info-popup div','left','40','','','.b-info-popup'),(982795,'deals','.w-product-reviews .reviews-list .review','left','10','3','','.w-product-reviews'),(982796,'deals','.b-dropdown .dropdown .dropdown-menu','left','0','','','.b-dropdown'),(982797,'deals','.b-form .hide-billing-address','left','0','','','.b-form'),(982798,'deals','.w-menu-big > ul > li > ul','left','0','','','.w-menu-big'),(982799,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','left','40','','','.b-switch'),(982800,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','left','0','','','.w-image-maps'),(982801,'deals','.b-product-images .mp-shadow, .b-product-images .media-popup','left','0','','','.b-product-images'),(982802,'deals','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','left','0','','','.b-menu-lev_display-down'),(982803,'deals','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','left','0','','','.b-menu-lev_display-down'),(982804,'deals','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','left','0','','','.b-menu-lev_display-down'),(982805,'deals','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','left','0','','','.b-menu-lev_display-down'),(982806,'deals','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','left','0','','','.b-menu-lev_display-down'),(982807,'deals','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left','100','','','.b-menu-lev_display-lra'),(982808,'deals','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left','100','','','.b-menu-lev_display-lra'),(982809,'deals','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left','100','','','.b-menu-lev_display-lra'),(982810,'deals','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left','100','','','.b-menu-lev_display-lra'),(982811,'deals','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left','100','','','.b-menu-lev_display-lra'),(982812,'deals','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','left','auto','','','.b-menu-lev_display-lra'),(982813,'deals','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','left','auto','','','.b-menu-lev_display-lra'),(982814,'deals','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','left','auto','','','.b-menu-lev_display-lra'),(982815,'deals','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','left','auto','','','.b-menu-lev_display-lra'),(982816,'deals','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','left','auto','','','.b-menu-lev_display-lra'),(982817,'deals','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left','100','','','.b-menu-lev_display-right'),(982818,'deals','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left','100','','','.b-menu-lev_display-right'),(982819,'deals','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left','100','','','.b-menu-lev_display-right'),(982820,'deals','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left','100','','','.b-menu-lev_display-right'),(982821,'deals','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left','100','','','.b-menu-lev_display-right'),(982822,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left','100','','','.b-menu-lev_display-slide'),(982823,'deals','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left','100','','','.b-menu-lev_display-slide'),(982824,'deals','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left','100','','','.b-menu-lev_display-slide'),(982825,'deals','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left','100','','','.b-menu-lev_display-slide'),(982826,'deals','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left','100','','','.b-menu-lev_display-slide'),(982827,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left','-110','','','.b-menu-open_from-left'),(982828,'deals','.b-menu-open_from-left .bi-opened .menu-style[data-open_from=\"left\"] .menu-content','left','0','','','.b-menu-open_from-left'),(982829,'deals','.b-slick .slick-track','left','0','','','.b-slick'),(982830,'deals','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left','50','','','.b-slick'),(982831,'deals','.b-slick button.slick-next','left','auto','','','.b-slick'),(982832,'deals','.b-slick button.slick-prev','left','0','','','.b-slick'),(982833,'deals','.w-quote .multicart .switch-cart','left','15','','','.w-quote'),(982834,'deals','.warrantyProduct .warranty','left','0','3','','.warrantyProduct'),(982835,'deals','.warrantyProduct .delivery','left','0','3','','.warrantyProduct'),(982836,'deals','.w-compare ','left','0','','','.w-compare'),(982837,'deals','.w-sample .multicart .switch-cart','left','15','','','.w-sample'),(982838,'deals','.p-sample-checkout-index .order-summary .heading-2','left','-14','3','','.p-sample-checkout-index'),(982839,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input','left','-50','','','.w-questionnaire-widgets-questionnaire'),(982840,'deals','.w-sale-category .badge','left','10','','','.w-sale-category'),(982841,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content:before','left','25','','','.w-product-properties-icons'),(982842,'deals','.w-product-bonus-points > div > div','left','10','3','','.w-product-bonus-points'),(982843,'deals','.w-product-designer-designer .productDesignerBox input','left','0','','','.w-product-designer-designer'),(982844,'deals','.w-product-configurator .pc-item label input','left','0','','','.w-product-configurator'),(982845,'deals','.homeBanner .carousel .bottom-center > span','left','0','3','','.homeBanner'),(982846,'deals','.w-account-personal-catalog .w-cart-listing .remove-btn','left','0','5639','','.w-account-personal-catalog'),(982847,'deals','.p-wedding-registry-view h1','left','-10','3','','.p-wedding-registry-view'),(982848,'deals','.w-product-wishlist-button .btn','left','0','3','','.w-product-wishlist-button'),(982849,'deals','.homeBanner .text-bottom-center .banner-text-holder','left','0','3','','.homeBanner'),(982850,'deals','.homeBanner .text-bottom-left .banner-text-holder','left','0','3','','.homeBanner'),(982851,'deals','.homeBanner .text-bottom-right .banner-text-holder','left','0','3','','.homeBanner'),(982858,'deals','.account-address-book .buttonBox .info','left','-6','3','','.account-address-book'),(982866,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','left','1','3','','.account-order-pay'),(982867,'deals','.account-order-pay .historyInfoColumn h2.title-delivery-address, .account-order-pay .historyInfoColumn h2.title-billing-address','left','10','3','','.account-order-pay'),(982868,'deals','.account-order-pay .historyInfoColumn h2.title-payment','left','10','3','','.account-order-pay'),(982869,'deals','.account-order-pay .not_fully_paid_td','left','15','','','.account-order-pay'),(982870,'deals','.account-samples .not_fully_paid_td','left','15','','','.account-samples'),(982871,'deals','.account-samples .orders-table .status-name','left','0','5639','','.account-samples'),(982872,'deals','.account-samples .orders-table .td-alignright','left','0','5639','','.account-samples'),(982873,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','left','1','3','','.account-sample-info'),(982874,'deals','.account-sample-info .historyInfoColumn h2.title-delivery-address, .account-sample-info .historyInfoColumn h2.title-billing-address','left','10','3','','.account-sample-info'),(982875,'deals','.account-sample-info .historyInfoColumn h2.title-payment','left','10','3','','.account-sample-info'),(982876,'deals','.account-sample-info .not_fully_paid_td','left','15','','','.account-sample-info'),(982877,'deals','.catalog-product-wrap .prev-product','left','0','','','.catalog-product-wrap'),(982878,'deals','.catalog-product-wrap .prev-product .pn-image','left','20','3','','.catalog-product-wrap'),(982879,'deals','.b-form .addresses .address-item input[type=\"radio\"]','left','0','','','.b-form'),(982880,'deals','.hide-page','left','0','','',''),(982881,'deals','.success-page .w-cart-listing .qty','left','60','','','.success-page'),(982884,'deals','.w-banner .banner img + img','left','0','','','.w-banner'),(982885,'deals','.w-banner .carousel-text','left','0','','','.w-banner'),(982886,'deals','.w-banner .image-text-banner.bottom-left .text-banner','left','0','','','.w-banner'),(982887,'deals','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','left','0','','','.w-banner'),(982888,'deals','.w-banner .image-text-banner.top-left .text-banner','left','0','','','.w-banner'),(982891,'deals','.w-menu-slider > ul > li > ul','left','0','','','.w-menu-slider'),(982892,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','left_important','important','','','.b-select-suggest'),(982893,'deals','.b-form .radio-button input[type=\"radio\"].no','left_measure','vw','','','.b-form'),(982894,'deals','.b-fancybox #fancybox-loading','left_measure','%','','','.b-fancybox'),(982895,'deals','.w-checkout-shipping-choice input:checked + span:before','left_measure','%','','','.w-checkout-shipping-choice'),(982896,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','left_measure','%','','','.b-switch'),(982897,'deals','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','left_measure','%','','','.b-menu-lev_display-lra'),(982898,'deals','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','left_measure','%','','','.b-menu-lev_display-lra'),(982899,'deals','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','left_measure','%','','','.b-menu-lev_display-lra'),(982900,'deals','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','left_measure','%','','','.b-menu-lev_display-lra'),(982901,'deals','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','left_measure','%','','','.b-menu-lev_display-lra'),(982902,'deals','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','left_measure','%','','','.b-menu-lev_display-right'),(982903,'deals','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','left_measure','%','','','.b-menu-lev_display-right'),(982904,'deals','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','left_measure','%','','','.b-menu-lev_display-right'),(982905,'deals','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','left_measure','%','','','.b-menu-lev_display-right'),(982906,'deals','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','left_measure','%','','','.b-menu-lev_display-right'),(982907,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','left_measure','vw','','','.b-menu-lev_display-slide'),(982908,'deals','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','left_measure','vw','','','.b-menu-lev_display-slide'),(982909,'deals','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','left_measure','vw','','','.b-menu-lev_display-slide'),(982910,'deals','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','left_measure','vw','','','.b-menu-lev_display-slide'),(982911,'deals','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','left_measure','vw','','','.b-menu-lev_display-slide'),(982912,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','left_measure','vw','','','.b-menu-open_from-left'),(982913,'deals','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','left_measure','%','','','.b-slick'),(982914,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content:before','left_measure','%','','','.w-product-properties-icons'),(982917,'deals','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','line-height','1.2','','','.w-communication-new-topic'),(982918,'deals','.b-info-popup .info-popup div','line-height','30','3','','.b-info-popup'),(982919,'deals','.b-form .shipping-method .sub-title','line-height','1.3','','','.b-form'),(982920,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','line-height','12','','','.b-switch'),(982921,'deals','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line-height','30','','','.b-switch'),(982922,'deals','.w-tabs .tab-li.tab-cart a','line-height','0.75','3','','.w-tabs'),(982923,'deals','.message.success','line-height','1','3','',''),(982924,'deals','.heading-4 .edit, h4 .edit','line-height','20','','',''),(982925,'deals','.w-socials .post_item > div','line-height','19','','','.w-socials'),(982926,'deals','.p-quick-order-index .paginate_button.previous','line-height','26','3','','.p-quick-order-index'),(982927,'deals','.p-quick-order-index .paginate_button.next','line-height','26','3','','.p-quick-order-index'),(982928,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.p-quick-order-index'),(982929,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.p-quick-order-index'),(982931,'deals','.w-promotions .prom-multi-discount .promo-range','line-height','23','','','.w-promotions'),(982932,'deals','.w-quote .cart-box-link','line-height','40','5639,3','','.w-quote'),(982933,'deals','.testimonials .heading-3','line-height','1','3','',''),(982934,'deals','.w-promotions .heading-3','line-height','1','','','.w-promotions'),(982935,'deals','.w-promotions .promo-salemaker .discount','line-height','23','','','.w-promotions'),(982936,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','line-height','23','','','.w-promotions'),(982937,'deals','.w-promotions .promo-cart-discount .promo-min-qty','line-height','23','','','.w-promotions'),(982938,'deals','.b-preloader .preloader','line-height','40','3','','.b-preloader'),(982939,'deals','.w-cart-compare .attributes-cell','line-height','22','','','.w-cart-compare'),(982940,'deals','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(982941,'deals','.b-bottom .closeable-heading','line-height','1.8','3','','.b-bottom'),(982942,'deals','.b-messages .messBtnMenuDelete','line-height','10','3','','.b-messages'),(982943,'deals','.b-messages span.starred::before','line-height','10','','','.b-messages'),(982944,'deals','.b-messages .messBtnMenuStarred','line-height','10','3','','.b-messages'),(982945,'deals','.b-messages .messBtnMenuUnread','line-height','10','3','','.b-messages'),(982946,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line-height','14','','','.b-messages'),(982947,'deals','.w-quote .cart-box-link','line-height','48','3','','.w-quote'),(982948,'deals','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(982949,'deals','.w-socials .post_item > div','line-height','19','','','.w-socials'),(982950,'deals','.p-payer-order-confirmation .ship-ico','line-height','20','3','','.p-payer-order-confirmation'),(982951,'deals','.p-payer-order-confirmation .order-ico','line-height','20','3','','.p-payer-order-confirmation'),(982952,'deals','.p-payer-order-confirmation .pay-ico','line-height','20','3','','.p-payer-order-confirmation'),(982953,'deals','.p-payer-order-confirmation .discount-ico','line-height','20','3','','.p-payer-order-confirmation'),(982954,'deals','.p-payer-order-confirmation .comment-ico','line-height','20','3','','.p-payer-order-confirmation'),(982955,'deals','.p-payer-order-pay .ship-ico','line-height','20','3','','.p-payer-order-pay'),(982956,'deals','.p-payer-order-pay .pay-ico','line-height','20','3','','.p-payer-order-pay'),(982957,'deals','.p-payer-order-pay .order-ico','line-height','20','3','','.p-payer-order-pay'),(982958,'deals','.p-payer-order-pay .discount-ico','line-height','20','3','','.p-payer-order-pay'),(982959,'deals','.p-payer-order-pay .comment-ico','line-height','20','3','','.p-payer-order-pay'),(982960,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','line-height','15','','','.b-switch'),(982961,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','line-height','15','','','.b-switch'),(982962,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','line-height','15','','','.b-switch'),(982963,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','line-height','56','4','','.b-switch'),(982964,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','line-height','16','','','.b-switch'),(982965,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','line-height','10','','','.b-switch'),(982966,'deals','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','line-height','1.2','','','.p-quick-order-index'),(982967,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','line-height','15','','','.b-switch'),(982968,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','line-height','10','','','.b-switch'),(982969,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','line-height','10','','','.b-switch'),(982970,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','line-height','12','','','.b-switch'),(982971,'deals','.bell-ico .heading-2','line-height','10','3','','.bell-ico'),(982973,'deals','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(982974,'deals','.w-tabs .tab-li.tab-sample a','line-height','0.75','3','','.w-tabs'),(982975,'deals','.w-cart-compare .compare-table','line-height','1.3','','','.w-cart-compare'),(982976,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line-height','18','','','.b-form'),(982977,'deals','.w-checkout-shipping-choice span','line-height','19','','','.w-checkout-shipping-choice'),(982978,'deals','.w-socials .post_item > div','line-height','19','','','.w-socials'),(982979,'deals','.b-info-popup .info-popup div','line-height','1.7','','','.b-info-popup'),(982980,'deals','.w-checkout-shipping-address .addresses .address-item label','line-height','1.3','','','.w-checkout-shipping-address'),(982981,'deals','.w-tabs .tab-li.tab-wishlist a','line-height','0.75','3','','.w-tabs'),(982983,'deals','.w-socials .post_item > div','line-height','19','','','.w-socials'),(982984,'deals','.b-info-popup .info-popup','line-height','2','','','.b-info-popup'),(982986,'deals','.btn-2','line-height','20','','',''),(982987,'deals','.w-cart-compare .delete-cart','line-height','1','','','.w-cart-compare'),(982989,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span','line-height','22','','','.b-form'),(982990,'deals','.w-filters .input-checkbox:checked + .checkbox-span:before','line-height','22','','','.w-filters'),(982991,'deals','.heading-3 .right-text, h3 .right-text','line-height','20','','',''),(982992,'deals','.heading-3 .edit, h3 .edit','line-height','20','','',''),(982993,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','line-height','56','4','','.b-switch'),(982994,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','line-height','56','4','','.b-switch'),(982996,'deals','.b-fancybox .fancybox-title-float-wrap .child','line-height','24','','','.b-fancybox'),(982997,'deals','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(982998,'deals','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(982999,'deals','.w-socials .post_item > div','line-height','19','','','.w-socials'),(983000,'deals','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(983001,'deals','.btn','line-height','20','','',''),(983002,'deals','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(983004,'deals','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(983005,'deals','.w-reviews .heading-3','line-height','1','3','','.w-reviews'),(983006,'deals','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(983007,'deals','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(983008,'deals','.p-quick-order-index .stock','line-height','1.2','','','.p-quick-order-index'),(983009,'deals','.b-form .checkbox-style:checked + .checkbox-span:before','line-height','18','','','.b-form'),(983010,'deals','.w-cart-listing .links','line-height','35','','','.w-cart-listing'),(983011,'deals','.price .old','line-height','0.6','','',''),(983012,'deals','.w-cart-compare .price-cell','line-height','22','','','.w-cart-compare'),(983013,'deals','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(983014,'deals','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(983015,'deals','.w-multi-cart-cart-switcher .cart-label','line-height','20','','','.w-multi-cart-cart-switcher'),(983016,'deals','.b-bottom .pop-up-close','line-height','25','','','.b-bottom'),(983017,'deals','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(983018,'deals','.w-tabs .tab-li.tab-quote a','line-height','0.75','3','','.w-tabs'),(983019,'deals','.b-fancybox .fancybox-close','line-height','40','','','.b-fancybox'),(983020,'deals','.b-form .form-inputs div.required-message','line-height','1.3','','','.b-form'),(983021,'deals','.w-product-customers-activity .close','line-height','32','','','.w-product-customers-activity'),(983022,'deals','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(983023,'deals','.w-checkout-billing-address .addresses .address-item label','line-height','1.3','','','.w-checkout-billing-address'),(983025,'deals','.w-cart-compare .cart-name a','line-height','1.2','','','.w-cart-compare'),(983026,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line-height','13','','','.b-select-suggest'),(983027,'deals','.b-switch .bootstrap-switch','line-height','28','','','.b-switch'),(983028,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line-height','30','','','.b-data-table'),(983029,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line-height','30','','','.b-data-table'),(983030,'deals','.b-products-listing .products-listing .name a','line-height','1.5','','','.b-products-listing'),(983031,'deals','.b-products-listing .btn-preloader','line-height','24','3','','.b-products-listing'),(983032,'deals','.b-products-listing .loader','line-height','30','4','','.b-products-listing'),(983033,'deals','.b-products-listing .products-listing .btn-buy','line-height','10','3','','.b-products-listing'),(983034,'deals','.checkbox input:not(checked) + span:before','line-height','24','','',''),(983037,'deals','.b-select-suggest .select2-container .select2-choice','line-height','26','','','.b-select-suggest'),(983038,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','line-height','10','','','.b-switch'),(983039,'deals','.b-tracking-numbers .tracking-numbers th','line-height','1.3','','','.b-tracking-numbers'),(983040,'deals','.w-socials .post_item > div','line-height','19','','','.w-socials'),(983041,'deals','.order-summary .price-row.ot_coupon .title','line-height','22','3','','.order-summary'),(983042,'deals','.heading-4 .right-text, h4 .right-text','line-height','20','','',''),(983043,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','40','','','.w-communication-new-topic'),(983044,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line-height','35','3','','.w-communication-new-topic'),(983045,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line-height','36','','','.w-communication-new-topic'),(983046,'deals','.btn-3','line-height','20','','',''),(983047,'deals','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(983048,'deals','.b-form .radio-button input[type=\"radio\"].no + span','line-height','30','3','','.b-form'),(983049,'deals','.w-promo-code .holder','line-height','80','3','','.w-promo-code'),(983050,'deals','.b-form .cart-popup .price','line-height','35','','','.b-form'),(983051,'deals','.w-menu-horizontal .menu-ico','line-height','54','','','.w-menu-horizontal'),(983052,'deals','.w-catalog-listing-look .grid','line-height','35','','','.w-catalog-listing-look'),(983053,'deals','.w-catalog-listing-look .b2b','line-height','35','','','.w-catalog-listing-look'),(983054,'deals','.w-catalog-listing-look .list','line-height','35','','','.w-catalog-listing-look'),(983055,'deals','.w-cart-listing .item .attributes','line-height','1.7','','','.w-cart-listing'),(983056,'deals','.w-cart-listing .points-earn','line-height','1','','','.w-cart-listing'),(983057,'deals','.w-cart-listing .points-redeem','line-height','1','','','.w-cart-listing'),(983058,'deals','.w-cart-listing .remove-btn','line-height','30','','','.w-cart-listing'),(983059,'deals','.b-tracking-numbers .tracking-numbers td','line-height','1.3','','','.b-tracking-numbers'),(983060,'deals','.b-fancybox .fancybox-nav span','line-height','40','','','.b-fancybox'),(983061,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','line-height','30','','','.b-switch'),(983062,'deals','.w-checkout-create-account .account-benefits strong','line-height','16','3','','.w-checkout-create-account'),(983063,'deals','.w-cart-compare .js-cart_totals_container','line-height','1.2','','','.w-cart-compare'),(983064,'deals','.btn-1','line-height','20','','',''),(983065,'deals','.b-products-listing .products-listing .btn-preloader','line-height','8','','','.b-products-listing'),(983066,'deals','.price .special','line-height','0.8','','',''),(983067,'deals','.b-data-table table.dataTable thead td','line-height','1.5','','','.b-data-table'),(983068,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','line-height','30','','','.b-switch'),(983069,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','line-height','30','','','.b-switch'),(983070,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','line-height','30','','','.b-switch'),(983071,'deals','.w-filters .input-checkbox:not(checked) + .checkbox-span','line-height','22','','','.w-filters'),(983072,'deals','.b-upload-file .snapshot','line-height','38','','','.b-upload-file'),(983073,'deals','.b-product-images .media-popup .mp-close','line-height','100','','','.b-product-images'),(983074,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','line-height','100','','','.b-product-images'),(983075,'deals','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line-height','30','','','.b-menu-burger_icon'),(983076,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(983077,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(983078,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(983079,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(983080,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line-height','40','','','.b-menu-lev_vis-click_icon'),(983081,'deals','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','line-height','1.3','','','.b-trade-approval'),(983082,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line-height','24','3','','.w-catalog-compare'),(983083,'deals','.w-catalog-compare td','line-height','1.5','','','.w-catalog-compare'),(983084,'deals','.w-catalog-compare span.btn-preloader','line-height','24','3','','.w-catalog-compare'),(983085,'deals','.w-delivery-day .ends','line-height','1','','','.w-delivery-day'),(983087,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','52','','','.b-slick'),(983088,'deals','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line-height','36','','','.b-slick'),(983089,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','line-height','48','5639','','.b-slick'),(983092,'deals','.w-social-links a','line-height','1','','','.w-social-links'),(983093,'deals','.b-quantity .qty-box .bigger','line-height','50','','','.b-quantity'),(983094,'deals','.b-quantity .qty-box .smaller','line-height','50','','','.b-quantity'),(983095,'deals','.w-product-sale-ends .ends','line-height','1','','','.w-product-sale-ends'),(983096,'deals','.warrantyProduct .title','line-height','1.2','','','.warrantyProduct'),(983097,'deals','.warrantyProduct .seeDetails','line-height','1.2','','','.warrantyProduct'),(983098,'deals','.w-sample .cart-box-link','line-height','48','3','','.w-sample'),(983099,'deals','.w-sample .cart-box-link','line-height','40','5639,3','','.w-sample'),(983100,'deals','.w-cart-bonus-points .title','line-height','1','','','.w-cart-bonus-points'),(983101,'deals','.w-cart-gift-certificate .gift-certificate .heading-4','line-height','16','3','','.w-cart-gift-certificate'),(983103,'deals','.b-pagination .pagination .next-pages','line-height','30','','','.b-pagination'),(983104,'deals','.b-pagination .pagination .page-number','line-height','30','','','.b-pagination'),(983105,'deals','.b-pagination .pagination .prev-pages','line-height','30','','','.b-pagination'),(983106,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','line-height','30','','','.b-pagination'),(983107,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','line-height','26','3','','.b-pagination'),(983108,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','line-height','30','','','.b-pagination'),(983109,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','line-height','26','3','','.b-pagination'),(983110,'deals','.b-pagination .pagination span','line-height','30','2','','.b-pagination'),(983111,'deals','.w-product-properties-filters-widgets-chosen-filters .remove','line-height','10','3','','.w-product-properties-filters-widgets-chosen-filters'),(983112,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','line-height','36','','','.w-questionnaire-widgets-questionnaire'),(983113,'deals','.w-product-custom-bundle .right-area .price','line-height','1.2','','','.w-product-custom-bundle'),(983114,'deals','.b-products-listing .products-listing.list-productlisting .attribute-qty-block > span','line-height','1.15','','','.b-products-listing'),(983115,'deals','.w-delivery-location-location-list .deliveryListParrent a','line-height','1.5','','','.w-delivery-location-location-list'),(983116,'deals','.w-sale-category .badge','line-height','27','','','.w-sale-category'),(983117,'deals','.w-sale-category .ends','line-height','1','','','.w-sale-category'),(983118,'deals','.w-sale-category .name','line-height','1.2','','','.w-sale-category'),(983119,'deals','.w-sale-category .old','line-height','0.8','','','.w-sale-category'),(983120,'deals','.w-sale-category .special-price','line-height','0.8','','','.w-sale-category'),(983121,'deals','.w-product-bonus-points .bonus-points-cost','line-height','1.2','','','.w-product-bonus-points'),(983122,'deals','.b-products-listing .productGroup label a','line-height','1','','','.b-products-listing'),(983123,'deals','.w-rma-returns-history .column .title','line-height','16','','','.w-rma-returns-history'),(983124,'deals','.b-products-listing .products-listing .bonus-points-cost','line-height','1.2','','','.b-products-listing'),(983125,'deals','.w-predefined-promotion .heading-3','line-height','1','','','.w-predefined-promotion'),(983126,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','line-height','23','','','.w-predefined-promotion'),(983127,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','line-height','23','','','.w-predefined-promotion'),(983128,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','line-height','23','','','.w-predefined-promotion'),(983129,'deals','.w-predefined-promotion .promo-salemaker .discount','line-height','23','','','.w-predefined-promotion'),(983130,'deals','.w-supplier-purchase-supplier-products .active .select_item > div','line-height','28','','','.w-supplier-purchase-supplier-products'),(983134,'deals','.headerWrap .w-contacts.phone','line-height','1','3','','.headerWrap'),(983135,'deals','.bannersWrap .text','line-height','1.3','','','.bannersWrap'),(983136,'deals','.w-filters span.open','line-height','1','','','.w-filters'),(983138,'deals','.w-breadcrumb .breadcrumb-li','line-height','24','','','.w-breadcrumb'),(983139,'deals','.messageBox .info','line-height','1','3','',''),(983140,'deals','.w-cart-listing .qty-box .bigger, .w-cart-listing .qty-box .smaller','line-height','30','','','.w-cart-listing'),(983141,'deals','.w-support-system-listing .tp-head','line-height','1.5','','','.w-support-system-listing'),(983142,'deals','.b-table-list .table-list th','line-height','1.5','','','.b-table-list'),(983143,'deals','.b-info .info','line-height','1','3','','.b-info'),(983144,'deals','.b-sub-totals .historyTotal table td','line-height','1.6','5639','','.b-sub-totals'),(983145,'deals','.w-product-personal-catalog-button .btn','line-height','20','','','.w-product-personal-catalog-button'),(983146,'deals','.w-product-wishlist-button .btn','line-height','14','','','.w-product-wishlist-button'),(983147,'deals','.w-product-wishlist-button .btn','line-height','1','3','','.w-product-wishlist-button'),(983148,'deals','.order-summary .icon','line-height','30','','','.order-summary'),(983149,'deals','.w-cart-discount-coupon .title','line-height','0.75','4','','.w-cart-discount-coupon'),(983162,'deals','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','line-height','20','','','.account-samples'),(983163,'deals','.account-samples .order_history_table th','line-height','16','','','.account-samples'),(983164,'deals','.account-samples .view_link','line-height','17','4','','.account-samples'),(983165,'deals','.account-samples .orders-table .td-alignright','line-height','35','5639','','.account-samples'),(983166,'deals','.catalog-product-wrap .pn-direction','line-height','1.2','','','.catalog-product-wrap'),(983167,'deals','.catalog-product-wrap .pn-image','line-height','24','3','','.catalog-product-wrap'),(983168,'deals','.checkout-index-wrap .closeable-heading','line-height','2','3','','.checkout-index-wrap'),(983169,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','line-height','20','','','.checkout-index-wrap'),(983170,'deals','.checkout-index-wrap .order-ico','line-height','20','3','','.checkout-index-wrap'),(983171,'deals','.checkout-index-wrap .pay-ico','line-height','20','3','','.checkout-index-wrap'),(983172,'deals','.checkout-index-wrap .ship-ico','line-height','20','3','','.checkout-index-wrap'),(983173,'deals','.checkout-order-confirmation .comment-ico','line-height','20','3','','.checkout-order-confirmation'),(983174,'deals','.checkout-order-confirmation .discount-ico','line-height','20','3','','.checkout-order-confirmation'),(983175,'deals','.checkout-order-confirmation .order-ico','line-height','20','3','','.checkout-order-confirmation'),(983176,'deals','.checkout-order-confirmation .ship-ico','line-height','20','3','','.checkout-order-confirmation'),(983177,'deals','.success-page .comment-ico','line-height','20','3','','.success-page'),(983178,'deals','.success-page .discount-ico','line-height','20','3','','.success-page'),(983179,'deals','.success-page .order-ico','line-height','20','3','','.success-page'),(983180,'deals','.success-page .page-success .text-1','line-height','20','3','','.success-page'),(983181,'deals','.success-page .pay-ico','line-height','20','3','','.success-page'),(983182,'deals','.success-page .prod-ico','line-height','20','3','','.success-page'),(983183,'deals','.success-page .ship-ico','line-height','20','3','','.success-page'),(983184,'deals','.success-page .w-cart-listing .qty','line-height','26','','','.success-page'),(983186,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line-height','31','','','.b-multi-page-checkout'),(983187,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line-height','35','3','','.b-multi-page-checkout'),(983188,'deals','.footer-menu .level-3 > li > a','line-height','1.2','5639','','.footer-menu'),(983189,'deals','.w-catalog-paging ','line-height','30','2','','.w-catalog-paging'),(983190,'deals','.w-catalog-paging .next','line-height','30','','','.w-catalog-paging'),(983191,'deals','.w-catalog-paging .next','line-height','26','3','','.w-catalog-paging'),(983192,'deals','.w-catalog-paging .next-pages','line-height','30','','','.w-catalog-paging'),(983193,'deals','.w-catalog-paging .page-number','line-height','30','','','.w-catalog-paging'),(983194,'deals','.w-catalog-paging .prev','line-height','30','','','.w-catalog-paging'),(983195,'deals','.w-catalog-paging .prev','line-height','26','3','','.w-catalog-paging'),(983196,'deals','.w-catalog-paging .prev-pages','line-height','30','','','.w-catalog-paging'),(983197,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line-height','30','','','.w-catalog-paging'),(983200,'deals','.w-menu-slider .close','line-height','10','','','.w-menu-slider'),(983201,'deals','.w-menu-slider .menu-ico','line-height','54','','','.w-menu-slider'),(983202,'deals','.w-rma-returns-history tbody td','line-height','1.3','','','.w-rma-returns-history'),(983203,'deals','.b-info-popup .info-popup div','line_height_measure','px','3','','.b-info-popup'),(983204,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(983205,'deals','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off, .b-switch .bootstrap-switch .bootstrap-switch-label','line_height_measure','px','','','.b-switch'),(983206,'deals','.b-form .radio-button input[type=\"radio\"].no + span','line_height_measure','px','3','','.b-form'),(983207,'deals','.heading-4 .edit, h4 .edit','line_height_measure','px','','',''),(983208,'deals','.p-quick-order-index .paginate_button.next','line_height_measure','px','3','','.p-quick-order-index'),(983209,'deals','.p-quick-order-index .paginate_button.previous','line_height_measure','px','3','','.p-quick-order-index'),(983210,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.p-quick-order-index'),(983211,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.p-quick-order-index'),(983212,'deals','.w-promotions .prom-multi-discount .promo-range','line_height_measure','px','','','.w-promotions'),(983213,'deals','.w-promotions .promo-salemaker .discount','line_height_measure','px','','','.w-promotions'),(983214,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','line_height_measure','px','','','.w-promotions'),(983215,'deals','.w-promotions .promo-cart-discount .promo-min-qty','line_height_measure','px','','','.w-promotions'),(983216,'deals','.b-preloader .preloader','line_height_measure','px','3','','.b-preloader'),(983217,'deals','.w-cart-compare .attributes-cell','line_height_measure','px','','','.w-cart-compare'),(983218,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-messages'),(983219,'deals','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(983220,'deals','.b-messages .messBtnMenuDelete','line_height_measure','px','3','','.b-messages'),(983221,'deals','.b-messages .messBtnMenuStarred','line_height_measure','px','3','','.b-messages'),(983222,'deals','.b-messages span.starred::before','line_height_measure','px','','','.b-messages'),(983223,'deals','.b-messages .messBtnMenuUnread','line_height_measure','px','3','','.b-messages'),(983224,'deals','.p-payer-order-confirmation .ship-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(983225,'deals','.p-payer-order-confirmation .pay-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(983226,'deals','.p-payer-order-confirmation .order-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(983227,'deals','.p-payer-order-confirmation .discount-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(983228,'deals','.p-payer-order-confirmation .comment-ico','line_height_measure','px','3','','.p-payer-order-confirmation'),(983229,'deals','.p-payer-order-pay .ship-ico','line_height_measure','px','3','','.p-payer-order-pay'),(983230,'deals','.p-payer-order-pay .pay-ico','line_height_measure','px','3','','.p-payer-order-pay'),(983231,'deals','.p-payer-order-pay .order-ico','line_height_measure','px','3','','.p-payer-order-pay'),(983232,'deals','.p-payer-order-pay .discount-ico','line_height_measure','px','3','','.p-payer-order-pay'),(983233,'deals','.p-payer-order-pay .comment-ico','line_height_measure','px','3','','.p-payer-order-pay'),(983234,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(983235,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(983236,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(983237,'deals','.b-fancybox .fancybox-close','line_height_measure','px','','','.b-fancybox'),(983238,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','line_height_measure','px','4','','.b-switch'),(983239,'deals','.b-info-popup .info-popup','line_height_measure','px','','','.b-info-popup'),(983240,'deals','.bell-ico .heading-2','line_height_measure','px','3','','.bell-ico'),(983241,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(983242,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(983243,'deals','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(983244,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(983245,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(983246,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(983247,'deals','.b-switch .bootstrap-switch','line_height_measure','px','','','.b-switch'),(983248,'deals','.w-checkout-shipping-choice span','line_height_measure','px','','','.w-checkout-shipping-choice'),(983249,'deals','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(983250,'deals','.b-form .checkbox-style:checked + .checkbox-span:before','line_height_measure','px','','','.b-form'),(983252,'deals','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(983253,'deals','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(983254,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span','line_height_measure','px','','','.b-form'),(983255,'deals','.btn-2','line_height_measure','px','','',''),(983256,'deals','.w-filters .input-checkbox:checked + .checkbox-span:before','line_height_measure','px','','','.w-filters'),(983257,'deals','.heading-3 .right-text, h3 .right-text','line_height_measure','px','','',''),(983258,'deals','.heading-3 .edit, h3 .edit','line_height_measure','px','','',''),(983259,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','line_height_measure','px','4','','.b-switch'),(983260,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','line_height_measure','px','4','','.b-switch'),(983262,'deals','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(983263,'deals','.b-fancybox .fancybox-title-float-wrap .child','line_height_measure','px','','','.b-fancybox'),(983264,'deals','.btn','line_height_measure','px','','',''),(983265,'deals','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(983266,'deals','.b-select-suggest .select2-container .select2-choice','line_height_measure','px','','','.b-select-suggest'),(983267,'deals','.w-cart-listing .links','line_height_measure','px','','','.w-cart-listing'),(983268,'deals','.b-bottom .pop-up-close','line_height_measure','px','','','.b-bottom'),(983269,'deals','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(983270,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span:before','line_height_measure','px','','','.b-form'),(983271,'deals','.w-product-customers-activity .close','line_height_measure','px','','','.w-product-customers-activity'),(983274,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(983275,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','line_height_measure','px','','','.b-select-suggest'),(983276,'deals','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(983278,'deals','.w-cart-compare .price-cell','line_height_measure','px','','','.w-cart-compare'),(983279,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','line_height_measure','px','','','.b-data-table'),(983280,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','line_height_measure','px','','','.b-data-table'),(983281,'deals','.b-products-listing .btn-preloader','line_height_measure','px','3','','.b-products-listing'),(983282,'deals','.b-products-listing .loader','line_height_measure','px','4','','.b-products-listing'),(983283,'deals','.b-products-listing .products-listing .btn-buy','line_height_measure','px','3','','.b-products-listing'),(983284,'deals','.checkbox input:not(checked) + span:before','line_height_measure','px','','',''),(983286,'deals','.w-socials .post_item > div','line_height_measure','px','','','.w-socials'),(983287,'deals','.w-quote .cart-box-link','line_height_measure','px','5639,3','','.w-quote'),(983288,'deals','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(983289,'deals','.order-summary .price-row.ot_coupon .title','line_height_measure','px','3','','.order-summary'),(983290,'deals','.w-checkout-create-account .account-benefits strong','line_height_measure','px','3','','.w-checkout-create-account'),(983291,'deals','.heading-4 .right-text, h4 .right-text','line_height_measure','px','','',''),(983292,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','','','.w-communication-new-topic'),(983293,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','line_height_measure','px','3','','.w-communication-new-topic'),(983294,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','line_height_measure','px','','','.w-communication-new-topic'),(983296,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(983297,'deals','.w-promo-code .holder','line_height_measure','px','3','','.w-promo-code'),(983298,'deals','.w-menu-horizontal .menu-ico','line_height_measure','px','','','.w-menu-horizontal'),(983299,'deals','.w-catalog-listing-look .grid','line_height_measure','px','','','.w-catalog-listing-look'),(983300,'deals','.w-catalog-listing-look .b2b','line_height_measure','px','','','.w-catalog-listing-look'),(983301,'deals','.w-catalog-listing-look .list','line_height_measure','px','','','.w-catalog-listing-look'),(983302,'deals','.w-cart-listing .remove-btn','line_height_measure','px','','','.w-cart-listing'),(983303,'deals','.b-fancybox .fancybox-nav span','line_height_measure','px','','','.b-fancybox'),(983304,'deals','.w-multi-cart-cart-switcher .cart-label','line_height_measure','px','','','.w-multi-cart-cart-switcher'),(983305,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','line_height_measure','px','','','.b-switch'),(983306,'deals','.b-form .cart-popup .price','line_height_measure','px','','','.b-form'),(983307,'deals','.btn-1','line_height_measure','px','','',''),(983308,'deals','.b-products-listing .products-listing .btn-preloader','line_height_measure','px','','','.b-products-listing'),(983309,'deals','.btn-3','line_height_measure','px','','',''),(983310,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','line_height_measure','px','','','.b-switch'),(983311,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on i','line_height_measure','px','','','.b-switch'),(983312,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','line_height_measure','px','','','.b-switch'),(983313,'deals','.w-filters .input-checkbox:not(checked) + .checkbox-span','line_height_measure','px','','','.w-filters'),(983314,'deals','.b-upload-file .snapshot','line_height_measure','px','','','.b-upload-file'),(983315,'deals','.b-product-images .media-popup .mp-close','line_height_measure','px','','','.b-product-images'),(983316,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','line_height_measure','px','','','.b-product-images'),(983317,'deals','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','line_height_measure','px','','','.b-menu-burger_icon'),(983318,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(983319,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(983320,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(983321,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(983322,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','line_height_measure','px','','','.b-menu-lev_vis-click_icon'),(983323,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','line_height_measure','px','3','','.w-catalog-compare'),(983324,'deals','.w-catalog-compare span.btn-preloader','line_height_measure','px','3','','.w-catalog-compare'),(983326,'deals','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','line_height_measure','px','','','.b-slick'),(983327,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','','','.b-slick'),(983328,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','line_height_measure','px','5639','','.b-slick'),(983331,'deals','.w-quote .cart-box-link','line_height_measure','px','3','','.w-quote'),(983332,'deals','.b-quantity .qty-box .bigger','line_height_measure','px','','','.b-quantity'),(983333,'deals','.b-quantity .qty-box .smaller','line_height_measure','px','','','.b-quantity'),(983334,'deals','.w-sample .cart-box-link','line_height_measure','px','3','','.w-sample'),(983335,'deals','.w-sample .cart-box-link','line_height_measure','px','5639,3','','.w-sample'),(983336,'deals','.w-cart-gift-certificate .gift-certificate .heading-4','line_height_measure','px','3','','.w-cart-gift-certificate'),(983338,'deals','.b-pagination .pagination .next-pages','line_height_measure','px','','','.b-pagination'),(983339,'deals','.b-pagination .pagination .page-number','line_height_measure','px','','','.b-pagination'),(983340,'deals','.b-pagination .pagination .prev-pages','line_height_measure','px','','','.b-pagination'),(983341,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','line_height_measure','px','','','.b-pagination'),(983342,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next, .b-pagination .pagination .next a, .b-pagination .pagination .next span','line_height_measure','px','3','','.b-pagination'),(983343,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','line_height_measure','px','','','.b-pagination'),(983344,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a, .b-pagination .pagination .prev span','line_height_measure','px','3','','.b-pagination'),(983345,'deals','.b-pagination .pagination span','line_height_measure','px','2','','.b-pagination'),(983346,'deals','.w-product-properties-filters-widgets-chosen-filters .remove','line_height_measure','px','3','','.w-product-properties-filters-widgets-chosen-filters'),(983347,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','line_height_measure','px','','','.w-questionnaire-widgets-questionnaire'),(983348,'deals','.w-sale-category .badge','line_height_measure','px','','','.w-sale-category'),(983349,'deals','.w-rma-returns-history .column .title','line_height_measure','px','','','.w-rma-returns-history'),(983350,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','line_height_measure','px','','','.w-predefined-promotion'),(983351,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','line_height_measure','px','','','.w-predefined-promotion'),(983352,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','line_height_measure','px','','','.w-predefined-promotion'),(983353,'deals','.w-predefined-promotion .promo-salemaker .discount','line_height_measure','px','','','.w-predefined-promotion'),(983354,'deals','.w-supplier-purchase-supplier-products .active .select_item > div','line_height_measure','px','','','.w-supplier-purchase-supplier-products'),(983356,'deals','.w-breadcrumb .breadcrumb-li','line_height_measure','px','','','.w-breadcrumb'),(983357,'deals','.w-cart-listing .qty-box .bigger, .w-cart-listing .qty-box .smaller','line_height_measure','px','','','.w-cart-listing'),(983358,'deals','.w-product-personal-catalog-button .btn','line_height_measure','px','','','.w-product-personal-catalog-button'),(983359,'deals','.w-product-wishlist-button .btn','line_height_measure','px','','','.w-product-wishlist-button'),(983360,'deals','.order-summary .icon','line_height_measure','px','','','.order-summary'),(983372,'deals','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','line_height_measure','px','','','.account-samples'),(983373,'deals','.account-samples .order_history_table th','line_height_measure','px','','','.account-samples'),(983374,'deals','.account-samples .view_link','line_height_measure','px','4','','.account-samples'),(983375,'deals','.account-samples .orders-table .td-alignright','line_height_measure','px','5639','','.account-samples'),(983376,'deals','.catalog-product-wrap .pn-image','line_height_measure','px','3','','.catalog-product-wrap'),(983377,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','line_height_measure','px','','','.checkout-index-wrap'),(983378,'deals','.checkout-index-wrap .order-ico','line_height_measure','px','3','','.checkout-index-wrap'),(983379,'deals','.checkout-index-wrap .pay-ico','line_height_measure','px','3','','.checkout-index-wrap'),(983380,'deals','.checkout-index-wrap .ship-ico','line_height_measure','px','3','','.checkout-index-wrap'),(983381,'deals','.checkout-order-confirmation .comment-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(983382,'deals','.checkout-order-confirmation .discount-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(983383,'deals','.checkout-order-confirmation .order-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(983384,'deals','.checkout-order-confirmation .ship-ico','line_height_measure','px','3','','.checkout-order-confirmation'),(983385,'deals','.success-page .comment-ico','line_height_measure','px','3','','.success-page'),(983386,'deals','.success-page .discount-ico','line_height_measure','px','3','','.success-page'),(983387,'deals','.success-page .order-ico','line_height_measure','px','3','','.success-page'),(983388,'deals','.success-page .page-success .text-1','line_height_measure','px','3','','.success-page'),(983389,'deals','.success-page .pay-ico','line_height_measure','px','3','','.success-page'),(983390,'deals','.success-page .prod-ico','line_height_measure','px','3','','.success-page'),(983391,'deals','.success-page .ship-ico','line_height_measure','px','3','','.success-page'),(983392,'deals','.success-page .w-cart-listing .qty','line_height_measure','px','','','.success-page'),(983393,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','line_height_measure','px','','','.b-multi-page-checkout'),(983394,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','line_height_measure','px','3','','.b-multi-page-checkout'),(983395,'deals','.w-catalog-paging ','line_height_measure','px','2','','.w-catalog-paging'),(983396,'deals','.w-catalog-paging .next','line_height_measure','px','','','.w-catalog-paging'),(983397,'deals','.w-catalog-paging .next','line_height_measure','px','3','','.w-catalog-paging'),(983398,'deals','.w-catalog-paging .next-pages','line_height_measure','px','','','.w-catalog-paging'),(983399,'deals','.w-catalog-paging .page-number','line_height_measure','px','','','.w-catalog-paging'),(983400,'deals','.w-catalog-paging .prev','line_height_measure','px','','','.w-catalog-paging'),(983401,'deals','.w-catalog-paging .prev','line_height_measure','px','3','','.w-catalog-paging'),(983402,'deals','.w-catalog-paging .prev-pages','line_height_measure','px','','','.w-catalog-paging'),(983403,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','line_height_measure','px','','','.w-catalog-paging'),(983406,'deals','.w-menu-slider .close','line_height_measure','px','','','.w-menu-slider'),(983407,'deals','.w-menu-slider .menu-ico','line_height_measure','px','','','.w-menu-slider'),(983408,'deals','.p-quick-order-index ul.token-input-list','list-style','none','','','.p-quick-order-index'),(983412,'deals','.b-messages .messages-menu ul','list-style','none','','','.b-messages'),(983413,'deals','.w-sitemap-delivery-location > ul > li > ul','list-style','none','','','.w-sitemap-delivery-location'),(983414,'deals','.w-sitemap-delivery-location > ul','list-style','none','','','.w-sitemap-delivery-location'),(983415,'deals','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(983416,'deals','.w-filters .filter-ul-content','list-style','none','','','.w-filters'),(983417,'deals','.w-menu-horizontal ul','list-style','none','','','.w-menu-horizontal'),(983418,'deals','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(983419,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(983420,'deals','.products-quick-index ul','list-style','none','','',''),(983421,'deals','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(983422,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(983423,'deals','.w-tabs .tab-navigation','list-style','none','','','.w-tabs'),(983424,'deals','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(983425,'deals','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(983426,'deals','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(983427,'deals','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(983428,'deals','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(983429,'deals','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(983430,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(983431,'deals','.b-autocomplete .ui-autocomplete','list-style','none','','','.b-autocomplete'),(983433,'deals','.b-select-suggest .select2-container-multi .select2-choices li','list-style','none','','','.b-select-suggest'),(983434,'deals','.b-select-suggest .select2-results li','list-style','none','','','.b-select-suggest'),(983435,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(983436,'deals','.w-menu-big ul','list-style','none','','','.w-menu-big'),(983438,'deals','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(983439,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(983440,'deals','.products-quick-index .token-input-list','list-style','none','','',''),(983441,'deals','.w-socials .wrap_socials_posts','list-style','none','','','.w-socials'),(983442,'deals','.products-quick-index ul.token-input-list','list-style','none','','',''),(983443,'deals','.b-dropdown .dropdown .dropdown-menu','list-style','none','','','.b-dropdown'),(983444,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','list-style','none','','','.w-menu-style-2'),(983445,'deals','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','list-style','none','','','.b-menu-style'),(983446,'deals','.w-catalog-additional-images ul, .w-catalog-additional-images li','list-style','none','','','.w-catalog-additional-images'),(983447,'deals','.LeftCategories .w-menu-simple ul','list-style','none','','','.LeftCategories'),(983448,'deals','.w-breadcrumb .breadcrumb-li','list-style','none','','','.w-breadcrumb'),(983449,'deals','.w-breadcrumb .breadcrumb-ul','list-style','none','','','.w-breadcrumb'),(983450,'deals','.b-pagination ul.pagination','list-style','none','','','.b-pagination'),(983451,'deals','.w-product-properties .properties-table','list-style','none','','','.w-product-properties'),(983452,'deals','.w-product-properties .property-ul','list-style','none','','','.w-product-properties'),(983453,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list'),(983454,'deals','.w-delivery-location-top-location-list .deliveryList ul','list-style','none','','','.w-delivery-location-top-location-list'),(983455,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list-block'),(983456,'deals','.w-delivery-location-location-list ul','list-style','none','','','.w-delivery-location-location-list'),(983457,'deals','.w-delivery-location-featured-list .deliveryList > ul > li','list-style','none','','','.w-delivery-location-featured-list'),(983458,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(983459,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(983460,'deals','.w-delivery-location-list-by-page .description ul','list-style','circle','','','.w-delivery-location-list-by-page'),(983461,'deals','.w-delivery-location-cross-pages .description ul','list-style','circle','','','.w-delivery-location-cross-pages'),(983462,'deals','.w-catalog-delivery-locations .description ul','list-style','circle','','','.w-catalog-delivery-locations'),(983463,'deals','.w-support-system-filter .filter_cats','list-style','none','','','.w-support-system-filter'),(983464,'deals','.w-product-configurator .pc-item','list-style','none','','','.w-product-configurator'),(983465,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','list-style','none','','','.w-catalog-pages-category-pages-list'),(983466,'deals','.b-info .info ul','list-style','disc inside','','','.b-info'),(983467,'deals','.w-account-personal-catalog .list-row-action ul','list-style','none','','','.w-account-personal-catalog'),(983472,'deals','.account-address-book .leftMes ul','list-style','disc inside','','','.account-address-book'),(983473,'deals','.account-address-book .rightMes ul','list-style','disc inside','','','.account-address-book'),(983474,'deals','.b-slick .slick-dots','list-style','none','','','.b-slick'),(983476,'deals','.w-menu-slider ul, .w-menu-slider li','list-style','none','','','.w-menu-slider'),(983477,'deals','.w-delivery-location-featured-list .deliveryList ul','list-style-type','circle','','','.w-delivery-location-featured-list'),(983478,'deals','.w-filters .choose-filters','list-style-type','none','','','.w-filters'),(983479,'deals','.b-form .middle-form','margin','0 auto','','','.b-form'),(983480,'deals','.b-messages .msv_btn .btn','margin','0px auto 0px','','','.b-messages'),(983481,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','margin','3px auto 3px','','','.b-select-suggest'),(983482,'deals','.b-select-suggest .select2-results','margin','4px auto 4px','','','.b-select-suggest'),(983483,'deals','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(983484,'deals','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(983485,'deals','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(983486,'deals','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','margin','0px auto 10px','','','.b-form'),(983487,'deals','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(983488,'deals','.w-socials .post_item_img','margin','0px auto 0px','','','.w-socials'),(983489,'deals','.w-catalog-b2b-add-button .b2b-add-box-wrap','margin','0 auto','','','.w-catalog-b2b-add-button'),(983490,'deals','.b-form .terms-login .bootstrap-switch','margin','9px auto 0px','','','.b-form'),(983491,'deals','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','margin','0 0 0 auto','','','.w-cart-listing'),(983492,'deals','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','margin','0 auto','','','.b-product-images'),(983493,'deals','.b-trade-approval .middle-form','margin','0 auto','','','.b-trade-approval'),(983495,'deals','.b-products-listing .products-listing .slick-slide img','margin','auto','','','.b-products-listing'),(983496,'deals','.b-products-listing .products-listing .compare input + span','margin','auto','','','.b-products-listing'),(983497,'deals','.w-product-quantity .qty_packs .price_1','margin','0px auto 0px','4','','.w-product-quantity'),(983498,'deals','.p-quote-checkout-index .datepicker-inline','margin','0 auto','','','.p-quote-checkout-index'),(983499,'deals','.p-sample-checkout-index .datepicker-inline','margin','0 auto','','','.p-sample-checkout-index'),(983500,'deals','.b-slick .slick-slide img','margin','auto','','','.b-slick'),(983501,'deals','.parallaxWrap .w-info-page','margin','0px auto','','','.parallaxWrap'),(983502,'deals','.loginWrapper','margin','0px auto','','',''),(983505,'deals','.account-address-book .address_book .row-buttons a','margin','0px auto 0px','','','.account-address-book'),(983506,'deals','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin','0px auto 15px','','','.account-address-book'),(983507,'deals','.account-address-book .address_book_row h2 a','margin','0px auto 0px','','','.account-address-book'),(983508,'deals','.account-address-book .buttonBox .info','margin','0px auto 0px','','','.account-address-book'),(983509,'deals','.checkout-index-wrap .datepicker-inline','margin','0 auto','','','.checkout-index-wrap'),(983510,'deals','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','margin','0 auto','','','.checkout-index-wrap'),(983511,'deals','.b-form .formWrapBox','margin','0 auto','','','.b-form'),(983512,'deals','.w-communication-new-topic #communication_group_holder input, .w-communication-new-topic select','margin-bottom','0','','','.w-communication-new-topic'),(983513,'deals','.w-checkout-billing-address .genders-title','margin-bottom','5','','','.w-checkout-billing-address'),(983514,'deals','.b-form .col-full-margin','margin-bottom','10','','','.b-form'),(983515,'deals','.w-tabs .tab-li.tab-cart a','margin-bottom','7','3','','.w-tabs'),(983517,'deals','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(983518,'deals','.w-catalog-items-on-page select','margin-bottom','0','','','.w-catalog-items-on-page'),(983519,'deals','.b-form .message.error','margin-bottom','10','','','.b-form'),(983520,'deals','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-bottom','0','','','.b-fancybox'),(983521,'deals','.p-quick-order-index .filters','margin-bottom','20','','','.p-quick-order-index'),(983522,'deals','.w-promotions .promo-date','margin-bottom','10','','','.w-promotions'),(983523,'deals','.w-promotions .promo-item','margin-bottom','30','','','.w-promotions'),(983524,'deals','.w-socials > li','margin-bottom','10','','','.w-socials'),(983525,'deals','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(983526,'deals','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(983530,'deals','.w-promotions .prom-multi-discount .heading','margin-bottom','10','','','.w-promotions'),(983531,'deals','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(983532,'deals','.testimonials .reviews-list .name','margin-bottom','20','','',''),(983533,'deals','.testimonials .heading-3','margin-bottom','10','','',''),(983534,'deals','.testimonials .name','margin-bottom','20','','',''),(983535,'deals','.b-products-listing .select-attributes','margin-bottom','10','','','.b-products-listing'),(983536,'deals','.b-products-listing .select-attributes select','margin-bottom','0','','','.b-products-listing'),(983537,'deals','.w-promotions .nextdiscount .promo-for-each','margin-bottom','10','','','.w-promotions'),(983538,'deals','.w-promotions .nextdiscount .heading','margin-bottom','20','','','.w-promotions'),(983539,'deals','.w-promotions .heading-3','margin-bottom','20','','','.w-promotions'),(983540,'deals','.w-promotions .promo-salemaker .item','margin-bottom','2','','','.w-promotions'),(983541,'deals','.w-promotions .promo-cart-discount .slave .item','margin-bottom','2','','','.w-promotions'),(983542,'deals','.w-promotions .promo-cart-discount .master .item','margin-bottom','12','','','.w-promotions'),(983543,'deals','.w-promotions .promo-cart-discount .master .heading','margin-bottom','10','','','.w-promotions'),(983544,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-bottom','20','','','.b-warehouses-popup'),(983545,'deals','.b-warehouses-popup .warehouses-popup .heading','margin-bottom','20','','','.b-warehouses-popup'),(983546,'deals','.w-info-content p','margin-bottom','10','','','.w-info-content'),(983548,'deals','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(983549,'deals','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(983550,'deals','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(983552,'deals','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(983553,'deals','.b-messages .messages-menu ul','margin-bottom','0','','','.b-messages'),(983554,'deals','.b-messages .messMenuButtonTop','margin-bottom','-39','','','.b-messages'),(983555,'deals','.b-messages .dataTables_wrapper > .top','margin-bottom','8','','','.b-messages'),(983556,'deals','.b-messages .messages-sidebar .heading-2','margin-bottom','20','','','.b-messages'),(983557,'deals','.b-messages .messages-menu li','margin-bottom','0','','','.b-messages'),(983558,'deals','.b-messages .messages-sidebar .btn-2','margin-bottom','20','','','.b-messages'),(983559,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-bottom','5','','','.b-messages'),(983560,'deals','.w-sitemap-delivery-location > ul > li > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(983561,'deals','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(983562,'deals','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(983563,'deals','.b-form .middle-form .bootstrap-switch','margin-bottom','15','','','.b-form'),(983564,'deals','.w-sitemap-delivery-location > ul','margin-bottom','0','','','.w-sitemap-delivery-location'),(983565,'deals','.p-payer-order-confirmation .input-wrapper','margin-bottom','10','','','.p-payer-order-confirmation'),(983566,'deals','.p-payer-order-confirmation .dob-hide','margin-bottom','-10','','','.p-payer-order-confirmation'),(983567,'deals','.p-payer-order-pay .input-wrapper','margin-bottom','10','','','.p-payer-order-pay'),(983568,'deals','.p-payer-order-pay .dob-hide','margin-bottom','-10','','','.p-payer-order-pay'),(983569,'deals','.p-quick-order-index ul.token-input-list','margin-bottom','0','','','.p-quick-order-index'),(983570,'deals','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(983571,'deals','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(983572,'deals','.w-checkout-shipping-address .genders-title','margin-bottom','5','','','.w-checkout-shipping-address'),(983573,'deals','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(983574,'deals','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(983575,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(983576,'deals','.w-upload-customer-id-upload-customer-id-form .upload-customer-id-form-box','margin-bottom','20','','','.w-upload-customer-id-upload-customer-id-form'),(983577,'deals','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(983578,'deals','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(983579,'deals','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(983580,'deals','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(983581,'deals','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(983582,'deals','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(983583,'deals','.w-filters .filter-box-head','margin-bottom','15','','','.w-filters'),(983584,'deals','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(983585,'deals','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(983586,'deals','.w-menu-horizontal li','margin-bottom','0','','','.w-menu-horizontal'),(983587,'deals','.w-menu-horizontal ul','margin-bottom','0','','','.w-menu-horizontal'),(983588,'deals','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(983589,'deals','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(983590,'deals','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(983591,'deals','.b-delete-account .delete-box > div','margin-bottom','10','','','.b-delete-account'),(983592,'deals','.w-info-content p','margin-bottom','10','','','.w-info-content'),(983593,'deals','.w-filters .input-checkbox','margin-bottom','0','','','.w-filters'),(983594,'deals','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(983595,'deals','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(983596,'deals','.b-form .newsletter-row','margin-bottom','10','','','.b-form'),(983597,'deals','.w-cart-give-away .ga_attributes > div','margin-bottom','1','','','.w-cart-give-away'),(983598,'deals','.heading-6, h6, .h-block h6','margin-bottom','5','','',''),(983599,'deals','.pop-up-content .buttons .left-buttons','margin-bottom','15','5639','',''),(983600,'deals','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(983601,'deals','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(983602,'deals','.w-communication-post .text-container','margin-bottom','20','','','.w-communication-post'),(983603,'deals','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(983604,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(983605,'deals','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(983606,'deals','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(983607,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-bottom','0','','','.b-select-suggest'),(983608,'deals','.b-form .password-forgotten-link','margin-bottom','0','','','.b-form'),(983609,'deals','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(983610,'deals','.w-socials > li','margin-bottom','10','','','.w-socials'),(983612,'deals','.b-delete-account .delete-box span','margin-bottom','0','','','.b-delete-account'),(983613,'deals','.w-socials > li','margin-bottom','10','','','.w-socials'),(983614,'deals','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(983615,'deals','.w-image-maps .default-links .item .title','margin-bottom','10','','','.w-image-maps'),(983616,'deals','.w-reviews .heading-3','margin-bottom','10','','','.w-reviews'),(983617,'deals','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(983618,'deals','.w-socials > li','margin-bottom','10','','','.w-socials'),(983619,'deals','.w-checkout-shipping-address .addresses .address-item','margin-bottom','10','','','.w-checkout-shipping-address'),(983620,'deals','.w-checkout-billing-address .same-address','margin-bottom','10','','','.w-checkout-billing-address'),(983621,'deals','.b-form .required-message-wrap','margin-bottom','0','','','.b-form'),(983622,'deals','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(983623,'deals','.w-tabs .tab-li.tab-wishlist a','margin-bottom','7','3','','.w-tabs'),(983624,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(983625,'deals','.w-tabs > .block','margin-bottom','20','','','.w-tabs'),(983626,'deals','.w-cart-cart-tabs .w-tabs .tab-navigation','margin-bottom','25','','','.w-cart-cart-tabs'),(983627,'deals','.w-tabs .tab-li','margin-bottom','0','','','.w-tabs'),(983628,'deals','.w-socials > li','margin-bottom','10','','','.w-socials'),(983629,'deals','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(983631,'deals','.b-dropdown .dropdown .dropdown-menu','margin-bottom','0','','','.b-dropdown'),(983632,'deals','.w-tabs .tab-li.tab-sample a','margin-bottom','7','3','','.w-tabs'),(983633,'deals','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(983634,'deals','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(983635,'deals','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(983636,'deals','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(983637,'deals','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(983638,'deals','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(983639,'deals','.heading-5, h5, .h-block h5','margin-bottom','5','','',''),(983640,'deals','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(983641,'deals','.w-filters .filter-ul-content','margin-bottom','0','','','.w-filters'),(983642,'deals','.heading-4, h4, .h-block h4','margin-bottom','5','','',''),(983643,'deals','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(983644,'deals','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(983645,'deals','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','margin-bottom','10','','','.b-form'),(983646,'deals','.order-summary .price-box','margin-bottom','10','','','.order-summary'),(983647,'deals','.b-form .addresses .address-item input[type=\"radio\"]','margin-bottom','0','','','.b-form'),(983648,'deals','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(983649,'deals','.w-image-maps .categories-items .item .title','margin-bottom','10','','','.w-image-maps'),(983650,'deals','.b-select-suggest .select2-drop-mask','margin-bottom','0','','','.b-select-suggest'),(983651,'deals','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(983652,'deals','.w-top-categories .categories','margin-bottom','0','5644','','.w-top-categories'),(983653,'deals','.products-quick-index ul','margin-bottom','0','','',''),(983654,'deals','.w-checkout-gdpr .col-left','margin-bottom','20','5639','','.w-checkout-gdpr'),(983655,'deals','.w-top-categories .categories h2','margin-bottom','0','','','.w-top-categories'),(983656,'deals','.w-product-reviews .reviews-list .name','margin-bottom','20','','','.w-product-reviews'),(983657,'deals','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(983658,'deals','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(983659,'deals','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(983660,'deals','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(983661,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(983662,'deals','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(983663,'deals','.b-form .required-message','margin-bottom','0','','','.b-form'),(983664,'deals','.w-socials .post_item_img','margin-bottom','0','','','.w-socials'),(983665,'deals','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(983666,'deals','.w-product-quantity .qty_packs .price_1','margin-bottom','0','4','','.w-product-quantity'),(983667,'deals','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(983668,'deals','.w-reviews .reviews-list','margin-bottom','20','','','.w-reviews'),(983669,'deals','.b-select-suggest .select2-container','margin-bottom','0','','','.b-select-suggest'),(983670,'deals','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(983671,'deals','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(983672,'deals','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(983673,'deals','.w-checkout-create-account .heading-2','margin-bottom','0','','','.w-checkout-create-account'),(983674,'deals','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(983675,'deals','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(983676,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(983677,'deals','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(983678,'deals','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(983679,'deals','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(983680,'deals','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(983681,'deals','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(983682,'deals','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(983683,'deals','.b-form .col-full-padding','margin-bottom','10','','','.b-form'),(983684,'deals','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','margin-bottom','15','','','.b-form'),(983685,'deals','.heading-3, h3, .h-block h3','margin-bottom','10','','',''),(983686,'deals','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(983688,'deals','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(983689,'deals','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(983690,'deals','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(983691,'deals','.w-account-apply-certificate .gift-certificate-input','margin-bottom','20','','','.w-account-apply-certificate'),(983692,'deals','.b-form .form-inputs label > span','margin-bottom','1','','','.b-form'),(983693,'deals','.b-autocomplete .ui-autocomplete','margin-bottom','0','','','.b-autocomplete'),(983694,'deals','.b-bottom .cart-options .js-carts','margin-bottom','10','','','.b-bottom'),(983695,'deals','.b-bottom .cart-options .option-item','margin-bottom','5','','','.b-bottom'),(983696,'deals','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(983697,'deals','.b-bottom .cart-options .cart-item','margin-bottom','5','','','.b-bottom'),(983699,'deals','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(983700,'deals','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(983701,'deals','.b-select-suggest .select2-results .select2-result-label','margin-bottom','0','','','.b-select-suggest'),(983703,'deals','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(983704,'deals','.w-login-block .password-info .info-popup','margin-bottom','-5','','','.w-login-block'),(983705,'deals','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(983706,'deals','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(983707,'deals','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(983708,'deals','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(983709,'deals','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(983710,'deals','.w-menu-big li','margin-bottom','0','','','.w-menu-big'),(983711,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(983712,'deals','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(983713,'deals','.b-fancybox .fancybox-error','margin-bottom','0','','','.b-fancybox'),(983714,'deals','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(983715,'deals','.w-cart-compare .product .image','margin-bottom','10','','','.w-cart-compare'),(983716,'deals','.w-checkout-billing-address .addresses .address-item','margin-bottom','10','','','.w-checkout-billing-address'),(983717,'deals','.b-bottom .confirm-popup .buttons .btn','margin-bottom','0','','','.b-bottom'),(983718,'deals','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-bottom','0','','','.b-switch'),(983719,'deals','.w-reviews-content .reviews-list','margin-bottom','20','','','.w-reviews-content'),(983720,'deals','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(983721,'deals','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(983722,'deals','.b-form #shipping-address .radio-buttons','margin-bottom','10','','','.b-form'),(983723,'deals','.w-login-block .row','margin-bottom','20','','','.w-login-block'),(983724,'deals','.w-socials .post_item_name','margin-bottom','10','','','.w-socials'),(983725,'deals','.w-tabs .tab-navigation','margin-bottom','0','','','.w-tabs'),(983726,'deals','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(983727,'deals','.w-social-links a','margin-bottom','0','','','.w-social-links'),(983728,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-bottom','1','','','.b-select-suggest'),(983729,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-bottom','0','','','.b-select-suggest'),(983730,'deals','.b-select-suggest .select2-container-multi .select2-choices','margin-bottom','0','','','.b-select-suggest'),(983731,'deals','.w-info-content p','margin-bottom','10','','','.w-info-content'),(983732,'deals','.b-select-suggest .select2-results ul.select2-result-sub','margin-bottom','0','','','.b-select-suggest'),(983733,'deals','.b-select-suggest .select2-search input','margin-bottom','0','','','.b-select-suggest'),(983734,'deals','.b-select-suggest .select2-search','margin-bottom','0','','','.b-select-suggest'),(983735,'deals','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(983739,'deals','.w-product-promotions .select-box','margin-bottom','5','','','.w-product-promotions'),(983741,'deals','.b-social-login .social-login-text-2','margin-bottom','0','3','','.b-social-login'),(983742,'deals','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(983743,'deals','.w-login-block .buttons','margin-bottom','20','','','.w-login-block'),(983744,'deals','.w-login-block .email-row','margin-bottom','20','','','.w-login-block'),(983745,'deals','.order-summary .btn-2, .order-summary .btn-3','margin-bottom','15','','','.order-summary'),(983747,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(983748,'deals','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(983749,'deals','.w-login-block .col-2:nth-child(2n)','margin-bottom','20','','','.w-login-block'),(983750,'deals','.b-bottom .content-item','margin-bottom','20','','','.b-bottom'),(983751,'deals','.b-form .middle-form .checkbox-holder','margin-bottom','15','','','.b-form'),(983752,'deals','.w-communication-new-topic .privacy-row','margin-bottom','10','','','.w-communication-new-topic'),(983753,'deals','.w-communication-post .communication-post-message','margin-bottom','20','','','.w-communication-post'),(983754,'deals','.w-communication-post .communication-post','margin-bottom','5','','','.w-communication-post'),(983755,'deals','.b-products-listing .products-listing .name','margin-bottom','5','','','.b-products-listing'),(983756,'deals','.b-products-listing .products-listing .model','margin-bottom','5','','','.b-products-listing'),(983757,'deals','.b-products-listing .products-listing .description','margin-bottom','5','','','.b-products-listing'),(983758,'deals','.b-products-listing .products-listing .bonusPoints','margin-bottom','7','','','.b-products-listing'),(983759,'deals','.b-products-listing .products-listing .description ul','margin-bottom','0','','','.b-products-listing'),(983760,'deals','.b-products-listing .products-listing .mult-qty-input','margin-bottom','3','','','.b-products-listing'),(983761,'deals','.b-products-listing .promos-info','margin-bottom','-30','','','.b-products-listing'),(983762,'deals','.b-products-listing .wedding-registry-count','margin-bottom','10','','','.b-products-listing'),(983763,'deals','.w-info-content p','margin-bottom','10','','','.w-info-content'),(983764,'deals','.w-checkout-gdpr .privacy-row','margin-bottom','0','','','.w-checkout-gdpr'),(983765,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(983766,'deals','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(983767,'deals','.b-fancybox .fancybox-title-float-wrap','margin-bottom','-35','','','.b-fancybox'),(983768,'deals','.w-socials > li','margin-bottom','10','','','.w-socials'),(983769,'deals','.w-product-reviews .reviews-list','margin-bottom','10','','','.w-product-reviews'),(983770,'deals','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(983772,'deals','.w-login-block .label','margin-bottom','5','','','.w-login-block'),(983773,'deals','.w-login-block .col-2:nth-child(2n + 1)','margin-bottom','10','','','.w-login-block'),(983774,'deals','.w-info-content p','margin-bottom','10','','','.w-info-content'),(983775,'deals','.b-social-login .social-login-text-2','margin-bottom','0','4','','.b-social-login'),(983776,'deals','.w-taxable label','margin-bottom','0','','','.w-taxable'),(983777,'deals','.w-taxable select','margin-bottom','0','','','.w-taxable'),(983778,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-bottom','0','','',''),(983779,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-bottom','0','','','.b-h-inline'),(983780,'deals','h1, .heading-1','margin-bottom','18','','',''),(983781,'deals','.w-communication-new-topic #rmaProductReturnButtonFilterHolder','margin-bottom','30','','','.w-communication-new-topic'),(983782,'deals','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(983783,'deals','.w-checkout-shipping-address #shippingchoice-choice','margin-bottom','10','','','.w-checkout-shipping-address'),(983784,'deals','.w-product-reviews .write-review-button','margin-bottom','20','','','.w-product-reviews'),(983785,'deals','.w-product-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-product-promotions'),(983786,'deals','.w-tabs .tab-li.tab-quote a','margin-bottom','7','3','','.w-tabs'),(983787,'deals','.b-form .checkbox-style','margin-bottom','0','','','.b-form'),(983788,'deals','.products-quick-index .token-input-list','margin-bottom','0','','',''),(983789,'deals','.products-quick-index ul.token-input-list','margin-bottom','0','','',''),(983790,'deals','.w-cart-checkout-btn .or-text','margin-bottom','5','','','.w-cart-checkout-btn'),(983791,'deals','.b-compare .col-two','margin-bottom','15','','','.b-compare'),(983792,'deals','.w-cart-listing .item','margin-bottom','10','5639','','.w-cart-listing'),(983793,'deals','.w-cart-give-away .ga_wrapper','margin-bottom','25','','','.w-cart-give-away'),(983795,'deals','.w-brands .brands-listing > div','margin-bottom','5','','','.w-brands'),(983796,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(983797,'deals','.b-tracking-numbers .tracking-numbers .item','margin-bottom','20','','','.b-tracking-numbers'),(983798,'deals','.w-image-maps .float-items .item .title','margin-bottom','10','','','.w-image-maps'),(983799,'deals','.w-info-content p','margin-bottom','10','','','.w-info-content'),(983800,'deals','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-bottom','0','','','.b-fancybox'),(983801,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(983802,'deals','.w-filters .ui-slider','margin-bottom','0','','','.w-filters'),(983803,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-bottom','0','','','.b-tracking-numbers'),(983804,'deals','.w-catalog-sorting select','margin-bottom','0','','','.w-catalog-sorting'),(983805,'deals','.b-form .radio-buttons','margin-bottom','10','','','.b-form'),(983806,'deals','.b-page-name .page-name','margin-bottom','0','','','.b-page-name'),(983807,'deals','.heading-2, h2, .h-block h2','margin-bottom','10','','',''),(983808,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-bottom','0','','','.w-menu-style-2'),(983809,'deals','.b-upload-files .upload-files','margin-bottom','20','','','.b-upload-files'),(983810,'deals','.w-communication-new-topic .text-container','margin-bottom','20','','','.w-communication-new-topic'),(983811,'deals','.b-form .addresses','margin-bottom','20','','','.b-form'),(983814,'deals','.w-menu-big ul','margin-bottom','0','','','.w-menu-big'),(983815,'deals','.w-quote-checkout-btn','margin-bottom','20','','','.w-quote-checkout-btn'),(983816,'deals','.b-product-images .media-popup .slick-dots','margin-bottom','0','','','.b-product-images'),(983817,'deals','.b-product-images .media-popup .slick-dots li','margin-bottom','0','','','.b-product-images'),(983818,'deals','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-bottom','0','','','.b-menu-style'),(983819,'deals','.b-personal-catalog-popup #personal_catalog_popup .lists-message-box','margin-bottom','20','','','.b-personal-catalog-popup'),(983820,'deals','.b-trade-approval .steps-bar','margin-bottom','25','','','.b-trade-approval'),(983821,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','margin-bottom','15','','','.b-trade-approval'),(983822,'deals','.b-trade-approval .middle-form textarea','margin-bottom','15','','','.b-trade-approval'),(983823,'deals','.w-account-personal-catalog .list-switcher','margin-bottom','20','','','.w-account-personal-catalog'),(983824,'deals','.w-account-subscription .send-email','margin-bottom','20','','','.w-account-subscription'),(983825,'deals','.w-account-subscription .subscription-list','margin-bottom','20','','','.w-account-subscription'),(983826,'deals','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-bottom','0','','','.w-catalog-additional-images'),(983827,'deals','.w-catalog-compare .cross-box .return','margin-bottom','30','','','.w-catalog-compare'),(983828,'deals','.w-delivery-day .time-left','margin-bottom','30','','','.w-delivery-day'),(983829,'deals','.w-delivery-day .ends','margin-bottom','20','','','.w-delivery-day'),(983830,'deals','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-bottom','0','','','.b-cookie-notice'),(983831,'deals','.lowestPricedBox .w-banner .banner','margin-bottom','0','','','.lowestPricedBox'),(983832,'deals','.shopByCollectionBox .w-banner .banner','margin-bottom','0','','','.shopByCollectionBox'),(983833,'deals','.preFooter .w-banner .single_banner','margin-bottom','0','','','.preFooter'),(983834,'deals','.b-slick .slick-list','margin-bottom','0','','','.b-slick'),(983835,'deals','.LeftCategories .w-menu-simple ul','margin-bottom','0','','','.LeftCategories'),(983836,'deals','.w-breadcrumb .breadcrumb-ul','margin-bottom','0','','','.w-breadcrumb'),(983837,'deals','.w-quote .multicart .name','margin-bottom','0','','','.w-quote'),(983838,'deals','.b-products-listing .rating, .b-products-listing .ratingCounts','margin-bottom','5','','','.b-products-listing'),(983839,'deals','.w-product-sale-ends .ends','margin-bottom','20','','','.w-product-sale-ends'),(983840,'deals','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','margin-bottom','10','','','.w-product-buttons'),(983841,'deals','.w-product-buttons .notify-form p','margin-bottom','15','','','.w-product-buttons'),(983842,'deals','.w-compare .clear-compare-button','margin-bottom','15','','','.w-compare'),(983843,'deals','.w-files-catalog-widgets-files-catalog ','margin-bottom','50','','','.w-files-catalog-widgets-files-catalog'),(983844,'deals','.w-files-catalog-widgets-files-list .files','margin-bottom','50','','','.w-files-catalog-widgets-files-list'),(983845,'deals','.w-files-catalog-widgets-files-list .name','margin-bottom','10','','','.w-files-catalog-widgets-files-list'),(983846,'deals','.w-sample .multicart .name','margin-bottom','0','','','.w-sample'),(983847,'deals','.w-filters-simple select','margin-bottom','0','','','.w-filters-simple'),(983848,'deals','.w-cart-discount-coupon .title','margin-bottom','0','','','.w-cart-discount-coupon'),(983849,'deals','.w-cart-sub-total ','margin-bottom','20','','','.w-cart-sub-total'),(983850,'deals','.shipping-ico .heading-3','margin-bottom','10','','','.shipping-ico'),(983851,'deals','.order-summary .heading-2','margin-bottom','0','','','.order-summary'),(983852,'deals','.w-cart-gift-certificate .heading-4','margin-bottom','0','','','.w-cart-gift-certificate'),(983853,'deals','.w-cart-gift-certificate .gift-code p','margin-bottom','0','','','.w-cart-gift-certificate'),(983854,'deals','.w-product-bundle .bundle-total-price','margin-bottom','20','','','.w-product-bundle'),(983855,'deals','.w-product-in-bundles .bundle-total-price','margin-bottom','20','','','.w-product-in-bundles'),(983856,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-bottom','0','','','.b-products-listing'),(983857,'deals','.b-pagination .pagination','margin-bottom','20','','','.b-pagination'),(983858,'deals','.b-pagination ul.pagination','margin-bottom','0','','','.b-pagination'),(983859,'deals','.w-catalog-compare .list-compareproduct .stock','margin-bottom','0','','','.w-catalog-compare'),(983860,'deals','.w-product-properties-filters-widgets-chosen-filters .item','margin-bottom','5','','','.w-product-properties-filters-widgets-chosen-filters'),(983861,'deals','.w-product-multi-inventory .radio-attributes > span','margin-bottom','5','','','.w-product-multi-inventory'),(983862,'deals','.w-product-multi-inventory .radio-attributes','margin-bottom','15','','','.w-product-multi-inventory'),(983863,'deals','.b-products-listing .products-listing .radio-attributes','margin-bottom','15','','','.b-products-listing'),(983864,'deals','.b-products-listing .products-listing .radio-attributes > span','margin-bottom','5','','','.b-products-listing'),(983865,'deals','.w-product-collection .qty','margin-bottom','10','','','.w-product-collection'),(983866,'deals','.w-product-collection .select-box','margin-bottom','10','','','.w-product-collection'),(983867,'deals','.w-product-collection .title','margin-bottom','10','','','.w-product-collection'),(983868,'deals','.w-product-attributes .radio-attributes','margin-bottom','15','','','.w-product-attributes'),(983869,'deals','.w-product-attributes .radio-attributes > span','margin-bottom','5','','','.w-product-attributes'),(983870,'deals','.w-product-properties .property-ul','margin-bottom','0','','','.w-product-properties'),(983871,'deals','.w-product-properties .properties-table','margin-bottom','0','','','.w-product-properties'),(983872,'deals','.w-questionnaire-widgets-questionnaire .question','margin-bottom','20','','','.w-questionnaire-widgets-questionnaire'),(983873,'deals','.w-questionnaire-widgets-questionnaire .description','margin-bottom','10','','','.w-questionnaire-widgets-questionnaire'),(983874,'deals','.w-product-groups .radioBox label','margin-bottom','5','','','.w-product-groups'),(983875,'deals','.w-delivery-day .title','margin-bottom','10','','','.w-delivery-day'),(983876,'deals','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img','margin-bottom','10','','','.w-product-groups'),(983877,'deals','.w-product-custom-bundle .qty','margin-bottom','10','','','.w-product-custom-bundle'),(983878,'deals','.w-product-custom-bundle .select-box','margin-bottom','10','','','.w-product-custom-bundle'),(983879,'deals','.w-product-custom-bundle .title','margin-bottom','10','','','.w-product-custom-bundle'),(983880,'deals','.b-products-listing .products-listing.list-productlisting .attribute-qty-block > span','margin-bottom','4','','','.b-products-listing'),(983881,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-bottom','0','','','.w-catalog-pages-category-pages-last-list'),(983882,'deals','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-top-location-list'),(983883,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-bottom','0','','','.w-catalog-pages-category-pages-last-list-block'),(983884,'deals','.w-delivery-location-top-location-list .deliveryName','margin-bottom','10','','','.w-delivery-location-top-location-list'),(983885,'deals','.w-delivery-location-location-list .deliveryName','margin-bottom','10','','','.w-delivery-location-location-list'),(983886,'deals','.w-delivery-location-location-list .deliveryList li','margin-bottom','1','','','.w-delivery-location-location-list'),(983887,'deals','.w-delivery-location-location-list .deliveryListParrent','margin-bottom','10','','','.w-delivery-location-location-list'),(983888,'deals','.w-delivery-location-location-list ul','margin-bottom','0','','','.w-delivery-location-location-list'),(983889,'deals','.w-delivery-location-top-location-list .deliveryList li','margin-bottom','1','5630','','.w-delivery-location-top-location-list'),(983890,'deals','.w-delivery-location-featured-list .deliveryList ul','margin-bottom','0','','','.w-delivery-location-featured-list'),(983891,'deals','.w-delivery-location-location-list .deliveryListParrent a','margin-bottom','5','','','.w-delivery-location-location-list'),(983892,'deals','.w-delivery-location-featured-list .deliveryList > ul > li','margin-bottom','20','','','.w-delivery-location-featured-list'),(983893,'deals','.w-sale-category .ends','margin-bottom','20','','','.w-sale-category'),(983894,'deals','.w-sale-category .left','margin-bottom','30','','','.w-sale-category'),(983895,'deals','.w-sale-category .name','margin-bottom','20','','','.w-sale-category'),(983896,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-img','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(983897,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-name','margin-bottom','10','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(983898,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(983899,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(983900,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-img','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(983901,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-name','margin-bottom','10','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(983902,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(983903,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-bottom','30','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(983904,'deals','.w-delivery-location-list-by-page .description ul','margin-bottom','5','','','.w-delivery-location-list-by-page'),(983905,'deals','.w-delivery-location-list-by-page .item','margin-bottom','20','','','.w-delivery-location-list-by-page'),(983906,'deals','.w-delivery-location-list-by-page .item','margin-bottom','10','5660','','.w-delivery-location-list-by-page'),(983907,'deals','.w-delivery-location-cross-pages .description ul','margin-bottom','5','','','.w-delivery-location-cross-pages'),(983908,'deals','.w-delivery-location-cross-pages .item','margin-bottom','20','','','.w-delivery-location-cross-pages'),(983909,'deals','.w-delivery-location-cross-pages .item','margin-bottom','10','5660','','.w-delivery-location-cross-pages'),(983910,'deals','.w-cart-credit-amount ','margin-bottom','10','','','.w-cart-credit-amount'),(983911,'deals','.w-catalog-delivery-locations .item','margin-bottom','20','','','.w-catalog-delivery-locations'),(983912,'deals','.w-catalog-delivery-locations .description ul','margin-bottom','5','','','.w-catalog-delivery-locations'),(983913,'deals','.w-catalog-delivery-locations .name','margin-bottom','10','','','.w-catalog-delivery-locations'),(983914,'deals','.w-catalog-delivery-locations .item','margin-bottom','20','5630','','.w-catalog-delivery-locations'),(983915,'deals','.w-product-designer-designer .grnamebox .title-sortable','margin-bottom','10','','','.w-product-designer-designer'),(983916,'deals','.w-product-designer-designer .prodDesignerType label','margin-bottom','10','','','.w-product-designer-designer'),(983917,'deals','.w-press-reviews-widgets-press-reviews-small ','margin-bottom','12','','','.w-press-reviews-widgets-press-reviews-small'),(983918,'deals','.w-press-reviews-widgets-press-reviews ','margin-bottom','30','','','.w-press-reviews-widgets-press-reviews'),(983919,'deals','.w-press-reviews-widgets-press-reviews .image','margin-bottom','15','','','.w-press-reviews-widgets-press-reviews'),(983920,'deals','.w-press-reviews-widgets-press-reviews .reviews-list','margin-bottom','20','','','.w-press-reviews-widgets-press-reviews'),(983921,'deals','.w-press-reviews-widgets-press-reviews .date','margin-bottom','10','5630','','.w-press-reviews-widgets-press-reviews'),(983922,'deals','.w-press-reviews-widgets-press-reviews-list .image','margin-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(983923,'deals','.w-press-reviews-widgets-press-reviews-list .item','margin-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(983924,'deals','.w-press-reviews-widgets-press-reviews-list .product-name','margin-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(983925,'deals','.b-products-listing .productGroup','margin-bottom','10','','','.b-products-listing'),(983926,'deals','.w-gift-wrap-message-checkout .text','margin-bottom','20','','','.w-gift-wrap-message-checkout'),(983927,'deals','.w-support-system-filter .filter_cats','margin-bottom','0','','','.w-support-system-filter'),(983928,'deals','.w-support-system-listing .topic-products-listing .item','margin-bottom','30','','','.w-support-system-listing'),(983929,'deals','.w-communication-post .buttons','margin-bottom','20','','','.w-communication-post'),(983930,'deals','.w-rma-returns-history .content-messages .messages-table .top','margin-bottom','10','','','.w-rma-returns-history'),(983931,'deals','.w-rma-returns-history .filterMessages','margin-bottom','0','','','.w-rma-returns-history'),(983932,'deals','.w-rma-returns-history .column','margin-bottom','10','','screen and (max-width: 768px)','.w-rma-returns-history'),(983933,'deals','.w-rma-returns-history .column .title','margin-bottom','5','','screen and (max-width: 768px)','.w-rma-returns-history'),(983934,'deals','.w-rma-returns-history .column:last-child .title','margin-bottom','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(983935,'deals','.w-product-designer-designer .productDesignerBox ul','margin-bottom','0','','','.w-product-designer-designer'),(983936,'deals','.w-product-designer-designer .grnamebox','margin-bottom','10','','','.w-product-designer-designer'),(983937,'deals','.w-product-configurator .pc-item','margin-bottom','0','','','.w-product-configurator'),(983938,'deals','.w-product-configurator .pc-total-price','margin-bottom','20','','','.w-product-configurator'),(983939,'deals','.w-product-configurator .pc_row','margin-bottom','10','','','.w-product-configurator'),(983940,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-bottom','0','','','.w-catalog-pages-category-pages-list'),(983941,'deals','.w-predefined-promotion .heading-3','margin-bottom','20','','','.w-predefined-promotion'),(983942,'deals','.w-predefined-promotion .nextdiscount .heading','margin-bottom','20','','','.w-predefined-promotion'),(983943,'deals','.w-predefined-promotion .nextdiscount .promo-for-each','margin-bottom','10','','','.w-predefined-promotion'),(983944,'deals','.w-predefined-promotion .prom-multi-discount .heading','margin-bottom','10','','','.w-predefined-promotion'),(983945,'deals','.w-predefined-promotion .promo-cart-discount .master .heading','margin-bottom','10','','','.w-predefined-promotion'),(983946,'deals','.w-predefined-promotion .promo-cart-discount .master .item','margin-bottom','12','','','.w-predefined-promotion'),(983947,'deals','.w-predefined-promotion .promo-cart-discount .slave .item','margin-bottom','2','','','.w-predefined-promotion'),(983948,'deals','.w-predefined-promotion .promo-date','margin-bottom','10','','','.w-predefined-promotion'),(983949,'deals','.w-predefined-promotion .promo-item','margin-bottom','30','','','.w-predefined-promotion'),(983950,'deals','.w-predefined-promotion .promo-salemaker .item','margin-bottom','2','','','.w-predefined-promotion'),(983951,'deals','.w-supplier-purchase-supplier-products .item','margin-bottom','10','','','.w-supplier-purchase-supplier-products'),(983954,'deals','.w-subscribers .heading-3','margin-bottom','0','','','.w-subscribers'),(983955,'deals','.preFooter .w-contacts > div','margin-bottom','10','','','.preFooter'),(983956,'deals','.w-top-categories .item','margin-bottom','25','','','.w-top-categories'),(983957,'deals','.w-categories .categories h2','margin-bottom','0','','','.w-categories'),(983958,'deals','.w-categories .item','margin-bottom','10','','','.w-categories'),(983959,'deals','.filterLine .before','margin-bottom','-2','','','.filterLine'),(983960,'deals','.w-filters .filter-widget-horizontal .filter-box-head','margin-bottom','0','','','.w-filters'),(983961,'deals','.w-categories .categories','margin-bottom','0','','','.w-categories'),(983962,'deals','.b-products-listing .products-listing .button-view','margin-bottom','10','','','.b-products-listing'),(983963,'deals','.b-products-listing .products-listing .personalCatalog > span','margin-bottom','10','','','.b-products-listing'),(983964,'deals','.w-product-quantity-discounts .quantity-discounts-content .item','margin-bottom','15','','','.w-product-quantity-discounts'),(983966,'deals','.savings-ico .heading-3','margin-bottom','10','','','.savings-ico'),(983967,'deals','.order-summary .w-image','margin-bottom','-10','','','.order-summary'),(983971,'deals','.headerWrap .w-account .my-acc-link','margin-bottom','0','5639','','.headerWrap'),(983972,'deals','.bannersWrap .box-block.type-12 > .block:nth-child(1)','margin-bottom','3','5630','','.bannersWrap'),(983973,'deals','.w-top-categories .item','margin-bottom','10','5644','','.w-top-categories'),(983974,'deals','.w-subscribers .heading-3','margin-bottom','10','5630','','.w-subscribers'),(983975,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li > .no-link','margin-bottom','5','','','.preFooter'),(983976,'deals','.b-info .info li','margin-bottom','0','','','.b-info'),(983977,'deals','.b-info .info ul','margin-bottom','0','','','.b-info'),(983978,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-1 > li > .no-link','margin-bottom','0','5630','','.headerWrap'),(983979,'deals','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','margin-bottom','10','','','.w-account-personal-catalog'),(983980,'deals','.w-account-personal-catalog .list-row-action li','margin-bottom','0','','','.w-account-personal-catalog'),(983981,'deals','.w-account-personal-catalog .list-row-action ul','margin-bottom','-1','','','.w-account-personal-catalog'),(983982,'deals','.w-cart-discount-coupon .discount-box','margin-bottom','10','','','.w-cart-discount-coupon'),(983983,'deals','.breadcrumb-box ','margin-bottom','20','','','.breadcrumb-box'),(983984,'deals','.w-cart-shipping-estimator .left-area','margin-bottom','20','5630','','.w-cart-shipping-estimator'),(983985,'deals','.w-promotions-widgets-promotions .promotion-data-2 .save','margin-bottom','30','','','.w-promotions-widgets-promotions'),(983986,'deals','.w-promotions-widgets-promotions .select-box','margin-bottom','5','','','.w-promotions-widgets-promotions'),(983995,'deals','.account-address-book .address_book .row-buttons a','margin-bottom','0','','','.account-address-book'),(983996,'deals','.account-address-book .address_book h1','margin-bottom','18','','','.account-address-book'),(983997,'deals','.account-address-book .address_book h2','margin-bottom','15','','','.account-address-book'),(983998,'deals','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-bottom','15','','','.account-address-book'),(983999,'deals','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-bottom','10','','','.account-address-book'),(984000,'deals','.account-address-book .address_book_row h2 a','margin-bottom','0','','','.account-address-book'),(984001,'deals','.account-address-book .buttonBox .info','margin-bottom','0','','','.account-address-book'),(984002,'deals','.account-address-book .address_book_row .column','margin-bottom','12','5630','','.account-address-book'),(984003,'deals','.account-address-book .address_book_row .column + .column','margin-bottom','12','5630','','.account-address-book'),(984004,'deals','.account-address-book .topInfo > div','margin-bottom','12','5630','','.account-address-book'),(984005,'deals','.account-address-book .topInfo > div + div','margin-bottom','12','5630','','.account-address-book'),(984014,'deals','.account-order-pay .buttons','margin-bottom','20','','','.account-order-pay'),(984015,'deals','.account-order-pay .history_info','margin-bottom','20','','','.account-order-pay'),(984016,'deals','.account-order-pay .history_info > div','margin-bottom','12','5639','','.account-order-pay'),(984017,'deals','.account-password-wrap .buttonedit','margin-bottom','0','','','.account-password-wrap'),(984018,'deals','.account-password-wrap .buttons','margin-bottom','20','','','.account-password-wrap'),(984019,'deals','.account-samples .buttonBox','margin-bottom','15','','','.account-samples'),(984020,'deals','.account-samples .order_history_table h2','margin-bottom','8','','','.account-samples'),(984021,'deals','.account-samples .orders-table .item','margin-bottom','10','5639','','.account-samples'),(984022,'deals','.account-sample-info .buttons','margin-bottom','20','','','.account-sample-info'),(984023,'deals','.account-sample-info .history_info','margin-bottom','20','','','.account-sample-info'),(984024,'deals','.account-sample-info .history_info > div','margin-bottom','12','5639','','.account-sample-info'),(984025,'deals','.catalog-product-wrap .pn-direction','margin-bottom','15','','','.catalog-product-wrap'),(984026,'deals','.catalog-product-wrap .rating, .catalog-product-wrap .ratingCounts','margin-bottom','0','','','.catalog-product-wrap'),(984027,'deals','.shopping-cart-index .closeable-heading','margin-bottom','10','','','.shopping-cart-index'),(984028,'deals','.shopping-cart-index .closeable-heading .heading-2','margin-bottom','0','','','.shopping-cart-index'),(984029,'deals','.shopping-cart-index .closeable-heading .heading-3','margin-bottom','0','','','.shopping-cart-index'),(984030,'deals','.checkout-index-wrap .closeable-heading .heading-2','margin-bottom','0','','','.checkout-index-wrap'),(984031,'deals','.checkout-index-wrap .dob-hide','margin-bottom','-10','','','.checkout-index-wrap'),(984032,'deals','.checkout-index-wrap .edit-address-popup .addresses .address-item','margin-bottom','20','','','.checkout-index-wrap'),(984033,'deals','.checkout-index-wrap .input-wrapper','margin-bottom','10','','','.checkout-index-wrap'),(984034,'deals','.b-form .columns','margin-bottom','10','','','.b-form'),(984035,'deals','.b-bottom .cart-options .buttons','margin-bottom','0','','','.b-bottom'),(984036,'deals','.b-bottom .pop-up-content .buttons','margin-bottom','0','','','.b-bottom'),(984037,'deals','.b-slick .slick-dots li','margin-bottom','0','','','.b-slick'),(984038,'deals','.success-page .order_totals','margin-bottom','30','','','.success-page'),(984039,'deals','.success-page .page-success .text-1','margin-bottom','0','3','','.success-page'),(984040,'deals','.success-page .w-order-products','margin-bottom','20','','','.success-page'),(984041,'deals','.w-cart-products .checkout-attention-message','margin-bottom','10','','','.w-cart-products'),(984042,'deals','.b-multi-page-checkout .multi-page-checkout .buttons','margin-bottom','0','','','.b-multi-page-checkout'),(984043,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-step','margin-bottom','5','','','.b-multi-page-checkout'),(984044,'deals','.bannersWrap .leftBanner .banner-item:first-of-type','margin-bottom','3','','','.bannersWrap'),(984045,'deals','.footer-menu .level-1 > li > a, .footer-menu .level-1 > li > .no-link','margin-bottom','10','','','.footer-menu'),(984046,'deals','.footer-menu .level-3 > li > a','margin-bottom','5','5639','','.footer-menu'),(984047,'deals','.footer-menu .level-3 > li.back-button','margin-bottom','20','5639','','.footer-menu'),(984048,'deals','.payment-method-tf label','margin-bottom','10','','','.payment-method-tf'),(984049,'deals','.accout-box ','margin-bottom','30','','','.accout-box'),(984050,'deals','.accout-box select[data-type=\"vat_number\"]','margin-bottom','0','','','.accout-box'),(984051,'deals','.w-account-customer-additional-field .field-type-checkbox','margin-bottom','10','','','.w-account-customer-additional-field'),(984052,'deals','.w-account-customer-additional-field .field-type-text','margin-bottom','10','','','.w-account-customer-additional-field'),(984055,'deals','.w-menu-slider ul, .w-menu-slider li','margin-bottom','0','','','.w-menu-slider'),(984056,'deals','.b-bottom .cart-options .buttons','margin-bottom_important','important','','','.b-bottom'),(984057,'deals','.heading-4 .edit, h4 .edit','margin-left','10','4','',''),(984058,'deals','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(984059,'deals','.message.success','margin-left','-40','3','',''),(984060,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(984062,'deals','.w-catalog-items-on-page select','margin-left','10','','','.w-catalog-items-on-page'),(984063,'deals','.w-chat .w-chat-box','margin-left','5','','','.w-chat'),(984064,'deals','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-left','0','','','.b-fancybox'),(984065,'deals','.p-quick-order-index ul.token-input-list','margin-left','5','','','.p-quick-order-index'),(984066,'deals','.p-quick-order-index .filters .clear','margin-left','15','','','.p-quick-order-index'),(984067,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','margin-left','5','','','.p-quick-order-index'),(984068,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.p-quick-order-index'),(984069,'deals','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(984073,'deals','.w-promotions .promo-salemaker .item','margin-left','2','','','.w-promotions'),(984074,'deals','.w-promotions .promo-cart-discount .slave .item','margin-left','2','','','.w-promotions'),(984075,'deals','.w-promotions .promo-cart-discount .master .item','margin-left','12','','','.w-promotions'),(984076,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','-17','3','','.b-warehouses-popup'),(984077,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-left','0','','','.b-warehouses-popup'),(984079,'deals','.b-form .password-forgotten-link','margin-left','0','','','.b-form'),(984080,'deals','.b-messages .messages-menu ul','margin-left','0','','','.b-messages'),(984081,'deals','.b-messages .msv_content','margin-left','0','','','.b-messages'),(984082,'deals','.b-messages .msv_history','margin-left','0','','','.b-messages'),(984083,'deals','.b-messages .messages-menu li','margin-left','0','','','.b-messages'),(984084,'deals','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(984085,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-left','5','','','.b-messages'),(984086,'deals','.w-sitemap-delivery-location > ul > li > ul','margin-left','0','','','.w-sitemap-delivery-location'),(984087,'deals','.w-sitemap-delivery-location > ul','margin-left','0','','','.w-sitemap-delivery-location'),(984088,'deals','.b-fancybox #fancybox-loading','margin-left','-22','','','.b-fancybox'),(984089,'deals','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(984091,'deals','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(984092,'deals','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(984093,'deals','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(984094,'deals','.w-coupons-and-vauchers-checkout .btn-remove','margin-left','-30','','','.w-coupons-and-vauchers-checkout'),(984095,'deals','.w-checkout-bonus-points .btn-remove','margin-left','-30','','','.w-checkout-bonus-points'),(984096,'deals','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(984097,'deals','.w-menu-horizontal li','margin-left','0','','','.w-menu-horizontal'),(984098,'deals','.w-filters .input-checkbox','margin-left','0','','','.w-filters'),(984099,'deals','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(984100,'deals','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(984101,'deals','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(984102,'deals','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','margin-left','7','3','','.order-summary'),(984103,'deals','.buttons .right-buttons .btn','margin-left','10','','',''),(984104,'deals','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(984105,'deals','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(984106,'deals','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(984107,'deals','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(984108,'deals','.b-form .col-3 + .col-3','margin-left','3','','','.b-form'),(984109,'deals','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(984110,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-left','0','','','.b-select-suggest'),(984111,'deals','.w-socials > li','margin-left','10','','','.w-socials'),(984113,'deals','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(984114,'deals','.b-delete-account .delete-box span','margin-left','10','','','.b-delete-account'),(984115,'deals','.w-socials > li','margin-left','10','','','.w-socials'),(984116,'deals','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(984117,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(984118,'deals','.w-catalog-listing-look .list','margin-left','5','','','.w-catalog-listing-look'),(984119,'deals','.view-all .btn','margin-left','10','4','',''),(984120,'deals','.w-socials > li','margin-left','10','','','.w-socials'),(984121,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(984122,'deals','.w-tabs .tab-navigation','margin-left','0','','','.w-tabs'),(984123,'deals','.w-tabs .tab-li','margin-left','0','','','.w-tabs'),(984124,'deals','.w-socials > li','margin-left','10','','','.w-socials'),(984125,'deals','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(984126,'deals','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(984127,'deals','.w-cart-credit-amount .btn-remove','margin-left','-30','','','.w-cart-credit-amount'),(984128,'deals','.heading-3 .right-text, h3 .right-text','margin-left','10','','',''),(984129,'deals','.w-product-reviews .reviews-list','margin-left','0','','','.w-product-reviews'),(984130,'deals','.b-products-listing .products-listing .bonus-points-price','margin-left','-20','3','','.b-products-listing'),(984132,'deals','.w-filters .filter-ul-content','margin-left','0','','','.w-filters'),(984133,'deals','.heading-3 .edit, h3 .edit','margin-left','10','4','',''),(984134,'deals','.w-checkout-shipping-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-shipping-address'),(984135,'deals','.b-dropdown .dropdown .dropdown-toggle','margin-left','5','4','','.b-dropdown'),(984136,'deals','.w-cart-bonus-points .btn-remove','margin-left','-30','','','.w-cart-bonus-points'),(984137,'deals','.b-select-suggest .select2-drop-mask','margin-left','0','','','.b-select-suggest'),(984138,'deals','.w-checkout-shipping-choice input:checked + span:before','margin-left','-5','','','.w-checkout-shipping-choice'),(984139,'deals','.products-quick-index ul','margin-left','0','','',''),(984140,'deals','.w-top-categories .categories h2','margin-left','0','','','.w-top-categories'),(984141,'deals','.b-form .checkbox-style','margin-left','0','','','.b-form'),(984142,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(984143,'deals','.b-form .addresses .address-item input[type=\"radio\"]','margin-left','0','','','.b-form'),(984144,'deals','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(984145,'deals','.b-form .columns .col-2:nth-child(2n)','margin-left','0','5660','','.b-form'),(984146,'deals','.w-product-quantity .qty_packs .price_1','margin-left','15','4','','.w-product-quantity'),(984147,'deals','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(984148,'deals','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(984149,'deals','.b-select-suggest .select2-container','margin-left','0','','','.b-select-suggest'),(984150,'deals','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(984151,'deals','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(984152,'deals','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(984153,'deals','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(984154,'deals','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(984155,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(984156,'deals','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(984159,'deals','.w-checkout-credit-amount .btn-remove','margin-left','-30','','','.w-checkout-credit-amount'),(984160,'deals','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(984161,'deals','.b-autocomplete .ui-autocomplete','margin-left','0','','','.b-autocomplete'),(984162,'deals','.w-top-categories .categories','margin-left','-10','5644','','.w-top-categories'),(984163,'deals','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(984164,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(984166,'deals','.b-select-suggest .select2-results .select2-result-label','margin-left','0','','','.b-select-suggest'),(984167,'deals','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(984168,'deals','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(984169,'deals','.w-checkout-billing-address .addresses .address-item:nth-child(2n + 1)','margin-left','0','','','.w-checkout-billing-address'),(984170,'deals','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(984172,'deals','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(984173,'deals','.b-fancybox .fancybox-error','margin-left','0','','','.b-fancybox'),(984174,'deals','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(984175,'deals','.w-cart-compare .product .image','margin-left','0','','','.w-cart-compare'),(984176,'deals','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(984177,'deals','.b-bottom .confirm-popup .buttons .btn','margin-left','20','','','.b-bottom'),(984178,'deals','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(984179,'deals','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-left','0','','','.b-switch'),(984180,'deals','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(984181,'deals','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(984182,'deals','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(984183,'deals','.w-cart-give-away .ga_attributes > div','margin-left','1','','','.w-cart-give-away'),(984184,'deals','.w-cart-checkout-btn .or-text','margin-left','0','','','.w-cart-checkout-btn'),(984185,'deals','.w-cart-give-away .ga_column','margin-left','2','','','.w-cart-give-away'),(984186,'deals','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(984187,'deals','.w-social-links a','margin-left','5','','','.w-social-links'),(984188,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(984189,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-left','0','','','.b-select-suggest'),(984190,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-left','0','','','.b-select-suggest'),(984191,'deals','.b-select-suggest .select2-container-multi .select2-choices','margin-left','0','','','.b-select-suggest'),(984192,'deals','.b-select-suggest .select2-results ul.select2-result-sub','margin-left','0','','','.b-select-suggest'),(984193,'deals','.b-select-suggest .select2-search input','margin-left','0','','','.b-select-suggest'),(984194,'deals','.b-select-suggest .select2-search','margin-left','0','','','.b-select-suggest'),(984195,'deals','.w-socials > li','margin-left','10','','','.w-socials'),(984198,'deals','.w-menu-horizontal ul','margin-left','0','','','.w-menu-horizontal'),(984200,'deals','.w-login-block .password-info .info-popup','margin-left','0','','','.w-login-block'),(984201,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','margin-left','5','','','.b-data-table'),(984202,'deals','.w-catalog-b2b-add-button .add-b2b-products','margin-left','50','','','.w-catalog-b2b-add-button'),(984203,'deals','.b-products-listing .products-listing .description ul','margin-left','0','','','.b-products-listing'),(984204,'deals','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(984205,'deals','.w-quote-checkout-btn','margin-left','0','','','.w-quote-checkout-btn'),(984206,'deals','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(984207,'deals','.w-checkout-gdpr .privacy-row','margin-left','0','','','.w-checkout-gdpr'),(984208,'deals','.w-checkout-gdpr .bootstrap-switch','margin-left','25','','','.w-checkout-gdpr'),(984209,'deals','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(984210,'deals','.w-socials > li','margin-left','10','','','.w-socials'),(984211,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(984212,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(984213,'deals','.w-taxable label','margin-left','5','','','.w-taxable'),(984214,'deals','.w-taxable select','margin-left','5','','','.w-taxable'),(984215,'deals','.heading-4 .right-text, h4 .right-text','margin-left','10','','',''),(984216,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-left','0','','',''),(984217,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-left','0','','','.b-h-inline'),(984218,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-left','0','','','.b-tracking-numbers'),(984219,'deals','.products-quick-index ul.token-input-list','margin-left','0','','',''),(984220,'deals','.b-form .required-message','margin-left','0','','','.b-form'),(984221,'deals','.w-catalog-listing-look .b2b','margin-left','5','','','.w-catalog-listing-look'),(984222,'deals','.b-page-name .page-name','margin-left','0','','','.b-page-name'),(984223,'deals','.w-cart-listing .points-redeem','margin-left','-25','3','','.w-cart-listing'),(984224,'deals','.w-cart-listing .remove-btn','margin-left','0','5639','','.w-cart-listing'),(984225,'deals','.w-cart-give-away .ga_column','margin-left','0','5630','','.w-cart-give-away'),(984226,'deals','.w-cart-discount-coupon .btn-remove','margin-left','-30','','','.w-cart-discount-coupon'),(984227,'deals','.w-brands .brands-listing > div','margin-left','0','','','.w-brands'),(984229,'deals','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-left','0','','','.b-fancybox'),(984230,'deals','.b-dropdown .dropdown .dropdown-menu','margin-left','0','','','.b-dropdown'),(984231,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(984232,'deals','.w-account-apply-certificate .gift-certificate-input','margin-left','0','','','.w-account-apply-certificate'),(984233,'deals','.w-socials .post_item_img','margin-left','0','','','.w-socials'),(984234,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-left','0','','','.w-menu-style-2'),(984235,'deals','.w-filters .view_more','margin-left','5','4','','.w-filters'),(984236,'deals','.products-quick-index .token-input-list','margin-left','0','','',''),(984237,'deals','.b-social-login .social-login-text-2','margin-left','10','3','','.b-social-login'),(984240,'deals','.w-menu-big ul','margin-left','0','','','.w-menu-big'),(984241,'deals','.w-menu-big li','margin-left','0','','','.w-menu-big'),(984243,'deals','.b-social-login .social-login-text-2','margin-left','10','4','','.b-social-login'),(984244,'deals','.b-form .required-message-wrap','margin-left','0','','','.b-form'),(984245,'deals','.b-product-images .media-popup .slick-dots','margin-left','0','','','.b-product-images'),(984246,'deals','.b-product-images .media-popup .slick-dots li','margin-left','5','','','.b-product-images'),(984247,'deals','.b-product-images .media-popup button.slick-prev:active','margin-left','-3','','','.b-product-images'),(984248,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(984249,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(984250,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(984251,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(984252,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-left','-40','','','.b-menu-lev_vis-click_icon'),(984253,'deals','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-left','0','','','.b-menu-style'),(984254,'deals','.b-trade-approval .steps-bar','margin-left','0','','','.b-trade-approval'),(984255,'deals','.b-trade-approval .col-3 + .col-3','margin-left','3','','','.b-trade-approval'),(984256,'deals','.w-account-personal-catalog .list-switcher','margin-left','0','','','.w-account-personal-catalog'),(984257,'deals','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-left','0','','','.w-catalog-additional-images'),(984258,'deals','.w-delivery-day .left-count','margin-left','2','','','.w-delivery-day'),(984259,'deals','.w-delivery-day .left-text-right','margin-left','2','','','.w-delivery-day'),(984260,'deals','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-left','0','','','.b-cookie-notice'),(984261,'deals','.lowestPricedBox .w-banner .banner','margin-left','-15','','','.lowestPricedBox'),(984262,'deals','.shopByCollectionBox .w-banner .banner','margin-left','-15','','','.shopByCollectionBox'),(984263,'deals','.preFooter .w-banner .single_banner','margin-left','2','','','.preFooter'),(984264,'deals','.b-slick .slick-list','margin-left','0','','','.b-slick'),(984265,'deals','.b-slick .slick-track','margin-left','auto','','','.b-slick'),(984266,'deals','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-left','-20','','','.b-slick'),(984267,'deals','.LeftCategories .w-menu-simple ul','margin-left','0','','','.LeftCategories'),(984268,'deals','.w-breadcrumb .breadcrumb-ul','margin-left','0','','','.w-breadcrumb'),(984269,'deals','.w-quote .image','margin-left','-90','','','.w-quote'),(984270,'deals','.w-quote .multicart .name','margin-left','-10','','','.w-quote'),(984271,'deals','.b-quantity .qty-box input','margin-left','3','','','.b-quantity'),(984272,'deals','.w-product-sale-ends .left-count','margin-left','2','','','.w-product-sale-ends'),(984273,'deals','.w-product-sale-ends .left-text-right','margin-left','2','','','.w-product-sale-ends'),(984274,'deals','.w-compare .image','margin-left','-80','','','.w-compare'),(984275,'deals','.w-files-catalog-widgets-files-list .file','margin-left','-20','3','','.w-files-catalog-widgets-files-list'),(984276,'deals','.w-files-catalog-widgets-files-list .files','margin-left','10','','','.w-files-catalog-widgets-files-list'),(984277,'deals','.w-sample .image','margin-left','-90','','','.w-sample'),(984278,'deals','.w-sample .multicart .name','margin-left','-10','','','.w-sample'),(984279,'deals','.w-cart-sub-total ','margin-left','0','','','.w-cart-sub-total'),(984280,'deals','.shipping-ico .heading-3','margin-left','0','','','.shipping-ico'),(984281,'deals','.order-summary .heading-2','margin-left','0','','','.order-summary'),(984282,'deals','.w-cart-gift-certificate .heading-4','margin-left','0','','','.w-cart-gift-certificate'),(984283,'deals','.w-cart-gift-certificate .gift-code p','margin-left','0','','','.w-cart-gift-certificate'),(984284,'deals','.w-cart-order-reference .input-apple button','margin-left','10','','','.w-cart-order-reference'),(984285,'deals','.w-cart-gift-certificate .btn','margin-left','10','','','.w-cart-gift-certificate'),(984286,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-left','0','','','.b-products-listing'),(984287,'deals','.b-pagination .pagination .next-pages','margin-left','5','','','.b-pagination'),(984288,'deals','.b-pagination .pagination .page-number','margin-left','5','','','.b-pagination'),(984289,'deals','.b-pagination .pagination .prev-pages','margin-left','5','','','.b-pagination'),(984290,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','margin-left','5','','','.b-pagination'),(984291,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','margin-left','5','','','.b-pagination'),(984292,'deals','.b-pagination .pagination span','margin-left','5','2','','.b-pagination'),(984293,'deals','.b-pagination ul.pagination','margin-left','0','','','.b-pagination'),(984294,'deals','.w-product-quantity-discounts .item:nth-child(2n)','margin-left','2','','','.w-product-quantity-discounts'),(984295,'deals','.w-product-multi-inventory .select-box:nth-child(2n)','margin-left','4','','','.w-product-multi-inventory'),(984296,'deals','.w-product-properties-filters-widgets-chosen-filters .item','margin-left','0','','','.w-product-properties-filters-widgets-chosen-filters'),(984297,'deals','.w-product-properties-filters-widgets-chosen-filters .remove','margin-left','5','','','.w-product-properties-filters-widgets-chosen-filters'),(984298,'deals','.p-sample-checkout-index .order-summary .heading-2','margin-left','-100','3','','.p-sample-checkout-index'),(984299,'deals','.w-product-attributes .select-box:nth-child(2n)','margin-left','4','','','.w-product-attributes'),(984300,'deals','.w-product-properties .property-ul','margin-left','0','','','.w-product-properties'),(984301,'deals','.w-product-properties .properties-table','margin-left','0','','','.w-product-properties'),(984302,'deals','.b-products-listing .mix-attributes .mult-qty-input .qty-box > input','margin-left','3','','','.b-products-listing'),(984303,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list'),(984304,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list-block'),(984305,'deals','.w-delivery-location-top-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-top-location-list'),(984306,'deals','.w-delivery-location-location-list .deliveryList li','margin-left','1','','','.w-delivery-location-location-list'),(984307,'deals','.w-delivery-location-location-list ul','margin-left','0','','','.w-delivery-location-location-list'),(984308,'deals','.w-delivery-location-top-location-list .deliveryList li','margin-left','0','5630','','.w-delivery-location-top-location-list'),(984309,'deals','.w-delivery-location-featured-list .deliveryList ul','margin-left','0','','','.w-delivery-location-featured-list'),(984310,'deals','.w-sale-category .left-count','margin-left','2','','','.w-sale-category'),(984311,'deals','.w-sale-category .left-text-right','margin-left','2','','','.w-sale-category'),(984312,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(984313,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(984314,'deals','.w-delivery-location-list-by-page .description ul','margin-left','0','','','.w-delivery-location-list-by-page'),(984315,'deals','.w-delivery-location-list-by-page .item','margin-left','1','','','.w-delivery-location-list-by-page'),(984316,'deals','.w-delivery-location-list-by-page .item','margin-left','0','5660','','.w-delivery-location-list-by-page'),(984317,'deals','.w-delivery-location-cross-pages .description ul','margin-left','0','','','.w-delivery-location-cross-pages'),(984318,'deals','.w-delivery-location-cross-pages .item','margin-left','1','','','.w-delivery-location-cross-pages'),(984319,'deals','.w-delivery-location-cross-pages .item','margin-left','0','5660','','.w-delivery-location-cross-pages'),(984320,'deals','.w-catalog-delivery-locations .item','margin-left','1','','','.w-catalog-delivery-locations'),(984321,'deals','.w-catalog-delivery-locations .description ul','margin-left','0','','','.w-catalog-delivery-locations'),(984322,'deals','.w-catalog-delivery-locations .item','margin-left','0','5630','','.w-catalog-delivery-locations'),(984323,'deals','.w-product-designer-designer .prodDesignerType label','margin-left','10','','','.w-product-designer-designer'),(984324,'deals','.w-press-reviews-widgets-press-reviews .date','margin-left','0','5630','','.w-press-reviews-widgets-press-reviews'),(984325,'deals','.w-press-reviews-widgets-press-reviews-list .image','margin-left','0','','','.w-press-reviews-widgets-press-reviews-list'),(984326,'deals','.w-press-reviews-widgets-press-reviews-list .item','margin-left','0','','','.w-press-reviews-widgets-press-reviews-list'),(984327,'deals','.w-support-system-filter .filter_cats','margin-left','0','','','.w-support-system-filter'),(984328,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','margin-left','2','','','.w-rma-returns-history'),(984329,'deals','.w-rma-returns-history .filterMessages','margin-left','-3','','','.w-rma-returns-history'),(984330,'deals','.w-rma-returns-history .linkButton','margin-left','5','4','','.w-rma-returns-history'),(984331,'deals','.w-rma-returns-history .column:last-child .title','margin-left','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(984332,'deals','.w-product-designer-designer .productDesignerBox ul','margin-left','0','','','.w-product-designer-designer'),(984333,'deals','.w-product-configurator .pc-item','margin-left','0','','','.w-product-configurator'),(984334,'deals','.b-products-listing .promos-info .promo-name','margin-left','-30','','','.b-products-listing'),(984335,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-left','0','','','.w-catalog-pages-category-pages-list'),(984336,'deals','.w-multi-cart-save-cart button','margin-left','20','','','.w-multi-cart-save-cart'),(984337,'deals','.w-predefined-promotion .promo-cart-discount .master .item','margin-left','12','','','.w-predefined-promotion'),(984338,'deals','.w-predefined-promotion .promo-cart-discount .slave .item','margin-left','2','','','.w-predefined-promotion'),(984339,'deals','.w-predefined-promotion .promo-salemaker .item','margin-left','2','','','.w-predefined-promotion'),(984341,'deals','.headerWrap .searchIcon','margin-left','15','','','.headerWrap'),(984342,'deals','.w-top-categories .item','margin-left','25','','','.w-top-categories'),(984343,'deals','.w-categories .categories h2','margin-left','0','','','.w-categories'),(984344,'deals','.w-categories .item','margin-left','10','','','.w-categories'),(984345,'deals','.filterLine .before','margin-left','0','','','.filterLine'),(984346,'deals','.filterLine .choose-filters li .btn-clear','margin-left','5','4','','.filterLine'),(984347,'deals','.w-filters .open','margin-left','5','3','','.w-filters'),(984348,'deals','.w-categories .categories','margin-left','-10','','','.w-categories'),(984349,'deals','.b-quantity .qty-box input[type=\'text\']','margin-left','3','','','.b-quantity'),(984350,'deals','.w-product-groups .radioBox label','margin-left','0','','','.w-product-groups'),(984351,'deals','.messageBox .info','margin-left','-40','3','',''),(984352,'deals','.savings-ico .heading-3','margin-left','0','','','.savings-ico'),(984353,'deals','.order-summary .w-image','margin-left','-20','','','.order-summary'),(984354,'deals','.headerWrap .w-account .my-acc-link','margin-left','0','5639','','.headerWrap'),(984355,'deals','.w-top-categories .item','margin-left','10','5644','','.w-top-categories'),(984356,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li > .no-link','margin-left','0','','','.preFooter'),(984357,'deals','.b-info .info','margin-left','-40','3','','.b-info'),(984358,'deals','.b-info .info li','margin-left','0','','','.b-info'),(984359,'deals','.b-info .info ul','margin-left','0','','','.b-info'),(984360,'deals','.w-account-personal-catalog .list-row-action li','margin-left','0','','','.w-account-personal-catalog'),(984361,'deals','.w-account-personal-catalog .list-row-action ul','margin-left','-1','','','.w-account-personal-catalog');
INSERT INTO `themes_styles` VALUES (984362,'deals','.w-account-personal-catalog .buy-box a + a','margin-left','10','5630','','.w-account-personal-catalog'),(984363,'deals','.w-multi-cart-save-cart button','margin-left','10','5660','','.w-multi-cart-save-cart'),(984364,'deals','.w-cart-discount-coupon .title','margin-left','10','4','','.w-cart-discount-coupon'),(984365,'deals','.w-cart-checkout-btn .with-card','margin-left','15','4','','.w-cart-checkout-btn'),(984372,'deals','.account-address-book .address_book .row-buttons a','margin-left','0','','','.account-address-book'),(984373,'deals','.account-address-book .address_book h1','margin-left','0','','','.account-address-book'),(984374,'deals','.account-address-book .address_book h2','margin-left','0','','','.account-address-book'),(984375,'deals','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-left','2','','','.account-address-book'),(984376,'deals','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-left','0','','','.account-address-book'),(984377,'deals','.account-address-book .address_book_row h2 a','margin-left','15','','','.account-address-book'),(984378,'deals','.account-address-book .buttonBox .info','margin-left','0','','','.account-address-book'),(984379,'deals','.account-address-book .address_book_row .column','margin-left','0','5630','','.account-address-book'),(984380,'deals','.account-address-book .address_book_row .column + .column','margin-left','0','5630','','.account-address-book'),(984381,'deals','.account-address-book .topInfo > div','margin-left','0','5630','','.account-address-book'),(984382,'deals','.account-address-book .topInfo > div + div','margin-left','0','5630','','.account-address-book'),(984388,'deals','.account-order-pay .buttons','margin-left','0','','','.account-order-pay'),(984389,'deals','.account-order-pay .history_info','margin-left','0','','','.account-order-pay'),(984390,'deals','.account-order-pay .history_info > div','margin-left','0','5639','','.account-order-pay'),(984391,'deals','.account-password-wrap .buttonedit','margin-left','0','','','.account-password-wrap'),(984392,'deals','.account-samples .buttonBox','margin-left','0','','','.account-samples'),(984393,'deals','.account-samples .order_history_table h2','margin-left','0','','','.account-samples'),(984394,'deals','.account-sample-info .buttons','margin-left','0','','','.account-sample-info'),(984395,'deals','.account-sample-info .history_info','margin-left','0','','','.account-sample-info'),(984396,'deals','.account-sample-info .history_info > div','margin-left','0','5639','','.account-sample-info'),(984397,'deals','.shopping-cart-index .closeable-heading','margin-left','0','','','.shopping-cart-index'),(984398,'deals','.shopping-cart-index .closeable-heading .heading-2','margin-left','0','','','.shopping-cart-index'),(984399,'deals','.shopping-cart-index .closeable-heading .heading-3','margin-left','0','','','.shopping-cart-index'),(984400,'deals','.b-bottom .cart-options .buttons','margin-left','0','','','.b-bottom'),(984401,'deals','.b-bottom .pop-up-content .buttons','margin-left','0','','','.b-bottom'),(984402,'deals','.b-slick .slick-dots li','margin-left','5','','','.b-slick'),(984403,'deals','.success-page .page-success .text-1','margin-left','-50','3','','.success-page'),(984404,'deals','.w-cart-products .checkout-attention-message','margin-left','0','','','.w-cart-products'),(984405,'deals','.b-multi-page-checkout .multi-page-checkout .buttons','margin-left','0','','','.b-multi-page-checkout'),(984406,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','margin-left','15','4','','.b-multi-page-checkout'),(984408,'deals','.footer-menu .level-3 > li.back-button','margin-left','0','5639','','.footer-menu'),(984409,'deals','.accout-box select[data-type=\"vat_number\"]','margin-left','0','','','.accout-box'),(984410,'deals','.w-catalog-paging .next','margin-left','2','','','.w-catalog-paging'),(984414,'deals','.w-menu-slider ul, .w-menu-slider li','margin-left','0','','','.w-menu-slider'),(984415,'deals','.b-bottom .cart-options .buttons','margin-left_important','important','','','.b-bottom'),(984416,'deals','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(984417,'deals','.w-checkout-billing-address .btn-cancel','margin-right','20','','','.w-checkout-billing-address'),(984418,'deals','.w-catalog-items-on-page select','margin-right','10','','','.w-catalog-items-on-page'),(984419,'deals','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-right','0','','','.b-fancybox'),(984420,'deals','.p-quick-order-index ul.token-input-list','margin-right','30','','','.p-quick-order-index'),(984421,'deals','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(984422,'deals','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(984426,'deals','.w-promotions .prom-multi-discount > .heading','margin-right','5','3','','.w-promotions'),(984427,'deals','.w-promotions .nextdiscount .heading','margin-right','10','3','','.w-promotions'),(984428,'deals','.w-promotions .icon','margin-right','15','','','.w-promotions'),(984429,'deals','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','margin-right','5','3','','.w-promotions'),(984430,'deals','.w-promotions .promo-salemaker .item','margin-right','2','','','.w-promotions'),(984431,'deals','.w-promotions .promo-cart-discount .slave .item','margin-right','2','','','.w-promotions'),(984432,'deals','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','margin-right','5','3','','.w-promotions'),(984433,'deals','.w-promotions .promo-cart-discount .master .item','margin-right','12','','','.w-promotions'),(984434,'deals','.b-warehouses-popup .warehouses-popup-link','margin-right','5','3','','.b-warehouses-popup'),(984435,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-right','20','','','.b-warehouses-popup'),(984436,'deals','.bell-ico .heading-2','margin-right','10','3','','.bell-ico'),(984437,'deals','.w-checkout-create-account .account-benefits strong','margin-right','5','3','','.w-checkout-create-account'),(984439,'deals','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-right','0','','','.b-fancybox'),(984440,'deals','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(984441,'deals','.b-messages .messages-menu ul','margin-right','0','','','.b-messages'),(984442,'deals','.b-messages .messBtnMenuDelete','margin-right','8','3','','.b-messages'),(984443,'deals','.b-messages .messBtnMenuUnread','margin-right','8','3','','.b-messages'),(984444,'deals','.b-messages .msv_content','margin-right','0','','','.b-messages'),(984445,'deals','.b-messages .msv_history','margin-right','0','','','.b-messages'),(984446,'deals','.b-messages .messBtnMenuStarred','margin-right','8','3','','.b-messages'),(984447,'deals','.b-messages .messages-menu li','margin-right','0','','','.b-messages'),(984448,'deals','.b-messages .content_management_attach span::before','margin-right','5','','','.b-messages'),(984449,'deals','.b-messages .content_management_attach span','margin-right','10','','','.b-messages'),(984450,'deals','.w-tabs .tab-navigation','margin-right','0','','','.w-tabs'),(984451,'deals','.w-sitemap-delivery-location > ul > li > ul','margin-right','0','','','.w-sitemap-delivery-location'),(984452,'deals','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(984453,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(984454,'deals','.w-sitemap-delivery-location > ul','margin-right','0','','','.w-sitemap-delivery-location'),(984455,'deals','.p-payer-order-confirmation .order-ico','margin-right','10','3','','.p-payer-order-confirmation'),(984456,'deals','.p-payer-order-confirmation .ship-ico','margin-right','10','3','','.p-payer-order-confirmation'),(984457,'deals','.p-payer-order-confirmation .pay-ico','margin-right','10','3','','.p-payer-order-confirmation'),(984458,'deals','.p-payer-order-confirmation .discount-ico','margin-right','10','3','','.p-payer-order-confirmation'),(984459,'deals','.p-payer-order-confirmation .comment-ico','margin-right','10','3','','.p-payer-order-confirmation'),(984460,'deals','.p-payer-order-pay .order-ico','margin-right','10','3','','.p-payer-order-pay'),(984461,'deals','.p-payer-order-pay .ship-ico','margin-right','10','3','','.p-payer-order-pay'),(984462,'deals','.p-payer-order-pay .pay-ico','margin-right','10','3','','.p-payer-order-pay'),(984463,'deals','.p-payer-order-pay .discount-ico','margin-right','10','3','','.p-payer-order-pay'),(984464,'deals','.p-payer-order-pay .comment-ico','margin-right','10','3','','.p-payer-order-pay'),(984465,'deals','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(984466,'deals','.b-delete-account .delete-box span','margin-right','10','','','.b-delete-account'),(984467,'deals','.w-checkout-shipping-address .genders-title label','margin-right','20','','','.w-checkout-shipping-address'),(984468,'deals','.w-checkout-shipping-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-shipping-address'),(984469,'deals','.b-messages span.starred::before','margin-right','8','','','.b-messages'),(984470,'deals','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(984471,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(984472,'deals','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(984473,'deals','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(984474,'deals','.w-menu-horizontal li','margin-right','0','','','.w-menu-horizontal'),(984475,'deals','.w-menu-horizontal ul','margin-right','0','','','.w-menu-horizontal'),(984476,'deals','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(984477,'deals','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(984478,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(984479,'deals','.buttons .left-buttons .btn','margin-right','10','','',''),(984480,'deals','.out-stock-icon','margin-right','3','3','',''),(984482,'deals','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(984483,'deals','.w-filters .input-checkbox:checked + .checkbox-span','margin-right','10','','','.w-filters'),(984484,'deals','.w-top-categories .categories','margin-right','-10','5644','','.w-top-categories'),(984485,'deals','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(984486,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-right','0','','','.b-select-suggest'),(984487,'deals','.w-socials > li','margin-right','10','','','.w-socials'),(984490,'deals','.w-socials > li','margin-right','10','','','.w-socials'),(984491,'deals','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(984492,'deals','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(984493,'deals','.w-checkout-shipping-address .btn-cancel','margin-right','20','','','.w-checkout-shipping-address'),(984494,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(984495,'deals','.w-multi-cart-actions .cart-actions .dropdown-toggle','margin-right','10','3','','.w-multi-cart-actions'),(984496,'deals','.w-tabs .tab-li','margin-right','0','','','.w-tabs'),(984497,'deals','.w-socials > li','margin-right','10','','','.w-socials'),(984498,'deals','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(984499,'deals','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(984500,'deals','.w-cart-listing .actions > div','margin-right','20','','','.w-cart-listing'),(984501,'deals','.b-form .required-message-wrap','margin-right','0','','','.b-form'),(984502,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(984503,'deals','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(984504,'deals','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(984507,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(984508,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-right','5','','','.b-messages'),(984509,'deals','.w-filters .filter-ul-content','margin-right','0','','','.w-filters'),(984510,'deals','.transit-icon','margin-right','3','3','',''),(984511,'deals','.in-stock-icon','margin-right','3','3','',''),(984512,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(984513,'deals','.b-select-suggest .select2-drop-mask','margin-right','0','','','.b-select-suggest'),(984514,'deals','.js-stock-icon','margin-right','3','3','',''),(984515,'deals','.b-form .addresses .address-item input[type=\"radio\"]','margin-right','5','','','.b-form'),(984516,'deals','.products-quick-index ul','margin-right','0','','',''),(984517,'deals','.b-fancybox .fancybox-title-float-wrap .child','margin-right','-100','','','.b-fancybox'),(984518,'deals','.w-top-categories .categories h2','margin-right','0','','','.w-top-categories'),(984519,'deals','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(984520,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(984521,'deals','.b-form .col-gender label','margin-right','20','','','.b-form'),(984522,'deals','.w-socials .post_item_img','margin-right','10','','','.w-socials'),(984523,'deals','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(984524,'deals','.w-product-quantity .qty_packs .price_1','margin-right','25','4','','.w-product-quantity'),(984525,'deals','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(984526,'deals','.b-select-suggest .select2-container.select2-allowclear .select2-choice .select2-chosen','margin-right','42','','','.b-select-suggest'),(984527,'deals','.b-select-suggest .select2-container .select2-choice > .select2-chosen','margin-right','26','','','.b-select-suggest'),(984528,'deals','.b-select-suggest .select2-container','margin-right','0','','','.b-select-suggest'),(984529,'deals','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(984530,'deals','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(984531,'deals','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(984532,'deals','.w-checkout-billing-address .genders-title > div:first-child','margin-right','20','','','.w-checkout-billing-address'),(984533,'deals','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(984534,'deals','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(984535,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(984536,'deals','.b-form .radio-buttons .radio-button','margin-right','30','','','.b-form'),(984537,'deals','.b-form .checkbox-style:checked + .checkbox-span','margin-right','5','','','.b-form'),(984538,'deals','.w-menu-big ul','margin-right','0','','','.w-menu-big'),(984540,'deals','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(984541,'deals','.w-checkout-billing-address .genders-title label','margin-right','20','','','.w-checkout-billing-address'),(984542,'deals','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(984543,'deals','.b-autocomplete .ui-autocomplete','margin-right','0','','','.b-autocomplete'),(984544,'deals','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(984545,'deals','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(984546,'deals','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(984547,'deals','.b-select-suggest .select2-results .select2-result-label','margin-right','0','','','.b-select-suggest'),(984549,'deals','.w-menu-big li','margin-right','0','','','.w-menu-big'),(984550,'deals','.w-socials > li','margin-right','10','','','.w-socials'),(984551,'deals','.b-fancybox .fancybox-error','margin-right','0','','','.b-fancybox'),(984552,'deals','.w-cart-compare .product .image','margin-right','10','','','.w-cart-compare'),(984553,'deals','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(984554,'deals','.b-form .radio-button input[type=\"radio\"].no + span','margin-right','5','3','','.b-form'),(984555,'deals','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-right','0','','','.b-switch'),(984556,'deals','.b-bottom .confirm-popup .buttons .btn','margin-right','20','','','.b-bottom'),(984557,'deals','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(984558,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(984559,'deals','.w-cart-checkout-btn .or-text','margin-right','0','','','.w-cart-checkout-btn'),(984560,'deals','.w-cart-give-away .ga_column','margin-right','2','','','.w-cart-give-away'),(984561,'deals','.w-cart-compare .product-actions .dropdown-toggle','margin-right','8','3','','.w-cart-compare'),(984562,'deals','.w-social-links a','margin-right','5','','','.w-social-links'),(984563,'deals','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(984564,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-right','0','','','.b-select-suggest'),(984565,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-right','0','','','.b-select-suggest'),(984566,'deals','.b-select-suggest .select2-container-multi .select2-choices','margin-right','0','','','.b-select-suggest'),(984567,'deals','.b-select-suggest .select2-results ul.select2-result-sub','margin-right','0','','','.b-select-suggest'),(984568,'deals','.b-select-suggest .select2-search input','margin-right','0','','','.b-select-suggest'),(984569,'deals','.b-select-suggest .select2-search','margin-right','0','','','.b-select-suggest'),(984570,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-right','0','','','.b-tracking-numbers'),(984573,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-right','0','','','.w-menu-style-2'),(984574,'deals','.b-products-listing .products-listing .bonus-points-cost','margin-right','12','','','.b-products-listing'),(984577,'deals','.w-account-addresses-list .address-fields input[type=\"radio\"]','margin-right','10','','','.w-account-addresses-list'),(984578,'deals','.b-products-listing .products-listing .btn-buy','margin-right','10','3','','.b-products-listing'),(984579,'deals','.b-products-listing .products-listing .description ul','margin-right','0','','','.b-products-listing'),(984580,'deals','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(984581,'deals','.b-products-listing .products-listing .bonus-points-price','margin-right','10','','','.b-products-listing'),(984582,'deals','.w-checkout-gdpr .privacy-row','margin-right','0','','','.w-checkout-gdpr'),(984583,'deals','.b-compare .compare-box-btn','margin-right','20','','','.b-compare'),(984584,'deals','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(984585,'deals','.w-socials > li','margin-right','10','','','.w-socials'),(984586,'deals','.w-quote-checkout-btn','margin-right','0','','','.w-quote-checkout-btn'),(984587,'deals','.w-product-reviews .reviews-list','margin-right','0','','','.w-product-reviews'),(984589,'deals','.w-login-block .password-info .info-popup','margin-right','0','','','.w-login-block'),(984590,'deals','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(984591,'deals','.b-social-login .social-login-text-2','margin-right','10','3','','.b-social-login'),(984592,'deals','.w-taxable label','margin-right','5','','','.w-taxable'),(984593,'deals','.w-taxable input[type=\"checkbox\"]','margin-right','5','','','.w-taxable'),(984594,'deals','.w-taxable select','margin-right','0','','','.w-taxable'),(984595,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-right','0','','',''),(984596,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-right','0','','','.b-h-inline'),(984597,'deals','.b-form .checkbox-style','margin-right','0','','','.b-form'),(984598,'deals','.b-page-name .page-name','margin-right','0','','','.b-page-name'),(984599,'deals','.b-social-login .social-login-text-2','margin-right','10','4','','.b-social-login'),(984600,'deals','.products-quick-index .token-input-list','margin-right','0','','',''),(984601,'deals','.w-cart-give-away .ga_attributes > div','margin-right','1','','','.w-cart-give-away'),(984602,'deals','.w-product-cross-sell .buy-all-checker','margin-right','5','','','.w-product-cross-sell'),(984603,'deals','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','margin-right','10','3','','.w-cart-listing'),(984604,'deals','.w-cart-give-away .ga_img','margin-right','2','','','.w-cart-give-away'),(984605,'deals','.w-cart-give-away .ga_column','margin-right','0','5630','','.w-cart-give-away'),(984607,'deals','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(984608,'deals','.w-socials > li','margin-right','10','','','.w-socials'),(984609,'deals','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(984610,'deals','.w-brands .brands-listing > div','margin-right','0','','','.w-brands'),(984611,'deals','.b-form .password-forgotten-link','margin-right','0','','','.b-form'),(984613,'deals','.w-catalog-listing-look .listing-look-title','margin-right','10','','','.w-catalog-listing-look'),(984614,'deals','.w-filters .input-checkbox','margin-right','0','','','.w-filters'),(984615,'deals','.products-quick-index ul.token-input-list','margin-right','0','','',''),(984616,'deals','.b-dropdown .dropdown .dropdown-menu','margin-right','0','','','.b-dropdown'),(984617,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span','margin-right','5','','','.b-form'),(984621,'deals','.b-form .required-message','margin-right','0','','','.b-form'),(984622,'deals','.w-filters .input-checkbox:not(checked) + .checkbox-span','margin-right','10','','','.w-filters'),(984623,'deals','.w-account-apply-certificate .gift-certificate-input','margin-right','0','','','.w-account-apply-certificate'),(984624,'deals','.b-product-images .media-popup .slick-dots','margin-right','0','','','.b-product-images'),(984625,'deals','.b-product-images .media-popup .slick-dots li','margin-right','5','','','.b-product-images'),(984626,'deals','.b-product-images .media-popup button.slick-next:active','margin-right','-3','','','.b-product-images'),(984627,'deals','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-right','0','','','.b-menu-style'),(984628,'deals','.b-trade-approval .steps-bar','margin-right','0','','','.b-trade-approval'),(984629,'deals','.w-account-personal-catalog .list-switcher','margin-right','0','','','.w-account-personal-catalog'),(984630,'deals','.w-account-subscription .info-popup','margin-right','20','','','.w-account-subscription'),(984631,'deals','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-right','0','','','.w-catalog-additional-images'),(984632,'deals','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-right','0','','','.b-cookie-notice'),(984633,'deals','.lowestPricedBox .w-banner .banner','margin-right','-15','','','.lowestPricedBox'),(984634,'deals','.b-products-listing .products-listing.list-productlisting .stock','margin-right','0','','','.b-products-listing'),(984635,'deals','.shopByCollectionBox .w-banner .banner','margin-right','-15','','','.shopByCollectionBox'),(984636,'deals','.preFooter .w-banner .single_banner','margin-right','2','','','.preFooter'),(984637,'deals','.b-slick .slick-list','margin-right','0','','','.b-slick'),(984638,'deals','.b-slick .slick-track','margin-right','auto','','','.b-slick'),(984639,'deals','.b-products-listing .del-from-personal-catalog','margin-right','10','3','','.b-products-listing'),(984640,'deals','.LeftCategories .w-menu-simple ul','margin-right','0','','','.LeftCategories'),(984641,'deals','.w-breadcrumb .breadcrumb-li','margin-right','10','','','.w-breadcrumb'),(984642,'deals','.w-breadcrumb .breadcrumb-ul','margin-right','0','','','.w-breadcrumb'),(984643,'deals','.w-quote .multicart .name','margin-right','-10','','','.w-quote'),(984644,'deals','.b-quantity .qty-box input','margin-right','3','','','.b-quantity'),(984645,'deals','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2','margin-right','10','3','','.w-product-buttons'),(984646,'deals','.w-compare .compare-list-buttons','margin-right','-250','','','.w-compare'),(984647,'deals','.w-sample .multicart .name','margin-right','-10','','','.w-sample'),(984648,'deals','.w-filters-simple .system-1','margin-right','20','','','.w-filters-simple'),(984649,'deals','.w-cart-discount-coupon input[type=\"text\"]','margin-right','10','','','.w-cart-discount-coupon'),(984650,'deals','.w-cart-sub-total ','margin-right','0','','','.w-cart-sub-total'),(984651,'deals','.shipping-ico .heading-3','margin-right','0','','','.shipping-ico'),(984652,'deals','.order-summary .heading-2','margin-right','0','','','.order-summary'),(984653,'deals','.w-cart-gift-certificate .heading-4','margin-right','0','','','.w-cart-gift-certificate'),(984654,'deals','.w-cart-gift-certificate .gift-certificate .heading-4','margin-right','10','3','','.w-cart-gift-certificate'),(984655,'deals','.w-cart-gift-certificate .gift-code p','margin-right','0','','','.w-cart-gift-certificate'),(984656,'deals','.w-product-inventory input[type=\"radio\"]','margin-right','5','','','.w-product-inventory'),(984658,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-right','0','','','.b-products-listing'),(984659,'deals','.b-pagination ul.pagination','margin-right','0','','','.b-pagination'),(984660,'deals','.w-product-quantity-discounts .item:nth-child(2n+1)','margin-right','2','','','.w-product-quantity-discounts'),(984661,'deals','.w-product-properties-filters-widgets-chosen-filters .item','margin-right','5','','','.w-product-properties-filters-widgets-chosen-filters'),(984662,'deals','.p-sample-checkout-index .order-summary .heading-2','margin-right','0','3','','.p-sample-checkout-index'),(984663,'deals','.p-sample-checkout-index .order-summary .heading-2','margin-right','-100','4','','.p-sample-checkout-index'),(984664,'deals','.w-product-collection .right-area .btn','margin-right','10','3','','.w-product-collection'),(984665,'deals','.w-product-collection .right-area .btn-2','margin-right','10','3','','.w-product-collection'),(984666,'deals','.w-product-properties .property-ul','margin-right','0','','','.w-product-properties'),(984667,'deals','.w-product-properties .properties-table','margin-right','0','','','.w-product-properties'),(984668,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','margin-right','30','','','.w-questionnaire-widgets-questionnaire'),(984669,'deals','.b-products-listing .mix-attributes .mult-qty-input .qty-box > input','margin-right','3','','','.b-products-listing'),(984670,'deals','.b-products-listing .products-listing .attribute-color','margin-right','4','','','.b-products-listing'),(984671,'deals','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','margin-right','10','3','','.w-product-custom-bundle'),(984672,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list'),(984673,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list-block'),(984674,'deals','.w-delivery-location-top-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-top-location-list'),(984675,'deals','.w-delivery-location-location-list .deliveryList li','margin-right','1','','','.w-delivery-location-location-list'),(984676,'deals','.w-delivery-location-location-list ul','margin-right','0','','','.w-delivery-location-location-list'),(984677,'deals','.w-delivery-location-top-location-list .deliveryList li','margin-right','0','5630','','.w-delivery-location-top-location-list'),(984678,'deals','.w-delivery-location-featured-list .deliveryList ul','margin-right','0','','','.w-delivery-location-featured-list'),(984679,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(984680,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(984681,'deals','.w-delivery-location-list-by-page .description ul','margin-right','0','','','.w-delivery-location-list-by-page'),(984682,'deals','.w-delivery-location-list-by-page .item','margin-right','1','','','.w-delivery-location-list-by-page'),(984683,'deals','.w-delivery-location-list-by-page .item','margin-right','0','5660','','.w-delivery-location-list-by-page'),(984684,'deals','.w-delivery-location-cross-pages .description ul','margin-right','0','','','.w-delivery-location-cross-pages'),(984685,'deals','.w-delivery-location-cross-pages .item','margin-right','1','','','.w-delivery-location-cross-pages'),(984686,'deals','.w-delivery-location-cross-pages .item','margin-right','0','5660','','.w-delivery-location-cross-pages'),(984687,'deals','.w-catalog-delivery-locations .item','margin-right','1','','','.w-catalog-delivery-locations'),(984688,'deals','.w-catalog-delivery-locations .description ul','margin-right','0','','','.w-catalog-delivery-locations'),(984689,'deals','.w-catalog-delivery-locations .item','margin-right','0','5630','','.w-catalog-delivery-locations'),(984690,'deals','.w-product-bonus-points .bonus-points-cost','margin-right','12','','','.w-product-bonus-points'),(984691,'deals','.w-product-designer-designer .prodDesignerType label','margin-right','10','','','.w-product-designer-designer'),(984692,'deals','.w-press-reviews-widgets-press-reviews .date','margin-right','0','5630','','.w-press-reviews-widgets-press-reviews'),(984693,'deals','.w-press-reviews-widgets-press-reviews-list .image','margin-right','0','','','.w-press-reviews-widgets-press-reviews-list'),(984694,'deals','.w-press-reviews-widgets-press-reviews-list .item','margin-right','0','','','.w-press-reviews-widgets-press-reviews-list'),(984695,'deals','.w-press-reviews-widgets-press-reviews-list .review-box > *','margin-right','30','','','.w-press-reviews-widgets-press-reviews-list'),(984696,'deals','.w-press-reviews-widgets-press-reviews-list .review-box > *','margin-right','0','5660','','.w-press-reviews-widgets-press-reviews-list'),(984697,'deals','.w-gift-wrap-message-checkout .max-counter, .w-gift-wrap-message-checkout .max-words','margin-right','20','','','.w-gift-wrap-message-checkout'),(984698,'deals','.w-gift-wrap-message-checkout .text','margin-right','20','','','.w-gift-wrap-message-checkout'),(984699,'deals','.w-support-system-filter .filter_cats','margin-right','0','','','.w-support-system-filter'),(984700,'deals','.w-support-system-listing .product_icon','margin-right','20','','','.w-support-system-listing'),(984701,'deals','.w-rma-returns-history .filterMessages','margin-right','-3','','','.w-rma-returns-history'),(984702,'deals','.w-rma-returns-history label[for=\'sCreateFrom\']','margin-right','5','','','.w-rma-returns-history'),(984703,'deals','.w-rma-returns-history .column:last-child .title','margin-right','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(984704,'deals','.w-show-inactive-show-inactive .out_stock_label','margin-right','10','','','.w-show-inactive-show-inactive'),(984705,'deals','.w-product-designer-button label > input[type=\"checkbox\"]','margin-right','7','','','.w-product-designer-button'),(984706,'deals','.w-product-designer-designer .productDesignerBox ul','margin-right','0','','','.w-product-designer-designer'),(984707,'deals','.w-product-configurator .pc-item','margin-right','0','','','.w-product-configurator'),(984708,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-right','0','','','.w-catalog-pages-category-pages-list'),(984709,'deals','.w-predefined-promotion .icon','margin-right','15','','','.w-predefined-promotion'),(984710,'deals','.w-predefined-promotion .nextdiscount .heading','margin-right','10','3','','.w-predefined-promotion'),(984711,'deals','.w-predefined-promotion .prom-multi-discount > .heading','margin-right','5','3','','.w-predefined-promotion'),(984712,'deals','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','margin-right','5','3','','.w-predefined-promotion'),(984713,'deals','.w-predefined-promotion .promo-cart-discount .master .item','margin-right','12','','','.w-predefined-promotion'),(984714,'deals','.w-predefined-promotion .promo-cart-discount .slave .item','margin-right','2','','','.w-predefined-promotion'),(984715,'deals','.w-predefined-promotion .promo-salemaker .item','margin-right','2','','','.w-predefined-promotion'),(984716,'deals','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','margin-right','5','3','','.w-predefined-promotion'),(984717,'deals','.w-supplier-purchase-supplier-products .select_item','margin-right','20','','','.w-supplier-purchase-supplier-products'),(984718,'deals','.w-supplier-purchase-supplier-products .name','margin-right','20','','','.w-supplier-purchase-supplier-products'),(984719,'deals','.w-supplier-purchase-supplier-products .col-full','margin-right','20','','','.w-supplier-purchase-supplier-products'),(984721,'deals','.headerWrap .w-contacts.phone','margin-right','10','3','','.headerWrap'),(984722,'deals','.w-top-categories .item','margin-right','25','','','.w-top-categories'),(984723,'deals','.headerWrap .menu-style[data-style=\"1\"] li.back-button','margin-right','10','3','','.headerWrap'),(984724,'deals','.w-categories .categories h2','margin-right','0','','','.w-categories'),(984725,'deals','.w-categories .item','margin-right','10','','','.w-categories'),(984726,'deals','.b-products-listing .products-listing a.btn.view-button','margin-right','10','3','','.b-products-listing'),(984727,'deals','.filterLine .before','margin-right','0','','','.filterLine'),(984728,'deals','.w-categories .categories','margin-right','-10','','','.w-categories'),(984729,'deals','.b-products-listing .add-to-personal-catalog','margin-right','10','3','','.b-products-listing'),(984730,'deals','.b-quantity .qty-box input[type=\'text\']','margin-right','3','','','.b-quantity'),(984731,'deals','.w-product-groups .radioBox label','margin-right','0','','','.w-product-groups'),(984732,'deals','.savings-ico .heading-3','margin-right','0','','','.savings-ico'),(984733,'deals','.order-summary .w-image','margin-right','-20','','','.order-summary'),(984734,'deals','.headerWrap .w-account .my-acc-link','margin-right','0','5639','','.headerWrap'),(984735,'deals','.w-top-categories .item','margin-right','10','5644','','.w-top-categories'),(984736,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li > .no-link','margin-right','0','','','.preFooter'),(984737,'deals','.b-products-listing .products-listing .attributes select','margin-right','2','','','.b-products-listing'),(984738,'deals','.b-products-listing .products-listing.list-productlisting .attributes select','margin-right','0','','','.b-products-listing'),(984739,'deals','.b-info .info li','margin-right','0','','','.b-info'),(984740,'deals','.b-info .info ul','margin-right','0','','','.b-info'),(984741,'deals','.w-product-personal-catalog-button .btn','margin-right','10','3','','.w-product-personal-catalog-button'),(984742,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','margin-right','20','','','.w-account-personal-catalog'),(984743,'deals','.w-account-personal-catalog .list-row-action li','margin-right','0','','','.w-account-personal-catalog'),(984744,'deals','.w-account-personal-catalog .list-row-action ul','margin-right','-1','','','.w-account-personal-catalog'),(984745,'deals','.w-compare .compare-list-buttons','margin-right','0','5639','','.w-compare'),(984746,'deals','.w-promotions-widgets-promotion-icons-desc .promo-icon','margin-right','7','','','.w-promotions-widgets-promotion-icons-desc'),(984754,'deals','.account-address-book .address_book .row-buttons a','margin-right','10','','','.account-address-book'),(984755,'deals','.account-address-book .address_book h1','margin-right','0','','','.account-address-book'),(984756,'deals','.account-address-book .address_book h2','margin-right','0','','','.account-address-book'),(984757,'deals','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-right','0','','','.account-address-book'),(984758,'deals','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-right','2','','','.account-address-book'),(984759,'deals','.account-address-book .address_book_row h2 a','margin-right','0','','','.account-address-book'),(984760,'deals','.account-address-book .buttonBox .info','margin-right','25','','','.account-address-book'),(984761,'deals','.account-address-book .address_book_row .column','margin-right','0','5630','','.account-address-book'),(984762,'deals','.account-address-book .address_book_row .column + .column','margin-right','0','5630','','.account-address-book'),(984763,'deals','.account-address-book .topInfo > div','margin-right','0','5630','','.account-address-book'),(984764,'deals','.account-address-book .topInfo > div + div','margin-right','0','5630','','.account-address-book'),(984770,'deals','.account-order-pay .buttons','margin-right','0','','','.account-order-pay'),(984771,'deals','.account-order-pay .history_info','margin-right','0','','','.account-order-pay'),(984772,'deals','.account-order-pay .history_info > div','margin-right','0','5639','','.account-order-pay'),(984773,'deals','.account-password-wrap .buttonedit','margin-right','0','','','.account-password-wrap'),(984774,'deals','.account-samples .buttonBox','margin-right','0','','','.account-samples'),(984775,'deals','.account-samples .order_history_table h2','margin-right','0','','','.account-samples'),(984776,'deals','.account-sample-info .buttons','margin-right','0','','','.account-sample-info'),(984777,'deals','.account-sample-info .history_info','margin-right','0','','','.account-sample-info'),(984778,'deals','.account-sample-info .history_info > div','margin-right','0','5639','','.account-sample-info'),(984779,'deals','.shopping-cart-index .closeable-heading','margin-right','0','','','.shopping-cart-index'),(984780,'deals','.shopping-cart-index .closeable-heading .heading-2','margin-right','0','','','.shopping-cart-index'),(984781,'deals','.shopping-cart-index .closeable-heading .heading-3','margin-right','0','','','.shopping-cart-index'),(984782,'deals','.checkout-index-wrap .order-ico','margin-right','10','3','','.checkout-index-wrap'),(984783,'deals','.checkout-index-wrap .pay-ico','margin-right','10','3','','.checkout-index-wrap'),(984784,'deals','.checkout-index-wrap .ship-ico','margin-right','10','3','','.checkout-index-wrap'),(984785,'deals','.checkout-order-confirmation .comment-ico','margin-right','10','3','','.checkout-order-confirmation'),(984786,'deals','.checkout-order-confirmation .discount-ico','margin-right','10','3','','.checkout-order-confirmation'),(984787,'deals','.checkout-order-confirmation .order-ico','margin-right','10','3','','.checkout-order-confirmation'),(984788,'deals','.checkout-order-confirmation .ship-ico','margin-right','10','3','','.checkout-order-confirmation'),(984789,'deals','.b-bottom .cart-options .buttons','margin-right','0','','','.b-bottom'),(984790,'deals','.b-bottom .pop-up-content .buttons','margin-right','0','','','.b-bottom'),(984791,'deals','.b-slick .slick-dots li','margin-right','5','','','.b-slick'),(984792,'deals','.success-page .comment-ico','margin-right','10','3','','.success-page'),(984793,'deals','.success-page .discount-ico','margin-right','10','3','','.success-page'),(984794,'deals','.success-page .order-ico','margin-right','10','3','','.success-page'),(984795,'deals','.success-page .page-success .text-1','margin-right','10','3','','.success-page'),(984796,'deals','.success-page .pay-ico','margin-right','10','3','','.success-page'),(984797,'deals','.success-page .prod-ico','margin-right','10','3','','.success-page'),(984798,'deals','.success-page .ship-ico','margin-right','10','3','','.success-page'),(984799,'deals','.w-cart-products .checkout-attention-message','margin-right','0','','','.w-cart-products'),(984800,'deals','.b-multi-page-checkout .multi-page-checkout .buttons','margin-right','0','','','.b-multi-page-checkout'),(984801,'deals','.footer-menu .level-3 > li.back-button','margin-right','0','5639','','.footer-menu'),(984802,'deals','.accout-box select[data-type=\"vat_number\"]','margin-right','0','','','.accout-box'),(984803,'deals','.w-catalog-paging .prev','margin-right','5','','','.w-catalog-paging'),(984807,'deals','.w-menu-slider ul, .w-menu-slider li','margin-right','0','','','.w-menu-slider'),(984808,'deals','.b-bottom .cart-options .buttons','margin-right_important','important','','','.b-bottom'),(984809,'deals','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','margin-top','0','','','.b-switch'),(984810,'deals','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(984811,'deals','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(984812,'deals','.w-catalog-items-on-page select','margin-top','0','','','.w-catalog-items-on-page'),(984813,'deals','.p-quick-order-index ul.token-input-list','margin-top','0','','','.p-quick-order-index'),(984814,'deals','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(984818,'deals','.w-promotions .promo-salemaker .item','margin-top','2','','','.w-promotions'),(984819,'deals','.w-promotions .promo-salemaker .content','margin-top','-18','','','.w-promotions'),(984820,'deals','.w-promotions .promo-cart-discount .slave .item','margin-top','2','','','.w-promotions'),(984821,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','margin-top','0','','','.b-warehouses-popup'),(984823,'deals','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(984824,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(984825,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(984826,'deals','.b-messages .messages-menu ul','margin-top','0','','','.b-messages'),(984827,'deals','.b-messages .msv_content','margin-top','15','','','.b-messages'),(984828,'deals','.b-messages .msv_btn','margin-top','10','','','.b-messages'),(984829,'deals','.b-messages .msv_history','margin-top','15','','','.b-messages'),(984830,'deals','.b-messages .messages-menu li','margin-top','0','','','.b-messages'),(984831,'deals','.w-sitemap-delivery-location > ul > li > ul','margin-top','0','','','.w-sitemap-delivery-location'),(984832,'deals','.w-tabs .tab-navigation','margin-top','0','','','.w-tabs'),(984833,'deals','.w-socials > li','margin-top','10','','','.w-socials'),(984834,'deals','.b-form .g-recaptcha','margin-top','10','','','.b-form'),(984835,'deals','.w-sitemap-delivery-location > ul','margin-top','0','','','.w-sitemap-delivery-location'),(984836,'deals','.p-payer-order-confirmation .dob-hide','margin-top','20','','','.p-payer-order-confirmation'),(984837,'deals','.p-payer-order-pay .dob-hide','margin-top','20','','','.p-payer-order-pay'),(984838,'deals','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(984839,'deals','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(984840,'deals','.b-fancybox #fancybox-loading','margin-top','-22','','','.b-fancybox'),(984841,'deals','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(984842,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-template .btn','margin-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(984843,'deals','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(984844,'deals','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(984845,'deals','.w-menu-horizontal ul','margin-top','0','','','.w-menu-horizontal'),(984846,'deals','.w-menu-horizontal li','margin-top','0','','','.w-menu-horizontal'),(984847,'deals','.b-form .password-forgotten-link','margin-top','0','','','.b-form'),(984848,'deals','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(984849,'deals','.b-form .privacy-row','margin-top','10','','','.b-form'),(984850,'deals','.b-fancybox .fancybox-title-outside-wrap','margin-top','10','','','.b-fancybox'),(984851,'deals','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(984852,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(984853,'deals','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(984854,'deals','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(984856,'deals','.w-socials > li','margin-top','10','','','.w-socials'),(984857,'deals','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(984859,'deals','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(984860,'deals','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(984861,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(984862,'deals','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(984863,'deals','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','margin-top','0','','','.b-fancybox'),(984864,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','margin-top','0','','','.b-select-suggest'),(984865,'deals','.w-socials > li','margin-top','10','','','.w-socials'),(984867,'deals','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(984868,'deals','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(984869,'deals','.w-cart-give-away .ga_attributes > div','margin-top','1','','','.w-cart-give-away'),(984870,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(984871,'deals','.w-multi-cart-cart-switcher .cart-label','margin-top','-20','','','.w-multi-cart-cart-switcher'),(984872,'deals','.w-tabs .tab-li','margin-top','0','','','.w-tabs'),(984873,'deals','.w-socials > li','margin-top','10','','','.w-socials'),(984874,'deals','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(984875,'deals','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(984876,'deals','.b-form .required-message-wrap','margin-top','0','','','.b-form'),(984877,'deals','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(984878,'deals','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(984879,'deals','.b-delete-account .delete-box span','margin-top','10','','','.b-delete-account'),(984880,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','margin-top','0','','','.b-messages'),(984881,'deals','.w-filters .filter-ul-content','margin-top','0','','','.w-filters'),(984882,'deals','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(984883,'deals','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(984884,'deals','.p-quick-order-index .dataTables_info','margin-top','5','','','.p-quick-order-index'),(984885,'deals','.b-select-suggest .select2-drop-mask','margin-top','0','','','.b-select-suggest'),(984886,'deals','.products-quick-index ul','margin-top','0','','',''),(984887,'deals','.w-top-categories .categories h2','margin-top','20','','','.w-top-categories'),(984888,'deals','.b-autocomplete .ui-autocomplete','margin-top','0','','','.b-autocomplete'),(984889,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(984890,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(984891,'deals','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(984892,'deals','.w-product-quantity .qty_packs .price_1','margin-top','0','4','','.w-product-quantity'),(984893,'deals','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(984894,'deals','.b-select-suggest .select2-container','margin-top','0','','','.b-select-suggest'),(984895,'deals','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(984896,'deals','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(984897,'deals','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(984898,'deals','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(984899,'deals','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(984900,'deals','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(984901,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(984903,'deals','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','margin-top','0','','','.b-fancybox'),(984904,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(984905,'deals','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(984906,'deals','.w-cart-checkout-btn .or-text','margin-top','-5','','','.w-cart-checkout-btn'),(984907,'deals','.w-promotions .promo-cart-discount .master .item','margin-top','12','','','.w-promotions'),(984908,'deals','.w-promotions .promo-cart-discount .master .image','margin-top','-16','','','.w-promotions'),(984909,'deals','.b-select-suggest .select2-results .select2-result-label','margin-top','0','','','.b-select-suggest'),(984910,'deals','.b-tracking-numbers .tracking-numbers.short-view .item','margin-top','0','','','.b-tracking-numbers'),(984911,'deals','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(984912,'deals','.b-form .required-message','margin-top','0','','','.b-form'),(984914,'deals','.w-menu-big ul','margin-top','0','','','.w-menu-big'),(984915,'deals','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(984916,'deals','.b-fancybox .fancybox-error','margin-top','0','','','.b-fancybox'),(984917,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off i, .b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on i','margin-top','0','','','.b-switch'),(984918,'deals','.w-cart-compare .product .image','margin-top','0','','','.w-cart-compare'),(984919,'deals','.b-fancybox .fancybox-nav span','margin-top','-18','','','.b-fancybox'),(984920,'deals','.w-product-customers-activity .buttons','margin-top','10','','','.w-product-customers-activity'),(984921,'deals','.b-bottom .confirm-popup .buttons .btn','margin-top','0','','','.b-bottom'),(984922,'deals','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(984923,'deals','.w-menu-big li','margin-top','0','','','.w-menu-big'),(984924,'deals','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(984925,'deals','.w-delayed-despatch-checkout-confirm .heading','margin-top','5','','','.w-delayed-despatch-checkout-confirm'),(984926,'deals','.b-page-name .page-name','margin-top','10','','','.b-page-name'),(984927,'deals','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(984928,'deals','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(984929,'deals','.w-social-links a','margin-top','0','','','.w-social-links'),(984930,'deals','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(984931,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','margin-top','1','','','.b-select-suggest'),(984932,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','margin-top','0','','','.b-select-suggest'),(984933,'deals','.b-select-suggest .select2-container-multi .select2-choices','margin-top','0','','','.b-select-suggest'),(984934,'deals','.b-select-suggest .select2-results ul.select2-result-sub','margin-top','0','','','.b-select-suggest'),(984935,'deals','.w-checkout-shipping-address .change-ab','margin-top','5','','','.w-checkout-shipping-address'),(984936,'deals','.w-checkout-contact-information .contact-info-buttons','margin-top','5','','','.w-checkout-contact-information'),(984937,'deals','.b-select-suggest .select2-drop.select2-drop-above .select2-search input','margin-top','4','','','.b-select-suggest'),(984938,'deals','.b-select-suggest .select2-search input','margin-top','0','','','.b-select-suggest'),(984939,'deals','.w-account-apply-certificate .gift-certificate-input','margin-top','20','','','.w-account-apply-certificate'),(984940,'deals','.b-select-suggest .select2-search','margin-top','0','','','.b-select-suggest'),(984941,'deals','.b-select-suggest .select2-drop.select2-drop-above','margin-top','1','','','.b-select-suggest'),(984942,'deals','.b-select-suggest .select2-drop','margin-top','-1','','','.b-select-suggest'),(984943,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(984945,'deals','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(984948,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','margin-top','0','','','.w-menu-style-2'),(984949,'deals','.b-social-login .social-login-text-2','margin-top','0','4','','.b-social-login'),(984950,'deals','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(984953,'deals','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(984954,'deals','.b-products-listing .products-listing .description ul','margin-top','0','','','.b-products-listing'),(984955,'deals','.b-social-login .social-login-text-2','margin-top','0','3','','.b-social-login'),(984956,'deals','.w-checkout-gdpr .privacy-row','margin-top','0','','','.w-checkout-gdpr'),(984957,'deals','.w-checkout-gdpr .bootstrap-switch','margin-top','0','','','.w-checkout-gdpr'),(984958,'deals','.b-form .checkbox-style','margin-top','0','','','.b-form'),(984959,'deals','.b-form .wedding-form .heading-2','margin-top','10','','','.b-form'),(984960,'deals','.w-product-reviews .reviews-list','margin-top','10','','','.w-product-reviews'),(984961,'deals','.w-taxable label','margin-top','0','','','.w-taxable'),(984962,'deals','.w-taxable select','margin-top','0','','','.w-taxable'),(984963,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','margin-top','0','','',''),(984964,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','margin-top','0','','','.b-h-inline'),(984965,'deals','.w-communication-new-topic .files-box','margin-top','50','','','.w-communication-new-topic'),(984966,'deals','.b-form .addresses .address-item input[type=\"radio\"]','margin-top','0','','','.b-form'),(984967,'deals','.w-top-categories .categories','margin-top','0','5644','','.w-top-categories'),(984968,'deals','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(984969,'deals','.products-quick-index .token-input-list','margin-top','0','','',''),(984970,'deals','.w-quote-checkout-btn','margin-top','20','','','.w-quote-checkout-btn'),(984971,'deals','.b-dropdown .dropdown .dropdown-menu','margin-top','0','','','.b-dropdown'),(984972,'deals','.w-cart-listing .points-redeem','margin-top','-2','3','','.w-cart-listing'),(984974,'deals','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(984975,'deals','.w-socials > li','margin-top','10','','','.w-socials'),(984976,'deals','.w-login-block .password-info .info-popup','margin-top','-18','','','.w-login-block'),(984978,'deals','.w-filters .ui-slider','margin-top','5','','','.w-filters'),(984979,'deals','.w-checkout-billing-address .bootstrap-switch','margin-top','-2','','','.w-checkout-billing-address'),(984980,'deals','.w-socials .post_item_img','margin-top','0','','','.w-socials'),(984981,'deals','.w-socials > li','margin-top','10','','','.w-socials'),(984982,'deals','.w-brands .brands-listing > div','margin-top','0','','','.w-brands'),(984983,'deals','.w-filters .input-checkbox','margin-top','0','','','.w-filters'),(984984,'deals','.products-quick-index ul.token-input-list','margin-top','0','','',''),(984985,'deals','.message.success','margin-top','-8','3','',''),(984988,'deals','.b-social-login .social-login-text-2','margin-top','-5','','','.b-social-login'),(984989,'deals','.b-product-images .media-popup .slick-dots','margin-top','0','','','.b-product-images'),(984990,'deals','.b-product-images .media-popup .slick-dots li','margin-top','0','','','.b-product-images'),(984991,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','margin-top','-50','','','.b-product-images'),(984992,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(984993,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','margin-top','-44','','','.b-menu-lev_vis-click_icon'),(984994,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(984995,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(984996,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','margin-top','-40','','','.b-menu-lev_vis-click_icon'),(984997,'deals','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','margin-top','0','','','.b-menu-style'),(984998,'deals','.b-trade-approval .steps-bar','margin-top','0','','','.b-trade-approval'),(984999,'deals','.w-account-personal-catalog .list-switcher','margin-top','0','','','.w-account-personal-catalog'),(985000,'deals','.w-catalog-additional-images ul, .w-catalog-additional-images li','margin-top','0','','','.w-catalog-additional-images'),(985001,'deals','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','margin-top','0','','','.b-cookie-notice'),(985002,'deals','.lowestPricedBox .w-banner .banner','margin-top','0','','','.lowestPricedBox'),(985003,'deals','.shopByCollectionBox .w-banner .banner','margin-top','0','','','.shopByCollectionBox'),(985004,'deals','.preFooter .w-banner .single_banner','margin-top','0','','','.preFooter'),(985005,'deals','.b-slick .slick-list','margin-top','0','','','.b-slick'),(985006,'deals','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','margin-top','0','','','.b-slick'),(985007,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','margin-top','-20','','','.b-slick'),(985008,'deals','.LeftCategories .w-menu-simple ul','margin-top','0','','','.LeftCategories'),(985009,'deals','.w-breadcrumb .breadcrumb-ul','margin-top','0','','','.w-breadcrumb'),(985010,'deals','.w-quote .multicart .name','margin-top','0','','','.w-quote'),(985011,'deals','.warrantyProduct .warranty','margin-top','-16','3','','.warrantyProduct'),(985012,'deals','.warrantyProduct .delivery','margin-top','-15','3','','.warrantyProduct'),(985013,'deals','.w-sample .cart-box-link','margin-top','-5','4','','.w-sample'),(985014,'deals','.w-sample .multicart .name','margin-top','0','','','.w-sample'),(985015,'deals','.w-cart-sub-total ','margin-top','0','','','.w-cart-sub-total'),(985016,'deals','.shipping-ico .heading-3','margin-top','0','','','.shipping-ico'),(985017,'deals','.order-summary .heading-2','margin-top','0','','','.order-summary'),(985018,'deals','.w-cart-gift-certificate .heading-4','margin-top','0','','','.w-cart-gift-certificate'),(985019,'deals','.w-cart-gift-certificate .gift-code p','margin-top','0','','','.w-cart-gift-certificate'),(985020,'deals','.w-product-bundle .bundle_price','margin-top','-5','','','.w-product-bundle'),(985021,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','margin-top','0','','','.b-products-listing'),(985022,'deals','.b-pagination ul.pagination','margin-top','0','','','.b-pagination'),(985023,'deals','.w-product-properties-filters-widgets-chosen-filters .item','margin-top','0','','','.w-product-properties-filters-widgets-chosen-filters'),(985025,'deals','.w-product-collection .main-button','margin-top','20','','','.w-product-collection'),(985026,'deals','.w-product-properties .property-ul','margin-top','0','','','.w-product-properties'),(985027,'deals','.w-product-properties .properties-table','margin-top','0','','','.w-product-properties'),(985028,'deals','.w-product-custom-bundle .main-button','margin-top','20','','','.w-product-custom-bundle'),(985029,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list'),(985030,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list-block'),(985031,'deals','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-top-location-list'),(985032,'deals','.w-delivery-location-location-list .deliveryList li','margin-top','1','','','.w-delivery-location-location-list'),(985033,'deals','.w-delivery-location-location-list ul','margin-top','0','','','.w-delivery-location-location-list'),(985034,'deals','.w-delivery-location-top-location-list .deliveryList li','margin-top','1','5630','','.w-delivery-location-top-location-list'),(985035,'deals','.w-delivery-location-featured-list .deliveryList ul','margin-top','0','','','.w-delivery-location-featured-list'),(985036,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(985037,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(985038,'deals','.w-delivery-location-list-by-page .description ul','margin-top','5','','','.w-delivery-location-list-by-page'),(985039,'deals','.w-delivery-location-list-by-page .item','margin-top','0','','','.w-delivery-location-list-by-page'),(985040,'deals','.w-delivery-location-list-by-page .item','margin-top','10','5660','','.w-delivery-location-list-by-page'),(985041,'deals','.w-delivery-location-cross-pages .description ul','margin-top','5','','','.w-delivery-location-cross-pages'),(985042,'deals','.w-delivery-location-cross-pages .item','margin-top','0','','','.w-delivery-location-cross-pages'),(985043,'deals','.w-delivery-location-cross-pages .item','margin-top','10','5660','','.w-delivery-location-cross-pages'),(985044,'deals','.w-catalog-delivery-locations .item','margin-top','0','','','.w-catalog-delivery-locations'),(985045,'deals','.w-catalog-delivery-locations .description ul','margin-top','5','','','.w-catalog-delivery-locations'),(985046,'deals','.w-catalog-delivery-locations .item','margin-top','0','5630','','.w-catalog-delivery-locations'),(985047,'deals','.w-product-designer-designer .prodDesignerType label','margin-top','10','','','.w-product-designer-designer'),(985048,'deals','.w-press-reviews-widgets-press-reviews .date','margin-top','10','5630','','.w-press-reviews-widgets-press-reviews'),(985049,'deals','.w-press-reviews-widgets-press-reviews-list .image','margin-top','0','','','.w-press-reviews-widgets-press-reviews-list'),(985050,'deals','.w-press-reviews-widgets-press-reviews-list .item','margin-top','10','','','.w-press-reviews-widgets-press-reviews-list'),(985051,'deals','.w-support-system-filter .filter_cats','margin-top','0','','','.w-support-system-filter'),(985052,'deals','.w-rma-returns-history .content-messages .messages-table .bottom','margin-top','10','','','.w-rma-returns-history'),(985053,'deals','.w-rma-returns-history .content-messages .messages-table .top','margin-top','10','','','.w-rma-returns-history'),(985054,'deals','.w-rma-returns-history .filterMessages','margin-top','0','','','.w-rma-returns-history'),(985055,'deals','.w-rma-returns-history .column:last-child .title','margin-top','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(985056,'deals','.w-product-designer-designer .productDesignerBox ul','margin-top','0','','','.w-product-designer-designer'),(985057,'deals','.w-product-configurator .pc-item','margin-top','0','','','.w-product-configurator'),(985058,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','margin-top','0','','','.w-catalog-pages-category-pages-list'),(985059,'deals','.w-predefined-promotion .promo-cart-discount .master .image','margin-top','-16','','','.w-predefined-promotion'),(985060,'deals','.w-predefined-promotion .promo-cart-discount .master .item','margin-top','12','','','.w-predefined-promotion'),(985061,'deals','.w-predefined-promotion .promo-cart-discount .slave .item','margin-top','2','','','.w-predefined-promotion'),(985062,'deals','.w-predefined-promotion .promo-salemaker .content','margin-top','-18','','','.w-predefined-promotion'),(985063,'deals','.w-predefined-promotion .promo-salemaker .item','margin-top','2','','','.w-predefined-promotion'),(985065,'deals','.w-top-categories .item','margin-top','25','','','.w-top-categories'),(985066,'deals','.w-categories .categories h2','margin-top','20','','','.w-categories'),(985067,'deals','.w-categories .item','margin-top','10','','','.w-categories'),(985068,'deals','.filterLine .before','margin-top','-2','','','.filterLine'),(985069,'deals','.w-categories .categories','margin-top','0','','','.w-categories'),(985070,'deals','.w-product-groups .radioBox label','margin-top','5','','','.w-product-groups'),(985071,'deals','.messageBox .info','margin-top','-8','3','',''),(985072,'deals','.savings-ico .heading-3','margin-top','0','','','.savings-ico'),(985073,'deals','.order-summary .w-image','margin-top','0','','','.order-summary'),(985074,'deals','.headerWrap .w-account .my-acc-link','margin-top','0','5639','','.headerWrap'),(985075,'deals','.w-top-categories .item','margin-top','10','5644','','.w-top-categories'),(985076,'deals','.w-top-categories .categories h2','margin-top','10','5630','','.w-top-categories'),(985077,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li > .no-link','margin-top','5','','','.preFooter'),(985078,'deals','.w-categories .categories h2','margin-top','10','5630','','.w-categories'),(985079,'deals','.b-info .info','margin-top','-8','3','','.b-info'),(985080,'deals','.b-info .info li','margin-top','0','','','.b-info'),(985081,'deals','.b-info .info ul','margin-top','0','','','.b-info'),(985082,'deals','.w-account-personal-catalog .list-row-action li','margin-top','0','','','.w-account-personal-catalog'),(985083,'deals','.w-account-personal-catalog .list-row-action ul','margin-top','-1','','','.w-account-personal-catalog'),(985084,'deals','.w-cart-discount-coupon .title.active + .inp, .w-cart-discount-coupon .title.active + .messageBox + .inp','margin-top','10','','','.w-cart-discount-coupon'),(985091,'deals','.account-address-book .address_book .row-buttons a','margin-top','0','','','.account-address-book'),(985092,'deals','.account-address-book .address_book h1','margin-top','0','','','.account-address-book'),(985093,'deals','.account-address-book .address_book h2','margin-top','0','','','.account-address-book'),(985094,'deals','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin-top','0','','','.account-address-book'),(985095,'deals','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin-top','0','','','.account-address-book'),(985096,'deals','.account-address-book .address_book_row h2 a','margin-top','0','','','.account-address-book'),(985097,'deals','.account-address-book .buttonBox .info','margin-top','0','','','.account-address-book'),(985098,'deals','.account-address-book .address_book_row .column','margin-top','0','5630','','.account-address-book'),(985099,'deals','.account-address-book .address_book_row .column + .column','margin-top','0','5630','','.account-address-book'),(985100,'deals','.account-address-book .topInfo > div','margin-top','0','5630','','.account-address-book'),(985101,'deals','.account-address-book .topInfo > div + div','margin-top','0','5630','','.account-address-book'),(985110,'deals','.account-order-pay .buttons','margin-top','20','','','.account-order-pay'),(985111,'deals','.account-order-pay .history_info','margin-top','0','','','.account-order-pay'),(985112,'deals','.account-order-pay .history_info > div','margin-top','0','5639','','.account-order-pay'),(985113,'deals','.account-password-wrap .buttonedit','margin-top','-40','','','.account-password-wrap'),(985114,'deals','.account-password-wrap .buttons','margin-top','-70','','','.account-password-wrap'),(985115,'deals','.account-samples .buttonBox','margin-top','15','','','.account-samples'),(985116,'deals','.account-samples .order_history_table h2','margin-top','0','','','.account-samples'),(985117,'deals','.account-sample-info .buttons','margin-top','20','','','.account-sample-info'),(985118,'deals','.account-sample-info .history_info','margin-top','0','','','.account-sample-info'),(985119,'deals','.account-sample-info .popup-tracking-number-link','margin-top','10','','','.account-sample-info'),(985120,'deals','.account-sample-info .history_info > div','margin-top','0','5639','','.account-sample-info'),(985121,'deals','.shopping-cart-index .closeable-heading','margin-top','0','','','.shopping-cart-index'),(985122,'deals','.shopping-cart-index .closeable-heading .heading-2','margin-top','0','','','.shopping-cart-index'),(985123,'deals','.shopping-cart-index .closeable-heading .heading-3','margin-top','0','','','.shopping-cart-index'),(985124,'deals','.checkout-index-wrap .dob-hide','margin-top','20','','','.checkout-index-wrap'),(985125,'deals','.b-bottom .cart-options .buttons','margin-top','10','','','.b-bottom'),(985126,'deals','.b-bottom .pop-up-content .buttons','margin-top','15','','','.b-bottom'),(985127,'deals','.b-slick .slick-dots li','margin-top','0','','','.b-slick'),(985128,'deals','.success-page .page-success .text-1','margin-top','0','3','','.success-page'),(985129,'deals','.success-page .totals-line','margin-top','10','','','.success-page'),(985130,'deals','.w-cart-products .checkout-attention-message','margin-top','10','','','.w-cart-products'),(985131,'deals','.b-multi-page-checkout .multi-page-checkout .buttons','margin-top','0','','','.b-multi-page-checkout'),(985132,'deals','.footer-menu .level-2 > li.component-item','margin-top','20','','','.footer-menu'),(985133,'deals','.footer-menu .level-3 > li.back-button','margin-top','0','5639','','.footer-menu'),(985134,'deals','.accout-box select[data-type=\"vat_number\"]','margin-top','0','','','.accout-box'),(985135,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top','0','','','.w-catalog-paging'),(985140,'deals','.w-menu-slider ul, .w-menu-slider li','margin-top','0','','','.w-menu-slider'),(985141,'deals','.b-bottom .cart-options .buttons','margin-top_important','important','','','.b-bottom'),(985142,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','margin-top_important','important','','','.w-catalog-paging'),(985143,'deals','.p-quick-order-index ul.token-input-list','margin_bottom_measure','pt','','','.p-quick-order-index'),(985144,'deals','.w-cart-give-away .ga_attributes > div','margin_bottom_measure','%','','','.w-cart-give-away'),(985145,'deals','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-top-location-list'),(985146,'deals','.w-delivery-location-location-list .deliveryList li','margin_bottom_measure','%','','','.w-delivery-location-location-list'),(985147,'deals','.w-delivery-location-top-location-list .deliveryList li','margin_bottom_measure','%','5630','','.w-delivery-location-top-location-list'),(985148,'deals','.bannersWrap .box-block.type-12 > .block:nth-child(1)','margin_bottom_measure','%','5630','','.bannersWrap'),(985149,'deals','.bannersWrap .leftBanner .banner-item:first-of-type','margin_bottom_measure','%','','','.bannersWrap'),(985150,'deals','.p-quick-order-index ul.token-input-list','margin_left_measure','pt','','','.p-quick-order-index'),(985151,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_left_measure','pt','','','.b-warehouses-popup'),(985152,'deals','.w-cart-give-away .ga_column','margin_left_measure','%','','','.w-cart-give-away'),(985153,'deals','.w-taxable select','margin_left_measure','pt','','','.w-taxable'),(985154,'deals','.b-form .col-3 + .col-3','margin_left_measure','%','','','.b-form'),(985155,'deals','.w-cart-give-away .ga_attributes > div','margin_left_measure','%','','','.w-cart-give-away'),(985156,'deals','.b-trade-approval .col-3 + .col-3','margin_left_measure','%','','','.b-trade-approval'),(985157,'deals','.w-delivery-day .left-count','margin_left_measure','%','','','.w-delivery-day'),(985158,'deals','.w-delivery-day .left-text-right','margin_left_measure','%','','','.w-delivery-day'),(985159,'deals','.w-product-sale-ends .left-count','margin_left_measure','%','','','.w-product-sale-ends'),(985160,'deals','.w-product-sale-ends .left-text-right','margin_left_measure','%','','','.w-product-sale-ends'),(985161,'deals','.w-product-quantity-discounts .item:nth-child(2n)','margin_left_measure','%','','','.w-product-quantity-discounts'),(985162,'deals','.w-product-multi-inventory .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-multi-inventory'),(985163,'deals','.p-sample-checkout-index .order-summary .heading-2','margin_left_measure','%','3','','.p-sample-checkout-index'),(985164,'deals','.w-product-attributes .select-box:nth-child(2n)','margin_left_measure','%','','','.w-product-attributes'),(985165,'deals','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-top-location-list'),(985166,'deals','.w-delivery-location-location-list .deliveryList li','margin_left_measure','%','','','.w-delivery-location-location-list'),(985167,'deals','.w-delivery-location-top-location-list .deliveryList li','margin_left_measure','%','5630','','.w-delivery-location-top-location-list'),(985168,'deals','.w-sale-category .left-count','margin_left_measure','%','','','.w-sale-category'),(985169,'deals','.w-sale-category .left-text-right','margin_left_measure','%','','','.w-sale-category'),(985170,'deals','.w-delivery-location-list-by-page .item','margin_left_measure','%','','','.w-delivery-location-list-by-page'),(985171,'deals','.w-delivery-location-cross-pages .item','margin_left_measure','%','','','.w-delivery-location-cross-pages'),(985172,'deals','.w-catalog-delivery-locations .item','margin_left_measure','%','','','.w-catalog-delivery-locations'),(985173,'deals','.account-address-book .address_book_row .column + .column, .account-address-book .topInfo > div + div','margin_left_measure','%','','','.account-address-book'),(985174,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','margin_right_measure','pt','','','.b-warehouses-popup'),(985175,'deals','.p-quick-order-index ul.token-input-list','margin_right_measure','pt','','','.p-quick-order-index'),(985176,'deals','.b-fancybox .fancybox-title-float-wrap .child','margin_right_measure','%','','','.b-fancybox'),(985177,'deals','.w-cart-give-away .ga_column','margin_right_measure','%','','','.w-cart-give-away'),(985178,'deals','.w-taxable select','margin_right_measure','pt','','','.w-taxable'),(985179,'deals','.w-cart-give-away .ga_img','margin_right_measure','%','','','.w-cart-give-away'),(985180,'deals','.w-cart-give-away .ga_attributes > div','margin_right_measure','%','','','.w-cart-give-away'),(985181,'deals','.w-product-quantity-discounts .item:nth-child(2n+1)','margin_right_measure','%','','','.w-product-quantity-discounts'),(985182,'deals','.p-sample-checkout-index .order-summary .heading-2','margin_right_measure','%','4','','.p-sample-checkout-index'),(985183,'deals','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-top-location-list'),(985184,'deals','.w-delivery-location-location-list .deliveryList li','margin_right_measure','%','','','.w-delivery-location-location-list'),(985185,'deals','.w-delivery-location-top-location-list .deliveryList li','margin_right_measure','%','5630','','.w-delivery-location-top-location-list'),(985186,'deals','.w-delivery-location-list-by-page .item','margin_right_measure','%','','','.w-delivery-location-list-by-page'),(985187,'deals','.w-delivery-location-cross-pages .item','margin_right_measure','%','','','.w-delivery-location-cross-pages'),(985188,'deals','.w-catalog-delivery-locations .item','margin_right_measure','%','','','.w-catalog-delivery-locations'),(985189,'deals','.b-products-listing .products-listing .attributes select','margin_right_measure','%','','','.b-products-listing'),(985190,'deals','.b-products-listing .products-listing.list-productlisting .attributes select','margin_right_measure','%','','','.b-products-listing'),(985192,'deals','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','margin_right_measure','%','','','.account-address-book'),(985193,'deals','.p-quick-order-index ul.token-input-list','margin_top_measure','pt','','','.p-quick-order-index'),(985194,'deals','.w-cart-give-away .ga_attributes > div','margin_top_measure','%','','','.w-cart-give-away'),(985195,'deals','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-top-location-list'),(985196,'deals','.w-delivery-location-location-list .deliveryList li','margin_top_measure','%','','','.w-delivery-location-location-list'),(985197,'deals','.w-delivery-location-top-location-list .deliveryList li','margin_top_measure','%','5630','','.w-delivery-location-top-location-list'),(985198,'deals','.w-promotions .prom-multi-discount .image img','max-height','80','','','.w-promotions'),(985199,'deals','.w-promotions .promo-salemaker .image img','max-height','80','','','.w-promotions'),(985200,'deals','.w-promotions .promo-cart-discount .image img','max-height','80','','','.w-promotions'),(985201,'deals','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(985202,'deals','.b-email-editor img','max-height','100','','','.b-email-editor'),(985203,'deals','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-height','100','','','.w-upload-customer-id-upload-customer-id-form'),(985204,'deals','.w-product-images-additional .item-img','max-height','70','5660','','.w-product-images-additional'),(985205,'deals','.w-product-images-additional .item-img','max-height','70','5660','','.w-product-images-additional'),(985206,'deals','.b-email-editor img','max-height','100','','','.b-email-editor'),(985207,'deals','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(985208,'deals','.b-fancybox .fancybox-tmp','max-height','99999','','','.b-fancybox'),(985209,'deals','.b-email-editor img','max-height','100','','','.b-email-editor'),(985210,'deals','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(985211,'deals','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(985212,'deals','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(985213,'deals','.b-fancybox .fancybox-image','max-height','100','','','.b-fancybox'),(985214,'deals','.b-email-editor img','max-height','100','','','.b-email-editor'),(985215,'deals','.b-email-editor img','max-height','100','','','.b-email-editor'),(985216,'deals','.w-product-images-additional .item-img','max-height','70','5660','','.w-product-images-additional'),(985217,'deals','.b-select-suggest .select2-results','max-height','200','','','.b-select-suggest'),(985218,'deals','.w-product-promotions .products img','max-height','100','','','.w-product-promotions'),(985219,'deals','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-height','100','','','.b-products-listing'),(985220,'deals','.b-email-editor img','max-height','100','','','.b-email-editor'),(985221,'deals','.w-product-images-additional .item-img','max-height','70','5660','','.w-product-images-additional'),(985222,'deals','.w-product-images-additional .item-img','max-height','70','5660','','.w-product-images-additional'),(985223,'deals','.w-product-images-additional .item-img','max-height','70','5660','','.w-product-images-additional'),(985224,'deals','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max-height','100','','','.b-product-images'),(985225,'deals','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max-height','90','','','.b-product-images'),(985226,'deals','.b-product-images .media-popup .mp-small-images img','max-height','90','','','.b-product-images'),(985227,'deals','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','max-height','0','','','.b-menu-burger_icon'),(985228,'deals','.b-menu-burger_icon .bi-opened .menu-style[data-open_from=\"top\"] .menu-content','max-height','2000','','','.b-menu-burger_icon'),(985229,'deals','.w-product-images img','max-height','100','','','.w-product-images'),(985230,'deals','.b-product-images .additional-horizontal .additional-images img','max-height','150','','','.b-product-images'),(985231,'deals','.b-product-images .produst-image img','max-height','400','','','.b-product-images'),(985232,'deals','.b-product-images .additional-horizontal .additional-images video','max-height','150','','','.b-product-images'),(985233,'deals','.w-product-video .item img, .w-product-video .item video','max-height','150','','','.w-product-video'),(985234,'deals','.w-catalog-additional-images img','max-height','150','','','.w-catalog-additional-images'),(985235,'deals','.b-products-listing .products-listing .radio-attributes img','max-height','30','','','.b-products-listing'),(985236,'deals','.b-product-images .additional-horizontal .additional-images img','max-height','100','5630','','.b-product-images'),(985237,'deals','.b-product-images .additional-horizontal .additional-images video','max-height','100','5630','','.b-product-images'),(985238,'deals','.w-sale-category .image img','max-height','300','','','.w-sale-category'),(985239,'deals','.w-predefined-promotion .prom-multi-discount .image img','max-height','80','','','.w-predefined-promotion'),(985240,'deals','.w-predefined-promotion .promo-cart-discount .image img','max-height','80','','','.w-predefined-promotion'),(985241,'deals','.w-predefined-promotion .promo-salemaker .image img','max-height','80','','','.w-predefined-promotion'),(985242,'deals','.w-promotions-widgets-promotions .products img','max-height','100','','','.w-promotions-widgets-promotions'),(985245,'deals','.footer-menu .level-3','max-height','600','5639','','.footer-menu'),(985246,'deals','.footer-menu .level-3 > li > a','max-height','47','5639','','.footer-menu'),(985247,'deals','.b-product-images .additional-horizontal .additional-images img','max-height_important','important','','','.b-product-images'),(985248,'deals','.b-product-images .additional-horizontal .additional-images video','max-height_important','important','','','.b-product-images'),(985249,'deals','.b-product-images .additional-horizontal .additional-images img','max-height_important','important','5630','','.b-product-images'),(985250,'deals','.b-product-images .additional-horizontal .additional-images video','max-height_important','important','5630','','.b-product-images'),(985251,'deals','.w-checkout-guest-btn .btn-2','max-width','100','','','.w-checkout-guest-btn'),(985252,'deals','.w-product-images-additional .item-img','max-width','70','5660','','.w-product-images-additional'),(985253,'deals','.w-promotions .heading-3','max-width','calc(100% - 100px)','','','.w-promotions'),(985254,'deals','.w-promotions .promo-salemaker .item','max-width','calc(50% - 4px)','','','.w-promotions'),(985255,'deals','.w-promotions .promo-cart-discount .slave .item','max-width','calc(50% - 4px)','','','.w-promotions'),(985256,'deals','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(985257,'deals','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(985258,'deals','.w-upload-customer-id-upload-customer-id-form .dz-details img','max-width','100','','','.w-upload-customer-id-upload-customer-id-form'),(985259,'deals','.b-fancybox .fancybox-tmp','max-width','99999','','','.b-fancybox'),(985260,'deals','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(985261,'deals','.w-product-images-additional .item-img','max-width','70','5660','','.w-product-images-additional'),(985262,'deals','.main-width, .type-1 > .block','max-width','1800','','',''),(985263,'deals','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(985264,'deals','textarea','max-width','100','','',''),(985265,'deals','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(985266,'deals','.w-socials .post_item_img img','max-width','100','','','.w-socials'),(985267,'deals','.w-product-images-additional .item-img','max-width','70','5660','','.w-product-images-additional'),(985268,'deals','div.cart-popup','max-width','95','','',''),(985269,'deals','.b-form .middle-form','max-width','560','','','.b-form'),(985270,'deals','.b-email-editor img','max-width','100','','','.b-email-editor'),(985271,'deals','.w-product-images-additional .item-img','max-width','70','5660','','.w-product-images-additional'),(985272,'deals','.w-promotions .promo-cart-discount .master .item','max-width','calc(50% - 24px)','','','.w-promotions'),(985274,'deals','.b-email-editor img','max-width','100','','','.b-email-editor'),(985277,'deals','.w-product-images-additional .item-img','max-width','70','5660','','.w-product-images-additional'),(985279,'deals','.w-catalog-b2b-add-button .b2b-add-box-wrap','max-width','1250','','','.w-catalog-b2b-add-button'),(985280,'deals','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max-width','100','','','.b-products-listing'),(985281,'deals','.b-products-listing .promo','max-width','30','','','.b-products-listing'),(985282,'deals','.b-bottom .terms-info-popup','max-width','95','','','.b-bottom'),(985283,'deals','.w-checkout-create-btn .btn-2','max-width','100','','','.w-checkout-create-btn'),(985284,'deals','.b-email-editor img','max-width','100','','','.b-email-editor'),(985285,'deals','.b-fancybox .fancybox-image','max-width','100','','','.b-fancybox'),(985286,'deals','.b-bottom .popup-credit-amount .popup-box','max-width','960','','','.b-bottom'),(985287,'deals','.b-email-editor img','max-width','100','','','.b-email-editor'),(985288,'deals','.b-email-editor img','max-width','100','','','.b-email-editor'),(985290,'deals','.w-product-images-additional .item-img','max-width','70','5660','','.w-product-images-additional'),(985291,'deals','.b-email-editor img','max-width','100','','','.b-email-editor'),(985292,'deals','.b-upload-files .attached-block','max-width','300','','','.b-upload-files'),(985294,'deals','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max-width','100','','','.b-product-images'),(985295,'deals','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max-width','100','','','.b-product-images'),(985296,'deals','.b-product-images .media-popup .mp-small-images img','max-width','90','','','.b-product-images'),(985297,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max-width','100','','','.b-menu-lev_display-slide'),(985298,'deals','.b-trade-approval .middle-form','max-width','560','','','.b-trade-approval'),(985299,'deals','.w-login-register .middle-form','max-width','100','','','.w-login-register'),(985300,'deals','.w-login-returning .middle-form','max-width','100','','','.w-login-returning'),(985301,'deals','.w-catalog-additional-images img','max-width','150','','','.w-catalog-additional-images'),(985302,'deals','.b-products-listing .products-listing .radio-attributes img','max-width','30','','','.b-products-listing'),(985303,'deals','.w-product-multi-inventory .radio-attributes label img','max-width','23','','','.w-product-multi-inventory'),(985304,'deals','.b-products-listing .products-listing .radio-attributes label img','max-width','23','','','.b-products-listing'),(985305,'deals','.w-product-attributes .radio-attributes label img','max-width','23','','','.w-product-attributes'),(985306,'deals','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img','max-width','100','','','.w-product-groups'),(985307,'deals','.w-product-properties-icons .hover-box img','max-width','150','','','.w-product-properties-icons'),(985308,'deals','.w-press-reviews-widgets-press-reviews-small .item','max-width','100','','','.w-press-reviews-widgets-press-reviews-small'),(985309,'deals','.w-predefined-promotion .heading-3','max-width','calc(100% - 100px)','','','.w-predefined-promotion'),(985310,'deals','.w-predefined-promotion .promo-cart-discount .master .item','max-width','calc(50% - 24px)','','','.w-predefined-promotion'),(985311,'deals','.w-predefined-promotion .promo-cart-discount .slave .item','max-width','calc(50% - 4px)','','','.w-predefined-promotion'),(985312,'deals','.w-predefined-promotion .promo-salemaker .item','max-width','calc(50% - 4px)','','','.w-predefined-promotion'),(985314,'deals','.headerWrap .w-logo .logo','max-width','200','','','.headerWrap'),(985315,'deals','.headerWrap >div.block, .headerWrap .headerInside >div.block','max-width','100','','','.headerWrap'),(985316,'deals','.parallaxWrap .w-info-page','max-width','1215','','','.parallaxWrap'),(985317,'deals','.loginWrapper','max-width','680','','',''),(985318,'deals','.headerWrap .w-logo .logo','max-width','180','5660','','.headerWrap'),(985319,'deals','.homeBanner .banner-item .banner-text-holder','max-width','100','','','.homeBanner'),(985321,'deals','.checkout-index-wrap .edit-address-popup .addresses.address-edit-holder','max-width','600','','','.checkout-index-wrap'),(985322,'deals','.b-form .formWrapBox','max-width','500','','','.b-form'),(985323,'deals','.footer-menu .level-3','max-width','1000','5639','','.footer-menu'),(985324,'deals','.w-banner .banner-item.text-bottom-text .banner-text-holder','max-width','100','','','.w-banner'),(985325,'deals','.w-banner .banner-text-holder','max-width','500','','','.w-banner'),(985326,'deals','.w-banner .na-banner','max-width','200','','','.w-banner'),(985327,'deals','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_height_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(985328,'deals','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(985329,'deals','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(985330,'deals','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(985331,'deals','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(985332,'deals','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(985333,'deals','.b-fancybox .fancybox-image','max_height_measure','%','','','.b-fancybox'),(985334,'deals','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_height_measure','%','','','.b-products-listing'),(985335,'deals','.b-email-editor img','max_height_measure','%','','','.b-email-editor'),(985336,'deals','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max_height_measure','%','','','.b-product-images'),(985337,'deals','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max_height_measure','%','','','.b-product-images'),(985338,'deals','.b-product-images .media-popup .mp-small-images img','max_height_measure','%','','','.b-product-images'),(985339,'deals','.w-product-images img','max_height_measure','%','','','.w-product-images'),(985340,'deals','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(985341,'deals','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(985342,'deals','.w-upload-customer-id-upload-customer-id-form .dz-details img','max_width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(985343,'deals','.w-checkout-guest-btn .btn-2','max_width_measure','%','','','.w-checkout-guest-btn'),(985344,'deals','.w-checkout-create-btn .btn-2','max_width_measure','%','','','.w-checkout-create-btn'),(985345,'deals','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(985346,'deals','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(985347,'deals','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(985348,'deals','textarea','max_width_measure','%','','',''),(985349,'deals','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(985350,'deals','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(985351,'deals','div.cart-popup','max_width_measure','%','','',''),(985352,'deals','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(985353,'deals','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(985354,'deals','.w-socials .post_item_img img','max_width_measure','%','','','.w-socials'),(985355,'deals','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','max_width_measure','%','','','.b-products-listing'),(985356,'deals','.b-products-listing .promo','max_width_measure','%','','','.b-products-listing'),(985357,'deals','.b-bottom .terms-info-popup','max_width_measure','%','','','.b-bottom'),(985358,'deals','.b-fancybox .fancybox-image','max_width_measure','%','','','.b-fancybox'),(985359,'deals','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(985360,'deals','.b-email-editor img','max_width_measure','%','','','.b-email-editor'),(985361,'deals','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','max_width_measure','%','','','.b-product-images'),(985362,'deals','.b-product-images .media-popup .mp-big-images img, .b-product-images .media-popup .mp-big-images video, .b-product-images .media-popup .mp-big-images iframe','max_width_measure','%','','','.b-product-images'),(985363,'deals','.b-product-images .media-popup .mp-small-images img','max_width_measure','%','','','.b-product-images'),(985364,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','max_width_measure','vw','','','.b-menu-lev_display-slide'),(985365,'deals','.w-login-register .middle-form','max_width_measure','%','','','.w-login-register'),(985366,'deals','.w-login-returning .middle-form','max_width_measure','%','','','.w-login-returning'),(985367,'deals','.headerWrap >div.block, .headerWrap .headerInside >div.block','max_width_measure','%','','','.headerWrap'),(985368,'deals','.homeBanner .banner-item .banner-text-holder','max_width_measure','%','','','.homeBanner'),(985369,'deals','.w-banner .banner-item.text-bottom-text .banner-text-holder','max_width_measure','%','','','.w-banner'),(985370,'deals','.b-select-suggest .select2-results .select2-result-label','min-height','1','','','.b-select-suggest'),(985371,'deals','.b-select-suggest .select2-container-multi .select2-choices','min-height','26','','','.b-select-suggest'),(985372,'deals','.b-select-suggest .select2-search input','min-height','26','','','.b-select-suggest'),(985373,'deals','.b-select-suggest .select2-search','min-height','26','','','.b-select-suggest'),(985374,'deals','.b-select-suggest .select2-drop-mask','min-height','100','','','.b-select-suggest'),(985377,'deals','.w-cart-listing .item > div','min-height','1','','','.w-cart-listing'),(985378,'deals','.b-slick .slick-slide','min-height','1','','','.b-slick'),(985379,'deals','.w-cart-gift-certificate .gift-code p','min-height','45','','','.w-cart-gift-certificate'),(985380,'deals','.w-supplier-purchase-supplier-products .qty_col','min-height','40','','','.w-supplier-purchase-supplier-products'),(985381,'deals','.filterLine .w-catalog-sorting .sorting','min-height','40','','','.filterLine'),(985382,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','min-height','40','5630','','.headerWrap'),(985386,'deals','.w-communication-new-topic #communication_group_holder table','min-width','800','','','.w-communication-new-topic'),(985387,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.p-quick-order-index'),(985388,'deals','.p-quick-order-index .al_incart, .p-quick-order-index .al-incart','min-width','60','','','.p-quick-order-index'),(985389,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.p-quick-order-index'),(985390,'deals','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','min-width','150','','','.w-menu-horizontal'),(985391,'deals','.w-communication-post .btn-submit','min-width','200','','','.w-communication-post'),(985392,'deals','.b-form .payment-method .sub-item input, .b-form .payment-method .sub-item select','min-width','70','','','.b-form'),(985393,'deals','.b-bottom .popup-box.popupCompare','min-width','800','','','.b-bottom'),(985394,'deals','.b-bottom .confirm-popup .buttons .btn','min-width','120','','','.b-bottom'),(985395,'deals','.b-select-suggest .select2-drop-mask','min-width','100','','','.b-select-suggest'),(985396,'deals','.w-menu-horizontal > ul > li > ul > li','min-width','150','','','.w-menu-horizontal'),(985397,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','min-width','30','','','.b-data-table'),(985398,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','min-width','30','','','.b-data-table'),(985399,'deals','.w-communication-new-topic .quantity','min-width','70','','','.w-communication-new-topic'),(985400,'deals','.w-communication-new-topic #communication_group_holder table table','min-width','0','','','.w-communication-new-topic'),(985401,'deals','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','min-width','200','','','.b-menu-lev_display-down'),(985402,'deals','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','min-width','200','','','.b-menu-lev_display-down'),(985403,'deals','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','min-width','200','','','.b-menu-lev_display-down'),(985404,'deals','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','min-width','200','','','.b-menu-lev_display-down'),(985405,'deals','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','min-width','200','','','.b-menu-lev_display-down'),(985406,'deals','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','min-width','200','','','.b-menu-lev_display-left'),(985407,'deals','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','min-width','200','','','.b-menu-lev_display-left'),(985408,'deals','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','min-width','200','','','.b-menu-lev_display-left'),(985409,'deals','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','min-width','200','','','.b-menu-lev_display-left'),(985410,'deals','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','min-width','200','','','.b-menu-lev_display-left'),(985411,'deals','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','min-width','200','','','.b-menu-lev_display-lra'),(985412,'deals','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','min-width','200','','','.b-menu-lev_display-lra'),(985413,'deals','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','min-width','200','','','.b-menu-lev_display-lra'),(985414,'deals','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','min-width','200','','','.b-menu-lev_display-lra'),(985415,'deals','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','min-width','200','','','.b-menu-lev_display-lra'),(985416,'deals','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','min-width','200','','','.b-menu-lev_display-right'),(985417,'deals','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','min-width','200','','','.b-menu-lev_display-right'),(985418,'deals','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','min-width','200','','','.b-menu-lev_display-right'),(985419,'deals','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','min-width','200','','','.b-menu-lev_display-right'),(985420,'deals','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','min-width','200','','','.b-menu-lev_display-right'),(985421,'deals','.w-quote .no-text','min-width','120','','','.w-quote'),(985422,'deals','.w-product-quantity .qty_packs .qty_price','min-width','150','','','.w-product-quantity'),(985423,'deals','.w-sample .no-text','min-width','120','','','.w-sample'),(985424,'deals','.b-pagination .pagination .next-pages','min-width','30','','','.b-pagination'),(985425,'deals','.b-pagination .pagination .page-number','min-width','30','','','.b-pagination'),(985426,'deals','.b-pagination .pagination .prev-pages','min-width','30','','','.b-pagination'),(985427,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','min-width','30','','','.b-pagination'),(985428,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','min-width','30','','','.b-pagination'),(985429,'deals','.b-pagination .pagination span','min-width','30','2','','.b-pagination'),(985430,'deals','.w-product-groups .radioBox label','min-width','16','','','.w-product-groups'),(985431,'deals','.w-catalog-paging ','min-width','30','2','','.w-catalog-paging'),(985432,'deals','.w-catalog-paging .next','min-width','30','','','.w-catalog-paging'),(985433,'deals','.w-catalog-paging .next-pages','min-width','30','','','.w-catalog-paging'),(985434,'deals','.w-catalog-paging .page-number','min-width','30','','','.w-catalog-paging'),(985435,'deals','.w-catalog-paging .prev','min-width','30','','','.w-catalog-paging'),(985436,'deals','.w-catalog-paging .prev-pages','min-width','30','','','.w-catalog-paging'),(985438,'deals','.b-select-suggest .select2-results .select2-result-label','min_height_measure','em','','','.b-select-suggest'),(985439,'deals','.b-select-suggest .select2-drop-mask','min_height_measure','%','','','.b-select-suggest'),(985440,'deals','.b-select-suggest .select2-drop-mask','min_width_measure','%','','','.b-select-suggest'),(985441,'deals','.w-product-groups .radioBox label','min_width_measure','%','','','.w-product-groups'),(985442,'deals','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','opacity','0','','','.b-switch'),(985443,'deals','.p-quick-order-index .paginate_button.next.disabled','opacity','0.3','3','','.p-quick-order-index'),(985444,'deals','.p-quick-order-index .paginate_button.previous.disabled','opacity','0.3','3','','.p-quick-order-index'),(985445,'deals','.b-fancybox #fancybox-loading','opacity','0.8','','','.b-fancybox'),(985446,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-off, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-off','opacity','0.5','','','.b-switch'),(985447,'deals','.b-form .hide-billing-address','opacity','0.7','','','.b-form'),(985448,'deals','.disabled-area','opacity','0.5','','',''),(985449,'deals','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled.readonly','opacity','0.7','','','.b-switch'),(985450,'deals','.b-switch .candlestick-wrapper .candlestick-bg.candlestick-disabled','opacity','0.4','','','.b-switch'),(985451,'deals','.b-form .checkbox-style','opacity','0','','','.b-form'),(985452,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-label','opacity','0.5','','','.b-switch'),(985453,'deals','.b-switch .bootstrap-switch.bootstrap-switch-disabled .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-readonly .bootstrap-switch-handle-on, .b-switch .bootstrap-switch.bootstrap-switch-indeterminate .bootstrap-switch-handle-on','opacity','0.5','','','.b-switch'),(985454,'deals','.b-select-suggest .select2-drop-mask','opacity','0','','','.b-select-suggest'),(985455,'deals','.b-products-listing .products-listing .qty-input.hidden','opacity','0.7','3','','.b-products-listing'),(985456,'deals','.b-form .required-message','opacity','0.5','1','','.b-form'),(985457,'deals','.w-filters .input-checkbox','opacity','0','','','.w-filters'),(985458,'deals','.b-slick button.slick-disabled','opacity','0.3','','','.b-slick'),(985459,'deals','.b-quantity .qty-box .disabled','opacity','0.5','','','.b-quantity'),(985460,'deals','.w-product-buttons #btn-cart-none','opacity','0.3','','','.w-product-buttons'),(985461,'deals','.b-pagination .pagination .paging span.prev, .b-pagination .pagination .paging span.next','opacity','0.3','','','.b-pagination'),(985462,'deals','.w-product-groups .radioBox label input','opacity','0','','','.w-product-groups'),(985463,'deals','.w-product-designer-designer .productDesignerBox input','opacity','0','','','.w-product-designer-designer'),(985464,'deals','.headerWrap .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','opacity','1','','','.headerWrap'),(985466,'deals','.account-order-pay .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-order-pay'),(985467,'deals','.account-sample-info .account_history_info.account_history_info_due .account_history_info_due_wr','opacity','0.5','','','.account-sample-info'),(985468,'deals','.w-catalog-paging .paging span.prev, .w-catalog-paging .paging span.next','opacity','0.3','','','.w-catalog-paging'),(985469,'deals','.w-promotions .promo-cart-discount .slave .heading','order','1','','','.w-promotions'),(985470,'deals','.w-promotions .promo-cart-discount .slave .content','order','3','','','.w-promotions'),(985471,'deals','.w-promotions .promo-cart-discount .slave .condition','order','2','','','.w-promotions'),(985472,'deals','.w-cart-gift-certificate .input-apple .btn','order','2','','','.w-cart-gift-certificate'),(985473,'deals','.w-cart-gift-certificate .input-apple div','order','1','','','.w-cart-gift-certificate'),(985474,'deals','.w-cart-order-reference .input-apple div','order','1','','','.w-cart-order-reference'),(985475,'deals','.w-cart-order-reference .input-apple button','order','2','','','.w-cart-order-reference'),(985477,'deals','.w-press-reviews-widgets-press-reviews-list .date-added','order','4','','','.w-press-reviews-widgets-press-reviews-list'),(985478,'deals','.w-press-reviews-widgets-press-reviews-list .description','order','5','','','.w-press-reviews-widgets-press-reviews-list'),(985479,'deals','.w-press-reviews-widgets-press-reviews-list .image','order','1','','','.w-press-reviews-widgets-press-reviews-list'),(985480,'deals','.w-press-reviews-widgets-press-reviews-list .out-link','order','6','','','.w-press-reviews-widgets-press-reviews-list'),(985481,'deals','.w-press-reviews-widgets-press-reviews-list .rating','order','2','','','.w-press-reviews-widgets-press-reviews-list'),(985482,'deals','.w-press-reviews-widgets-press-reviews-list .short-description','order','3','','','.w-press-reviews-widgets-press-reviews-list'),(985483,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition','order','2','','','.w-predefined-promotion'),(985484,'deals','.w-predefined-promotion .promo-cart-discount .slave .content','order','3','','','.w-predefined-promotion'),(985485,'deals','.w-predefined-promotion .promo-cart-discount .slave .heading','order','1','','','.w-predefined-promotion'),(985491,'deals','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','outline','none','','','.b-fancybox'),(985492,'deals','.b-select-suggest .select2-container .select2-choice abbr','outline','0','','','.b-select-suggest'),(985493,'deals','.b-switch .bootstrap-switch.bootstrap-switch-focused','outline','0','','','.b-switch'),(985494,'deals','.b-select-suggest .select2-search-choice-close','outline','none','','','.b-select-suggest'),(985495,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','outline','0','','','.b-select-suggest'),(985496,'deals','.b-select-suggest .select2-container-multi.select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(985497,'deals','.b-select-suggest .select2-container-active .select2-choice, .b-select-suggest .select2-container-active .select2-choices','outline','none','','','.b-select-suggest'),(985498,'deals','.b-select-suggest .select2-search input','outline','0','','','.b-select-suggest'),(985499,'deals','input:focus','outline','none','','',''),(985500,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline','0','','','.b-select-suggest'),(985501,'deals','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','outline','none','','','.b-fancybox'),(985502,'deals','.b-product-images .media-popup .mp-big-images .item','outline','none','','','.b-product-images'),(985503,'deals','.b-product-images .media-popup .mp-small-images .item','outline','none','','','.b-product-images'),(985504,'deals','.b-slick .slick-list:focus','outline','none','','','.b-slick'),(985505,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','outline_important','important','','','.b-select-suggest'),(985506,'deals','.w-communication-new-topic #communication_group_holder','overflow','auto','','','.w-communication-new-topic'),(985507,'deals','.b-form .shipping-method .sub-title','overflow','hidden','','','.b-form'),(985508,'deals','.p-quick-order-index .top','overflow','hidden','','','.p-quick-order-index'),(985509,'deals','.w-promotions .prom-multi-discount .promo-product a.name, .w-promotions .prom-multi-discount .promo-category-item a.name','overflow','hidden','','','.w-promotions'),(985510,'deals','.w-cart-compare .product .name','overflow','hidden','','','.w-cart-compare'),(985511,'deals','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(985512,'deals','.b-switch .bootstrap-switch','overflow','hidden','','','.b-switch'),(985513,'deals','.b-fancybox .fancybox-lock .fancybox-overlay','overflow','auto','','','.b-fancybox'),(985514,'deals','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(985515,'deals','.b-select-suggest .select2-measure-scrollbar','overflow','scroll','','','.b-select-suggest'),(985516,'deals','.b-fancybox .fancybox-tmp','overflow','visible','','','.b-fancybox'),(985517,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow','hidden','','','.b-select-suggest'),(985518,'deals','.p-quick-order-index .bottom','overflow','hidden','','','.p-quick-order-index'),(985519,'deals','.w-cart-listing .right-area','overflow','hidden','5639','','.w-cart-listing'),(985521,'deals','.b-fancybox .fancybox-inner','overflow','hidden','','','.b-fancybox'),(985522,'deals','.b-fancybox .fancybox-lock','overflow','hidden','','','.b-fancybox'),(985523,'deals','.b-fancybox .fancybox-overlay','overflow','hidden','','','.b-fancybox'),(985524,'deals','.b-select-suggest .select2-container .select2-choice','overflow','hidden','','','.b-select-suggest'),(985525,'deals','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(985526,'deals','.b-bottom .cart-options .options','overflow','hidden','','','.b-bottom'),(985527,'deals','.b-autocomplete .ui-autocomplete','overflow','auto','','','.b-autocomplete'),(985528,'deals','.b-upload-files .attach-active-holder','overflow','hidden','','','.b-upload-files'),(985529,'deals','.b-upload-files .added-file','overflow','hidden','','','.b-upload-files'),(985530,'deals','.b-fancybox .fancybox-lock body','overflow','hidden','','','.b-fancybox'),(985531,'deals','.w-checkout-shipping-choice input','overflow','hidden','','','.w-checkout-shipping-choice'),(985532,'deals','.w-checkout-shipping-choice #shippingchoice-choice','overflow','hidden','','','.w-checkout-shipping-choice'),(985533,'deals','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(985534,'deals','.b-select-suggest .select2-container-multi .select2-choices','overflow','hidden','','','.b-select-suggest'),(985535,'deals','.b-preloader .preloader','overflow','hidden','3','','.b-preloader'),(985536,'deals','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(985537,'deals','.w-account-addresses-list ','overflow','hidden','','','.w-account-addresses-list'),(985538,'deals','.b-products-listing .btn-preloader','overflow','hidden','3','','.b-products-listing'),(985539,'deals','.b-products-listing .loader','overflow','hidden','4','','.b-products-listing'),(985540,'deals','.b-compare .compare-box-item','overflow','hidden','','','.b-compare'),(985541,'deals','.b-form .payment-method .item-radio label span','overflow','hidden','','','.b-form'),(985542,'deals','.w-quote .no-text','overflow','hidden','','','.w-quote'),(985543,'deals','.b-compare .col-two','overflow','hidden','','','.b-compare'),(985544,'deals','.w-cart-give-away .ga_ovr','overflow','hidden','','','.w-cart-give-away'),(985545,'deals','.w-cart-give-away .ga_wrapper','overflow','hidden','','','.w-cart-give-away'),(985548,'deals','.w-brands .brands-listing','overflow','hidden','','','.w-brands'),(985549,'deals','.w-cart-shipping-estimator .item .row','overflow','hidden','','','.w-cart-shipping-estimator'),(985550,'deals','.b-upload-files .attached-block','overflow','hidden','','','.b-upload-files'),(985551,'deals','.b-upload-files .attach-block','overflow','hidden','','','.b-upload-files'),(985552,'deals','.b-select-suggest .select2-container .select2-choice > .select2-chosen','overflow','hidden','','','.b-select-suggest'),(985553,'deals','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','overflow','hidden','','','.b-menu-burger_icon'),(985554,'deals','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','overflow','auto','','','.b-menu-lev_display-width'),(985555,'deals','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','overflow','auto','','','.b-menu-lev_display-width'),(985556,'deals','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','overflow','auto','','','.b-menu-lev_display-width'),(985557,'deals','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','overflow','auto','','','.b-menu-lev_display-width'),(985558,'deals','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','overflow','auto','','','.b-menu-lev_display-width'),(985559,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','overflow','auto','','','.b-menu-lev_display-width_cont'),(985560,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','overflow','auto','','','.b-menu-lev_display-width_cont'),(985561,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','overflow','auto','','','.b-menu-lev_display-width_cont'),(985562,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','overflow','auto','','','.b-menu-lev_display-width_cont'),(985563,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','overflow','auto','','','.b-menu-lev_display-width_cont'),(985564,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','overflow','auto','','','.b-menu-open_from-left'),(985565,'deals','.b-trade-approval .steps-bar','overflow','hidden','','','.b-trade-approval'),(985566,'deals','.w-catalog-compare .compare','overflow','hidden','','','.w-catalog-compare'),(985567,'deals','.w-delivery-day .time-left','overflow','hidden','','','.w-delivery-day'),(985568,'deals','.w-product-images .slick-vertical + .produst-image','overflow','hidden','','','.w-product-images'),(985569,'deals','.b-slick .slick-list','overflow','hidden','','','.b-slick'),(985570,'deals','.w-quote .multicart .sub-total-row','overflow','hidden','','','.w-quote'),(985571,'deals','.w-quote .sub-total-row','overflow','hidden','','','.w-quote'),(985572,'deals','.w-product-sale-ends .left','overflow','hidden','','','.w-product-sale-ends'),(985573,'deals','.w-compare .compare-list-holder','overflow','hidden','','','.w-compare'),(985574,'deals','.w-compare .item-holder','overflow','hidden','','','.w-compare'),(985575,'deals','.w-sample .multicart .sub-total-row','overflow','hidden','','','.w-sample'),(985576,'deals','.w-sample .no-text','overflow','hidden','','','.w-sample'),(985577,'deals','.w-sample .sub-total-row','overflow','hidden','','','.w-sample'),(985578,'deals','.w-cart-gift-certificate .gift-code .input-apple > div','overflow','hidden','','','.w-cart-gift-certificate'),(985579,'deals','.w-product-bundle .right-area-bundle','overflow','hidden','','','.w-product-bundle'),(985580,'deals','.w-product-bundle .bundle_item','overflow','hidden','','','.w-product-bundle'),(985581,'deals','.w-product-in-bundles .bundle_item','overflow','hidden','','','.w-product-in-bundles'),(985582,'deals','.w-product-in-bundles .right-area-bundle','overflow','hidden','','','.w-product-in-bundles'),(985583,'deals','.w-product-groups .radioBox','overflow','hidden','','','.w-product-groups'),(985584,'deals','.w-sale-category .left','overflow','hidden','','','.w-sale-category'),(985585,'deals','.w-sale-category .sale-holder','overflow','hidden','','','.w-sale-category'),(985586,'deals','.w-gift-wrap-message-checkout ','overflow','hidden','','','.w-gift-wrap-message-checkout'),(985587,'deals','.w-support-system-listing .support-head','overflow','hidden','','','.w-support-system-listing'),(985588,'deals','.w-rma-returns-history .content-messages .messages-table .top','overflow','hidden','','','.w-rma-returns-history'),(985589,'deals','.w-predefined-promotion .prom-multi-discount .promo-product a.name, .w-predefined-promotion .prom-multi-discount .promo-category-item a.name','overflow','hidden','','','.w-predefined-promotion'),(985591,'deals','.w-top-categories picture','overflow','hidden','','','.w-top-categories'),(985592,'deals','.headerWrap .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','overflow','visible','','','.headerWrap'),(985593,'deals','.w-categories picture','overflow','hidden','','','.w-categories'),(985594,'deals','.filterLine .filter-widget-horizontal .content-filter-widget.openBoxes','overflow','inherit','','','.filterLine'),(985595,'deals','.w-support-system-listing .topicList','overflow','inherit','','','.w-support-system-listing'),(985596,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','overflow','hidden','','','.w-account-personal-catalog'),(985597,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','overflow','visible','1','','.w-account-personal-catalog'),(985601,'deals','.account-address-book .buttonBox','overflow','hidden','','','.account-address-book'),(985603,'deals','.account-order-pay .history_info','overflow','hidden','','','.account-order-pay'),(985604,'deals','.account-sample-info .history_info','overflow','hidden','','','.account-sample-info'),(985605,'deals','.fake-input','overflow','hidden','','',''),(985606,'deals','.footer-menu .level-3','overflow','auto','5639','','.footer-menu'),(985607,'deals','.payment-method-tf label','overflow','hidden','','','.payment-method-tf'),(985608,'deals','.w-banner .banner .image-box','overflow','hidden','','','.w-banner'),(985609,'deals','.w-catalog-paging .paging-holder','overflow','hidden','','','.w-catalog-paging'),(985610,'deals','.w-catalog-paging .paging-holder.slick-slider','overflow','visible','','','.w-catalog-paging'),(985611,'deals','.b-compare .compare_list','overflow-x','hidden','','','.b-compare'),(985612,'deals','.b-select-suggest .select2-results','overflow-x','hidden','','','.b-select-suggest'),(985613,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-x','hidden','','','.b-menu-lev_display-slide'),(985614,'deals','.b-compare .compare_list','overflow-y','auto','','','.b-compare'),(985615,'deals','.b-fancybox .fancybox-lock .fancybox-overlay','overflow-y','scroll','','','.b-fancybox'),(985616,'deals','.b-fancybox .fancybox-lock-test','overflow-y','hidden','','','.b-fancybox'),(985617,'deals','.b-select-suggest .select2-results','overflow-y','auto','','','.b-select-suggest'),(985618,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .menu-content','overflow-y','auto','','','.b-menu-lev_display-slide'),(985619,'deals','.b-fancybox .fancybox-lock-test','overflow-y_important','important','','','.b-fancybox'),(985620,'deals','.b-fancybox .fancybox-lock','overflow_important','important','','','.b-fancybox'),(985621,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','overflow_important','important','','','.b-select-suggest'),(985622,'deals','.b-fancybox .fancybox-tmp','overflow_important','important','','','.b-fancybox'),(985623,'deals','.b-fancybox .fancybox-lock body','overflow_important','important','','','.b-fancybox'),(985624,'deals','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-bottom','10','','','.w-communication-new-topic'),(985625,'deals','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(985626,'deals','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(985627,'deals','.b-email .heading-model','padding-bottom','5','','','.b-email'),(985628,'deals','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(985629,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(985630,'deals','.w-product-images-additional .images','padding-bottom','20','5660','','.w-product-images-additional'),(985633,'deals','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(985634,'deals','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(985635,'deals','.p-quick-order-index ul.token-input-list','padding-bottom','0','','','.p-quick-order-index'),(985636,'deals','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-bottom','7','','','.p-quick-order-index'),(985637,'deals','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-bottom','8','','','.p-quick-order-index'),(985638,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.p-quick-order-index'),(985639,'deals','.w-promotions .promo-item','padding-bottom','20','','','.w-promotions'),(985640,'deals','.w-top-categories h2.name','padding-bottom','3','','','.w-top-categories'),(985641,'deals','.w-cart-compare .attributes-label','padding-bottom','10','','','.w-cart-compare'),(985648,'deals','.w-personal-gift-status-bar .start-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(985649,'deals','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(985650,'deals','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(985651,'deals','.testimonials .review','padding-bottom','10','','',''),(985652,'deals','.testimonials .heading-3','padding-bottom','10','','',''),(985653,'deals','.testimonials .reviews-list .name','padding-bottom','5','','',''),(985654,'deals','.testimonials .name','padding-bottom','5','','',''),(985655,'deals','.w-categories .image','padding-bottom','75','','','.w-categories'),(985656,'deals','.w-promotions .prom-multi-discount .promo-range','padding-bottom','0','','','.w-promotions'),(985657,'deals','.w-promotions .prom-multi-discount .promo-product','padding-bottom','20','','','.w-promotions'),(985658,'deals','.w-promotions .nextdiscount .promo-for-each','padding-bottom','2','','','.w-promotions'),(985659,'deals','.w-promotions .nextdiscount .content > div','padding-bottom','10','','','.w-promotions'),(985660,'deals','.w-promotions .promo-salemaker .item','padding-bottom','20','','','.w-promotions'),(985661,'deals','.w-promotions .promo-salemaker .discount','padding-bottom','0','','','.w-promotions'),(985662,'deals','.w-promotions .promo-cart-discount .slave .item','padding-bottom','20','','','.w-promotions'),(985663,'deals','.w-promotions .promo-cart-discount .slave .heading','padding-bottom','1','','','.w-promotions'),(985664,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','padding-bottom','0','','','.w-promotions'),(985665,'deals','.w-promotions .promo-cart-discount .promo-min-qty','padding-bottom','0','','','.w-promotions'),(985666,'deals','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-bottom','20','','','.b-warehouses-popup'),(985667,'deals','.w-product-available-in-warehouses .warehouse-item','padding-bottom','20','','','.w-product-available-in-warehouses'),(985668,'deals','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-bottom','6','','','.b-products-listing'),(985670,'deals','.w-cart-compare .attributes-cell','padding-bottom','8','','','.w-cart-compare'),(985671,'deals','.b-bottom .confirm-popup .confirm-text','padding-bottom','30','','','.b-bottom'),(985672,'deals','.b-messages .msv_btn','padding-bottom','12','','','.b-messages'),(985673,'deals','.b-messages .msv_content','padding-bottom','10','','','.b-messages'),(985674,'deals','.b-messages .msv_history','padding-bottom','10','','','.b-messages'),(985675,'deals','.b-messages .messMenuButton span','padding-bottom','10','','','.b-messages'),(985676,'deals','.b-messages .messages-menu li a','padding-bottom','8','','','.b-messages'),(985677,'deals','.b-messages .messages-menu li','padding-bottom','0','','','.b-messages'),(985678,'deals','.b-messages .messages-menu ul','padding-bottom','0','','','.b-messages'),(985679,'deals','.b-messages .content_management_attach button','padding-bottom','1','','','.b-messages'),(985680,'deals','.b-messages .email-heading','padding-bottom','15','','','.b-messages'),(985681,'deals','.b-messages .content_management_attach','padding-bottom','8','','','.b-messages'),(985682,'deals','.b-messages .emailLineTextArea textarea','padding-bottom','30','','','.b-messages'),(985683,'deals','.b-messages .msv_to_cc','padding-bottom','10','','','.b-messages'),(985684,'deals','.b-messages .emailBtn','padding-bottom','10','','','.b-messages'),(985685,'deals','.b-messages .dataTables_wrapper > .bottom','padding-bottom','4','','','.b-messages'),(985686,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-bottom','5','','','.b-messages'),(985687,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-bottom','6','','',''),(985688,'deals','.w-sitemap-delivery-location > ul > li > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(985690,'deals','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(985691,'deals','.w-reviews-content .item','padding-bottom','25','','','.w-reviews-content'),(985692,'deals','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(985693,'deals','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(985694,'deals','.w-sitemap-delivery-location > ul','padding-bottom','0','','','.w-sitemap-delivery-location'),(985695,'deals','.w-checkout-terms .required-message','padding-bottom','5','','','.w-checkout-terms'),(985696,'deals','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(985697,'deals','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(985698,'deals','.b-email .model','padding-bottom','5','','','.b-email'),(985699,'deals','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(985700,'deals','.w-checkout-shipping-address .edit-ab','padding-bottom','0','','','.w-checkout-shipping-address'),(985701,'deals','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(985702,'deals','.w-reviews-content .author','padding-bottom','20','','','.w-reviews-content'),(985703,'deals','.w-promo-code .holder','padding-bottom','20','5660','','.w-promo-code'),(985704,'deals','.w-cart-listing .item .remove','padding-bottom','5','5639','','.w-cart-listing'),(985705,'deals','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(985706,'deals','.b-email .image','padding-bottom','5','','','.b-email'),(985707,'deals','.b-email .heading-price','padding-bottom','5','','','.b-email'),(985708,'deals','.b-email .heading-image','padding-bottom','5','','','.b-email'),(985709,'deals','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(985710,'deals','.w-filters .filter-ul-content','padding-bottom','0','','','.w-filters'),(985711,'deals','.w-filters .filter-box-head','padding-bottom','5','','','.w-filters'),(985712,'deals','.w-filters .filter-li-content','padding-bottom','15','','','.w-filters'),(985713,'deals','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(985714,'deals','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(985715,'deals','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(985716,'deals','.w-menu-horizontal > ul > li > ul > li','padding-bottom','2','','','.w-menu-horizontal'),(985717,'deals','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-bottom','2','','','.w-menu-horizontal'),(985718,'deals','.w-menu-horizontal ul','padding-bottom','0','','','.w-menu-horizontal'),(985719,'deals','.w-tabs .tab-navigation','padding-bottom','7','','','.w-tabs'),(985720,'deals','.b-email .heading-name','padding-bottom','5','','','.b-email'),(985721,'deals','.b-email .heading-model','padding-bottom','5','','','.b-email'),(985723,'deals','.b-email .totals-value','padding-bottom','5','','','.b-email'),(985724,'deals','.b-email .name','padding-bottom','5','','','.b-email'),(985725,'deals','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(985726,'deals','.b-email .qty','padding-bottom','5','','','.b-email'),(985727,'deals','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(985728,'deals','.b-bottom .terms-info-popup .pop-up-content','padding-bottom','20','','','.b-bottom'),(985729,'deals','.w-cart-compare .dropdown .dropdown-menu','padding-bottom','5','','','.w-cart-compare'),(985730,'deals','.no-found','padding-bottom','20','','',''),(985731,'deals','textarea','padding-bottom','5','','',''),(985732,'deals','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(985733,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(985734,'deals','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(985735,'deals','.p-quick-order-index .bottom','padding-bottom','10','','','.p-quick-order-index'),(985736,'deals','.w-chat .w-chat-box','padding-bottom','2','','','.w-chat'),(985738,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-bottom','10','','','.w-image-maps'),(985739,'deals','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(985740,'deals','.message.success','padding-bottom','15','','',''),(985741,'deals','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(985742,'deals','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(985743,'deals','.b-email .image','padding-bottom','5','','','.b-email'),(985744,'deals','.b-email .heading-price','padding-bottom','5','','','.b-email'),(985745,'deals','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-bottom','0','','','.b-fancybox'),(985746,'deals','.w-checkout-shipping-choice span','padding-bottom','4','','','.w-checkout-shipping-choice'),(985747,'deals','.b-email .model','padding-bottom','5','','','.b-email'),(985748,'deals','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(985749,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-bottom','0','','','.b-select-suggest'),(985750,'deals','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(985751,'deals','.w-reviews .review','padding-bottom','5','','','.w-reviews'),(985752,'deals','.w-socials > li','padding-bottom','15','','','.w-socials'),(985754,'deals','.b-info-popup .info-popup div','padding-bottom','10','','','.b-info-popup'),(985755,'deals','.b-form .payment-method .item','padding-bottom','7','','','.b-form'),(985756,'deals','.w-checkout-create-account .create-account','padding-bottom','10','','','.w-checkout-create-account'),(985757,'deals','.b-form .password-forgotten-link','padding-bottom','0','','','.b-form'),(985758,'deals','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(985759,'deals','.w-catalog-sorting .before','padding-bottom','0','','','.w-catalog-sorting'),(985761,'deals','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(985762,'deals','.b-email .qty','padding-bottom','5','','','.b-email'),(985763,'deals','.b-email .heading-price','padding-bottom','5','','','.b-email'),(985764,'deals','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(985765,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(985766,'deals','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-bottom','3','','','.w-multi-cart-actions'),(985767,'deals','.w-top-categories .item','padding-bottom','40','','','.w-top-categories'),(985768,'deals','.w-tabs > .block','padding-bottom','30','','','.w-tabs'),(985769,'deals','.w-tabs .accordion-heading','padding-bottom','6','2','','.w-tabs'),(985770,'deals','.w-tabs .accordion-heading','padding-bottom','9','5630','','.w-tabs'),(985771,'deals','.w-cart-cart-tabs .w-tabs > .block','padding-bottom','0','','','.w-cart-cart-tabs'),(985772,'deals','.w-tabs .tab-a','padding-bottom','0','','','.w-tabs'),(985773,'deals','.w-tabs .tab-li','padding-bottom','0','','','.w-tabs'),(985774,'deals','.w-socials > li','padding-bottom','15','','','.w-socials'),(985775,'deals','.w-promo-code .holder','padding-bottom','20','5660','','.w-promo-code'),(985776,'deals','.b-bottom .popup-buttons','padding-bottom','15','','','.b-bottom'),(985777,'deals','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-bottom','7','','','.order-summary'),(985778,'deals','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(985779,'deals','.b-sub-totals .historyTotal td','padding-bottom','2','','','.b-sub-totals'),(985780,'deals','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(985781,'deals','.b-form .required-message','padding-bottom','0','','','.b-form'),(985782,'deals','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(985783,'deals','.btn-1','padding-bottom','10','','',''),(985784,'deals','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(985785,'deals','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(985786,'deals','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(985787,'deals','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(985788,'deals','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(985790,'deals','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(985791,'deals','.btn-3','padding-bottom','8','','',''),(985792,'deals','.b-products-listing .products-listing .buyButton .btn','padding-bottom','4','','','.b-products-listing'),(985793,'deals','.w-product-images-additional .images','padding-bottom','20','5660','','.w-product-images-additional'),(985794,'deals','.b-form .required-message-wrap','padding-bottom','0','','','.b-form'),(985795,'deals','.b-email .image','padding-bottom','5','','','.b-email'),(985796,'deals','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(985797,'deals','.w-cart-discount-coupon .btn','padding-bottom','4','','','.w-cart-discount-coupon'),(985798,'deals','.b-email .heading-image','padding-bottom','5','','','.b-email'),(985799,'deals','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(985800,'deals','.b-email .heading-model','padding-bottom','5','','','.b-email'),(985801,'deals','.order-summary .price-row','padding-bottom','7','','','.order-summary'),(985802,'deals','.b-email .heading-model','padding-bottom','5','','','.b-email'),(985803,'deals','.b-email .price','padding-bottom','5','','','.b-email'),(985804,'deals','.b-email .heading-name','padding-bottom','5','','','.b-email'),(985805,'deals','.w-socials > li','padding-bottom','15','','','.w-socials'),(985806,'deals','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(985807,'deals','.b-upload-file .upload-file-template','padding-bottom','25','','','.b-upload-file'),(985809,'deals','.b-select-suggest .select2-drop-mask','padding-bottom','0','','','.b-select-suggest'),(985810,'deals','.w-quote .cart-box-link','padding-bottom','0','','','.w-quote'),(985811,'deals','.w-reviews .author','padding-bottom','10','','','.w-reviews'),(985812,'deals','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(985813,'deals','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(985815,'deals','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(985816,'deals','.b-email .price','padding-bottom','5','','','.b-email'),(985817,'deals','.b-fancybox .fancybox-title-float-wrap .child','padding-bottom','2','','','.b-fancybox'),(985818,'deals','.w-checkout-shipping-choice span','padding-bottom','4','5660','','.w-checkout-shipping-choice'),(985819,'deals','.w-top-categories .categories h2','padding-bottom','0','','','.w-top-categories'),(985820,'deals','.w-top-categories .image','padding-bottom','75','','','.w-top-categories'),(985821,'deals','.w-product-reviews .reviews-list .review','padding-bottom','10','','','.w-product-reviews'),(985822,'deals','.w-product-reviews .reviews-list .name','padding-bottom','5','','','.w-product-reviews'),(985823,'deals','.w-reviews-content .rating','padding-bottom','10','','','.w-reviews-content'),(985824,'deals','.b-email .totals-value','padding-bottom','5','','','.b-email'),(985825,'deals','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(985826,'deals','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(985827,'deals','.b-bottom .rfq-form','padding-bottom','0','','','.b-bottom'),(985828,'deals','.b-bottom .popup-simple','padding-bottom','20','','','.b-bottom'),(985829,'deals','.b-bottom .popup-heading','padding-bottom','12','','','.b-bottom'),(985830,'deals','.b-email .model','padding-bottom','5','','','.b-email'),(985831,'deals','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(985832,'deals','.b-email .image','padding-bottom','5','','','.b-email'),(985833,'deals','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(985834,'deals','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(985835,'deals','.b-email .image','padding-bottom','5','','','.b-email'),(985836,'deals','.b-email .name','padding-bottom','5','','','.b-email'),(985837,'deals','.b-email .heading-price','padding-bottom','5','','','.b-email'),(985838,'deals','.b-email .heading-model','padding-bottom','5','','','.b-email'),(985839,'deals','.b-email .totals-title','padding-bottom','5','','','.b-email'),(985840,'deals','.b-email .totals-value','padding-bottom','5','','','.b-email'),(985841,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(985842,'deals','.b-email .qty','padding-bottom','5','','','.b-email'),(985843,'deals','.b-email .model','padding-bottom','5','','','.b-email'),(985844,'deals','.b-email .price','padding-bottom','5','','','.b-email'),(985845,'deals','.b-email .heading-name','padding-bottom','5','','','.b-email'),(985846,'deals','.b-email .heading-image','padding-bottom','5','','','.b-email'),(985847,'deals','.w-checkout-shipping .sub-item','padding-bottom','5','','','.w-checkout-shipping'),(985848,'deals','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(985849,'deals','.b-email .totals-value','padding-bottom','5','','','.b-email'),(985850,'deals','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(985851,'deals','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(985852,'deals','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(985853,'deals','.w-promo-code .holder','padding-bottom','20','5660','','.w-promo-code'),(985854,'deals','.b-form .center-buttons','padding-bottom','20','','','.b-form'),(985855,'deals','.b-form .shipping-method .input','padding-bottom','0','','','.b-form'),(985856,'deals','.w-reviews .item','padding-bottom','15','','','.w-reviews'),(985857,'deals','.w-reviews .product-name','padding-bottom','12','','','.w-reviews'),(985858,'deals','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(985859,'deals','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(985860,'deals','.b-select-suggest .select2-container .select2-choice','padding-bottom','0','','','.b-select-suggest'),(985861,'deals','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(985862,'deals','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(985863,'deals','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(985864,'deals','.w-cart-compare .price-label','padding-bottom','10','','','.w-cart-compare'),(985865,'deals','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(985866,'deals','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(985868,'deals','.b-upload-files .upload-files','padding-bottom','10','','','.b-upload-files'),(985869,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(985870,'deals','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(985871,'deals','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(985872,'deals','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(985873,'deals','.b-form .col-full-padding','padding-bottom','30','','','.b-form'),(985874,'deals','.w-categories .item','padding-bottom','20','','','.w-categories'),(985875,'deals','.b-form .form-buttons','padding-bottom','50','','','.b-form'),(985876,'deals','.b-fancybox .fancybox-title-over-wrap','padding-bottom','10','','','.b-fancybox'),(985877,'deals','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(985878,'deals','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(985879,'deals','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(985880,'deals','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(985881,'deals','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(985882,'deals','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(985883,'deals','.w-cart-compare .delete-cart','padding-bottom','10','','','.w-cart-compare'),(985884,'deals','.p-quick-order-index .all-scroll-div','padding-bottom','10','','','.p-quick-order-index'),(985885,'deals','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(985886,'deals','.w-checkout-billing-address .same-address','padding-bottom','10','','','.w-checkout-billing-address'),(985887,'deals','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(985888,'deals','.b-email .heading-image','padding-bottom','5','','','.b-email'),(985889,'deals','.b-email .price','padding-bottom','5','','','.b-email'),(985890,'deals','.b-email .heading-name','padding-bottom','5','','','.b-email'),(985891,'deals','.b-email .model','padding-bottom','5','','','.b-email'),(985892,'deals','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-bottom','10','','','.b-bottom'),(985893,'deals','.w-cart-compare .cart-cell','padding-bottom','20','','','.w-cart-compare'),(985894,'deals','.w-promotions .promo-cart-discount .master .item','padding-bottom','20','','','.w-promotions'),(985895,'deals','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(985896,'deals','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(985897,'deals','.b-bottom .cart-options','padding-bottom','20','','','.b-bottom'),(985898,'deals','.b-bottom .alert-message','padding-bottom','20','','','.b-bottom'),(985899,'deals','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(985900,'deals','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(985901,'deals','.b-select-suggest .select2-results .select2-result-label','padding-bottom','4','','','.b-select-suggest'),(985902,'deals','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(985903,'deals','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(985904,'deals','.b-email .totals-title','padding-bottom','5','','','.b-email'),(985905,'deals','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(985906,'deals','.w-reviews-content .product-name','padding-bottom','20','','','.w-reviews-content'),(985907,'deals','.b-email .name','padding-bottom','5','','','.b-email'),(985908,'deals','.b-email .heading-price','padding-bottom','5','','','.b-email'),(985909,'deals','.b-email .heading-image','padding-bottom','5','','','.b-email'),(985910,'deals','.b-email .heading-name','padding-bottom','5','','','.b-email'),(985911,'deals','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(985912,'deals','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(985913,'deals','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-bottom','4','','','.b-compare'),(985914,'deals','.b-bottom .pop-up-close','padding-bottom','1','','','.b-bottom'),(985915,'deals','.b-bottom .footerTitle','padding-bottom','9','5630','','.b-bottom'),(985916,'deals','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(985917,'deals','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(985918,'deals','.w-cart-up-sell .w-list-type-1','padding-bottom','0','','','.w-cart-up-sell'),(985919,'deals','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','0','1','','.w-cart-up-sell'),(985920,'deals','.w-cart-up-sell .w-list-type-1 .item','padding-bottom','1','','','.w-cart-up-sell'),(985921,'deals','.b-products-listing .products-listing .btn-buy','padding-bottom','11','','','.b-products-listing'),(985922,'deals','.b-upload-files .added-file','padding-bottom','5','','','.b-upload-files'),(985924,'deals','.w-menu-big ul','padding-bottom','0','','','.w-menu-big'),(985925,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(985926,'deals','.w-categories h2.name','padding-bottom','3','','','.w-categories'),(985927,'deals','.b-bottom .header-info','padding-bottom','20','','','.b-bottom'),(985928,'deals','.b-bottom .popup-box-wrap','padding-bottom','10','','','.b-bottom'),(985929,'deals','.w-product-images-additional .images','padding-bottom','20','5660','','.w-product-images-additional'),(985930,'deals','.b-bottom .pop-up-info','padding-bottom','20','','','.b-bottom'),(985931,'deals','.b-email .price','padding-bottom','5','','','.b-email'),(985932,'deals','.b-fancybox .fancybox-error','padding-bottom','15','','','.b-fancybox'),(985933,'deals','.w-product-customers-activity .customers-activity','padding-bottom','20','','','.w-product-customers-activity'),(985934,'deals','.b-compare .compare-box-item','padding-bottom','10','','','.b-compare'),(985935,'deals','.b-bottom .confirm-popup .buttons','padding-bottom','30','','','.b-bottom'),(985936,'deals','.b-compare .compare-head','padding-bottom','0','','','.b-compare'),(985937,'deals','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(985938,'deals','.b-email .heading-image','padding-bottom','5','','','.b-email'),(985939,'deals','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(985940,'deals','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(985941,'deals','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(985942,'deals','.b-form .login-col-1','padding-bottom','0','','','.b-form'),(985943,'deals','.b-social-login .social-login-text-1','padding-bottom','15','','','.b-social-login'),(985944,'deals','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(985946,'deals','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(985947,'deals','.w-checkout-billing-address .edit-ab','padding-bottom','0','','','.w-checkout-billing-address'),(985948,'deals','.w-checkout-shipping-choice #shippingchoice-choice','padding-bottom','7','','','.w-checkout-shipping-choice'),(985949,'deals','.w-promo-code .holder','padding-bottom','20','5660','','.w-promo-code'),(985950,'deals','.w-product-images-additional .images','padding-bottom','20','5660','','.w-product-images-additional'),(985951,'deals','.b-bottom .header-error','padding-bottom','20','','','.b-bottom'),(985952,'deals','.w-tabs .accordion-heading','padding-bottom','8','','','.w-tabs'),(985953,'deals','.w-socials > li','padding-bottom','15','','','.w-socials'),(985954,'deals','.b-autocomplete .ui-autocomplete li','padding-bottom','3','','','.b-autocomplete'),(985955,'deals','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(985956,'deals','.w-cart-give-away .ga_column','padding-bottom','15','','','.w-cart-give-away'),(985957,'deals','.w-cart-compare .price-cell','padding-bottom','8','','','.w-cart-compare'),(985958,'deals','.p-sample-checkout-confirmation .buttons','padding-bottom','20','','','.p-sample-checkout-confirmation'),(985959,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(985960,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-bottom','3','','','.b-select-suggest'),(985961,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-bottom','5','','','.b-select-suggest'),(985962,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-bottom','0','','','.b-select-suggest'),(985963,'deals','.b-select-suggest .select2-locked','padding-bottom','3','','','.b-select-suggest'),(985964,'deals','.b-select-suggest .select2-container-multi .select2-choices','padding-bottom','0','','','.b-select-suggest'),(985965,'deals','.b-select-suggest .select2-results','padding-bottom','0','','','.b-select-suggest'),(985966,'deals','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','5','','','.w-menu-horizontal'),(985967,'deals','.b-form .shipping-method .item + .item','padding-bottom','5','','','.b-form'),(985968,'deals','.b-select-suggest .select2-search input','padding-bottom','4','','','.b-select-suggest'),(985969,'deals','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(985970,'deals','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-bottom','12','5639','','.w-menu-horizontal'),(985971,'deals','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(985972,'deals','.w-login-block .guest','padding-bottom','30','','','.w-login-block'),(985973,'deals','.w-socials > li','padding-bottom','15','','','.w-socials'),(985976,'deals','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(985977,'deals','.w-cart-compare .dropdown li','padding-bottom','5','','','.w-cart-compare'),(985978,'deals','.w-cart-compare .product-label','padding-bottom','15','','','.w-cart-compare'),(985981,'deals','.b-compare .col-two label','padding-bottom','5','','','.b-compare'),(985982,'deals','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(985985,'deals','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(985986,'deals','.w-login-block .password-row','padding-bottom','0','','','.w-login-block'),(985987,'deals','.w-account-addresses-list .addsess-suggestion-item','padding-bottom','20','','','.w-account-addresses-list'),(985988,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom','0','','','.b-data-table'),(985989,'deals','.w-communication-post .communication-post','padding-bottom','5','','','.w-communication-post'),(985990,'deals','.w-communication-post .communication-post-author','padding-bottom','10','','','.w-communication-post'),(985991,'deals','.b-products-listing .in-cart','padding-bottom','4','','','.b-products-listing'),(985992,'deals','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-bottom','5','','','.w-catalog-b2b-add-button'),(985993,'deals','.b-products-listing .promos-info .promo-item','padding-bottom','3','','','.b-products-listing'),(985994,'deals','.b-products-listing .promos-info .promo-name','padding-bottom','3','','','.b-products-listing'),(986000,'deals','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(986001,'deals','.w-checkout-gdpr .privacy-row','padding-bottom','0','','','.w-checkout-gdpr'),(986002,'deals','.w-checkout-gdpr .terms-login','padding-bottom','0','','','.w-checkout-gdpr'),(986003,'deals','.b-email-editor .price','padding-bottom','10','','','.b-email-editor'),(986004,'deals','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(986005,'deals','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(986006,'deals','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(986007,'deals','.b-email .qty','padding-bottom','5','','','.b-email'),(986008,'deals','.b-email .name','padding-bottom','5','','','.b-email'),(986009,'deals','.b-email .heading-price','padding-bottom','5','','','.b-email'),(986010,'deals','.w-reviews .heading-3','padding-bottom','15','','','.w-reviews'),(986012,'deals','.w-personal-gift-status-bar .timeline','padding-bottom','16','','','.w-personal-gift-status-bar'),(986013,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(986014,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(986015,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-bottom','0','','',''),(986016,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-bottom','0','','','.b-h-inline'),(986017,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-bottom','0','','','.w-communication-new-topic'),(986018,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-bottom','5','','','.w-communication-new-topic'),(986019,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-bottom','5','','','.w-communication-new-topic'),(986020,'deals','.w-communication-new-topic #communication_topic_form .middle-form','padding-bottom','0','','','.w-communication-new-topic'),(986021,'deals','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(986022,'deals','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(986023,'deals','.b-bottom .popup-content','padding-bottom','15','','','.b-bottom'),(986024,'deals','.b-compare .compare_pagination','padding-bottom','10','','','.b-compare'),(986025,'deals','.w-promo-code .holder','padding-bottom','20','5660','','.w-promo-code'),(986026,'deals','.w-top-categories .item','padding-bottom','15','5630','','.w-top-categories'),(986027,'deals','.p-sample-cart-index .empty','padding-bottom','100','','','.p-sample-cart-index'),(986028,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-bottom','0','','','.w-menu-style-2'),(986029,'deals','.w-login-block .new','padding-bottom','30','','','.w-login-block'),(986032,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(986033,'deals','.b-tracking-numbers .tracking-numbers th','padding-bottom','5','','','.b-tracking-numbers'),(986034,'deals','.b-tracking-numbers .tracking-numbers td','padding-bottom','5','','','.b-tracking-numbers'),(986035,'deals','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-bottom','0','','','.b-fancybox'),(986036,'deals','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(986037,'deals','.b-email-editor .widget-item:not(.block_block)','padding-bottom','20','','','.b-email-editor'),(986038,'deals','.b-email .qty','padding-bottom','5','','','.b-email'),(986039,'deals','.b-email .totals-title','padding-bottom','5','','','.b-email'),(986040,'deals','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(986041,'deals','.b-email .name','padding-bottom','5','','','.b-email'),(986042,'deals','.products-quick-index .token-input-list','padding-bottom','0','','',''),(986043,'deals','.w-cart-compare .product','padding-bottom','10','','','.w-cart-compare'),(986044,'deals','.w-cart-compare .product-actions','padding-bottom','0','','','.w-cart-compare'),(986045,'deals','.w-cart-shipping-estimator .address-item','padding-bottom','20','','','.w-cart-shipping-estimator'),(986046,'deals','.w-promo-code .promo-text-2','padding-bottom','0','','','.w-promo-code'),(986047,'deals','.w-promo-code .holder','padding-bottom','20','','','.w-promo-code'),(986048,'deals','.b-form .shipping-method .item','padding-bottom','5','','','.b-form'),(986049,'deals','.b-email .model','padding-bottom','5','','','.b-email'),(986050,'deals','.b-form .middle-form','padding-bottom','0','','','.b-form'),(986051,'deals','.b-email .totals-title','padding-bottom','5','','','.b-email'),(986052,'deals','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(986053,'deals','.b-email .heading-qty','padding-bottom','5','','','.b-email'),(986054,'deals','.w-product-images-additional .images','padding-bottom','20','5660','','.w-product-images-additional'),(986055,'deals','.b-email .totals-value','padding-bottom','5','','','.b-email'),(986056,'deals','.w-cart-listing .item .gift-wrap label','padding-bottom','10','','','.w-cart-listing'),(986057,'deals','.w-cart-listing .item > div','padding-bottom','10','','','.w-cart-listing'),(986058,'deals','.w-cart-listing .points-earn','padding-bottom','5','','','.w-cart-listing'),(986059,'deals','.w-cart-listing .points-redeem','padding-bottom','10','','','.w-cart-listing'),(986065,'deals','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(986066,'deals','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(986067,'deals','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(986068,'deals','.b-email-editor .old-price','padding-bottom','0','','','.b-email-editor'),(986069,'deals','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(986070,'deals','.b-email .totals-value','padding-bottom','5','','','.b-email'),(986071,'deals','.b-email .totals-title','padding-bottom','5','','','.b-email'),(986072,'deals','.b-email .price','padding-bottom','5','','','.b-email'),(986073,'deals','.b-email .name','padding-bottom','5','','','.b-email'),(986074,'deals','.b-dropdown .dropdown .dropdown-menu','padding-bottom','5','','','.b-dropdown'),(986075,'deals','.b-email .heading-name','padding-bottom','5','','','.b-email'),(986076,'deals','.b-email .image','padding-bottom','5','','','.b-email'),(986077,'deals','.w-product-images-additional .images','padding-bottom','20','5660','','.w-product-images-additional'),(986078,'deals','.w-promo-code .holder','padding-bottom','20','5660','','.w-promo-code'),(986079,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(986080,'deals','.w-login-block .returning','padding-bottom','30','','','.w-login-block'),(986082,'deals','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(986083,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-bottom','20','','','.b-tracking-numbers'),(986084,'deals','.w-brands .brands-listing > div','padding-bottom','15','','','.w-brands'),(986085,'deals','.w-filters .fsl_handle','padding-bottom','15','','','.w-filters'),(986086,'deals','.w-filters .head-filter-widget','padding-bottom','0','5639','','.w-filters'),(986087,'deals','.w-filters .filter-box-content','padding-bottom','20','','','.w-filters'),(986088,'deals','.w-filters .ui-slider-range','padding-bottom','0','','','.w-filters'),(986089,'deals','.w-brands .brands-listing','padding-bottom','15','','','.w-brands'),(986091,'deals','.w-filters .head-filter-widget','padding-bottom','10','','','.w-filters'),(986092,'deals','.b-autocomplete .ui-autocomplete','padding-bottom','2','','','.b-autocomplete'),(986093,'deals','.b-bottom .notify-form','padding-bottom','0','','','.b-bottom'),(986094,'deals','.order-summary .heading-2','padding-bottom','10','','','.order-summary'),(986095,'deals','.w-personal-gift-status-bar .end-label','padding-bottom','0','','','.w-personal-gift-status-bar'),(986096,'deals','.b-compare .column_wrapper','padding-bottom','10','','','.b-compare'),(986097,'deals','.b-email-editor .special-price','padding-bottom','10','','','.b-email-editor'),(986098,'deals','.b-email .heading-model','padding-bottom','5','','','.b-email'),(986099,'deals','.w-socials > li','padding-bottom','15','','','.w-socials'),(986100,'deals','.b-social-login .social-login-text-2','padding-bottom','15','','','.b-social-login'),(986101,'deals','.w-reviews-content .review','padding-bottom','10','','','.w-reviews-content'),(986102,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom','0','','','.b-data-table'),(986103,'deals','.b-data-table table.dataTable tbody td','padding-bottom','10','','','.b-data-table'),(986104,'deals','.b-data-table table.dataTable thead td','padding-bottom','10','','','.b-data-table'),(986105,'deals','.b-compare .popupCompare .pop-up-content','padding-bottom','10','','','.b-compare'),(986107,'deals','.w-product-promotions select','padding-bottom','0','','','.w-product-promotions'),(986108,'deals','.btn-2','padding-bottom','10','','',''),(986110,'deals','.w-quote-products .empty','padding-bottom','100','','','.w-quote-products'),(986111,'deals','.b-email-editor .product-item','padding-bottom','10','','','.b-email-editor'),(986112,'deals','.b-compare .col-gender','padding-bottom','10','','','.b-compare'),(986113,'deals','.b-email .totals-title','padding-bottom','5','','','.b-email'),(986114,'deals','.b-email .qty','padding-bottom','5','','','.b-email'),(986115,'deals','.btn','padding-bottom','8','','',''),(986116,'deals','.b-product-images .media-popup .mp-content','padding-bottom','0','','','.b-product-images'),(986117,'deals','.b-product-images .media-popup .mp-small-images .item','padding-bottom','10','','','.b-product-images'),(986118,'deals','.b-product-images .media-popup .slick-dots','padding-bottom','0','','','.b-product-images'),(986119,'deals','.b-product-images .media-popup .slick-dots li','padding-bottom','0','','','.b-product-images'),(986120,'deals','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-bottom','0','','','.b-menu-style'),(986121,'deals','.b-personal-catalog-popup #personal_catalog_popup','padding-bottom','20','','','.b-personal-catalog-popup'),(986122,'deals','.b-trade-approval .steps-bar li a','padding-bottom','7','','','.b-trade-approval'),(986123,'deals','.b-trade-approval .middle-form','padding-bottom','20','','','.b-trade-approval'),(986124,'deals','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-bottom','5','','','.b-trade-approval'),(986125,'deals','.b-trade-approval .steps-bar','padding-bottom','0','','','.b-trade-approval'),(986126,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-bottom','6','','','.b-trade-approval'),(986127,'deals','.b-trade-approval .center-buttons','padding-bottom','20','','','.b-trade-approval'),(986128,'deals','.w-account-personal-catalog .list-switcher','padding-bottom','0','','','.w-account-personal-catalog'),(986129,'deals','.w-account-personal-catalog .list-switcher a','padding-bottom','12','','','.w-account-personal-catalog'),(986130,'deals','.w-account-subscription .subscription-variant','padding-bottom','10','','','.w-account-subscription'),(986131,'deals','.w-catalog-additional-images li','padding-bottom','10','','','.w-catalog-additional-images'),(986132,'deals','.w-catalog-additional-images ul','padding-bottom','0','','','.w-catalog-additional-images'),(986133,'deals','.w-catalog-compare td','padding-bottom','10','','','.w-catalog-compare'),(986134,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-bottom','0','','','.w-catalog-compare'),(986135,'deals','.w-catalog-compare .cross-box .different-all > div','padding-bottom','11','2','','.w-catalog-compare'),(986136,'deals','.w-catalog-compare .cross-box .different-all > div','padding-bottom','10','','','.w-catalog-compare'),(986137,'deals','.w-delivery-day .left-count','padding-bottom','0','','','.w-delivery-day'),(986138,'deals','.w-delivery-day .left-text-left','padding-bottom','24','','','.w-delivery-day'),(986139,'deals','.w-delivery-day .left-text-right','padding-bottom','24','','','.w-delivery-day'),(986140,'deals','.w-top-text .top-text','padding-bottom','5','','','.w-top-text'),(986141,'deals','.w-product-images .additional-horizontal .item','padding-bottom','10','','','.w-product-images'),(986142,'deals','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-bottom','10','','','.b-cookie-notice'),(986143,'deals','.lowestPricedBox .w-banner .single_banner','padding-bottom','0','','','.lowestPricedBox'),(986144,'deals','.lowestPricedBox .w-banner .banner','padding-bottom','30','','','.lowestPricedBox'),(986145,'deals','.shopByCollectionBox .w-banner .single_banner','padding-bottom','0','','','.shopByCollectionBox'),(986146,'deals','.b-slick .slick-list','padding-bottom','0','','','.b-slick'),(986147,'deals','.b-slick .slick-vertical button.slick-next','padding-bottom','0','3','','.b-slick'),(986148,'deals','.b-slick .slick-vertical button.slick-prev','padding-bottom','0','3','','.b-slick'),(986149,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','padding-bottom','0','','','.b-slick'),(986150,'deals','.w-cart-listing .headings .head','padding-bottom','10','','','.w-cart-listing'),(986151,'deals','.LeftCategories .w-menu-simple ul','padding-bottom','0','','','.LeftCategories'),(986152,'deals','.LeftCategories .w-menu-simple ul li a','padding-bottom','4','','','.LeftCategories'),(986153,'deals','.b-products-listing .products-listing.list-productlisting .item','padding-bottom','20','','','.b-products-listing'),(986154,'deals','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-bottom','0','','','.b-products-listing'),(986155,'deals','.b-products-listing .products-listing.list-productlisting .item-content','padding-bottom','0','','','.b-products-listing'),(986156,'deals','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-bottom','15','','','.b-products-listing'),(986157,'deals','.b-products-listing .products-listing.list-rows .item-nav > div','padding-bottom','0','','','.b-products-listing'),(986158,'deals','.w-breadcrumb .breadcrumb-ul','padding-bottom','0','','','.w-breadcrumb'),(986159,'deals','.w-quote .buttons','padding-bottom','15','','','.w-quote'),(986160,'deals','.w-quote .buttons .btn','padding-bottom','4','','','.w-quote'),(986161,'deals','.w-quote .cart-content','padding-bottom','5','','','.w-quote'),(986162,'deals','.w-quote .cart-total','padding-bottom','10','','','.w-quote'),(986163,'deals','.w-quote .multicart .cart-content','padding-bottom','0','','','.w-quote'),(986164,'deals','.w-quote .multicart .item','padding-bottom','15','','','.w-quote'),(986165,'deals','.w-quote .multicart .name','padding-bottom','0','','','.w-quote'),(986166,'deals','.w-quote .no-text','padding-bottom','0','','','.w-quote'),(986167,'deals','.w-quote a.item','padding-bottom','5','','','.w-quote'),(986168,'deals','.w-social-links a','padding-bottom','4','','','.w-social-links'),(986169,'deals','.w-product-images .additional-vertical .additional-images','padding-bottom','30','','','.w-product-images'),(986170,'deals','.w-product-personal-catalog-button .btn','padding-bottom','8','','','.w-product-personal-catalog-button'),(986171,'deals','.b-quantity .qty-box input','padding-bottom','5','','','.b-quantity'),(986172,'deals','.w-product-model > div','padding-bottom','7','','','.w-product-model'),(986173,'deals','.w-product-sale-ends .left-count','padding-bottom','0','','','.w-product-sale-ends'),(986174,'deals','.w-product-sale-ends .left-text-left','padding-bottom','24','','','.w-product-sale-ends'),(986175,'deals','.w-product-sale-ends .left-text-right','padding-bottom','24','','','.w-product-sale-ends'),(986176,'deals','.w-product-sale-ends .left-count-days','padding-bottom','7','','','.w-product-sale-ends'),(986177,'deals','.w-product-sale-ends .left-count-hours','padding-bottom','7','','','.w-product-sale-ends'),(986178,'deals','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-bottom','0','','','.w-product-quantity'),(986179,'deals','.w-product-quantity .qty_packs .qty-input','padding-bottom','20','','','.w-product-quantity'),(986180,'deals','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-bottom','20','','','.w-product-quantity'),(986181,'deals','.w-product-quantity .total-qty','padding-bottom','0','','','.w-product-quantity'),(986182,'deals','.w-product-quantity .total-qty .qty_price','padding-bottom','0','','','.w-product-quantity'),(986183,'deals','.warrantyProduct .warranty, .warrantyProduct .delivery','padding-bottom','10','','','.warrantyProduct'),(986184,'deals','.w-compare .compare-list-buttons','padding-bottom','10','','','.w-compare'),(986185,'deals','.w-compare .item-holder','padding-bottom','10','','','.w-compare'),(986186,'deals','.w-compare .compare-list-products','padding-bottom','0','','','.w-compare'),(986187,'deals','.w-files-catalog-widgets-files-catalog .name','padding-bottom','10','','','.w-files-catalog-widgets-files-catalog'),(986188,'deals','.w-sample .buttons','padding-bottom','15','','','.w-sample'),(986189,'deals','.w-sample .buttons .btn','padding-bottom','4','','','.w-sample'),(986190,'deals','.w-sample .cart-box-link','padding-bottom','0','','','.w-sample'),(986191,'deals','.w-sample .cart-content','padding-bottom','5','','','.w-sample'),(986192,'deals','.w-sample .cart-total','padding-bottom','10','','','.w-sample'),(986193,'deals','.w-sample .multicart .cart-content','padding-bottom','0','','','.w-sample'),(986194,'deals','.w-sample .multicart .item','padding-bottom','15','','','.w-sample'),(986195,'deals','.w-sample .multicart .name','padding-bottom','0','','','.w-sample'),(986196,'deals','.w-sample .no-text','padding-bottom','0','','','.w-sample'),(986197,'deals','.w-sample a.item','padding-bottom','5','','','.w-sample'),(986198,'deals','.w-cart-listing .item > div.points','padding-bottom','0','','','.w-cart-listing'),(986199,'deals','.w-filters-simple .integrate-price-holder','padding-bottom','10','','','.w-filters-simple'),(986200,'deals','.w-product-video .item','padding-bottom','10','','','.w-product-video'),(986201,'deals','.w-cart-bonus-points .title','padding-bottom','5','','','.w-cart-bonus-points'),(986202,'deals','.shipping-ico .heading-3','padding-bottom','10','','','.shipping-ico'),(986203,'deals','.w-cart-order-reference .btn','padding-bottom','4','','','.w-cart-order-reference'),(986204,'deals','.w-cart-gift-certificate .btn','padding-bottom','4','','','.w-cart-gift-certificate'),(986205,'deals','.w-cart-shipping-estimator .btn','padding-bottom','4','','','.w-cart-shipping-estimator'),(986206,'deals','.w-product-bundle .attributes-item','padding-bottom','10','','','.w-product-bundle'),(986207,'deals','.w-product-bundle .bundle_item','padding-bottom','10','','','.w-product-bundle'),(986208,'deals','.w-product-in-bundles .attributes-item','padding-bottom','10','','','.w-product-in-bundles'),(986209,'deals','.w-product-in-bundles .bundle_item','padding-bottom','10','','','.w-product-in-bundles'),(986210,'deals','.w-cart-listing .item > div.actions','padding-bottom','10','5630','','.w-cart-listing'),(986212,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-bottom','0','','','.b-products-listing'),(986213,'deals','.b-pagination ul.pagination','padding-bottom','0','','','.b-pagination'),(986214,'deals','.w-product-properties-filters-widgets-chosen-filters .item','padding-bottom','3','','','.w-product-properties-filters-widgets-chosen-filters'),(986215,'deals','.p-quote-checkout-index .datepicker-inline','padding-bottom','10','','','.p-quote-checkout-index'),(986216,'deals','.p-sample-checkout-index .datepicker-inline','padding-bottom','10','','','.p-sample-checkout-index'),(986220,'deals','.w-product-multi-inventory .radio-attributes','padding-bottom','5','','','.w-product-multi-inventory'),(986221,'deals','.w-product-multi-inventory .radio-attributes .option-item','padding-bottom','10','','','.w-product-multi-inventory'),(986222,'deals','.w-product-multi-inventory .radio-attributes > label','padding-bottom','10','','','.w-product-multi-inventory'),(986223,'deals','.b-products-listing .products-listing .radio-attributes','padding-bottom','5','','','.b-products-listing'),(986224,'deals','.b-products-listing .products-listing .radio-attributes .option','padding-bottom','10','','','.b-products-listing'),(986225,'deals','.b-products-listing .products-listing .radio-attributes > label','padding-bottom','10','','','.b-products-listing'),(986226,'deals','.w-product-collection .item','padding-bottom','10','','','.w-product-collection'),(986227,'deals','.w-product-collection .right-area .btn','padding-bottom','14','','','.w-product-collection'),(986228,'deals','.w-product-collection .right-area','padding-bottom','20','5639','','.w-product-collection'),(986229,'deals','.w-product-attributes .radio-attributes','padding-bottom','5','','','.w-product-attributes'),(986230,'deals','.w-product-attributes .radio-attributes .option-item','padding-bottom','10','','','.w-product-attributes'),(986231,'deals','.w-product-attributes .radio-attributes > label','padding-bottom','10','','','.w-product-attributes'),(986232,'deals','.w-product-properties .property-ul','padding-bottom','0','','','.w-product-properties'),(986233,'deals','.w-product-properties .properties-table','padding-bottom','0','','','.w-product-properties'),(986234,'deals','.w-product-properties li','padding-bottom','5','','','.w-product-properties'),(986235,'deals','.w-product-groups ','padding-bottom','30','','','.w-product-groups'),(986236,'deals','.w-product-groups .radioBox','padding-bottom','20','','','.w-product-groups'),(986237,'deals','.w-product-groups .radioBox label','padding-bottom','0','','','.w-product-groups'),(986238,'deals','.w-product-groups .radioBox label .containerBlock','padding-bottom','5','','','.w-product-groups'),(986239,'deals','.w-product-groups .radioBox label .containerBlock','padding-bottom','5','5660','','.w-product-groups'),(986240,'deals','.b-products-listing .mix-attributes .attribute-qty-block','padding-bottom','5','','','.b-products-listing'),(986241,'deals','.b-products-listing .products-listing .attribute-qty-block','padding-bottom','5','','','.b-products-listing'),(986242,'deals','.blogsidebar','padding-bottom','0','5639','',''),(986243,'deals','.w-product-custom-bundle .item','padding-bottom','10','','','.w-product-custom-bundle'),(986244,'deals','.w-product-custom-bundle .chosen-products','padding-bottom','10','','','.w-product-custom-bundle'),(986245,'deals','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-bottom','12','','','.w-product-custom-bundle'),(986246,'deals','.w-product-custom-bundle .right-area .main-button','padding-bottom','20','5639','','.w-product-custom-bundle'),(986247,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list'),(986248,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list'),(986249,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list-block'),(986250,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list-block'),(986251,'deals','.w-delivery-location-top-location-list .deliveryName','padding-bottom','10','','','.w-delivery-location-top-location-list'),(986252,'deals','.w-delivery-location-location-list .deliveryName','padding-bottom','10','','','.w-delivery-location-location-list'),(986253,'deals','.w-delivery-location-location-list ul','padding-bottom','0','','','.w-delivery-location-location-list'),(986254,'deals','.w-delivery-location-location-description .deliveryDesc','padding-bottom','10','','','.w-delivery-location-location-description'),(986255,'deals','.w-delivery-location-location-long-description ','padding-bottom','20','','','.w-delivery-location-location-long-description'),(986256,'deals','.w-delivery-location-location-list .deliveryListParrent a','padding-bottom','6','','','.w-delivery-location-location-list'),(986257,'deals','.w-delivery-location-location-list .deliveryList li a','padding-bottom','10','','','.w-delivery-location-location-list'),(986258,'deals','.w-delivery-location-featured-list .deliveryName','padding-bottom','10','','','.w-delivery-location-featured-list'),(986259,'deals','.w-sale-category .holder-1','padding-bottom','20','','','.w-sale-category'),(986260,'deals','.w-sale-category .holder-2','padding-bottom','20','','','.w-sale-category'),(986261,'deals','.w-sale-category .left-count','padding-bottom','0','','','.w-sale-category'),(986262,'deals','.w-sale-category .left-text-left','padding-bottom','24','','','.w-sale-category'),(986263,'deals','.w-sale-category .left-text-right','padding-bottom','24','','','.w-sale-category'),(986264,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(986265,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(986266,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(986267,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-bottom','20','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(986268,'deals','.w-product-properties-icons .property-image','padding-bottom','10','','','.w-product-properties-icons'),(986269,'deals','.w-product-properties-icons .hover-box-content','padding-bottom','10','','','.w-product-properties-icons'),(986270,'deals','.w-delivery-location-product-categories .item.category-link','padding-bottom','15','','','.w-delivery-location-product-categories'),(986271,'deals','.w-delivery-location-product-categories .item.category-link','padding-bottom','10','5639','','.w-delivery-location-product-categories'),(986272,'deals','.w-delivery-location-product-categories .item.category-link','padding-bottom','10','5660','','.w-delivery-location-product-categories'),(986273,'deals','.w-delivery-location-product-categories .name','padding-bottom','10','','','.w-delivery-location-product-categories'),(986274,'deals','.w-catalog-delivery-locations .name','padding-bottom','10','','','.w-catalog-delivery-locations'),(986275,'deals','.delivery-options-popup','padding-bottom','20','','',''),(986276,'deals','.w-product-bonus-points .bonus-points-cost','padding-bottom','7','','','.w-product-bonus-points'),(986277,'deals','.w-product-designer-designer .grnamebox .title-sortable','padding-bottom','8','','','.w-product-designer-designer'),(986278,'deals','.w-product-designer-designer .prodDesignerType label','padding-bottom','10','','','.w-product-designer-designer'),(986279,'deals','.w-press-reviews-widgets-press-reviews-small ','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews-small'),(986280,'deals','.w-press-reviews-widgets-press-reviews ','padding-bottom','30','','','.w-press-reviews-widgets-press-reviews'),(986281,'deals','.w-press-reviews-widgets-press-reviews .author','padding-bottom','20','','','.w-press-reviews-widgets-press-reviews'),(986282,'deals','.w-press-reviews-widgets-press-reviews .item','padding-bottom','20','','','.w-press-reviews-widgets-press-reviews'),(986283,'deals','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-bottom','30','','','.w-press-reviews-widgets-press-reviews'),(986284,'deals','.w-press-reviews-widgets-press-reviews .rating','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews'),(986285,'deals','.w-press-reviews-widgets-press-reviews .review','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews'),(986286,'deals','.w-press-reviews-widgets-press-reviews ','padding-bottom','20','5630','','.w-press-reviews-widgets-press-reviews'),(986287,'deals','.w-press-reviews-widgets-press-reviews .author','padding-bottom','0','5630','','.w-press-reviews-widgets-press-reviews'),(986288,'deals','.w-press-reviews-widgets-press-reviews .item','padding-bottom','15','5630','','.w-press-reviews-widgets-press-reviews'),(986289,'deals','.w-press-reviews-widgets-press-reviews .review','padding-bottom','10','5630','','.w-press-reviews-widgets-press-reviews'),(986290,'deals','.w-press-reviews-widgets-press-reviews-list .date-added','padding-bottom','20','','','.w-press-reviews-widgets-press-reviews-list'),(986291,'deals','.w-press-reviews-widgets-press-reviews-list .item','padding-bottom','0','','','.w-press-reviews-widgets-press-reviews-list'),(986292,'deals','.w-press-reviews-widgets-press-reviews-list .rating','padding-bottom','5','','','.w-press-reviews-widgets-press-reviews-list'),(986293,'deals','.w-press-reviews-widgets-press-reviews-list .short-description','padding-bottom','10','','','.w-press-reviews-widgets-press-reviews-list'),(986294,'deals','.b-products-listing .productGroup label a','padding-bottom','5','','','.b-products-listing'),(986295,'deals','.w-support-system-filter ','padding-bottom','25','','','.w-support-system-filter'),(986296,'deals','.w-support-system-filter .filter_cats','padding-bottom','0','','','.w-support-system-filter'),(986297,'deals','.w-support-system-listing .support-head','padding-bottom','13','','','.w-support-system-listing'),(986298,'deals','.w-communication-post .btn.refresh','padding-bottom','0','','','.w-communication-post'),(986299,'deals','.w-rma-returns-history .btn','padding-bottom','7','','','.w-rma-returns-history'),(986300,'deals','.w-rma-returns-history .column','padding-bottom','0','','','.w-rma-returns-history'),(986301,'deals','.w-rma-returns-history .column .title','padding-bottom','5','','','.w-rma-returns-history'),(986302,'deals','.w-rma-returns-history .topRow','padding-bottom','10','','','.w-rma-returns-history'),(986303,'deals','.w-rma-returns-history .column:last-child .title','padding-bottom','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(986304,'deals','.w-product-designer-designer .productDesignerBox ul','padding-bottom','0','','','.w-product-designer-designer'),(986305,'deals','.w-product-configurator .pc-item','padding-bottom','0','','','.w-product-configurator'),(986306,'deals','.w-product-configurator .pc_stock','padding-bottom','0','','','.w-product-configurator'),(986307,'deals','.w-product-configurator .pc_item','padding-bottom','10','5639','','.w-product-configurator'),(986308,'deals','.w-product-configurator .pc_attr','padding-bottom','5','5630','','.w-product-configurator'),(986309,'deals','.b-products-listing .promos-info .promo-name-span','padding-bottom','3','','','.b-products-listing'),(986310,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-bottom','0','','','.w-catalog-pages-category-pages-list'),(986311,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-bottom','20','','','.w-catalog-pages-category-pages-list'),(986312,'deals','.w-predefined-promotion .nextdiscount .content > div','padding-bottom','10','','','.w-predefined-promotion'),(986313,'deals','.w-predefined-promotion .nextdiscount .promo-for-each','padding-bottom','2','','','.w-predefined-promotion'),(986314,'deals','.w-predefined-promotion .prom-multi-discount .promo-product','padding-bottom','20','','','.w-predefined-promotion'),(986315,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','padding-bottom','0','','','.w-predefined-promotion'),(986316,'deals','.w-predefined-promotion .promo-cart-discount .master .item','padding-bottom','20','','','.w-predefined-promotion'),(986317,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-bottom','0','','','.w-predefined-promotion'),(986318,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-bottom','0','','','.w-predefined-promotion'),(986319,'deals','.w-predefined-promotion .promo-cart-discount .slave .heading','padding-bottom','1','','','.w-predefined-promotion'),(986320,'deals','.w-predefined-promotion .promo-cart-discount .slave .item','padding-bottom','20','','','.w-predefined-promotion'),(986321,'deals','.w-predefined-promotion .promo-item','padding-bottom','20','','','.w-predefined-promotion'),(986322,'deals','.w-predefined-promotion .promo-salemaker .discount','padding-bottom','0','','','.w-predefined-promotion'),(986323,'deals','.w-predefined-promotion .promo-salemaker .item','padding-bottom','20','','','.w-predefined-promotion'),(986324,'deals','.w-supplier-purchase-supplier-products .item','padding-bottom','10','','','.w-supplier-purchase-supplier-products'),(986325,'deals','.headerWrap ','padding-bottom','10','','','.headerWrap'),(986326,'deals','.headerWrap .searchIcon','padding-bottom','10','','','.headerWrap'),(986327,'deals','.headerWrap >div.block, .headerWrap .headerInside >div.block','padding-bottom','0','','','.headerWrap'),(986329,'deals','.parallaxWrap .w-info-page','padding-bottom','15','','','.parallaxWrap'),(986330,'deals','.bannersWrap .text','padding-bottom','20','','','.bannersWrap'),(986331,'deals','.headerWrap .menu-style[data-style=\"1\"] li.back-button','padding-bottom','10','','','.headerWrap'),(986332,'deals','.w-categories .categories h2','padding-bottom','0','','','.w-categories'),(986333,'deals','.w-categories .item','padding-bottom','15','5630','','.w-categories'),(986334,'deals','.filterLine .before','padding-bottom','6','','','.filterLine'),(986335,'deals','.filterLine .choose-filters li .btn-clear','padding-bottom','3','','','.filterLine'),(986336,'deals','.w-filters .filter-widget-horizontal .filter-box-head','padding-bottom','8','','','.w-filters'),(986337,'deals','.w-filters .filter-widget-horizontal .filter-box-content','padding-bottom','20','','','.w-filters'),(986338,'deals','.w-filters .filter-ul-content > li:last-of-type','padding-bottom','0','','','.w-filters'),(986339,'deals','.w-filters .choose-filters > li > *','padding-bottom','5','','','.w-filters'),(986340,'deals','.w-filters .choose-filters > li','padding-bottom','0','','','.w-filters'),(986341,'deals','.b-products-listing .products-listing .bonus-points-cost','padding-bottom','7','','','.b-products-listing'),(986342,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span','padding-bottom','5','','','.w-product-quantity-discounts'),(986343,'deals','.b-quantity .qty-box input[type=\'text\']','padding-bottom','5','','','.b-quantity'),(986344,'deals','.w-product-groups .property-category-heading','padding-bottom','2','','','.w-product-groups'),(986345,'deals','.w-product-groups .property-category-heading + .property-category-content','padding-bottom','10','','','.w-product-groups'),(986346,'deals','.w-product-groups .radioBoxHead','padding-bottom','10','','','.w-product-groups'),(986347,'deals','.w-product-name h1','padding-bottom','0','','','.w-product-name'),(986348,'deals','.w-product-buttons button.add-to-cart','padding-bottom','14','','','.w-product-buttons'),(986349,'deals','.messageBox .info','padding-bottom','15','','',''),(986350,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','padding-bottom','8','','','.b-products-listing'),(986351,'deals','.savings-ico .heading-3','padding-bottom','10','','','.savings-ico'),(986352,'deals','.order-summary > div','padding-bottom','10','','','.order-summary'),(986353,'deals','.w-delayed-despatch-checkout .btn','padding-bottom','5','','','.w-delayed-despatch-checkout'),(986354,'deals','.w-coupons-and-vauchers-checkout .btn','padding-bottom','5','','','.w-coupons-and-vauchers-checkout'),(986355,'deals','.b-table-list .table-list td','padding-bottom','5','','','.b-table-list'),(986356,'deals','.b-table-list .table-list th','padding-bottom','5','','','.b-table-list'),(986357,'deals','.b-table .table .headings td','padding-bottom','3','','','.b-table'),(986358,'deals','.b-table .table td','padding-bottom','15','','','.b-table'),(986360,'deals','.headerWrap .headerInside >div.block','padding-bottom','0','5639','','.headerWrap'),(986361,'deals','.homeBanner .carousel .bottom-center > span','padding-bottom','50','3','','.homeBanner'),(986362,'deals','.homeBanner .carousel .bottom-center > span','padding-bottom','40','','','.homeBanner'),(986363,'deals','.homeBanner .carousel .bottom-center > span','padding-bottom','20','5644','','.homeBanner'),(986364,'deals','.homeBanner .carousel .bottom-center > span','padding-bottom','10','5660','','.homeBanner'),(986365,'deals','.homeBanner .carousel .bottom-center > span','padding-bottom','30','5660,3','','.homeBanner'),(986367,'deals','.bannersWrap .text','padding-bottom','15','5639','','.bannersWrap'),(986368,'deals','.w-filters .filter-widget-horizontal .head-filter-widget','padding-bottom','5','5639','','.w-filters'),(986369,'deals','.w-filters .filter-widget-horizontal .filter-box','padding-bottom','0','5639','','.w-filters'),(986370,'deals','.w-filters .filter_buttons','padding-bottom','10','','','.w-filters'),(986371,'deals','.b-products-listing .products-listing.list-productlisting .radio-attributes > label','padding-bottom','10','','','.b-products-listing'),(986372,'deals','.b-info .info','padding-bottom','15','','','.b-info'),(986373,'deals','.b-info .info li','padding-bottom','0','','','.b-info'),(986374,'deals','.b-info .info ul','padding-bottom','0','','','.b-info'),(986375,'deals','.b-sub-totals .historyTotal','padding-bottom','20','','','.b-sub-totals'),(986376,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','padding-bottom','10','5630','','.headerWrap'),(986377,'deals','.b-personal-catalog-popup button.btn.btn-save-new-list','padding-bottom','5','','','.b-personal-catalog-popup'),(986378,'deals','.w-account-personal-catalog .list-row-action li','padding-bottom','5','','','.w-account-personal-catalog'),(986379,'deals','.w-account-personal-catalog .list-row-action ul','padding-bottom','0','','','.w-account-personal-catalog'),(986380,'deals','.w-multi-cart-save-cart .btn','padding-bottom','6','5660','','.w-multi-cart-save-cart'),(986381,'deals','.w-product-wishlist-button .btn','padding-bottom','0','','','.w-product-wishlist-button'),(986382,'deals','.w-catalog-compare .compare-list','padding-bottom','30','','','.w-catalog-compare'),(986383,'deals','.w-compare .compare-list-holder','padding-bottom','50','','','.w-compare'),(986384,'deals','.homeBanner .banner-item .banner-text','padding-bottom','0','','','.homeBanner'),(986385,'deals','.homeBanner .banner-item .banner-text-holder','padding-bottom','40','','','.homeBanner'),(986386,'deals','.homeBanner .banner-item.text-middle-center .banner-text-holder','padding-bottom','20','','','.homeBanner'),(986387,'deals','.homeBanner .banner-item.text-middle-left .banner-text-holder','padding-bottom','20','','','.homeBanner'),(986388,'deals','.homeBanner .banner-item.text-middle-right .banner-text-holder','padding-bottom','20','','','.homeBanner'),(986389,'deals','.homeBanner .banner-item.text-top-center .banner-text-holder','padding-bottom','20','','','.homeBanner'),(986390,'deals','.homeBanner .banner-item.text-top-left .banner-text-holder','padding-bottom','20','','','.homeBanner'),(986391,'deals','.homeBanner .banner-item.text-top-right .banner-text-holder','padding-bottom','20','','','.homeBanner'),(986392,'deals','.homeBanner .text-bottom-center .banner-text-holder','padding-bottom','50','3','','.homeBanner'),(986393,'deals','.homeBanner .text-bottom-left .banner-text-holder','padding-bottom','50','3','','.homeBanner'),(986394,'deals','.homeBanner .text-bottom-right .banner-text-holder','padding-bottom','50','3','','.homeBanner'),(986395,'deals','.homeBanner .banner-item .banner-text-holder','padding-bottom','20','5644','','.homeBanner'),(986396,'deals','.homeBanner .banner-item .banner-text-holder','padding-bottom','10','5660','','.homeBanner'),(986397,'deals','.homeBanner .text-bottom-center .banner-text-holder','padding-bottom','30','5660,3','','.homeBanner'),(986398,'deals','.homeBanner .text-bottom-left .banner-text-holder','padding-bottom','30','5660,3','','.homeBanner'),(986399,'deals','.homeBanner .text-bottom-right .banner-text-holder','padding-bottom','30','5660,3','','.homeBanner'),(986400,'deals','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','padding-bottom','5','','','.w-promotions-widgets-promotion-icons-desc'),(986401,'deals','.order-summary .w-cart-listing .item > div ~ div','padding-bottom','10','','','.order-summary'),(986402,'deals','.w-cart-discount-coupon .discount-box','padding-bottom','5','','','.w-cart-discount-coupon'),(986403,'deals','.main-content','padding-bottom','30','','',''),(986404,'deals','.breadcrumb-box ','padding-bottom','13','','','.breadcrumb-box'),(986405,'deals','.w-promotions-widgets-promotions select','padding-bottom','0','','','.w-promotions-widgets-promotions'),(986430,'deals','.account-address-book .address_book','padding-bottom','30','','','.account-address-book'),(986431,'deals','.account-address-book .address_book h1','padding-bottom','5','','','.account-address-book'),(986432,'deals','.account-address-book .address_book h2','padding-bottom','10','','','.account-address-book'),(986433,'deals','.account-address-book .address_book, .account-address-book .account_history_info','padding-bottom','10','','','.account-address-book'),(986434,'deals','.account-address-book .btn-edit','padding-bottom','0','4','','.account-address-book'),(986435,'deals','.account-address-book .buttonBox','padding-bottom','15','','','.account-address-book'),(986436,'deals','.account-address-book .rightMes ul','padding-bottom','0','','','.account-address-book'),(986437,'deals','.account-address-book .topButtons','padding-bottom','15','','','.account-address-book'),(986451,'deals','.account-order-pay .contentColumn','padding-bottom','10','','','.account-order-pay'),(986452,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-bottom','5','','','.account-order-pay'),(986453,'deals','.account-order-pay .history_info > div + div','padding-bottom','0','','','.account-order-pay'),(986454,'deals','.account-order-pay .history_info > div','padding-bottom','0','5639','','.account-order-pay'),(986455,'deals','.account-order-pay .history_info > div + div','padding-bottom','0','5639','','.account-order-pay'),(986456,'deals','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-bottom','10','','','.account-samples'),(986457,'deals','.account-samples .orders-table th','padding-bottom','2','','','.account-samples'),(986458,'deals','.account-samples .order_history_table th','padding-bottom','10','','','.account-samples'),(986459,'deals','.account-samples .view_link','padding-bottom','0','','','.account-samples'),(986460,'deals','.account-samples .orders-table .item','padding-bottom','60','5639','','.account-samples'),(986461,'deals','.account-samples .orders-table .td-alignright','padding-bottom','5','5639','','.account-samples'),(986462,'deals','.account-samples .orders-table td','padding-bottom','5','5639','','.account-samples'),(986463,'deals','.account-sample-info .contentColumn','padding-bottom','10','','','.account-sample-info'),(986464,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-bottom','5','','','.account-sample-info'),(986465,'deals','.account-sample-info .history_info > div + div','padding-bottom','0','','','.account-sample-info'),(986466,'deals','.account-sample-info .popup-tracking-number','padding-bottom','10','','','.account-sample-info'),(986467,'deals','.account-sample-info .history_info > div','padding-bottom','0','5639','','.account-sample-info'),(986468,'deals','.account-sample-info .history_info > div + div','padding-bottom','0','5639','','.account-sample-info'),(986469,'deals','.catalog-product-wrap .next-product','padding-bottom','20','','','.catalog-product-wrap'),(986470,'deals','.catalog-product-wrap .pn-direction','padding-bottom','0','','','.catalog-product-wrap'),(986471,'deals','.catalog-product-wrap .pn-image','padding-bottom','20','','','.catalog-product-wrap'),(986472,'deals','.catalog-product-wrap .prev-product','padding-bottom','20','','','.catalog-product-wrap'),(986473,'deals','.catalog-product-wrap .next-product','padding-bottom','20','5639','','.catalog-product-wrap'),(986474,'deals','.catalog-product-wrap .pn-direction','padding-bottom','0','5639','','.catalog-product-wrap'),(986475,'deals','.catalog-product-wrap .prev-product','padding-bottom','20','5639','','.catalog-product-wrap'),(986476,'deals','.shopping-cart-index .cart-page .empty','padding-bottom','100','','','.shopping-cart-index'),(986477,'deals','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-bottom','10','','','.shopping-cart-index'),(986478,'deals','.shopping-cart-index .closeable-heading','padding-bottom','10','','','.shopping-cart-index'),(986479,'deals','.shopping-cart-index .closeable-heading .heading-3','padding-bottom','0','','','.shopping-cart-index'),(986480,'deals','.checkout-index-wrap .checkout-cart-listing.main-listing','padding-bottom','30','','','.checkout-index-wrap'),(986481,'deals','.checkout-index-wrap .datepicker-inline','padding-bottom','10','','','.checkout-index-wrap'),(986482,'deals','.checkout-index-wrap .edit-address-popup','padding-bottom','20','','','.checkout-index-wrap'),(986483,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-bottom','6','','','.checkout-index-wrap'),(986484,'deals','.checkout-order-confirmation .price-row','padding-bottom','5','','','.checkout-order-confirmation'),(986485,'deals','.b-form .columns .col-2','padding-bottom','0','','','.b-form'),(986486,'deals','.b-bottom .pop-up-content','padding-bottom','20','','','.b-bottom'),(986487,'deals','.b-slick .slick-dots li','padding-bottom','5','','','.b-slick'),(986489,'deals','.success-page .check-ico-block','padding-bottom','0','','','.success-page'),(986490,'deals','.success-page .order_totals .price-row','padding-bottom','5','','','.success-page'),(986491,'deals','.success-page .price-row','padding-bottom','5','','','.success-page'),(986492,'deals','.success-page .w-cart-listing .qty','padding-bottom','0','','','.success-page'),(986494,'deals','.b-multi-page-checkout .multi-page-checkout .buttons','padding-bottom','0','','','.b-multi-page-checkout'),(986495,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-bottom','20','','','.b-multi-page-checkout'),(986496,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-bottom','6','','','.b-multi-page-checkout'),(986497,'deals','.bannersWrap .rightBanner .banner-text','padding-bottom','20','','','.bannersWrap'),(986499,'deals','.footer-menu .level-1 > li > .no-link','padding-bottom','5','5639','','.footer-menu'),(986500,'deals','.footer-menu .level-2','padding-bottom','20','5639','','.footer-menu'),(986501,'deals','.footer-menu .level-3 > li','padding-bottom','10','5639','','.footer-menu'),(986502,'deals','.footer-menu .level-3 > li > a','padding-bottom','5','5639','','.footer-menu'),(986503,'deals','.footer-menu .level-3 > li.back-button','padding-bottom','9','5639','','.footer-menu'),(986504,'deals','.footer-menu .level-4 > li','padding-bottom','5','5639','','.footer-menu'),(986505,'deals','.w-banner .banner-text','padding-bottom','20','','','.w-banner'),(986506,'deals','.w-banner .carousel-text > span','padding-bottom','20','','','.w-banner'),(986507,'deals','.w-catalog-paging .paging-item','padding-bottom','0','','','.w-catalog-paging'),(986516,'deals','.w-menu-slider > ul > li > a','padding-bottom','5','','','.w-menu-slider'),(986517,'deals','.w-menu-slider > ul > li > ul > li','padding-bottom','10','','','.w-menu-slider'),(986518,'deals','.w-menu-slider ul, .w-menu-slider li','padding-bottom','0','','','.w-menu-slider'),(986519,'deals','.bannersWrap .leftBanner .banner-text','padding-bottom','0','','','.bannersWrap'),(986520,'deals','.b-data-table table.dataTable tbody td','padding-bottom_important','important','','','.b-data-table'),(986521,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-bottom_important','important','','','.b-data-table'),(986522,'deals','.b-data-table table.dataTable thead td','padding-bottom_important','important','','','.b-data-table'),(986523,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-bottom_important','important','','','.b-data-table'),(986524,'deals','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-left','10','','','.w-communication-new-topic'),(986525,'deals','.b-email .heading-name','padding-left','10','','','.b-email'),(986526,'deals','.b-email .name','padding-left','10','','','.b-email'),(986527,'deals','.b-email .heading-image','padding-left','10','','','.b-email'),(986528,'deals','.b-email .heading-price','padding-left','10','','','.b-email'),(986529,'deals','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(986530,'deals','.order-summary .btn-2, .order-summary .btn-3','padding-left','5','','','.order-summary'),(986531,'deals','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(986532,'deals','.w-promo-code .holder','padding-left','20','5660','','.w-promo-code'),(986535,'deals','.b-email .totals-value','padding-left','10','','','.b-email'),(986536,'deals','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(986537,'deals','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-left','10','','','.p-quick-order-index'),(986538,'deals','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-left','10','','','.p-quick-order-index'),(986539,'deals','.p-quick-order-index ul.token-input-list','padding-left','0','','','.p-quick-order-index'),(986540,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.p-quick-order-index'),(986541,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.p-quick-order-index'),(986542,'deals','.w-promotions .promo-item','padding-left','40','','','.w-promotions'),(986543,'deals','.w-top-categories h2.name','padding-left','3','','','.w-top-categories'),(986544,'deals','.w-cart-compare .attributes-label','padding-left','10','','','.w-cart-compare'),(986549,'deals','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(986550,'deals','.b-email .heading-price','padding-left','10','','','.b-email'),(986551,'deals','.b-email .name','padding-left','10','','','.b-email'),(986552,'deals','.testimonials .review','padding-left','10','','',''),(986553,'deals','.testimonials .heading-3','padding-left','55','','',''),(986554,'deals','.w-categories .image','padding-left','0','','','.w-categories'),(986555,'deals','.w-promotions .prom-multi-discount .promo-range','padding-left','20','','','.w-promotions'),(986556,'deals','.w-promotions .prom-multi-discount .promo-product','padding-left','20','','','.w-promotions'),(986557,'deals','.w-promotions .nextdiscount .promo-for-each','padding-left','10','','','.w-promotions'),(986558,'deals','.w-promotions .nextdiscount .content > div','padding-left','10','','','.w-promotions'),(986559,'deals','.w-promotions .promo-salemaker .item','padding-left','20','','','.w-promotions'),(986560,'deals','.w-promotions .promo-salemaker .promo-manufacturers','padding-left','12','','','.w-promotions'),(986561,'deals','.w-promotions .promo-salemaker .discount','padding-left','20','','','.w-promotions'),(986562,'deals','.w-promotions .promo-cart-discount .slave .item','padding-left','20','','','.w-promotions'),(986563,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','padding-left','20','','','.w-promotions'),(986564,'deals','.w-promotions .promo-cart-discount .slave','padding-left','15','','','.w-promotions'),(986565,'deals','.w-promotions .promo-cart-discount .promo-min-qty','padding-left','20','','','.w-promotions'),(986566,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','padding-left','17','','','.b-warehouses-popup'),(986567,'deals','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-left','20','','','.b-warehouses-popup'),(986568,'deals','.w-product-available-in-warehouses .warehouse-item','padding-left','0','','','.w-product-available-in-warehouses'),(986569,'deals','.w-checkout-create-account .account-benefits ul','padding-left','20','','','.w-checkout-create-account'),(986570,'deals','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-left','2','','','.b-products-listing'),(986572,'deals','.w-cart-compare .dropdown li','padding-left','10','','','.w-cart-compare'),(986573,'deals','.w-cart-compare .attributes-cell','padding-left','20','','','.w-cart-compare'),(986575,'deals','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(986577,'deals','.w-login-block .new','padding-left','40','','','.w-login-block'),(986578,'deals','.b-bottom .confirm-popup .confirm-text','padding-left','0','','','.b-bottom'),(986579,'deals','.b-messages .messages-menu ul','padding-left','0','','','.b-messages'),(986580,'deals','.b-messages .development-content .type-6 .content','padding-left','0','','','.b-messages'),(986581,'deals','.b-messages .msv_btn','padding-left','0','','','.b-messages'),(986582,'deals','.b-messages .msv_content','padding-left','20','','','.b-messages'),(986583,'deals','.b-messages .msv_history','padding-left','20','','','.b-messages'),(986584,'deals','.b-messages .messMenuButton span','padding-left','15','','','.b-messages'),(986585,'deals','.b-messages .messages-menu li a','padding-left','0','','','.b-messages'),(986586,'deals','.b-messages .messages-menu li','padding-left','0','','','.b-messages'),(986587,'deals','.b-messages .content_management_attach button','padding-left','27','','','.b-messages'),(986588,'deals','.b-messages .email-heading','padding-left','15','','','.b-messages'),(986589,'deals','.b-messages .content_management_attach','padding-left','8','','','.b-messages'),(986590,'deals','.b-messages .emailLineTextArea textarea','padding-left','10','','','.b-messages'),(986591,'deals','.b-messages .msv_to_cc','padding-left','15','','','.b-messages'),(986592,'deals','.b-messages .emailBtn','padding-left','10','','','.b-messages'),(986593,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-left','10','','','.b-messages'),(986594,'deals','.w-sitemap-delivery-location > ul > li > ul','padding-left','0','','','.w-sitemap-delivery-location'),(986595,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-left','10','','',''),(986596,'deals','.w-sitemap-delivery-location > ul > li > ul ul','padding-left','20','','','.w-sitemap-delivery-location'),(986597,'deals','.w-tabs .tab-navigation','padding-left','0','','','.w-tabs'),(986598,'deals','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(986599,'deals','.w-reviews-content .item','padding-left','0','','','.w-reviews-content'),(986600,'deals','.p-quick-order-index .bottom','padding-left','0','','','.p-quick-order-index'),(986601,'deals','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(986602,'deals','.w-sitemap-delivery-location > ul','padding-left','0','','','.w-sitemap-delivery-location'),(986603,'deals','.w-checkout-terms .required-message','padding-left','10','','','.w-checkout-terms'),(986604,'deals','.w-cart-listing .item .remove','padding-left','10','5639','','.w-cart-listing'),(986605,'deals','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(986606,'deals','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(986607,'deals','.w-socials > li','padding-left','15','','','.w-socials'),(986608,'deals','.b-form .required-message-wrap','padding-left','0','','','.b-form'),(986609,'deals','.b-email .image','padding-left','10','','','.b-email'),(986610,'deals','.w-upload-customer-id-upload-customer-id-form .dz-preview','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(986611,'deals','.w-upload-customer-id-upload-customer-id-form .dz-details','padding-left','20','','','.w-upload-customer-id-upload-customer-id-form'),(986612,'deals','.b-email .model','padding-left','10','','','.b-email'),(986613,'deals','.b-email .heading-name','padding-left','10','','','.b-email'),(986614,'deals','.b-email .heading-model','padding-left','10','','','.b-email'),(986615,'deals','.w-login-block .guest','padding-left','40','','','.w-login-block'),(986616,'deals','.w-login-block .new','padding-left','40','','','.w-login-block'),(986617,'deals','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(986618,'deals','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-left','10','','','.w-menu-horizontal'),(986619,'deals','.w-menu-horizontal > ul > li > ul > li','padding-left','10','','','.w-menu-horizontal'),(986620,'deals','.w-menu-horizontal ul','padding-left','0','','','.w-menu-horizontal'),(986621,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(986622,'deals','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(986623,'deals','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(986624,'deals','.w-product-images-additional .images','padding-left','0','5660','','.w-product-images-additional'),(986625,'deals','.b-form .login-col-1','padding-left','0','','','.b-form'),(986626,'deals','.b-email .heading-image','padding-left','10','','','.b-email'),(986628,'deals','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(986629,'deals','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-left','0','','','.order-summary'),(986630,'deals','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(986631,'deals','.b-email .price','padding-left','10','','','.b-email'),(986632,'deals','.b-email .heading-model','padding-left','10','','','.b-email'),(986634,'deals','.w-categories .item','padding-left','25','','','.w-categories'),(986635,'deals','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(986636,'deals','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(986637,'deals','.b-bottom .terms-info-popup .pop-up-content','padding-left','20','','','.b-bottom'),(986638,'deals','.w-cart-compare .dropdown .dropdown-menu','padding-left','0','','','.w-cart-compare'),(986639,'deals','textarea','padding-left','10','','',''),(986643,'deals','.w-socials > li','padding-left','15','','','.w-socials'),(986644,'deals','.w-reviews-content .review','padding-left','20','','','.w-reviews-content'),(986646,'deals','.w-filters .filter-ul-content','padding-left','0','','','.w-filters'),(986647,'deals','.message.success','padding-left','40','','',''),(986648,'deals','.p-quick-order-index .all-scroll-div','padding-left','0','','','.p-quick-order-index'),(986649,'deals','.w-personal-gift-status-bar .end-label','padding-left','5','','','.w-personal-gift-status-bar'),(986650,'deals','.w-promo-code .heading-4','padding-left','30','5660','','.w-promo-code'),(986651,'deals','.b-email .heading-model','padding-left','10','','','.b-email'),(986652,'deals','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(986653,'deals','.b-email .heading-name','padding-left','10','','','.b-email'),(986654,'deals','.b-email .name','padding-left','10','','','.b-email'),(986655,'deals','.b-email .qty','padding-left','10','','','.b-email'),(986656,'deals','.b-email .totals-value','padding-left','10','','','.b-email'),(986657,'deals','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-left','0','','','.b-fancybox'),(986658,'deals','.w-checkout-shipping-choice span','padding-left','0','','','.w-checkout-shipping-choice'),(986660,'deals','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(986661,'deals','.b-fancybox .fancybox-title-over-wrap','padding-left','10','','','.b-fancybox'),(986662,'deals','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(986663,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-left','0','','','.b-select-suggest'),(986664,'deals','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(986665,'deals','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(986666,'deals','.w-reviews .review','padding-left','0','','','.w-reviews'),(986667,'deals','.w-socials > li','padding-left','15','','','.w-socials'),(986670,'deals','.b-compare .popupCompare td.level-2:first-child','padding-left','12','','','.b-compare'),(986671,'deals','.b-info-popup .info-popup div','padding-left','15','','','.b-info-popup'),(986672,'deals','.b-form .payment-method .item','padding-left','0','','','.b-form'),(986673,'deals','.b-form .password-forgotten-link','padding-left','0','','','.b-form'),(986674,'deals','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(986675,'deals','.w-cart-compare .price-label','padding-left','10','','','.w-cart-compare'),(986676,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-left','10','','','.w-image-maps'),(986677,'deals','.w-promo-code .holder','padding-left','20','5660','','.w-promo-code'),(986679,'deals','.w-reviews .heading-3','padding-left','55','','','.w-reviews'),(986680,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(986682,'deals','.b-email .name','padding-left','10','','','.b-email'),(986683,'deals','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(986684,'deals','.b-email .heading-name','padding-left','10','','','.b-email'),(986685,'deals','.b-email .heading-image','padding-left','10','','','.b-email'),(986686,'deals','.b-email .image','padding-left','10','','','.b-email'),(986687,'deals','.b-email .heading-qty','padding-left','10','','','.b-email'),(986688,'deals','.b-email .totals-value','padding-left','10','','','.b-email'),(986689,'deals','.b-email .price','padding-left','10','','','.b-email'),(986690,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(986691,'deals','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-left','0','','','.w-multi-cart-actions'),(986693,'deals','.w-top-categories .item','padding-left','10','','','.w-top-categories'),(986694,'deals','.w-tabs > .block','padding-left','0','','','.w-tabs'),(986695,'deals','.w-cart-cart-tabs .w-tabs > .block','padding-left','0','','','.w-cart-cart-tabs'),(986696,'deals','.w-tabs .accordion-heading','padding-left','8','5630','','.w-tabs'),(986697,'deals','.w-tabs .tab-a','padding-left','15','','','.w-tabs'),(986698,'deals','.w-tabs .tab-li','padding-left','0','','','.w-tabs'),(986699,'deals','.w-socials > li','padding-left','15','','','.w-socials'),(986702,'deals','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(986703,'deals','.b-bottom .popup-box-wrap','padding-left','10','','','.b-bottom'),(986704,'deals','.b-bottom .popup-buttons','padding-left','15','','','.b-bottom'),(986706,'deals','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(986707,'deals','.w-chat .w-chat-box','padding-left','12','','','.w-chat'),(986708,'deals','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(986709,'deals','.b-form .required-message','padding-left','3','','','.b-form'),(986710,'deals','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(986711,'deals','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(986712,'deals','.btn-1','padding-left','25','','',''),(986713,'deals','.b-autocomplete .ui-autocomplete li','padding-left','10','','','.b-autocomplete'),(986714,'deals','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(986715,'deals','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(986716,'deals','.w-socials > li','padding-left','15','','','.w-socials'),(986717,'deals','.w-login-block .guest','padding-left','40','','','.w-login-block'),(986718,'deals','.b-products-listing .products-listing .buyButton .btn','padding-left','10','','','.b-products-listing'),(986719,'deals','.w-product-images-additional .images','padding-left','0','5660','','.w-product-images-additional'),(986720,'deals','.b-products-listing .products-listing .bonus-points-price','padding-left','20','','','.b-products-listing'),(986721,'deals','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(986722,'deals','.b-email .heading-qty','padding-left','10','','','.b-email'),(986723,'deals','.order-summary .price-row','padding-left','0','','','.order-summary'),(986724,'deals','.b-email .heading-image','padding-left','10','','','.b-email'),(986725,'deals','.w-quote .no-text','padding-left','20','','','.w-quote'),(986726,'deals','.b-select-suggest .select2-drop-mask','padding-left','0','','','.b-select-suggest'),(986727,'deals','.w-reviews .author','padding-left','0','','','.w-reviews'),(986729,'deals','.testimonials .answer','padding-left','30','','',''),(986730,'deals','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(986731,'deals','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(986732,'deals','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(986734,'deals','.b-fancybox .fancybox-title-float-wrap .child','padding-left','20','','','.b-fancybox'),(986735,'deals','.w-checkout-shipping-choice span','padding-left','10','5660','','.w-checkout-shipping-choice'),(986736,'deals','.w-top-categories .categories h2','padding-left','0','','','.w-top-categories'),(986737,'deals','.w-top-categories .image','padding-left','0','','','.w-top-categories'),(986738,'deals','.w-product-reviews .reviews-list .review','padding-left','10','','','.w-product-reviews'),(986739,'deals','.b-email .model','padding-left','10','','','.b-email'),(986740,'deals','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(986741,'deals','.b-email .price','padding-left','10','','','.b-email'),(986742,'deals','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(986743,'deals','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(986744,'deals','.w-promo-code .heading-4','padding-left','30','5660','','.w-promo-code'),(986745,'deals','.w-product-images-additional .images','padding-left','0','5660','','.w-product-images-additional'),(986746,'deals','.b-bottom .popup-heading','padding-left','15','','','.b-bottom'),(986747,'deals','.b-bottom .popup-simple','padding-left','20','','','.b-bottom'),(986748,'deals','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(986749,'deals','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(986750,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(986751,'deals','.b-email .image','padding-left','10','','','.b-email'),(986752,'deals','.b-email .heading-qty','padding-left','10','','','.b-email'),(986753,'deals','.b-email .name','padding-left','10','','','.b-email'),(986754,'deals','.b-email .heading-price','padding-left','10','','','.b-email'),(986755,'deals','.b-email .heading-model','padding-left','10','','','.b-email'),(986756,'deals','.b-email .totals-value','padding-left','10','','','.b-email'),(986757,'deals','.b-email .qty','padding-left','10','','','.b-email'),(986758,'deals','.b-email .totals-title','padding-left','10','','','.b-email'),(986759,'deals','.b-email .model','padding-left','10','','','.b-email'),(986760,'deals','.b-email .heading-name','padding-left','10','','','.b-email'),(986761,'deals','.b-email .heading-image','padding-left','10','','','.b-email'),(986762,'deals','.w-checkout-create-account .create-account','padding-left','0','','','.w-checkout-create-account'),(986763,'deals','.w-checkout-shipping .sub-item','padding-left','0','','','.w-checkout-shipping'),(986764,'deals','.b-email .totals-value','padding-left','10','','','.b-email'),(986765,'deals','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(986766,'deals','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(986767,'deals','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(986768,'deals','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(986769,'deals','.w-promo-code .holder','padding-left','20','5660','','.w-promo-code'),(986770,'deals','.w-promo-code .heading-4','padding-left','30','5660','','.w-promo-code'),(986771,'deals','.b-form .shipping-method .input','padding-left','0','','','.b-form'),(986772,'deals','.b-form .center-buttons','padding-left','0','','','.b-form'),(986773,'deals','.w-reviews .item','padding-left','0','','','.w-reviews'),(986774,'deals','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(986775,'deals','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(986776,'deals','.b-select-suggest .select2-container .select2-choice','padding-left','8','','','.b-select-suggest'),(986780,'deals','.b-sub-totals .historyTotal td','padding-left','5','','','.b-sub-totals'),(986781,'deals','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(986782,'deals','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(986783,'deals','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(986784,'deals','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(986786,'deals','.b-upload-files .upload-files','padding-left','10','','','.b-upload-files'),(986787,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(986788,'deals','.w-login-block .guest','padding-left','40','','','.w-login-block'),(986789,'deals','.w-login-block .new','padding-left','40','','','.w-login-block'),(986790,'deals','.w-product-images-additional .images','padding-left','0','5660','','.w-product-images-additional'),(986791,'deals','.w-checkout-shipping-address .edit-ab','padding-left','15','','','.w-checkout-shipping-address'),(986792,'deals','.b-bottom .header-error','padding-left','20','','','.b-bottom'),(986793,'deals','.w-categories h2.name','padding-left','3','','','.w-categories'),(986794,'deals','.w-cart-discount-coupon .btn','padding-left','25','','','.w-cart-discount-coupon'),(986795,'deals','.b-form .form-buttons','padding-left','0','','','.b-form'),(986796,'deals','.b-form .payment-method .item-radio label span','padding-left','5','','','.b-form'),(986797,'deals','.w-checkout-billing-address .same-address','padding-left','10','','','.w-checkout-billing-address'),(986798,'deals','.btn-3','padding-left','25','','',''),(986799,'deals','.w-cart-compare .delete-cart','padding-left','10','','','.w-cart-compare'),(986800,'deals','.w-cart-compare .price-cell','padding-left','20','','','.w-cart-compare'),(986801,'deals','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','60','','','.b-select-suggest'),(986802,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(986803,'deals','.b-email .totals-title','padding-left','10','','','.b-email'),(986804,'deals','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(986805,'deals','.b-email .heading-qty','padding-left','10','','','.b-email'),(986806,'deals','.b-bottom .cart-options .cart-item input[type=\"radio\"]:checked + span input[type=\"text\"]','padding-left','10','','','.b-bottom'),(986807,'deals','.w-product-images-additional .images','padding-left','0','5660','','.w-product-images-additional'),(986808,'deals','.w-promo-code .heading-4','padding-left','30','5660','','.w-promo-code'),(986809,'deals','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-left','20','','','.b-bottom'),(986810,'deals','.b-bottom .cart-options .cart-item input[type=\"text\"]','padding-left','0','','','.b-bottom'),(986811,'deals','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-left','6','','','.b-compare'),(986812,'deals','.w-cart-compare .cart-cell','padding-left','7','','','.w-cart-compare'),(986813,'deals','.w-cart-compare .product','padding-left','15','','','.w-cart-compare'),(986814,'deals','.w-promotions .promo-cart-discount .master .item','padding-left','20','','','.w-promotions'),(986816,'deals','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(986817,'deals','.b-bottom .alert-message','padding-left','20','','','.b-bottom'),(986818,'deals','.b-bottom .cart-options','padding-left','20','','','.b-bottom'),(986819,'deals','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','5639','','.w-menu-horizontal'),(986820,'deals','.w-login-block .guest','padding-left','40','','','.w-login-block'),(986821,'deals','.b-select-suggest .select2-results .select2-result-label','padding-left','7','','','.b-select-suggest'),(986822,'deals','.w-login-block .new','padding-left','40','','','.w-login-block'),(986823,'deals','.w-login-block .guest','padding-left','40','','','.w-login-block'),(986824,'deals','.w-quote .cart-box-link','padding-left','10','','','.w-quote'),(986825,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(986826,'deals','.b-email .totals-value','padding-left','10','','','.b-email'),(986827,'deals','.b-email .totals-title','padding-left','10','','','.b-email'),(986828,'deals','.b-email .qty','padding-left','10','','','.b-email'),(986829,'deals','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(986830,'deals','.b-email .heading-price','padding-left','10','','','.b-email'),(986831,'deals','.b-bottom .rfq-form','padding-left','20','','','.b-bottom'),(986832,'deals','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(986833,'deals','.b-bottom .footerTitle','padding-left','0','5630','','.b-bottom'),(986834,'deals','.b-bottom .pop-up-close','padding-left','1','','','.b-bottom'),(986835,'deals','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(986836,'deals','.w-cart-up-sell .w-list-type-1','padding-left','0','','','.w-cart-up-sell'),(986837,'deals','.w-cart-shipping-estimator .address-item','padding-left','0','','','.w-cart-shipping-estimator'),(986838,'deals','.w-cart-up-sell .w-list-type-1 .item','padding-left','20','1','','.w-cart-up-sell'),(986839,'deals','.w-cart-up-sell .w-list-type-1 .item','padding-left','21','','','.w-cart-up-sell'),(986840,'deals','.b-products-listing .products-listing .btn-buy','padding-left','10','','','.b-products-listing'),(986841,'deals','.b-upload-files .added-file','padding-left','0','','','.b-upload-files'),(986842,'deals','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(986843,'deals','.w-menu-big ul','padding-left','0','','','.w-menu-big'),(986844,'deals','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(986845,'deals','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(986846,'deals','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(986848,'deals','.w-promo-code .holder','padding-left','20','5660','','.w-promo-code'),(986849,'deals','.b-bottom .pop-up-info','padding-left','20','','','.b-bottom'),(986850,'deals','.b-email .heading-price','padding-left','10','','','.b-email'),(986851,'deals','.b-email .image','padding-left','10','','','.b-email'),(986852,'deals','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(986853,'deals','.b-fancybox .fancybox-error','padding-left','15','','','.b-fancybox'),(986854,'deals','.w-cart-compare .product .stock','padding-left','3','','','.w-cart-compare'),(986855,'deals','.b-fancybox .fancybox-next span','padding-left','4','3','','.b-fancybox'),(986856,'deals','.b-form .middle-form','padding-left','0','','','.b-form'),(986857,'deals','.w-product-customers-activity .customers-activity','padding-left','20','','','.w-product-customers-activity'),(986858,'deals','.b-compare .compare-box-item','padding-left','10','','','.b-compare'),(986859,'deals','.b-compare .compare-head','padding-left','10','','','.b-compare'),(986860,'deals','.b-email .model','padding-left','10','','','.b-email'),(986861,'deals','.b-email .image','padding-left','10','','','.b-email'),(986862,'deals','.b-email .heading-qty','padding-left','10','','','.b-email'),(986863,'deals','.b-email .totals-title','padding-left','10','','','.b-email'),(986864,'deals','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(986868,'deals','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(986869,'deals','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(986870,'deals','.w-login-block .new','padding-left','40','','','.w-login-block'),(986871,'deals','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(986872,'deals','.w-login-block .guest','padding-left','40','','','.w-login-block'),(986874,'deals','.w-checkout-billing-address .edit-ab','padding-left','15','','','.w-checkout-billing-address'),(986875,'deals','.w-checkout-billing-address .addresses.address-main label','padding-left','0','','','.w-checkout-billing-address'),(986876,'deals','.w-checkout-billing-address .addresses .address-item label','padding-left','15','','','.w-checkout-billing-address'),(986877,'deals','.w-promo-code .holder','padding-left','20','5660','','.w-promo-code'),(986878,'deals','.w-promo-code .heading-4','padding-left','30','5660','','.w-promo-code'),(986879,'deals','.w-product-images-additional .images','padding-left','0','5660','','.w-product-images-additional'),(986880,'deals','.w-tabs .accordion-heading','padding-left','6','','','.w-tabs'),(986881,'deals','.b-bottom .header-info','padding-left','20','','','.b-bottom'),(986882,'deals','.w-personal-gift-status-bar .start-label','padding-left','30','','','.w-personal-gift-status-bar'),(986883,'deals','.b-upload-file .upload-file-template','padding-left','1','','','.b-upload-file'),(986884,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(986885,'deals','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','padding-left','5','','','.b-switch'),(986886,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-left','5','','','.b-select-suggest'),(986887,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-left','18','','','.b-select-suggest'),(986889,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-left','5','','','.b-select-suggest'),(986890,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-left','0','','','.b-select-suggest'),(986891,'deals','.b-select-suggest .select2-locked','padding-left','5','','','.b-select-suggest'),(986892,'deals','.b-select-suggest .select2-container-multi .select2-choices','padding-left','0','','','.b-select-suggest'),(986893,'deals','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','100','','','.b-select-suggest'),(986894,'deals','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','120','','','.b-select-suggest'),(986895,'deals','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','110','','','.b-select-suggest'),(986896,'deals','.b-select-suggest .select2-results ul.select2-result-sub','padding-left','0','','','.b-select-suggest'),(986897,'deals','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','80','','','.b-select-suggest'),(986898,'deals','.b-select-suggest .select2-results ul.select2-result-sub ul.select2-result-sub > li .select2-result-label','padding-left','40','','','.b-select-suggest'),(986899,'deals','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-left','10','','','.w-menu-horizontal'),(986900,'deals','.b-select-suggest .select2-results','padding-left','4','','','.b-select-suggest'),(986901,'deals','.w-checkout-shipping-address .addresses .address-item label','padding-left','15','','','.w-checkout-shipping-address'),(986902,'deals','.b-select-suggest .select2-results ul.select2-result-sub > li .select2-result-label','padding-left','20','','','.b-select-suggest'),(986903,'deals','.b-form .shipping-method .item + .item','padding-left','0','','','.b-form'),(986904,'deals','.w-checkout-shipping-address .addresses.address-main label','padding-left','0','','','.w-checkout-shipping-address'),(986905,'deals','.b-select-suggest .select2-search input','padding-left','5','','','.b-select-suggest'),(986906,'deals','.b-select-suggest .select2-search','padding-left','4','','','.b-select-suggest'),(986907,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(986911,'deals','.w-cart-compare .product-label','padding-left','10','','','.w-cart-compare'),(986912,'deals','.w-product-promotions select','padding-left','0','','','.w-product-promotions'),(986913,'deals','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(986914,'deals','.b-compare .col-two label','padding-left','0','','','.b-compare'),(986917,'deals','.w-product-promotions .promotion-data-2','padding-left','30','','','.w-product-promotions'),(986918,'deals','.b-bottom .notify-form','padding-left','20','','','.b-bottom'),(986919,'deals','.w-account-addresses-list .addsess-suggestion-item','padding-left','0','','','.w-account-addresses-list'),(986920,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left','5','','','.b-data-table'),(986921,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left','5','','','.b-data-table'),(986922,'deals','.w-communication-post .communication-post-author','padding-left','0','','','.w-communication-post'),(986923,'deals','.b-products-listing .in-cart','padding-left','10','','','.b-products-listing'),(986924,'deals','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-left','5','','','.w-catalog-b2b-add-button'),(986925,'deals','.b-products-listing .promos-info .promo-item','padding-left','0','','','.b-products-listing'),(986926,'deals','.b-products-listing .promos-info .promo-name','padding-left','15','','','.b-products-listing'),(986927,'deals','.blogsidebar','padding-left','35','','',''),(986933,'deals','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(986934,'deals','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(986935,'deals','.b-social-login .social-login-text-1','padding-left','15','','','.b-social-login'),(986936,'deals','.w-checkout-gdpr .terms-login','padding-left','0','','','.w-checkout-gdpr'),(986937,'deals','.w-checkout-gdpr .privacy-row','padding-left','0','','','.w-checkout-gdpr'),(986938,'deals','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(986939,'deals','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(986940,'deals','.b-compare .column_wrapper','padding-left','10','','','.b-compare'),(986941,'deals','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(986942,'deals','.b-email .price','padding-left','10','','','.b-email'),(986943,'deals','.b-email .heading-name','padding-left','10','','','.b-email'),(986944,'deals','.b-email .heading-model','padding-left','10','','','.b-email'),(986945,'deals','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(986947,'deals','.w-top-categories .item','padding-left','10','5630','','.w-top-categories'),(986948,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(986949,'deals','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(986950,'deals','.w-personal-gift-status-bar .timeline','padding-left','10','','','.w-personal-gift-status-bar'),(986951,'deals','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(986952,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-left','0','','',''),(986953,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-left','0','','','.b-h-inline'),(986954,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-left','5','','','.w-communication-new-topic'),(986955,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-left','10','','','.w-communication-new-topic'),(986956,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-left','5','','','.w-communication-new-topic'),(986957,'deals','.w-communication-new-topic #communication_topic_form .middle-form','padding-left','0','','','.w-communication-new-topic'),(986958,'deals','.b-dropdown .dropdown .dropdown-menu','padding-left','10','','','.b-dropdown'),(986959,'deals','.b-email .heading-price','padding-left','10','','','.b-email'),(986960,'deals','.b-email .image','padding-left','10','','','.b-email'),(986961,'deals','.btn-2','padding-left','25','','',''),(986962,'deals','.b-compare .compare_pagination','padding-left','0','','','.b-compare'),(986963,'deals','.b-bottom .popup-content','padding-left','15','','','.b-bottom'),(986964,'deals','.w-reviews-content .author','padding-left','20','','','.w-reviews-content'),(986965,'deals','.b-email .qty','padding-left','10','','','.b-email'),(986966,'deals','.w-login-block .new','padding-left','40','','','.w-login-block'),(986968,'deals','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-left','0','','','.b-fancybox'),(986969,'deals','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(986970,'deals','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(986971,'deals','.b-email .heading-image','padding-left','10','','','.b-email'),(986972,'deals','.b-email .price','padding-left','10','','','.b-email'),(986973,'deals','.products-quick-index .token-input-list','padding-left','0','','',''),(986976,'deals','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(986977,'deals','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(986978,'deals','.b-form .shipping-method .item','padding-left','0','','','.b-form'),(986979,'deals','.b-email .model','padding-left','10','','','.b-email'),(986980,'deals','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(986981,'deals','.w-promo-code .holder','padding-left','20','5660','','.w-promo-code'),(986982,'deals','.b-email-editor .product-item','padding-left','10','','','.b-email-editor'),(986983,'deals','.w-cart-listing .item .gift-wrap label','padding-left','10','','','.w-cart-listing'),(986984,'deals','.w-cart-listing .item > div','padding-left','10','','','.w-cart-listing'),(986985,'deals','.w-cart-listing .points-earn','padding-left','10','','','.w-cart-listing'),(986986,'deals','.w-cart-listing .points-redeem','padding-left','25','','','.w-cart-listing'),(986987,'deals','.w-cart-listing .item .gift-wrap .value','padding-left','5','','','.w-cart-listing'),(986988,'deals','.w-cart-listing .item .gift-wrap','padding-left','0','5639','','.w-cart-listing'),(986989,'deals','.w-cart-give-away .ga_img','padding-left','1','','','.w-cart-give-away'),(986996,'deals','.w-brands .brands-listing > div','padding-left','0','','','.w-brands'),(986997,'deals','.w-brands .brands-listing','padding-left','0','','','.w-brands'),(986998,'deals','.b-email-editor .old-price','padding-left','10','','','.b-email-editor'),(986999,'deals','.b-email-editor .special-price','padding-left','10','','','.b-email-editor'),(987000,'deals','.b-email-editor .price','padding-left','10','','','.b-email-editor'),(987001,'deals','.b-email .heading-model','padding-left','10','','','.b-email'),(987002,'deals','.b-email .model','padding-left','10','','','.b-email'),(987003,'deals','.b-compare .col-gender','padding-left','0','','','.b-compare'),(987005,'deals','.w-socials > li','padding-left','15','','','.w-socials'),(987006,'deals','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(987007,'deals','.w-promo-code .promo-text-2','padding-left','15','','','.w-promo-code'),(987008,'deals','.w-promo-code .holder','padding-left','110','','','.w-promo-code'),(987010,'deals','.b-compare .popupCompare td.level-3:first-child','padding-left','18','','','.b-compare'),(987012,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-left','20','','','.b-tracking-numbers'),(987013,'deals','.b-tracking-numbers .tracking-numbers td','padding-left','10','','','.b-tracking-numbers'),(987014,'deals','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(987016,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-left','0','','','.w-menu-style-2'),(987017,'deals','.w-filters .fsl_handle','padding-left','0','','','.w-filters'),(987018,'deals','.w-filters .head-filter-widget','padding-left','10','5639','','.w-filters'),(987019,'deals','.w-catalog-sorting .before','padding-left','0','','','.w-catalog-sorting'),(987020,'deals','.w-filters .ui-slider-range','padding-left','0','','','.w-filters'),(987022,'deals','.b-tracking-numbers .tracking-numbers th','padding-left','10','','','.b-tracking-numbers'),(987023,'deals','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(987024,'deals','.w-filters .head-filter-widget','padding-left','0','','','.w-filters'),(987025,'deals','.w-login-block .password-row','padding-left','0','','','.w-login-block'),(987026,'deals','.b-autocomplete .ui-autocomplete','padding-left','2','','','.b-autocomplete'),(987027,'deals','.w-promo-code .heading-4','padding-left','30','5660','','.w-promo-code'),(987028,'deals','.order-summary .heading-2','padding-left','0','','','.order-summary'),(987029,'deals','.b-email .name','padding-left','10','','','.b-email'),(987030,'deals','.b-email .totals-title','padding-left','10','','','.b-email'),(987031,'deals','.b-email .heading-qty','padding-left','10','','','.b-email'),(987033,'deals','.b-data-table table.dataTable tbody td','padding-left','20','','','.b-data-table'),(987034,'deals','.b-data-table table.dataTable thead td','padding-left','20','','','.b-data-table'),(987035,'deals','.b-compare .popupCompare .pop-up-content','padding-left','10','','','.b-compare'),(987038,'deals','.b-email .qty','padding-left','10','','','.b-email'),(987039,'deals','.b-email .totals-title','padding-left','10','','','.b-email'),(987040,'deals','.b-email .qty','padding-left','10','','','.b-email'),(987041,'deals','.b-email .price','padding-left','10','','','.b-email'),(987042,'deals','.btn','padding-left','25','','',''),(987043,'deals','.p-sample-checkout-confirmation .buttons','padding-left','0','','','.p-sample-checkout-confirmation'),(987044,'deals','.b-product-images .media-popup .mp-content','padding-left','5','','','.b-product-images'),(987045,'deals','.b-product-images .media-popup .mp-small-images .item','padding-left','10','','','.b-product-images'),(987046,'deals','.b-product-images .media-popup .slick-dots','padding-left','0','','','.b-product-images'),(987047,'deals','.b-product-images .media-popup .slick-dots li','padding-left','0','','','.b-product-images'),(987048,'deals','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-left','0','','','.b-menu-style'),(987049,'deals','.b-personal-catalog-popup #personal_catalog_popup','padding-left','0','','','.b-personal-catalog-popup'),(987050,'deals','.b-trade-approval .steps-bar li a','padding-left','0','','','.b-trade-approval'),(987051,'deals','.b-trade-approval .middle-form','padding-left','0','','','.b-trade-approval'),(987052,'deals','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-left','5','','','.b-trade-approval'),(987053,'deals','.b-trade-approval .steps-bar','padding-left','12','','','.b-trade-approval'),(987054,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-left','10','','','.b-trade-approval'),(987055,'deals','.b-trade-approval .center-buttons','padding-left','0','','','.b-trade-approval'),(987056,'deals','.w-account-personal-catalog .list-switcher','padding-left','0','','','.w-account-personal-catalog'),(987057,'deals','.w-account-personal-catalog .list-switcher a','padding-left','6','','','.w-account-personal-catalog'),(987058,'deals','.w-account-subscription .subscription-variant','padding-left','10','','','.w-account-subscription'),(987059,'deals','.w-catalog-additional-images li','padding-left','10','','','.w-catalog-additional-images'),(987060,'deals','.w-catalog-additional-images ul','padding-left','0','','','.w-catalog-additional-images'),(987061,'deals','.w-catalog-compare td','padding-left','20','','','.w-catalog-compare'),(987062,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-left','0','','','.w-catalog-compare'),(987063,'deals','.w-catalog-compare .cross-box .different-all > div','padding-left','5','2','','.w-catalog-compare'),(987064,'deals','.w-catalog-compare .cross-box .different-all > div','padding-left','5','','','.w-catalog-compare'),(987065,'deals','.w-catalog-compare .cross-box .return','padding-left','20','','','.w-catalog-compare'),(987066,'deals','.w-delivery-day .left-count','padding-left','5','','','.w-delivery-day'),(987067,'deals','.w-top-text .top-text','padding-left','10','','','.w-top-text'),(987068,'deals','.w-product-images .additional-horizontal .item','padding-left','10','','','.w-product-images'),(987069,'deals','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-left','10','','','.b-cookie-notice'),(987071,'deals','.lowestPricedBox .w-banner .single_banner','padding-left','15','','','.lowestPricedBox'),(987072,'deals','.lowestPricedBox .w-banner .banner','padding-left','0','','','.lowestPricedBox'),(987073,'deals','.shopByCollectionBox .w-banner .single_banner','padding-left','15','','','.shopByCollectionBox'),(987074,'deals','.b-slick .slick-list','padding-left','0','','','.b-slick'),(987075,'deals','.b-slick .slick-vertical button.slick-next','padding-left','0','3','','.b-slick'),(987076,'deals','.b-slick .slick-vertical button.slick-prev','padding-left','0','3','','.b-slick'),(987077,'deals','.b-slick button.slick-next','padding-left','4','3','','.b-slick'),(987078,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','padding-left','0','','','.b-slick'),(987079,'deals','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-left','15','','',''),(987080,'deals','.w-cart-listing .headings .head','padding-left','0','','','.w-cart-listing'),(987081,'deals','.LeftCategories .w-menu-simple ul','padding-left','0','','','.LeftCategories'),(987082,'deals','.LeftCategories .w-menu-simple ul li a','padding-left','25','','','.LeftCategories'),(987083,'deals','.b-products-listing .products-listing.list-productlisting .item','padding-left','15','','','.b-products-listing'),(987084,'deals','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-left','0','','','.b-products-listing'),(987085,'deals','.b-products-listing .products-listing.list-productlisting .item-content','padding-left','25','','','.b-products-listing'),(987086,'deals','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-left','25','','','.b-products-listing'),(987087,'deals','.b-products-listing .products-listing.list-rows .item-nav > div','padding-left','5','','','.b-products-listing'),(987088,'deals','.w-breadcrumb .breadcrumb-ul','padding-left','0','','','.w-breadcrumb'),(987089,'deals','.w-quote .buttons','padding-left','15','','','.w-quote'),(987090,'deals','.w-quote .buttons .btn','padding-left','15','','','.w-quote'),(987091,'deals','.w-quote .cart-content','padding-left','15','','','.w-quote'),(987092,'deals','.w-quote .cart-total','padding-left','0','','','.w-quote'),(987093,'deals','.w-quote .multicart .cart-content','padding-left','0','','','.w-quote'),(987094,'deals','.w-quote .multicart .item','padding-left','45','','','.w-quote'),(987095,'deals','.w-quote .multicart .name','padding-left','10','','','.w-quote'),(987096,'deals','.w-quote .qty','padding-left','5','4','','.w-quote'),(987097,'deals','.w-quote a.item','padding-left','90','','','.w-quote'),(987098,'deals','.w-social-links a','padding-left','8','','','.w-social-links'),(987099,'deals','.w-product-images .additional-vertical .additional-images','padding-left','0','','','.w-product-images'),(987100,'deals','.w-product-personal-catalog-button .btn','padding-left','25','','','.w-product-personal-catalog-button'),(987101,'deals','.b-quantity .qty-box input','padding-left','3','','','.b-quantity'),(987102,'deals','.w-product-sale-ends .left-count','padding-left','5','','','.w-product-sale-ends'),(987103,'deals','.w-product-sale-ends .left-count-days','padding-left','0','','','.w-product-sale-ends'),(987104,'deals','.w-product-sale-ends .left-count-hours','padding-left','0','','','.w-product-sale-ends'),(987105,'deals','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-left','0','','','.w-product-quantity'),(987106,'deals','.w-product-quantity .qty_packs .qty-input','padding-left','0','','','.w-product-quantity'),(987107,'deals','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-left','0','','','.w-product-quantity'),(987108,'deals','.w-product-quantity .total-qty','padding-left','0','','','.w-product-quantity'),(987109,'deals','.w-product-quantity .total-qty .qty_price','padding-left','0','','','.w-product-quantity'),(987110,'deals','.w-product-bonus-points > div > div','padding-left','25','','','.w-product-bonus-points'),(987111,'deals','.warrantyProduct .warranty, .warrantyProduct .delivery','padding-left','50','','','.warrantyProduct'),(987112,'deals','.w-compare .compare-list-buttons','padding-left','10','','','.w-compare'),(987113,'deals','.w-compare .item-holder','padding-left','90','','','.w-compare'),(987114,'deals','.w-compare .compare-list-products','padding-left','30','','','.w-compare'),(987115,'deals','.w-files-catalog-widgets-files-catalog .name','padding-left','10','','','.w-files-catalog-widgets-files-catalog'),(987116,'deals','.w-files-catalog-widgets-files-list .file','padding-left','20','','','.w-files-catalog-widgets-files-list'),(987117,'deals','.w-sample .buttons','padding-left','15','','','.w-sample'),(987118,'deals','.w-sample .buttons .btn','padding-left','15','','','.w-sample'),(987119,'deals','.w-sample .cart-box-link','padding-left','10','','','.w-sample'),(987120,'deals','.w-sample .cart-content','padding-left','15','','','.w-sample'),(987121,'deals','.w-sample .cart-total','padding-left','0','','','.w-sample'),(987122,'deals','.w-sample .multicart .cart-content','padding-left','0','','','.w-sample'),(987123,'deals','.w-sample .multicart .item','padding-left','45','','','.w-sample'),(987124,'deals','.w-sample .multicart .name','padding-left','10','','','.w-sample'),(987125,'deals','.w-sample .no-text','padding-left','20','','','.w-sample'),(987126,'deals','.w-sample .qty','padding-left','5','4','','.w-sample'),(987127,'deals','.w-sample a.item','padding-left','90','','','.w-sample'),(987128,'deals','.w-cart-listing .item > div.points','padding-left','0','','','.w-cart-listing'),(987129,'deals','.w-filters-simple .integrate-price-holder','padding-left','0','','','.w-filters-simple'),(987130,'deals','.w-product-video .item','padding-left','10','','','.w-product-video'),(987131,'deals','.shipping-ico .heading-3','padding-left','0','','','.shipping-ico'),(987132,'deals','.w-cart-order-reference .btn','padding-left','25','','','.w-cart-order-reference'),(987133,'deals','.w-cart-gift-certificate .btn','padding-left','25','','','.w-cart-gift-certificate'),(987134,'deals','.w-cart-shipping-estimator .btn','padding-left','25','','','.w-cart-shipping-estimator'),(987135,'deals','.w-product-bundle .attributes-item','padding-left','0','','','.w-product-bundle'),(987136,'deals','.w-product-bundle .bundle_item','padding-left','10','','','.w-product-bundle'),(987137,'deals','.w-product-in-bundles .attributes-item','padding-left','0','','','.w-product-in-bundles'),(987138,'deals','.w-product-in-bundles .bundle_item','padding-left','10','','','.w-product-in-bundles'),(987139,'deals','.w-cart-listing .item > div.actions','padding-left','10','5630','','.w-cart-listing'),(987141,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-left','0','','','.b-products-listing'),(987142,'deals','.b-pagination .pagination .next-pages','padding-left','5','','','.b-pagination'),(987143,'deals','.b-pagination .pagination .page-number','padding-left','5','','','.b-pagination'),(987144,'deals','.b-pagination .pagination .prev-pages','padding-left','5','','','.b-pagination'),(987145,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','padding-left','5','','','.b-pagination'),(987146,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','padding-left','5','','','.b-pagination'),(987147,'deals','.b-pagination .pagination span','padding-left','5','2','','.b-pagination'),(987148,'deals','.b-pagination ul.pagination','padding-left','0','','','.b-pagination'),(987149,'deals','.w-product-properties-filters-widgets-chosen-filters .item','padding-left','10','','','.w-product-properties-filters-widgets-chosen-filters'),(987150,'deals','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block, .checkout > .type-1 > .block','padding-left','15','','',''),(987151,'deals','.p-quote-checkout-index .datepicker-inline','padding-left','0','','','.p-quote-checkout-index'),(987152,'deals','.p-sample-checkout-index .datepicker-inline','padding-left','0','','','.p-sample-checkout-index'),(987156,'deals','.w-product-multi-inventory .radio-attributes .option-item','padding-left','15','','','.w-product-multi-inventory'),(987157,'deals','.b-products-listing .products-listing .radio-attributes .option','padding-left','15','','','.b-products-listing'),(987158,'deals','.w-product-collection .item','padding-left','10','','','.w-product-collection'),(987159,'deals','.w-product-collection .right-area .btn','padding-left','25','','','.w-product-collection'),(987160,'deals','.w-product-collection .right-area','padding-left','2','','','.w-product-collection'),(987161,'deals','.w-product-collection .right-area','padding-left','0','5639','','.w-product-collection'),(987162,'deals','.w-product-attributes .radio-attributes .option-item','padding-left','15','','','.w-product-attributes'),(987163,'deals','.w-product-properties .property-ul','padding-left','0','','','.w-product-properties'),(987164,'deals','.w-product-properties .properties-table','padding-left','0','','','.w-product-properties'),(987165,'deals','.w-product-properties li','padding-left','0','','','.w-product-properties'),(987166,'deals','.w-product-properties li.level-2:first-child','padding-left','15','','','.w-product-properties'),(987167,'deals','.w-product-properties li.level-3:first-child','padding-left','25','','','.w-product-properties'),(987168,'deals','.w-product-properties li.level-4:first-child','padding-left','35','','','.w-product-properties'),(987169,'deals','.w-product-properties li.level-5:first-child','padding-left','45','','','.w-product-properties'),(987170,'deals','.w-product-groups .radioBox','padding-left','0','','','.w-product-groups'),(987171,'deals','.w-product-groups .radioBox label','padding-left','0','','','.w-product-groups'),(987172,'deals','.w-product-groups .radioBox label .containerBlock','padding-left','10','','','.w-product-groups'),(987173,'deals','.w-product-groups .radioBox label .containerBlock','padding-left','10','5660','','.w-product-groups'),(987174,'deals','.w-product-groups .radioBox label .containerBlock img + .name','padding-left','60','','','.w-product-groups'),(987175,'deals','.w-product-groups .radioBox label .containerBlock img + .name + .val2','padding-left','60','','','.w-product-groups'),(987176,'deals','.b-products-listing .mix-attributes .attribute-qty-block','padding-left','10','','','.b-products-listing'),(987177,'deals','.b-products-listing .products-listing .attribute-qty-block','padding-left','5','','','.b-products-listing'),(987178,'deals','.blogsidebar','padding-left','0','5639','',''),(987179,'deals','.w-product-custom-bundle .item','padding-left','10','','','.w-product-custom-bundle'),(987180,'deals','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-left','25','','','.w-product-custom-bundle'),(987181,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list'),(987182,'deals','.w-delivery-location-top-location-list .deliveryList ul','padding-left','0','','','.w-delivery-location-top-location-list'),(987183,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-left','10','','','.w-catalog-pages-category-pages-last-list'),(987184,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list-block'),(987185,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-left','10','','','.w-catalog-pages-category-pages-last-list-block'),(987186,'deals','.w-delivery-location-location-list ul','padding-left','0','','','.w-delivery-location-location-list'),(987187,'deals','.w-delivery-location-location-description .deliveryDesc','padding-left','0','','','.w-delivery-location-location-description'),(987188,'deals','.w-delivery-location-location-list .deliveryListParrent a','padding-left','25','','','.w-delivery-location-location-list'),(987189,'deals','.w-delivery-location-location-list .deliveryList li a','padding-left','15','','','.w-delivery-location-location-list'),(987190,'deals','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding-left','2','','','.w-delivery-location-featured-list'),(987191,'deals','.w-delivery-location-featured-list .deliveryList > ul','padding-left','0','','','.w-delivery-location-featured-list'),(987192,'deals','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding-left','0','5660','','.w-delivery-location-featured-list'),(987193,'deals','.w-sale-category .holder-1','padding-left','20','','','.w-sale-category'),(987194,'deals','.w-sale-category .holder-2','padding-left','20','','','.w-sale-category'),(987195,'deals','.w-sale-category .left-count','padding-left','5','','','.w-sale-category'),(987196,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(987197,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-left','10','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(987198,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(987199,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-left','10','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(987200,'deals','.w-delivery-location-list-by-page .description ul','padding-left','30','','','.w-delivery-location-list-by-page'),(987201,'deals','.w-product-properties-icons .property-image','padding-left','10','','','.w-product-properties-icons'),(987202,'deals','.w-product-properties-icons .hover-box-content','padding-left','10','','','.w-product-properties-icons'),(987203,'deals','.w-delivery-location-cross-pages .description ul','padding-left','30','','','.w-delivery-location-cross-pages'),(987204,'deals','.w-delivery-location-product-categories .item.category-link','padding-left','15','','','.w-delivery-location-product-categories'),(987205,'deals','.w-delivery-location-product-categories .item.category-link','padding-left','10','5639','','.w-delivery-location-product-categories'),(987206,'deals','.w-delivery-location-product-categories .item.category-link','padding-left','0','5660','','.w-delivery-location-product-categories'),(987207,'deals','.w-delivery-location-product-categories .name','padding-left','15','','','.w-delivery-location-product-categories'),(987208,'deals','.w-catalog-delivery-locations .description ul','padding-left','30','','','.w-catalog-delivery-locations'),(987209,'deals','.delivery-options-popup','padding-left','20','','',''),(987210,'deals','.w-product-bonus-points .bonus-points-cost','padding-left','45','','','.w-product-bonus-points'),(987211,'deals','.w-product-designer-designer .grnamebox .title-sortable','padding-left','15','','','.w-product-designer-designer'),(987212,'deals','.w-product-designer-designer .prodDesignerType label','padding-left','10','','','.w-product-designer-designer'),(987213,'deals','.w-press-reviews-widgets-press-reviews ','padding-left','30','','','.w-press-reviews-widgets-press-reviews'),(987214,'deals','.w-press-reviews-widgets-press-reviews .author','padding-left','25','','','.w-press-reviews-widgets-press-reviews'),(987215,'deals','.w-press-reviews-widgets-press-reviews .item','padding-left','20','','','.w-press-reviews-widgets-press-reviews'),(987216,'deals','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-left','30','','','.w-press-reviews-widgets-press-reviews'),(987217,'deals','.w-press-reviews-widgets-press-reviews .rating','padding-left','15','','','.w-press-reviews-widgets-press-reviews'),(987218,'deals','.w-press-reviews-widgets-press-reviews .review','padding-left','25','','','.w-press-reviews-widgets-press-reviews'),(987219,'deals','.w-press-reviews-widgets-press-reviews .sub-box','padding-left','20','','','.w-press-reviews-widgets-press-reviews'),(987220,'deals','.w-press-reviews-widgets-press-reviews .sub-box ul','padding-left','20','','','.w-press-reviews-widgets-press-reviews'),(987221,'deals','.w-press-reviews-widgets-press-reviews .title','padding-left','15','','','.w-press-reviews-widgets-press-reviews'),(987222,'deals','.w-press-reviews-widgets-press-reviews ','padding-left','15','5630','','.w-press-reviews-widgets-press-reviews'),(987223,'deals','.w-press-reviews-widgets-press-reviews .author','padding-left','0','5630','','.w-press-reviews-widgets-press-reviews'),(987224,'deals','.w-press-reviews-widgets-press-reviews .item','padding-left','0','5630','','.w-press-reviews-widgets-press-reviews'),(987225,'deals','.w-press-reviews-widgets-press-reviews .rating','padding-left','0','5630','','.w-press-reviews-widgets-press-reviews'),(987226,'deals','.w-press-reviews-widgets-press-reviews .review','padding-left','0','5630','','.w-press-reviews-widgets-press-reviews'),(987227,'deals','.w-press-reviews-widgets-press-reviews .title','padding-left','0','5630','','.w-press-reviews-widgets-press-reviews'),(987228,'deals','.w-press-reviews-widgets-press-reviews-list .item','padding-left','25','','','.w-press-reviews-widgets-press-reviews-list'),(987229,'deals','.w-press-reviews-widgets-press-reviews-list .short-description','padding-left','0','','','.w-press-reviews-widgets-press-reviews-list'),(987230,'deals','.b-products-listing .productGroup label a','padding-left','16','','','.b-products-listing'),(987231,'deals','.w-support-system-filter ','padding-left','0','','','.w-support-system-filter'),(987232,'deals','.w-support-system-filter .filter_cats','padding-left','0','','','.w-support-system-filter'),(987233,'deals','.w-support-system-listing .support-head','padding-left','13','','','.w-support-system-listing'),(987234,'deals','.w-communication-post .btn.refresh','padding-left','0','','','.w-communication-post'),(987235,'deals','.w-rma-returns-history .btn','padding-left','10','','','.w-rma-returns-history'),(987236,'deals','.w-rma-returns-history .column','padding-left','3','','','.w-rma-returns-history'),(987237,'deals','.w-rma-returns-history .column .title','padding-left','10','','','.w-rma-returns-history'),(987238,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','padding-left','5','','','.w-rma-returns-history'),(987239,'deals','.w-rma-returns-history .icons .print','padding-left','15','','','.w-rma-returns-history'),(987240,'deals','.w-rma-returns-history .topRow','padding-left','0','','','.w-rma-returns-history'),(987241,'deals','.w-rma-returns-history .column:last-child .title','padding-left','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(987242,'deals','.w-product-designer-designer .productDesignerBox ul','padding-left','0','','','.w-product-designer-designer'),(987243,'deals','.w-product-configurator .pc-item','padding-left','0','','','.w-product-configurator'),(987244,'deals','.w-product-configurator .pc_stock','padding-left','10','','','.w-product-configurator'),(987245,'deals','.w-product-configurator .pc_item','padding-left','0','5639','','.w-product-configurator'),(987246,'deals','.w-product-configurator .pc_attr','padding-left','0','5630','','.w-product-configurator'),(987247,'deals','.w-product-configurator .pc-item label','padding-left','20','','','.w-product-configurator'),(987248,'deals','.b-products-listing .promos-info .promo-name-span','padding-left','40','','','.b-products-listing'),(987249,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-left','0','','','.w-catalog-pages-category-pages-list'),(987250,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-left','10','','','.w-catalog-pages-category-pages-list'),(987251,'deals','.w-predefined-promotion .nextdiscount .content > div','padding-left','10','','','.w-predefined-promotion'),(987252,'deals','.w-predefined-promotion .nextdiscount .promo-for-each','padding-left','10','','','.w-predefined-promotion'),(987253,'deals','.w-predefined-promotion .prom-multi-discount .promo-product','padding-left','20','','','.w-predefined-promotion'),(987254,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','padding-left','20','','','.w-predefined-promotion'),(987255,'deals','.w-predefined-promotion .promo-cart-discount .master .item','padding-left','20','','','.w-predefined-promotion'),(987256,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-left','20','','','.w-predefined-promotion'),(987257,'deals','.w-predefined-promotion .promo-cart-discount .slave','padding-left','15','','','.w-predefined-promotion'),(987258,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-left','20','','','.w-predefined-promotion'),(987259,'deals','.w-predefined-promotion .promo-cart-discount .slave .item','padding-left','20','','','.w-predefined-promotion'),(987260,'deals','.w-predefined-promotion .promo-item','padding-left','40','','','.w-predefined-promotion'),(987261,'deals','.w-predefined-promotion .promo-salemaker .discount','padding-left','20','','','.w-predefined-promotion'),(987262,'deals','.w-predefined-promotion .promo-salemaker .item','padding-left','20','','','.w-predefined-promotion'),(987263,'deals','.w-predefined-promotion .promo-salemaker .promo-manufacturers','padding-left','12','','','.w-predefined-promotion'),(987264,'deals','.w-supplier-purchase-supplier-products .item','padding-left','20','','','.w-supplier-purchase-supplier-products'),(987265,'deals','.headerWrap ','padding-left','0','','','.headerWrap'),(987266,'deals','.headerWrap .searchIcon','padding-left','30','','','.headerWrap'),(987267,'deals','.headerWrap .w-contacts.phone','padding-left','15','','','.headerWrap'),(987268,'deals','.headerWrap >div.block, .headerWrap .headerInside >div.block','padding-left','20','','','.headerWrap'),(987270,'deals','.parallaxWrap .w-info-page','padding-left','0','','','.parallaxWrap'),(987271,'deals','.bannersWrap .text','padding-left','50','','','.bannersWrap'),(987272,'deals','.bannersWrap .rightBanner','padding-left','1','','','.bannersWrap'),(987273,'deals','.headerWrap .menu-style[data-style=\"1\"] li.back-button','padding-left','20','','','.headerWrap'),(987274,'deals','.w-categories .categories h2','padding-left','0','','','.w-categories'),(987275,'deals','.w-categories .item','padding-left','10','5630','','.w-categories'),(987276,'deals','.filterLine .before','padding-left','10','','','.filterLine'),(987277,'deals','.filterLine .choose-filters li .btn-clear','padding-left','10','','','.filterLine'),(987278,'deals','.w-filters .filter-widget-horizontal .filter-box-content','padding-left','15','','','.w-filters'),(987279,'deals','.w-filters .filter-widget-horizontal .filter-box-head','padding-left','7','','','.w-filters'),(987280,'deals','.w-filters .choose-filters','padding-left','0','','','.w-filters'),(987281,'deals','.w-filters .choose-filters > li > *','padding-left','10','','','.w-filters'),(987282,'deals','.w-filters .choose-filters > li','padding-left','10','','','.w-filters'),(987283,'deals','.b-products-listing .products-listing .bonus-points-cost','padding-left','30','','','.b-products-listing'),(987284,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span','padding-left','10','','','.w-product-quantity-discounts'),(987285,'deals','.b-quantity .qty-box input[type=\'text\']','padding-left','3','','','.b-quantity'),(987286,'deals','.w-product-groups .property-category-heading','padding-left','21','','','.w-product-groups'),(987287,'deals','.w-product-groups .property-category-heading + .property-category-content','padding-left','20','','','.w-product-groups'),(987288,'deals','.w-product-name h1','padding-left','0','','','.w-product-name'),(987289,'deals','.w-product-buttons button.add-to-cart','padding-left','25','','','.w-product-buttons'),(987290,'deals','.messageBox .info','padding-left','40','','',''),(987291,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','padding-left','25','','','.b-products-listing'),(987292,'deals','.savings-ico .heading-3','padding-left','0','','','.savings-ico'),(987293,'deals','.order-summary > div','padding-left','20','','','.order-summary'),(987294,'deals','.w-delayed-despatch-checkout .btn','padding-left','25','','','.w-delayed-despatch-checkout'),(987295,'deals','.w-coupons-and-vauchers-checkout .btn','padding-left','25','','','.w-coupons-and-vauchers-checkout'),(987296,'deals','.b-table-list .table-list td','padding-left','10','','','.b-table-list'),(987297,'deals','.b-table-list .table-list th','padding-left','10','','','.b-table-list'),(987298,'deals','.b-table .table .headings td','padding-left','10','','','.b-table'),(987299,'deals','.b-table .table td','padding-left','15','','','.b-table'),(987300,'deals','.headerWrap .headerInside >div.block','padding-left','0','5639','','.headerWrap'),(987301,'deals','.homeBanner .carousel .bottom-center > span','padding-left','50','3','','.homeBanner'),(987302,'deals','.homeBanner .carousel .bottom-center > span','padding-left','10','5644','','.homeBanner'),(987303,'deals','.homeBanner .carousel .bottom-center > span','padding-left','10','5660','','.homeBanner'),(987304,'deals','.homeBanner .carousel .bottom-center > span','padding-left','30','5660,3','','.homeBanner'),(987306,'deals','.bannersWrap .rightBanner','padding-left','0','5630','','.bannersWrap'),(987307,'deals','.bannersWrap .text','padding-left','30','5639','','.bannersWrap'),(987308,'deals','.w-filters .filter-widget-horizontal .head-filter-widget','padding-left','10','5639','','.w-filters'),(987309,'deals','.w-filters .filter-widget-horizontal .filter-box','padding-left','10','5639','','.w-filters'),(987310,'deals','.w-filters .filter_buttons','padding-left','10','','','.w-filters'),(987311,'deals','.b-info .info','padding-left','40','','','.b-info'),(987312,'deals','.b-info .info li','padding-left','0','','','.b-info'),(987313,'deals','.b-info .info ul','padding-left','0','','','.b-info'),(987314,'deals','.payer > .type-1 > .block','padding-left','15','','',''),(987315,'deals','.trade_form > .type-1 > .block','padding-left','15','','',''),(987316,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','padding-left','20','5630','','.headerWrap'),(987317,'deals','.b-personal-catalog-popup button.btn.btn-save-new-list','padding-left','25','','','.b-personal-catalog-popup'),(987318,'deals','.w-account-personal-catalog .list-row-action li','padding-left','10','','','.w-account-personal-catalog'),(987319,'deals','.w-account-personal-catalog .list-row-action ul','padding-left','0','','','.w-account-personal-catalog'),(987320,'deals','.w-multi-cart-save-cart .btn','padding-left','15','5660','','.w-multi-cart-save-cart'),(987321,'deals','.w-product-wishlist-button .btn','padding-left','30','','','.w-product-wishlist-button'),(987322,'deals','.w-catalog-compare .compare-list','padding-left','0','','','.w-catalog-compare'),(987323,'deals','.homeBanner .banner-item .banner-text','padding-left','0','','','.homeBanner'),(987324,'deals','.homeBanner .banner-item.text-bottom-left .banner-text-holder','padding-left','20','','','.homeBanner'),(987325,'deals','.homeBanner .banner-item.text-middle-left .banner-text-holder','padding-left','20','','','.homeBanner'),(987326,'deals','.homeBanner .banner-item.text-top-left .banner-text-holder','padding-left','20','','','.homeBanner'),(987327,'deals','.homeBanner .text-bottom-center .banner-text-holder','padding-left','50','3','','.homeBanner'),(987328,'deals','.homeBanner .text-bottom-left .banner-text-holder','padding-left','50','3','','.homeBanner'),(987329,'deals','.homeBanner .text-bottom-right .banner-text-holder','padding-left','50','3','','.homeBanner'),(987330,'deals','.homeBanner .banner-item .banner-text-holder','padding-left','10','5644','','.homeBanner'),(987331,'deals','.homeBanner .banner-item .banner-text-holder','padding-left','10','5660','','.homeBanner'),(987332,'deals','.homeBanner .text-bottom-center .banner-text-holder','padding-left','30','5660,3','','.homeBanner'),(987333,'deals','.homeBanner .text-bottom-left .banner-text-holder','padding-left','30','5660,3','','.homeBanner'),(987334,'deals','.homeBanner .text-bottom-right .banner-text-holder','padding-left','30','5660,3','','.homeBanner'),(987335,'deals','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','padding-left','0','','','.w-promotions-widgets-promotion-icons-desc'),(987336,'deals','.order-summary .w-cart-listing .item .name','padding-left','0','','','.order-summary'),(987337,'deals','.order-summary .w-cart-listing .item > div ~ div','padding-left','10','','','.order-summary'),(987338,'deals','.w-cart-discount-coupon .discount-box','padding-left','10','','','.w-cart-discount-coupon'),(987339,'deals','.main-content','padding-left','0','','',''),(987340,'deals','.w-promotions-widgets-promotions .promotion-data-2','padding-left','30','','','.w-promotions-widgets-promotions'),(987341,'deals','.w-promotions-widgets-promotions select','padding-left','0','','','.w-promotions-widgets-promotions'),(987367,'deals','.account-address-book .address_book','padding-left','0','','','.account-address-book'),(987368,'deals','.account-address-book .address_book h1','padding-left','0','','','.account-address-book'),(987369,'deals','.account-address-book .address_book h2','padding-left','10','','','.account-address-book'),(987370,'deals','.account-address-book .address_book, .account-address-book .account_history_info','padding-left','0','','','.account-address-book'),(987371,'deals','.account-address-book .btn-edit','padding-left','10','4','','.account-address-book'),(987372,'deals','.account-address-book .buttonBox','padding-left','0','','','.account-address-book'),(987373,'deals','.account-address-book .leftMes ul','padding-left','0','','','.account-address-book'),(987374,'deals','.account-address-book .rightMes ul','padding-left','19','','','.account-address-book'),(987375,'deals','.account-address-book .topButtons','padding-left','0','','','.account-address-book'),(987388,'deals','.account-order-pay .contentColumn','padding-left','40','','','.account-order-pay'),(987389,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-left','40','','','.account-order-pay'),(987390,'deals','.account-order-pay .history_info > div + div','padding-left','2','','','.account-order-pay'),(987391,'deals','.account-order-pay .history_info > div','padding-left','0','5639','','.account-order-pay'),(987392,'deals','.account-order-pay .history_info > div + div','padding-left','0','5639','','.account-order-pay'),(987393,'deals','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-left','10','','','.account-samples'),(987394,'deals','.account-samples .orders-table th','padding-left','10','','','.account-samples'),(987395,'deals','.account-samples .order_history_table th','padding-left','10','','','.account-samples'),(987396,'deals','.account-samples .view_link','padding-left','0','','','.account-samples'),(987397,'deals','.account-samples .orders-table .td-alignright','padding-left','10','5639','','.account-samples'),(987398,'deals','.account-samples .orders-table td','padding-left','10','5639','','.account-samples'),(987399,'deals','.account-sample-info .contentColumn','padding-left','40','','','.account-sample-info'),(987400,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-left','40','','','.account-sample-info'),(987401,'deals','.account-sample-info .history_info > div + div','padding-left','2','','','.account-sample-info'),(987402,'deals','.account-sample-info .popup-tracking-number','padding-left','10','','','.account-sample-info'),(987403,'deals','.account-sample-info .history_info > div','padding-left','0','5639','','.account-sample-info'),(987404,'deals','.account-sample-info .history_info > div + div','padding-left','0','5639','','.account-sample-info'),(987405,'deals','.catalog-product-wrap .next-product','padding-left','20','','','.catalog-product-wrap'),(987406,'deals','.catalog-product-wrap .next-product .pn-image','padding-left','2','3','','.catalog-product-wrap'),(987407,'deals','.catalog-product-wrap .pn-direction','padding-left','4','','','.catalog-product-wrap'),(987408,'deals','.catalog-product-wrap .pn-image','padding-left','5','','','.catalog-product-wrap'),(987409,'deals','.catalog-product-wrap .prev-product','padding-left','50','','','.catalog-product-wrap'),(987410,'deals','.catalog-product-wrap .next-product','padding-left','0','5639','','.catalog-product-wrap'),(987411,'deals','.catalog-product-wrap .pn-direction','padding-left','0','5639','','.catalog-product-wrap'),(987412,'deals','.catalog-product-wrap .prev-product','padding-left','0','5639','','.catalog-product-wrap'),(987413,'deals','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-left','20','','','.shopping-cart-index'),(987414,'deals','.shopping-cart-index .closeable-heading .heading-3','padding-left','0','','','.shopping-cart-index'),(987415,'deals','.checkout-index-wrap .checkout-cart-listing.main-listing','padding-left','30','','','.checkout-index-wrap'),(987416,'deals','.checkout-index-wrap .datepicker-inline','padding-left','0','','','.checkout-index-wrap'),(987417,'deals','.checkout-index-wrap .edit-address-popup','padding-left','20','','','.checkout-index-wrap'),(987418,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-left','25','','','.checkout-index-wrap'),(987419,'deals','.checkout-order-confirmation .price-row','padding-left','0','','','.checkout-order-confirmation'),(987420,'deals','.checkout-order-confirmation .type-4 .type-1 > .block > .type-2 > .block:nth-child(2)','padding-left','20','','','.checkout-order-confirmation'),(987421,'deals','.checkout-order-confirmation .type-4 .type-1 > .block > .type-2 > .block:nth-child(2)','padding-left','0','5660','','.checkout-order-confirmation'),(987422,'deals','.b-form .columns .col-2','padding-left','10','','','.b-form'),(987423,'deals','.b-bottom .pop-up-content','padding-left','20','','','.b-bottom'),(987424,'deals','.b-form .addresses.address-main .address-item','padding-left','0','','','.b-form'),(987425,'deals','.b-slick .slick-dots li','padding-left','5','','','.b-slick'),(987428,'deals','.success-page .check-ico-block','padding-left','10','','','.success-page'),(987429,'deals','.success-page .order-summary2 .btn-2','padding-left','50','','','.success-page'),(987430,'deals','.success-page .order_totals .price-row','padding-left','0','','','.success-page'),(987431,'deals','.success-page .price-row','padding-left','0','','','.success-page'),(987432,'deals','.success-page .w-cart-listing .item.sub-product','padding-left','50','','','.success-page'),(987433,'deals','.success-page .w-cart-listing .qty','padding-left','0','','','.success-page'),(987434,'deals','.success-page .w-cart-listing .sub-product .image','padding-left','0','','','.success-page'),(987435,'deals','.b-multi-page-checkout .multi-page-checkout .buttons','padding-left','0','','','.b-multi-page-checkout'),(987436,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-left','10','','','.b-multi-page-checkout'),(987437,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-left','10','','','.b-multi-page-checkout'),(987438,'deals','.bannersWrap .rightBanner .banner-text','padding-left','35','','','.bannersWrap'),(987440,'deals','.footer-menu .level-2 > li.component-item','padding-left','0','','','.footer-menu'),(987441,'deals','.footer-menu .level-1 > li > .no-link','padding-left','0','5639','','.footer-menu'),(987442,'deals','.footer-menu .level-3 > li','padding-left','20','5639','','.footer-menu'),(987443,'deals','.footer-menu .level-3 > li.back-button','padding-left','20','5639','','.footer-menu'),(987444,'deals','.footer-menu .level-4 > li','padding-left','0','5639','','.footer-menu'),(987445,'deals','.w-banner .banner-text','padding-left','20','','','.w-banner'),(987446,'deals','.w-banner .carousel-text > span','padding-left','20','','','.w-banner'),(987447,'deals','.w-catalog-paging ','padding-left','5','2','','.w-catalog-paging'),(987448,'deals','.w-catalog-paging .next','padding-left','5','','','.w-catalog-paging'),(987449,'deals','.w-catalog-paging .next-pages','padding-left','5','','','.w-catalog-paging'),(987450,'deals','.w-catalog-paging .page-number','padding-left','5','','','.w-catalog-paging'),(987451,'deals','.w-catalog-paging .paging-item','padding-left','2','','','.w-catalog-paging'),(987452,'deals','.w-catalog-paging .prev','padding-left','5','','','.w-catalog-paging'),(987453,'deals','.w-catalog-paging .prev-pages','padding-left','5','','','.w-catalog-paging'),(987462,'deals','.w-menu-slider > ul > li > a','padding-left','10','','','.w-menu-slider'),(987463,'deals','.w-menu-slider > ul > li > ul > li','padding-left','10','','','.w-menu-slider'),(987464,'deals','.w-menu-slider ul, .w-menu-slider li','padding-left','0','','','.w-menu-slider'),(987465,'deals','.bannersWrap .leftBanner .banner-text','padding-left','0','','','.bannersWrap'),(987466,'deals','.b-data-table table.dataTable tbody td','padding-left_important','important','','','.b-data-table'),(987467,'deals','.b-data-table table.dataTable thead td','padding-left_important','important','','','.b-data-table'),(987468,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-left_important','important','','','.b-data-table'),(987469,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-left_important','important','','','.b-data-table'),(987470,'deals','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-right','10','','','.w-communication-new-topic'),(987471,'deals','.b-email .image','padding-right','10','','','.b-email'),(987472,'deals','.order-summary .btn-2, .order-summary .btn-3','padding-right','5','','','.order-summary'),(987475,'deals','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(987476,'deals','.b-form .required-message-wrap','padding-right','0','','','.b-form'),(987477,'deals','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-right','10','','','.p-quick-order-index'),(987478,'deals','.p-quick-order-index ul.token-input-list','padding-right','0','','','.p-quick-order-index'),(987479,'deals','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-right','10','','','.p-quick-order-index'),(987480,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.p-quick-order-index'),(987481,'deals','.w-promotions .promo-date > div','padding-right','50','','','.w-promotions'),(987482,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.p-quick-order-index'),(987483,'deals','.w-promotions .promo-item','padding-right','40','','','.w-promotions'),(987484,'deals','.w-socials > li','padding-right','15','','','.w-socials'),(987485,'deals','.w-cart-compare .attributes-label','padding-right','10','','','.w-cart-compare'),(987490,'deals','.w-personal-gift-status-bar .start-label','padding-right','5','','','.w-personal-gift-status-bar'),(987491,'deals','.w-personal-gift-status-bar .end-label','padding-right','30','','','.w-personal-gift-status-bar'),(987492,'deals','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(987493,'deals','.b-email .image','padding-right','10','','','.b-email'),(987494,'deals','.b-email .heading-qty','padding-right','10','','','.b-email'),(987495,'deals','.b-email .totals-value','padding-right','10','','','.b-email'),(987496,'deals','.b-email .model','padding-right','10','','','.b-email'),(987497,'deals','.testimonials .heading-3','padding-right','0','','',''),(987498,'deals','.testimonials .review','padding-right','10','','',''),(987499,'deals','.testimonials .reviews-list .name','padding-right','10','','',''),(987500,'deals','.testimonials .name','padding-right','10','','',''),(987501,'deals','.w-categories .image','padding-right','0','','','.w-categories'),(987502,'deals','.w-promotions .prom-multi-discount .promo-range','padding-right','20','','','.w-promotions'),(987503,'deals','.w-promotions .prom-multi-discount .promo-product','padding-right','20','','','.w-promotions'),(987504,'deals','.w-promotions .nextdiscount .item-holder .image','padding-right','10','','','.w-promotions'),(987505,'deals','.w-promotions .nextdiscount .content > div','padding-right','10','','','.w-promotions'),(987506,'deals','.w-promotions .master','padding-right','15','','','.w-promotions'),(987507,'deals','.w-promotions .nextdiscount .promo-for-each','padding-right','20','','','.w-promotions'),(987508,'deals','.w-promotions .heading','padding-right','10','','','.w-promotions'),(987509,'deals','.w-promotions .promo-salemaker .promo-categories','padding-right','12','','','.w-promotions'),(987510,'deals','.w-promotions .promo-salemaker .item','padding-right','20','','','.w-promotions'),(987511,'deals','.w-promotions .promo-salemaker .discount','padding-right','20','','','.w-promotions'),(987512,'deals','.w-promotions .promo-cart-discount .slave .item','padding-right','20','','','.w-promotions'),(987513,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','padding-right','20','','','.w-promotions'),(987514,'deals','.w-promotions .promo-cart-discount .promo-min-qty','padding-right','20','','','.w-promotions'),(987515,'deals','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-right','20','','','.b-warehouses-popup'),(987516,'deals','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-right','2','','','.b-products-listing'),(987518,'deals','.w-cart-compare .attributes-cell','padding-right','20','','','.w-cart-compare'),(987519,'deals','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(987520,'deals','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(987522,'deals','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(987523,'deals','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(987524,'deals','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(987525,'deals','.b-bottom .confirm-popup .confirm-text','padding-right','0','','','.b-bottom'),(987526,'deals','.w-top-categories h2.name','padding-right','3','','','.w-top-categories'),(987527,'deals','.b-messages .messages-menu ul','padding-right','0','','','.b-messages'),(987528,'deals','.b-messages .development-content .type-6 .content','padding-right','40','','','.b-messages'),(987529,'deals','.b-messages .msv_btn','padding-right','0','','','.b-messages'),(987530,'deals','.b-messages .msv_content','padding-right','20','','','.b-messages'),(987531,'deals','.b-messages .msv_history','padding-right','20','','','.b-messages'),(987532,'deals','.b-messages .messMenuButton span','padding-right','15','','','.b-messages'),(987533,'deals','.b-messages .messages-menu li a','padding-right','0','','','.b-messages'),(987534,'deals','.b-messages .messages-menu li','padding-right','0','','','.b-messages'),(987535,'deals','.b-messages .content_management_attach button','padding-right','27','','','.b-messages'),(987536,'deals','.b-messages .email-heading','padding-right','15','','','.b-messages'),(987537,'deals','.b-messages .content_management_attach','padding-right','8','','','.b-messages'),(987538,'deals','.b-messages .emailLineTextArea textarea','padding-right','10','','','.b-messages'),(987539,'deals','.b-messages .msv_to_cc','padding-right','15','','','.b-messages'),(987540,'deals','.b-messages .emailBtn','padding-right','10','','','.b-messages'),(987541,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-right','10','','','.b-messages'),(987542,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-right','10','','',''),(987543,'deals','.w-sitemap-delivery-location > ul > li > ul > li','padding-right','20','','','.w-sitemap-delivery-location'),(987544,'deals','.w-reviews-content .item','padding-right','0','','','.w-reviews-content'),(987545,'deals','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(987546,'deals','.w-sitemap-delivery-location > ul > li > ul','padding-right','0','','','.w-sitemap-delivery-location'),(987547,'deals','.w-sitemap-delivery-location > ul','padding-right','0','','','.w-sitemap-delivery-location'),(987548,'deals','.w-checkout-terms .required-message','padding-right','10','','','.w-checkout-terms'),(987549,'deals','.w-cart-listing .item .remove','padding-right','10','5639','','.w-cart-listing'),(987550,'deals','.b-email .model','padding-right','10','','','.b-email'),(987551,'deals','.b-upload-file .upload-file-template','padding-right','1','','','.b-upload-file'),(987552,'deals','.b-email .heading-image','padding-right','10','','','.b-email'),(987553,'deals','.b-email .heading-image','padding-right','10','','','.b-email'),(987554,'deals','.b-email .heading-price','padding-right','10','','','.b-email'),(987555,'deals','.b-email .heading-name','padding-right','10','','','.b-email'),(987556,'deals','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(987557,'deals','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(987558,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(987559,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(987560,'deals','.b-email .price','padding-right','10','','','.b-email'),(987561,'deals','.w-filters .filter-ul-content','padding-right','0','','','.w-filters'),(987562,'deals','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(987563,'deals','.w-login-block .returning','padding-right','40','','','.w-login-block'),(987564,'deals','.w-menu-horizontal > ul > li > ul > li','padding-right','10','','','.w-menu-horizontal'),(987565,'deals','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-right','10','','','.w-menu-horizontal'),(987566,'deals','.w-menu-horizontal ul','padding-right','0','','','.w-menu-horizontal'),(987567,'deals','.w-tabs .tab-navigation','padding-right','0','','','.w-tabs'),(987568,'deals','.b-email .heading-model','padding-right','10','','','.b-email'),(987569,'deals','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(987570,'deals','.b-email .heading-price','padding-right','10','','','.b-email'),(987572,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(987573,'deals','.b-fancybox .fancybox-title-over-wrap','padding-right','10','','','.b-fancybox'),(987574,'deals','.b-email .image','padding-right','10','','','.b-email'),(987575,'deals','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(987576,'deals','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(987577,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(987578,'deals','.b-sub-totals .historyTotal td','padding-right','5','','','.b-sub-totals'),(987579,'deals','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(987580,'deals','.b-email .heading-price','padding-right','10','','','.b-email'),(987581,'deals','.b-email .qty','padding-right','10','','','.b-email'),(987582,'deals','.w-cart-compare .dropdown .dropdown-menu','padding-right','0','','','.w-cart-compare'),(987583,'deals','textarea','padding-right','10','','',''),(987584,'deals','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(987585,'deals','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(987586,'deals','.w-cart-compare .product','padding-right','15','','','.w-cart-compare'),(987587,'deals','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(987589,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-right','10','','','.w-image-maps'),(987590,'deals','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(987591,'deals','.b-form .payment-method .item','padding-right','0','','','.b-form'),(987592,'deals','.message.success','padding-right','0','','',''),(987593,'deals','.w-promo-code .holder','padding-right','20','5660','','.w-promo-code'),(987594,'deals','.w-cart-discount-coupon .btn','padding-right','25','','','.w-cart-discount-coupon'),(987595,'deals','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(987596,'deals','.w-checkout-shipping-choice span','padding-right','0','','','.w-checkout-shipping-choice'),(987597,'deals','.b-email .heading-qty','padding-right','10','','','.b-email'),(987598,'deals','.p-quick-order-index .bottom','padding-right','0','','','.p-quick-order-index'),(987599,'deals','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(987600,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-right','0','','','.b-select-suggest'),(987601,'deals','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(987602,'deals','.w-reviews .review','padding-right','10','','','.w-reviews'),(987603,'deals','.w-socials > li','padding-right','15','','','.w-socials'),(987606,'deals','.b-info-popup .info-popup div','padding-right','15','','','.b-info-popup'),(987607,'deals','.b-form .password-forgotten-link','padding-right','0','','','.b-form'),(987609,'deals','.w-cart-compare .atr-col','padding-right','30','','','.w-cart-compare'),(987610,'deals','.w-reviews .author','padding-right','10','','','.w-reviews'),(987611,'deals','.b-form .login-col-1','padding-right','20','','','.b-form'),(987612,'deals','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(987613,'deals','.w-promo-code .holder','padding-right','20','5660','','.w-promo-code'),(987614,'deals','.w-product-images-additional .images','padding-right','0','5660','','.w-product-images-additional'),(987615,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(987616,'deals','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-right','0','','','.w-multi-cart-actions'),(987617,'deals','.w-top-categories .item','padding-right','10','','','.w-top-categories'),(987618,'deals','.w-tabs > .block','padding-right','0','','','.w-tabs'),(987619,'deals','.w-tabs .accordion-heading','padding-right','8','5630','','.w-tabs'),(987620,'deals','.w-cart-cart-tabs .w-tabs > .block','padding-right','0','','','.w-cart-cart-tabs'),(987621,'deals','.w-tabs .tab-a','padding-right','15','','','.w-tabs'),(987622,'deals','.w-tabs .tab-li','padding-right','0','','','.w-tabs'),(987623,'deals','.w-socials > li','padding-right','15','','','.w-socials'),(987624,'deals','.b-autocomplete .ui-autocomplete li','padding-right','10','','','.b-autocomplete'),(987625,'deals','.b-bottom .popup-buttons','padding-right','15','','','.b-bottom'),(987626,'deals','.b-bottom .popup-content','padding-right','15','','','.b-bottom'),(987627,'deals','.w-product-images-additional .images','padding-right','0','5660','','.w-product-images-additional'),(987628,'deals','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(987629,'deals','.b-form .required-message','padding-right','3','','','.b-form'),(987630,'deals','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(987631,'deals','.btn-1','padding-right','25','','',''),(987632,'deals','.w-reviews-content .review','padding-right','20','','','.w-reviews-content'),(987633,'deals','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(987634,'deals','.btn-3','padding-right','25','','',''),(987635,'deals','.w-filters .filter-widget-horizontal .filter-box','padding-right','20','','','.w-filters'),(987636,'deals','.w-product-images-additional .images','padding-right','0','5660','','.w-product-images-additional'),(987637,'deals','.b-products-listing .products-listing .buyButton .btn','padding-right','10','','','.b-products-listing'),(987638,'deals','.b-bottom .popup-heading','padding-right','15','','','.b-bottom'),(987639,'deals','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(987640,'deals','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(987641,'deals','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(987642,'deals','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(987643,'deals','.b-email .totals-title','padding-right','10','','','.b-email'),(987644,'deals','.b-email .price','padding-right','10','','','.b-email'),(987645,'deals','.b-email .totals-value','padding-right','10','','','.b-email'),(987646,'deals','.b-email .heading-name','padding-right','10','','','.b-email'),(987647,'deals','.b-email .image','padding-right','10','','','.b-email'),(987648,'deals','.b-email .name','padding-right','10','','','.b-email'),(987649,'deals','.order-summary .price-row','padding-right','0','','','.order-summary'),(987650,'deals','.b-email .name','padding-right','10','','','.b-email'),(987651,'deals','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-right','0','','','.b-fancybox'),(987652,'deals','.w-socials > li','padding-right','15','','','.w-socials'),(987654,'deals','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(987655,'deals','.b-select-suggest .select2-drop-mask','padding-right','0','','','.b-select-suggest'),(987657,'deals','.w-quote .cart-box-link','padding-right','10','','','.w-quote'),(987658,'deals','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(987659,'deals','.b-email .price','padding-right','10','','','.b-email'),(987660,'deals','.b-fancybox .fancybox-title-float-wrap .child','padding-right','20','','','.b-fancybox'),(987661,'deals','.w-checkout-shipping-choice span','padding-right','10','5660','','.w-checkout-shipping-choice'),(987662,'deals','.w-top-categories .categories h2','padding-right','0','','','.w-top-categories'),(987663,'deals','.w-top-categories .image','padding-right','0','','','.w-top-categories'),(987664,'deals','.w-product-reviews .reviews-list .review','padding-right','10','','','.w-product-reviews'),(987665,'deals','.w-reviews-content .product-image','padding-right','10','','','.w-reviews-content'),(987666,'deals','.w-product-reviews .reviews-list .name','padding-right','10','','','.w-product-reviews'),(987667,'deals','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(987668,'deals','.b-email .name','padding-right','10','','','.b-email'),(987669,'deals','.b-fancybox .fancybox-prev span','padding-right','4','3','','.b-fancybox'),(987670,'deals','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(987671,'deals','.b-bottom .popup-simple','padding-right','20','','','.b-bottom'),(987672,'deals','.b-bottom .rfq-form','padding-right','20','','','.b-bottom'),(987673,'deals','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(987674,'deals','.b-email .heading-image','padding-right','10','','','.b-email'),(987675,'deals','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(987676,'deals','.b-email .model','padding-right','10','','','.b-email'),(987677,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(987678,'deals','.b-email .name','padding-right','10','','','.b-email'),(987679,'deals','.b-email .heading-price','padding-right','10','','','.b-email'),(987680,'deals','.b-email .heading-qty','padding-right','10','','','.b-email'),(987681,'deals','.b-email .image','padding-right','10','','','.b-email'),(987682,'deals','.b-email .price','padding-right','10','','','.b-email'),(987683,'deals','.b-email .heading-model','padding-right','10','','','.b-email'),(987684,'deals','.b-email .totals-title','padding-right','10','','','.b-email'),(987685,'deals','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(987686,'deals','.b-email .totals-value','padding-right','10','','','.b-email'),(987687,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(987688,'deals','.b-email .price','padding-right','10','','','.b-email'),(987689,'deals','.b-email .qty','padding-right','10','','','.b-email'),(987690,'deals','.b-email .heading-name','padding-right','10','','','.b-email'),(987691,'deals','.b-email .heading-image','padding-right','10','','','.b-email'),(987692,'deals','.w-checkout-shipping .sub-item','padding-right','0','','','.w-checkout-shipping'),(987693,'deals','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(987694,'deals','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(987695,'deals','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(987696,'deals','.w-promo-code .holder','padding-right','20','5660','','.w-promo-code'),(987697,'deals','.b-form .center-buttons','padding-right','0','','','.b-form'),(987698,'deals','.b-form .shipping-method .input','padding-right','10','','','.b-form'),(987699,'deals','.w-reviews .item','padding-right','0','','','.w-reviews'),(987700,'deals','.w-reviews .product-image','padding-right','20','','','.w-reviews'),(987701,'deals','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(987702,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(987703,'deals','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(987704,'deals','.b-select-suggest .select2-container .select2-choice','padding-right','0','','','.b-select-suggest'),(987705,'deals','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(987706,'deals','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(987707,'deals','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(987708,'deals','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(987709,'deals','.b-bottom .terms-info-popup .pop-up-content','padding-right','20','','','.b-bottom'),(987710,'deals','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','5639','','.w-menu-horizontal'),(987711,'deals','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(987712,'deals','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(987713,'deals','.b-upload-files .upload-files','padding-right','10','','','.b-upload-files'),(987714,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(987715,'deals','.w-login-block .returning','padding-right','40','','','.w-login-block'),(987716,'deals','.b-form .form-buttons','padding-right','0','','','.b-form'),(987717,'deals','.w-login-block .returning','padding-right','40','','','.w-login-block'),(987718,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(987720,'deals','.w-login-block .password-row','padding-right','0','','','.w-login-block'),(987721,'deals','.w-cart-compare .delete-cart','padding-right','10','','','.w-cart-compare'),(987722,'deals','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(987723,'deals','.b-email .name','padding-right','10','','','.b-email'),(987724,'deals','.b-email .totals-value','padding-right','10','','','.b-email'),(987725,'deals','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(987726,'deals','.b-email .qty','padding-right','10','','','.b-email'),(987727,'deals','.b-email .heading-name','padding-right','10','','','.b-email'),(987728,'deals','.b-email .heading-model','padding-right','10','','','.b-email'),(987729,'deals','.w-categories .item','padding-right','25','','','.w-categories'),(987730,'deals','.b-dropdown .dropdown .dropdown-menu','padding-right','10','','','.b-dropdown'),(987731,'deals','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(987732,'deals','.b-email .heading-image','padding-right','10','','','.b-email'),(987733,'deals','.b-email .heading-price','padding-right','10','','','.b-email'),(987734,'deals','.b-email .image','padding-right','10','','','.b-email'),(987735,'deals','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-right','20','','','.b-bottom'),(987736,'deals','.w-promo-code .holder','padding-right','20','5660','','.w-promo-code'),(987737,'deals','.b-compare .popupCompare .pop-up-content','padding-right','10','','','.b-compare'),(987738,'deals','.w-promotions .promo-cart-discount .master .item','padding-right','20','','','.w-promotions'),(987739,'deals','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(987740,'deals','.b-bottom .cart-options','padding-right','20','','','.b-bottom'),(987741,'deals','.b-bottom .alert-message','padding-right','20','','','.b-bottom'),(987742,'deals','.b-select-suggest .select2-results .select2-result-label','padding-right','7','','','.b-select-suggest'),(987743,'deals','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(987744,'deals','.b-email .totals-title','padding-right','10','','','.b-email'),(987747,'deals','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(987748,'deals','.b-email .heading-model','padding-right','10','','','.b-email'),(987749,'deals','.b-email .heading-qty','padding-right','10','','','.b-email'),(987750,'deals','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(987751,'deals','.b-email .model','padding-right','10','','','.b-email'),(987752,'deals','.b-email .heading-model','padding-right','10','','','.b-email'),(987753,'deals','.b-bottom .footerTitle','padding-right','0','5630','','.b-bottom'),(987754,'deals','.b-bottom .pop-up-close','padding-right','1','','','.b-bottom'),(987755,'deals','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(987756,'deals','.b-tracking-numbers .tracking-numbers td','padding-right','10','','','.b-tracking-numbers'),(987757,'deals','.w-cart-shipping-estimator .address-item','padding-right','10','','','.w-cart-shipping-estimator'),(987758,'deals','.w-cart-up-sell .w-list-type-1','padding-right','0','','','.w-cart-up-sell'),(987759,'deals','.w-cart-up-sell .w-list-type-1 .item','padding-right','21','','','.w-cart-up-sell'),(987760,'deals','.w-cart-up-sell .w-list-type-1 .item','padding-right','20','1','','.w-cart-up-sell'),(987761,'deals','.b-products-listing .products-listing .btn-buy','padding-right','10','','','.b-products-listing'),(987762,'deals','.b-upload-files .added-file','padding-right','0','','','.b-upload-files'),(987763,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(987764,'deals','.b-bottom .popup-box-wrap','padding-right','10','','','.b-bottom'),(987765,'deals','.b-bottom .pop-up-info','padding-right','20','','','.b-bottom'),(987766,'deals','.b-email .qty','padding-right','10','','','.b-email'),(987767,'deals','.b-email .name','padding-right','10','','','.b-email'),(987768,'deals','.b-email .heading-qty','padding-right','10','','','.b-email'),(987769,'deals','.b-fancybox .fancybox-error','padding-right','15','','','.b-fancybox'),(987770,'deals','.b-email .totals-title','padding-right','10','','','.b-email'),(987771,'deals','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(987772,'deals','.w-product-customers-activity .customers-activity','padding-right','20','','','.w-product-customers-activity'),(987773,'deals','.w-product-available-in-warehouses .warehouse-item','padding-right','20','','','.w-product-available-in-warehouses'),(987774,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(987775,'deals','.b-email .heading-name','padding-right','10','','','.b-email'),(987776,'deals','.b-email .heading-model','padding-right','10','','','.b-email'),(987777,'deals','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(987778,'deals','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(987779,'deals','.w-cart-compare .price-label','padding-right','10','','','.w-cart-compare'),(987780,'deals','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(987781,'deals','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(987782,'deals','.w-checkout-billing-address .edit-ab','padding-right','0','','','.w-checkout-billing-address'),(987783,'deals','.w-checkout-billing-address .addresses .address-item label','padding-right','10','','','.w-checkout-billing-address'),(987784,'deals','.w-promo-code .holder','padding-right','20','5660','','.w-promo-code'),(987785,'deals','.w-product-images-additional .images','padding-right','0','5660','','.w-product-images-additional'),(987786,'deals','.w-categories h2.name','padding-right','3','','','.w-categories'),(987787,'deals','.w-tabs .accordion-heading','padding-right','6','','','.w-tabs'),(987788,'deals','.w-socials > li','padding-right','15','','','.w-socials'),(987789,'deals','.w-product-images-additional .images','padding-right','0','5660','','.w-product-images-additional'),(987790,'deals','.w-promo-code .holder','padding-right','20','5660','','.w-promo-code'),(987791,'deals','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','padding-right','5','','','.b-switch'),(987792,'deals','.p-quick-order-index .all-scroll-div','padding-right','0','','','.p-quick-order-index'),(987793,'deals','.w-cart-compare .price-cell','padding-right','20','','','.w-cart-compare'),(987794,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(987795,'deals','.w-checkout-shipping-address .edit-ab','padding-right','0','','','.w-checkout-shipping-address'),(987796,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-right','5','','','.b-select-suggest'),(987797,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-right','5','','','.b-select-suggest'),(987798,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-right','0','','','.b-select-suggest'),(987799,'deals','.b-select-suggest .select2-locked','padding-right','5','','','.b-select-suggest'),(987800,'deals','.b-select-suggest .select2-container-multi .select2-choices','padding-right','0','','','.b-select-suggest'),(987801,'deals','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-right','10','','','.w-menu-horizontal'),(987802,'deals','.b-form .shipping-method .item + .item','padding-right','0','','','.b-form'),(987803,'deals','.w-checkout-shipping-address .addresses .address-item label','padding-right','10','','','.w-checkout-shipping-address'),(987804,'deals','.b-select-suggest .select2-search','padding-right','4','','','.b-select-suggest'),(987805,'deals','.b-select-suggest .select2-search input','padding-right','20','','','.b-select-suggest'),(987806,'deals','.b-select-suggest .select2-results','padding-right','4','','','.b-select-suggest'),(987807,'deals','.p-wedding-registry-search .search-list','padding-right','20','','','.p-wedding-registry-search'),(987811,'deals','.b-compare .compare-box-item','padding-right','10','','','.b-compare'),(987812,'deals','.w-cart-compare .product-label','padding-right','10','','','.w-cart-compare'),(987813,'deals','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(987814,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(987815,'deals','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(987816,'deals','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(987817,'deals','.w-cart-compare .dropdown li','padding-right','10','','','.w-cart-compare'),(987819,'deals','.w-login-block .returning','padding-right','40','','','.w-login-block'),(987820,'deals','.w-menu-big ul','padding-right','0','','','.w-menu-big'),(987821,'deals','.w-product-promotions select','padding-right','0','','','.w-product-promotions'),(987822,'deals','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(987823,'deals','.b-bottom .notify-form','padding-right','20','','','.b-bottom'),(987824,'deals','.w-account-addresses-list .addsess-suggestion-item','padding-right','20','','','.w-account-addresses-list'),(987825,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right','5','','','.b-data-table'),(987826,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right','5','','','.b-data-table'),(987827,'deals','.w-communication-post .communication-post-author','padding-right','0','','','.w-communication-post'),(987828,'deals','.b-products-listing .in-cart','padding-right','10','','','.b-products-listing'),(987829,'deals','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-right','5','','','.w-catalog-b2b-add-button'),(987830,'deals','.b-products-listing .promos-info .promo-name','padding-right','15','','','.b-products-listing'),(987831,'deals','.b-products-listing .promos-info .promo-item','padding-right','10','','','.b-products-listing'),(987832,'deals','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(987838,'deals','.b-compare .col-two label','padding-right','0','','','.b-compare'),(987839,'deals','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(987840,'deals','.w-checkout-gdpr .privacy-row','padding-right','0','','','.w-checkout-gdpr'),(987841,'deals','.w-checkout-gdpr .terms-login','padding-right','0','','','.w-checkout-gdpr'),(987842,'deals','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(987843,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(987844,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(987845,'deals','.b-form .middle-form','padding-right','0','','','.b-form'),(987846,'deals','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(987848,'deals','.w-checkout-billing-address .same-address','padding-right','10','','','.w-checkout-billing-address'),(987849,'deals','.w-reviews .heading-3','padding-right','0','','','.w-reviews'),(987850,'deals','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(987851,'deals','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(987852,'deals','.w-personal-gift-status-bar .timeline','padding-right','10','','','.w-personal-gift-status-bar'),(987853,'deals','.w-catalog-sorting .before','padding-right','5','','','.w-catalog-sorting'),(987854,'deals','.w-chat .w-chat-box','padding-right','12','','','.w-chat'),(987855,'deals','.b-compare .compare-head','padding-right','10','','','.b-compare'),(987856,'deals','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(987857,'deals','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(987858,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-right','0','','',''),(987859,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-right','0','','','.b-h-inline'),(987860,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-right','0','','','.w-communication-new-topic'),(987861,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-right','10','','','.w-communication-new-topic'),(987862,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-right','5','','','.w-communication-new-topic'),(987863,'deals','.w-communication-new-topic #communication_topic_form .middle-form','padding-right','0','','','.w-communication-new-topic'),(987864,'deals','.b-email .totals-title','padding-right','10','','','.b-email'),(987865,'deals','.b-email-editor .product-item','padding-right','10','','','.b-email-editor'),(987866,'deals','.b-email .heading-qty','padding-right','10','','','.b-email'),(987867,'deals','.b-email .model','padding-right','10','','','.b-email'),(987868,'deals','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-right','6','','','.b-compare'),(987869,'deals','.btn-2','padding-right','25','','',''),(987870,'deals','.b-compare .compare_pagination','padding-right','0','','','.b-compare'),(987871,'deals','.w-product-images-additional .images','padding-right','0','5660','','.w-product-images-additional'),(987872,'deals','.b-bottom .header-info','padding-right','20','','','.b-bottom'),(987873,'deals','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(987874,'deals','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-right','10','','','.order-summary'),(987877,'deals','.b-social-login .social-login-icons','padding-right','24','','','.b-social-login'),(987878,'deals','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-right','0','','','.b-fancybox'),(987879,'deals','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(987880,'deals','.products-quick-index .token-input-list','padding-right','0','','',''),(987881,'deals','.w-cart-compare .cart-cell','padding-right','7','','','.w-cart-compare'),(987882,'deals','.w-promo-code .holder','padding-right','20','','','.w-promo-code'),(987883,'deals','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(987884,'deals','.b-form .shipping-method .item','padding-right','0','','','.b-form'),(987885,'deals','.b-email .price','padding-right','10','','','.b-email'),(987886,'deals','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(987887,'deals','.b-email .heading-image','padding-right','10','','','.b-email'),(987888,'deals','.w-cart-listing .item .attributes strong','padding-right','10','','','.w-cart-listing'),(987889,'deals','.w-cart-listing .item .gift-wrap label','padding-right','10','','','.w-cart-listing'),(987890,'deals','.w-cart-listing .item > div','padding-right','10','','','.w-cart-listing'),(987891,'deals','.w-cart-listing .points-earn','padding-right','0','','','.w-cart-listing'),(987892,'deals','.w-cart-listing .points-redeem','padding-right','0','','','.w-cart-listing'),(987893,'deals','.w-cart-give-away .ga_img','padding-right','1','','','.w-cart-give-away'),(987894,'deals','.b-bottom .header-error','padding-right','20','','','.b-bottom'),(987895,'deals','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(987902,'deals','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(987903,'deals','.w-brands .brands-listing > div','padding-right','0.5','','','.w-brands'),(987904,'deals','.b-tracking-numbers .tracking-numbers th','padding-right','10','','','.b-tracking-numbers'),(987905,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-right','20','','','.b-tracking-numbers'),(987906,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','padding-right','10','','','.b-tracking-numbers'),(987907,'deals','.b-email-editor .special-price','padding-right','10','','','.b-email-editor'),(987908,'deals','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(987909,'deals','.b-compare .col-gender','padding-right','0','','','.b-compare'),(987910,'deals','.b-email .qty','padding-right','10','','','.b-email'),(987911,'deals','.b-email .heading-price','padding-right','10','','','.b-email'),(987912,'deals','.w-top-categories .item','padding-right','10','5630','','.w-top-categories'),(987913,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-right','0','','','.w-menu-style-2'),(987916,'deals','.p-sample-checkout-confirmation .buttons','padding-right','0','','','.p-sample-checkout-confirmation'),(987917,'deals','.w-socials > li','padding-right','15','','','.w-socials'),(987918,'deals','.w-login-block .returning','padding-right','40','','','.w-login-block'),(987920,'deals','.w-filters .fsl_handle','padding-right','0','','','.w-filters'),(987921,'deals','.w-filters .head-filter-widget','padding-right','10','5639','','.w-filters'),(987922,'deals','.w-filters .ui-slider-range','padding-right','0','','','.w-filters'),(987923,'deals','.b-email-editor .price','padding-right','10','','','.b-email-editor'),(987924,'deals','.w-filters .head-filter-widget','padding-right','0','','','.w-filters'),(987925,'deals','.w-filters .handle_tit','padding-right','5','','','.w-filters'),(987926,'deals','.b-autocomplete .ui-autocomplete','padding-right','2','','','.b-autocomplete'),(987927,'deals','.order-summary .heading-2','padding-right','0','','','.order-summary'),(987928,'deals','.b-compare .column_wrapper','padding-right','10','','','.b-compare'),(987929,'deals','.b-email .totals-value','padding-right','10','','','.b-email'),(987930,'deals','.b-email-editor .old-price','padding-right','10','','','.b-email-editor'),(987931,'deals','.b-email .model','padding-right','10','','','.b-email'),(987932,'deals','.b-email .heading-name','padding-right','10','','','.b-email'),(987933,'deals','.b-social-login .social-login-text-1','padding-right','15','','','.b-social-login'),(987934,'deals','.w-reviews-content .author','padding-right','20','','','.w-reviews-content'),(987935,'deals','.w-login-block .returning','padding-right','40','','','.w-login-block'),(987936,'deals','.b-data-table table.dataTable tbody td','padding-right','20','','','.b-data-table'),(987937,'deals','.b-data-table table.dataTable thead td','padding-right','20','','','.b-data-table'),(987940,'deals','.w-promo-code .promo-text-2','padding-right','0','','','.w-promo-code'),(987941,'deals','.w-checkout-create-account .create-account','padding-right','0','','','.w-checkout-create-account'),(987942,'deals','.b-email .totals-title','padding-right','10','','','.b-email'),(987943,'deals','.b-email .totals-value','padding-right','10','','','.b-email'),(987944,'deals','.b-email .qty','padding-right','10','','','.b-email'),(987945,'deals','.btn','padding-right','25','','',''),(987946,'deals','.w-brands .brands-listing','padding-right','0','','','.w-brands'),(987947,'deals','.b-product-images .media-popup .mp-content','padding-right','5','','','.b-product-images'),(987948,'deals','.b-product-images .media-popup .mp-small-images .item','padding-right','10','','','.b-product-images'),(987949,'deals','.b-product-images .media-popup .slick-dots','padding-right','0','','','.b-product-images'),(987950,'deals','.b-product-images .media-popup .slick-dots li','padding-right','0','','','.b-product-images'),(987951,'deals','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-right','0','','','.b-menu-style'),(987952,'deals','.b-personal-catalog-popup #personal_catalog_popup','padding-right','0','','','.b-personal-catalog-popup'),(987953,'deals','.b-trade-approval .steps-bar li a','padding-right','0','','','.b-trade-approval'),(987954,'deals','.b-trade-approval .middle-form','padding-right','0','','','.b-trade-approval'),(987955,'deals','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-right','5','','','.b-trade-approval'),(987956,'deals','.b-trade-approval .steps-bar','padding-right','0','','','.b-trade-approval'),(987957,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-right','10','','','.b-trade-approval'),(987958,'deals','.b-trade-approval .center-buttons','padding-right','0','','','.b-trade-approval'),(987959,'deals','.w-account-personal-catalog .list-switcher','padding-right','0','','','.w-account-personal-catalog'),(987960,'deals','.w-account-personal-catalog .list-switcher a','padding-right','6','','','.w-account-personal-catalog'),(987961,'deals','.w-account-subscription .subscription-variant','padding-right','10','','','.w-account-subscription'),(987962,'deals','.w-catalog-additional-images li','padding-right','10','','','.w-catalog-additional-images'),(987963,'deals','.w-catalog-additional-images ul','padding-right','0','','','.w-catalog-additional-images'),(987964,'deals','.w-catalog-compare td','padding-right','20','','','.w-catalog-compare'),(987965,'deals','.w-catalog-compare .image','padding-right','10','','','.w-catalog-compare'),(987966,'deals','.w-catalog-compare .cross-box .different-all > div','padding-right','5','2','','.w-catalog-compare'),(987967,'deals','.w-catalog-compare .cross-box .different-all > div','padding-right','5','','','.w-catalog-compare'),(987968,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-right','0','','','.w-catalog-compare'),(987969,'deals','.w-delivery-day .left-count','padding-right','5','','','.w-delivery-day'),(987970,'deals','.w-top-text .top-text','padding-right','10','','','.w-top-text'),(987971,'deals','.w-product-images .additional-horizontal .item','padding-right','10','','','.w-product-images'),(987972,'deals','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-right','10','','','.b-cookie-notice'),(987973,'deals','.lowestPricedBox .w-banner .single_banner','padding-right','15','','','.lowestPricedBox'),(987974,'deals','.lowestPricedBox .w-banner .banner','padding-right','0','','','.lowestPricedBox'),(987975,'deals','.shopByCollectionBox .w-banner .single_banner','padding-right','15','','','.shopByCollectionBox'),(987976,'deals','.b-slick .slick-list','padding-right','0','','','.b-slick'),(987977,'deals','.b-slick .slick-vertical button.slick-next','padding-right','0','3','','.b-slick'),(987978,'deals','.b-slick .slick-vertical button.slick-prev','padding-right','0','3','','.b-slick'),(987979,'deals','.b-slick button.slick-prev','padding-right','4','3','','.b-slick'),(987980,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','padding-right','0','','','.b-slick'),(987981,'deals','.header-middle ','padding-right','50','5639','','.header-middle'),(987982,'deals','.main-width, .header > .type-1 > .block, .footer > .type-1 > .block, .main-content > .type-1 > .block, .main-content > div > .type-1 > .block','padding-right','15','','',''),(987983,'deals','.w-cart-listing .headings .head','padding-right','0','','','.w-cart-listing'),(987984,'deals','.w-cart-listing .item div.price','padding-right','0','','','.w-cart-listing'),(987985,'deals','.LeftCategories .w-menu-simple ul','padding-right','0','','','.LeftCategories'),(987986,'deals','.LeftCategories .w-menu-simple ul li a','padding-right','25','','','.LeftCategories'),(987987,'deals','.b-products-listing .products-listing.list-productlisting .item','padding-right','15','','','.b-products-listing'),(987988,'deals','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-right','0','','','.b-products-listing'),(987989,'deals','.b-products-listing .products-listing.list-productlisting .item-content','padding-right','25','','','.b-products-listing'),(987990,'deals','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-right','25','','','.b-products-listing'),(987991,'deals','.b-products-listing .products-listing.list-rows .item-nav > div','padding-right','5','','','.b-products-listing'),(987992,'deals','.w-breadcrumb .breadcrumb-li','padding-right','10','','','.w-breadcrumb'),(987993,'deals','.w-breadcrumb .breadcrumb-name','padding-right','10','','','.w-breadcrumb'),(987994,'deals','.w-breadcrumb .breadcrumb-name-item','padding-right','10','','','.w-breadcrumb'),(987995,'deals','.w-breadcrumb .breadcrumb-ul','padding-right','0','','','.w-breadcrumb'),(987996,'deals','.w-quote .buttons','padding-right','15','','','.w-quote'),(987997,'deals','.w-quote .buttons .btn','padding-right','15','','','.w-quote'),(987998,'deals','.w-quote .cart-content','padding-right','15','','','.w-quote'),(987999,'deals','.w-quote .cart-total','padding-right','0','','','.w-quote'),(988000,'deals','.w-quote .multicart .cart-content','padding-right','0','','','.w-quote'),(988001,'deals','.w-quote .multicart .item','padding-right','15','','','.w-quote'),(988002,'deals','.w-quote .multicart .name','padding-right','10','','','.w-quote'),(988003,'deals','.w-quote .no-text','padding-right','20','','','.w-quote'),(988004,'deals','.w-quote .qty','padding-right','5','4','','.w-quote'),(988005,'deals','.w-quote a.item','padding-right','0','','','.w-quote'),(988006,'deals','.w-social-links a','padding-right','8','','','.w-social-links'),(988007,'deals','.w-product-images .additional-vertical .additional-images','padding-right','0','','','.w-product-images'),(988008,'deals','.w-product-personal-catalog-button .btn','padding-right','25','','','.w-product-personal-catalog-button'),(988009,'deals','.b-quantity .qty-box input','padding-right','3','','','.b-quantity'),(988010,'deals','.w-product-sale-ends .left-count','padding-right','5','','','.w-product-sale-ends'),(988011,'deals','.w-product-sale-ends .left-count-days','padding-right','0','','','.w-product-sale-ends'),(988012,'deals','.w-product-sale-ends .left-count-hours','padding-right','0','','','.w-product-sale-ends'),(988013,'deals','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-right','0','','','.w-product-quantity'),(988014,'deals','.w-product-quantity .qty_packs .qty-input','padding-right','0','','','.w-product-quantity'),(988015,'deals','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-right','0','','','.w-product-quantity'),(988016,'deals','.w-product-quantity .total-qty','padding-right','0','','','.w-product-quantity'),(988017,'deals','.w-product-quantity .total-qty .qty_price','padding-right','0','','','.w-product-quantity'),(988018,'deals','.w-compare .compare-list-holder','padding-right','250','','','.w-compare'),(988019,'deals','.w-compare .compare-list-buttons','padding-right','10','','','.w-compare'),(988020,'deals','.w-compare .item-holder','padding-right','10','','','.w-compare'),(988021,'deals','.w-compare .compare-list-products','padding-right','30','','','.w-compare'),(988022,'deals','.w-files-catalog-widgets-files-catalog .name','padding-right','10','','','.w-files-catalog-widgets-files-catalog'),(988023,'deals','.w-sample .buttons','padding-right','15','','','.w-sample'),(988024,'deals','.w-sample .buttons .btn','padding-right','15','','','.w-sample'),(988025,'deals','.w-sample .cart-box-link','padding-right','10','','','.w-sample'),(988026,'deals','.w-sample .cart-content','padding-right','15','','','.w-sample'),(988027,'deals','.w-sample .cart-total','padding-right','0','','','.w-sample'),(988028,'deals','.w-sample .multicart .cart-content','padding-right','0','','','.w-sample'),(988029,'deals','.w-sample .multicart .item','padding-right','15','','','.w-sample'),(988030,'deals','.w-sample .multicart .name','padding-right','10','','','.w-sample'),(988031,'deals','.w-sample .no-text','padding-right','20','','','.w-sample'),(988032,'deals','.w-sample .qty','padding-right','5','4','','.w-sample'),(988033,'deals','.w-sample a.item','padding-right','0','','','.w-sample'),(988034,'deals','.w-cart-listing .item > div.points','padding-right','0','','','.w-cart-listing'),(988035,'deals','.w-filters-simple .integrate-price-holder','padding-right','0','','','.w-filters-simple'),(988036,'deals','.w-product-video .item','padding-right','10','','','.w-product-video'),(988037,'deals','.shipping-ico .heading-3','padding-right','0','','','.shipping-ico'),(988038,'deals','.w-cart-order-reference .btn','padding-right','25','','','.w-cart-order-reference'),(988039,'deals','.w-cart-gift-certificate .btn','padding-right','25','','','.w-cart-gift-certificate'),(988040,'deals','.w-cart-shipping-estimator .btn','padding-right','25','','','.w-cart-shipping-estimator'),(988041,'deals','.w-product-bundle .attributes-item','padding-right','2','','','.w-product-bundle'),(988042,'deals','.w-product-bundle .bundle_image','padding-right','10','','','.w-product-bundle'),(988043,'deals','.w-product-bundle .bundle_item','padding-right','10','','','.w-product-bundle'),(988044,'deals','.w-product-in-bundles .attributes-item','padding-right','2','','','.w-product-in-bundles'),(988045,'deals','.w-product-in-bundles .bundle_image','padding-right','10','','','.w-product-in-bundles'),(988046,'deals','.w-product-in-bundles .bundle_item','padding-right','10','','','.w-product-in-bundles'),(988047,'deals','.w-cart-listing .item > div.actions','padding-right','0','5630','','.w-cart-listing'),(988048,'deals','.w-cart-listing .item div.price','padding-right','10','5639','','.w-cart-listing'),(988050,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-right','0','','','.b-products-listing'),(988051,'deals','.b-pagination .pagination .next-pages','padding-right','5','','','.b-pagination'),(988052,'deals','.b-pagination .pagination .page-number','padding-right','5','','','.b-pagination'),(988053,'deals','.b-pagination .pagination .prev-pages','padding-right','5','','','.b-pagination'),(988054,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','padding-right','5','','','.b-pagination'),(988055,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','padding-right','5','','','.b-pagination'),(988056,'deals','.b-pagination .pagination span','padding-right','5','2','','.b-pagination'),(988057,'deals','.b-pagination ul.pagination','padding-right','0','','','.b-pagination'),(988058,'deals','.w-product-properties-filters-widgets-chosen-filters .item','padding-right','6','','','.w-product-properties-filters-widgets-chosen-filters'),(988059,'deals','.main-content > div > .block > .type-1 > .block, .main-content > form > div > .block > .type-1 > .block , .main-content > div > form > .block > .type-1 > .block, .checkout > .type-1 > .block','padding-right','15','','',''),(988060,'deals','.w-tabs .tab-li:last-of-type','padding-right','0','','','.w-tabs'),(988061,'deals','.w-cart-listing .no-price .headings .qty','padding-right','10','','','.w-cart-listing'),(988062,'deals','.p-quote-checkout-index .datepicker-inline','padding-right','0','','','.p-quote-checkout-index'),(988063,'deals','.p-sample-checkout-index .datepicker-inline','padding-right','0','','','.p-sample-checkout-index'),(988066,'deals','.w-quote-products .cart-listing .qty','padding-right','10','','','.w-quote-products'),(988067,'deals','.w-product-multi-inventory .radio-attributes .option-item','padding-right','15','','','.w-product-multi-inventory'),(988068,'deals','.w-product-multi-inventory .radio-attributes > label','padding-right','10','','','.w-product-multi-inventory'),(988069,'deals','.b-products-listing .products-listing .radio-attributes .option','padding-right','15','','','.b-products-listing'),(988070,'deals','.b-products-listing .products-listing .radio-attributes > label','padding-right','10','','','.b-products-listing'),(988071,'deals','.w-product-collection .item','padding-right','10','','','.w-product-collection'),(988072,'deals','.w-product-collection .right-area .btn','padding-right','25','','','.w-product-collection'),(988073,'deals','.w-product-attributes .radio-attributes .option-item','padding-right','15','','','.w-product-attributes'),(988074,'deals','.w-product-attributes .radio-attributes > label','padding-right','10','','','.w-product-attributes'),(988075,'deals','.w-product-properties .property-ul','padding-right','0','','','.w-product-properties'),(988076,'deals','.w-product-properties .properties-table','padding-right','0','','','.w-product-properties'),(988077,'deals','.w-product-properties li','padding-right','5','','','.w-product-properties'),(988078,'deals','.w-product-groups .radioBox','padding-right','0','','','.w-product-groups'),(988079,'deals','.w-product-groups .radioBox label','padding-right','20','','','.w-product-groups'),(988080,'deals','.w-product-groups .radioBox label .containerBlock','padding-right','10','','','.w-product-groups'),(988081,'deals','.w-product-groups .radioBox label .containerBlock','padding-right','10','5660','','.w-product-groups'),(988082,'deals','.b-products-listing .mix-attributes .attribute-qty-block','padding-right','10','','','.b-products-listing'),(988083,'deals','.b-products-listing .products-listing .attribute-qty-block','padding-right','5','','','.b-products-listing'),(988084,'deals','.blogsidebar','padding-right','0','5639','',''),(988085,'deals','.w-product-custom-bundle .item','padding-right','10','','','.w-product-custom-bundle'),(988086,'deals','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-right','25','','','.w-product-custom-bundle'),(988087,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list'),(988088,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-right','10','','','.w-catalog-pages-category-pages-last-list'),(988089,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list-block'),(988090,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-right','10','','','.w-catalog-pages-category-pages-last-list-block'),(988091,'deals','.w-delivery-location-location-list ul','padding-right','0','','','.w-delivery-location-location-list'),(988092,'deals','.w-delivery-location-location-description .deliveryDesc','padding-right','0','','','.w-delivery-location-location-description'),(988093,'deals','.w-delivery-location-location-list .deliveryListParrent a','padding-right','25','','','.w-delivery-location-location-list'),(988094,'deals','.w-delivery-location-location-list .deliveryList li a','padding-right','15','','','.w-delivery-location-location-list'),(988095,'deals','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding-right','2','','','.w-delivery-location-featured-list'),(988096,'deals','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding-right','0','5660','','.w-delivery-location-featured-list'),(988097,'deals','.w-sale-category .holder-1','padding-right','20','','','.w-sale-category'),(988098,'deals','.w-sale-category .holder-2','padding-right','20','','','.w-sale-category'),(988099,'deals','.w-sale-category .left-count','padding-right','5','','','.w-sale-category'),(988100,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(988101,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-right','10','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(988102,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(988103,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-right','10','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(988104,'deals','.w-product-properties-icons .property-image','padding-right','10','','','.w-product-properties-icons'),(988105,'deals','.w-product-properties-icons .hover-box-content','padding-right','10','','','.w-product-properties-icons'),(988106,'deals','.w-delivery-location-product-categories .item.category-link','padding-right','15','','','.w-delivery-location-product-categories'),(988107,'deals','.w-delivery-location-product-categories .item.category-link','padding-right','10','5639','','.w-delivery-location-product-categories'),(988108,'deals','.w-delivery-location-product-categories .item.category-link','padding-right','0','5660','','.w-delivery-location-product-categories'),(988109,'deals','.w-delivery-location-product-categories .name','padding-right','15','','','.w-delivery-location-product-categories'),(988110,'deals','.delivery-options-popup','padding-right','20','','',''),(988111,'deals','.w-product-bonus-points .bonus-points-cost','padding-right','15','','','.w-product-bonus-points'),(988112,'deals','.w-product-designer-designer .grnamebox .title-sortable','padding-right','15','','','.w-product-designer-designer'),(988113,'deals','.w-product-designer-designer .prodDesignerType label','padding-right','10','','','.w-product-designer-designer'),(988114,'deals','.w-press-reviews-widgets-press-reviews ','padding-right','30','','','.w-press-reviews-widgets-press-reviews'),(988115,'deals','.w-press-reviews-widgets-press-reviews .author','padding-right','25','','','.w-press-reviews-widgets-press-reviews'),(988116,'deals','.w-press-reviews-widgets-press-reviews .image','padding-right','10','','','.w-press-reviews-widgets-press-reviews'),(988117,'deals','.w-press-reviews-widgets-press-reviews .item','padding-right','20','','','.w-press-reviews-widgets-press-reviews'),(988118,'deals','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-right','30','','','.w-press-reviews-widgets-press-reviews'),(988119,'deals','.w-press-reviews-widgets-press-reviews .review','padding-right','25','','','.w-press-reviews-widgets-press-reviews'),(988120,'deals','.w-press-reviews-widgets-press-reviews ','padding-right','15','5630','','.w-press-reviews-widgets-press-reviews'),(988121,'deals','.w-press-reviews-widgets-press-reviews .item','padding-right','0','5630','','.w-press-reviews-widgets-press-reviews'),(988122,'deals','.w-press-reviews-widgets-press-reviews .review','padding-right','0','5630','','.w-press-reviews-widgets-press-reviews'),(988123,'deals','.w-press-reviews-widgets-press-reviews-list .item','padding-right','25','','','.w-press-reviews-widgets-press-reviews-list'),(988124,'deals','.w-press-reviews-widgets-press-reviews-list .short-description','padding-right','0','','','.w-press-reviews-widgets-press-reviews-list'),(988125,'deals','.b-products-listing .productGroup label a','padding-right','16','','','.b-products-listing'),(988126,'deals','.w-support-system-filter ','padding-right','0','','','.w-support-system-filter'),(988127,'deals','.w-support-system-filter .filter_cats','padding-right','0','','','.w-support-system-filter'),(988128,'deals','.w-support-system-listing .support-head','padding-right','13','','','.w-support-system-listing'),(988129,'deals','.w-communication-post .btn.refresh','padding-right','0','','','.w-communication-post'),(988130,'deals','.w-rma-returns-history .btn','padding-right','10','','','.w-rma-returns-history'),(988131,'deals','.w-rma-returns-history .column','padding-right','3','','','.w-rma-returns-history'),(988132,'deals','.w-rma-returns-history .column .title','padding-right','10','','','.w-rma-returns-history'),(988133,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','padding-right','5','','','.w-rma-returns-history'),(988134,'deals','.w-rma-returns-history .topRow','padding-right','0','','','.w-rma-returns-history'),(988135,'deals','.w-rma-returns-history .column:last-child .title','padding-right','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(988136,'deals','.w-product-designer-designer .productDesignerBox ul','padding-right','0','','','.w-product-designer-designer'),(988137,'deals','.w-product-configurator .pc-item','padding-right','0','','','.w-product-configurator'),(988138,'deals','.w-product-configurator .pc_stock','padding-right','10','','','.w-product-configurator'),(988139,'deals','.w-product-configurator .pc_item','padding-right','0','5639','','.w-product-configurator'),(988140,'deals','.w-product-configurator .pc_attr','padding-right','0','5630','','.w-product-configurator'),(988141,'deals','.b-products-listing .promos-info .promo-name-span','padding-right','40','','','.b-products-listing'),(988142,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-right','0','','','.w-catalog-pages-category-pages-list'),(988143,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-right','10','','','.w-catalog-pages-category-pages-list'),(988144,'deals','.w-predefined-promotion .heading','padding-right','10','','','.w-predefined-promotion'),(988145,'deals','.w-predefined-promotion .master','padding-right','15','','','.w-predefined-promotion'),(988146,'deals','.w-predefined-promotion .nextdiscount .content > div','padding-right','10','','','.w-predefined-promotion'),(988147,'deals','.w-predefined-promotion .nextdiscount .item-holder .image','padding-right','10','','','.w-predefined-promotion'),(988148,'deals','.w-predefined-promotion .nextdiscount .promo-for-each','padding-right','20','','','.w-predefined-promotion'),(988149,'deals','.w-predefined-promotion .prom-multi-discount .promo-product','padding-right','20','','','.w-predefined-promotion'),(988150,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','padding-right','20','','','.w-predefined-promotion'),(988151,'deals','.w-predefined-promotion .promo-cart-discount .master .item','padding-right','20','','','.w-predefined-promotion'),(988152,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-right','20','','','.w-predefined-promotion'),(988153,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-right','20','','','.w-predefined-promotion'),(988154,'deals','.w-predefined-promotion .promo-cart-discount .slave .item','padding-right','20','','','.w-predefined-promotion'),(988155,'deals','.w-predefined-promotion .promo-date > div','padding-right','50','','','.w-predefined-promotion'),(988156,'deals','.w-predefined-promotion .promo-item','padding-right','40','','','.w-predefined-promotion'),(988157,'deals','.w-predefined-promotion .promo-salemaker .discount','padding-right','20','','','.w-predefined-promotion'),(988158,'deals','.w-predefined-promotion .promo-salemaker .item','padding-right','20','','','.w-predefined-promotion'),(988159,'deals','.w-predefined-promotion .promo-salemaker .promo-categories','padding-right','12','','','.w-predefined-promotion'),(988160,'deals','.w-supplier-purchase-supplier-products .item','padding-right','20','','','.w-supplier-purchase-supplier-products'),(988161,'deals','.headerWrap ','padding-right','0','','','.headerWrap'),(988162,'deals','.headerWrap >div.block, .headerWrap .headerInside >div.block','padding-right','20','','','.headerWrap'),(988164,'deals','.parallaxWrap .w-info-page','padding-right','0','','','.parallaxWrap'),(988165,'deals','.bannersWrap .text','padding-right','50','','','.bannersWrap'),(988166,'deals','.bannersWrap .leftBanner','padding-right','3','','','.bannersWrap'),(988167,'deals','.headerWrap .menu-style[data-style=\"1\"] li.back-button','padding-right','20','','','.headerWrap'),(988168,'deals','.w-categories .categories h2','padding-right','0','','','.w-categories'),(988169,'deals','.w-categories .item','padding-right','10','5630','','.w-categories'),(988170,'deals','.filterLine .before','padding-right','10','','','.filterLine'),(988171,'deals','.filterLine .choose-filters li .btn-clear','padding-right','10','','','.filterLine'),(988172,'deals','.filterLine .filter-widget-horizontal .content-filter-widget','padding-right','200','','','.filterLine'),(988173,'deals','.filterLine .filter-widget-horizontal .content-filter-widget.openBoxes','padding-right','0','','','.filterLine'),(988174,'deals','.w-filters .filter-widget-horizontal .filter-box-content','padding-right','15','','','.w-filters'),(988175,'deals','.w-filters .filter-widget-horizontal .filter-box-head','padding-right','7','','','.w-filters'),(988176,'deals','.w-filters .choose-filters > li > *','padding-right','10','','','.w-filters'),(988177,'deals','.w-filters .choose-filters > li','padding-right','10','','','.w-filters'),(988178,'deals','.b-products-listing .products-listing .bonus-points-cost','padding-right','15','','','.b-products-listing'),(988179,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span','padding-right','10','','','.w-product-quantity-discounts'),(988180,'deals','.b-quantity .qty-box input[type=\'text\']','padding-right','3','','','.b-quantity'),(988181,'deals','.w-product-groups .property-category-heading','padding-right','21','','','.w-product-groups'),(988182,'deals','.w-product-groups .property-category-heading + .property-category-content','padding-right','20','','','.w-product-groups'),(988183,'deals','.w-product-name h1','padding-right','0','','','.w-product-name'),(988184,'deals','.w-product-buttons button.add-to-cart','padding-right','25','','','.w-product-buttons'),(988185,'deals','.messageBox .info','padding-right','0','','',''),(988186,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','padding-right','25','','','.b-products-listing'),(988187,'deals','.savings-ico .heading-3','padding-right','0','','','.savings-ico'),(988188,'deals','.w-support-system-listing .tp-head','padding-right','10','','','.w-support-system-listing'),(988189,'deals','.w-support-system-listing .support-item-body-content .tp-head','padding-right','0','','','.w-support-system-listing'),(988190,'deals','.order-summary > div','padding-right','20','','','.order-summary'),(988191,'deals','.w-delayed-despatch-checkout .btn','padding-right','25','','','.w-delayed-despatch-checkout'),(988192,'deals','.w-coupons-and-vauchers-checkout .btn','padding-right','25','','','.w-coupons-and-vauchers-checkout'),(988193,'deals','.b-table-list .table-list td','padding-right','10','','','.b-table-list'),(988194,'deals','.b-table-list .table-list th','padding-right','10','','','.b-table-list'),(988195,'deals','.b-table .table .headings td','padding-right','10','','','.b-table'),(988196,'deals','.b-table .table td','padding-right','15','','','.b-table'),(988197,'deals','.headerWrap .headerInside >div.block','padding-right','0','5639','','.headerWrap'),(988198,'deals','.homeBanner .carousel .bottom-center > span','padding-right','50','3','','.homeBanner'),(988199,'deals','.homeBanner .carousel .bottom-center > span','padding-right','10','5644','','.homeBanner'),(988200,'deals','.homeBanner .carousel .bottom-center > span','padding-right','10','5660','','.homeBanner'),(988201,'deals','.homeBanner .carousel .bottom-center > span','padding-right','30','5660,3','','.homeBanner'),(988203,'deals','.bannersWrap .leftBanner','padding-right','0','5630','','.bannersWrap'),(988204,'deals','.bannersWrap .text','padding-right','30','5639','','.bannersWrap'),(988205,'deals','.w-filters .filter-widget-horizontal .head-filter-widget','padding-right','10','5639','','.w-filters'),(988206,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','padding-right','0','5639','','.w-filters'),(988207,'deals','.filterLine .filter-widget-horizontal .content-filter-widget','padding-right','0','5639','','.filterLine'),(988208,'deals','.w-filters .filter-widget-horizontal .filter-box','padding-right','10','5639','','.w-filters'),(988209,'deals','.w-filters .filter_buttons','padding-right','10','','','.w-filters'),(988210,'deals','.b-products-listing .products-listing.list-productlisting .radio-attributes > label','padding-right','0','','','.b-products-listing'),(988211,'deals','.w-cart-listing .item > div.points','padding-right','10','5639','','.w-cart-listing'),(988212,'deals','.b-info .info','padding-right','0','','','.b-info'),(988213,'deals','.b-info .info li','padding-right','0','','','.b-info'),(988214,'deals','.b-info .info ul','padding-right','0','','','.b-info'),(988215,'deals','.closeable-heading','padding-right','25','','',''),(988216,'deals','.payer > .type-1 > .block','padding-right','15','','',''),(988217,'deals','.trade_form > .type-1 > .block','padding-right','15','','',''),(988218,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','padding-right','20','5630','','.headerWrap'),(988219,'deals','.b-personal-catalog-popup button.btn.btn-save-new-list','padding-right','25','','','.b-personal-catalog-popup'),(988220,'deals','.w-account-personal-catalog .list-row-action li','padding-right','10','','','.w-account-personal-catalog'),(988221,'deals','.w-account-personal-catalog .list-row-action ul','padding-right','20','','','.w-account-personal-catalog'),(988222,'deals','.w-account-personal-catalog .price','padding-right','10','','','.w-account-personal-catalog'),(988223,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li','padding-right','10','','','.preFooter'),(988224,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li','padding-right','0','5630','','.preFooter'),(988226,'deals','.w-multi-cart-save-cart .btn','padding-right','15','5660','','.w-multi-cart-save-cart'),(988227,'deals','.w-product-wishlist-button .btn','padding-right','0','','','.w-product-wishlist-button'),(988228,'deals','.w-compare .compare-list-holder','padding-right','0','5639','','.w-compare'),(988229,'deals','.w-catalog-compare .compare-list','padding-right','0','','','.w-catalog-compare'),(988230,'deals','.headerWrap .w-logo .logo','padding-right','20','','','.headerWrap'),(988231,'deals','.homeBanner .banner-item .banner-text','padding-right','0','','','.homeBanner'),(988232,'deals','.homeBanner .banner-item.text-bottom-right .banner-text-holder','padding-right','20','','','.homeBanner'),(988233,'deals','.homeBanner .banner-item.text-middle-right .banner-text-holder','padding-right','20','','','.homeBanner'),(988234,'deals','.homeBanner .banner-item.text-top-right .banner-text-holder','padding-right','20','','','.homeBanner'),(988235,'deals','.homeBanner .text-bottom-center .banner-text-holder','padding-right','50','3','','.homeBanner'),(988236,'deals','.homeBanner .text-bottom-left .banner-text-holder','padding-right','50','3','','.homeBanner'),(988237,'deals','.homeBanner .text-bottom-right .banner-text-holder','padding-right','50','3','','.homeBanner'),(988238,'deals','.homeBanner .banner-item .banner-text-holder','padding-right','10','5644','','.homeBanner'),(988239,'deals','.homeBanner .banner-item .banner-text-holder','padding-right','10','5660','','.homeBanner'),(988240,'deals','.homeBanner .text-bottom-center .banner-text-holder','padding-right','30','5660,3','','.homeBanner'),(988241,'deals','.homeBanner .text-bottom-left .banner-text-holder','padding-right','30','5660,3','','.homeBanner'),(988242,'deals','.homeBanner .text-bottom-right .banner-text-holder','padding-right','30','5660,3','','.homeBanner'),(988243,'deals','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','padding-right','0','','','.w-promotions-widgets-promotion-icons-desc'),(988244,'deals','.order-summary .w-cart-listing .item > div ~ div','padding-right','0','','','.order-summary'),(988245,'deals','.w-cart-discount-coupon .discount-box','padding-right','10','','','.w-cart-discount-coupon'),(988246,'deals','.main-content','padding-right','0','','',''),(988247,'deals','.w-promotions-widgets-promotions select','padding-right','0','','','.w-promotions-widgets-promotions'),(988271,'deals','.account-address-book .address_book','padding-right','0','','','.account-address-book'),(988272,'deals','.account-address-book .address_book h1','padding-right','0','','','.account-address-book'),(988273,'deals','.account-address-book .address_book h2','padding-right','10','','','.account-address-book'),(988274,'deals','.account-address-book .address_book, .account-address-book .account_history_info','padding-right','0','','','.account-address-book'),(988275,'deals','.account-address-book .btn-edit','padding-right','0','4','','.account-address-book'),(988276,'deals','.account-address-book .buttonBox','padding-right','0','','','.account-address-book'),(988277,'deals','.account-address-book .rightMes ul','padding-right','0','','','.account-address-book'),(988278,'deals','.account-address-book .topButtons','padding-right','0','','','.account-address-book'),(988292,'deals','.account-order-pay .contentColumn','padding-right','10','','','.account-order-pay'),(988293,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-right','0','','','.account-order-pay'),(988294,'deals','.account-order-pay .history_attr div strong, .account-order-pay .history_attr div span','padding-right','10','','','.account-order-pay'),(988295,'deals','.account-order-pay .history_info > div + div','padding-right','0','','','.account-order-pay'),(988296,'deals','.account-order-pay .history_info > div','padding-right','0','5639','','.account-order-pay'),(988297,'deals','.account-order-pay .history_info > div + div','padding-right','0','5639','','.account-order-pay'),(988298,'deals','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-right','10','','','.account-samples'),(988299,'deals','.account-samples .orders-table th','padding-right','10','','','.account-samples'),(988300,'deals','.account-samples .order_history_table th','padding-right','10','','','.account-samples'),(988301,'deals','.account-samples .view_link','padding-right','20','','','.account-samples'),(988302,'deals','.account-samples .orders-table .td-alignright','padding-right','10','5639','','.account-samples'),(988303,'deals','.account-samples .orders-table td','padding-right','10','5639','','.account-samples'),(988304,'deals','.account-sample-info .contentColumn','padding-right','10','','','.account-sample-info'),(988305,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-right','0','','','.account-sample-info'),(988306,'deals','.account-sample-info .history_attr div strong, .account-sample-info .history_attr div span','padding-right','10','','','.account-sample-info'),(988307,'deals','.account-sample-info .history_info > div + div','padding-right','0','','','.account-sample-info'),(988308,'deals','.account-sample-info .popup-tracking-number','padding-right','10','','','.account-sample-info'),(988309,'deals','.account-sample-info .history_info > div','padding-right','0','5639','','.account-sample-info'),(988310,'deals','.account-sample-info .history_info > div + div','padding-right','0','5639','','.account-sample-info'),(988311,'deals','.catalog-product-wrap .next-product','padding-right','50','','','.catalog-product-wrap'),(988312,'deals','.catalog-product-wrap .pn-direction','padding-right','4','','','.catalog-product-wrap'),(988313,'deals','.catalog-product-wrap .pn-image','padding-right','5','','','.catalog-product-wrap'),(988314,'deals','.catalog-product-wrap .prev-product','padding-right','20','','','.catalog-product-wrap'),(988315,'deals','.catalog-product-wrap .prev-product .pn-image','padding-right','2','3','','.catalog-product-wrap'),(988316,'deals','.catalog-product-wrap .next-product','padding-right','0','5639','','.catalog-product-wrap'),(988317,'deals','.catalog-product-wrap .pn-direction','padding-right','0','5639','','.catalog-product-wrap'),(988318,'deals','.catalog-product-wrap .prev-product','padding-right','0','5639','','.catalog-product-wrap'),(988319,'deals','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-right','20','','','.shopping-cart-index'),(988320,'deals','.shopping-cart-index .closeable-heading .heading-3','padding-right','0','','','.shopping-cart-index'),(988321,'deals','.checkout-index-wrap .checkout-cart-listing.main-listing','padding-right','30','','','.checkout-index-wrap'),(988322,'deals','.checkout-index-wrap .datepicker-inline','padding-right','0','','','.checkout-index-wrap'),(988323,'deals','.checkout-index-wrap .edit-address-popup','padding-right','20','','','.checkout-index-wrap'),(988324,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-right','25','','','.checkout-index-wrap'),(988325,'deals','.checkout-order-confirmation .price-row','padding-right','0','','','.checkout-order-confirmation'),(988326,'deals','.checkout-order-confirmation .type-4 .type-1 > .block > .type-2 > .block:nth-child(1)','padding-right','20','','','.checkout-order-confirmation'),(988327,'deals','.checkout-order-confirmation .type-4 .type-1 > .block > .type-2 > .block:nth-child(1)','padding-right','0','5660','','.checkout-order-confirmation'),(988328,'deals','.b-form .columns .col-2','padding-right','10','','','.b-form'),(988329,'deals','.b-bottom .pop-up-content','padding-right','20','','','.b-bottom'),(988330,'deals','.b-slick .slick-dots li','padding-right','5','','','.b-slick'),(988332,'deals','.success-page .check-ico-block','padding-right','0','','','.success-page'),(988333,'deals','.success-page .order-summary2 .btn-2','padding-right','50','','','.success-page'),(988334,'deals','.success-page .order_totals .price-row','padding-right','0','','','.success-page'),(988335,'deals','.success-page .price-row','padding-right','0','','','.success-page'),(988336,'deals','.success-page .w-cart-listing .price','padding-right','0','','','.success-page'),(988337,'deals','.success-page .w-cart-listing .qty','padding-right','0','','','.success-page'),(988338,'deals','.b-multi-page-checkout .multi-page-checkout .buttons','padding-right','0','','','.b-multi-page-checkout'),(988339,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-right','10','','','.b-multi-page-checkout'),(988340,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-right','10','','','.b-multi-page-checkout'),(988341,'deals','.bannersWrap .rightBanner .banner-text','padding-right','35','','','.bannersWrap'),(988342,'deals','.b-form .addresses .address-item','padding-right','20','','','.b-form'),(988344,'deals','.footer-menu .level-1 > li > .no-link','padding-right','0','5639','','.footer-menu'),(988345,'deals','.footer-menu .level-3 > li','padding-right','20','5639','','.footer-menu'),(988346,'deals','.footer-menu .level-3 > li.back-button','padding-right','20','5639','','.footer-menu'),(988347,'deals','.footer-menu .level-4 > li','padding-right','0','5639','','.footer-menu'),(988348,'deals','.w-banner .banner-text','padding-right','20','','','.w-banner'),(988349,'deals','.w-banner .carousel-text > span','padding-right','20','','','.w-banner'),(988350,'deals','.w-catalog-paging ','padding-right','5','2','','.w-catalog-paging'),(988351,'deals','.w-catalog-paging .next','padding-right','5','','','.w-catalog-paging'),(988352,'deals','.w-catalog-paging .next-pages','padding-right','5','','','.w-catalog-paging'),(988353,'deals','.w-catalog-paging .page-number','padding-right','5','','','.w-catalog-paging'),(988354,'deals','.w-catalog-paging .paging-item','padding-right','2','','','.w-catalog-paging'),(988355,'deals','.w-catalog-paging .prev','padding-right','5','','','.w-catalog-paging'),(988356,'deals','.w-catalog-paging .prev-pages','padding-right','5','','','.w-catalog-paging'),(988365,'deals','.w-menu-slider > ul > li > a','padding-right','10','','','.w-menu-slider'),(988366,'deals','.w-menu-slider > ul > li > ul > li','padding-right','50','','','.w-menu-slider'),(988367,'deals','.w-menu-slider ul, .w-menu-slider li','padding-right','0','','','.w-menu-slider'),(988368,'deals','.bannersWrap .leftBanner .banner-text','padding-right','0','','','.bannersWrap'),(988369,'deals','.b-data-table table.dataTable tbody td','padding-right_important','important','','','.b-data-table'),(988370,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-right_important','important','','','.b-data-table'),(988371,'deals','.b-data-table table.dataTable thead td','padding-right_important','important','','','.b-data-table'),(988372,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-right_important','important','','','.b-data-table'),(988373,'deals','.w-account-personal-catalog .price','padding-right_important','important','','','.w-account-personal-catalog'),(988374,'deals','.w-communication-new-topic #communication_group_holder td, .w-communication-new-topic #communication_group_holder th','padding-top','10','','','.w-communication-new-topic'),(988375,'deals','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(988376,'deals','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(988377,'deals','.heading-4 .edit, h4 .edit','padding-top','2','','',''),(988378,'deals','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(988379,'deals','.b-form .password-forgotten-link','padding-top','15','','','.b-form'),(988380,'deals','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(988383,'deals','.w-cart-discount-coupon .btn','padding-top','6','','','.w-cart-discount-coupon'),(988384,'deals','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(988385,'deals','.b-email .totals-title','padding-top','5','','','.b-email'),(988386,'deals','.p-quick-order-index ul.token-input-list','padding-top','0','','','.p-quick-order-index'),(988387,'deals','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','padding-top','7','','','.p-quick-order-index'),(988388,'deals','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','padding-top','8','','','.p-quick-order-index'),(988389,'deals','.w-promotions .promo-item','padding-top','30','','','.w-promotions'),(988390,'deals','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(988391,'deals','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(988392,'deals','.w-cart-compare .attributes-label','padding-top','10','','','.w-cart-compare'),(988399,'deals','.w-personal-gift-status-bar .end-label','padding-top','0','','','.w-personal-gift-status-bar'),(988400,'deals','.p-sample-checkout-success .page-success .text-1','padding-top','120','','','.p-sample-checkout-success'),(988401,'deals','.w-personal-gift-status-bar .start-label','padding-top','0','','','.w-personal-gift-status-bar'),(988402,'deals','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(988403,'deals','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(988404,'deals','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(988405,'deals','.b-email .heading-image','padding-top','5','','','.b-email'),(988406,'deals','.w-product-images-additional .images','padding-top','10','5660','','.w-product-images-additional'),(988407,'deals','.testimonials .reviews-list .name','padding-top','5','','',''),(988408,'deals','.testimonials .heading-3','padding-top','7','','',''),(988409,'deals','.testimonials .review','padding-top','10','','',''),(988410,'deals','.testimonials .name','padding-top','5','','',''),(988411,'deals','.testimonials .reviews-list .answer .name','padding-top','10','','',''),(988412,'deals','.w-categories .image','padding-top','0','','','.w-categories'),(988413,'deals','.w-promotions .prom-multi-discount .promo-range','padding-top','0','','','.w-promotions'),(988414,'deals','.w-promotions .prom-multi-discount .promo-product','padding-top','20','','','.w-promotions'),(988415,'deals','.w-catalog-items-on-page .before, .w-catalog-items-on-page .after','padding-top','5','','','.w-catalog-items-on-page'),(988416,'deals','.w-promotions .nextdiscount .content > div','padding-top','10','','','.w-promotions'),(988417,'deals','.w-promotions .nextdiscount .promo-for-each','padding-top','3','','','.w-promotions'),(988418,'deals','.w-promotions .promo-salemaker .item','padding-top','20','','','.w-promotions'),(988419,'deals','.w-promotions .promo-salemaker .discount','padding-top','0','','','.w-promotions'),(988420,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.p-quick-order-index'),(988421,'deals','.w-promotions .promo-cart-discount .slave .item','padding-top','20','','','.w-promotions'),(988422,'deals','.w-promotions .promo-cart-discount .slave .condition-holder','padding-top','0','','','.w-promotions'),(988423,'deals','.w-promotions .promo-cart-discount .promo-min-qty','padding-top','0','','','.w-promotions'),(988424,'deals','.b-warehouses-popup .warehouses-popup .pop-up-content','padding-top','20','','','.b-warehouses-popup'),(988425,'deals','.w-product-available-in-warehouses .warehouse-item','padding-top','0','','','.w-product-available-in-warehouses'),(988426,'deals','.w-chat .w-chat-box','padding-top','2','','','.w-chat'),(988427,'deals','.w-cart-give-away .ga_column','padding-top','15','','','.w-cart-give-away'),(988428,'deals','.w-cart-compare .attributes-cell','padding-top','8','','','.w-cart-compare'),(988429,'deals','.p-quick-order-index .bottom','padding-top','10','','','.p-quick-order-index'),(988430,'deals','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(988431,'deals','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(988432,'deals','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(988433,'deals','.b-messages .messages-menu ul','padding-top','0','','','.b-messages'),(988434,'deals','.b-messages .messages-menu li','padding-top','0','','','.b-messages'),(988435,'deals','.b-messages .messMenuButton span','padding-top','10','','','.b-messages'),(988436,'deals','.b-messages .msv_btn','padding-top','12','','','.b-messages'),(988437,'deals','.b-messages .msv_content','padding-top','10','','','.b-messages'),(988438,'deals','.b-messages .msv_history','padding-top','10','','','.b-messages'),(988439,'deals','.b-messages .messages-menu li a','padding-top','10','','','.b-messages'),(988440,'deals','.b-messages .email-heading','padding-top','15','','','.b-messages'),(988441,'deals','.b-messages .content_management_attach button','padding-top','1','','','.b-messages'),(988442,'deals','.b-messages .content_management_attach','padding-top','8','','','.b-messages'),(988443,'deals','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(988444,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','padding-top','4','','','.b-messages'),(988445,'deals','.b-messages .emailBtn','padding-top','10','','','.b-messages'),(988446,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable thead th, .b-messages #DataTables_Table_0_wrapper table.dataTable thead td','padding-top','5','','','.b-messages'),(988447,'deals','.b-messages .msv_to_cc','padding-top','10','','','.b-messages'),(988448,'deals','.b-messages .messMenuButtonTop','padding-top','5','','','.b-messages'),(988449,'deals','input[type=\'text\'], input[type=\'password\'], input[type=\'number\'], input[type=\'email\'], input[type=\'search\'], select','padding-top','4','','',''),(988450,'deals','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(988451,'deals','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(988452,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(988453,'deals','.w-sitemap-delivery-location > ul > li > ul','padding-top','0','','','.w-sitemap-delivery-location'),(988454,'deals','.w-sitemap-delivery-location > ul','padding-top','0','','','.w-sitemap-delivery-location'),(988455,'deals','.p-payer-order-confirmation .dob-hide label','padding-top','5','','','.p-payer-order-confirmation'),(988456,'deals','.p-payer-order-pay .dob-hide label','padding-top','5','','','.p-payer-order-pay'),(988457,'deals','.w-checkout-terms .required-message','padding-top','5','','','.w-checkout-terms'),(988458,'deals','.w-cart-listing .item .remove','padding-top','5','5639','','.w-cart-listing'),(988459,'deals','.b-email .heading-image','padding-top','5','','','.b-email'),(988460,'deals','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(988461,'deals','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(988462,'deals','.w-reviews-content .item','padding-top','20','','','.w-reviews-content'),(988464,'deals','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(988465,'deals','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(988466,'deals','.b-email .heading-name','padding-top','5','','','.b-email'),(988467,'deals','.b-email .heading-price','padding-top','5','','','.b-email'),(988468,'deals','.b-email .heading-model','padding-top','5','','','.b-email'),(988469,'deals','.p-quick-order-index .all-scroll-div','padding-top','10','','','.p-quick-order-index'),(988470,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-template','padding-top','10','','','.w-upload-customer-id-upload-customer-id-form'),(988471,'deals','.b-email .name','padding-top','5','','','.b-email'),(988472,'deals','.b-email .qty','padding-top','5','','','.b-email'),(988473,'deals','.b-email .heading-qty','padding-top','5','','','.b-email'),(988474,'deals','.b-email .heading-model','padding-top','5','','','.b-email'),(988475,'deals','.w-filters .filter-ul-content','padding-top','0','','','.w-filters'),(988476,'deals','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(988477,'deals','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(988478,'deals','.w-menu-horizontal > ul > li > ul > li > ul li a, .w-menu-horizontal > ul > li > ul > li > ul li .no-link','padding-top','2','','','.w-menu-horizontal'),(988479,'deals','.w-menu-horizontal ul','padding-top','0','','','.w-menu-horizontal'),(988480,'deals','.w-tabs .tab-navigation','padding-top','0','','','.w-tabs'),(988481,'deals','.w-promo-code .holder','padding-top','20','5660','','.w-promo-code'),(988482,'deals','.w-promo-code .holder','padding-top','20','5660','','.w-promo-code'),(988483,'deals','.w-product-images-additional .images','padding-top','10','5660','','.w-product-images-additional'),(988484,'deals','.p-quote-checkout-success .page-success .text-1','padding-top','5','5630','','.p-quote-checkout-success'),(988485,'deals','.b-fancybox .fancybox-title-over-wrap','padding-top','10','','','.b-fancybox'),(988486,'deals','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(988487,'deals','.b-fancybox .fancybox-title-inside-wrap','padding-top','10','','','.b-fancybox'),(988488,'deals','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(988489,'deals','.w-multi-cart-cart-switcher .carts-switcher','padding-top','20','','','.w-multi-cart-cart-switcher'),(988490,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(988491,'deals','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(988492,'deals','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(988493,'deals','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(988494,'deals','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','padding-top','0','','','.b-fancybox'),(988495,'deals','.w-cart-compare .dropdown li','padding-top','5','','','.w-cart-compare'),(988496,'deals','.no-found','padding-top','20','','',''),(988498,'deals','.b-upload-files .attached-block','padding-top','10','','','.b-upload-files'),(988500,'deals','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(988501,'deals','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(988502,'deals','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(988504,'deals','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(988505,'deals','.message.success','padding-top','20','','',''),(988506,'deals','.w-cart-compare .dropdown .dropdown-menu','padding-top','5','','','.w-cart-compare'),(988507,'deals','.b-email .heading-qty','padding-top','5','','','.b-email'),(988508,'deals','.b-email .model','padding-top','5','','','.b-email'),(988509,'deals','.b-email .totals-title','padding-top','5','','','.b-email'),(988510,'deals','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(988511,'deals','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(988512,'deals','.b-email .totals-value','padding-top','5','','','.b-email'),(988513,'deals','.b-email .heading-name','padding-top','5','','','.b-email'),(988514,'deals','.b-email .name','padding-top','5','','','.b-email'),(988515,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','padding-top','0','','','.b-select-suggest'),(988516,'deals','.w-reviews .review','padding-top','10','','','.w-reviews'),(988517,'deals','.w-socials > li','padding-top','15','','','.w-socials'),(988520,'deals','.w-cart-compare .product','padding-top','10','','','.w-cart-compare'),(988521,'deals','.b-info-popup .info-popup div','padding-top','10','','','.b-info-popup'),(988523,'deals','.w-quote .cart-box-link','padding-top','0','','','.w-quote'),(988524,'deals','.order-summary .price-row.ot_gv, .order-summary .price-row.ot_coupon, .order-summary .price-row.ot_bonus_points','padding-top','7','','','.order-summary'),(988525,'deals','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(988526,'deals','.w-reviews .author','padding-top','0','','','.w-reviews'),(988527,'deals','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(988528,'deals','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(988529,'deals','.b-email .heading-model','padding-top','5','','','.b-email'),(988530,'deals','.b-email .model','padding-top','5','','','.b-email'),(988531,'deals','textarea','padding-top','5','','',''),(988532,'deals','.p-quote-checkout-success .page-success .text-1','padding-top','5','5630','','.p-quote-checkout-success'),(988533,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(988534,'deals','.w-multi-cart-actions .cart-actions .dropdown-toggle','padding-top','3','','','.w-multi-cart-actions'),(988535,'deals','.w-top-categories h2.name','padding-top','3','','','.w-top-categories'),(988536,'deals','.w-top-categories .item','padding-top','25','','','.w-top-categories'),(988537,'deals','.w-tabs .accordion-heading','padding-top','9','5630','','.w-tabs'),(988538,'deals','.w-tabs > .block','padding-top','30','','','.w-tabs'),(988539,'deals','.w-cart-cart-tabs .w-tabs > .block','padding-top','0','','','.w-cart-cart-tabs'),(988540,'deals','.w-tabs .tab-a','padding-top','0','','','.w-tabs'),(988541,'deals','.w-tabs .tab-li','padding-top','0','','','.w-tabs'),(988542,'deals','.w-socials > li','padding-top','15','','','.w-socials'),(988543,'deals','.order-summary > div','padding-top','10','','','.order-summary'),(988544,'deals','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(988545,'deals','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(988546,'deals','.b-bottom .popup-buttons','padding-top','15','','','.b-bottom'),(988547,'deals','.b-autocomplete .ui-autocomplete li','padding-top','3','','','.b-autocomplete'),(988548,'deals','.b-bottom .popup-content','padding-top','15','','','.b-bottom'),(988549,'deals','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(988550,'deals','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(988551,'deals','.btn-1','padding-top','10','','',''),(988552,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(988553,'deals','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(988554,'deals','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(988555,'deals','.p-sample-checkout-success .page-success .text-1','padding-top','5','5630','','.p-sample-checkout-success'),(988556,'deals','.b-messages .emailLineTextArea textarea','padding-top','30','','','.b-messages'),(988557,'deals','.btn-3','padding-top','8','','',''),(988558,'deals','.b-bottom .confirm-popup .confirm-text','padding-top','40','','','.b-bottom'),(988559,'deals','.w-product-images-additional .images','padding-top','10','5660','','.w-product-images-additional'),(988560,'deals','.b-products-listing .products-listing .buyButton .btn','padding-top','5','','','.b-products-listing'),(988561,'deals','.heading-3 .right-text, h3 .right-text','padding-top','3','','',''),(988562,'deals','.b-bottom .popup-heading','padding-top','10','','','.b-bottom'),(988563,'deals','.b-form .shipping-method .item + .item','padding-top','5','','','.b-form'),(988564,'deals','.heading-3 .edit, h3 .edit','padding-top','2','','',''),(988565,'deals','.b-email .model','padding-top','5','','','.b-email'),(988566,'deals','.b-upload-file .upload-file-template','padding-top','25','','','.b-upload-file'),(988567,'deals','.p-quote-checkout-success .page-success .text-1','padding-top','5','5630','','.p-quote-checkout-success'),(988568,'deals','.b-form .middle-form','padding-top','20','','','.b-form'),(988569,'deals','.b-email .qty','padding-top','5','','','.b-email'),(988570,'deals','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(988571,'deals','.b-email .heading-price','padding-top','5','','','.b-email'),(988572,'deals','.w-socials > li','padding-top','15','','','.w-socials'),(988573,'deals','.order-summary .price-row','padding-top','7','','','.order-summary'),(988574,'deals','.b-email .model','padding-top','5','','','.b-email'),(988575,'deals','.b-email .image','padding-top','5','','','.b-email'),(988576,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(988577,'deals','.b-select-suggest .select2-drop-mask','padding-top','0','','','.b-select-suggest'),(988579,'deals','.w-reviews-content .review','padding-top','20','','','.w-reviews-content'),(988580,'deals','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(988581,'deals','.b-email .price','padding-top','5','','','.b-email'),(988582,'deals','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(988583,'deals','.b-fancybox .fancybox-title-float-wrap .child','padding-top','2','','','.b-fancybox'),(988584,'deals','.w-checkout-shipping-choice span','padding-top','7','5660','','.w-checkout-shipping-choice'),(988585,'deals','.w-top-categories .categories h2','padding-top','0','','','.w-top-categories'),(988586,'deals','.w-top-categories .image','padding-top','0','','','.w-top-categories'),(988587,'deals','.w-product-reviews .reviews-list .review','padding-top','10','','','.w-product-reviews'),(988588,'deals','.w-product-reviews .reviews-list .name','padding-top','5','','','.w-product-reviews'),(988589,'deals','.b-email .heading-qty','padding-top','5','','','.b-email'),(988590,'deals','.b-email .name','padding-top','5','','','.b-email'),(988591,'deals','.b-form .required-message','padding-top','0','','','.b-form'),(988592,'deals','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(988593,'deals','.p-quote-checkout-success .page-success .text-1','padding-top','5','5630','','.p-quote-checkout-success'),(988594,'deals','.w-promo-code .holder','padding-top','20','5660','','.w-promo-code'),(988595,'deals','.b-bottom .popup-simple','padding-top','20','','','.b-bottom'),(988596,'deals','.b-bottom .rfq-form','padding-top','0','','','.b-bottom'),(988597,'deals','.b-email .heading-model','padding-top','5','','','.b-email'),(988598,'deals','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(988599,'deals','.b-email .price','padding-top','5','','','.b-email'),(988600,'deals','.b-email .heading-name','padding-top','5','','','.b-email'),(988601,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(988602,'deals','.b-email .model','padding-top','5','','','.b-email'),(988603,'deals','.b-email .heading-price','padding-top','5','','','.b-email'),(988604,'deals','.b-email .heading-qty','padding-top','5','','','.b-email'),(988605,'deals','.b-email .heading-model','padding-top','5','','','.b-email'),(988606,'deals','.b-email .qty','padding-top','5','','','.b-email'),(988607,'deals','.b-email .totals-value','padding-top','5','','','.b-email'),(988608,'deals','.b-email .totals-title','padding-top','5','','','.b-email'),(988609,'deals','.b-email .image','padding-top','5','','','.b-email'),(988610,'deals','.b-email .price','padding-top','5','','','.b-email'),(988611,'deals','.b-email .qty','padding-top','5','','','.b-email'),(988612,'deals','.b-email .name','padding-top','5','','','.b-email'),(988613,'deals','.b-email .heading-image','padding-top','5','','','.b-email'),(988614,'deals','.b-email .heading-name','padding-top','5','','','.b-email'),(988615,'deals','.w-checkout-shipping .sub-item','padding-top','5','','','.w-checkout-shipping'),(988616,'deals','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(988617,'deals','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(988618,'deals','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(988619,'deals','.w-promo-code .holder','padding-top','20','5660','','.w-promo-code'),(988620,'deals','.w-socials > li','padding-top','15','','','.w-socials'),(988621,'deals','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(988622,'deals','.b-form .center-buttons','padding-top','20','','','.b-form'),(988623,'deals','.b-form .shipping-method .input','padding-top','0','','','.b-form'),(988624,'deals','.w-reviews .heading-3','padding-top','7','','','.w-reviews'),(988625,'deals','.w-checkout-shipping-address .edit-ab','padding-top','5','','','.w-checkout-shipping-address'),(988626,'deals','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(988627,'deals','.b-select-suggest .select2-container .select2-choice','padding-top','0','','','.b-select-suggest'),(988628,'deals','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(988629,'deals','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(988630,'deals','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(988631,'deals','.b-bottom .terms-info-popup .pop-up-content','padding-top','20','','','.b-bottom'),(988632,'deals','.w-checkout-create-account .create-account-switcher','padding-top','8','','','.w-checkout-create-account'),(988633,'deals','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','12','5639','','.w-menu-horizontal'),(988634,'deals','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(988635,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(988636,'deals','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(988637,'deals','.w-product-images-additional .images','padding-top','10','5660','','.w-product-images-additional'),(988638,'deals','.b-form .login-col-1','padding-top','40','','','.b-form'),(988639,'deals','.b-form .form-buttons','padding-top','17','','','.b-form'),(988640,'deals','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(988642,'deals','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(988643,'deals','.w-cart-compare .delete-cart','padding-top','10','','','.w-cart-compare'),(988644,'deals','.w-catalog-listing-look .listing-look-title','padding-top','4','','','.w-catalog-listing-look'),(988645,'deals','.b-email .heading-price','padding-top','5','','','.b-email'),(988646,'deals','.b-email .image','padding-top','5','','','.b-email'),(988647,'deals','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(988648,'deals','.b-email .price','padding-top','5','','','.b-email'),(988649,'deals','.w-product-images-additional .images','padding-top','10','5660','','.w-product-images-additional'),(988650,'deals','.b-bottom .cart-options .heading-4','padding-top','10','','','.b-bottom'),(988651,'deals','.b-bottom .cart-popup .cart-page, .b-bottom .cart-popup .wishlist-page','padding-top','0','','','.b-bottom'),(988652,'deals','.b-compare .popupCompare .pop-up-content','padding-top','0','','','.b-compare'),(988653,'deals','.w-promotions .promo-cart-discount .master .item','padding-top','0','','','.w-promotions'),(988654,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(988655,'deals','.b-bottom .alert-message','padding-top','20','','','.b-bottom'),(988656,'deals','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(988657,'deals','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(988658,'deals','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(988659,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(988660,'deals','.b-email .image','padding-top','5','','','.b-email'),(988661,'deals','.b-bottom .cart-options','padding-top','20','','','.b-bottom'),(988662,'deals','.b-email .totals-title','padding-top','5','','','.b-email'),(988663,'deals','.b-email .price','padding-top','5','','','.b-email'),(988664,'deals','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(988665,'deals','.b-email .image','padding-top','5','','','.b-email'),(988666,'deals','.b-email .heading-image','padding-top','5','','','.b-email'),(988667,'deals','.b-email .heading-qty','padding-top','5','','','.b-email'),(988668,'deals','.b-bottom .footerTitle','padding-top','9','5630','','.b-bottom'),(988669,'deals','.b-bottom .pop-up-info','padding-top','20','','','.b-bottom'),(988670,'deals','.b-bottom .pop-up-close','padding-top','1','','','.b-bottom'),(988671,'deals','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(988672,'deals','.w-cart-up-sell .w-list-type-1','padding-top','0','','','.w-cart-up-sell'),(988673,'deals','.w-cart-up-sell .w-list-type-1 .item','padding-top','1','','','.w-cart-up-sell'),(988674,'deals','.w-cart-shipping-estimator .address-item','padding-top','0','','','.w-cart-shipping-estimator'),(988675,'deals','.w-cart-up-sell .w-list-type-1 .item','padding-top','0','1','','.w-cart-up-sell'),(988676,'deals','.b-products-listing .products-listing .btn-buy','padding-top','12','','','.b-products-listing'),(988677,'deals','.b-upload-files .added-file','padding-top','5','','','.b-upload-files'),(988678,'deals','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(988679,'deals','.w-socials > li','padding-top','15','','','.w-socials'),(988680,'deals','.p-quote-checkout-success .page-success .text-1','padding-top','5','5630','','.p-quote-checkout-success'),(988681,'deals','.b-bottom .popup-box-wrap','padding-top','10','','','.b-bottom'),(988682,'deals','.b-fancybox .fancybox-error','padding-top','15','','','.b-fancybox'),(988683,'deals','.b-form .privacy-row','padding-top','10','','','.b-form'),(988684,'deals','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(988685,'deals','.b-form .payment-method .item','padding-top','7','','','.b-form'),(988686,'deals','.b-form .required-message-wrap','padding-top','0','','','.b-form'),(988687,'deals','.w-product-customers-activity .customers-activity','padding-top','35','','','.w-product-customers-activity'),(988688,'deals','.b-email .name','padding-top','5','','','.b-email'),(988689,'deals','.b-email .heading-price','padding-top','5','','','.b-email'),(988690,'deals','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(988691,'deals','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(988692,'deals','.w-checkout-billing-address .edit-ab','padding-top','5','','','.w-checkout-billing-address'),(988693,'deals','.w-checkout-shipping-choice span','padding-top','7','','','.w-checkout-shipping-choice'),(988694,'deals','.w-promo-code .holder','padding-top','20','5660','','.w-promo-code'),(988695,'deals','.w-product-images-additional .images','padding-top','10','5660','','.w-product-images-additional'),(988696,'deals','.w-categories .item','padding-top','15','','','.w-categories'),(988697,'deals','.w-tabs .accordion-heading','padding-top','6','','','.w-tabs'),(988698,'deals','.w-socials > li','padding-top','15','','','.w-socials'),(988699,'deals','.b-form .shipping-method .sub-title','padding-top','2','','','.b-form'),(988700,'deals','.w-categories h2.name','padding-top','3','','','.w-categories'),(988701,'deals','.w-catalog-sorting .before','padding-top','5','','','.w-catalog-sorting'),(988702,'deals','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(988704,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(988705,'deals','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(988706,'deals','.b-select-suggest .select2-container-multi.select2-container-disabled .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(988707,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','padding-top','3','','','.b-select-suggest'),(988708,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','padding-top','0','','','.b-select-suggest'),(988709,'deals','.b-select-suggest .select2-locked','padding-top','3','','','.b-select-suggest'),(988710,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field input','padding-top','5','','','.b-select-suggest'),(988711,'deals','.b-select-suggest .select2-container-multi .select2-choices','padding-top','0','','','.b-select-suggest'),(988712,'deals','.b-select-suggest .select2-results .select2-result-label','padding-top','3','','','.b-select-suggest'),(988713,'deals','.w-menu-horizontal > ul > li > a, .w-menu-horizontal > ul > li > .no-link','padding-top','5','','','.w-menu-horizontal'),(988714,'deals','.b-select-suggest .select2-results','padding-top','0','','','.b-select-suggest'),(988715,'deals','.b-select-suggest .select2-container .select2-choice > .select2-chosen','padding-top','4','','','.b-select-suggest'),(988716,'deals','.b-select-suggest .select2-search input','padding-top','4','','','.b-select-suggest'),(988717,'deals','.b-bottom .notify-form','padding-top','0','','','.b-bottom'),(988718,'deals','.b-select-suggest .select2-drop-auto-width .select2-search','padding-top','4','','','.b-select-suggest'),(988719,'deals','.w-neighbour-checkout .neighbour-comment-box','padding-top','10','','','.w-neighbour-checkout'),(988720,'deals','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(988721,'deals','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(988723,'deals','.w-checkout-billing-address .same-address','padding-top','10','','','.w-checkout-billing-address'),(988724,'deals','.w-menu-horizontal > ul > li > ul > li','padding-top','2','','','.w-menu-horizontal'),(988725,'deals','.w-menu-big ul','padding-top','0','','','.w-menu-big'),(988729,'deals','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(988730,'deals','.w-cart-compare .product-label','padding-top','15','','','.w-cart-compare'),(988731,'deals','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(988732,'deals','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(988733,'deals','.b-sub-totals .historyTotal td','padding-top','2','','','.b-sub-totals'),(988734,'deals','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(988735,'deals','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(988736,'deals','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(988737,'deals','.b-tracking-numbers .tracking-numbers-popup .pop-up-content','padding-top','20','','','.b-tracking-numbers'),(988738,'deals','.w-cart-compare .price-cell','padding-top','8','','','.w-cart-compare'),(988742,'deals','.w-login-block .new .buttons','padding-top','20','','','.w-login-block'),(988743,'deals','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(988744,'deals','.w-account-addresses-list .addsess-suggestion-item','padding-top','0','','','.w-account-addresses-list'),(988745,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top','0','','','.b-data-table'),(988746,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top','0','','','.b-data-table'),(988747,'deals','.w-communication-post .communication-post-author','padding-top','10','','','.w-communication-post'),(988748,'deals','.b-products-listing .in-cart','padding-top','5','','','.b-products-listing'),(988749,'deals','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','padding-top','4','','','.b-products-listing'),(988750,'deals','.w-catalog-b2b-add-button .b2b-add-box-wrap','padding-top','5','','','.w-catalog-b2b-add-button'),(988751,'deals','.b-products-listing .promos-info .promo-name','padding-top','3','','','.b-products-listing'),(988752,'deals','.b-products-listing .promos-info .promo-item','padding-top','3','','','.b-products-listing'),(988758,'deals','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(988759,'deals','.p-quote-checkout-success .page-success .text-1','padding-top','5','5630','','.p-quote-checkout-success'),(988760,'deals','.w-checkout-gdpr .privacy-row','padding-top','0','','','.w-checkout-gdpr'),(988761,'deals','.w-checkout-gdpr .terms-login','padding-top','0','','','.w-checkout-gdpr'),(988762,'deals','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(988763,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow b','padding-top','3','3','','.b-select-suggest'),(988764,'deals','.b-tracking-numbers .tracking-numbers th','padding-top','5','','','.b-tracking-numbers'),(988765,'deals','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(988766,'deals','.b-compare .compare-box-item','padding-top','10','','','.b-compare'),(988767,'deals','.b-email .heading-qty','padding-top','5','','','.b-email'),(988768,'deals','.b-bottom .header-info','padding-top','20','','','.b-bottom'),(988769,'deals','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(988770,'deals','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(988771,'deals','.b-compare .compare-head','padding-top','10','','','.b-compare'),(988772,'deals','.heading-4 .right-text, h4 .right-text','padding-top','4','','',''),(988773,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','padding-top','0','','',''),(988774,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','padding-top','0','','','.b-h-inline'),(988775,'deals','h1, .heading-1','padding-top','20','','',''),(988776,'deals','.w-communication-new-topic .topick-left-col','padding-top','24','','','.w-communication-new-topic'),(988777,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td td','padding-top','0','','','.w-communication-new-topic'),(988778,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','padding-top','5','','','.w-communication-new-topic'),(988779,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder input','padding-top','5','','','.w-communication-new-topic'),(988780,'deals','.w-communication-new-topic #communication_topic_form .middle-form','padding-top','20','','','.w-communication-new-topic'),(988781,'deals','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(988782,'deals','.b-email .heading-image','padding-top','5','','','.b-email'),(988783,'deals','.b-email .price','padding-top','5','','','.b-email'),(988784,'deals','.b-compare .popupCompare td, .b-compare .popupCompare th','padding-top','4','','','.b-compare'),(988786,'deals','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(988787,'deals','.w-cart-compare .price-label','padding-top','10','','','.w-cart-compare'),(988788,'deals','.b-email-editor .product-item','padding-top','10','','','.b-email-editor'),(988790,'deals','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(988791,'deals','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(988792,'deals','.b-email-editor .price','padding-top','10','','','.b-email-editor'),(988793,'deals','.b-email .model','padding-top','5','','','.b-email'),(988794,'deals','.b-email .totals-value','padding-top','5','','','.b-email'),(988795,'deals','.b-email .heading-name','padding-top','5','','','.b-email'),(988796,'deals','.products-quick-index .token-input-list','padding-top','0','','',''),(988797,'deals','.w-cart-compare .cart-cell','padding-top','0','','','.w-cart-compare'),(988799,'deals','.w-reviews .item','padding-top','15','','','.w-reviews'),(988800,'deals','.w-promo-code .holder','padding-top','20','','','.w-promo-code'),(988801,'deals','.w-promo-code .promo-code-form','padding-top','8','','','.w-promo-code'),(988802,'deals','.w-promo-code .promo-text-2','padding-top','15','','','.w-promo-code'),(988803,'deals','.b-email .name','padding-top','5','','','.b-email'),(988804,'deals','.b-form .shipping-method .item','padding-top','0','','','.b-form'),(988805,'deals','.b-email .heading-name','padding-top','5','','','.b-email'),(988806,'deals','.b-email .qty','padding-top','5','','','.b-email'),(988807,'deals','.b-email .totals-value','padding-top','5','','','.b-email'),(988808,'deals','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(988809,'deals','.b-email .heading-model','padding-top','5','','','.b-email'),(988810,'deals','.b-compare .col-two label','padding-top','5','','','.b-compare'),(988811,'deals','.w-cart-listing .item .attributes','padding-top','5','','','.w-cart-listing'),(988812,'deals','.w-cart-listing .item .gift-wrap label','padding-top','10','','','.w-cart-listing'),(988813,'deals','.w-cart-listing .item > div','padding-top','10','','','.w-cart-listing'),(988814,'deals','.w-cart-listing .points-earn','padding-top','5','','','.w-cart-listing'),(988815,'deals','.w-cart-listing .points-redeem','padding-top','0','','','.w-cart-listing'),(988816,'deals','.b-bottom .header-error','padding-top','20','','','.b-bottom'),(988822,'deals','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(988823,'deals','.w-brands .brands-listing > div','padding-top','0','','','.w-brands'),(988824,'deals','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(988825,'deals','.b-email-editor .special-price','padding-top','0','','','.b-email-editor'),(988826,'deals','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(988827,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','padding-top','10','','','.w-image-maps'),(988828,'deals','.b-compare .col-gender','padding-top','0','','','.b-compare'),(988829,'deals','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(988830,'deals','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','padding-top','0','','','.b-fancybox'),(988831,'deals','.b-compare .compare_pagination','padding-top','10','','','.b-compare'),(988832,'deals','.w-top-categories .item','padding-top','5','5630','','.w-top-categories'),(988833,'deals','.w-product-promotions select','padding-top','0','','','.w-product-promotions'),(988836,'deals','.p-sample-cart-index .empty','padding-top','100','','','.p-sample-cart-index'),(988837,'deals','.w-brands .brands-listing','padding-top','0','','','.w-brands'),(988838,'deals','.p-sample-checkout-confirmation .buttons','padding-top','20','','','.p-sample-checkout-confirmation'),(988840,'deals','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(988841,'deals','.w-filters .fsl_handle','padding-top','20','','','.w-filters'),(988842,'deals','.w-filters .head-filter-widget','padding-top','0','5639','','.w-filters'),(988843,'deals','.w-filters .ui-slider-range','padding-top','0','','','.w-filters'),(988844,'deals','.p-quote-checkout-success .page-success .text-1','padding-top','120','','','.p-quote-checkout-success'),(988845,'deals','.w-filters .head-filter-widget','padding-top','0','','','.w-filters'),(988846,'deals','.b-autocomplete .ui-autocomplete','padding-top','2','','','.b-autocomplete'),(988847,'deals','.w-promo-code .holder','padding-top','20','5660','','.w-promo-code'),(988849,'deals','.order-summary .heading-2','padding-top','0','','','.order-summary'),(988850,'deals','.b-compare .column_wrapper','padding-top','0','','','.b-compare'),(988851,'deals','.b-email .image','padding-top','5','','','.b-email'),(988852,'deals','.b-email .heading-price','padding-top','5','','','.b-email'),(988853,'deals','.b-email .heading-image','padding-top','5','','','.b-email'),(988854,'deals','.b-dropdown .dropdown .dropdown-menu','padding-top','5','','','.b-dropdown'),(988855,'deals','.w-reviews-content .author','padding-top','0','','','.w-reviews-content'),(988856,'deals','.w-menu-style-2 ul, .w-menu-style-2 li','padding-top','0','','','.w-menu-style-2'),(988857,'deals','.w-login-block .password-row','padding-top','0','','','.w-login-block'),(988858,'deals','.price .old','padding-top','0.3','','',''),(988859,'deals','.b-data-table table.dataTable tbody td','padding-top','10','','','.b-data-table'),(988860,'deals','.b-data-table table.dataTable thead td','padding-top','10','','','.b-data-table'),(988861,'deals','.b-tracking-numbers .tracking-numbers td','padding-top','5','','','.b-tracking-numbers'),(988863,'deals','.btn-2','padding-top','10','','',''),(988864,'deals','.w-quote-products .empty','padding-top','100','','','.w-quote-products'),(988865,'deals','.b-social-login .social-login-text-1','padding-top','15','','','.b-social-login'),(988866,'deals','.w-checkout-create-account .create-account','padding-top','10','','','.w-checkout-create-account'),(988867,'deals','.b-email .totals-title','padding-top','5','','','.b-email'),(988868,'deals','.b-email-editor .old-price','padding-top','10','','','.b-email-editor'),(988869,'deals','.b-upload-files .upload-files','padding-top','0','','','.b-upload-files'),(988870,'deals','.b-email .totals-value','padding-top','5','','','.b-email'),(988871,'deals','.b-email .totals-value','padding-top','5','','','.b-email'),(988872,'deals','.b-email .totals-title','padding-top','5','','','.b-email'),(988873,'deals','.b-email .qty','padding-top','5','','','.b-email'),(988874,'deals','.btn','padding-top','8','','',''),(988875,'deals','.w-personal-gift-status-bar .timeline','padding-top','16','','','.w-personal-gift-status-bar'),(988876,'deals','.b-product-images .media-popup .mp-content','padding-top','0','','','.b-product-images'),(988877,'deals','.b-product-images .media-popup .mp-small-images .item','padding-top','10','','','.b-product-images'),(988878,'deals','.b-product-images .media-popup .slick-dots','padding-top','0','','','.b-product-images'),(988879,'deals','.b-product-images .media-popup .slick-dots li','padding-top','0','','','.b-product-images'),(988880,'deals','.b-menu-style .menu-style ul, .b-menu-style .menu-style li','padding-top','0','','','.b-menu-style'),(988881,'deals','.b-personal-catalog-popup #personal_catalog_popup','padding-top','20','','','.b-personal-catalog-popup'),(988882,'deals','.b-trade-approval .steps-bar li a','padding-top','7','','','.b-trade-approval'),(988883,'deals','.b-trade-approval .middle-form','padding-top','20','','','.b-trade-approval'),(988884,'deals','.b-trade-approval .orders-table td, .b-trade-approval .orders-table th','padding-top','5','','','.b-trade-approval'),(988885,'deals','.b-trade-approval .steps-bar','padding-top','0','','','.b-trade-approval'),(988886,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','padding-top','4','','','.b-trade-approval'),(988887,'deals','.b-trade-approval .center-buttons','padding-top','20','','','.b-trade-approval'),(988888,'deals','.w-account-personal-catalog .list-switcher','padding-top','0','','','.w-account-personal-catalog'),(988889,'deals','.w-account-personal-catalog .list-switcher a','padding-top','14','','','.w-account-personal-catalog'),(988890,'deals','.w-account-personal-catalog .list-switcher a','padding-top','12','2','','.w-account-personal-catalog'),(988891,'deals','.w-account-subscription .subscription-variant','padding-top','10','','','.w-account-subscription'),(988892,'deals','.w-catalog-additional-images li','padding-top','10','','','.w-catalog-additional-images'),(988893,'deals','.w-catalog-additional-images ul','padding-top','0','','','.w-catalog-additional-images'),(988894,'deals','.w-catalog-compare td','padding-top','10','','','.w-catalog-compare'),(988895,'deals','.w-catalog-compare .cross-box .different-all > div','padding-top','12','','','.w-catalog-compare'),(988896,'deals','.w-catalog-compare .cross-box .different-all > div','padding-top','10','2','','.w-catalog-compare'),(988897,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','padding-top','0','','','.w-catalog-compare'),(988898,'deals','.w-delivery-day .left-count','padding-top','5','','','.w-delivery-day'),(988899,'deals','.w-delivery-day .left-text-left','padding-top','24','','','.w-delivery-day'),(988900,'deals','.w-delivery-day .left-text-right','padding-top','24','','','.w-delivery-day'),(988901,'deals','.w-top-text .top-text','padding-top','5','','','.w-top-text'),(988902,'deals','.w-product-images .slick-vertical + .produst-image','padding-top','400','','','.w-product-images'),(988903,'deals','.w-product-images .additional-horizontal .item','padding-top','10','','','.w-product-images'),(988904,'deals','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','padding-top','10','','','.b-cookie-notice'),(988905,'deals','.lowestPricedBox .w-banner .single_banner','padding-top','0','','','.lowestPricedBox'),(988906,'deals','.lowestPricedBox .w-banner .banner','padding-top','30','','','.lowestPricedBox'),(988907,'deals','.shopByCollectionBox .w-banner .single_banner','padding-top','0','','','.shopByCollectionBox'),(988908,'deals','.preFooter .w-banner .single_banner picture','padding-top','0','','','.preFooter'),(988909,'deals','.b-slick .slick-list','padding-top','0','','','.b-slick'),(988910,'deals','.b-slick .slick-vertical button.slick-next','padding-top','0','3','','.b-slick'),(988911,'deals','.b-slick .slick-vertical button.slick-prev','padding-top','0','3','','.b-slick'),(988912,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','padding-top','0','','','.b-slick'),(988913,'deals','.w-cart-listing .headings .head','padding-top','10','','','.w-cart-listing'),(988914,'deals','.LeftCategories .w-menu-simple ul','padding-top','0','','','.LeftCategories'),(988915,'deals','.LeftCategories .w-menu-simple ul li a','padding-top','4','','','.LeftCategories'),(988916,'deals','.b-products-listing .products-listing.list-productlisting .item','padding-top','20','','','.b-products-listing'),(988917,'deals','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','padding-top','0','','','.b-products-listing'),(988918,'deals','.b-products-listing .products-listing.list-productlisting .item-content','padding-top','15','','','.b-products-listing'),(988919,'deals','.b-products-listing .products-listing.list-productlisting.slick-slider .item-content','padding-top','15','','','.b-products-listing'),(988920,'deals','.b-products-listing .products-listing.list-rows .item-nav > div','padding-top','0','','','.b-products-listing'),(988921,'deals','.b-products-listing .products-listing.list-rows .item:first-of-type .BlockBox.item-holder','padding-top','10','','','.b-products-listing'),(988922,'deals','.w-breadcrumb .breadcrumb-ul','padding-top','0','','','.w-breadcrumb'),(988923,'deals','.w-quote .buttons','padding-top','15','','','.w-quote'),(988924,'deals','.w-quote .buttons .btn','padding-top','5','','','.w-quote'),(988925,'deals','.w-quote .cart-content','padding-top','15','','','.w-quote'),(988926,'deals','.w-quote .cart-total','padding-top','10','','','.w-quote'),(988927,'deals','.w-quote .multicart .cart-content','padding-top','0','','','.w-quote'),(988928,'deals','.w-quote .multicart .item','padding-top','15','','','.w-quote'),(988929,'deals','.w-quote .multicart .name','padding-top','0','','','.w-quote'),(988930,'deals','.w-quote .no-text','padding-top','0','','','.w-quote'),(988931,'deals','.w-quote a.item','padding-top','5','','','.w-quote'),(988932,'deals','.w-social-links a','padding-top','4','','','.w-social-links'),(988933,'deals','.w-product-images .additional-vertical .additional-images','padding-top','30','','','.w-product-images'),(988934,'deals','.w-product-personal-catalog-button .btn','padding-top','8','','','.w-product-personal-catalog-button'),(988935,'deals','.b-quantity .qty-box input','padding-top','5','','','.b-quantity'),(988936,'deals','.b-quantity .qty-input label','padding-top','4','','','.b-quantity'),(988937,'deals','.w-product-sale-ends .left-count','padding-top','5','','','.w-product-sale-ends'),(988938,'deals','.w-product-sale-ends .left-text-left','padding-top','24','','','.w-product-sale-ends'),(988939,'deals','.w-product-sale-ends .left-text-right','padding-top','24','','','.w-product-sale-ends'),(988940,'deals','.w-product-sale-ends .left-count-days','padding-top','7','','','.w-product-sale-ends'),(988941,'deals','.w-product-sale-ends .left-count-hours','padding-top','7','','','.w-product-sale-ends'),(988942,'deals','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty_price','padding-top','3','','','.w-product-quantity'),(988943,'deals','.w-product-quantity .qty_packs .qty-input','padding-top','0','','','.w-product-quantity'),(988944,'deals','.w-product-quantity .qty_packs .qty-input + .qty-input','padding-top','20','','','.w-product-quantity'),(988945,'deals','.w-product-quantity .total-qty','padding-top','15','','','.w-product-quantity'),(988946,'deals','.w-product-quantity .total-qty .qty_price','padding-top','0','','','.w-product-quantity'),(988947,'deals','.warrantyProduct .warranty, .warrantyProduct .delivery','padding-top','10','','','.warrantyProduct'),(988948,'deals','.w-compare .compare-list-buttons','padding-top','10','','','.w-compare'),(988949,'deals','.w-compare .item-holder','padding-top','10','','','.w-compare'),(988950,'deals','.w-compare .compare-list-products','padding-top','0','','','.w-compare'),(988951,'deals','.w-files-catalog-widgets-files-catalog .name','padding-top','10','','','.w-files-catalog-widgets-files-catalog'),(988952,'deals','.w-files-catalog-widgets-files-list .item + .item','padding-top','30','','','.w-files-catalog-widgets-files-list'),(988953,'deals','.w-sample .buttons','padding-top','15','','','.w-sample'),(988954,'deals','.w-sample .buttons .btn','padding-top','5','','','.w-sample'),(988955,'deals','.w-sample .cart-box-link','padding-top','0','','','.w-sample'),(988956,'deals','.w-sample .cart-content','padding-top','15','','','.w-sample'),(988957,'deals','.w-sample .cart-total','padding-top','10','','','.w-sample'),(988958,'deals','.w-sample .multicart .cart-content','padding-top','0','','','.w-sample'),(988959,'deals','.w-sample .multicart .item','padding-top','15','','','.w-sample'),(988960,'deals','.w-sample .multicart .name','padding-top','0','','','.w-sample'),(988961,'deals','.w-sample .no-text','padding-top','0','','','.w-sample'),(988962,'deals','.w-sample a.item','padding-top','5','','','.w-sample'),(988963,'deals','.w-cart-listing .item > div.points','padding-top','0','','','.w-cart-listing'),(988964,'deals','.w-filters-simple .integrate-price-holder','padding-top','10','','','.w-filters-simple'),(988965,'deals','.w-product-video .item','padding-top','10','','','.w-product-video'),(988966,'deals','.shipping-ico .heading-3','padding-top','0','','','.shipping-ico'),(988967,'deals','.w-cart-order-reference .btn','padding-top','6','','','.w-cart-order-reference'),(988968,'deals','.w-cart-gift-certificate .btn','padding-top','6','','','.w-cart-gift-certificate'),(988969,'deals','.w-cart-shipping-estimator .btn','padding-top','6','','','.w-cart-shipping-estimator'),(988970,'deals','.w-product-bundle .attributes-item','padding-top','0','','','.w-product-bundle'),(988971,'deals','.w-product-bundle .bundle_item','padding-top','10','','','.w-product-bundle'),(988972,'deals','.w-product-in-bundles .attributes-item','padding-top','0','','','.w-product-in-bundles'),(988973,'deals','.w-product-in-bundles .bundle_item','padding-top','10','','','.w-product-in-bundles'),(988974,'deals','.w-cart-listing .item > div.actions','padding-top','10','5630','','.w-cart-listing'),(988976,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','padding-top','0','','','.b-products-listing'),(988977,'deals','.b-pagination ul.pagination','padding-top','0','','','.b-pagination'),(988978,'deals','.w-product-properties-filters-widgets-chosen-filters .item','padding-top','3','','','.w-product-properties-filters-widgets-chosen-filters'),(988979,'deals','.p-quote-checkout-index .datepicker-inline','padding-top','10','','','.p-quote-checkout-index'),(988980,'deals','.p-sample-checkout-index .datepicker-inline','padding-top','10','','','.p-sample-checkout-index'),(988984,'deals','.w-product-multi-inventory .radio-attributes .option-item','padding-top','10','','','.w-product-multi-inventory'),(988985,'deals','.b-products-listing .products-listing .radio-attributes .option','padding-top','10','','','.b-products-listing'),(988986,'deals','.w-product-collection .item','padding-top','10','','','.w-product-collection'),(988987,'deals','.w-product-collection .right-area','padding-top','30','','','.w-product-collection'),(988988,'deals','.w-product-collection .choose-products','padding-top','20','','','.w-product-collection'),(988989,'deals','.w-product-collection .right-area .btn','padding-top','12','','','.w-product-collection'),(988990,'deals','.w-product-attributes .radio-attributes .option-item','padding-top','10','','','.w-product-attributes'),(988991,'deals','.w-product-properties .property-ul','padding-top','0','','','.w-product-properties'),(988992,'deals','.w-product-properties .properties-table','padding-top','0','','','.w-product-properties'),(988993,'deals','.w-product-properties li','padding-top','5','','','.w-product-properties'),(988994,'deals','.w-questionnaire-widgets-questionnaire .question + .question','padding-top','20','','','.w-questionnaire-widgets-questionnaire'),(988995,'deals','.w-product-groups .radioBox','padding-top','0','','','.w-product-groups'),(988996,'deals','.w-product-groups .radioBox label','padding-top','0','','','.w-product-groups'),(988997,'deals','.w-product-groups .radioBox label .containerBlock','padding-top','5','','','.w-product-groups'),(988998,'deals','.w-product-groups .radioBox label .containerBlock','padding-top','5','5660','','.w-product-groups'),(988999,'deals','.b-products-listing .mix-attributes .attribute-qty-block','padding-top','5','','','.b-products-listing'),(989000,'deals','.b-products-listing .products-listing .attribute-qty-block','padding-top','5','','','.b-products-listing'),(989001,'deals','.blogsidebar','padding-top','0','5639','',''),(989002,'deals','.w-product-custom-bundle .item','padding-top','10','','','.w-product-custom-bundle'),(989003,'deals','.w-product-custom-bundle .right-area','padding-top','30','','','.w-product-custom-bundle'),(989004,'deals','.w-product-custom-bundle .choose-products','padding-top','10','','','.w-product-custom-bundle'),(989005,'deals','.w-product-custom-bundle .main-button .btn, .w-product-custom-bundle .main-button .btn-2','padding-top','14','','','.w-product-custom-bundle'),(989006,'deals','.w-product-custom-bundle .right-area','padding-top','0','5639','','.w-product-custom-bundle'),(989007,'deals','.w-product-custom-bundle .right-area .price','padding-top','20','5639','','.w-product-custom-bundle'),(989008,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list'),(989009,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','padding-top','0','','','.w-catalog-pages-category-pages-last-list'),(989010,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list-block'),(989011,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','padding-top','0','','','.w-catalog-pages-category-pages-last-list-block'),(989012,'deals','.w-delivery-location-location-list .deliveryListParrent','padding-top','10','','','.w-delivery-location-location-list'),(989013,'deals','.w-delivery-location-location-list ul','padding-top','0','','','.w-delivery-location-location-list'),(989014,'deals','.w-delivery-location-location-description .deliveryDesc','padding-top','10','','','.w-delivery-location-location-description'),(989015,'deals','.w-delivery-location-location-list .deliveryListParrent a','padding-top','6','','','.w-delivery-location-location-list'),(989016,'deals','.w-delivery-location-location-list .deliveryList li a','padding-top','10','','','.w-delivery-location-location-list'),(989017,'deals','.w-sale-category .holder-1','padding-top','20','','','.w-sale-category'),(989018,'deals','.w-sale-category .holder-2','padding-top','20','','','.w-sale-category'),(989019,'deals','.w-sale-category .left-count','padding-top','5','','','.w-sale-category'),(989020,'deals','.w-sale-category .left-text-left','padding-top','24','','','.w-sale-category'),(989021,'deals','.w-sale-category .left-text-right','padding-top','24','','','.w-sale-category'),(989022,'deals','.w-sale-category .text','padding-top','10','','','.w-sale-category'),(989023,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(989024,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(989025,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(989026,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','padding-top','0','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(989027,'deals','.w-delivery-location-list-by-page .item','padding-top','20','','','.w-delivery-location-list-by-page'),(989028,'deals','.w-product-properties-icons .property-image','padding-top','10','','','.w-product-properties-icons'),(989029,'deals','.w-product-properties-icons .hover-box-content','padding-top','10','','','.w-product-properties-icons'),(989030,'deals','.w-delivery-location-cross-pages .item','padding-top','20','','','.w-delivery-location-cross-pages'),(989031,'deals','.w-delivery-location-product-categories .item.category-link','padding-top','15','','','.w-delivery-location-product-categories'),(989032,'deals','.w-delivery-location-product-categories .item.category-link','padding-top','10','5639','','.w-delivery-location-product-categories'),(989033,'deals','.w-delivery-location-product-categories .item.category-link','padding-top','10','5660','','.w-delivery-location-product-categories'),(989034,'deals','.w-delivery-location-product-categories .name','padding-top','10','','','.w-delivery-location-product-categories'),(989035,'deals','.delivery-options-popup','padding-top','20','','',''),(989036,'deals','.w-product-bonus-points .bonus-points-cost','padding-top','8','','','.w-product-bonus-points'),(989037,'deals','.w-product-designer-designer .grnamebox .title-sortable','padding-top','7','','','.w-product-designer-designer'),(989038,'deals','.w-product-designer-designer .prodDesignerType label','padding-top','10','','','.w-product-designer-designer'),(989039,'deals','.w-press-reviews-widgets-press-reviews ','padding-top','30','','','.w-press-reviews-widgets-press-reviews'),(989040,'deals','.w-press-reviews-widgets-press-reviews .author','padding-top','0','','','.w-press-reviews-widgets-press-reviews'),(989041,'deals','.w-press-reviews-widgets-press-reviews .item','padding-top','20','','','.w-press-reviews-widgets-press-reviews'),(989042,'deals','.w-press-reviews-widgets-press-reviews .press-reviews-button','padding-top','30','','','.w-press-reviews-widgets-press-reviews'),(989043,'deals','.w-press-reviews-widgets-press-reviews .review','padding-top','10','','','.w-press-reviews-widgets-press-reviews'),(989044,'deals','.w-press-reviews-widgets-press-reviews ','padding-top','20','5630','','.w-press-reviews-widgets-press-reviews'),(989045,'deals','.w-press-reviews-widgets-press-reviews .item','padding-top','15','5630','','.w-press-reviews-widgets-press-reviews'),(989046,'deals','.w-press-reviews-widgets-press-reviews .review','padding-top','10','5630','','.w-press-reviews-widgets-press-reviews'),(989047,'deals','.w-press-reviews-widgets-press-reviews-list .item','padding-top','0','','','.w-press-reviews-widgets-press-reviews-list'),(989048,'deals','.w-press-reviews-widgets-press-reviews-list .short-description','padding-top','0','','','.w-press-reviews-widgets-press-reviews-list'),(989049,'deals','.b-products-listing .productGroup label a','padding-top','5','','','.b-products-listing'),(989050,'deals','.w-gift-wrap-message-checkout .text','padding-top','2','','','.w-gift-wrap-message-checkout'),(989051,'deals','.w-support-system-filter ','padding-top','0','','','.w-support-system-filter'),(989052,'deals','.w-support-system-filter .filter_cats','padding-top','0','','','.w-support-system-filter'),(989053,'deals','.w-support-system-listing .support-head','padding-top','13','','','.w-support-system-listing'),(989054,'deals','.w-communication-post .btn.refresh','padding-top','0','','','.w-communication-post'),(989055,'deals','.w-rma-returns-history .btn','padding-top','7','','','.w-rma-returns-history'),(989056,'deals','.w-rma-returns-history .column','padding-top','0','','','.w-rma-returns-history'),(989057,'deals','.w-rma-returns-history .column .title','padding-top','5','','','.w-rma-returns-history'),(989058,'deals','.w-rma-returns-history .topRow','padding-top','10','','','.w-rma-returns-history'),(989059,'deals','.w-rma-returns-history .column:last-child .title','padding-top','0','','screen and (max-width: 768px)','.w-rma-returns-history'),(989060,'deals','.w-show-inactive-show-inactive .out_stock_label','padding-top','2','','','.w-show-inactive-show-inactive'),(989061,'deals','.w-product-designer-designer .productDesignerBox ul','padding-top','0','','','.w-product-designer-designer'),(989062,'deals','.w-product-configurator .pc-item','padding-top','0','','','.w-product-configurator'),(989063,'deals','.w-product-configurator .pc_stock','padding-top','0','','','.w-product-configurator'),(989064,'deals','.w-product-configurator .pc_item','padding-top','10','5639','','.w-product-configurator'),(989065,'deals','.w-product-configurator .pc_attr','padding-top','5','5630','','.w-product-configurator'),(989066,'deals','.b-products-listing .promos-info .promo-name-span','padding-top','3','','','.b-products-listing'),(989067,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul','padding-top','0','','','.w-catalog-pages-category-pages-list'),(989068,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','padding-top','0','','','.w-catalog-pages-category-pages-list'),(989069,'deals','.w-predefined-promotion .nextdiscount .content > div','padding-top','10','','','.w-predefined-promotion'),(989070,'deals','.w-predefined-promotion .nextdiscount .promo-for-each','padding-top','3','','','.w-predefined-promotion'),(989071,'deals','.w-predefined-promotion .prom-multi-discount .promo-product','padding-top','20','','','.w-predefined-promotion'),(989072,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','padding-top','0','','','.w-predefined-promotion'),(989073,'deals','.w-predefined-promotion .promo-cart-discount .master .item','padding-top','0','','','.w-predefined-promotion'),(989074,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','padding-top','0','','','.w-predefined-promotion'),(989075,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition-holder','padding-top','0','','','.w-predefined-promotion'),(989076,'deals','.w-predefined-promotion .promo-cart-discount .slave .item','padding-top','20','','','.w-predefined-promotion'),(989077,'deals','.w-predefined-promotion .promo-item','padding-top','30','','','.w-predefined-promotion'),(989078,'deals','.w-predefined-promotion .promo-salemaker .discount','padding-top','0','','','.w-predefined-promotion'),(989079,'deals','.w-predefined-promotion .promo-salemaker .item','padding-top','20','','','.w-predefined-promotion'),(989080,'deals','.w-supplier-purchase-supplier-products .item','padding-top','10','','','.w-supplier-purchase-supplier-products'),(989081,'deals','.headerWrap ','padding-top','10','','','.headerWrap'),(989082,'deals','.headerWrap .searchIcon','padding-top','10','','','.headerWrap'),(989083,'deals','.headerWrap >div.block, .headerWrap .headerInside >div.block','padding-top','0','','','.headerWrap'),(989085,'deals','.parallaxWrap .w-info-page','padding-top','15','','','.parallaxWrap'),(989086,'deals','.bannersWrap .text','padding-top','20','','','.bannersWrap'),(989087,'deals','.headerWrap .menu-style[data-style=\"1\"] li.back-button','padding-top','10','','','.headerWrap'),(989088,'deals','.w-categories .categories h2','padding-top','0','','','.w-categories'),(989089,'deals','.w-categories .item','padding-top','5','5630','','.w-categories'),(989090,'deals','.filterLine ','padding-top','0','','','.filterLine'),(989091,'deals','.filterLine .before','padding-top','6','','','.filterLine'),(989092,'deals','.filterLine .choose-filters li .btn-clear','padding-top','3','','','.filterLine'),(989093,'deals','.w-filters .filter-widget-horizontal .filter-box-content','padding-top','20','','','.w-filters'),(989094,'deals','.w-filters .filter-widget-horizontal .filter-box-head','padding-top','8','','','.w-filters'),(989095,'deals','.w-filters .choose-filters > li > *','padding-top','5','','','.w-filters'),(989096,'deals','.w-filters .choose-filters > li','padding-top','0','','','.w-filters'),(989097,'deals','.b-products-listing .products-listing .bonus-points-cost','padding-top','8','','','.b-products-listing'),(989098,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span','padding-top','5','','','.w-product-quantity-discounts'),(989099,'deals','.b-quantity .qty-box input[type=\'text\']','padding-top','5','','','.b-quantity'),(989100,'deals','.w-product-groups .property-category-heading','padding-top','3','','','.w-product-groups'),(989101,'deals','.w-product-groups .property-category-heading + .property-category-content','padding-top','10','','','.w-product-groups'),(989102,'deals','.w-product-name h1','padding-top','0','','','.w-product-name'),(989103,'deals','.w-product-buttons button.add-to-cart','padding-top','14','','','.w-product-buttons'),(989104,'deals','.messageBox .info','padding-top','20','','',''),(989105,'deals','.b-products-listing span.add-to-personal-catalog, .b-products-listing span.del-from-personal-catalog','padding-top','8','','','.b-products-listing'),(989106,'deals','.w-product-price .price','padding-top','7','','','.w-product-price'),(989107,'deals','.savings-ico .heading-3','padding-top','0','','','.savings-ico'),(989108,'deals','.w-support-system-listing .tp-head','padding-top','10','','','.w-support-system-listing'),(989109,'deals','.w-support-system-listing .support-item-body-content .tp-head','padding-top','0','','','.w-support-system-listing'),(989110,'deals','.w-delayed-despatch-checkout .btn','padding-top','6','','','.w-delayed-despatch-checkout'),(989111,'deals','.w-coupons-and-vauchers-checkout .btn','padding-top','6','','','.w-coupons-and-vauchers-checkout'),(989112,'deals','.b-table-list .table-list td','padding-top','5','','','.b-table-list'),(989113,'deals','.b-table-list .table-list th','padding-top','5','','','.b-table-list'),(989114,'deals','.b-table .table .headings td','padding-top','5','','','.b-table'),(989115,'deals','.b-table .table td','padding-top','15','','','.b-table'),(989116,'deals','.headerWrap .headerInside >div.block','padding-top','0','5639','','.headerWrap'),(989117,'deals','.headerWrap .w-contacts.phone','padding-top','8','5639','','.headerWrap'),(989118,'deals','.homeBanner .carousel .bottom-center > span','padding-top','50','3','','.homeBanner'),(989119,'deals','.homeBanner .carousel .bottom-center > span','padding-top','10','5644','','.homeBanner'),(989120,'deals','.homeBanner .carousel .bottom-center > span','padding-top','5','5660','','.homeBanner'),(989121,'deals','.homeBanner .carousel .bottom-center > span','padding-top','30','5660,3','','.homeBanner'),(989123,'deals','.bannersWrap .text','padding-top','15','5639','','.bannersWrap'),(989124,'deals','.w-filters .filter-widget-horizontal .head-filter-widget','padding-top','5','5639','','.w-filters'),(989125,'deals','.w-filters .filter-widget-horizontal .filter-box','padding-top','0','5639','','.w-filters'),(989126,'deals','.w-filters .filter_buttons','padding-top','10','','','.w-filters'),(989127,'deals','.b-info .info','padding-top','20','','','.b-info'),(989128,'deals','.b-info .info li','padding-top','0','','','.b-info'),(989129,'deals','.b-info .info ul','padding-top','0','','','.b-info'),(989130,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','padding-top','10','5630','','.headerWrap'),(989131,'deals','.b-personal-catalog-popup button.btn.btn-save-new-list','padding-top','6','','','.b-personal-catalog-popup'),(989132,'deals','.w-account-personal-catalog .list-row-action li','padding-top','5','','','.w-account-personal-catalog'),(989133,'deals','.w-account-personal-catalog .list-row-action ul','padding-top','0','','','.w-account-personal-catalog'),(989134,'deals','.w-multi-cart-save-cart .btn','padding-top','6','5660','','.w-multi-cart-save-cart'),(989135,'deals','.w-product-wishlist-button .btn','padding-top','0','','','.w-product-wishlist-button'),(989136,'deals','.w-catalog-compare .compare-list','padding-top','30','','','.w-catalog-compare'),(989137,'deals','.homeBanner .banner-item .banner-text','padding-top','0','','','.homeBanner'),(989138,'deals','.homeBanner .text-bottom-center .banner-text-holder','padding-top','50','3','','.homeBanner'),(989139,'deals','.homeBanner .text-bottom-left .banner-text-holder','padding-top','50','3','','.homeBanner'),(989140,'deals','.homeBanner .text-bottom-right .banner-text-holder','padding-top','50','3','','.homeBanner'),(989141,'deals','.homeBanner .banner-item .banner-text-holder','padding-top','10','5644','','.homeBanner'),(989142,'deals','.homeBanner .banner-item .banner-text-holder','padding-top','5','5660','','.homeBanner'),(989143,'deals','.homeBanner .text-bottom-center .banner-text-holder','padding-top','30','5660,3','','.homeBanner'),(989144,'deals','.homeBanner .text-bottom-left .banner-text-holder','padding-top','30','5660,3','','.homeBanner'),(989145,'deals','.homeBanner .text-bottom-right .banner-text-holder','padding-top','30','5660,3','','.homeBanner'),(989146,'deals','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-item','padding-top','5','','','.w-promotions-widgets-promotion-icons-desc'),(989147,'deals','.order-summary .w-cart-listing .item > div ~ div','padding-top','0','','','.order-summary'),(989148,'deals','.w-cart-discount-coupon .discount-box','padding-top','5','','','.w-cart-discount-coupon'),(989149,'deals','.main-content','padding-top','0','','',''),(989150,'deals','.breadcrumb-box ','padding-top','13','','','.breadcrumb-box'),(989151,'deals','.p-quote-checkout-index .order-summary','padding-top','10','','','.p-quote-checkout-index'),(989152,'deals','.w-promotions-widgets-promotions select','padding-top','0','','','.w-promotions-widgets-promotions'),(989175,'deals','.account-address-book .address_book','padding-top','0','','','.account-address-book'),(989176,'deals','.account-address-book .address_book h1','padding-top','0','','','.account-address-book'),(989177,'deals','.account-address-book .address_book h2','padding-top','15','','','.account-address-book'),(989178,'deals','.account-address-book .address_book, .account-address-book .account_history_info','padding-top','10','','','.account-address-book'),(989179,'deals','.account-address-book .btn-edit','padding-top','0','4','','.account-address-book'),(989180,'deals','.account-address-book .buttonBox','padding-top','15','','','.account-address-book'),(989181,'deals','.account-address-book .rightMes ul','padding-top','22','','','.account-address-book'),(989182,'deals','.account-address-book .topButtons','padding-top','0','','','.account-address-book'),(989196,'deals','.account-order-pay .contentColumn','padding-top','10','','','.account-order-pay'),(989197,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','padding-top','5','','','.account-order-pay'),(989198,'deals','.account-order-pay .history_attr','padding-top','5','','','.account-order-pay'),(989199,'deals','.account-order-pay .history_info > div + div','padding-top','0','','','.account-order-pay'),(989200,'deals','.account-order-pay .history_info > div','padding-top','0','5639','','.account-order-pay'),(989201,'deals','.account-order-pay .history_info > div + div','padding-top','0','5639','','.account-order-pay'),(989202,'deals','.account-samples .orders-table td, .account-samples .order-info td, .account-samples .order_history_table td','padding-top','10','','','.account-samples'),(989203,'deals','.account-samples .orders-table th','padding-top','2','','','.account-samples'),(989204,'deals','.account-samples .order_history_table th','padding-top','10','','','.account-samples'),(989205,'deals','.account-samples .view_link','padding-top','0','','','.account-samples'),(989206,'deals','.account-samples .orders-table .td-alignright','padding-top','5','5639','','.account-samples'),(989207,'deals','.account-samples .orders-table td','padding-top','5','5639','','.account-samples'),(989208,'deals','.account-sample-info .contentColumn','padding-top','10','','','.account-sample-info'),(989209,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','padding-top','5','','','.account-sample-info'),(989210,'deals','.account-sample-info .history_attr','padding-top','5','','','.account-sample-info'),(989211,'deals','.account-sample-info .history_info > div + div','padding-top','0','','','.account-sample-info'),(989212,'deals','.account-sample-info .popup-tracking-number','padding-top','10','','','.account-sample-info'),(989213,'deals','.account-sample-info .history_info > div','padding-top','0','5639','','.account-sample-info'),(989214,'deals','.account-sample-info .history_info > div + div','padding-top','0','5639','','.account-sample-info'),(989215,'deals','.catalog-product-wrap .next-product','padding-top','20','','','.catalog-product-wrap'),(989216,'deals','.catalog-product-wrap .pn-direction','padding-top','0','','','.catalog-product-wrap'),(989217,'deals','.catalog-product-wrap .pn-image','padding-top','20','','','.catalog-product-wrap'),(989218,'deals','.catalog-product-wrap .pn-name','padding-top','15','','','.catalog-product-wrap'),(989219,'deals','.catalog-product-wrap .prev-product','padding-top','20','','','.catalog-product-wrap'),(989220,'deals','.catalog-product-wrap .next-product','padding-top','20','5639','','.catalog-product-wrap'),(989221,'deals','.catalog-product-wrap .pn-direction','padding-top','0','5639','','.catalog-product-wrap'),(989222,'deals','.catalog-product-wrap .prev-product','padding-top','20','5639','','.catalog-product-wrap'),(989223,'deals','.shopping-cart-index .cart-page .empty','padding-top','100','','','.shopping-cart-index'),(989224,'deals','.shopping-cart-index .cart-popup .cart-page, .shopping-cart-index .cart-popup .wishlist-page','padding-top','0','','','.shopping-cart-index'),(989225,'deals','.shopping-cart-index .closeable-heading .heading-3','padding-top','0','','','.shopping-cart-index'),(989226,'deals','.checkout-index-wrap .checkout-cart-listing.main-listing','padding-top','30','','','.checkout-index-wrap'),(989227,'deals','.checkout-index-wrap .closeable-heading + .closeable-content','padding-top','10','','','.checkout-index-wrap'),(989228,'deals','.checkout-index-wrap .datepicker-inline','padding-top','10','','','.checkout-index-wrap'),(989229,'deals','.checkout-index-wrap .dob-hide label','padding-top','5','','','.checkout-index-wrap'),(989230,'deals','.checkout-index-wrap .edit-address-popup','padding-top','20','','','.checkout-index-wrap'),(989231,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons a, .checkout-index-wrap .btn-cancel','padding-top','7','','','.checkout-index-wrap'),(989232,'deals','.checkout-order-confirmation .price-row','padding-top','5','','','.checkout-order-confirmation'),(989233,'deals','.checkout-success-wrap .page-success .text-1','padding-top','120','','','.checkout-success-wrap'),(989234,'deals','.checkout-success-wrap .page-success .text-1','padding-top','5','5630','','.checkout-success-wrap'),(989235,'deals','.checkout-login-wrap .password-forgotten-link','padding-top','0','','','.checkout-login-wrap'),(989236,'deals','.b-form .columns .col-2','padding-top','0','','','.b-form'),(989237,'deals','.b-bottom .pop-up-content','padding-top','20','','','.b-bottom'),(989238,'deals','.b-slick .slick-dots li','padding-top','5','','','.b-slick'),(989240,'deals','.success-page .check-ico-block','padding-top','20','','','.success-page'),(989241,'deals','.success-page .order_totals .price-row','padding-top','5','','','.success-page'),(989242,'deals','.success-page .page-success .text-1','padding-top','5','5630','','.success-page'),(989243,'deals','.success-page .price-row','padding-top','5','','','.success-page'),(989244,'deals','.success-page .totals-line','padding-top','10','','','.success-page'),(989245,'deals','.success-page .w-cart-listing .qty','padding-top','0','','','.success-page'),(989249,'deals','.b-multi-page-checkout .multi-page-checkout','padding-top','20','','','.b-multi-page-checkout'),(989250,'deals','.b-multi-page-checkout .multi-page-checkout .buttons','padding-top','0','','','.b-multi-page-checkout'),(989251,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-content','padding-top','20','','','.b-multi-page-checkout'),(989252,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading','padding-top','8','','','.b-multi-page-checkout'),(989253,'deals','.bannersWrap .rightBanner .banner-text','padding-top','20','','','.bannersWrap'),(989255,'deals','.footer-menu .level-1 > li > .no-link','padding-top','5','5639','','.footer-menu'),(989256,'deals','.footer-menu .level-3 > li','padding-top','10','5639','','.footer-menu'),(989257,'deals','.footer-menu .level-3 > li.back-button','padding-top','9','5639','','.footer-menu'),(989258,'deals','.footer-menu .level-4 > li','padding-top','5','5639','','.footer-menu'),(989259,'deals','.w-banner .banner-text','padding-top','20','','','.w-banner'),(989260,'deals','.w-banner .carousel-text > span','padding-top','20','','','.w-banner'),(989261,'deals','.w-catalog-paging .paging-item','padding-top','0','','','.w-catalog-paging'),(989270,'deals','.w-menu-slider > ul > li > a','padding-top','5','','','.w-menu-slider'),(989271,'deals','.w-menu-slider > ul > li > ul > li','padding-top','5','','','.w-menu-slider'),(989272,'deals','.w-menu-slider ul, .w-menu-slider li','padding-top','0','','','.w-menu-slider'),(989273,'deals','.bannersWrap .leftBanner .banner-text','padding-top','0','','','.bannersWrap'),(989274,'deals','.b-data-table table.dataTable tbody td','padding-top_important','important','','','.b-data-table'),(989275,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','padding-top_important','important','','','.b-data-table'),(989276,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','padding-top_important','important','','','.b-data-table'),(989277,'deals','.b-data-table table.dataTable thead td','padding-top_important','important','','','.b-data-table'),(989278,'deals','.preFooter .w-banner .single_banner picture','padding-top_important','important','','','.preFooter'),(989279,'deals','.filterLine ','padding-top_important','important','','','.filterLine'),(989280,'deals','.success-page .totals-line','padding-top_important','important','','','.success-page'),(989281,'deals','.w-categories .image','padding_bottom_measure','%','','','.w-categories'),(989282,'deals','.w-top-categories .image','padding_bottom_measure','%','','','.w-top-categories'),(989283,'deals','.parallaxWrap .w-info-page','padding_bottom_measure','%','','','.parallaxWrap'),(989284,'deals','.b-upload-file .upload-file-template','padding_left_measure','%','','','.b-upload-file'),(989285,'deals','.w-cart-give-away .ga_img','padding_left_measure','%','','','.w-cart-give-away'),(989286,'deals','.b-product-images .media-popup .mp-content','padding_left_measure','%','','','.b-product-images'),(989287,'deals','.w-product-collection .right-area','padding_left_measure','%','','','.w-product-collection'),(989288,'deals','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding_left_measure','%','','','.w-delivery-location-featured-list'),(989289,'deals','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n)','padding_left_measure','%','5660','','.w-delivery-location-featured-list'),(989291,'deals','.bannersWrap .rightBanner','padding_left_measure','%','','','.bannersWrap'),(989294,'deals','.account-order-pay .history_info > div + div','padding_left_measure','%','','','.account-order-pay'),(989295,'deals','.account-sample-info .history_info > div + div','padding_left_measure','%','','','.account-sample-info'),(989296,'deals','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(989297,'deals','.b-upload-file .upload-file-template','padding_right_measure','%','','','.b-upload-file'),(989298,'deals','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(989299,'deals','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(989300,'deals','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(989301,'deals','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(989302,'deals','.w-cart-give-away .ga_img','padding_right_measure','%','','','.w-cart-give-away'),(989303,'deals','.w-brands .brands-listing > div','padding_right_measure','%','','','.w-brands'),(989304,'deals','.b-product-images .media-popup .mp-content','padding_right_measure','%','','','.b-product-images'),(989305,'deals','.w-product-bundle .attributes-item','padding_right_measure','%','','','.w-product-bundle'),(989306,'deals','.w-product-in-bundles .attributes-item','padding_right_measure','%','','','.w-product-in-bundles'),(989307,'deals','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding_right_measure','%','','','.w-delivery-location-featured-list'),(989308,'deals','.w-delivery-location-featured-list .deliveryList > ul > li:nth-child(2n+1)','padding_right_measure','%','5660','','.w-delivery-location-featured-list'),(989310,'deals','.bannersWrap .leftBanner','padding_right_measure','%','','','.bannersWrap'),(989312,'deals','.price .old','padding_top_measure','em','','',''),(989313,'deals','.parallaxWrap .w-info-page','padding_top_measure','%','','','.parallaxWrap'),(989314,'deals','.b-slick .slick-slide.dragging img','pointer-events','none','','','.b-slick'),(989315,'deals','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(989316,'deals','.w-checkout-shipping-address .addresses .address-item label','position','relative','','','.w-checkout-shipping-address'),(989317,'deals','.b-form .radio-buttons .radio-button','position','relative','','','.b-form'),(989318,'deals','.w-checkout-billing-address .addresses .address-item label','position','relative','','','.w-checkout-billing-address'),(989319,'deals','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position','absolute','','','.b-switch'),(989320,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','position','relative','3','','.b-switch'),(989321,'deals','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(989322,'deals','.b-fancybox .filter-listing-preloader','position','absolute','','','.b-fancybox'),(989323,'deals','.b-fancybox .filter-listing-loader','position','absolute','','','.b-fancybox'),(989324,'deals','.w-promotions .prom-multi-discount > .heading','position','relative','3','','.w-promotions'),(989325,'deals','.w-promotions .prom-multi-discount .promo-range','position','relative','','','.w-promotions'),(989326,'deals','.w-promotions .promo-date','position','relative','','','.w-promotions'),(989331,'deals','.p-sample-checkout-success .page-success > div','position','relative','','','.p-sample-checkout-success'),(989332,'deals','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(989333,'deals','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(989334,'deals','.testimonials .reviews-list span','position','relative','','',''),(989335,'deals','.testimonials .heading-3','position','relative','','',''),(989336,'deals','.testimonials .review','position','absolute','3','',''),(989337,'deals','.testimonials .review','position','relative','','',''),(989338,'deals','.testimonials .rating','position','relative','','',''),(989339,'deals','.testimonials .heading-3','position','absolute','3','',''),(989340,'deals','.w-promotions .prom-multi-discount .products','position','relative','','','.w-promotions'),(989341,'deals','.w-promotions .icon','position','relative','','','.w-promotions'),(989342,'deals','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','position','relative','3','','.w-promotions'),(989343,'deals','.w-promotions .promo-salemaker .discount','position','relative','','','.w-promotions'),(989344,'deals','.w-promotions .promo-cart-discount .slave .content','position','relative','','','.w-promotions'),(989345,'deals','.w-promotions .promo-cart-discount .promo-min-qty','position','relative','','','.w-promotions'),(989346,'deals','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','position','relative','3','','.w-promotions'),(989347,'deals','.b-preloader .preloader','position','absolute','3','','.b-preloader'),(989348,'deals','.b-preloader .preloader','position','absolute','','','.b-preloader'),(989349,'deals','.w-checkout-create-account .account-benefits strong','position','relative','3','','.w-checkout-create-account'),(989350,'deals','.w-cart-compare .cart-cell > div','position','relative','','','.w-cart-compare'),(989352,'deals','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(989353,'deals','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(989354,'deals','.closeable-heading','position','absolute','3','',''),(989355,'deals','.closeable-heading','position','relative','','',''),(989356,'deals','.b-messages .messBtnMenuDelete','position','relative','3','','.b-messages'),(989357,'deals','.b-messages .messMenuButton span','position','relative','','','.b-messages'),(989358,'deals','.b-messages .messBtnMenuStarred','position','relative','3','','.b-messages'),(989359,'deals','.b-messages span.starred::before','position','relative','','','.b-messages'),(989360,'deals','.b-messages .messBtnMenuUnread','position','relative','3','','.b-messages'),(989361,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-messages'),(989362,'deals','.b-info-popup .info-popup div','position','absolute','3','','.b-info-popup'),(989363,'deals','.p-payer-order-confirmation .order-ico','position','relative','3','','.p-payer-order-confirmation'),(989364,'deals','.p-payer-order-confirmation .comment-ico','position','relative','3','','.p-payer-order-confirmation'),(989365,'deals','.p-payer-order-confirmation .discount-ico','position','relative','3','','.p-payer-order-confirmation'),(989366,'deals','.p-payer-order-pay .order-ico','position','relative','3','','.p-payer-order-pay'),(989367,'deals','.w-checkout-terms .terms-box','position','relative','','','.w-checkout-terms'),(989368,'deals','.p-payer-order-pay .discount-ico','position','relative','3','','.p-payer-order-pay'),(989369,'deals','.p-payer-order-pay .comment-ico','position','relative','3','','.p-payer-order-pay'),(989370,'deals','.w-checkout-terms .required-message-wrap','position','static','','','.w-checkout-terms'),(989371,'deals','.w-checkout-terms input[type=\"checkbox\"]','position','relative','','','.w-checkout-terms'),(989372,'deals','.w-checkout-shipping-address .genders-title input','position','relative','','','.w-checkout-shipping-address'),(989373,'deals','.b-fancybox #fancybox-loading','position','fixed','','','.b-fancybox'),(989374,'deals','.b-form .radio-button input[type=\"radio\"]','position','relative','','','.b-form'),(989375,'deals','.b-fancybox .fancybox-wrap','position','absolute','','','.b-fancybox'),(989376,'deals','.b-upload-file .snapshot','position','absolute','','','.b-upload-file'),(989378,'deals','.b-rating .glyphicon','position','relative','','','.b-rating'),(989379,'deals','.w-checkout-shipping-choice input:checked + span:before','position','absolute','','','.w-checkout-shipping-choice'),(989380,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(989381,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(989382,'deals','.w-upload-customer-id-upload-customer-id-form .upload-remove','position','absolute','','','.w-upload-customer-id-upload-customer-id-form'),(989383,'deals','.w-upload-customer-id-upload-customer-id-form .dz-details','position','relative','','','.w-upload-customer-id-upload-customer-id-form'),(989384,'deals','.b-switch .bootstrap-switch','position','relative','','','.b-switch'),(989385,'deals','.w-coupons-and-vauchers-checkout .btn-remove','position','relative','','','.w-coupons-and-vauchers-checkout'),(989386,'deals','.b-products-listing .products-listing .radio-attributes input','position','relative','','','.b-products-listing'),(989387,'deals','.w-checkout-bonus-points .btn-remove','position','relative','','','.w-checkout-bonus-points'),(989388,'deals','.b-products-listing .products-listing .btn-buy','position','relative','3','','.b-products-listing'),(989389,'deals','.b-form .col-3','position','relative','','','.b-form'),(989392,'deals','.w-menu-horizontal li','position','relative','','','.w-menu-horizontal'),(989393,'deals','.b-form .billing-address','position','relative','','','.b-form'),(989394,'deals','.w-quote .cart-box-link','position','relative','','','.w-quote'),(989395,'deals','.b-form .form-buttons','position','relative','','','.b-form'),(989396,'deals','.b-fancybox .fancybox-title-over-wrap','position','absolute','','','.b-fancybox'),(989397,'deals','.b-fancybox .fancybox-title-outside-wrap','position','relative','','','.b-fancybox'),(989400,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','position','absolute','','','.b-switch'),(989401,'deals','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(989407,'deals','.w-cart-compare .atr-col','position','relative','','','.w-cart-compare'),(989409,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','position','relative','','','.b-switch'),(989410,'deals','.b-switch .candlestick-wrapper','position','relative','','','.b-switch'),(989411,'deals','.b-bottom .footerTitle','position','absolute','5630,4','','.b-bottom'),(989412,'deals','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(989413,'deals','.b-select-suggest .select2-measure-scrollbar','position','absolute','','','.b-select-suggest'),(989414,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position','absolute','','','.b-select-suggest'),(989416,'deals','.w-reviews .review','position','relative','','','.w-reviews'),(989417,'deals','.w-reviews .heading-3','position','relative','','','.w-reviews'),(989418,'deals','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(989420,'deals','.b-info-popup .info-popup div','position','absolute','','','.b-info-popup'),(989421,'deals','.bell-ico .heading-2','position','relative','3','','.bell-ico'),(989424,'deals','.b-select-suggest .select2-search-choice-close','position','absolute','','','.b-select-suggest'),(989425,'deals','.view-all','position','absolute','3','',''),(989426,'deals','.view-all','position','relative','','',''),(989427,'deals','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(989428,'deals','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(989429,'deals','.view-all .btn','position','relative','','',''),(989432,'deals','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(989434,'deals','.b-form .checkbox-style','position','absolute','','','.b-form'),(989436,'deals','.edit-link','position','relative','','',''),(989437,'deals','.message.success','position','relative','3','',''),(989439,'deals','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(989440,'deals','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(989441,'deals','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(989442,'deals','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(989443,'deals','.b-upload-file .upload-remove','position','absolute','','','.b-upload-file'),(989445,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','position','absolute','','','.b-switch'),(989447,'deals','.w-cart-bonus-points .btn-remove','position','relative','','','.w-cart-bonus-points'),(989448,'deals','.w-multi-cart-actions .cart-actions','position','relative','','','.w-multi-cart-actions'),(989449,'deals','.w-reviews .review','position','absolute','3','','.w-reviews'),(989450,'deals','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(989452,'deals','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(989453,'deals','.b-form .addresses .address-item input[type=\"radio\"]','position','relative','','','.b-form'),(989454,'deals','.w-product-reviews .reviews-list .review','position','relative','','','.w-product-reviews'),(989455,'deals','.b-fancybox .fancybox-skin','position','relative','','','.b-fancybox'),(989456,'deals','.b-fancybox .fancybox-overlay-fixed','position','fixed','','','.b-fancybox'),(989457,'deals','.b-fancybox .fancybox-overlay','position','absolute','','','.b-fancybox'),(989458,'deals','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(989461,'deals','.b-pass-strength .pass-strength span','position','absolute','','','.b-pass-strength'),(989463,'deals','.b-fancybox .fancybox-nav','position','absolute','','','.b-fancybox'),(989464,'deals','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(989465,'deals','.w-promo-code .holder','position','relative','','','.w-promo-code'),(989466,'deals','.b-form .shipping-method .input input','position','relative','','','.b-form'),(989467,'deals','.w-reviews .heading-3','position','absolute','3','','.w-reviews'),(989468,'deals','.b-select-suggest .select2-container .select2-choice','position','relative','','','.b-select-suggest'),(989469,'deals','.b-select-suggest .select2-container','position','relative','','','.b-select-suggest'),(989470,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','position','relative','3','','.b-switch'),(989471,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','position','relative','3','','.b-switch'),(989473,'deals','.b-form .hide-billing-address','position','absolute','','','.b-form'),(989474,'deals','.b-form .radio-button input[type=\"radio\"].no','position','absolute','','','.b-form'),(989475,'deals','.b-form .payment-method .item-radio input','position','relative','','','.b-form'),(989476,'deals','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(989477,'deals','.w-reviews-content .review','position','absolute','3','','.w-reviews-content'),(989479,'deals','.p-quick-order-index .all-scroll-div','position','fixed','','','.p-quick-order-index'),(989480,'deals','.w-checkout-billing-address .genders-title input','position','relative','','','.w-checkout-billing-address'),(989481,'deals','.b-form .required-message-wrap','position','relative','','','.b-form'),(989482,'deals','.b-form .radio-button input[type=\"radio\"].no + span','position','relative','3','','.b-form'),(989483,'deals','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(989484,'deals','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(989485,'deals','.w-promotions .promo-cart-discount .slave .condition','position','relative','','','.w-promotions'),(989486,'deals','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(989489,'deals','.w-checkout-credit-amount .btn-remove','position','relative','','','.w-checkout-credit-amount'),(989491,'deals','.w-promo-code .holder','position','relative','','','.w-promo-code'),(989492,'deals','.b-info-popup .info-popup','position','relative','3','','.b-info-popup'),(989493,'deals','.b-autocomplete .ui-autocomplete','position','absolute','','','.b-autocomplete'),(989494,'deals','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(989495,'deals','.b-bottom .footerTitle','position','relative','5630','','.b-bottom'),(989496,'deals','.b-info-popup .info-popup','position','relative','','','.b-info-popup'),(989497,'deals','.b-upload-files .attach-active-holder .attach-file','position','absolute','','','.b-upload-files'),(989499,'deals','.w-cart-credit-amount .btn-remove','position','relative','','','.w-cart-credit-amount'),(989500,'deals','.b-fancybox .fancybox-close','position','absolute','','','.b-fancybox'),(989501,'deals','.b-form .required-message','position','absolute','','','.b-form'),(989502,'deals','.b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner','position','relative','','','.b-fancybox'),(989503,'deals','.w-product-customers-activity .customers-activity','position','fixed','','','.w-product-customers-activity'),(989504,'deals','.w-product-customers-activity .close','position','absolute','','','.w-product-customers-activity'),(989507,'deals','.w-cart-compare .remove-cart','position','absolute','','','.w-cart-compare'),(989508,'deals','.w-promo-code .holder','position','relative','','','.w-promo-code'),(989509,'deals','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(989511,'deals','.w-checkout-billing-address .addresses .address-item label input','position','absolute','','','.w-checkout-billing-address'),(989512,'deals','.w-checkout-shipping-choice input:checked + span','position','relative','','','.w-checkout-shipping-choice'),(989513,'deals','.w-checkout-shipping-choice input','position','absolute','','','.w-checkout-shipping-choice'),(989515,'deals','.w-quote .cart-box','position','relative','','','.w-quote'),(989516,'deals','.w-product-reviews .reviews-list span','position','relative','','','.w-product-reviews'),(989517,'deals','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(989518,'deals','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(989519,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','position','relative','','','.b-select-suggest'),(989520,'deals','.b-select-suggest .select2-container-multi .select2-choices','position','relative','','','.b-select-suggest'),(989521,'deals','.b-select-suggest .select2-results','position','relative','','','.b-select-suggest'),(989522,'deals','.w-image-maps .svg-wrap svg','position','absolute','','','.w-image-maps'),(989523,'deals','.w-checkout-shipping-address .addresses .address-item label input','position','absolute','','','.w-checkout-shipping-address'),(989524,'deals','.w-neighbour-checkout .bootstrap-switch','position','relative','','','.w-neighbour-checkout'),(989525,'deals','.b-select-suggest .select2-search','position','relative','','','.b-select-suggest'),(989526,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow','position','absolute','','','.b-select-suggest'),(989527,'deals','.b-select-suggest .select2-drop','position','absolute','','','.b-select-suggest'),(989528,'deals','.b-select-suggest .select2-drop-mask','position','fixed','','','.b-select-suggest'),(989529,'deals','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(989535,'deals','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(989537,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','position','absolute','','','.b-switch'),(989538,'deals','.b-pass-strength .pass-strength','position','relative','','','.b-pass-strength'),(989539,'deals','.p-sample-checkout-success .page-success','position','relative','','','.p-sample-checkout-success'),(989540,'deals','.w-menu-big li','position','static','','','.w-menu-big'),(989541,'deals','.w-promo-code .holder','position','relative','','','.w-promo-code'),(989542,'deals','.w-account-addresses-list .address-fields input[type=\"radio\"]','position','relative','','','.w-account-addresses-list'),(989543,'deals','.b-products-listing .products-listing .promos-info','position','absolute','','','.b-products-listing'),(989544,'deals','.b-products-listing .products-listing .image','position','relative','','','.b-products-listing'),(989545,'deals','.b-products-listing .hover-box-content','position','absolute','3','','.b-products-listing'),(989546,'deals','.b-products-listing .hover-box','position','relative','','','.b-products-listing'),(989547,'deals','.b-products-listing .hover-box-content','position','absolute','','','.b-products-listing'),(989548,'deals','.b-products-listing .loader','position','absolute','4','','.b-products-listing'),(989549,'deals','.b-products-listing .loader','position','absolute','3','','.b-products-listing'),(989550,'deals','.b-products-listing .loader','position','relative','','','.b-products-listing'),(989551,'deals','.w-catalog-b2b-add-button ','position','fixed','','','.w-catalog-b2b-add-button'),(989552,'deals','.b-products-listing .products-listing .qty-input.hidden','position','absolute','3','','.b-products-listing'),(989553,'deals','.b-products-listing .promo','position','absolute','','','.b-products-listing'),(989554,'deals','.b-products-listing .promo-icon','position','relative','','','.b-products-listing'),(989555,'deals','.b-products-listing .promos-info','position','relative','','','.b-products-listing'),(989556,'deals','.checkbox input:not(checked) + span:before','position','absolute','','',''),(989557,'deals','.checkbox input','position','ablolute','','',''),(989562,'deals','.w-promo-code .holder','position','relative','','','.w-promo-code'),(989563,'deals','.b-form .hide-box','position','relative','','','.b-form'),(989564,'deals','.b-fancybox .fancybox-title','position','relative','','','.b-fancybox'),(989565,'deals','.b-fancybox .fancybox-title-float-wrap','position','absolute','','','.b-fancybox'),(989567,'deals','.w-taxable input[type=\"radio\"]','position','relative','','','.w-taxable'),(989568,'deals','.b-form .eye-password-wrap','position','relative','','','.b-form'),(989569,'deals','.b-form .eye-password','position','absolute','','','.b-form'),(989570,'deals','.w-taxable input[type=\"checkbox\"]','position','relative','','','.w-taxable'),(989571,'deals','.b-fancybox .fancybox-tmp','position','absolute','','','.b-fancybox'),(989572,'deals','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(989573,'deals','.b-datepicker .datepicker-dropdown','position','absolute','','','.b-datepicker'),(989576,'deals','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(989577,'deals','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(989578,'deals','.b-form .columns .col-2','position','relative','','','.b-form'),(989579,'deals','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','position','relative','3','','.order-summary'),(989580,'deals','.w-cart-compare .atr-col','position','absolute','3','','.w-cart-compare'),(989581,'deals','.w-promo-code .holder','position','relative','','','.w-promo-code'),(989582,'deals','.w-promo-code .holder','position','absolute','3','','.w-promo-code'),(989583,'deals','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(989584,'deals','.w-menu-horizontal ul ul','position','absolute','','','.w-menu-horizontal'),(989585,'deals','.w-cart-listing .item .gift-wrap label','position','relative','','','.w-cart-listing'),(989586,'deals','.w-cart-listing .remove-btn span','position','relative','5639','','.w-cart-listing'),(989587,'deals','.w-cart-discount-coupon .btn-remove','position','relative','','','.w-cart-discount-coupon'),(989592,'deals','.w-image-maps .svg-wrap','position','relative','','','.w-image-maps'),(989593,'deals','.b-fancybox .fancybox-nav span','position','absolute','','','.b-fancybox'),(989594,'deals','.b-dropdown .dropdown','position','relative','','','.b-dropdown'),(989596,'deals','.w-socials .post_item > div','position','absolute','3','','.w-socials'),(989597,'deals','.p-quote-checkout-success .page-success > div','position','relative','','','.p-quote-checkout-success'),(989599,'deals','.w-product-reviews .reviews-list .review','position','absolute','3','','.w-product-reviews'),(989600,'deals','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(989601,'deals','.w-filters .input-checkbox','position','absolute','','','.w-filters'),(989602,'deals','.w-filters .head-filter-widget','position','relative','','','.w-filters'),(989603,'deals','.b-bottom .pop-up-close','position','absolute','','','.b-bottom'),(989604,'deals','.w-reviews-content .review','position','relative','','','.w-reviews-content'),(989606,'deals','.b-dropdown .dropdown .dropdown-toggle','position','relative','4','','.b-dropdown'),(989607,'deals','.b-form .same-address','position','relative','','','.b-form'),(989610,'deals','.w-menu-big ','position','relative','','','.w-menu-big'),(989614,'deals','.w-menu-big > ul > li > ul','position','absolute','','','.w-menu-big'),(989615,'deals','.p-quote-checkout-success .page-success','position','relative','','','.p-quote-checkout-success'),(989616,'deals','.b-dropdown .dropdown .dropdown-menu','position','absolute','','','.b-dropdown'),(989617,'deals','.b-select-suggest .select2-container .select2-choice abbr','position','absolute','','','.b-select-suggest'),(989618,'deals','.w-filters .mobileCollapse','position','absolute','','','.w-filters'),(989619,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','position','fixed','','','.w-image-maps'),(989620,'deals','.b-product-images .media-popup .mp-close','position','absolute','','','.b-product-images'),(989621,'deals','.b-product-images .mp-shadow, .b-product-images .media-popup','position','fixed','','','.b-product-images'),(989622,'deals','.b-menu-burger_icon .menu-style[data-burger_icon]','position','relative','','','.b-menu-burger_icon'),(989623,'deals','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-1 > li','position','relative','','','.b-menu-lev_display-down'),(989624,'deals','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','position','absolute','','','.b-menu-lev_display-down'),(989625,'deals','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-2 > li','position','relative','','','.b-menu-lev_display-down'),(989626,'deals','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','position','absolute','','','.b-menu-lev_display-down'),(989627,'deals','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-3 > li','position','relative','','','.b-menu-lev_display-down'),(989628,'deals','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','position','absolute','','','.b-menu-lev_display-down'),(989629,'deals','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-4 > li','position','relative','','','.b-menu-lev_display-down'),(989630,'deals','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','position','absolute','','','.b-menu-lev_display-down'),(989631,'deals','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-5 > li','position','relative','','','.b-menu-lev_display-down'),(989632,'deals','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','position','absolute','','','.b-menu-lev_display-down'),(989633,'deals','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-1 > li','position','relative','','','.b-menu-lev_display-left'),(989634,'deals','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','position','absolute','','','.b-menu-lev_display-left'),(989635,'deals','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-2 > li','position','relative','','','.b-menu-lev_display-left'),(989636,'deals','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','position','absolute','','','.b-menu-lev_display-left'),(989637,'deals','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-3 > li','position','relative','','','.b-menu-lev_display-left'),(989638,'deals','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','position','absolute','','','.b-menu-lev_display-left'),(989639,'deals','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-4 > li','position','relative','','','.b-menu-lev_display-left'),(989640,'deals','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','position','absolute','','','.b-menu-lev_display-left'),(989641,'deals','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-5 > li','position','relative','','','.b-menu-lev_display-left'),(989642,'deals','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','position','absolute','','','.b-menu-lev_display-left'),(989643,'deals','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-1 > li','position','relative','','','.b-menu-lev_display-lra'),(989644,'deals','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','position','absolute','','','.b-menu-lev_display-lra'),(989645,'deals','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-2 > li','position','relative','','','.b-menu-lev_display-lra'),(989646,'deals','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','position','absolute','','','.b-menu-lev_display-lra'),(989647,'deals','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-3 > li','position','relative','','','.b-menu-lev_display-lra'),(989648,'deals','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','position','absolute','','','.b-menu-lev_display-lra'),(989649,'deals','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-4 > li','position','relative','','','.b-menu-lev_display-lra'),(989650,'deals','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','position','absolute','','','.b-menu-lev_display-lra'),(989651,'deals','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-5 > li','position','relative','','','.b-menu-lev_display-lra'),(989652,'deals','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','position','absolute','','','.b-menu-lev_display-lra'),(989653,'deals','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right'),(989654,'deals','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','position','absolute','','','.b-menu-lev_display-right'),(989655,'deals','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right'),(989656,'deals','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','position','absolute','','','.b-menu-lev_display-right'),(989657,'deals','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right'),(989658,'deals','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','position','absolute','','','.b-menu-lev_display-right'),(989659,'deals','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right'),(989660,'deals','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','position','absolute','','','.b-menu-lev_display-right'),(989661,'deals','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right'),(989662,'deals','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','position','absolute','','','.b-menu-lev_display-right'),(989663,'deals','.b-menu-lev_display-right_top .menu-style[data-lev2_display=\"right_top\"] .level-1 > li','position','relative','','','.b-menu-lev_display-right_top'),(989664,'deals','.b-menu-lev_display-right_top .menu-style[data-lev3_display=\"right_top\"] .level-2 > li','position','relative','','','.b-menu-lev_display-right_top'),(989665,'deals','.b-menu-lev_display-right_top .menu-style[data-lev4_display=\"right_top\"] .level-3 > li','position','relative','','','.b-menu-lev_display-right_top'),(989666,'deals','.b-menu-lev_display-right_top .menu-style[data-lev5_display=\"right_top\"] .level-4 > li','position','relative','','','.b-menu-lev_display-right_top'),(989667,'deals','.b-menu-lev_display-right_top .menu-style[data-lev6_display=\"right_top\"] .level-5 > li','position','relative','','','.b-menu-lev_display-right_top'),(989668,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] .level-1','position','relative','','','.b-menu-lev_display-slide'),(989669,'deals','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] .level-2','position','relative','','','.b-menu-lev_display-slide'),(989670,'deals','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','position','absolute','','','.b-menu-lev_display-slide'),(989671,'deals','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] .level-3','position','relative','','','.b-menu-lev_display-slide'),(989672,'deals','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','position','absolute','','','.b-menu-lev_display-slide'),(989673,'deals','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] .level-4','position','relative','','','.b-menu-lev_display-slide'),(989674,'deals','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','position','absolute','','','.b-menu-lev_display-slide'),(989675,'deals','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] .level-5','position','relative','','','.b-menu-lev_display-slide'),(989676,'deals','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','position','absolute','','','.b-menu-lev_display-slide'),(989677,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','position','absolute','','','.b-menu-lev_display-slide'),(989678,'deals','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width'),(989679,'deals','.b-menu-lev_display-width .menu-style[data-lev2_display=\"width\"] .level-2','position','absolute','','','.b-menu-lev_display-width'),(989680,'deals','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width'),(989681,'deals','.b-menu-lev_display-width .menu-style[data-lev3_display=\"width\"] .level-3','position','absolute','','','.b-menu-lev_display-width'),(989682,'deals','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width'),(989683,'deals','.b-menu-lev_display-width .menu-style[data-lev4_display=\"width\"] .level-4','position','absolute','','','.b-menu-lev_display-width'),(989684,'deals','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width'),(989685,'deals','.b-menu-lev_display-width .menu-style[data-lev5_display=\"width\"] .level-5','position','absolute','','','.b-menu-lev_display-width'),(989686,'deals','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width'),(989687,'deals','.b-menu-lev_display-width .menu-style[data-lev6_display=\"width\"] .level-6','position','absolute','','','.b-menu-lev_display-width'),(989688,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-1 > li','position','relative','','','.b-menu-lev_display-width_cont'),(989689,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev2_display=\"width_cont\"] .level-2','position','absolute','','','.b-menu-lev_display-width_cont'),(989690,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-2 > li','position','relative','','','.b-menu-lev_display-width_cont'),(989691,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev3_display=\"width_cont\"] .level-3','position','absolute','','','.b-menu-lev_display-width_cont'),(989692,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-3 > li','position','relative','','','.b-menu-lev_display-width_cont'),(989693,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev4_display=\"width_cont\"] .level-4','position','absolute','','','.b-menu-lev_display-width_cont'),(989694,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-4 > li','position','relative','','','.b-menu-lev_display-width_cont'),(989695,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev5_display=\"width_cont\"] .level-5','position','absolute','','','.b-menu-lev_display-width_cont'),(989696,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-5 > li','position','relative','','','.b-menu-lev_display-width_cont'),(989697,'deals','.b-menu-lev_display-width_cont .menu-style[data-lev6_display=\"width_cont\"] .level-6','position','absolute','','','.b-menu-lev_display-width_cont'),(989698,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(989699,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(989700,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(989701,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(989702,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','position','relative','','','.b-menu-lev_vis-click_icon'),(989703,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','position','fixed','','','.b-menu-open_from-left'),(989704,'deals','.w-catalog-compare .compare .checkbox span','position','relative','','','.w-catalog-compare'),(989705,'deals','.preFooter .w-banner .single_banner picture img','position','static','','','.preFooter'),(989706,'deals','.b-slick .slick-list','position','relative','','','.b-slick'),(989707,'deals','.b-slick .slick-slider','position','relative','','','.b-slick'),(989708,'deals','.b-slick .slick-track','position','relative','','','.b-slick'),(989709,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','position','absolute','','','.b-slick'),(989710,'deals','.header-middle ','position','relative','5639','','.header-middle'),(989711,'deals','.b-products-listing .del-from-personal-catalog','position','relative','3','','.b-products-listing'),(989712,'deals','.b-products-listing .products-listing .compare .checkbox input:not(checked) + span:before','position','static','','','.b-products-listing'),(989713,'deals','.w-quote .multicart .item','position','relative','','','.w-quote'),(989714,'deals','.w-quote .multicart .switch-cart','position','absolute','','','.w-quote'),(989716,'deals','.w-product-personal-catalog-button .btn','position','relative','3','','.w-product-personal-catalog-button'),(989717,'deals','.b-quantity .qty-input.hidden','position','relative','','','.b-quantity'),(989718,'deals','.w-product-quantity .pr_attr','position','absolute','','','.w-product-quantity'),(989719,'deals','.warrantyProduct .warranty, .warrantyProduct .delivery','position','relative','','','.warrantyProduct'),(989720,'deals','.warrantyProduct .warranty','position','absolute','3','','.warrantyProduct'),(989721,'deals','.warrantyProduct .delivery','position','absolute','3','','.warrantyProduct'),(989722,'deals','.w-compare ','position','fixed','','','.w-compare'),(989723,'deals','.w-compare .item-holder','position','relative','','','.w-compare'),(989724,'deals','.w-compare .remove','position','absolute','','','.w-compare'),(989725,'deals','.w-files-catalog-widgets-files-list .file','position','relative','3','','.w-files-catalog-widgets-files-list'),(989726,'deals','.w-sample .cart-box','position','relative','','','.w-sample'),(989727,'deals','.w-sample .cart-box-link','position','relative','','','.w-sample'),(989728,'deals','.w-sample .multicart .item','position','relative','','','.w-sample'),(989729,'deals','.w-sample .multicart .switch-cart','position','absolute','','','.w-sample'),(989730,'deals','.w-sample .qty','position','relative','4','','.w-sample'),(989731,'deals','.w-quote .cart-box.hover-box .cart-content','position','absolute','','','.w-quote'),(989732,'deals','.w-sample .cart-box .cart-content','position','absolute','','','.w-sample'),(989733,'deals','.w-cart-listing .points-earn','position','relative','','','.w-cart-listing'),(989734,'deals','.w-cart-gift-certificate .gift-certificate .heading-4','position','relative','3','','.w-cart-gift-certificate'),(989735,'deals','.w-product-inventory input[type=\"radio\"]','position','relative','','','.w-product-inventory'),(989737,'deals','.w-product-properties-filters-widgets-chosen-filters .remove','position','relative','3','','.w-product-properties-filters-widgets-chosen-filters'),(989738,'deals','.p-sample-checkout-index .order-summary .heading-2','position','relative','3','','.p-sample-checkout-index'),(989739,'deals','.p-sample-checkout-index .order-summary .heading-2','position','relative','4','','.p-sample-checkout-index'),(989740,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input','position','absolute','','','.w-questionnaire-widgets-questionnaire'),(989741,'deals','.w-product-groups .radioBox label','position','relative','','','.w-product-groups'),(989742,'deals','.w-product-groups .radioBox label input','position','absolute','','','.w-product-groups'),(989743,'deals','.w-sale-category .badge','position','absolute','','','.w-sale-category'),(989744,'deals','.w-sale-category .sale-holder','position','relative','','','.w-sale-category'),(989745,'deals','.w-product-bonus-points .bonus-points-cost','position','relative','','','.w-product-bonus-points'),(989746,'deals','.w-product-bonus-points > div > div','position','absolute','3','','.w-product-bonus-points'),(989747,'deals','.w-product-designer-designer .prodDesignerType label','position','relative','','','.w-product-designer-designer'),(989748,'deals','.w-product-designer-designer .productDesignerBox input','position','absolute','','','.w-product-designer-designer'),(989749,'deals','.w-press-reviews-widgets-press-reviews .review','position','relative','','','.w-press-reviews-widgets-press-reviews'),(989750,'deals','.w-support-system-listing .support-head','position','relative','','','.w-support-system-listing'),(989751,'deals','.w-product-configurator .pc-item label','position','relative','','','.w-product-configurator'),(989752,'deals','.w-product-configurator .pc-item label input','position','absolute','','','.w-product-configurator'),(989753,'deals','.w-predefined-promotion .icon','position','relative','','','.w-predefined-promotion'),(989754,'deals','.w-predefined-promotion .prom-multi-discount .products','position','relative','','','.w-predefined-promotion'),(989755,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','position','relative','','','.w-predefined-promotion'),(989756,'deals','.w-predefined-promotion .prom-multi-discount > .heading','position','relative','3','','.w-predefined-promotion'),(989757,'deals','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','position','relative','3','','.w-predefined-promotion'),(989758,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','position','relative','','','.w-predefined-promotion'),(989759,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition','position','relative','','','.w-predefined-promotion'),(989760,'deals','.w-predefined-promotion .promo-cart-discount .slave .content','position','relative','','','.w-predefined-promotion'),(989761,'deals','.w-predefined-promotion .promo-date','position','relative','','','.w-predefined-promotion'),(989762,'deals','.w-predefined-promotion .promo-salemaker .discount','position','relative','','','.w-predefined-promotion'),(989763,'deals','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','position','relative','3','','.w-predefined-promotion'),(989765,'deals','.headerWrap ','position','relative','','','.headerWrap'),(989766,'deals','.headerWrap .headerInside >.block','position','relative','','','.headerWrap'),(989767,'deals','.w-subscribers .left_box','position','relative','','','.w-subscribers'),(989768,'deals','.w-subscribers .right_box','position','relative','','','.w-subscribers'),(989769,'deals','.w-top-categories picture > img, .w-top-categories picture > img','position','static','','','.w-top-categories'),(989770,'deals','.w-categories picture > img, .w-categories picture > img','position','static','','','.w-categories'),(989771,'deals','.filterLine .before','position','relative','','','.filterLine'),(989772,'deals','.filterLine .filter-ul-content .count','position','absolute','','','.filterLine'),(989773,'deals','.filterLine .w-catalog-sorting .sorting','position','relative','','','.filterLine'),(989774,'deals','.w-filters .filter-widget-horizontal .filter-box-content','position','absolute','','','.w-filters'),(989775,'deals','.w-filters .filter-widget-horizontal .filter-box','position','relative','','','.w-filters'),(989776,'deals','.w-filters span.open','position','relative','','','.w-filters'),(989777,'deals','.filterLine .w-catalog-sorting .sort-select','position','absolute','','','.filterLine'),(989778,'deals','.w-breadcrumb .breadcrumb-li','position','relative','','','.w-breadcrumb'),(989779,'deals','.w-breadcrumb .breadcrumb-li','position','absolute','4','','.w-breadcrumb'),(989780,'deals','.w-breadcrumb .catalog-breadcrumb','position','relative','','','.w-breadcrumb'),(989781,'deals','.messageBox .info','position','relative','','',''),(989782,'deals','.messageBox .info','position','relative','3','',''),(989783,'deals','.w-cart-listing .item','position','relative','','','.w-cart-listing'),(989784,'deals','.homeBanner .carousel .bottom-center > span','position','absolute','3','','.homeBanner'),(989785,'deals','.homeBanner .carousel .bottom-center > span','position','relative','','','.homeBanner'),(989786,'deals','.homeBanner .carousel-text.bottom-center','position','static','5639','','.homeBanner'),(989787,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','position','absolute','5639','','.w-filters'),(989788,'deals','.w-filters .filter-widget-horizontal','position','relative','5639','','.w-filters'),(989789,'deals','.b-info .info','position','relative','','','.b-info'),(989790,'deals','.b-info .info','position','relative','3','','.b-info'),(989791,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','position','relative','5630','','.headerWrap'),(989792,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li.parent > a','position','absolute','5630,4','','.headerWrap'),(989793,'deals','.w-account-personal-catalog .checkbox input:not(checked) + span:before','position','static','','','.w-account-personal-catalog'),(989794,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','position','relative','','','.w-account-personal-catalog'),(989795,'deals','.w-account-personal-catalog .list-row-action ul','position','relative','','','.w-account-personal-catalog'),(989796,'deals','.w-account-personal-catalog .list-row-action ul','position','absolute','4','','.w-account-personal-catalog'),(989797,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li .no-link','position','relative','5630','','.preFooter'),(989798,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li .no-link','position','absolute','5630,4','','.preFooter'),(989799,'deals','.p-wedding-registry-view h1','position','relative','3','','.p-wedding-registry-view'),(989800,'deals','.p-wedding-registry-view h1','position','relative','4','','.p-wedding-registry-view'),(989801,'deals','.w-product-wishlist-button .btn','position','relative','','','.w-product-wishlist-button'),(989802,'deals','.w-product-wishlist-button .btn','position','absolute','3','','.w-product-wishlist-button'),(989803,'deals','.homeBanner .banner-item .banner-text-holder','position','relative','','','.homeBanner'),(989804,'deals','.homeBanner .text-bottom-center .banner-text-holder','position','absolute','3','','.homeBanner'),(989805,'deals','.homeBanner .text-bottom-left .banner-text-holder','position','absolute','3','','.homeBanner'),(989806,'deals','.homeBanner .text-bottom-right .banner-text-holder','position','absolute','3','','.homeBanner'),(989807,'deals','.order-summary .icon','position','relative','','','.order-summary'),(989808,'deals','.order-summary .icon','position','absolute','3','','.order-summary'),(989809,'deals','.w-cart-discount-coupon .title','position','relative','','','.w-cart-discount-coupon'),(989836,'deals','.account-order-pay .account_history_info.account_history_info_due','position','relative','','','.account-order-pay'),(989837,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','position','relative','','','.account-order-pay'),(989838,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','position','absolute','3','','.account-order-pay'),(989839,'deals','.account-order-pay .not_fully_paid_td','position','absolute','','','.account-order-pay'),(989840,'deals','.account-samples .moduleRowDue td','position','relative','','','.account-samples'),(989841,'deals','.account-samples .not_fully_paid_td','position','absolute','','','.account-samples'),(989842,'deals','.account-samples .view_link','position','relative','','','.account-samples'),(989843,'deals','.account-samples .view_link','position','absolute','4','','.account-samples'),(989844,'deals','.account-samples .orders-table .item','position','relative','5639','','.account-samples'),(989845,'deals','.account-samples .orders-table .order-total','position','absolute','5639','','.account-samples'),(989846,'deals','.account-samples .orders-table .status-name','position','absolute','5639','','.account-samples'),(989847,'deals','.account-samples .orders-table .td-alignright','position','absolute','5639','','.account-samples'),(989848,'deals','.account-sample-info .account_history_info.account_history_info_due','position','relative','','','.account-sample-info'),(989849,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','position','relative','','','.account-sample-info'),(989850,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','position','absolute','3','','.account-sample-info'),(989851,'deals','.account-sample-info .not_fully_paid_td','position','absolute','','','.account-sample-info'),(989852,'deals','.catalog-product-wrap .pn-image','position','absolute','3','','.catalog-product-wrap'),(989853,'deals','.catalog-product-wrap .prev-next-product','position','fixed','','','.catalog-product-wrap'),(989854,'deals','.shopping-cart-index .gift-code .heading-4','position','absolute','4','','.shopping-cart-index'),(989855,'deals','.shopping-cart-index .gift-code .heading-4','position','relative','5630','','.shopping-cart-index'),(989856,'deals','.checkout-index-wrap .order-ico','position','relative','3','','.checkout-index-wrap'),(989857,'deals','.checkout-order-confirmation .comment-ico','position','relative','3','','.checkout-order-confirmation'),(989858,'deals','.checkout-order-confirmation .discount-ico','position','relative','3','','.checkout-order-confirmation'),(989859,'deals','.checkout-order-confirmation .order-ico','position','relative','3','','.checkout-order-confirmation'),(989860,'deals','.checkout-success-wrap .page-success','position','relative','','','.checkout-success-wrap'),(989861,'deals','.checkout-success-wrap .page-success > div','position','relative','','','.checkout-success-wrap'),(989862,'deals','.b-form .addresses .address-item','position','relative','','','.b-form'),(989863,'deals','.hide-page','position','fixed','','',''),(989864,'deals','.success-page .comment-ico','position','relative','3','','.success-page'),(989865,'deals','.success-page .discount-ico','position','relative','3','','.success-page'),(989866,'deals','.success-page .order-ico','position','relative','3','','.success-page'),(989867,'deals','.success-page .page-success','position','relative','','','.success-page'),(989868,'deals','.success-page .page-success .text-1','position','relative','','','.success-page'),(989869,'deals','.success-page .page-success > div','position','relative','','','.success-page'),(989870,'deals','.success-page .w-cart-listing .qty','position','relative','','','.success-page'),(989872,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','position','relative','4','','.b-multi-page-checkout'),(989875,'deals','.footer-menu .level-1 > li','position','relative','5639','','.footer-menu'),(989876,'deals','.w-banner .banner','position','relative','','','.w-banner'),(989877,'deals','.w-banner .banner img + img','position','absolute','','','.w-banner'),(989878,'deals','.w-banner .carousel .item','position','relative','','','.w-banner'),(989879,'deals','.w-banner .carousel-text','position','absolute','','','.w-banner'),(989880,'deals','.w-banner .image-text-banner','position','relative','','','.w-banner'),(989881,'deals','.w-banner .image-text-banner .text-banner','position','absolute','','','.w-banner'),(989882,'deals','.w-catalog-paging .paging-holder','position','relative','','','.w-catalog-paging'),(989883,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','position','static','','','.w-catalog-paging'),(989892,'deals','.w-menu-slider .close','position','absolute','','','.w-menu-slider'),(989893,'deals','.w-menu-slider > ul','position','relative','','','.w-menu-slider'),(989894,'deals','.w-menu-slider > ul > li > ul','position','absolute','','','.w-menu-slider'),(989895,'deals','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','position_important','important','','','.b-switch'),(989897,'deals','.b-autocomplete .ui-autocomplete','position_important','important','','','.b-autocomplete'),(989900,'deals','.w-checkout-billing-address .addresses .address-item label input','position_important','important','','','.w-checkout-billing-address'),(989901,'deals','.w-checkout-shipping-address .addresses .address-item label input','position_important','important','','','.w-checkout-shipping-address'),(989903,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','position_important','important','','','.b-select-suggest'),(989906,'deals','.w-socials .post_item > div','right','10','3','','.w-socials'),(989908,'deals','.b-upload-file .snapshot','right','5','','','.b-upload-file'),(989909,'deals','.w-upload-customer-id-upload-customer-id-form .upload-remove','right','5','','','.w-upload-customer-id-upload-customer-id-form'),(989910,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','right','0','','','.b-switch'),(989911,'deals','.w-cart-compare .dropdown .dropdown-menu','right','0','','','.w-cart-compare'),(989912,'deals','.closeable-heading','right','0','3','',''),(989913,'deals','.b-bottom .footerTitle','right','0','5630,4','','.b-bottom'),(989914,'deals','.w-socials .post_item > div','right','10','3','','.w-socials'),(989915,'deals','.b-info-popup .info-popup.top-left div','right','13','3','','.b-info-popup'),(989917,'deals','.w-socials .post_item > div','right','10','3','','.w-socials'),(989918,'deals','.w-socials .post_item > div','right','10','3','','.w-socials'),(989919,'deals','.w-cart-compare .atr-col','right','0','3','','.w-cart-compare'),(989920,'deals','.w-multi-cart-actions .dropdown .dropdown-menu','right','auto','','','.w-multi-cart-actions'),(989921,'deals','.w-socials .post_item > div','right','10','3','','.w-socials'),(989922,'deals','.b-pass-strength .pass-strength span','right','25','','','.b-pass-strength'),(989923,'deals','.b-info-popup .info-popup.top-left div','right','-10','','','.b-info-popup'),(989924,'deals','.b-fancybox .fancybox-overlay-fixed','right','0','','','.b-fancybox'),(989925,'deals','.w-cart-compare .remove-cart','right','0','','','.w-cart-compare'),(989926,'deals','.b-fancybox .fancybox-close','right','10','','','.b-fancybox'),(989927,'deals','.b-fancybox .fancybox-next','right','0','','','.b-fancybox'),(989928,'deals','.b-fancybox .fancybox-next span','right','10','','','.b-fancybox'),(989929,'deals','.w-product-customers-activity .customers-activity','right','20','','','.w-product-customers-activity'),(989930,'deals','.w-product-customers-activity .close','right','5','','','.w-product-customers-activity'),(989931,'deals','.b-select-suggest .select2-search-choice-close','right','3','','','.b-select-suggest'),(989932,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow','right','0','','','.b-select-suggest'),(989934,'deals','.b-fancybox .fancybox-title-float-wrap','right','50','','','.b-fancybox'),(989935,'deals','.b-form .eye-password','right','5','','','.b-form'),(989937,'deals','.b-upload-file .upload-remove','right','10','','','.b-upload-file'),(989938,'deals','.w-socials .post_item > div','right','10','3','','.w-socials'),(989940,'deals','.b-bottom .pop-up-close','right','6','','','.b-bottom'),(989941,'deals','.w-menu-big > ul > li > ul','right','0','','','.w-menu-big'),(989942,'deals','.b-select-suggest .select2-container .select2-choice abbr','right','24','','','.b-select-suggest'),(989943,'deals','.w-filters .mobileCollapse','right','12','','','.w-filters'),(989944,'deals','.b-product-images .media-popup .mp-close','right','20','','','.b-product-images'),(989945,'deals','.b-product-images .mp-shadow, .b-product-images .media-popup','right','0','','','.b-product-images'),(989946,'deals','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right','100','','','.b-menu-lev_display-left'),(989947,'deals','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right','100','','','.b-menu-lev_display-left'),(989948,'deals','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right','100','','','.b-menu-lev_display-left'),(989949,'deals','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right','100','','','.b-menu-lev_display-left'),(989950,'deals','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right','100','','','.b-menu-lev_display-left'),(989951,'deals','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right','100','','','.b-menu-lev_display-lra'),(989952,'deals','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right','100','','','.b-menu-lev_display-lra'),(989953,'deals','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right','100','','','.b-menu-lev_display-lra'),(989954,'deals','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right','100','','','.b-menu-lev_display-lra'),(989955,'deals','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right','100','','','.b-menu-lev_display-lra'),(989956,'deals','.b-slick .slick-vertical button.slick-prev, .b-slick .slick-vertical button.slick-next','right','auto','','','.b-slick'),(989957,'deals','.b-slick button.slick-next','right','0','','','.b-slick'),(989958,'deals','.b-slick button.slick-prev','right','auto','','','.b-slick'),(989959,'deals','.w-compare ','right','0','','','.w-compare'),(989960,'deals','.w-compare .remove','right','20','','','.w-compare'),(989961,'deals','.p-sample-checkout-index .order-summary .heading-2','right','-14','4','','.p-sample-checkout-index'),(989962,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','right','-100','','','.w-product-properties-icons'),(989963,'deals','.w-product-bonus-points .bonus-points-cost','right','-14','5660,4','','.w-product-bonus-points'),(989965,'deals','.filterLine .filter-ul-content .count','right','0','','','.filterLine'),(989966,'deals','.filterLine .w-catalog-sorting .sort-select','right','0','','','.filterLine'),(989967,'deals','.w-breadcrumb .breadcrumb-li','right','-5','4','','.w-breadcrumb'),(989968,'deals','.homeBanner .carousel .bottom-center > span','right','0','3','','.homeBanner'),(989969,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li.parent > a','right','15','5630,4','','.headerWrap'),(989970,'deals','.w-account-personal-catalog .list-row-action ul','right','7','4','','.w-account-personal-catalog'),(989971,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li .no-link','right','0','5630,4','','.preFooter'),(989972,'deals','.p-wedding-registry-view h1','right','-10','4','','.p-wedding-registry-view'),(989973,'deals','.homeBanner .text-bottom-center .banner-text-holder','right','0','3','','.homeBanner'),(989974,'deals','.homeBanner .text-bottom-left .banner-text-holder','right','0','3','','.homeBanner'),(989975,'deals','.homeBanner .text-bottom-right .banner-text-holder','right','0','3','','.homeBanner'),(989976,'deals','.order-summary .icon','right','0','3','','.order-summary'),(989979,'deals','.account-samples .orders-table .order-total','right','0','5639','','.account-samples'),(989980,'deals','.catalog-product-wrap .next-product','right','0','','','.catalog-product-wrap'),(989981,'deals','.catalog-product-wrap .next-product .pn-image','right','20','3','','.catalog-product-wrap'),(989982,'deals','.shopping-cart-index .gift-code .heading-4','right','0','4','','.shopping-cart-index'),(989984,'deals','.w-banner .image-text-banner.bottom-right .text-banner','right','0','','','.w-banner'),(989985,'deals','.w-banner .image-text-banner.middle-right .text-banner','right','0','','','.w-banner'),(989986,'deals','.w-banner .image-text-banner.top-right .text-banner','right','0','','','.w-banner'),(989989,'deals','.w-menu-slider .close','right','10','','','.w-menu-slider'),(989990,'deals','.b-fancybox .fancybox-title-float-wrap','right_measure','%','','','.b-fancybox'),(989991,'deals','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','right_measure','%','','','.b-menu-lev_display-left'),(989992,'deals','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','right_measure','%','','','.b-menu-lev_display-left'),(989993,'deals','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','right_measure','%','','','.b-menu-lev_display-left'),(989994,'deals','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','right_measure','%','','','.b-menu-lev_display-left'),(989995,'deals','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','right_measure','%','','','.b-menu-lev_display-left'),(989996,'deals','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .lra-left > .level-2','right_measure','%','','','.b-menu-lev_display-lra'),(989997,'deals','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .lra-left > .level-3','right_measure','%','','','.b-menu-lev_display-lra'),(989998,'deals','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .lra-left > .level-4','right_measure','%','','','.b-menu-lev_display-lra'),(989999,'deals','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .lra-left > .level-5','right_measure','%','','','.b-menu-lev_display-lra'),(990000,'deals','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .lra-left > .level-6','right_measure','%','','','.b-menu-lev_display-lra'),(990001,'deals','.b-info-popup .info-popup.top-left div','rotate','-135','3','','.b-info-popup'),(990002,'deals','.w-checkout-shipping-choice input:checked + span:before','rotate','45','','','.w-checkout-shipping-choice'),(990003,'deals','.b-info-popup .info-popup div','rotate','-45','3','','.b-info-popup'),(990004,'deals','.w-sample .cart-box-link','rotate','45','4','','.w-sample'),(990005,'deals','.w-image-maps rect, .w-image-maps circle, .w-image-maps polygon','stroke-width','0','','','.w-image-maps'),(990006,'deals','.w-image-maps rect:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(990007,'deals','.w-image-maps circle:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(990008,'deals','.w-image-maps polygon:not(.no-items):hover','stroke-width','0','','','.w-image-maps'),(990009,'deals','.w-tabs .tab-navigation','table-layout','fixed','','','.w-tabs'),(990010,'deals','.w-communication-new-topic .orders-id','text-align','center','','','.w-communication-new-topic'),(990011,'deals','.w-communication-new-topic .model','text-align','center','','','.w-communication-new-topic'),(990012,'deals','.w-communication-new-topic .date-purchased','text-align','right','','','.w-communication-new-topic'),(990013,'deals','.w-communication-new-topic .quantity','text-align','center','','','.w-communication-new-topic'),(990014,'deals','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(990015,'deals','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(990016,'deals','.b-email .price','text-align','right','','','.b-email'),(990017,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.p-quick-order-index'),(990018,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.p-quick-order-index'),(990019,'deals','.w-promotions .promo-date','text-align','center','','','.w-promotions'),(990020,'deals','.w-promotions .promo-item','text-align','center','','','.w-promotions'),(990022,'deals','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(990024,'deals','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(990025,'deals','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(990026,'deals','.b-email .heading-model','text-align','center','','','.b-email'),(990027,'deals','.w-categories .item','text-align','center','','','.w-categories'),(990028,'deals','.w-promotions .prom-multi-discount .heading','text-align','center','','','.w-promotions'),(990029,'deals','.b-products-listing .products-listing .btn-preloader','text-align','center','','','.b-products-listing'),(990030,'deals','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(990031,'deals','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(990032,'deals','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(990033,'deals','.b-messages .development-content','text-align','left','','','.b-messages'),(990034,'deals','.b-messages .msv_to_cc, .b-messages .msv_btn','text-align','left','','','.b-messages'),(990035,'deals','.b-messages .msv_content','text-align','left','','','.b-messages'),(990036,'deals','.b-messages .msv_history','text-align','left','','','.b-messages'),(990037,'deals','.b-messages .attach-view','text-align','left','','','.b-messages'),(990038,'deals','.b-messages .messages-sidebar .heading-2','text-align','center','','','.b-messages'),(990039,'deals','.b-messages .messages-sidebar .btn-2','text-align','center','','','.b-messages'),(990040,'deals','.b-messages .emailBtn','text-align','right','','','.b-messages'),(990041,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable tbody th, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td','text-align','left','','','.b-messages'),(990042,'deals','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(990043,'deals','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align','left','','','.p-quick-order-index'),(990044,'deals','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(990045,'deals','.w-checkout-terms .terms-box','text-align','left','','','.w-checkout-terms'),(990046,'deals','.w-checkout-terms .required-message','text-align','left','','','.w-checkout-terms'),(990047,'deals','.w-cart-listing .price','text-align','right','5630','','.w-cart-listing'),(990048,'deals','.b-email .heading-model','text-align','center','','','.b-email'),(990049,'deals','.b-email .heading-qty','text-align','center','','','.b-email'),(990050,'deals','.b-email .heading-price','text-align','right','','','.b-email'),(990051,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','text-align','center','','','.b-switch'),(990052,'deals','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(990053,'deals','.order-summary .price-box .title','text-align','left','','','.order-summary'),(990054,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','text-align','center','','','.w-upload-customer-id-upload-customer-id-form'),(990055,'deals','.b-switch .bootstrap-switch','text-align','left','','','.b-switch'),(990056,'deals','.b-page-name .page-name','text-align','center','','','.b-page-name'),(990057,'deals','.b-email .totals-label','text-align','right','','','.b-email'),(990058,'deals','.w-coupons-and-vauchers-checkout .btn-remove','text-align','center','','','.w-coupons-and-vauchers-checkout'),(990059,'deals','.w-checkout-bonus-points .btn-remove','text-align','center','','','.w-checkout-bonus-points'),(990060,'deals','.w-login-block .buttons','text-align','right','','','.w-login-block'),(990061,'deals','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(990062,'deals','.b-email .heading-qty','text-align','center','','','.b-email'),(990063,'deals','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(990064,'deals','.b-email .totals-value','text-align','right','','','.b-email'),(990065,'deals','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(990066,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','text-align','center','','','.b-switch'),(990067,'deals','.b-email .totals-value','text-align','right','','','.b-email'),(990068,'deals','.b-email .qty','text-align','center','','','.b-email'),(990069,'deals','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(990070,'deals','.pop-up-content .buttons .btn-2','text-align','center','5639','',''),(990071,'deals','.pop-up-content .buttons .btn','text-align','center','5639','',''),(990072,'deals','.no-found','text-align','center','','',''),(990073,'deals','.w-login-block .buttons','text-align','right','','','.w-login-block'),(990074,'deals','.p-quick-order-index .all-scroll-div td + td','text-align','right','','','.p-quick-order-index'),(990075,'deals','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(990076,'deals','.b-email-editor .price','text-align','center','','','.b-email-editor'),(990077,'deals','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(990078,'deals','.b-email .model','text-align','center','','','.b-email'),(990079,'deals','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(990080,'deals','.b-form .wedding-form .heading-2','text-align','left','','','.b-form'),(990081,'deals','.b-email .heading-price','text-align','right','','','.b-email'),(990082,'deals','.b-email .price','text-align','right','','','.b-email'),(990083,'deals','.w-top-categories .categories','text-align','center','','','.w-top-categories'),(990084,'deals','.w-success-continue-btn','text-align','center','5639','','.w-success-continue-btn'),(990085,'deals','.b-page-name .page-name','text-align','center','','','.b-page-name'),(990086,'deals','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(990087,'deals','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(990088,'deals','.b-page-name .page-name','text-align','center','','','.b-page-name'),(990089,'deals','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(990090,'deals','.b-email .heading-qty','text-align','center','','','.b-email'),(990091,'deals','.w-tabs .tab-a','text-align','center','','','.w-tabs'),(990092,'deals','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(990093,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','text-align','center','','','.b-switch'),(990094,'deals','.b-switch .bootstrap-switch .bootstrap-switch-label','text-align','center','','','.b-switch'),(990095,'deals','.b-social-login .social-login','text-align','center','','','.b-social-login'),(990096,'deals','.b-page-name .page-name','text-align','center','','','.b-page-name'),(990097,'deals','.b-email .price','text-align','right','','','.b-email'),(990098,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','text-align','center','','','.b-switch'),(990099,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','text-align','center','','','.b-switch'),(990100,'deals','.b-email .totals-title','text-align','right','','','.b-email'),(990101,'deals','.b-email .heading-model','text-align','center','','','.b-email'),(990102,'deals','.b-email .totals-label','text-align','right','','','.b-email'),(990103,'deals','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(990104,'deals','.b-email .totals-value','text-align','right','','','.b-email'),(990105,'deals','.w-cart-bonus-points .bonus_points_amount','text-align','center','','','.w-cart-bonus-points'),(990106,'deals','.w-cart-bonus-points .btn-remove','text-align','center','','','.w-cart-bonus-points'),(990107,'deals','.w-cart-credit-amount input','text-align','center','','','.w-cart-credit-amount'),(990108,'deals','.b-email .heading-qty','text-align','center','','','.b-email'),(990109,'deals','.w-reviews .date','text-align','right','','','.w-reviews'),(990110,'deals','.w-success-continue-btn','text-align','center','5639','','.w-success-continue-btn'),(990111,'deals','.w-top-categories .item','text-align','center','','','.w-top-categories'),(990112,'deals','.w-reviews-content .product-image','text-align','center','','','.w-reviews-content'),(990113,'deals','.b-email .model','text-align','center','','','.b-email'),(990114,'deals','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(990115,'deals','.b-email .heading-price','text-align','right','','','.b-email'),(990116,'deals','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(990117,'deals','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(990118,'deals','.b-email .heading-price','text-align','right','','','.b-email'),(990119,'deals','.b-email .price','text-align','right','','','.b-email'),(990120,'deals','.b-email .totals-title','text-align','right','','','.b-email'),(990121,'deals','.b-email .totals-value','text-align','right','','','.b-email'),(990122,'deals','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(990123,'deals','.b-email .heading-model','text-align','center','','','.b-email'),(990124,'deals','.b-email .qty','text-align','center','','','.b-email'),(990125,'deals','.b-email .model','text-align','center','','','.b-email'),(990126,'deals','.b-email .totals-label','text-align','right','','','.b-email'),(990127,'deals','.b-email .heading-qty','text-align','center','','','.b-email'),(990128,'deals','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(990129,'deals','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(990130,'deals','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(990131,'deals','.b-form .center-buttons','text-align','center','','','.b-form'),(990132,'deals','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(990133,'deals','.w-reviews .product-image','text-align','center','','','.w-reviews'),(990134,'deals','.b-sub-totals .historyTotal table td','text-align','right','','','.b-sub-totals'),(990135,'deals','.b-social-login .social-login','text-align','center','','','.b-social-login'),(990136,'deals','.w-success-continue-btn','text-align','center','5639','','.w-success-continue-btn'),(990137,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','text-align','center','3','','.b-switch'),(990139,'deals','.b-social-login .social-login','text-align','center','','','.b-social-login'),(990140,'deals','.w-login-block .buttons','text-align','right','','','.w-login-block'),(990141,'deals','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(990142,'deals','.p-quick-order-index table.dataTable thead th, .p-quick-order-index table.dataTable thead td','text-align','center','','','.p-quick-order-index'),(990143,'deals','.w-categories .categories','text-align','center','','','.w-categories'),(990144,'deals','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(990145,'deals','.w-login-block .buttons','text-align','right','','','.w-login-block'),(990146,'deals','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(990147,'deals','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(990148,'deals','.view-all','text-align','center','','',''),(990149,'deals','.b-page-name .page-name','text-align','center','','','.b-page-name'),(990150,'deals','.b-form .message.error','text-align','center','','','.b-form'),(990151,'deals','.b-email .qty','text-align','center','','','.b-email'),(990152,'deals','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','text-align','center','3','','.w-checkout-contact-information'),(990153,'deals','.b-email .model','text-align','center','','','.b-email'),(990154,'deals','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','text-align','center','3','','.w-checkout-contact-information'),(990155,'deals','.p-wedding-registry-search .result-table td:nth-child(4)','text-align','right','','','.p-wedding-registry-search'),(990156,'deals','.b-email .heading-qty','text-align','center','','','.b-email'),(990157,'deals','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(990158,'deals','.b-email .totals-value','text-align','right','','','.b-email'),(990159,'deals','.b-bottom .cart-options .js-carts','text-align','center','','','.b-bottom'),(990160,'deals','.b-bottom .cart-options .heading-4','text-align','center','','','.b-bottom'),(990161,'deals','.b-bottom .cart-options .heading-3','text-align','center','','','.b-bottom'),(990162,'deals','.b-bottom .cart-options .buttons','text-align','center','','','.b-bottom'),(990163,'deals','.b-bottom .alert-message','text-align','center','','','.b-bottom'),(990164,'deals','.w-checkout-credit-amount .btn-remove','text-align','center','','','.w-checkout-credit-amount'),(990165,'deals','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(990166,'deals','.b-products-listing .btn-choose-options','text-align','center','','','.b-products-listing'),(990167,'deals','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(990168,'deals','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(990169,'deals','.b-email-editor .price','text-align','center','','','.b-email-editor'),(990170,'deals','.b-email .qty','text-align','center','','','.b-email'),(990171,'deals','.b-email-editor .price','text-align','center','','','.b-email-editor'),(990173,'deals','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(990174,'deals','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(990175,'deals','.order-summary .price-row.ot_gv .title','text-align','center','3','','.order-summary'),(990176,'deals','.w-cart-credit-amount .btn-remove','text-align','center','','','.w-cart-credit-amount'),(990177,'deals','.b-email .qty','text-align','center','','','.b-email'),(990178,'deals','.b-email-editor .price','text-align','center','','','.b-email-editor'),(990179,'deals','.b-fancybox .fancybox-close','text-align','center','','','.b-fancybox'),(990180,'deals','.w-product-customers-activity .customers-activity','text-align','center','','','.w-product-customers-activity'),(990181,'deals','.w-product-customers-activity .close','text-align','center','','','.w-product-customers-activity'),(990182,'deals','.b-bottom .confirm-popup .buttons','text-align','center','','','.b-bottom'),(990183,'deals','.b-bottom .confirm-popup .confirm-text','text-align','center','','','.b-bottom'),(990184,'deals','.b-email .totals-title','text-align','right','','','.b-email'),(990185,'deals','.b-email .totals-label','text-align','right','','','.b-email'),(990186,'deals','.b-email .price','text-align','right','','','.b-email'),(990187,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','text-align','center','3','','.b-switch'),(990188,'deals','.w-quote-products .empty','text-align','center','','','.w-quote-products'),(990189,'deals','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(990190,'deals','.w-menu-horizontal .menu-ico','text-align','center','','','.w-menu-horizontal'),(990191,'deals','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(990192,'deals','.w-checkout-credit-amount .cot_gv_amount','text-align','center','','','.w-checkout-credit-amount'),(990193,'deals','.w-checkout-bonus-points .bonus_points_amount','text-align','center','','','.w-checkout-bonus-points'),(990194,'deals','.w-success-continue-btn','text-align','center','5639','','.w-success-continue-btn'),(990195,'deals','.p-wedding-registry-search #searchform-status label','text-align','right','','','.p-wedding-registry-search'),(990196,'deals','.b-page-name .page-name','text-align','center','','','.b-page-name'),(990197,'deals','.b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-align','left','','','.b-switch'),(990198,'deals','.b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-align','right','','','.b-switch'),(990199,'deals','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(990200,'deals','.b-social-login .social-login','text-align','center','','','.b-social-login'),(990201,'deals','.b-products-listing .products-listing .buyButton .btn','text-align','center','','','.b-products-listing'),(990203,'deals','.w-menu-big li li li','text-align','left','','','.w-menu-big'),(990204,'deals','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(990205,'deals','.w-menu-horizontal .box','text-align','center','','','.w-menu-horizontal'),(990206,'deals','.w-login-block .heading-3','text-align','center','','','.w-login-block'),(990207,'deals','.p-sample-cart-index .empty','text-align','center','','','.p-sample-cart-index'),(990208,'deals','.b-social-login .social-login','text-align','center','','','.b-social-login'),(990209,'deals','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(990210,'deals','.w-login-block .buttons','text-align','right','','','.w-login-block'),(990211,'deals','.w-cart-listing .links','text-align','center','','','.w-cart-listing'),(990212,'deals','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(990213,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','text-align','center','','','.b-data-table'),(990214,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','text-align','center','','','.b-data-table'),(990215,'deals','.w-communication-post .communication-post-attach','text-align','right','','','.w-communication-post'),(990216,'deals','.b-products-listing .products-listing .image','text-align','center','','','.b-products-listing'),(990217,'deals','.b-products-listing .products-listing','text-align','center','','','.b-products-listing'),(990218,'deals','.b-products-listing .products-listing .btn-buy','text-align','center','','','.b-products-listing'),(990219,'deals','.w-catalog-b2b-add-button .b2b-add-box-wrap','text-align','right','','','.w-catalog-b2b-add-button'),(990220,'deals','.b-products-listing .products-listing .properties','text-align','left','','','.b-products-listing'),(990221,'deals','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','text-align','left','','','.b-products-listing'),(990222,'deals','.b-products-listing .show-ofstock-products','text-align','center','','','.b-products-listing'),(990223,'deals','.checkbox input:checked + span:before','text-align','center','','',''),(990224,'deals','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(990225,'deals','.p-sample-checkout-success .page-success','text-align','center','','','.p-sample-checkout-success'),(990226,'deals','.b-products-listing .products-listing .in-cart','text-align','center','','','.b-products-listing'),(990227,'deals','.b-email-editor .price','text-align','center','','','.b-email-editor'),(990228,'deals','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(990229,'deals','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','text-align','center','3','','.w-checkout-contact-information'),(990230,'deals','.b-fancybox .fancybox-title-float-wrap','text-align','center','','','.b-fancybox'),(990231,'deals','.b-email .model','text-align','center','','','.b-email'),(990233,'deals','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(990234,'deals','.order-summary .price-row.ot_coupon .title','text-align','center','3','','.order-summary'),(990235,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','text-align','center','','','.w-communication-new-topic'),(990236,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','text-align','center','','','.w-communication-new-topic'),(990237,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(5), .w-communication-new-topic #rmaProductReturnQuantityFilterHolder td:nth-child(7)','text-align','center','','','.w-communication-new-topic'),(990238,'deals','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(990239,'deals','.b-email .heading-model','text-align','center','','','.b-email'),(990241,'deals','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(990242,'deals','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(990243,'deals','.b-email .model','text-align','center','','','.b-email'),(990244,'deals','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(990245,'deals','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(990246,'deals','.b-email .totals-title','text-align','right','','','.b-email'),(990247,'deals','.b-email .heading-price','text-align','right','','','.b-email'),(990248,'deals','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(990250,'deals','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(990251,'deals','.b-email-editor .image, .b-email-editor .name','text-align','center','','','.b-email-editor'),(990252,'deals','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(990253,'deals','.b-email .totals-label','text-align','right','','','.b-email'),(990254,'deals','.b-email .totals-title','text-align','right','','','.b-email'),(990255,'deals','.b-email .price','text-align','right','','','.b-email'),(990256,'deals','.b-email .heading-price','text-align','right','','','.b-email'),(990257,'deals','.b-compare .compare-head','text-align','left','','','.b-compare'),(990258,'deals','.w-menu-horizontal ul ul li','text-align','left','','','.w-menu-horizontal'),(990260,'deals','.b-email .heading-model','text-align','center','','','.b-email'),(990261,'deals','.w-catalog-listing-look .grid','text-align','center','','','.w-catalog-listing-look'),(990262,'deals','.w-catalog-listing-look .b2b','text-align','center','','','.w-catalog-listing-look'),(990263,'deals','.w-catalog-listing-look .list','text-align','center','','','.w-catalog-listing-look'),(990264,'deals','.w-cart-listing .image','text-align','center','','','.w-cart-listing'),(990265,'deals','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','text-align','left','','','.w-cart-listing'),(990266,'deals','.w-cart-listing .points-earn','text-align','right','','','.w-cart-listing'),(990267,'deals','.w-cart-listing .points-redeem','text-align','left','','','.w-cart-listing'),(990268,'deals','.w-cart-listing .no-price .qty','text-align','right','','','.w-cart-listing'),(990269,'deals','.w-cart-listing .remove-btn','text-align','center','','','.w-cart-listing'),(990270,'deals','.w-cart-listing .price','text-align','right','','','.w-cart-listing'),(990271,'deals','.w-cart-listing .remove','text-align','center','','','.w-cart-listing'),(990272,'deals','.w-cart-give-away .ga_img','text-align','center','','','.w-cart-give-away'),(990273,'deals','.w-cart-discount-coupon .btn-remove','text-align','center','','','.w-cart-discount-coupon'),(990275,'deals','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(990276,'deals','.b-email-editor .special-price','text-align','center','','','.b-email-editor'),(990277,'deals','.b-email-editor .old-price','text-align','center','','','.b-email-editor'),(990278,'deals','.b-fancybox .fancybox-nav span','text-align','center','','','.b-fancybox'),(990279,'deals','.w-success-continue-btn','text-align','center','5639','','.w-success-continue-btn'),(990280,'deals','.w-tabs .accordion-heading','text-align','center','','','.w-tabs'),(990281,'deals','.w-quote-checkout-btn','text-align','right','','','.w-quote-checkout-btn'),(990282,'deals','.w-product-promotions .promotion','text-align','center','','','.w-product-promotions'),(990283,'deals','.p-quick-order-index table.dataTable tbody th, .p-quick-order-index table.dataTable tbody td','text-align','center','','','.p-quick-order-index'),(990284,'deals','.w-brands .brands-listing > div','text-align','center','','','.w-brands'),(990285,'deals','.p-quote-checkout-success .page-success','text-align','center','','','.p-quote-checkout-success'),(990286,'deals','.w-login-block .buttons','text-align','right','','','.w-login-block'),(990287,'deals','.w-filters .handle-to','text-align','right','','','.w-filters'),(990288,'deals','.order-summary .box','text-align','center','','','.order-summary'),(990289,'deals','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(990290,'deals','.b-bottom .pop-up-close','text-align','center','','','.b-bottom'),(990291,'deals','.order-summary .price-row.ot_bonus_points .title','text-align','center','3','','.order-summary'),(990292,'deals','.w-success-continue-btn','text-align','center','5639','','.w-success-continue-btn'),(990293,'deals','.b-form .radio-button input[type=\"radio\"].no + span','text-align','center','3','','.b-form'),(990294,'deals','.b-social-login .social-login','text-align','center','','','.b-social-login'),(990295,'deals','.w-reviews-content .date','text-align','right','','','.w-reviews-content'),(990296,'deals','.b-data-table table.dataTable tbody td:last-child','text-align','right','','','.b-data-table'),(990297,'deals','.b-data-table .dt-body-center','text-align','center','','','.b-data-table'),(990298,'deals','.b-tracking-numbers .tracking-numbers .model','text-align','right','','','.b-tracking-numbers'),(990299,'deals','.w-menu-big li a, .w-menu-big li .no-link','text-align','left','','','.w-menu-big'),(990300,'deals','.b-tracking-numbers .tracking-numbers-popup .heading-4','text-align','center','','','.b-tracking-numbers'),(990301,'deals','.b-upload-file .upload-file-template','text-align','center','','','.b-upload-file'),(990302,'deals','.b-email-editor .price','text-align','center','','','.b-email-editor'),(990303,'deals','.b-email .totals-value','text-align','right','','','.b-email'),(990304,'deals','.b-email .totals-label','text-align','right','','','.b-email'),(990305,'deals','.b-email .totals-title','text-align','right','','','.b-email'),(990306,'deals','.b-email .qty','text-align','center','','','.b-email'),(990307,'deals','.b-upload-file .snapshot','text-align','center','','','.b-upload-file'),(990308,'deals','.w-account-apply-certificate .gift-certificate','text-align','center','','','.w-account-apply-certificate'),(990309,'deals','.b-product-images .media-popup .mp-close','text-align','center','','','.b-product-images'),(990310,'deals','.b-product-images .media-popup .mp-small-images','text-align','center','','','.b-product-images'),(990311,'deals','.b-product-images .media-popup .mp-small-images .item','text-align','center','','','.b-product-images'),(990312,'deals','.b-product-images .media-popup .slick-dots','text-align','center','','','.b-product-images'),(990313,'deals','.b-product-images .media-popup .slick-dots li','text-align','center','','','.b-product-images'),(990314,'deals','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','text-align','center','','','.b-menu-burger_icon'),(990315,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(990316,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(990317,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(990318,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(990319,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','text-align','center','','','.b-menu-lev_vis-click_icon'),(990320,'deals','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(990321,'deals','.b-personal-catalog-popup #personal_catalog_popup','text-align','left','','','.b-personal-catalog-popup'),(990322,'deals','.b-trade-approval .steps-bar li','text-align','center','','','.b-trade-approval'),(990323,'deals','.b-trade-approval .steps-bar li a','text-align','center','','','.b-trade-approval'),(990324,'deals','.b-trade-approval .orders-table td:nth-child(1), .b-trade-approval .orders-table th:nth-child(1)','text-align','left','','','.b-trade-approval'),(990325,'deals','.b-trade-approval .orders-table td:nth-child(2)','text-align','right','','','.b-trade-approval'),(990326,'deals','.b-trade-approval .w-login-block label','text-align','left','','','.b-trade-approval'),(990327,'deals','.b-trade-approval .steps-bar','text-align','left','','','.b-trade-approval'),(990328,'deals','.b-trade-approval .center-buttons','text-align','center','','','.b-trade-approval'),(990329,'deals','.b-trade-approval .comments','text-align','left','','','.b-trade-approval'),(990330,'deals','.w-account-personal-catalog .list-switcher a','text-align','center','','','.w-account-personal-catalog'),(990331,'deals','.w-catalog-additional-images ul, .w-catalog-additional-images li','text-align','center','','','.w-catalog-additional-images'),(990332,'deals','.w-catalog-compare .cross-box .different-all > div','text-align','center','','','.w-catalog-compare'),(990333,'deals','.w-delivery-day .time-left','text-align','center','','','.w-delivery-day'),(990334,'deals','.w-top-text .top-text','text-align','center','','','.w-top-text'),(990335,'deals','.b-cookie-notice .cookie-notice','text-align','center','','','.b-cookie-notice'),(990339,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','text-align','center','','','.b-slick'),(990340,'deals','.b-products-listing .products-listing.list-productlisting .BlockBox.item-holder','text-align','center','','','.b-products-listing'),(990341,'deals','.w-quote .cart-box-link','text-align','center','3','','.w-quote'),(990342,'deals','.w-quote .price','text-align','right','','','.w-quote'),(990343,'deals','.b-quantity .qty-box .bigger','text-align','center','','','.b-quantity'),(990344,'deals','.b-quantity .qty-box .smaller','text-align','center','','','.b-quantity'),(990345,'deals','.b-quantity .qty-box input','text-align','center','','','.b-quantity'),(990346,'deals','.b-quantity .qty-input','text-align','right','','','.b-quantity'),(990347,'deals','.b-quantity .qty-input input','text-align','center','','','.b-quantity'),(990348,'deals','.productNavigation .test','text-align','center','','','.productNavigation'),(990349,'deals','.w-product-sale-ends .ends','text-align','center','','','.w-product-sale-ends'),(990350,'deals','.w-product-sale-ends .left','text-align','center','','','.w-product-sale-ends'),(990351,'deals','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','text-align','center','','','.w-product-buttons'),(990352,'deals','.w-product-buttons .notify-form','text-align','left','','','.w-product-buttons'),(990353,'deals','.w-product-quantity .qty-input','text-align','left','','','.w-product-quantity'),(990354,'deals','.w-product-quantity .qty_packs .qty_price','text-align','right','','','.w-product-quantity'),(990355,'deals','.w-files-catalog-widgets-files-catalog .item','text-align','center','','','.w-files-catalog-widgets-files-catalog'),(990356,'deals','.w-sample .cart-box-link','text-align','center','3','','.w-sample'),(990357,'deals','.w-sample .price','text-align','right','','','.w-sample'),(990358,'deals','.w-cart-listing .item > div.points','text-align','right','','','.w-cart-listing'),(990359,'deals','.w-filters-simple .integrate-price-holder','text-align','right','','','.w-filters-simple'),(990360,'deals','.w-cart-sub-total .price','text-align','right','','','.w-cart-sub-total'),(990361,'deals','.w-product-images .additional-horizontal .item','text-align','center','','','.w-product-images'),(990362,'deals','.w-product-video .frame-video','text-align','center','','','.w-product-video'),(990363,'deals','.w-product-video .item','text-align','center','','','.w-product-video'),(990364,'deals','.w-product-bundle .bundle-total-price','text-align','right','','','.w-product-bundle'),(990365,'deals','.w-product-in-bundles .bundle-total-price','text-align','right','','','.w-product-in-bundles'),(990366,'deals','.w-cart-listing .item div.price','text-align','right','5639','','.w-cart-listing'),(990367,'deals','.w-sample-products .w-cart-listing .item .qty','text-align','right','5630','','.w-sample-products'),(990369,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','text-align','inherit','','','.b-products-listing'),(990370,'deals','.b-pagination .pagination .next-pages','text-align','center','','','.b-pagination'),(990371,'deals','.b-pagination .pagination .p-blog-index','text-align','right','','','.b-pagination'),(990372,'deals','.b-pagination .pagination .page-number','text-align','center','','','.b-pagination'),(990373,'deals','.b-pagination .pagination .prev-pages','text-align','center','','','.b-pagination'),(990374,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','text-align','center','','','.b-pagination'),(990375,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','text-align','center','','','.b-pagination'),(990376,'deals','.b-pagination .pagination span','text-align','center','2','','.b-pagination'),(990377,'deals','.p-quote-checkout-index .heading-2','text-align','left','','','.p-quote-checkout-index'),(990378,'deals','.p-sample-checkout-index .heading-2','text-align','left','','','.p-sample-checkout-index'),(990379,'deals','.p-quote-checkout-index .order-summary .heading-2','text-align','center','','','.p-quote-checkout-index'),(990380,'deals','.w-sample-products .w-cart-listing .qty','text-align','center','','','.w-sample-products'),(990381,'deals','.p-sample-checkout-index .order-summary .heading-2','text-align','center','','','.p-sample-checkout-index'),(990383,'deals','.w-quote-products .cart-listing .qty','text-align','right','','','.w-quote-products'),(990384,'deals','.w-product-multi-inventory .radio-attributes .option-item','text-align','center','','','.w-product-multi-inventory'),(990385,'deals','.b-products-listing .products-listing.list-rows .qtyInput','text-align','center','','','.b-products-listing'),(990386,'deals','.b-products-listing .products-listing .radio-attributes .option','text-align','center','','','.b-products-listing'),(990387,'deals','.b-products-listing .products-listing.list-b2b .qtyInput','text-align','center','','','.b-products-listing'),(990388,'deals','.w-product-collection .current-product','text-align','center','','','.w-product-collection'),(990389,'deals','.w-product-collection .item','text-align','center','','','.w-product-collection'),(990390,'deals','.w-product-collection .right-area','text-align','center','','','.w-product-collection'),(990391,'deals','.w-product-collection .choose-products .heading-3','text-align','center','','','.w-product-collection'),(990392,'deals','.w-product-attributes .radio-attributes .option-item','text-align','center','','','.w-product-attributes'),(990393,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','text-align','center','','','.w-questionnaire-widgets-questionnaire'),(990394,'deals','.w-product-groups .val1','text-align','center','','','.w-product-groups'),(990395,'deals','.w-product-groups .prop-group-swatch','text-align','center','','','.w-product-groups'),(990396,'deals','.w-product-groups .radioBox label .containerBlock .prop-group-swatch img + .val2','text-align','center','','','.w-product-groups'),(990397,'deals','.b-products-listing .products-listing .attribute-qty-block > span','text-align','center','','','.b-products-listing'),(990398,'deals','.w-product-custom-bundle .heading-3','text-align','center','','','.w-product-custom-bundle'),(990399,'deals','.w-product-custom-bundle .current-product','text-align','center','','','.w-product-custom-bundle'),(990400,'deals','.w-product-custom-bundle .item','text-align','center','','','.w-product-custom-bundle'),(990401,'deals','.w-product-custom-bundle .right-area','text-align','center','','','.w-product-custom-bundle'),(990402,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','text-align','center','','','.w-catalog-pages-category-pages-last-list'),(990403,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','text-align','center','','','.w-catalog-pages-category-pages-last-list-block'),(990404,'deals','.w-delivery-location-location-list .deliveryListParrent','text-align','center','','','.w-delivery-location-location-list'),(990405,'deals','.w-delivery-location-location-list .deliveryList li','text-align','center','','','.w-delivery-location-location-list'),(990406,'deals','.w-sale-category .badge','text-align','center','','','.w-sale-category'),(990407,'deals','.w-sale-category .btn','text-align','center','','','.w-sale-category'),(990408,'deals','.w-sale-category .image','text-align','center','','','.w-sale-category'),(990409,'deals','.w-sale-category .left','text-align','center','','','.w-sale-category'),(990410,'deals','.w-success-download table','text-align','center','','','.w-success-download'),(990411,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-img','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(990412,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-name','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(990413,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(990414,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-img','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(990415,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-name','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(990416,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(990417,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-short_description + div','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(990418,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(990419,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(990420,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-short_description + div','text-align','center','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(990421,'deals','.w-product-properties-icons .hover-box-content','text-align','center','','','.w-product-properties-icons'),(990422,'deals','.w-delivery-location-product-categories .item.category-link','text-align','center','','','.w-delivery-location-product-categories'),(990423,'deals','.w-product-bonus-points .bonus-points-cost','text-align','left','','','.w-product-bonus-points'),(990424,'deals','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','text-align','right','','','.w-press-reviews-widgets-press-reviews-small'),(990425,'deals','.w-press-reviews-widgets-press-reviews .date','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(990426,'deals','.w-press-reviews-widgets-press-reviews .heading-3','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(990427,'deals','.w-press-reviews-widgets-press-reviews .image','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(990428,'deals','.w-press-reviews-widgets-press-reviews .item','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(990429,'deals','.w-press-reviews-widgets-press-reviews .press-reviews-button','text-align','center','','','.w-press-reviews-widgets-press-reviews'),(990430,'deals','.w-press-reviews-widgets-press-reviews .sub-box','text-align','left','','','.w-press-reviews-widgets-press-reviews'),(990431,'deals','.w-press-reviews-widgets-press-reviews .author','text-align','center','5630','','.w-press-reviews-widgets-press-reviews'),(990432,'deals','.w-press-reviews-widgets-press-reviews .date','text-align','center','5630','','.w-press-reviews-widgets-press-reviews'),(990433,'deals','.w-press-reviews-widgets-press-reviews .image','text-align','center','5630','','.w-press-reviews-widgets-press-reviews'),(990434,'deals','.w-press-reviews-widgets-press-reviews .rating','text-align','center','5630','','.w-press-reviews-widgets-press-reviews'),(990435,'deals','.w-press-reviews-widgets-press-reviews .review','text-align','center','5630','','.w-press-reviews-widgets-press-reviews'),(990436,'deals','.w-press-reviews-widgets-press-reviews .title','text-align','center','5630','','.w-press-reviews-widgets-press-reviews'),(990437,'deals','.w-press-reviews-widgets-press-reviews-list .review-box ul li','text-align','left','','','.w-press-reviews-widgets-press-reviews-list'),(990438,'deals','.w-support-system-listing .product_icon','text-align','center','','','.w-support-system-listing'),(990439,'deals','.w-rma-returns-history .btn','text-align','center','','','.w-rma-returns-history'),(990440,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','text-align','center','','','.w-rma-returns-history'),(990441,'deals','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(990442,'deals','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(990443,'deals','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','text-align','center','','','.b-menu-position'),(990444,'deals','.w-product-configurator .pc-total-price','text-align','right','','','.w-product-configurator'),(990445,'deals','.w-product-configurator .pc_price','text-align','right','','','.w-product-configurator'),(990446,'deals','.w-product-configurator .pc_qty','text-align','right','','','.w-product-configurator'),(990447,'deals','.w-product-configurator .pc_qty','text-align','left','5630','','.w-product-configurator'),(990448,'deals','.b-products-listing .promo-icon','text-align','center','','','.b-products-listing'),(990449,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','text-align','center','','','.w-catalog-pages-category-pages-list'),(990450,'deals','.w-predefined-promotion .prom-multi-discount .heading','text-align','center','','','.w-predefined-promotion'),(990451,'deals','.w-predefined-promotion .promo-date','text-align','center','','','.w-predefined-promotion'),(990452,'deals','.w-predefined-promotion .promo-item','text-align','center','','','.w-predefined-promotion'),(990453,'deals','.w-supplier-purchase-supplier-products .active .select_item > div','text-align','center','','','.w-supplier-purchase-supplier-products'),(990457,'deals','.headerWrap .w-contacts.phone','text-align','center','','','.headerWrap'),(990458,'deals','.parallaxWrap .w-info-page','text-align','center','','','.parallaxWrap'),(990459,'deals','.w-subscribers .sb_tc + .sb_tc','text-align','right','','','.w-subscribers'),(990460,'deals','.filterLine .before','text-align','center','','','.filterLine'),(990461,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span','text-align','center','','','.w-product-quantity-discounts'),(990462,'deals','.b-quantity .qty-box input[type=\'text\']','text-align','center','','','.b-quantity'),(990463,'deals','.w-product-groups .radioBox label','text-align','center','','','.w-product-groups'),(990464,'deals','.w-product-name h1','text-align','left','','','.w-product-name'),(990466,'deals','.w-tabs .tab-navigation','text-align','center','','','.w-tabs'),(990467,'deals','.homeBanner .carousel .bottom-center > span','text-align','center','','','.homeBanner'),(990469,'deals','.filterLine .before','text-align','left','5660','','.filterLine'),(990470,'deals','.w-filters .filter_buttons','text-align','center','','','.w-filters'),(990471,'deals','.b-products-listing .item-nav, .b-products-listing .item-nav > div','text-align','center','','','.b-products-listing'),(990472,'deals','.w-cart-listing .item .qty','text-align','left','5630','','.w-cart-listing'),(990473,'deals','.btn','text-align','center','','',''),(990474,'deals','.btn-1','text-align','center','','',''),(990475,'deals','.btn-2','text-align','center','','',''),(990476,'deals','.btn-3','text-align','center','','',''),(990477,'deals','.w-product-personal-catalog-button .btn','text-align','center','','','.w-product-personal-catalog-button'),(990478,'deals','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','text-align','center','','','.w-account-personal-catalog'),(990479,'deals','.w-account-personal-catalog .check-box','text-align','center','','','.w-account-personal-catalog'),(990480,'deals','.w-account-personal-catalog .remove','text-align','center','','','.w-account-personal-catalog'),(990481,'deals','.w-account-personal-catalog .w-cart-listing .item .remove','text-align','center','5639','','.w-account-personal-catalog'),(990482,'deals','.w-account-personal-catalog .qty-input','text-align','center','','','.w-account-personal-catalog'),(990483,'deals','.w-account-personal-catalog .qty-input','text-align','left','5630','','.w-account-personal-catalog'),(990484,'deals','.w-product-wishlist-button .btn','text-align','center','5630','','.w-product-wishlist-button'),(990485,'deals','.homeBanner .banner-item .banner-text-holder','text-align','center','','','.homeBanner'),(990486,'deals','.homeBanner .banner-item.text-bottom-left .banner-text-holder','text-align','left','','','.homeBanner'),(990487,'deals','.homeBanner .banner-item.text-bottom-right .banner-text-holder','text-align','right','','','.homeBanner'),(990488,'deals','.homeBanner .banner-item.text-middle-center .banner-text-holder','text-align','center','','','.homeBanner'),(990489,'deals','.homeBanner .banner-item.text-middle-left .banner-text-holder','text-align','left','','','.homeBanner'),(990490,'deals','.homeBanner .banner-item.text-middle-right .banner-text-holder','text-align','right','','','.homeBanner'),(990491,'deals','.homeBanner .banner-item.text-top-center .banner-text-holder','text-align','center','','','.homeBanner'),(990492,'deals','.homeBanner .banner-item.text-top-left .banner-text-holder','text-align','left','','','.homeBanner'),(990493,'deals','.homeBanner .banner-item.text-top-right .banner-text-holder','text-align','right','','','.homeBanner'),(990494,'deals','.order-summary .w-cart-listing .item .name','text-align','left','','','.order-summary'),(990495,'deals','.order-summary .w-cart-listing.type-2 .image','text-align','left','','','.order-summary'),(990496,'deals','.w-cart-discount-coupon .title','text-align','left','','','.w-cart-discount-coupon'),(990497,'deals','.w-quote-products .w-cart-listing .item .qty','text-align','right','5630','','.w-quote-products'),(990498,'deals','.w-promotions-widgets-promotions .promotion','text-align','center','','','.w-promotions-widgets-promotions'),(990507,'deals','.account-address-book .address_book h2','text-align','right','','','.account-address-book'),(990515,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-align','left','','','.account-order-pay'),(990516,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-align','left','3','','.account-order-pay'),(990517,'deals','.account-order-pay .tableForm th','text-align','left','','','.account-order-pay'),(990518,'deals','.account-samples .orders-table td.td-alignright','text-align','right','','','.account-samples'),(990519,'deals','.account-samples .orders-table th','text-align','left','','','.account-samples'),(990520,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-align','left','','','.account-sample-info'),(990521,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-align','left','3','','.account-sample-info'),(990522,'deals','.account-sample-info .popup-tracking-number','text-align','center','','','.account-sample-info'),(990523,'deals','.account-sample-info .tableForm th','text-align','left','','','.account-sample-info'),(990524,'deals','.account-sample-info .trackings-nambers','text-align','center','','','.account-sample-info'),(990525,'deals','.catalog-product-wrap .prev-next-product','text-align','center','','','.catalog-product-wrap'),(990526,'deals','.shopping-cart-index .cart-page .empty','text-align','center','','','.shopping-cart-index'),(990527,'deals','.checkout-index-wrap .heading-2','text-align','left','','','.checkout-index-wrap'),(990528,'deals','.checkout-index-wrap .order-summary .heading-2','text-align','center','','','.checkout-index-wrap'),(990529,'deals','.checkout-order-confirmation .heading-2.prod-ico','text-align','left','','','.checkout-order-confirmation'),(990530,'deals','.checkout-order-confirmation .price-box .title','text-align','left','','','.checkout-order-confirmation'),(990531,'deals','.checkout-success-wrap .page-success','text-align','center','','','.checkout-success-wrap'),(990532,'deals','.b-bottom .cart-options .cart-item','text-align','center','','','.b-bottom'),(990533,'deals','.success-page .page-success .text-1','text-align','center','','','.success-page'),(990534,'deals','.success-page .price-box .title','text-align','left','','','.success-page'),(990535,'deals','.success-page .w-cart-listing .qty','text-align','center','','','.success-page'),(990538,'deals','.w-cart-products .checkout-attention-message','text-align','center','','','.w-cart-products'),(990539,'deals','.b-multi-page-checkout .messageBox .info','text-align','left','','','.b-multi-page-checkout'),(990540,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','text-align','center','','','.b-multi-page-checkout'),(990541,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','text-align','center','3','','.b-multi-page-checkout'),(990542,'deals','.bannersWrap .rightBanner .banner-text','text-align','center','','','.bannersWrap'),(990543,'deals','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','text-align','center','','','.w-banner'),(990544,'deals','.w-banner .single_banner','text-align','center','','','.w-banner'),(990545,'deals','.w-catalog-paging ','text-align','center','2','','.w-catalog-paging'),(990546,'deals','.w-catalog-paging .next','text-align','center','','','.w-catalog-paging'),(990547,'deals','.w-catalog-paging .next-pages','text-align','center','','','.w-catalog-paging'),(990548,'deals','.w-catalog-paging .p-blog-index','text-align','right','','','.w-catalog-paging'),(990549,'deals','.w-catalog-paging .page-number','text-align','center','','','.w-catalog-paging'),(990550,'deals','.w-catalog-paging .prev','text-align','center','','','.w-catalog-paging'),(990551,'deals','.w-catalog-paging .prev-pages','text-align','center','','','.w-catalog-paging'),(990552,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align','center','','','.w-catalog-paging'),(990554,'deals','.w-menu-slider .close','text-align','center','','','.w-menu-slider'),(990555,'deals','.w-menu-slider .menu-ico','text-align','center','','','.w-menu-slider'),(990556,'deals','.w-menu-slider > ul','text-align','center','','','.w-menu-slider'),(990557,'deals','.w-menu-slider > ul > li > ul','text-align','center','','','.w-menu-slider'),(990558,'deals','.w-menu-slider > ul > li > ul li','text-align','left','','','.w-menu-slider'),(990559,'deals','.w-success-continue-btn','text-align_important','important','5639','','.w-success-continue-btn'),(990560,'deals','.w-success-continue-btn','text-align_important','important','5639','','.w-success-continue-btn'),(990561,'deals','.w-success-continue-btn','text-align_important','important','5639','','.w-success-continue-btn'),(990562,'deals','.w-success-continue-btn','text-align_important','important','5639','','.w-success-continue-btn'),(990563,'deals','.w-success-continue-btn','text-align_important','important','5639','','.w-success-continue-btn'),(990564,'deals','.w-success-continue-btn','text-align_important','important','5639','','.w-success-continue-btn'),(990565,'deals','.p-quick-order-index .al_name, .p-quick-order-index .al-name, .p-quick-order-index .al_model, .p-quick-order-index .al-model','text-align_important','important','','','.p-quick-order-index'),(990566,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','text-align_important','important','','','.w-catalog-paging'),(990567,'deals','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(990568,'deals','.b-fancybox a.fancybox-close','text-decoration','none','1','','.b-fancybox'),(990569,'deals','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(990570,'deals','.w-chat .w-chat-box a','text-decoration','none','1','','.w-chat'),(990572,'deals','.w-socials > li a','text-decoration','none','','','.w-socials'),(990573,'deals','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(990574,'deals','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(990575,'deals','.price .old','text-decoration','line-through','','',''),(990576,'deals','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(990577,'deals','.b-select-suggest .select2-result-selectable .select2-match, .b-select-suggest .select2-result-unselectable .select2-match','text-decoration','underline','','','.b-select-suggest'),(990578,'deals','.w-socials > li a','text-decoration','none','','','.w-socials'),(990579,'deals','.w-tabs .tab-a','text-decoration','none','','','.w-tabs'),(990580,'deals','.w-socials > li a','text-decoration','none','','','.w-socials'),(990581,'deals','.btn-edit','text-decoration','none','1','',''),(990582,'deals','.w-socials > li a','text-decoration','none','','','.w-socials'),(990583,'deals','.heading-3 .right-text, h3 .right-text','text-decoration','none','','',''),(990584,'deals','.w-socials > li a','text-decoration','none','','','.w-socials'),(990585,'deals','.w-image-maps .categories-items .item a','text-decoration','none','1','','.w-image-maps'),(990586,'deals','.w-social-links a','text-decoration','none','1','','.w-social-links'),(990587,'deals','.w-chat .w-chat-box a','text-decoration','none','','','.w-chat'),(990588,'deals','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(990589,'deals','.w-socials > li a','text-decoration','none','','','.w-socials'),(990590,'deals','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(990591,'deals','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(990592,'deals','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(990593,'deals','.b-select-suggest .select2-container .select2-choice','text-decoration','none','','','.b-select-suggest'),(990594,'deals','.b-email-editor .name a','text-decoration','none','','','.b-email-editor'),(990595,'deals','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(990596,'deals','.w-cart-listing .remove-btn','text-decoration','none','','','.w-cart-listing'),(990599,'deals','.b-email-editor .old-price','text-decoration','line-through','','','.b-email-editor'),(990600,'deals','.w-image-maps .float-items .item a','text-decoration','none','1','','.w-image-maps'),(990601,'deals','.b-fancybox .fancybox-nav','text-decoration','none','','','.b-fancybox'),(990602,'deals','.w-tabs .accordion-heading','text-decoration','none','','','.w-tabs'),(990603,'deals','.b-select-suggest .select2-container .select2-choice abbr','text-decoration','none','','','.b-select-suggest'),(990604,'deals','.w-filters .mobileCollapse','text-decoration','none','1','','.w-filters'),(990605,'deals','.w-account-personal-catalog .list-switcher a','text-decoration','none','','','.w-account-personal-catalog'),(990608,'deals','.LeftCategories ul li a','text-decoration','none','1','','.LeftCategories'),(990609,'deals','.w-quote .multicart a.name','text-decoration','none','1','','.w-quote'),(990610,'deals','.w-quote .multicart a.switch-cart','text-decoration','none','1','','.w-quote'),(990611,'deals','.w-quote a.cart-box-link','text-decoration','none','1','','.w-quote'),(990612,'deals','.w-quote a.item','text-decoration','none','1','','.w-quote'),(990613,'deals','.w-sample .multicart a.name','text-decoration','none','1','','.w-sample'),(990614,'deals','.w-sample .multicart a.switch-cart','text-decoration','none','1','','.w-sample'),(990615,'deals','.w-sample a.cart-box-link','text-decoration','none','1','','.w-sample'),(990616,'deals','.w-sample a.item','text-decoration','none','1','','.w-sample'),(990617,'deals','.w-product-bundle .bundle_price .old','text-decoration','line-through','','','.w-product-bundle'),(990618,'deals','.w-product-in-bundles .bundle_price .old','text-decoration','line-through','','','.w-product-in-bundles'),(990619,'deals','.b-pagination .pagination a','text-decoration','none','1','','.b-pagination'),(990620,'deals','.b-pagination .pagination span','text-decoration','none','1','','.b-pagination'),(990621,'deals','.w-delivery-location-location-list .deliveryList li a','text-decoration','none','1','','.w-delivery-location-location-list'),(990622,'deals','.w-sale-category .old','text-decoration','line-through','','','.w-sale-category'),(990623,'deals','.w-checkout-shipping-address .change-ab','text-decoration','underline','','','.w-checkout-shipping-address'),(990624,'deals','.w-checkout-shipping-address .change-ab','text-decoration','none','1','','.w-checkout-shipping-address'),(990625,'deals','.w-checkout-shipping-address .edit-ab','text-decoration','underline','','','.w-checkout-shipping-address'),(990626,'deals','.w-checkout-shipping-address .edit-ab','text-decoration','none','1','','.w-checkout-shipping-address'),(990627,'deals','.w-checkout-contact-information .btn-edit1','text-decoration','underline','','','.w-checkout-contact-information'),(990628,'deals','.w-checkout-contact-information .btn-edit1','text-decoration','none','1','','.w-checkout-contact-information'),(990629,'deals','.w-top-categories .item','text-decoration','none','1','','.w-top-categories'),(990630,'deals','.w-categories .item','text-decoration','none','1','','.w-categories'),(990631,'deals','.w-breadcrumb a','text-decoration','none','1','','.w-breadcrumb'),(990632,'deals','.w-product-groups .radioBox label a','text-decoration','none','','','.w-product-groups'),(990633,'deals','.headerWrap .menu-style[data-style=\"1\"] a','text-decoration','none','1','','.headerWrap'),(990640,'deals','.account-samples .orders-table a, .account-samples .order-info a','text-decoration','none','1','','.account-samples'),(990641,'deals','.account-samples .view_link','text-decoration','underline','','','.account-samples'),(990642,'deals','.catalog-product-wrap a.prev-next-product','text-decoration','none','1','','.catalog-product-wrap'),(990643,'deals','.checkout-index-wrap .edit-address-popup .edit-ab','text-decoration','underline','','','.checkout-index-wrap'),(990644,'deals','.checkout-index-wrap .edit-address-popup .edit-ab','text-decoration','none','1','','.checkout-index-wrap'),(990645,'deals','.b-form .addresses .address-item .edit-ab','text-decoration','underline','','','.b-form'),(990646,'deals','.w-catalog-paging a','text-decoration','none','1','','.w-catalog-paging'),(990647,'deals','.w-catalog-paging span','text-decoration','none','1','','.w-catalog-paging'),(990648,'deals','.b-select-suggest .select2-container .select2-choice > .select2-chosen','text-overflow','ellipsis','','','.b-select-suggest'),(990649,'deals','.b-fancybox .fancybox-skin','text-shadow','none','','','.b-fancybox'),(990650,'deals','.b-fancybox .fancybox-title','text-shadow','none','','','.b-fancybox'),(990651,'deals','.heading-4 .right-text, h4 .right-text','text-transform','none','','',''),(990652,'deals','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(990653,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-on','text-transform','uppercase','','','.b-switch'),(990654,'deals','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(990655,'deals','.p-sample-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-sample-checkout-success'),(990656,'deals','.p-sample-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-sample-checkout-success'),(990657,'deals','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(990658,'deals','.w-promotions .heading-3','text-transform','uppercase','','','.w-promotions'),(990659,'deals','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(990660,'deals','.b-messages .content-messages .heading-2','text-transform','none','','','.b-messages'),(990661,'deals','.heading-4 .edit, h4 .edit','text-transform','none','','',''),(990662,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','text-transform','uppercase','4','','.b-switch'),(990663,'deals','.w-personal-gift-status-bar .end-date','text-transform','uppercase','','','.w-personal-gift-status-bar'),(990664,'deals','.w-checkout-shipping-choice span','text-transform','uppercase','','','.w-checkout-shipping-choice'),(990665,'deals','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(990667,'deals','.w-cart-compare .cart-name a','text-transform','uppercase','','','.w-cart-compare'),(990668,'deals','.heading-3 .edit, h3 .edit','text-transform','none','','',''),(990669,'deals','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(990670,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','text-transform','uppercase','4','','.b-switch'),(990671,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','text-transform','uppercase','4','','.b-switch'),(990672,'deals','.w-multi-cart-cart-switcher .cart-list .dropdown-toggle','text-transform','uppercase','','','.w-multi-cart-cart-switcher'),(990673,'deals','.w-top-categories .categories h2','text-transform','inherit','','','.w-top-categories'),(990674,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','text-transform','uppercase','','','.b-switch'),(990675,'deals','.b-bottom .cart-options .heading-4','text-transform','none','','','.b-bottom'),(990676,'deals','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(990677,'deals','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(990678,'deals','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(990679,'deals','.p-quote-checkout-success .page-success .text-1','text-transform','uppercase','','','.p-quote-checkout-success'),(990680,'deals','.w-personal-gift-status-bar .inform','text-transform','uppercase','','','.w-personal-gift-status-bar'),(990681,'deals','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(990682,'deals','.h-inline h2, .h-inline h3, .h-inline h4, .h-inline h5, .h-inline h6','text-transform','inherit','','',''),(990683,'deals','.b-h-inline h2, .b-h-inline h3, .b-h-inline h4, .b-h-inline h5, .b-h-inline h6','text-transform','inherit','','','.b-h-inline'),(990684,'deals','.p-quote-checkout-success .page-success .text-2','text-transform','uppercase','','','.p-quote-checkout-success'),(990685,'deals','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','text-transform','uppercase','','','.w-cart-listing'),(990687,'deals','.w-tabs .accordion-heading','text-transform','uppercase','','','.w-tabs'),(990688,'deals','.w-account-personal-catalog .list-switcher a','text-transform','uppercase','','','.w-account-personal-catalog'),(990689,'deals','.w-quote .multicart .title','text-transform','uppercase','','','.w-quote'),(990690,'deals','.w-product-personal-catalog-button .btn','text-transform','uppercase','','','.w-product-personal-catalog-button'),(990691,'deals','.w-files-catalog-widgets-files-catalog .name','text-transform','uppercase','','','.w-files-catalog-widgets-files-catalog'),(990692,'deals','.w-files-catalog-widgets-files-list .name','text-transform','uppercase','','','.w-files-catalog-widgets-files-list'),(990693,'deals','.w-sample .multicart .title','text-transform','uppercase','','','.w-sample'),(990694,'deals','.w-cart-discount-coupon .btn','text-transform','none','','','.w-cart-discount-coupon'),(990695,'deals','.w-cart-up-sell .products-listing .name a','text-transform','none','','','.w-cart-up-sell'),(990696,'deals','.w-cart-order-reference .btn','text-transform','none','','','.w-cart-order-reference'),(990697,'deals','.w-cart-gift-certificate .btn','text-transform','none','','','.w-cart-gift-certificate'),(990698,'deals','.w-cart-shipping-estimator .btn','text-transform','none','','','.w-cart-shipping-estimator'),(990699,'deals','.b-products-listing .products-listing h2, .b-products-listing .products-listing h3, .b-products-listing .products-listing h4','text-transform','inherit','','','.b-products-listing'),(990700,'deals','.w-rma-returns-history .column .title','text-transform','uppercase','','','.w-rma-returns-history'),(990701,'deals','.w-rma-returns-history .tableTitle','text-transform','uppercase','','','.w-rma-returns-history'),(990702,'deals','.w-predefined-promotion .heading-3','text-transform','uppercase','','','.w-predefined-promotion'),(990703,'deals','.preFooter .w-contacts > div','text-transform','uppercase','','','.preFooter'),(990704,'deals','.w-categories .categories h2','text-transform','inherit','','','.w-categories'),(990705,'deals','.b-products-listing .products-listing a.btn.view-button','text-transform','uppercase','','','.b-products-listing'),(990706,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span','text-transform','uppercase','','','.w-product-quantity-discounts'),(990707,'deals','.w-product-groups .radioBoxHead','text-transform','uppercase','','','.w-product-groups'),(990708,'deals','.btn','text-transform','uppercase','','',''),(990709,'deals','.btn-1','text-transform','uppercase','','',''),(990710,'deals','.btn-2','text-transform','uppercase','','',''),(990711,'deals','.btn-3','text-transform','uppercase','','',''),(990712,'deals','.w-tabs .tab-a','text-transform','uppercase','','','.w-tabs'),(990713,'deals','.b-info .info strong','text-transform','uppercase','','','.b-info'),(990714,'deals','.w-product-wishlist-button .btn','text-transform','none','','','.w-product-wishlist-button'),(990718,'deals','.account-address-book .address_book h2','text-transform','uppercase','','','.account-address-book'),(990719,'deals','.account-address-book .address_book_row h2 a','text-transform','none','','','.account-address-book'),(990720,'deals','.account-address-book .leftMes div','text-transform','uppercase','','','.account-address-book'),(990726,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','text-transform','uppercase','','','.account-order-pay'),(990727,'deals','.account-order-pay .not_fully_paid_td','text-transform','uppercase','','','.account-order-pay'),(990728,'deals','.account-samples .not_fully_paid_td','text-transform','uppercase','','','.account-samples'),(990729,'deals','.account-samples .order_history_table h2','text-transform','uppercase','','','.account-samples'),(990730,'deals','.account-samples .order_history_table th','text-transform','none','','','.account-samples'),(990731,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','text-transform','uppercase','','','.account-sample-info'),(990732,'deals','.account-sample-info .not_fully_paid_td','text-transform','uppercase','','','.account-sample-info'),(990733,'deals','.catalog-product-wrap .pn-direction','text-transform','uppercase','','','.catalog-product-wrap'),(990734,'deals','.checkout-success-wrap .page-success .text-1','text-transform','uppercase','','','.checkout-success-wrap'),(990735,'deals','.checkout-success-wrap .page-success .text-2','text-transform','uppercase','','','.checkout-success-wrap'),(990736,'deals','.success-page .page-success .text-1','text-transform','uppercase','','','.success-page'),(990737,'deals','.success-page .page-success .text-2','text-transform','uppercase','','','.success-page'),(990738,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading','text-transform','uppercase','','','.b-multi-page-checkout'),(990739,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','text-transform','none','','','.b-multi-page-checkout'),(990740,'deals','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_color','#222','','','.b-fancybox'),(990741,'deals','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left','0','','','.b-fancybox'),(990742,'deals','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_left_measure','','','','.b-fancybox'),(990743,'deals','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size','2','','','.b-fancybox'),(990744,'deals','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_size_measure','px','','','.b-fancybox'),(990745,'deals','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top','1','','','.b-fancybox'),(990746,'deals','.b-fancybox .fancybox-title-float-wrap .child','text_shadow_top_measure','px','','','.b-fancybox'),(990747,'deals','.b-pass-strength .pass-strength span','top','6','','','.b-pass-strength'),(990748,'deals','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(990749,'deals','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','top','0','','','.b-switch'),(990750,'deals','.w-promotions .prom-multi-discount > .heading','top','2','3','','.w-promotions'),(990751,'deals','.w-promotions .promo-date','top','-10','','','.w-promotions'),(990753,'deals','.w-promo-code .holder','top','2','5660,3','','.w-promo-code'),(990754,'deals','.testimonials .rating','top','2','','',''),(990755,'deals','.testimonials .heading-3','top','0','3','',''),(990756,'deals','.testimonials .reviews-list span','top','2','','',''),(990757,'deals','.w-promotions .prom-multi-discount .products','top','-13','','','.w-promotions'),(990758,'deals','.w-promotions .promo-salemaker .promo-manufacturers .heading, .w-promotions .promo-salemaker .promo-conditions','top','2','3','','.w-promotions'),(990759,'deals','.w-promotions .promo-cart-discount .slave .content','top','-17','','','.w-promotions'),(990760,'deals','.w-promotions .promo-cart-discount .promo-min-qty','top','-19','','','.w-promotions'),(990761,'deals','.w-promotions .promo-cart-discount .master .heading, .w-promotions .promo-cart-discount .slave .heading','top','2','3','','.w-promotions'),(990762,'deals','.b-preloader .preloader','top','calc(50% - 20px)','3','','.b-preloader'),(990763,'deals','.b-preloader .preloader','top','0','','','.b-preloader'),(990764,'deals','.b-messages .messBtnMenuDelete','top','3','3','','.b-messages'),(990765,'deals','.b-messages span.starred::before','top','3','','','.b-messages'),(990766,'deals','.b-messages .messBtnMenuStarred','top','3','3','','.b-messages'),(990767,'deals','.b-messages .messBtnMenuUnread','top','3','3','','.b-messages'),(990768,'deals','.b-messages .select2-container-multi .select2-choices .select2-search-choice','top','5','','','.b-messages'),(990771,'deals','.p-payer-order-confirmation .order-ico','top','7','3','','.p-payer-order-confirmation'),(990772,'deals','.p-payer-order-confirmation .discount-ico','top','3','3','','.p-payer-order-confirmation'),(990773,'deals','.p-payer-order-confirmation .comment-ico','top','7','3','','.p-payer-order-confirmation'),(990774,'deals','.p-payer-order-pay .order-ico','top','7','3','','.p-payer-order-pay'),(990775,'deals','.p-payer-order-pay .discount-ico','top','3','3','','.p-payer-order-pay'),(990776,'deals','.p-payer-order-pay .comment-ico','top','7','3','','.p-payer-order-pay'),(990777,'deals','.w-checkout-terms .required-message','top','40','','','.w-checkout-terms'),(990778,'deals','.w-checkout-terms input[type=\"checkbox\"]','top','2','','','.w-checkout-terms'),(990779,'deals','.w-checkout-shipping-address .genders-title input','top','2','','','.w-checkout-shipping-address'),(990780,'deals','.b-fancybox #fancybox-loading','top','50','','','.b-fancybox'),(990781,'deals','.b-form .form-buttons','top','10','','','.b-form'),(990782,'deals','.b-rating .glyphicon','top','1','','','.b-rating'),(990783,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(990784,'deals','.w-upload-customer-id-upload-customer-id-form .upload-remove','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(990785,'deals','.w-upload-customer-id-upload-customer-id-form .dz-details','top','0','','','.w-upload-customer-id-upload-customer-id-form'),(990786,'deals','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(990787,'deals','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(990788,'deals','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(990790,'deals','.b-form .shipping-method .input input','top','2','','','.b-form'),(990792,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','top','8','','','.b-switch'),(990793,'deals','.b-fancybox .fancybox-tmp','top','-99999','','','.b-fancybox'),(990794,'deals','.w-filters .ui-slider-handle','top','-5','','','.w-filters'),(990795,'deals','.order-summary .price-row.ot_gv .remove-discount, .order-summary .price-row.ot_coupon .remove-discount, .order-summary .price-row.ot_bonus_points .remove-discount','top','-1','3','','.order-summary'),(990796,'deals','.view-all','top','50','3','',''),(990797,'deals','.b-products-listing .products-listing .btn-buy','top','3','3','','.b-products-listing'),(990798,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','top','-2','','','.b-switch'),(990799,'deals','.b-switch .candlestick-wrapper','top','-2','','','.b-switch'),(990800,'deals','.closeable-heading','top','0','3','',''),(990801,'deals','.b-bottom .footerTitle','top','8','5630,4','','.b-bottom'),(990802,'deals','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(990803,'deals','.b-info-popup .info-popup div','top','15','3','','.b-info-popup'),(990804,'deals','.b-form .form-inputs div.required-message','top','-15','','','.b-form'),(990805,'deals','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(990806,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top','0','','','.b-select-suggest'),(990807,'deals','.b-form .hide-billing-address','top','0','','','.b-form'),(990808,'deals','.b-select-suggest .select2-measure-scrollbar','top','-10000','','','.b-select-suggest'),(990809,'deals','.w-socials .post_item > div','top','10','3','','.w-socials'),(990810,'deals','.w-cart-compare .atr-col','top','0','3','','.w-cart-compare'),(990811,'deals','.b-info-popup .info-popup.top-left div','top','auto','3','','.b-info-popup'),(990812,'deals','.b-info-popup .info-popup div','top','-12','','','.b-info-popup'),(990813,'deals','.bell-ico .heading-2','top','5','3','','.bell-ico'),(990815,'deals','.w-socials .post_item > div','top','10','3','','.w-socials'),(990816,'deals','.w-socials .post_item > div','top','10','3','','.w-socials'),(990818,'deals','.w-socials .post_item > div','top','10','3','','.w-socials'),(990820,'deals','.message.success','top','3','3','',''),(990821,'deals','.b-form .middle-form .required-message','top','-15','','','.b-form'),(990822,'deals','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(990823,'deals','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(990824,'deals','.w-socials .post_item > div','top','10','3','','.w-socials'),(990825,'deals','.b-info-popup .info-popup.top-left div','top','auto','','','.b-info-popup'),(990826,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off','top','8','','','.b-switch'),(990827,'deals','.b-form .radio-button input[type=\"radio\"]','top','2','','','.b-form'),(990828,'deals','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(990830,'deals','.w-multi-cart-actions .cart-actions','top','-3','','','.w-multi-cart-actions'),(990831,'deals','.b-fancybox .fancybox-overlay','top','0','','','.b-fancybox'),(990832,'deals','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(990833,'deals','.w-promo-code .holder','top','19','3','','.w-promo-code'),(990834,'deals','.w-promo-code .holder','top','2','5660,3','','.w-promo-code'),(990835,'deals','.w-reviews .review','top','-16','3','','.w-reviews'),(990836,'deals','.w-reviews .heading-3','top','0','3','','.w-reviews'),(990837,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','top','4','3','','.b-switch'),(990838,'deals','.w-menu-horizontal ul ul ul','top','0','','','.w-menu-horizontal'),(990841,'deals','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(990842,'deals','.b-form .payment-method .item-radio input','top','5','','','.b-form'),(990843,'deals','.w-checkout-billing-address .genders-title input','top','2','','','.w-checkout-billing-address'),(990844,'deals','.w-promo-code .holder','top','2','5660,3','','.w-promo-code'),(990845,'deals','.b-dropdown .dropdown .dropdown-menu','top','100','','','.b-dropdown'),(990846,'deals','.w-menu-horizontal > ul > li > ul','top','100','','','.w-menu-horizontal'),(990847,'deals','.b-info-popup .info-popup','top','4','3','','.b-info-popup'),(990848,'deals','.b-form .radio-button input[type=\"radio\"].no + span','top','1','3','','.b-form'),(990849,'deals','.w-promo-code .holder','top','2','5660,3','','.w-promo-code'),(990850,'deals','.b-upload-files .attach-active-holder .attach-file','top','-200','','','.b-upload-files'),(990851,'deals','.w-promo-code .holder','top','2','5660,3','','.w-promo-code'),(990852,'deals','.b-fancybox .fancybox-close','top','10','','','.b-fancybox'),(990853,'deals','.w-product-customers-activity .close','top','5','','','.w-product-customers-activity'),(990854,'deals','.w-reviews-content .review','top','-16','3','','.w-reviews-content'),(990856,'deals','.w-cart-compare .remove-cart','top','0','','','.w-cart-compare'),(990857,'deals','.w-promo-code .holder','top','19','3','','.w-promo-code'),(990858,'deals','.w-promo-code .holder','top','19','3','','.w-promo-code'),(990859,'deals','.w-promo-code .holder','top','2','5660,3','','.w-promo-code'),(990860,'deals','.w-checkout-shipping-choice input','top','-200','','','.w-checkout-shipping-choice'),(990862,'deals','.w-socials .post_item > div','top','10','3','','.w-socials'),(990863,'deals','.w-product-reviews .reviews-list span','top','2','','','.w-product-reviews'),(990864,'deals','.b-select-suggest .select2-search-choice-close','top','4','','','.b-select-suggest'),(990865,'deals','.w-image-maps .svg-wrap svg','top','0','','','.w-image-maps'),(990866,'deals','.w-neighbour-checkout .bootstrap-switch','top','-2','','','.w-neighbour-checkout'),(990867,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow','top','0','','','.b-select-suggest'),(990868,'deals','.b-select-suggest .select2-drop-mask','top','0','','','.b-select-suggest'),(990869,'deals','.b-select-suggest .select2-drop','top','100','','','.b-select-suggest'),(990872,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','top','4','3','','.b-switch'),(990873,'deals','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(990874,'deals','.w-checkout-create-account .account-benefits strong','top','3','3','','.w-checkout-create-account'),(990875,'deals','.w-promo-code .holder','top','19','3','','.w-promo-code'),(990876,'deals','.w-account-addresses-list .address-fields input[type=\"radio\"]','top','4','','','.w-account-addresses-list'),(990877,'deals','.b-products-listing .products-listing .promos-info','top','0','','','.b-products-listing'),(990878,'deals','.b-products-listing .hover-box-content','top','-10','3','','.b-products-listing'),(990879,'deals','.b-products-listing .hover-box-content','top','40','','','.b-products-listing'),(990880,'deals','.b-products-listing .loader','top','calc(50% - 15px)','4','','.b-products-listing'),(990881,'deals','.b-products-listing .loader','top','0','3','','.b-products-listing'),(990882,'deals','.b-products-listing .products-listing .qty-input.hidden','top','0','3','','.b-products-listing'),(990883,'deals','.b-products-listing .promo','top','0','','','.b-products-listing'),(990888,'deals','.w-promo-code .holder','top','19','3','','.w-promo-code'),(990889,'deals','.w-checkout-gdpr .candlestick-wrapper','top','0','','','.w-checkout-gdpr'),(990890,'deals','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(990891,'deals','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(990892,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','top','0','','','.b-switch'),(990893,'deals','.b-form .eye-password','top','5','','','.b-form'),(990894,'deals','.w-taxable input[type=\"radio\"]','top','2','','','.w-taxable'),(990895,'deals','.w-taxable input[type=\"checkbox\"]','top','2','','','.w-taxable'),(990896,'deals','.b-form .radio-button + .required-message-wrap .required-message','top','-5','','','.b-form'),(990897,'deals','.b-products-listing .products-listing .radio-attributes input','top','2','','','.b-products-listing'),(990900,'deals','.w-promo-code .holder','top','19','3','','.w-promo-code'),(990901,'deals','.b-dropdown .dropdown .dropdown-toggle','top','2','4','','.b-dropdown'),(990902,'deals','.w-cart-listing .remove-btn span','top','-7','5639','','.w-cart-listing'),(990904,'deals','.b-upload-file .upload-remove','top','5','','','.b-upload-file'),(990905,'deals','.b-fancybox .fancybox-nav span','top','50','','','.b-fancybox'),(990906,'deals','.b-fancybox .fancybox-nav','top','0','','','.b-fancybox'),(990907,'deals','.b-form .addresses .address-item input[type=\"radio\"]','top','3','','','.b-form'),(990908,'deals','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(990909,'deals','.b-bottom .pop-up-close','top','7','','','.b-bottom'),(990910,'deals','.b-switch .bootstrap-switch .bootstrap-switch-container','top','0','','','.b-switch'),(990911,'deals','.w-login-block .pass-strength span','top','10','','','.w-login-block'),(990912,'deals','.b-fancybox .fancybox-wrap','top','0','','','.b-fancybox'),(990913,'deals','.w-menu-big > ul > li > ul','top','100','','','.w-menu-big'),(990914,'deals','.b-select-suggest .select2-container .select2-choice abbr','top','8','','','.b-select-suggest'),(990915,'deals','.w-filters .mobileCollapse','top','1','','','.w-filters'),(990916,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','top','0','','','.w-image-maps'),(990917,'deals','.b-product-images .media-popup .mp-close','top','20','','','.b-product-images'),(990918,'deals','.b-product-images .mp-shadow, .b-product-images .media-popup','top','0','','','.b-product-images'),(990919,'deals','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top','100','','','.b-menu-lev_display-down'),(990920,'deals','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top','100','','','.b-menu-lev_display-down'),(990921,'deals','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top','100','','','.b-menu-lev_display-down'),(990922,'deals','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top','100','','','.b-menu-lev_display-down'),(990923,'deals','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top','100','','','.b-menu-lev_display-down'),(990924,'deals','.b-menu-lev_display-left .menu-style[data-lev2_display=\"left\"] .level-2','top','0','','','.b-menu-lev_display-left'),(990925,'deals','.b-menu-lev_display-left .menu-style[data-lev3_display=\"left\"] .level-3','top','0','','','.b-menu-lev_display-left'),(990926,'deals','.b-menu-lev_display-left .menu-style[data-lev4_display=\"left\"] .level-4','top','0','','','.b-menu-lev_display-left'),(990927,'deals','.b-menu-lev_display-left .menu-style[data-lev5_display=\"left\"] .level-5','top','0','','','.b-menu-lev_display-left'),(990928,'deals','.b-menu-lev_display-left .menu-style[data-lev6_display=\"left\"] .level-6','top','0','','','.b-menu-lev_display-left'),(990929,'deals','.b-menu-lev_display-lra .menu-style[data-lev2_display=\"lra\"] .level-2','top','0','','','.b-menu-lev_display-lra'),(990930,'deals','.b-menu-lev_display-lra .menu-style[data-lev3_display=\"lra\"] .level-3','top','0','','','.b-menu-lev_display-lra'),(990931,'deals','.b-menu-lev_display-lra .menu-style[data-lev4_display=\"lra\"] .level-4','top','0','','','.b-menu-lev_display-lra'),(990932,'deals','.b-menu-lev_display-lra .menu-style[data-lev5_display=\"lra\"] .level-5','top','0','','','.b-menu-lev_display-lra'),(990933,'deals','.b-menu-lev_display-lra .menu-style[data-lev6_display=\"lra\"] .level-6','top','0','','','.b-menu-lev_display-lra'),(990934,'deals','.b-menu-lev_display-right .menu-style[data-lev5_display=\"right\"] .level-5','top','0','','','.b-menu-lev_display-right'),(990935,'deals','.b-menu-lev_display-right .menu-style[data-lev6_display=\"right\"] .level-6','top','0','','','.b-menu-lev_display-right'),(990936,'deals','.b-menu-lev_display-right .menu-style[data-lev2_display=\"right\"] .level-2','top','0','','','.b-menu-lev_display-right'),(990937,'deals','.b-menu-lev_display-right .menu-style[data-lev3_display=\"right\"] .level-3','top','0','','','.b-menu-lev_display-right'),(990938,'deals','.b-menu-lev_display-right .menu-style[data-lev4_display=\"right\"] .level-4','top','0','','','.b-menu-lev_display-right'),(990939,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','top','0','','','.b-menu-lev_display-slide'),(990940,'deals','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','top','0','','','.b-menu-lev_display-slide'),(990941,'deals','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','top','0','','','.b-menu-lev_display-slide'),(990942,'deals','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','top','0','','','.b-menu-lev_display-slide'),(990943,'deals','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','top','0','','','.b-menu-lev_display-slide'),(990944,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','top','0','','','.b-menu-open_from-left'),(990945,'deals','.b-slick .slick-track','top','0','','','.b-slick'),(990946,'deals','.b-slick .slick-vertical button.slick-next','top','auto','','','.b-slick'),(990947,'deals','.b-slick .slick-vertical button.slick-prev','top','0','','','.b-slick'),(990948,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','top','50','','','.b-slick'),(990949,'deals','.w-quote .multicart .switch-cart','top','14','','','.w-quote'),(990951,'deals','.warrantyProduct .warranty','top','50','3','','.warrantyProduct'),(990952,'deals','.warrantyProduct .delivery','top','50','3','','.warrantyProduct'),(990953,'deals','.w-files-catalog-widgets-files-list .file','top','-1','3','','.w-files-catalog-widgets-files-list'),(990954,'deals','.w-sample .multicart .switch-cart','top','14','','','.w-sample'),(990955,'deals','.w-sample .qty','top','-1','4','','.w-sample'),(990956,'deals','.w-cart-gift-certificate .gift-certificate .heading-4','top','3','3','','.w-cart-gift-certificate'),(990957,'deals','.w-product-inventory input[type=\"radio\"]','top','1','','','.w-product-inventory'),(990959,'deals','.w-product-properties-filters-widgets-chosen-filters .remove','top','2','3','','.w-product-properties-filters-widgets-chosen-filters'),(990960,'deals','.p-sample-checkout-index .order-summary .heading-2','top','-10','3','','.p-sample-checkout-index'),(990961,'deals','.p-sample-checkout-index .order-summary .heading-2','top','-10','4','','.p-sample-checkout-index'),(990962,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input','top','-50','','','.w-questionnaire-widgets-questionnaire'),(990963,'deals','.w-sale-category .badge','top','10','','','.w-sale-category'),(990964,'deals','.w-product-properties-icons .hover-box-content','top','50','','','.w-product-properties-icons'),(990965,'deals','.w-product-designer-designer .productDesignerBox input','top','0','','','.w-product-designer-designer'),(990966,'deals','.w-product-configurator .pc-item label input','top','5','','','.w-product-configurator'),(990967,'deals','.w-predefined-promotion .prom-multi-discount .products','top','-13','','','.w-predefined-promotion'),(990968,'deals','.w-predefined-promotion .prom-multi-discount > .heading','top','2','3','','.w-predefined-promotion'),(990969,'deals','.w-predefined-promotion .promo-cart-discount .master .heading, .w-predefined-promotion .promo-cart-discount .slave .heading','top','2','3','','.w-predefined-promotion'),(990970,'deals','.w-predefined-promotion .promo-cart-discount .promo-min-qty','top','-19','','','.w-predefined-promotion'),(990971,'deals','.w-predefined-promotion .promo-cart-discount .slave .content','top','-17','','','.w-predefined-promotion'),(990972,'deals','.w-predefined-promotion .promo-date','top','-10','','','.w-predefined-promotion'),(990973,'deals','.w-predefined-promotion .promo-salemaker .promo-manufacturers .heading, .w-predefined-promotion .promo-salemaker .promo-conditions','top','2','3','','.w-predefined-promotion'),(990975,'deals','.filterLine .filter-ul-content .count','top','7','','','.filterLine'),(990976,'deals','.w-filters span.open','top','4','','','.w-filters'),(990977,'deals','.filterLine .w-catalog-sorting .sort-select','top','0','','','.filterLine'),(990978,'deals','.w-breadcrumb .breadcrumb-li','top','0','4','','.w-breadcrumb'),(990979,'deals','.messageBox .info','top','3','3','',''),(990980,'deals','.homeBanner .carousel .bottom-center > span','top','-100','3','','.homeBanner'),(990981,'deals','.homeBanner .carousel .bottom-center > span','top','-60','5660,3','','.homeBanner'),(990982,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','top','42','5639','','.w-filters'),(990983,'deals','.w-filters .filter-widget-horizontal .mobileCollapse','top','5','5639','','.w-filters'),(990984,'deals','.filterLine .w-catalog-sorting .sort-select','top','0','5639','','.filterLine'),(990985,'deals','.b-info .info','top','3','3','','.b-info'),(990986,'deals','.w-account-personal-catalog .list-row-action ul','top','5','4','','.w-account-personal-catalog'),(990987,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li .no-link','top','0','5630,4','','.preFooter'),(990988,'deals','.p-wedding-registry-view h1','top','-4','3','','.p-wedding-registry-view'),(990989,'deals','.p-wedding-registry-view h1','top','-4','4','','.p-wedding-registry-view'),(990990,'deals','.w-product-wishlist-button .btn','top','1','3','','.w-product-wishlist-button'),(990991,'deals','.homeBanner .text-bottom-center .banner-text-holder','top','-100','3','','.homeBanner'),(990992,'deals','.homeBanner .text-bottom-left .banner-text-holder','top','-100','3','','.homeBanner'),(990993,'deals','.homeBanner .text-bottom-right .banner-text-holder','top','-100','3','','.homeBanner'),(990994,'deals','.homeBanner .text-bottom-center .banner-text-holder','top','-50','5660,3','','.homeBanner'),(990995,'deals','.homeBanner .text-bottom-left .banner-text-holder','top','-50','5660,3','','.homeBanner'),(990996,'deals','.homeBanner .text-bottom-right .banner-text-holder','top','-50','5660,3','','.homeBanner'),(990997,'deals','.order-summary .icon','top','0','3','','.order-summary'),(991008,'deals','.account-order-pay .historyInfoColumn h2, .account-order-pay h2.product_details, .account-order-pay h2.o_history_info','top','2','3','','.account-order-pay'),(991009,'deals','.account-order-pay .not_fully_paid_td','top','19','','','.account-order-pay'),(991010,'deals','.account-samples .not_fully_paid_td','top','19','','','.account-samples'),(991011,'deals','.account-samples .view_link','top','4','4','','.account-samples'),(991012,'deals','.account-sample-info .historyInfoColumn h2, .account-sample-info h2.product_details, .account-sample-info h2.o_history_info','top','2','3','','.account-sample-info'),(991013,'deals','.account-sample-info .not_fully_paid_td','top','19','','','.account-sample-info'),(991014,'deals','.catalog-product-wrap .pn-image','top','120','3','','.catalog-product-wrap'),(991015,'deals','.catalog-product-wrap .prev-next-product','top','calc(50% - 200px)','','','.catalog-product-wrap'),(991016,'deals','.shopping-cart-index .gift-code .heading-4','top','0','4','','.shopping-cart-index'),(991017,'deals','.checkout-index-wrap .order-ico','top','7','3','','.checkout-index-wrap'),(991018,'deals','.checkout-order-confirmation .comment-ico','top','7','3','','.checkout-order-confirmation'),(991019,'deals','.checkout-order-confirmation .discount-ico','top','3','3','','.checkout-order-confirmation'),(991020,'deals','.checkout-order-confirmation .order-ico','top','7','3','','.checkout-order-confirmation'),(991021,'deals','.hide-page','top','0','','',''),(991022,'deals','.success-page .comment-ico','top','7','3','','.success-page'),(991023,'deals','.success-page .discount-ico','top','3','3','','.success-page'),(991024,'deals','.success-page .order-ico','top','7','3','','.success-page'),(991025,'deals','.success-page .page-success .text-1','top','7','3','','.success-page'),(991026,'deals','.success-page .w-cart-listing .qty','top','10','','','.success-page'),(991028,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading .edit','top','-2','4','','.b-multi-page-checkout'),(991030,'deals','.w-banner .banner img + img','top','0','','','.w-banner'),(991031,'deals','.w-banner .carousel-text','top','0','','','.w-banner'),(991032,'deals','.w-banner .image-text-banner.bottom-center .text-banner','top','auto','','','.w-banner'),(991033,'deals','.w-banner .image-text-banner.middle-left .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.middle-right .text-banner','top','0','','','.w-banner'),(991034,'deals','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','top','0','','','.w-banner'),(991035,'deals','.w-banner .image-text-banner.top-left .text-banner','top','0','','','.w-banner'),(991036,'deals','.w-banner .image-text-banner.top-right .text-banner','top','0','','','.w-banner'),(991037,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top','0','','','.w-catalog-paging'),(991044,'deals','.w-menu-slider .close','top','10','','','.w-menu-slider'),(991045,'deals','.w-menu-slider > ul > li > ul','top','100','','','.w-menu-slider'),(991046,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','top_important','important','','','.b-select-suggest'),(991047,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','top_important','important','','','.w-catalog-paging'),(991048,'deals','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(991050,'deals','.b-fancybox #fancybox-loading','top_measure','%','','','.b-fancybox'),(991051,'deals','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(991052,'deals','.view-all','top_measure','%','3','',''),(991053,'deals','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(991054,'deals','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(991055,'deals','.w-menu-horizontal > ul > li > ul','top_measure','%','','','.w-menu-horizontal'),(991056,'deals','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(991057,'deals','.b-select-suggest .select2-drop','top_measure','%','','','.b-select-suggest'),(991058,'deals','.b-dropdown .dropdown .dropdown-menu','top_measure','%','','','.b-dropdown'),(991059,'deals','.b-fancybox .fancybox-nav span','top_measure','%','','','.b-fancybox'),(991060,'deals','.w-menu-big > ul > li > ul','top_measure','%','','','.w-menu-big'),(991061,'deals','.b-menu-lev_display-down .menu-style[data-lev2_display=\"down\"] .level-2','top_measure','%','','','.b-menu-lev_display-down'),(991062,'deals','.b-menu-lev_display-down .menu-style[data-lev3_display=\"down\"] .level-3','top_measure','%','','','.b-menu-lev_display-down'),(991063,'deals','.b-menu-lev_display-down .menu-style[data-lev4_display=\"down\"] .level-4','top_measure','%','','','.b-menu-lev_display-down'),(991064,'deals','.b-menu-lev_display-down .menu-style[data-lev5_display=\"down\"] .level-5','top_measure','%','','','.b-menu-lev_display-down'),(991065,'deals','.b-menu-lev_display-down .menu-style[data-lev6_display=\"down\"] .level-6','top_measure','%','','','.b-menu-lev_display-down'),(991066,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','top_measure','%','','','.b-slick'),(991067,'deals','.warrantyProduct .warranty','top_measure','%','3','','.warrantyProduct'),(991068,'deals','.warrantyProduct .delivery','top_measure','%','3','','.warrantyProduct'),(991069,'deals','.w-product-properties-icons .hover-box-content','top_measure','%','','','.w-product-properties-icons'),(991073,'deals','.w-menu-slider > ul > li > ul','top_measure','%','','','.w-menu-slider'),(991074,'deals','.b-slick .slick-slider','touch-action','pan-y','','','.b-slick'),(991075,'deals','.b-products-listing .hover-box-content','transform','rotate( 45deg )','3','','.b-products-listing'),(991076,'deals','.b-switch .bootstrap-switch .bootstrap-switch-container','transform','translate3d(0, 0, 0)','','','.b-switch'),(991077,'deals','.b-product-images .media-popup .mp-close','transform','scale(1.5)','1','','.b-product-images'),(991078,'deals','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','transform','scale(1.2)','1','','.b-product-images'),(991079,'deals','.b-product-images .media-popup .slick-list:first-child .slick-track','transform','none','','','.b-product-images'),(991080,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','transform','scale(1.5)','1','','.b-product-images'),(991081,'deals','.b-menu-lev_display-slide .menu-style .slide-parent','transform','translateX(-100vw)','','','.b-menu-lev_display-slide'),(991082,'deals','.b-slick .slick-slider .slick-track, .b-slick .slick-slider .slick-list','transform','translate3d(0, 0, 0)','','','.b-slick'),(991083,'deals','.w-top-categories .item:hover img','transform','scale(1.1,1.1)','','','.w-top-categories'),(991084,'deals','.w-top-categories picture > img, .w-top-categories picture > img','transform','scale(1,1)','','','.w-top-categories'),(991085,'deals','.w-categories .item:hover img','transform','scale(1.1,1.1)','','','.w-categories'),(991086,'deals','.w-categories picture > img, .w-categories picture > img','transform','scale(1,1)','','','.w-categories'),(991087,'deals','.b-product-images .media-popup .slick-list:first-child .slick-track','transform_important','important','','','.b-product-images'),(991088,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','transition','0.3s','','','.b-switch'),(991089,'deals','.b-switch .bootstrap-switch','transition','border-color ease-in-out .15s, box-shadow ease-in-out .15s','','','.b-switch'),(991090,'deals','.b-switch .bootstrap-switch.bootstrap-switch-animate .bootstrap-switch-container','transition','margin-left 0.5s','','','.b-switch'),(991091,'deals','.b-product-images .media-popup .mp-close','transition','transform 0.3s, color 0.3s','','','.b-product-images'),(991092,'deals','.b-product-images .media-popup .mp-small-images video, .b-product-images .media-popup .mp-small-images iframe, .b-product-images .media-popup .mp-small-images img','transition','transform 0.3s','','','.b-product-images'),(991093,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','transition','transform 0.3s, color 0.3s','','','.b-product-images'),(991094,'deals','.b-menu-burger_icon .menu-style[data-open_from=\"top\"] .menu-content','transition','max-height 1s','','','.b-menu-burger_icon'),(991095,'deals','.b-menu-lev_display-slide .menu-style ul','transition','visibility 300ms, transform 300ms','','','.b-menu-lev_display-slide'),(991096,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','transition','left 300ms','','','.b-menu-open_from-left'),(991100,'deals','.headerWrap ','transition','padding 0.3s','','','.headerWrap'),(991101,'deals','.w-subscribers .left_box','transition','0.5s ease-out 0.3s','','','.w-subscribers'),(991102,'deals','.w-subscribers .right_box','transition','0.5s ease-out 0.3s','','','.w-subscribers'),(991103,'deals','.w-top-categories .categories h2','transition','0.3s','','','.w-top-categories'),(991104,'deals','a','transition','0.3s','','',''),(991105,'deals','.w-top-categories picture > img, .w-top-categories picture > img','transition','0.3s','','','.w-top-categories'),(991106,'deals','.w-categories .categories h2','transition','0.3s','','','.w-categories'),(991107,'deals','.w-categories picture > img, .w-categories picture > img','transition','0.3s','','','.w-categories'),(991108,'deals','.w-product-price-from ','transition','font-size 0.3s, padding 0.3s','','','.w-product-price-from'),(991110,'deals','.footer-menu .level-3 > li > a','transition','0s','5639','','.footer-menu'),(991111,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-choice','user-select','none','','','.b-select-suggest'),(991112,'deals','.b-select-suggest .select2-results .select2-result-label','user-select','none','','','.b-select-suggest'),(991113,'deals','.b-select-suggest .select2-container .select2-choice','user-select','none','','','.b-select-suggest'),(991114,'deals','.b-slick .slick-slider','user-select','none','','','.b-slick'),(991115,'deals','.b-email .name','vertical-align','top','','','.b-email'),(991116,'deals','.w-tabs .tab-li.tab-cart a','vertical-align','middle','3','','.w-tabs'),(991117,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.p-quick-order-index'),(991118,'deals','.p-quick-order-index .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.p-quick-order-index'),(991119,'deals','.b-email .model','vertical-align','top','','','.b-email'),(991120,'deals','.w-categories .item','vertical-align','top','','','.w-categories'),(991121,'deals','.w-promotions .heading-3','vertical-align','top','','','.w-promotions'),(991122,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','vertical-align','top','','','.b-warehouses-popup'),(991123,'deals','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(991124,'deals','.b-upload-file .upload-file-template','vertical-align','top','','','.b-upload-file'),(991125,'deals','.b-messages .msv_to_cc div span','vertical-align','middle','','','.b-messages'),(991126,'deals','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(991127,'deals','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(991128,'deals','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(991129,'deals','.b-email .price','vertical-align','top','','','.b-email'),(991130,'deals','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(991131,'deals','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(991132,'deals','.b-switch .bootstrap-switch','vertical-align','middle','','','.b-switch'),(991133,'deals','.w-menu-horizontal li a, .w-menu-horizontal li .no-link','vertical-align','middle','','','.w-menu-horizontal'),(991134,'deals','.w-filters .input-checkbox:checked + .checkbox-span','vertical-align','middle','','','.w-filters'),(991135,'deals','.b-email .name','vertical-align','top','','','.b-email'),(991136,'deals','.b-email .qty','vertical-align','top','','','.b-email'),(991137,'deals','.b-email .image','vertical-align','top','','','.b-email'),(991138,'deals','.b-form .checkbox-style:checked + .checkbox-span','vertical-align','middle','','','.b-form'),(991139,'deals','.b-form .middle-form .dob-input input, .b-form .middle-form .dob-input span','vertical-align','middle','','','.b-form'),(991140,'deals','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(991141,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc','vertical-align','top','','','.b-switch'),(991142,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','vertical-align','middle','','','.b-switch'),(991143,'deals','.b-switch .candlestick-wrapper','vertical-align','middle','','','.b-switch'),(991144,'deals','.order-summary .price-row.ot_gv .title','vertical-align','top','3','','.order-summary'),(991145,'deals','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(991146,'deals','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(991147,'deals','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(991148,'deals','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(991149,'deals','.w-tabs .tab-li.tab-wishlist a','vertical-align','middle','3','','.w-tabs'),(991150,'deals','.w-tabs .tab-li','vertical-align','bottom','','','.w-tabs'),(991151,'deals','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(991152,'deals','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(991153,'deals','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(991154,'deals','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(991155,'deals','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(991156,'deals','.b-email .image','vertical-align','top','','','.b-email'),(991157,'deals','.w-checkout-billing-address .genders-title > div','vertical-align','top','','','.w-checkout-billing-address'),(991158,'deals','.w-checkout-shipping-address .genders-title > div','vertical-align','top','','','.w-checkout-shipping-address'),(991159,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span','vertical-align','middle','','','.b-form'),(991160,'deals','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(991161,'deals','.b-email .qty','vertical-align','top','','','.b-email'),(991162,'deals','.b-email .price','vertical-align','top','','','.b-email'),(991163,'deals','.b-email .price','vertical-align','top','','','.b-email'),(991164,'deals','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(991165,'deals','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(991166,'deals','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(991167,'deals','.w-top-categories .item','vertical-align','top','','','.w-top-categories'),(991168,'deals','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(991169,'deals','.b-email .qty','vertical-align','top','','','.b-email'),(991170,'deals','.b-email .name','vertical-align','top','','','.b-email'),(991171,'deals','.b-email .model','vertical-align','top','','','.b-email'),(991172,'deals','.b-email .price','vertical-align','top','','','.b-email'),(991173,'deals','.b-email .image','vertical-align','top','','','.b-email'),(991174,'deals','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(991175,'deals','.w-cart-discount-coupon .btn','vertical-align','top','','','.w-cart-discount-coupon'),(991176,'deals','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(991177,'deals','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(991178,'deals','.b-email .price','vertical-align','top','','','.b-email'),(991179,'deals','.b-email .model','vertical-align','top','','','.b-email'),(991180,'deals','.b-email .model','vertical-align','top','','','.b-email'),(991181,'deals','.w-product-promotions .promotion-data-2','vertical-align','top','','','.w-product-promotions'),(991182,'deals','.b-email .model','vertical-align','top','','','.b-email'),(991183,'deals','.b-compare .compare_select_items','vertical-align','middle','','','.b-compare'),(991184,'deals','.b-email .name','vertical-align','top','','','.b-email'),(991185,'deals','.b-email .image','vertical-align','top','','','.b-email'),(991186,'deals','.w-tabs .tab-li.tab-quote a','vertical-align','middle','3','','.w-tabs'),(991187,'deals','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(991188,'deals','.b-email .price','vertical-align','top','','','.b-email'),(991189,'deals','.w-cart-compare .product-label','vertical-align','bottom','','','.w-cart-compare'),(991190,'deals','.w-product-available-in-warehouses .warehouse-item','vertical-align','top','','','.w-product-available-in-warehouses'),(991191,'deals','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(991192,'deals','.w-cart-compare .product-actions .dropdown-toggle','vertical-align','middle','3','','.w-cart-compare'),(991193,'deals','.w-menu-big li li','vertical-align','top','','','.w-menu-big'),(991194,'deals','.w-cart-compare .product-cell','vertical-align','top','','','.w-cart-compare'),(991195,'deals','.w-product-promotions .products','vertical-align','top','','','.w-product-promotions'),(991196,'deals','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(991197,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button.current','vertical-align','top','','','.b-data-table'),(991198,'deals','.b-data-table .dataTables_wrapper .dataTables_paginate .paginate_button','vertical-align','top','','','.b-data-table'),(991199,'deals','.b-products-listing .products-listing .item','vertical-align','top','','','.b-products-listing'),(991200,'deals','.checkbox input + span','vertical-align','middle','','',''),(991201,'deals','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(991202,'deals','.b-email .name','vertical-align','top','','','.b-email'),(991203,'deals','.b-email .image','vertical-align','top','','','.b-email'),(991204,'deals','.b-email .qty','vertical-align','top','','','.b-email'),(991205,'deals','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(991206,'deals','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(991207,'deals','.order-summary .price-row.ot_coupon .title','vertical-align','top','3','','.order-summary'),(991208,'deals','.w-tabs .tab-li.tab-sample a','vertical-align','middle','3','','.w-tabs'),(991209,'deals','.b-tracking-numbers .tracking-numbers td','vertical-align','top','','','.b-tracking-numbers'),(991210,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','','','.w-communication-new-topic'),(991211,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement, .w-communication-new-topic .rmaProductReturnQuantityHolder .increment','vertical-align','top','3','','.w-communication-new-topic'),(991212,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','vertical-align','top','','','.w-communication-new-topic'),(991213,'deals','.w-communication-new-topic #rmaProductReturnQuantityFilterHolder td','vertical-align','bottom','','','.w-communication-new-topic'),(991214,'deals','.w-quote .no-text','vertical-align','top','','','.w-quote'),(991215,'deals','.b-email-editor td','vertical-align','top','','','.b-email-editor'),(991216,'deals','.b-email .qty','vertical-align','top','','','.b-email'),(991217,'deals','.b-email .name','vertical-align','top','','','.b-email'),(991218,'deals','.b-email .image','vertical-align','top','','','.b-email'),(991219,'deals','.w-catalog-listing-look .grid','vertical-align','top','','','.w-catalog-listing-look'),(991220,'deals','.w-catalog-listing-look .b2b','vertical-align','top','','','.w-catalog-listing-look'),(991221,'deals','.w-catalog-listing-look .list','vertical-align','top','','','.w-catalog-listing-look'),(991222,'deals','.w-catalog-compare-button .compare_button','vertical-align','middle','','','.w-catalog-compare-button'),(991223,'deals','.b-fancybox .fancybox-wrap, .b-fancybox .fancybox-skin, .b-fancybox .fancybox-outer, .b-fancybox .fancybox-inner, .b-fancybox .fancybox-image','vertical-align','top','','','.b-fancybox'),(991224,'deals','.b-email .model','vertical-align','top','','','.b-email'),(991225,'deals','.w-product-promotions .products .item','vertical-align','top','','','.w-product-promotions'),(991226,'deals','.order-summary .price-row.ot_bonus_points .title','vertical-align','top','3','','.order-summary'),(991227,'deals','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align','top','','','.b-switch'),(991228,'deals','.b-fancybox .fancybox-wrap iframe, .b-fancybox .fancybox-wrap object, .b-fancybox .fancybox-nav, .b-fancybox .fancybox-nav span, .b-fancybox .fancybox-tmp','vertical-align','top','','','.b-fancybox'),(991229,'deals','.w-menu-big li a, .w-menu-big li .no-link','vertical-align','middle','','','.w-menu-big'),(991230,'deals','.b-email .qty','vertical-align','top','','','.b-email'),(991231,'deals','.w-filters .input-checkbox:not(checked) + .checkbox-span','vertical-align','middle','','','.w-filters'),(991232,'deals','.b-product-images .media-popup .mp-small-images .item','vertical-align','top','','','.b-product-images'),(991233,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1','vertical-align','middle','3','','.w-catalog-compare'),(991234,'deals','.b-cookie-notice .cookie-notice.top .text, .b-cookie-notice .cookie-notice.top .buttons, .b-cookie-notice .cookie-notice.bottom .text, .b-cookie-notice .cookie-notice.bottom .buttons','vertical-align','middle','','','.b-cookie-notice'),(991235,'deals','.b-quantity .qty-box .bigger','vertical-align','top','','','.b-quantity'),(991236,'deals','.b-quantity .qty-box .smaller','vertical-align','top','','','.b-quantity'),(991237,'deals','.b-quantity .qty-box input','vertical-align','top','','','.b-quantity'),(991238,'deals','.w-product-quantity .qty_packs .price_1','vertical-align','top','4','','.w-product-quantity'),(991239,'deals','.w-product-quantity .qty_packs .price_1, .w-product-quantity .qty_packs .qty-box','vertical-align','top','','','.w-product-quantity'),(991240,'deals','.w-sample .no-text','vertical-align','top','','','.w-sample'),(991241,'deals','.w-cart-order-reference .btn','vertical-align','top','','','.w-cart-order-reference'),(991242,'deals','.w-cart-gift-certificate .btn','vertical-align','top','','','.w-cart-gift-certificate'),(991243,'deals','.w-cart-shipping-estimator .btn','vertical-align','top','','','.w-cart-shipping-estimator'),(991245,'deals','.b-pagination .pagination .next-pages','vertical-align','top','','','.b-pagination'),(991246,'deals','.b-pagination .pagination .page-number','vertical-align','top','','','.b-pagination'),(991247,'deals','.b-pagination .pagination .prev-pages','vertical-align','top','','','.b-pagination'),(991248,'deals','.b-pagination .pagination a.next, .b-pagination .pagination span.next','vertical-align','top','','','.b-pagination'),(991249,'deals','.b-pagination .pagination a.prev, .b-pagination .pagination span.prev, .b-pagination .pagination .prev a','vertical-align','top','','','.b-pagination'),(991250,'deals','.b-pagination .pagination span','vertical-align','top','2','','.b-pagination'),(991251,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','vertical-align','top','','','.w-rma-returns-history'),(991252,'deals','.w-product-configurator .item-content > div','vertical-align','top','','','.w-product-configurator'),(991253,'deals','.w-predefined-promotion .heading-3','vertical-align','top','','','.w-predefined-promotion'),(991255,'deals','.b-quantity .qty-box input[type=\'text\']','vertical-align','top','','','.b-quantity'),(991256,'deals','.w-promotions-widgets-promotion-icons-desc .promo-icon','vertical-align','top','','','.w-promotions-widgets-promotion-icons-desc'),(991257,'deals','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','vertical-align','top','','','.w-promotions-widgets-promotion-icons-desc'),(991258,'deals','.w-cart-discount-coupon .title','vertical-align','middle','4','','.w-cart-discount-coupon'),(991259,'deals','.w-cart-checkout-btn .with-card','vertical-align','middle','4','','.w-cart-checkout-btn'),(991260,'deals','.w-promotions-widgets-promotions .products','vertical-align','top','','','.w-promotions-widgets-promotions'),(991261,'deals','.w-promotions-widgets-promotions .products .item','vertical-align','top','','','.w-promotions-widgets-promotions'),(991262,'deals','.w-promotions-widgets-promotions .promotion-data-2','vertical-align','top','','','.w-promotions-widgets-promotions'),(991267,'deals','.account-samples .view_link','vertical-align','middle','4','','.account-samples'),(991268,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','vertical-align','middle','3','','.b-multi-page-checkout'),(991269,'deals','.w-banner .image-text-banner.middle-left .text-banner-2, .w-banner .image-text-banner.middle-center .text-banner-2, .w-banner .image-text-banner.middle-right .text-banner-2','vertical-align','middle','','','.w-banner'),(991270,'deals','.w-catalog-paging ','vertical-align','top','2','','.w-catalog-paging'),(991271,'deals','.w-catalog-paging .next','vertical-align','top','','','.w-catalog-paging'),(991272,'deals','.w-catalog-paging .next-pages','vertical-align','top','','','.w-catalog-paging'),(991273,'deals','.w-catalog-paging .page-number','vertical-align','top','','','.w-catalog-paging'),(991274,'deals','.w-catalog-paging .prev','vertical-align','top','','','.w-catalog-paging'),(991275,'deals','.w-catalog-paging .prev-pages','vertical-align','top','','','.w-catalog-paging'),(991276,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','vertical-align','top','','','.w-catalog-paging'),(991278,'deals','.w-menu-slider .close','vertical-align','20px','','','.w-menu-slider'),(991279,'deals','.w-menu-slider > ul > li','vertical-align','top','','','.w-menu-slider'),(991280,'deals','.w-menu-slider > ul > li > ul > li','vertical-align','top','','','.w-menu-slider'),(991281,'deals','.b-switch .bootstrap-switch .bootstrap-switch-container > span','vertical-align_important','important','','','.b-switch'),(991282,'deals','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(991283,'deals','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(991284,'deals','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(991285,'deals','.b-fancybox .fancybox-tmp','visibility','hidden','','','.b-fancybox'),(991286,'deals','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(991287,'deals','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(991288,'deals','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(991289,'deals','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(991290,'deals','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(991291,'deals','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(991292,'deals','.b-hidden-boxes .box[data-name=\"Logo\"], .b-hidden-boxes .box[data-name=\"info\\\\Content\"], .b-hidden-boxes .box[data-name=\"Copyright\"], .b-hidden-boxes .box[data-name=\"invoice\\\\StoreAddress\"], .b-hidden-boxes .box[data-name=\"info\\\\Title\"]','visibility','visible','','','.b-hidden-boxes'),(991293,'deals','.b-upload-files .attach-active-holder .attach-file','visibility','hidden','','','.b-upload-files'),(991294,'deals','.b-fancybox .fancybox-nav:hover span','visibility','visible','','','.b-fancybox'),(991295,'deals','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(991296,'deals','.b-fancybox .fancybox-opened .fancybox-title','visibility','visible','','','.b-fancybox'),(991297,'deals','.checkbox input','visibility','hidden','','',''),(991298,'deals','.b-fancybox .fancybox-title','visibility','hidden','','','.b-fancybox'),(991299,'deals','.b-fancybox .fancybox-nav span','visibility','hidden','','','.b-fancybox'),(991300,'deals','.b-form .radio-button input[type=\"radio\"].no','visibility','hidden','','','.b-form'),(991301,'deals','.b-hidden-boxes .box','visibility','hidden','','','.b-hidden-boxes'),(991302,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','visibility','hidden','','','.b-menu-lev_display-slide'),(991303,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-1 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(991304,'deals','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','visibility','hidden','','','.b-menu-lev_display-slide'),(991305,'deals','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','visibility','hidden','','','.b-menu-lev_display-slide'),(991306,'deals','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','visibility','hidden','','','.b-menu-lev_display-slide'),(991307,'deals','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','visibility','hidden','','','.b-menu-lev_display-slide'),(991308,'deals','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-2 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(991309,'deals','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-4 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(991310,'deals','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-5 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(991311,'deals','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-3 > li.vis-show > ul','visibility','visible','','','.b-menu-lev_display-slide'),(991312,'deals','.b-slick .slick-loading .slick-slide','visibility','hidden','','','.b-slick'),(991313,'deals','.b-slick .slick-loading .slick-track','visibility','hidden','','','.b-slick'),(991314,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no input','visibility','hidden','','','.w-questionnaire-widgets-questionnaire'),(991315,'deals','.b-fancybox .fancybox-title-float-wrap .child','white-space','nowrap','','','.b-fancybox'),(991316,'deals','.w-checkout-shipping-choice span','white-space','nowrap','5660','','.w-checkout-shipping-choice'),(991317,'deals','.b-select-suggest .select2-container .select2-choice > .select2-chosen','white-space','nowrap','','','.b-select-suggest'),(991318,'deals','.w-menu-horizontal > ul','white-space','nowrap','','','.w-menu-horizontal'),(991319,'deals','.w-menu-horizontal > ul','white-space','normal','5639','','.w-menu-horizontal'),(991320,'deals','.b-fancybox .fancybox-error','white-space','nowrap','','','.b-fancybox'),(991321,'deals','.w-catalog-sorting .before','white-space','nowrap','','','.w-catalog-sorting'),(991322,'deals','.b-select-suggest .select2-search','white-space','nowrap','','','.b-select-suggest'),(991323,'deals','.b-select-suggest .select2-container-multi .select2-choices .select2-search-field','white-space','nowrap','','','.b-select-suggest'),(991324,'deals','.b-select-suggest .select2-container .select2-choice','white-space','nowrap','','','.b-select-suggest'),(991325,'deals','.w-cart-listing .remove-btn','white-space','nowrap','5639','','.w-cart-listing'),(991326,'deals','.b-quantity .qty-box','white-space','nowrap','','','.b-quantity'),(991327,'deals','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','white-space','nowrap','','','.w-cart-listing'),(991328,'deals','.w-filters .filter-widget-horizontal .filter-box-head','white-space','nowrap','','','.w-filters'),(991331,'deals','.account-samples .view_link','white-space','nowrap','','','.account-samples'),(991332,'deals','.w-communication-new-topic .model','width','100','','','.w-communication-new-topic'),(991333,'deals','.w-communication-new-topic .date-purchased','width','130','','','.w-communication-new-topic'),(991334,'deals','.w-communication-new-topic .request-type','width','150','','','.w-communication-new-topic'),(991335,'deals','.w-communication-new-topic .return-reason','width','150','','','.w-communication-new-topic'),(991336,'deals','.b-form .col-left','width','48','','','.b-form'),(991337,'deals','.b-email img','width','60','','','.b-email'),(991338,'deals','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(991339,'deals','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(991340,'deals','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(991341,'deals','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(991342,'deals','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(991343,'deals','.w-product-images-additional .item','width','80','5660','','.w-product-images-additional'),(991345,'deals','.b-email .totals-value','width','30','','','.b-email'),(991346,'deals','.w-promotions .prom-multi-discount .image img','width','auto','','','.w-promotions'),(991347,'deals','.w-promotions .promo-salemaker > div','width','50','','','.w-promotions'),(991348,'deals','.w-promotions .promo-cart-discount > div','width','50','','','.w-promotions'),(991353,'deals','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width','100','','','.p-sample-checkout-login'),(991354,'deals','.b-email .image','width','100','','','.b-email'),(991355,'deals','.w-categories .item','width','calc(15% - 20px)','','','.w-categories'),(991356,'deals','.w-promotions .prom-multi-discount .list','width','100','','','.w-promotions'),(991357,'deals','.w-promotions .nextdiscount .item-holder .image','width','40','','','.w-promotions'),(991358,'deals','.w-promotions .nextdiscount .item-holder .name','width','60','','','.w-promotions'),(991359,'deals','.w-promotions .icon','width','45','','','.w-promotions'),(991360,'deals','.w-promotions .promo-salemaker .image img','width','auto','','','.w-promotions'),(991361,'deals','.w-promotions .promo-salemaker .item','width','50','','','.w-promotions'),(991362,'deals','.w-promotions .promo-cart-discount .slave .item','width','calc(50% - 4px)','','','.w-promotions'),(991363,'deals','.w-promotions .promo-cart-discount .image img','width','auto','','','.w-promotions'),(991364,'deals','.b-warehouses-popup .warehouses-popup','width','570','','','.b-warehouses-popup'),(991365,'deals','.b-warehouses-popup .warehouses-popup .warehouse-item','width','230','','','.b-warehouses-popup'),(991366,'deals','.b-preloader .preloader','width','40','3','','.b-preloader'),(991367,'deals','.b-preloader .preloader','width','100','','','.b-preloader'),(991368,'deals','.b-products-listing .products-listing .attribute-qty-block','width','47','','','.b-products-listing'),(991369,'deals','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(991370,'deals','.w-brands .brands-listing > div','width','16','','','.w-brands'),(991371,'deals','.w-cart-continue-btn a','width','100','5630','','.w-cart-continue-btn'),(991372,'deals','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(991373,'deals','.order-summary .price-row.ot_gv .title','width','32','3','','.order-summary'),(991374,'deals','.w-brands .brands-listing > div','width','16','','','.w-brands'),(991375,'deals','.w-login-block .returning','width','50','','','.w-login-block'),(991376,'deals','.w-product-images-additional .item','width','80','5660','','.w-product-images-additional'),(991377,'deals','.w-product-images-additional .additional-images','width','80','5660','','.w-product-images-additional'),(991378,'deals','.b-products-listing .select-attributes select','width','66','','','.b-products-listing'),(991379,'deals','.b-messages .box-block.type-6 > .block:nth-child(1)','width','25','','','.b-messages'),(991380,'deals','.b-messages .msv_to_cc div span.msv_to_cc_bold','width','100','','','.b-messages'),(991381,'deals','.b-messages .messages-sidebar .btn-2','width','100','','','.b-messages'),(991382,'deals','.b-messages .pre_upload','width','auto','','','.b-messages'),(991383,'deals','.b-messages .email-line input','width','100','','','.b-messages'),(991384,'deals','.b-messages .email-line label','width','150','','','.b-messages'),(991385,'deals','.b-messages #DataTables_Table_0_wrapper table.dataTable thead td:last-child, .b-messages #DataTables_Table_0_wrapper table.dataTable tbody td:last-child','width','200','','','.b-messages'),(991386,'deals','.w-sitemap-delivery-location > ul > li > ul > li','width','25','','','.w-sitemap-delivery-location'),(991387,'deals','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(991388,'deals','.b-bottom .terms-info-popup','width','1000','','','.b-bottom'),(991389,'deals','.b-form .col-right','width','100','5639','','.b-form'),(991390,'deals','.p-payer-order-confirmation .order-summary2 .btn-2','width','100','','','.p-payer-order-confirmation'),(991391,'deals','.p-payer-order-confirmation .dob-hide > div','width','48','','','.p-payer-order-confirmation'),(991392,'deals','.p-payer-order-pay .order-summary2 .btn-2','width','100','','','.p-payer-order-pay'),(991393,'deals','.p-payer-order-pay .dob-hide > div','width','48','','','.p-payer-order-pay'),(991394,'deals','.w-checkout-terms .required-message','width','100','','','.w-checkout-terms'),(991395,'deals','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(991396,'deals','.w-checkout-create-btn .btn-2','width','260','','','.w-checkout-create-btn'),(991397,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-off','width','15','','','.b-switch'),(991398,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-toggle','width','40','','','.b-switch'),(991399,'deals','.b-fancybox #fancybox-loading div','width','44','','','.b-fancybox'),(991400,'deals','.b-datepicker .bootstrap-datetimepicker-widget table td span.decade, .b-datepicker .bootstrap-datetimepicker-widget table td span.decade ~ span','width','79','','','.b-datepicker'),(991401,'deals','.b-email .image','width','100','','','.b-email'),(991402,'deals','.w-checkout-contact-information div[data-name=\"checkout[email_address]\"]','width','25','3','','.w-checkout-contact-information'),(991403,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-nc','width','100','','','.b-switch'),(991404,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-nc','width','15','','','.b-switch'),(991405,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width','20','3','','.b-switch'),(991406,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file-wrap','width','150','','','.w-upload-customer-id-upload-customer-id-form'),(991407,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(991408,'deals','.w-upload-customer-id-upload-customer-id-form .dz-details','width','100','','','.w-upload-customer-id-upload-customer-id-form'),(991409,'deals','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(991410,'deals','.b-email .image','width','100','','','.b-email'),(991411,'deals','.w-checkout-bonus-points .btn-remove','width','25','','','.w-checkout-bonus-points'),(991412,'deals','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(991413,'deals','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(991414,'deals','.w-login-block .input','width','100','','','.w-login-block'),(991415,'deals','.w-login-block .guest','width','50','','','.w-login-block'),(991416,'deals','.w-login-block .new','width','50','','','.w-login-block'),(991417,'deals','.w-menu-horizontal li','width','auto','','','.w-menu-horizontal'),(991418,'deals','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(991419,'deals','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(991420,'deals','.w-login-block .input','width','100','','','.w-login-block'),(991421,'deals','.b-form .checkbox-style:checked + .checkbox-span','width','15','','','.b-form'),(991422,'deals','.w-delayed-despatch-checkout #delivery_date','width','150','','','.w-delayed-despatch-checkout'),(991423,'deals','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(991424,'deals','.w-product-images-additional .item-div','width','80','5660','','.w-product-images-additional'),(991425,'deals','.b-fancybox .fancybox-lock','width','auto','','','.b-fancybox'),(991426,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-on','width','15','','','.b-switch'),(991427,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-off','width','10','','','.b-switch'),(991428,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-nc','width','10','','','.b-switch'),(991429,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs','width','30','','','.b-switch'),(991430,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm .candlestick-bg .candlestick-toggle','width','15','','','.b-switch'),(991432,'deals','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(991433,'deals','.w-promo-code .promo-code-form','width','100','5639','','.w-promo-code'),(991434,'deals','.b-email .totals-value','width','30','','','.b-email'),(991435,'deals','.b-email .totals-title','width','70','','','.b-email'),(991436,'deals','.w-filters .ui-slider-handle','width','15','','','.w-filters'),(991437,'deals','.pop-up-content .buttons .btn-2','width','100','5639','',''),(991438,'deals','.pop-up-content .buttons .btn','width','100','5639','',''),(991439,'deals','.pop-up-content .buttons .left-buttons','width','100','5639','',''),(991440,'deals','.pop-up-content .buttons .right-buttons','width','100','5639','',''),(991442,'deals','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(991443,'deals','.w-login-block .returning','width','50','','','.w-login-block'),(991445,'deals','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(991447,'deals','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(991448,'deals','.b-products-listing .btn-choose-options','width','100','','','.b-products-listing'),(991449,'deals','.w-filters .input-checkbox:checked + .checkbox-span','width','24','','','.w-filters'),(991450,'deals','.w-filters .ui-slider','width','100','','','.w-filters'),(991451,'deals','.w-checkout-shipping-choice input:checked + span:before','width','10','','','.w-checkout-shipping-choice'),(991452,'deals','.b-switch .candlestick-wrapper','width','60','','','.b-switch'),(991453,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','width','20','3','','.b-switch'),(991454,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(991455,'deals','.b-email .image','width','100','','','.b-email'),(991456,'deals','.b-email .totals-value','width','30','','','.b-email'),(991457,'deals','.b-email .heading-image','width','100','','','.b-email'),(991458,'deals','.b-email .products-table','width','100','','','.b-email'),(991459,'deals','.b-form .login-col-1','width','25','','','.b-form'),(991460,'deals','.b-select-suggest .select2-container','width','100','','','.b-select-suggest'),(991461,'deals','.b-select-suggest .select2-measure-scrollbar','width','100','','','.b-select-suggest'),(991462,'deals','.b-email-editor img','width','auto','','','.b-email-editor'),(991463,'deals','.b-form .middle-form .dob-input input[type=\"text\"]','width','48','','','.b-form'),(991464,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width','1','','','.b-select-suggest'),(991465,'deals','.w-brands .brands-listing > div','width','16','','','.w-brands'),(991466,'deals','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(991467,'deals','.w-socials .post_item_img','width','100','','','.w-socials'),(991469,'deals','.b-info-popup .info-popup div','width','250','','','.b-info-popup'),(991470,'deals','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5639','','.w-promo-code'),(991471,'deals','.w-brands .brands-listing > div','width','16','','','.w-brands'),(991472,'deals','.w-cart-listing .right-area','width','100','5639','','.w-cart-listing'),(991473,'deals','.w-product-images-additional .additional-images','width','80','5660','','.w-product-images-additional'),(991474,'deals','.w-promo-code .promo-text','width','100','5639','','.w-promo-code'),(991475,'deals','.w-cart-continue-btn a','width','100','5630','','.w-cart-continue-btn'),(991476,'deals','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(991477,'deals','.w-cart-order-total.box','width','100','5630','','.w-cart-order-total'),(991478,'deals','.b-info-popup .info-popup div','width','20','3','','.b-info-popup'),(991479,'deals','.b-email .totals-value','width','30','','','.b-email'),(991480,'deals','.b-email .heading-image','width','100','','','.b-email'),(991481,'deals','.b-email .heading-image','width','100','','','.b-email'),(991482,'deals','.view-all','width','100','3','',''),(991483,'deals','.w-promo-code .promo-code-form','width','100','5639','','.w-promo-code'),(991484,'deals','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5639','','.w-promo-code'),(991486,'deals','.b-form .columns .col-2','width','50','','','.b-form'),(991487,'deals','.b-bottom .popup-box.popupCompare','width','80','','','.b-bottom'),(991488,'deals','.w-promo-code .promo-code-form','width','100','5639','','.w-promo-code'),(991489,'deals','.w-cart-continue-btn a','width','100','5630','','.w-cart-continue-btn'),(991490,'deals','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(991491,'deals','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(991492,'deals','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(991493,'deals','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(991494,'deals','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(991495,'deals','.w-checkout-guest-btn .btn-2','width','260','','','.w-checkout-guest-btn'),(991496,'deals','textarea','width','100','','',''),(991497,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(991498,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','width','100','','','.b-switch'),(991499,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-on','width','100','','','.b-switch'),(991500,'deals','.b-switch .bootstrap-switch .bootstrap-switch-label','width','30','','','.b-switch'),(991502,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(991503,'deals','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(991504,'deals','.b-email-editor img','width','auto','','','.b-email-editor'),(991505,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-off','width','100','','','.b-switch'),(991506,'deals','.b-form .checkbox-style','width','0','','','.b-form'),(991507,'deals','.b-email .image','width','100','','','.b-email'),(991508,'deals','.b-email .totals-title','width','70','','','.b-email'),(991509,'deals','.w-checkout-contact-information div[data-name=\"checkout[telephone]\"]','width','25','3','','.w-checkout-contact-information'),(991510,'deals','.b-form .addresses .address-item','width','48','','','.b-form'),(991511,'deals','.w-categories .item','width','calc(50% - 20px)','5630','','.w-categories'),(991512,'deals','.order-summary .btn-2, .order-summary .btn-3','width','100','','','.order-summary'),(991513,'deals','.w-cart-bonus-points .bonus_points_amount','width','150','','','.w-cart-bonus-points'),(991514,'deals','.w-cart-bonus-points .btn-remove','width','25','','','.w-cart-bonus-points'),(991515,'deals','.order-summary .price-box .price','width','auto','','','.order-summary'),(991516,'deals','.b-email .totals-table','width','100','','','.b-email'),(991517,'deals','.w-socials .post_item_img','width','100','','','.w-socials'),(991518,'deals','.w-list-b2b .select-attributes','width','47','','','.w-list-b2b'),(991519,'deals','.w-promo-code .promo-text','width','100','5639','','.w-promo-code'),(991520,'deals','.w-checkout-shipping-choice label','width','50','','','.w-checkout-shipping-choice'),(991521,'deals','.b-switch .candlestick-wrapper.candlestick-contents','width','306','','','.b-switch'),(991522,'deals','.b-email .products-table','width','100','','','.b-email'),(991523,'deals','.w-checkout-shipping-choice label','width','auto','5660','','.w-checkout-shipping-choice'),(991524,'deals','.w-checkout-create-account .col-2','width','100','5639','','.w-checkout-create-account'),(991525,'deals','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(991526,'deals','.w-top-categories .item','width','calc(25% - 50px)','','','.w-top-categories'),(991527,'deals','.w-checkout-billing-address .addresses .address-item','width','50','','','.w-checkout-billing-address'),(991528,'deals','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(991529,'deals','.w-cart-give-away .ga_attributes select','width','100','','','.w-cart-give-away'),(991530,'deals','.b-autocomplete .ui-autocomplete','width','200','','','.b-autocomplete'),(991531,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(991532,'deals','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(991533,'deals','.w-socials .post_item_img','width','100','','','.w-socials'),(991535,'deals','.b-email .totals-value','width','30','','','.b-email'),(991536,'deals','.b-email .totals-table','width','100','','','.b-email'),(991537,'deals','.b-email .totals-title','width','70','','','.b-email'),(991538,'deals','.b-email .heading-image','width','100','','','.b-email'),(991539,'deals','.b-email img','width','60','','','.b-email'),(991540,'deals','.b-email .products-table','width','100','','','.b-email'),(991541,'deals','.b-email .image','width','100','','','.b-email'),(991542,'deals','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width','100','','','.p-quote-checkout-login'),(991543,'deals','.b-form .col-right','width','48','','','.b-form'),(991544,'deals','.b-email img','width','60','','','.b-email'),(991545,'deals','.w-cart-continue-btn a','width','100','5630','','.w-cart-continue-btn'),(991546,'deals','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5639','','.w-promo-code'),(991547,'deals','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(991548,'deals','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(991549,'deals','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(991550,'deals','.w-promo-code .promo-code-form','width','100','5639','','.w-promo-code'),(991551,'deals','.w-promo-code .promo-text','width','100','5639','','.w-promo-code'),(991552,'deals','.b-form .columns .col-2','width','100','5660','','.b-form'),(991553,'deals','.b-select-suggest .select2-container .select2-choice abbr','width','12','','','.b-select-suggest'),(991554,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(991555,'deals','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(991556,'deals','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(991557,'deals','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(991558,'deals','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(991559,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-off, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-nc, .b-switch .candlestick-wrapper .candlestick-bg .candlestick-on','width','20','','','.b-switch'),(991560,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','width','28','','','.b-switch'),(991561,'deals','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(991562,'deals','.w-login-block .new','width','50','','','.w-login-block'),(991563,'deals','.w-login-block .guest','width','50','','','.w-login-block'),(991564,'deals','.w-login-block .input','width','100','','','.w-login-block'),(991565,'deals','.w-login-block .returning','width','50','','','.w-login-block'),(991566,'deals','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(991567,'deals','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(991568,'deals','div.cart-popup','width','850','','',''),(991569,'deals','.w-cart-give-away .ga_column','width','46','','','.w-cart-give-away'),(991570,'deals','.w-cart-give-away .ga_attributes > div','width','48','','','.w-cart-give-away'),(991571,'deals','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width','100','','','.b-form'),(991572,'deals','.b-products-listing .products-listing .buyButton .btn','width','100','','','.b-products-listing'),(991573,'deals','.w-image-maps .svg-wrap svg','width','100','','','.w-image-maps'),(991574,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(991575,'deals','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(991576,'deals','.w-login-block .guest','width','50','','','.w-login-block'),(991577,'deals','.w-login-block .new','width','50','','','.w-login-block'),(991578,'deals','.w-cart-shipping-estimator .right-area','width','48','','','.w-cart-shipping-estimator'),(991579,'deals','.w-product-promotions .products .item','width','260','','','.w-product-promotions'),(991580,'deals','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(991582,'deals','.w-checkout-credit-amount .btn-remove','width','25','','','.w-checkout-credit-amount'),(991583,'deals','.w-checkout-credit-amount .cot_gv_amount','width','150','','','.w-checkout-credit-amount'),(991584,'deals','.p-quick-order-index .all-scroll-div','width','100','','','.p-quick-order-index'),(991585,'deals','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(991586,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(991587,'deals','.b-email-editor img','width','auto','','','.b-email-editor'),(991588,'deals','.b-form .col-left','width','100','5639','','.b-form'),(991589,'deals','.b-email .totals-title','width','70','','','.b-email'),(991590,'deals','.b-email .totals-table','width','100','','','.b-email'),(991591,'deals','.w-product-images-additional .additional-images','width','80','5660','','.w-product-images-additional'),(991592,'deals','.w-product-images-additional .item','width','80','5660','','.w-product-images-additional'),(991593,'deals','.b-bottom .cart-options .option-item','width','50','','','.b-bottom'),(991594,'deals','.w-promotions .promo-cart-discount .master .item','width','calc(50% - 24px)','','','.w-promotions'),(991595,'deals','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(991596,'deals','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(991597,'deals','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(991598,'deals','.b-bottom .cart-options .cart-item','width','100','','','.b-bottom'),(991599,'deals','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(991600,'deals','.w-cart-shipping-estimator .left-area','width','48','','','.w-cart-shipping-estimator'),(991602,'deals','.w-login-block .returning','width','50','','','.w-login-block'),(991603,'deals','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(991604,'deals','.b-email img','width','60','','','.b-email'),(991605,'deals','.b-form .col-3','width','31.33','','','.b-form'),(991606,'deals','.b-email .products-table','width','100','','','.b-email'),(991607,'deals','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(991608,'deals','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width','100','','','.b-form'),(991609,'deals','.w-login-block .input','width','100','','','.w-login-block'),(991610,'deals','.b-products-listing .products-listing .mult-qty-input input[type=\'text\']','width','35','','','.b-products-listing'),(991611,'deals','.w-login-block .guest','width','50','','','.w-login-block'),(991612,'deals','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(991613,'deals','.w-product-images-additional .item-div','width','80','5660','','.w-product-images-additional'),(991614,'deals','.b-bottom .popup-box','width','530','','','.b-bottom'),(991615,'deals','.b-email .totals-table','width','100','','','.b-email'),(991616,'deals','.b-email img','width','60','','','.b-email'),(991617,'deals','.b-form .login-col-2','width','50','','','.b-form'),(991618,'deals','.b-fancybox .fancybox-close','width','40','','','.b-fancybox'),(991619,'deals','.w-cart-compare .product .image','width','50','','','.w-cart-compare'),(991620,'deals','.w-product-customers-activity .customers-activity','width','255','','','.w-product-customers-activity'),(991621,'deals','.w-product-customers-activity .close','width','30','','','.w-product-customers-activity'),(991622,'deals','.b-form .hide-billing-address','width','100','','','.b-form'),(991623,'deals','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(991624,'deals','.b-email-editor img','width','auto','','','.b-email-editor'),(991625,'deals','.w-top-categories .item','width','calc(50% - 20px)','5630','','.w-top-categories'),(991626,'deals','.w-personal-gift-status-bar .progress-bar','width','230','','','.w-personal-gift-status-bar'),(991627,'deals','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(991628,'deals','.w-checkout-billing-address .addresses.address-main .address-item','width','100','','','.w-checkout-billing-address'),(991629,'deals','.w-checkout-bonus-points .bonus_points_amount','width','150','','','.w-checkout-bonus-points'),(991630,'deals','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width','150','','','.w-coupons-and-vauchers-checkout'),(991631,'deals','.w-checkout-shipping-address .addresses.address-main .address-item','width','100','','','.w-checkout-shipping-address'),(991632,'deals','.w-checkout-shipping-choice #shippingchoice-choice','width','430','','','.w-checkout-shipping-choice'),(991633,'deals','.w-product-images-additional .item-div','width','80','5660','','.w-product-images-additional'),(991634,'deals','.w-product-images-additional .item','width','80','5660','','.w-product-images-additional'),(991635,'deals','.w-product-images-additional .additional-images','width','80','5660','','.w-product-images-additional'),(991636,'deals','.w-cart-order-total.box','width','100','5630','','.w-cart-order-total'),(991637,'deals','.w-promo-code .promo-code-form','width','100','5639','','.w-promo-code'),(991638,'deals','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5639','','.w-promo-code'),(991639,'deals','.w-cart-continue-btn a','width','100','5630','','.w-cart-continue-btn'),(991640,'deals','.w-promo-code .promo-text','width','100','5639','','.w-promo-code'),(991641,'deals','.w-cart-order-total.box','width','100','5630','','.w-cart-order-total'),(991642,'deals','.w-product-images-additional .item-div','width','80','5660','','.w-product-images-additional'),(991643,'deals','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(991644,'deals','.b-select-suggest .select2-search-choice-close','width','12','','','.b-select-suggest'),(991645,'deals','.b-select-suggest .select2-search input','width','100','','','.b-select-suggest'),(991646,'deals','.b-select-suggest .select2-search','width','100','','','.b-select-suggest'),(991647,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow','width','18','','','.b-select-suggest'),(991648,'deals','.b-select-suggest .select2-drop-auto-width','width','auto','','','.b-select-suggest'),(991649,'deals','.b-select-suggest .select2-drop','width','100','','','.b-select-suggest'),(991650,'deals','.b-select-suggest .select2-drop-mask','width','auto','','','.b-select-suggest'),(991651,'deals','.w-socials .post_item_img','width','100','','','.w-socials'),(991652,'deals','.w-tabs .tab-navigation','width','100','','','.w-tabs'),(991654,'deals','.w-login-block .returning','width','50','','','.w-login-block'),(991656,'deals','.b-email-editor img','width','auto','','','.b-email-editor'),(991657,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width','20','3','','.b-switch'),(991658,'deals','.b-social-login .social-login-text-2','width','70','3','','.b-social-login'),(991659,'deals','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(991660,'deals','.w-socials .post_item_img','width','100','','','.w-socials'),(991662,'deals','.w-login-block .guest','width','50','','','.w-login-block'),(991663,'deals','.w-login-block .returning','width','50','','','.w-login-block'),(991664,'deals','.w-menu-big li','width','auto','','','.w-menu-big'),(991665,'deals','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(991666,'deals','.w-cart-listing .links','width','19','','','.w-cart-listing'),(991667,'deals','.w-cart-order-total.box','width','100','5630','','.w-cart-order-total'),(991668,'deals','.w-account-addresses-list .addsess-suggestion-item','width','50','','','.w-account-addresses-list'),(991669,'deals','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width','80','','','.b-products-listing'),(991670,'deals','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width','60','','','.b-products-listing'),(991671,'deals','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width','40','','','.b-products-listing'),(991672,'deals','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width','20','','','.b-products-listing'),(991673,'deals','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width','40','','','.b-products-listing'),(991674,'deals','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width','20','','','.b-products-listing'),(991675,'deals','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width','60','','','.b-products-listing'),(991676,'deals','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width','60','','','.b-products-listing'),(991677,'deals','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width','20','','','.b-products-listing'),(991678,'deals','.b-products-listing .BlockBox.type-14 > .col','width','25','','','.b-products-listing'),(991679,'deals','.b-products-listing .BlockBox.type-15 > .col','width','20','','','.b-products-listing'),(991680,'deals','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width','50','','','.b-products-listing'),(991681,'deals','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(991682,'deals','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(991683,'deals','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width','33.33','','','.b-products-listing'),(991684,'deals','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width','50','','','.b-products-listing'),(991685,'deals','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width','33.33','','','.b-products-listing'),(991686,'deals','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width','66.66','','','.b-products-listing'),(991687,'deals','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width','66.66','','','.b-products-listing'),(991688,'deals','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width','33.33','','','.b-products-listing'),(991689,'deals','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width','25','','','.b-products-listing'),(991690,'deals','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width','25','','','.b-products-listing'),(991691,'deals','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width','75','','','.b-products-listing'),(991692,'deals','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width','75','','','.b-products-listing'),(991693,'deals','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width','25','','','.b-products-listing'),(991694,'deals','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width','50','','','.b-products-listing'),(991695,'deals','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width','25','','','.b-products-listing'),(991696,'deals','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width','20','','','.b-products-listing'),(991697,'deals','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width','80','','','.b-products-listing'),(991698,'deals','.b-products-listing .btn-preloader','width','24','3','','.b-products-listing'),(991699,'deals','.b-products-listing .hover-box-content','width','20','3','','.b-products-listing'),(991700,'deals','.b-products-listing .loader','width','30','4','','.b-products-listing'),(991701,'deals','.b-products-listing .loader','width','100','3','','.b-products-listing'),(991702,'deals','.b-products-listing .products-listing .attribute-qty-block > span','width','100','','','.b-products-listing'),(991703,'deals','.b-products-listing .products-listing .attributes select','width','48','','','.b-products-listing'),(991704,'deals','.b-products-listing .products-listing .btn-buy','width','100','','','.b-products-listing'),(991705,'deals','.w-catalog-b2b-add-button ','width','100','','','.w-catalog-b2b-add-button'),(991706,'deals','.b-products-listing .products-listing .item','width','25','','','.b-products-listing'),(991707,'deals','.b-products-listing .products-listing .qty-input.hidden','width','100','3','','.b-products-listing'),(991708,'deals','.b-products-listing .products-listing.list-type-1_2 .image img, .b-products-listing .products-listing.list-type-2_2 .image img, .b-products-listing .products-listing.list-type-1_3 .image img','width','auto','','','.b-products-listing'),(991709,'deals','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width','100','','','.b-products-listing'),(991710,'deals','.checkbox input:not(checked) + span:before','width','22','','',''),(991711,'deals','.checkbox input + span','width','24','','',''),(991713,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width','100','','','.b-select-suggest'),(991714,'deals','.b-products-listing .products-listing .in-cart','width','100','','','.b-products-listing'),(991715,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-toggle','width','10','','','.b-switch'),(991716,'deals','.b-switch .candlestick-wrapper.candlestick-size-xs .candlestick-bg .candlestick-on','width','10','','','.b-switch'),(991717,'deals','.w-checkout-contact-information div[data-name=\"checkout[landline]\"]','width','25','3','','.w-checkout-contact-information'),(991718,'deals','.b-form .radio-button input[type=\"radio\"].no + span','width','30','3','','.b-form'),(991719,'deals','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width','100','','','.b-fancybox'),(991720,'deals','.b-email .heading-image','width','100','','','.b-email'),(991721,'deals','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(991722,'deals','.w-product-images-additional .additional-images','width','80','5660','','.w-product-images-additional'),(991723,'deals','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5639','','.w-promo-code'),(991724,'deals','.w-socials .post_item_img','width','100','','','.w-socials'),(991725,'deals','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(991726,'deals','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(991727,'deals','.w-cart-credit-amount .btn-remove','width','25','','','.w-cart-credit-amount'),(991728,'deals','.w-coupons-and-vauchers-checkout .btn-remove','width','25','','','.w-coupons-and-vauchers-checkout'),(991729,'deals','.p-wedding-registry-search .search-list input','width','100','','','.p-wedding-registry-search'),(991730,'deals','.order-summary .price-row.ot_coupon .title','width','32','3','','.order-summary'),(991731,'deals','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterSku\"]','width','60','','','.w-communication-new-topic'),(991732,'deals','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterOrderId\"]','width','60','','','.w-communication-new-topic'),(991733,'deals','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterName\"]','width','100','','','.w-communication-new-topic'),(991734,'deals','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateFrom\"]','width','60','','','.w-communication-new-topic'),(991735,'deals','.w-communication-new-topic input[name=\"rmaProductReturnQuantityFilterDateTo\"]','width','60','','','.w-communication-new-topic'),(991736,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .increment','width','36','','','.w-communication-new-topic'),(991737,'deals','.w-communication-new-topic .rmaProductReturnQuantityHolder .decrement','width','36','','','.w-communication-new-topic'),(991738,'deals','.w-communication-new-topic .middle-form select','width','100','','','.w-communication-new-topic'),(991739,'deals','.w-login-block .input','width','100','','','.w-login-block'),(991740,'deals','.w-checkout-shipping-address .addresses .address-item','width','50','','','.w-checkout-shipping-address'),(991741,'deals','.b-form .checkbox-style:not(checked) + .checkbox-span','width','15','','','.b-form'),(991742,'deals','.w-checkout-shipping-choice #shippingchoice-choice','width','auto','5660','','.w-checkout-shipping-choice'),(991743,'deals','.b-email img','width','60','','','.b-email'),(991744,'deals','.w-cart-continue-btn a','width','100','5630','','.w-cart-continue-btn'),(991745,'deals','.b-bottom .popup-credit-amount .popup-box','width','100','','','.b-bottom'),(991746,'deals','.w-product-images-additional .item','width','80','5660','','.w-product-images-additional'),(991747,'deals','.w-promo-code .promo-code-form','width','100','5639','','.w-promo-code'),(991748,'deals','.b-email .products-table','width','100','','','.b-email'),(991749,'deals','.b-email .totals-title','width','70','','','.b-email'),(991750,'deals','.w-login-block .new','width','50','','','.w-login-block'),(991751,'deals','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(991752,'deals','.b-email-editor img','width','auto','','','.b-email-editor'),(991753,'deals','.b-email .heading-image','width','100','','','.b-email'),(991754,'deals','.w-promo-code input[type=\"text\"]','width','calc(100% - 120px)','','','.w-promo-code'),(991755,'deals','.w-promo-code .promo-code-form','width','45','','','.w-promo-code'),(991756,'deals','.w-promo-code .promo-text','width','45','','','.w-promo-code'),(991757,'deals','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(991758,'deals','.b-compare .col-two label','width','20','','','.b-compare'),(991759,'deals','.w-cart-order-total.box','width','100','5630','','.w-cart-order-total'),(991760,'deals','.w-promo-code .promo-text','width','100','5639','','.w-promo-code'),(991761,'deals','.w-menu-horizontal .menu-ico','width','54','','','.w-menu-horizontal'),(991762,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(991763,'deals','.w-product-promotions .select-box','width','45','','','.w-product-promotions'),(991764,'deals','.w-catalog-listing-look .grid','width','35','','','.w-catalog-listing-look'),(991765,'deals','.w-catalog-listing-look .b2b','width','35','','','.w-catalog-listing-look'),(991766,'deals','.w-catalog-listing-look .list','width','35','','','.w-catalog-listing-look'),(991767,'deals','.w-cart-listing .multi-product-copy, .w-cart-listing .multi-product-move, .w-cart-listing .multi-product-delete','width','130','','','.w-cart-listing'),(991768,'deals','.w-cart-listing .remove-btn','width','30','','','.w-cart-listing'),(991769,'deals','.w-cart-listing .right-area','width','35','','','.w-cart-listing'),(991770,'deals','.w-cart-listing .item .image','width','80','5639','','.w-cart-listing'),(991771,'deals','.w-cart-listing .item .remove','width','100','5639','','.w-cart-listing'),(991772,'deals','.w-cart-give-away .ga_img','width','30','','','.w-cart-give-away'),(991773,'deals','.w-cart-give-away .ga_column','width','100','5630','','.w-cart-give-away'),(991774,'deals','.w-cart-discount-coupon input[type=\"text\"]','width','100','','','.w-cart-discount-coupon'),(991775,'deals','.w-cart-discount-coupon .btn-remove','width','25','','','.w-cart-discount-coupon'),(991777,'deals','.w-brands .brands-listing > div','width','16','','','.w-brands'),(991778,'deals','.b-upload-file .snapshot','width','38','','','.b-upload-file'),(991779,'deals','.b-fancybox .fancybox-nav span','width','40','','','.b-fancybox'),(991780,'deals','.b-fancybox .fancybox-nav','width','40','','','.b-fancybox'),(991781,'deals','.b-email .totals-table','width','100','','','.b-email'),(991782,'deals','.w-product-images-additional .item','width','80','5660','','.w-product-images-additional'),(991783,'deals','.b-upload-file .upload-file-template','width','150','','','.b-upload-file'),(991784,'deals','.w-login-block .col-2:nth-child(2n + 1)','width','48','','','.w-login-block'),(991785,'deals','.w-login-block .col-2:nth-child(2n)','width','48','','','.w-login-block'),(991786,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','width','65','','','.b-tracking-numbers'),(991787,'deals','.b-tracking-numbers div.tracking-numbers-popup','width','800','','','.b-tracking-numbers'),(991788,'deals','.b-tracking-numbers .tracking-numbers .qty','width','40','','','.b-tracking-numbers'),(991789,'deals','.b-switch .candlestick-wrapper.candlestick-size-sm','width','45','','','.b-switch'),(991790,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-on','width','40','','','.b-switch'),(991791,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(991793,'deals','.w-login-block .new','width','50','','','.w-login-block'),(991794,'deals','.w-filters .handle-to','width','50','','','.w-filters'),(991795,'deals','.w-filters .handle-from','width','50','','','.w-filters'),(991796,'deals','.w-promo-code input[type=\"text\"]','width','calc(100% - 95px)','5639','','.w-promo-code'),(991797,'deals','.order-summary .price-row.ot_bonus_points .title','width','32','3','','.order-summary'),(991798,'deals','.w-filters .input-checkbox','width','0','','','.w-filters'),(991799,'deals','.b-bottom .pop-up-close','width','31','','','.b-bottom'),(991800,'deals','.w-product-images-additional .item-div','width','80','5660','','.w-product-images-additional'),(991801,'deals','.w-promo-code .promo-text','width','100','5639','','.w-promo-code'),(991802,'deals','.w-product-images-additional .additional-images','width','80','5660','','.w-product-images-additional'),(991803,'deals','.w-product-images-additional .item-div','width','80','5660','','.w-product-images-additional'),(991804,'deals','.w-cart-order-total.box','width','100','5630','','.w-cart-order-total'),(991805,'deals','.b-compare .col-two select','width','80','','','.b-compare'),(991806,'deals','.b-dropdown .dropdown:hover .dropdown-menu','width','200','','','.b-dropdown'),(991807,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(991808,'deals','.w-login-block .new','width','50','','','.w-login-block'),(991809,'deals','.w-login-block .input','width','100','','','.w-login-block'),(991810,'deals','.w-login-block .guest','width','50','','','.w-login-block'),(991811,'deals','.b-products-listing .products-listing .btn-preloader','width','100','','','.b-products-listing'),(991812,'deals','.w-communication-new-topic .btn-submit','width','200','','','.w-communication-new-topic'),(991813,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','width','35','','','.b-tracking-numbers'),(991815,'deals','.w-cart-credit-amount input[type=\"text\"]','width','150','','','.w-cart-credit-amount'),(991817,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg','width','120','','','.b-switch'),(991818,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-nc','width','40','','','.b-switch'),(991819,'deals','.b-switch .candlestick-wrapper.candlestick-size-lg .candlestick-bg .candlestick-off','width','40','','','.b-switch'),(991820,'deals','.b-social-login .social-login-text-2','width','70','4','','.b-social-login'),(991821,'deals','.b-email .products-table','width','100','','','.b-email'),(991822,'deals','.b-email .totals-value','width','30','','','.b-email'),(991823,'deals','.b-email .totals-title','width','70','','','.b-email'),(991824,'deals','.b-email .totals-table','width','100','','','.b-email'),(991825,'deals','.w-filters .mobileCollapse','width','17','','','.w-filters'),(991826,'deals','.w-filters .input-txt-keywords','width','100','','','.w-filters'),(991827,'deals','.w-filters .input-txt','width','60','','','.w-filters'),(991828,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','width','250','','','.w-image-maps'),(991829,'deals','.w-filters .input-checkbox:not(checked) + .checkbox-span','width','24','','','.w-filters'),(991830,'deals','.w-brands .brands-listing > div','width','16','','','.w-brands'),(991831,'deals','.b-product-images .additional-images .item img, .b-product-images .additional-images .item video, .b-product-images .additional-videos .item img','width','auto','','','.b-product-images'),(991832,'deals','.b-product-images .media-popup .mp-close','width','100','','','.b-product-images'),(991833,'deals','.b-product-images .media-popup .mp-small-images .item','width','150','','','.b-product-images'),(991834,'deals','.b-product-images .media-popup button.slick-prev, .b-product-images .media-popup button.slick-next','width','100','','','.b-product-images'),(991835,'deals','.b-menu-burger_icon .menu-style[data-burger_icon] .burger-icon','width','30','','','.b-menu-burger_icon'),(991836,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width','100','','','.b-menu-lev_display-slide'),(991837,'deals','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width','100','','','.b-menu-lev_display-slide'),(991838,'deals','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width','100','','','.b-menu-lev_display-slide'),(991839,'deals','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width','100','','','.b-menu-lev_display-slide'),(991840,'deals','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width','100','','','.b-menu-lev_display-slide'),(991841,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(991842,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(991843,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(991844,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(991845,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','width','40','','','.b-menu-lev_vis-click_icon'),(991846,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width','100','','','.b-menu-open_from-left'),(991847,'deals','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(991848,'deals','.b-trade-approval .steps-bar','width','100','','','.b-trade-approval'),(991849,'deals','.b-trade-approval .col-right','width','48','','','.b-trade-approval'),(991850,'deals','.b-trade-approval .col-left','width','48','','','.b-trade-approval'),(991851,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width','100','','','.b-trade-approval'),(991852,'deals','.b-trade-approval .col-3','width','31.33','','','.b-trade-approval'),(991853,'deals','.w-account-personal-catalog .list-switcher','width','100','','','.w-account-personal-catalog'),(991854,'deals','.w-catalog-compare .buyButton a.btn, .w-catalog-compare .buyButton a.btn-1, .w-catalog-compare .buyButton span.btn-preloader','width','auto','','','.w-catalog-compare'),(991855,'deals','.w-catalog-compare .cross-box .different-all > div','width','50','','','.w-catalog-compare'),(991856,'deals','.w-product-images .additional-vertical .produst-image','width','calc(100% - 100px)','','','.w-product-images'),(991857,'deals','.w-product-images .additional-vertical .additional-images','width','100','','','.w-product-images'),(991860,'deals','.lowestPricedBox .w-banner .single_banner','width','50','','','.lowestPricedBox'),(991861,'deals','.b-products-listing .products-listing.list-productlisting .BlockBox.type-2 > .col:nth-child(1)','width','100','','','.b-products-listing'),(991862,'deals','.b-products-listing .products-listing.list-productlisting .BlockBox.type-2 > .col:nth-child(2)','width','100','','','.b-products-listing'),(991863,'deals','.shopByCollectionBox .w-banner .single_banner','width','33.333','','','.shopByCollectionBox'),(991864,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','width','50','','','.b-slick'),(991865,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','width','50','5639','','.b-slick'),(991869,'deals','.w-filters .ui-state-default, .w-filters .ui-widget-content .ui-state-default, .w-filters .ui-widget-header .ui-state-default','width','13','','','.w-filters'),(991870,'deals','.w-quote .cart-box-link','width','48','3','','.w-quote'),(991871,'deals','.w-quote .image','width','70','','','.w-quote'),(991872,'deals','.w-quote .cart-box-link','width','40','5639,3','','.w-quote'),(991873,'deals','.b-quantity .qty-box .bigger','width','50','','','.b-quantity'),(991874,'deals','.b-quantity .qty-box .smaller','width','50','','','.b-quantity'),(991875,'deals','.b-quantity .qty-box input','width','60','','','.b-quantity'),(991876,'deals','.b-quantity .qty-input input','width','40','','','.b-quantity'),(991877,'deals','.w-product-sale-ends .left-count','width','23','','','.w-product-sale-ends'),(991878,'deals','.w-product-sale-ends .left-text-left','width','24','','','.w-product-sale-ends'),(991879,'deals','.w-product-sale-ends .left-text-right','width','24','','','.w-product-sale-ends'),(991880,'deals','.w-product-buttons .notify-form input','width','100','','','.w-product-buttons'),(991881,'deals','.w-product-bonus-points > div > div','width','100','','','.w-product-bonus-points'),(991882,'deals','.warrantyProduct .warranty','width','35','3','','.warrantyProduct'),(991883,'deals','.warrantyProduct .delivery','width','37','3','','.warrantyProduct'),(991884,'deals','.w-compare .image','width','70','','','.w-compare'),(991885,'deals','.w-files-catalog-widgets-files-catalog .item','width','18','','','.w-files-catalog-widgets-files-catalog'),(991886,'deals','.w-files-catalog-widgets-files-catalog .item','width','23','5644','','.w-files-catalog-widgets-files-catalog'),(991887,'deals','.w-files-catalog-widgets-files-catalog .item','width','31','5639','','.w-files-catalog-widgets-files-catalog'),(991888,'deals','.w-files-catalog-widgets-files-catalog .item','width','48','5630','','.w-files-catalog-widgets-files-catalog'),(991889,'deals','.w-sample .cart-box-link','width','10','4','','.w-sample'),(991890,'deals','.w-sample .cart-box-link','width','48','3','','.w-sample'),(991891,'deals','.w-sample .image','width','70','','','.w-sample'),(991892,'deals','.w-sample .cart-box-link','width','40','5639,3','','.w-sample'),(991893,'deals','.w-quote .cart-box.hover-box .cart-content','width','410','','','.w-quote'),(991894,'deals','.w-sample .cart-box .cart-content','width','410','','','.w-sample'),(991895,'deals','.w-cart-sub-total .price-row','width','100','','','.w-cart-sub-total'),(991896,'deals','.w-cart-sub-total .price-row > div','width','50','','','.w-cart-sub-total'),(991897,'deals','.w-cart-gift-certificate .gift-code input','width','100','','','.w-cart-gift-certificate'),(991898,'deals','.w-cart-gift-certificate .input-apple','width','100','','','.w-cart-gift-certificate'),(991899,'deals','.w-cart-gift-certificate .input-apple div','width','100','','','.w-cart-gift-certificate'),(991900,'deals','.w-cart-order-reference .input-apple','width','100','','','.w-cart-order-reference'),(991901,'deals','.w-cart-order-reference .input-apple div','width','100','','','.w-cart-order-reference'),(991902,'deals','.w-cart-order-reference .input-apple div input','width','100','','','.w-cart-order-reference'),(991903,'deals','.w-product-bundle .attributes-item','width','48','','','.w-product-bundle'),(991904,'deals','.w-product-bundle .attributes-select','width','100','','','.w-product-bundle'),(991905,'deals','.w-product-bundle .bundle_image','width','30','','','.w-product-bundle'),(991906,'deals','.w-product-bundle .bundle_item','width','30','','','.w-product-bundle'),(991907,'deals','.w-product-bundle .bundle_item','width','48','5639','','.w-product-bundle'),(991908,'deals','.w-product-bundle .bundle_item','width','100','5630','','.w-product-bundle'),(991909,'deals','.w-product-in-bundles .attributes-item','width','48','','','.w-product-in-bundles'),(991910,'deals','.w-product-in-bundles .attributes-select','width','100','','','.w-product-in-bundles'),(991911,'deals','.w-product-in-bundles .bundle_item','width','48','5639','','.w-product-in-bundles'),(991912,'deals','.w-product-in-bundles .bundle_item','width','100','5630','','.w-product-in-bundles'),(991913,'deals','.w-product-in-bundles .bundle_image','width','30','','','.w-product-in-bundles'),(991914,'deals','.w-product-in-bundles .bundle_item','width','30','','','.w-product-in-bundles'),(991915,'deals','.w-catalog-additional-images img','width','auto','','','.w-catalog-additional-images'),(991916,'deals','.w-catalog-additional-images picture','width','150','','','.w-catalog-additional-images'),(991917,'deals','.w-product-quantity-discounts .item','width','48','','','.w-product-quantity-discounts'),(991918,'deals','.w-product-multi-inventory .select-box:nth-child(2n)','width','48','','','.w-product-multi-inventory'),(991919,'deals','.w-product-multi-inventory .select-box:nth-child(2n+1)','width','48','','','.w-product-multi-inventory'),(991920,'deals','.p-quote-checkout-index .datepicker-inline','width','280','','','.p-quote-checkout-index'),(991921,'deals','.p-sample-checkout-index .datepicker-inline','width','280','','','.p-sample-checkout-index'),(991922,'deals','.p-sample-checkout-index .order-summary .heading-2','width','100','3','','.p-sample-checkout-index'),(991923,'deals','.p-sample-checkout-index .order-summary .heading-2','width','100','4','','.p-sample-checkout-index'),(991925,'deals','.w-product-multi-inventory .radio-attributes > label','width','33.3333','','','.w-product-multi-inventory'),(991926,'deals','.w-product-multi-inventory .radio-attributes .option-item','width','100','','','.w-product-multi-inventory'),(991927,'deals','.w-product-multi-inventory .radio-attributes > label','width','50','5644','','.w-product-multi-inventory'),(991928,'deals','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width','65','5644','','.b-products-listing'),(991929,'deals','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width','35','5644','','.b-products-listing'),(991930,'deals','.b-products-listing .products-listing .radio-attributes .option','width','100','','','.b-products-listing'),(991931,'deals','.b-products-listing .products-listing .radio-attributes > label','width','50','','','.b-products-listing'),(991932,'deals','.w-product-collection .chosen-products','width','48','','','.w-product-collection'),(991933,'deals','.w-product-collection .current-product','width','25','','','.w-product-collection'),(991934,'deals','.w-product-collection .right-area','width','25','','','.w-product-collection'),(991935,'deals','.w-product-collection .select-box select','width','100','','','.w-product-collection'),(991936,'deals','.w-product-collection .current-product, .w-product-collection .chosen-products','width','100','5639','','.w-product-collection'),(991937,'deals','.w-product-collection .right-area','width','100','5639','','.w-product-collection'),(991938,'deals','.w-product-attributes .radio-attributes .option-item','width','100','','','.w-product-attributes'),(991939,'deals','.w-product-attributes .radio-attributes > label','width','33.3333','','','.w-product-attributes'),(991940,'deals','.w-product-attributes .select-box:nth-child(2n)','width','48','','','.w-product-attributes'),(991941,'deals','.w-product-attributes .select-box:nth-child(2n+1)','width','48','','','.w-product-attributes'),(991942,'deals','.w-product-attributes .radio-attributes > label','width','50','5644','','.w-product-attributes'),(991943,'deals','.w-product-properties .properties-table','width','100','','','.w-product-properties'),(991944,'deals','.w-product-properties .property-ul','width','100','','','.w-product-properties'),(991945,'deals','.w-product-properties li','width','50','','','.w-product-properties'),(991946,'deals','.w-questionnaire-widgets-questionnaire .answer-yes-no span','width','40','','','.w-questionnaire-widgets-questionnaire'),(991947,'deals','.w-product-groups .radioBox label','width','50','5660','','.w-product-groups'),(991948,'deals','.b-products-listing .mix-attributes .mult-qty-input .qty-box > span','width','35','','','.b-products-listing'),(991949,'deals','.b-products-listing .mix-attributes .mult-qty-input .qty-box > input','width','60','','','.b-products-listing'),(991950,'deals','.w-product-custom-bundle .chosen-products','width','50','','','.w-product-custom-bundle'),(991951,'deals','.w-product-custom-bundle .current-product','width','25','','','.w-product-custom-bundle'),(991952,'deals','.w-product-custom-bundle .right-area','width','25','','','.w-product-custom-bundle'),(991953,'deals','.w-product-custom-bundle .select-box select','width','100','','','.w-product-custom-bundle'),(991954,'deals','.w-product-custom-bundle .chosen-products','width','100','5639','','.w-product-custom-bundle'),(991955,'deals','.w-product-custom-bundle .right-area','width','100','5639','','.w-product-custom-bundle'),(991956,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width','25','','','.w-catalog-pages-category-pages-last-list'),(991957,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width','33.33','5639','','.w-catalog-pages-category-pages-last-list'),(991958,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width','50','5630','','.w-catalog-pages-category-pages-last-list'),(991959,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width','25','','','.w-catalog-pages-category-pages-last-list-block'),(991960,'deals','.w-delivery-location-top-location-list .deliveryList li','width','48','','','.w-delivery-location-top-location-list'),(991961,'deals','.w-delivery-location-location-list .deliveryList li','width','23','','','.w-delivery-location-location-list'),(991962,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width','33.33','5639','','.w-catalog-pages-category-pages-last-list-block'),(991963,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width','50','5630','','.w-catalog-pages-category-pages-last-list-block'),(991964,'deals','.w-delivery-location-location-list .deliveryList li','width','31.333','5639','','.w-delivery-location-location-list'),(991965,'deals','.w-delivery-location-location-list .deliveryList li','width','48','5630','','.w-delivery-location-location-list'),(991966,'deals','.w-delivery-location-top-location-list .deliveryList li','width','100','5630','','.w-delivery-location-top-location-list'),(991967,'deals','.w-delivery-location-featured-list .deliveryList > ul > li','width','48','','','.w-delivery-location-featured-list'),(991968,'deals','.w-delivery-location-featured-list .deliveryList > ul > li','width','100','5660','','.w-delivery-location-featured-list'),(991969,'deals','.w-sale-category .badge','width','80','','','.w-sale-category'),(991970,'deals','.w-sale-category .holder-1','width','25','','','.w-sale-category'),(991971,'deals','.w-sale-category .holder-2','width','25','','','.w-sale-category'),(991972,'deals','.w-sale-category .image','width','50','','','.w-sale-category'),(991973,'deals','.w-sale-category .left-count','width','23','','','.w-sale-category'),(991974,'deals','.w-sale-category .left-text-left','width','24','','','.w-sale-category'),(991975,'deals','.w-sale-category .left-text-right','width','24','','','.w-sale-category'),(991976,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width','25','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(991977,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width','50','5630','','.w-catalog-pages-category-pages-last-list-by-catalog'),(991978,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width','25','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(991979,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width','50','5630','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(991980,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width','33.33','5639','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(991981,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width','33.33','5639','','.w-catalog-pages-category-pages-last-list-by-catalog'),(991982,'deals','.w-delivery-location-list-by-page .item','width','31.333','','','.w-delivery-location-list-by-page'),(991983,'deals','.w-delivery-location-list-by-page .item','width','48','5639','','.w-delivery-location-list-by-page'),(991984,'deals','.w-delivery-location-list-by-page .item','width','100','5660','','.w-delivery-location-list-by-page'),(991985,'deals','.w-product-properties-icons .hover-box-content','width','100','','','.w-product-properties-icons'),(991986,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','width','200','','','.w-product-properties-icons'),(991987,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','width','100','5660','','.w-product-properties-icons'),(991988,'deals','.w-delivery-location-cross-pages .item','width','31.333','','','.w-delivery-location-cross-pages'),(991989,'deals','.w-delivery-location-cross-pages .item','width','48','5639','','.w-delivery-location-cross-pages'),(991990,'deals','.w-delivery-location-cross-pages .item','width','100','5660','','.w-delivery-location-cross-pages'),(991991,'deals','.w-delivery-location-product-categories .item.category-link','width','25','','','.w-delivery-location-product-categories'),(991992,'deals','.w-delivery-location-product-categories .item.category-link','width','33.3333','5639','','.w-delivery-location-product-categories'),(991993,'deals','.w-delivery-location-product-categories .item.category-link','width','100','5660','','.w-delivery-location-product-categories'),(991994,'deals','.w-delivery-location-product-categories .item.category-link','width','50','5630','','.w-delivery-location-product-categories'),(991995,'deals','.w-catalog-delivery-locations .item','width','48','','','.w-catalog-delivery-locations'),(991996,'deals','.w-catalog-delivery-locations .item','width','100','5630','','.w-catalog-delivery-locations'),(991997,'deals','.delivery-options-popup .datepicker-inline','width','220','','',''),(991998,'deals','.w-product-bonus-points .bonus-points-cost','width','100','','','.w-product-bonus-points'),(991999,'deals','.w-product-designer-designer .productDesignerBox input','width','100','','','.w-product-designer-designer'),(992000,'deals','.w-product-designer-designer .prodDesignerType label','width','82','','','.w-product-designer-designer'),(992001,'deals','.w-product-designer-designer .prodDesignerType','width','100','','','.w-product-designer-designer'),(992002,'deals','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','width','30','','','.w-press-reviews-widgets-press-reviews-small'),(992003,'deals','.w-press-reviews-widgets-press-reviews-small .small-press-review','width','70','','','.w-press-reviews-widgets-press-reviews-small'),(992004,'deals','.w-press-reviews-widgets-press-reviews .sub-box','width','300','','','.w-press-reviews-widgets-press-reviews'),(992005,'deals','.w-gift-wrap-message-checkout .text','width','calc(100$ - 100px)','','','.w-gift-wrap-message-checkout'),(992006,'deals','.w-support-system-listing .product_icon','width','40','','','.w-support-system-listing'),(992007,'deals','.w-rma-returns-history .content-messages .messages-table .bottom select','width','auto','','','.w-rma-returns-history'),(992008,'deals','.w-rma-returns-history .dataTables_paginate a.paginate_button.previous, .w-rma-returns-history .dataTables_paginate a.paginate_button.next','width','35','','','.w-rma-returns-history'),(992009,'deals','.w-rma-returns-history input[type=\'text\'], .w-rma-returns-history input[type=\'password\'], .w-rma-returns-history input[type=\'number\'], .w-rma-returns-history input[type=\'email\'], .w-rma-returns-history input[type=\'search\'], .w-rma-returns-history select','width','100','','','.w-rma-returns-history'),(992010,'deals','.w-rma-returns-history thead tr td:first-child','width','300','','','.w-rma-returns-history'),(992011,'deals','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(992012,'deals','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(992013,'deals','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','width','100','','','.b-menu-position'),(992014,'deals','.w-product-configurator .item-content','width','calc(100% - 300px)','','','.w-product-configurator'),(992015,'deals','.w-product-configurator .pc_details','width','60','','','.w-product-configurator'),(992016,'deals','.w-product-configurator .pc_item','width','300','','','.w-product-configurator'),(992017,'deals','.w-product-configurator .pc_item select','width','100','','','.w-product-configurator'),(992018,'deals','.w-product-configurator .pc_price','width','150','','','.w-product-configurator'),(992019,'deals','.w-product-configurator .pc_qty','width','150','','','.w-product-configurator'),(992020,'deals','.w-product-configurator .pc_stock','width','150','','','.w-product-configurator'),(992021,'deals','.w-product-configurator .item-content','width','100','5639','','.w-product-configurator'),(992022,'deals','.w-product-configurator .pc_item','width','100','5639','','.w-product-configurator'),(992023,'deals','.b-products-listing .products-listing .bonus-points-cost','width','100','','','.b-products-listing'),(992024,'deals','.b-products-listing .promo-icon','width','60','','','.b-products-listing'),(992025,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width','25','','','.w-catalog-pages-category-pages-list'),(992026,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width','33.33','5639','','.w-catalog-pages-category-pages-list'),(992027,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width','50','5630','','.w-catalog-pages-category-pages-list'),(992028,'deals','.w-predefined-promotion .icon','width','45','','','.w-predefined-promotion'),(992029,'deals','.w-predefined-promotion .nextdiscount .item-holder .image','width','40','','','.w-predefined-promotion'),(992030,'deals','.w-predefined-promotion .nextdiscount .item-holder .name','width','60','','','.w-predefined-promotion'),(992031,'deals','.w-predefined-promotion .prom-multi-discount .image img','width','auto','','','.w-predefined-promotion'),(992032,'deals','.w-predefined-promotion .prom-multi-discount .list','width','100','','','.w-predefined-promotion'),(992033,'deals','.w-predefined-promotion .promo-cart-discount .image img','width','auto','','','.w-predefined-promotion'),(992034,'deals','.w-predefined-promotion .promo-cart-discount .master .item','width','calc(50% - 24px)','','','.w-predefined-promotion'),(992035,'deals','.w-predefined-promotion .promo-cart-discount .slave .item','width','calc(50% - 4px)','','','.w-predefined-promotion'),(992036,'deals','.w-predefined-promotion .promo-cart-discount > div','width','50','','','.w-predefined-promotion'),(992037,'deals','.w-predefined-promotion .promo-salemaker .image img','width','auto','','','.w-predefined-promotion'),(992038,'deals','.w-predefined-promotion .promo-salemaker .item','width','50','','','.w-predefined-promotion'),(992039,'deals','.w-predefined-promotion .promo-salemaker > div','width','50','','','.w-predefined-promotion'),(992041,'deals','.headerWrap .searchIcon','width','22','3','','.headerWrap'),(992043,'deals','.w-subscribers .left_box','width','40','','','.w-subscribers'),(992044,'deals','.w-subscribers .right_box','width','60','','','.w-subscribers'),(992045,'deals','.w-subscribers .sb_tc','width','90','','','.w-subscribers'),(992046,'deals','.w-subscribers .sb_tc + .sb_tc','width','130','','','.w-subscribers'),(992047,'deals','.filterLine .before','width','132','','','.filterLine'),(992048,'deals','.filterLine .w-catalog-sorting','width','25','','','.filterLine'),(992049,'deals','.filterLine .w-filters','width','75','','','.filterLine'),(992050,'deals','.filterLine > .block','width','100','','','.filterLine'),(992051,'deals','.w-filters .filter-widget-horizontal .filter-box-content','width','250','','','.w-filters'),(992052,'deals','.filterLine .w-catalog-sorting .sort-select','width','calc(100% - 132px)','','','.filterLine'),(992053,'deals','.b-quantity .qty-box input[type=\'text\']','width','60','','','.b-quantity'),(992054,'deals','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','width','100','','','.w-product-buttons'),(992055,'deals','.w-product-quantity-discounts .quantity-discounts-content .item','width','48','','','.w-product-quantity-discounts'),(992056,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span','width','100','','','.w-product-quantity-discounts'),(992057,'deals','.w-cart-listing .qty-box .bigger, .w-cart-listing .qty-box .smaller','width','30','','','.w-cart-listing'),(992058,'deals','.w-cart-listing .qty-box input[type=\'text\']','width','40','','','.w-cart-listing'),(992059,'deals','.w-cart-listing .points-earn','width','80','','','.w-cart-listing'),(992060,'deals','.w-support-system-listing .tp-head','width','auto','','','.w-support-system-listing'),(992061,'deals','.homeBanner .carousel .bottom-center > span','width','100','','','.homeBanner'),(992063,'deals','.bannersWrap .box-block.type-12 > .block:nth-child(1)','width','100','5630','','.bannersWrap'),(992064,'deals','.bannersWrap .box-block.type-12 > .block:nth-child(2)','width','100','5630','','.bannersWrap'),(992065,'deals','.w-top-categories .item','width','calc(25% - 20px)','5644','','.w-top-categories'),(992066,'deals','.w-subscribers .left_box, .w-subscribers .right_box','width','100','5630','','.w-subscribers'),(992067,'deals','.w-categories .item','width','calc(25% - 20px)','5644','','.w-categories'),(992068,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','width','100','5639','','.w-filters'),(992069,'deals','.filterLine .w-filters','width','50','5639','','.filterLine'),(992070,'deals','.filterLine .w-catalog-sorting','width','50','5639','','.filterLine'),(992071,'deals','.w-filters .filter-widget-horizontal .filter-box-content','width','96','5639','','.w-filters'),(992072,'deals','.filterLine .w-filters, .filterLine .w-catalog-sorting','width','100','5660','','.filterLine'),(992073,'deals','.b-products-listing .products-listing.list-productlisting .attributes select','width','100','','','.b-products-listing'),(992074,'deals','.b-products-listing .products-listing.list-productlisting .radio-attributes > label','width','100','','','.b-products-listing'),(992076,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','width','100','5630','','.headerWrap'),(992077,'deals','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','width','100','','','.w-account-personal-catalog'),(992078,'deals','.w-account-personal-catalog .w-cart-listing .item .image','width','110','5630','','.w-account-personal-catalog'),(992079,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li','width','33.3333','','','.preFooter'),(992080,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li','width','100','5630','','.preFooter'),(992081,'deals','.w-product-wishlist-button .btn','width','110','','','.w-product-wishlist-button'),(992082,'deals','.w-product-wishlist-button .btn','width','100','5630','','.w-product-wishlist-button'),(992083,'deals','.w-catalog-compare .cross-box','width','100','','','.w-catalog-compare'),(992084,'deals','.homeBanner .banner-item .banner-text-holder','width','100','','','.homeBanner'),(992085,'deals','.w-promotions-widgets-promotion-icons-desc .promo-icon','width','20','','','.w-promotions-widgets-promotion-icons-desc'),(992086,'deals','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','width','75','','','.w-promotions-widgets-promotion-icons-desc'),(992087,'deals','.w-cart-shipping-estimator .left-area','width','100','5630','','.w-cart-shipping-estimator'),(992088,'deals','.w-cart-shipping-estimator .right-area','width','100','5630','','.w-cart-shipping-estimator'),(992089,'deals','.w-promotions-widgets-promotions .products .item','width','260','','','.w-promotions-widgets-promotions'),(992090,'deals','.w-promotions-widgets-promotions .select-box','width','45','','','.w-promotions-widgets-promotions'),(992107,'deals','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','width','48','','','.account-address-book'),(992108,'deals','.account-address-book .address_book_row .column','width','100','5630','','.account-address-book'),(992109,'deals','.account-address-book .address_book_row .column + .column','width','100','5630','','.account-address-book'),(992110,'deals','.account-address-book .topInfo > div','width','100','5630','','.account-address-book'),(992111,'deals','.account-address-book .topInfo > div + div','width','100','5630','','.account-address-book'),(992118,'deals','.account-order-pay .history_info > div','width','33.3','','','.account-order-pay'),(992119,'deals','.account-order-pay .not_fully_paid_td','width','300','','','.account-order-pay'),(992120,'deals','.account-order-pay .history_info > div','width','100','5639','','.account-order-pay'),(992121,'deals','.account-samples .not_fully_paid_td','width','300','','','.account-samples'),(992122,'deals','.account-samples .orders-table .hidden','width','130','5639','','.account-samples'),(992123,'deals','.account-samples .orders-table .td-alignright','width','100','5639','','.account-samples'),(992124,'deals','.account-sample-info .history_info > div','width','33.3','','','.account-sample-info'),(992125,'deals','.account-sample-info .not_fully_paid_td','width','300','','','.account-sample-info'),(992126,'deals','.account-sample-info .history_info > div','width','100','5639','','.account-sample-info'),(992127,'deals','.catalog-product-wrap .pn-image','width','24','3','','.catalog-product-wrap'),(992128,'deals','.catalog-product-wrap .prev-next-product','width','190','','','.catalog-product-wrap'),(992129,'deals','.catalog-product-wrap .next-product','width','60','5639','','.catalog-product-wrap'),(992130,'deals','.catalog-product-wrap .prev-product','width','60','5639','','.catalog-product-wrap'),(992131,'deals','.checkout-index-wrap .datepicker-inline','width','280','','','.checkout-index-wrap'),(992132,'deals','.checkout-index-wrap .dob-hide > div','width','48','','','.checkout-index-wrap'),(992133,'deals','.checkout-index-wrap .edit-address-popup','width','1000','','','.checkout-index-wrap'),(992134,'deals','.checkout-index-wrap .edit-address-popup .addresses .address-item','width','33','','','.checkout-index-wrap'),(992135,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons','width','100','','','.checkout-index-wrap'),(992136,'deals','.checkout-index-wrap .order-summary2 .btn-2','width','100','','','.checkout-index-wrap'),(992137,'deals','.checkout-order-confirmation .order-summary2 .btn-2','width','100','','','.checkout-order-confirmation'),(992138,'deals','.checkout-login-wrap .col-left, .checkout-login-wrap .col-right','width','100','','','.checkout-login-wrap'),(992139,'deals','.checkout-login-wrap .middle-form .btn-2','width','100','','','.checkout-login-wrap'),(992140,'deals','.b-form .password-row, .b-form .col-gender','width','100','','','.b-form'),(992141,'deals','.b-form .center-buttons','width','100','','','.b-form'),(992142,'deals','.b-slick .slick-dots li','width','10','3','','.b-slick'),(992143,'deals','.hide-page','width','100','','',''),(992144,'deals','.success-page .w-cart-listing .qty','width','24','','','.success-page'),(992146,'deals','.w-cart-products .checkout-cart-listing .w-cart-listing .price','width','165','','','.w-cart-products'),(992147,'deals','.w-cart-products .checkout-cart-listing .w-cart-listing .qty','width','50','','','.w-cart-products'),(992148,'deals','.b-multi-page-checkout .multi-page-checkout .checkout-heading .count','width','33','','','.b-multi-page-checkout'),(992149,'deals','.b-multi-page-checkout .multi-page-checkout .past .checkout-heading','width','35','3','','.b-multi-page-checkout'),(992150,'deals','.bannersWrap .leftBanner .banner-text','width','50','','','.bannersWrap'),(992151,'deals','.checkout-index-wrap .w-cart-products .checkout-cart-listing .w-cart-listing .price','width','auto','','','.checkout-index-wrap'),(992154,'deals','.footer-menu .level-2 > li','width','100','5644','','.footer-menu'),(992155,'deals','.footer-menu .level-3 > li','width','100','5639','','.footer-menu'),(992156,'deals','.accout-box select[data-type=\"vat_number\"]','width','40','','','.accout-box'),(992157,'deals','.w-account-customer-additional-field .field-type-checkbox label','width','40','','','.w-account-customer-additional-field'),(992158,'deals','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width','60','','','.w-account-customer-additional-field'),(992159,'deals','.w-account-customer-additional-field .field-type-text label','width','40','','','.w-account-customer-additional-field'),(992160,'deals','.w-banner .banner-text-holder','width','100','','','.w-banner'),(992161,'deals','.w-banner .carousel-text','width','100','','','.w-banner'),(992162,'deals','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width','100','','','.w-banner'),(992163,'deals','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width','100','','','.w-banner'),(992164,'deals','.w-catalog-paging .paging-holder','width','150','','','.w-catalog-paging'),(992165,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width','30','','','.w-catalog-paging'),(992170,'deals','.w-menu-slider .menu-ico','width','54','','','.w-menu-slider'),(992171,'deals','.w-menu-slider > ul > li > ul','width','100','','','.w-menu-slider'),(992172,'deals','.b-warehouses-popup .warehouses-popup','width_important','important','','','.b-warehouses-popup'),(992175,'deals','.b-messages .pre_upload','width_important','important','','','.b-messages'),(992176,'deals','.b-switch .bootstrap-switch.bootstrap-switch-on .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-off .bootstrap-switch-label','width_important','important','3','','.b-switch'),(992177,'deals','.b-switch .bootstrap-switch.bootstrap-switch-off .bootstrap-switch-label, .b-switch .bootstrap-switch.bootstrap-switch-inverse.bootstrap-switch-on .bootstrap-switch-label','width_important','important','3','','.b-switch'),(992180,'deals','.b-select-suggest .select2-offscreen, .b-select-suggest .select2-offscreen:focus','width_important','important','','','.b-select-suggest'),(992181,'deals','.w-checkout-credit-amount .cot_gv_amount','width_important','important','','','.w-checkout-credit-amount'),(992184,'deals','.w-checkout-bonus-points .bonus_points_amount','width_important','important','','','.w-checkout-bonus-points'),(992185,'deals','.w-coupons-and-vauchers-checkout input[type=\"text\"]','width_important','important','','','.w-coupons-and-vauchers-checkout'),(992190,'deals','.w-cart-discount-coupon input[type=\"text\"]','width_important','important','','','.w-cart-discount-coupon'),(992191,'deals','.w-cart-credit-amount input[type=\"text\"]','width_important','important','','','.w-cart-credit-amount'),(992194,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_important','important','','','.b-menu-open_from-left'),(992195,'deals','.w-cart-bonus-points .bonus_points_amount','width_important','important','','','.w-cart-bonus-points'),(992196,'deals','.w-rma-returns-history thead tr td:first-child','width_important','important','','','.w-rma-returns-history'),(992197,'deals','.w-catalog-compare .cross-box','width_important','important','','','.w-catalog-compare'),(992198,'deals','.checkout-index-wrap .edit-address-popup','width_important','important','','','.checkout-index-wrap'),(992199,'deals','.footer-menu .level-2 > li','width_important','important','5644','','.footer-menu'),(992200,'deals','.accout-box select[data-type=\"vat_number\"]','width_important','important','','','.accout-box'),(992201,'deals','.w-catalog-paging button.slick-prev, .w-catalog-paging button.slick-next','width_important','important','','','.w-catalog-paging'),(992202,'deals','.b-form .col-right','width_measure','%','5639','','.b-form'),(992203,'deals','.b-form .login-col-2','width_measure','%','','','.b-form'),(992204,'deals','.order-summary .btn-2, .order-summary .btn-3','width_measure','%','','','.order-summary'),(992205,'deals','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(992206,'deals','.w-promotions .promo-salemaker > div','width_measure','%','','','.w-promotions'),(992207,'deals','.w-promotions .promo-cart-discount > div','width_measure','%','','','.w-promotions'),(992210,'deals','.p-sample-checkout-login .col-left, .p-sample-checkout-login .col-right','width_measure','%','','','.p-sample-checkout-login'),(992211,'deals','.w-promotions .prom-multi-discount .list','width_measure','%','','','.w-promotions'),(992212,'deals','.w-promotions .nextdiscount .item-holder .name','width_measure','%','','','.w-promotions'),(992213,'deals','.w-promotions .nextdiscount .item-holder .image','width_measure','%','','','.w-promotions'),(992214,'deals','.w-promotions .promo-salemaker .item','width_measure','%','','','.w-promotions'),(992215,'deals','.b-preloader .preloader','width_measure','%','','','.b-preloader'),(992216,'deals','.b-products-listing .products-listing .attribute-qty-block','width_measure','%','','','.b-products-listing'),(992217,'deals','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(992218,'deals','.w-cart-continue-btn a','width_measure','%','5630','','.w-cart-continue-btn'),(992219,'deals','.b-messages .box-block.type-6 > .block:nth-child(1)','width_measure','%','','','.b-messages'),(992220,'deals','.b-messages .messages-sidebar .btn-2','width_measure','%','','','.b-messages'),(992221,'deals','.b-messages .email-line input','width_measure','%','','','.b-messages'),(992222,'deals','.w-sitemap-delivery-location > ul > li > ul > li','width_measure','%','','','.w-sitemap-delivery-location'),(992223,'deals','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(992224,'deals','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(992225,'deals','.p-payer-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-confirmation'),(992226,'deals','.p-payer-order-confirmation .dob-hide > div','width_measure','%','','','.p-payer-order-confirmation'),(992227,'deals','.p-payer-order-pay .order-summary2 .btn-2','width_measure','%','','','.p-payer-order-pay'),(992228,'deals','.p-payer-order-pay .dob-hide > div','width_measure','%','','','.p-payer-order-pay'),(992229,'deals','.w-checkout-terms .required-message','width_measure','%','','','.w-checkout-terms'),(992230,'deals','.b-form .checkbox-style:checked + .checkbox-span','width_measure','x','','','.b-form'),(992231,'deals','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(992232,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(992233,'deals','.w-upload-customer-id-upload-customer-id-form .dz-details','width_measure','%','','','.w-upload-customer-id-upload-customer-id-form'),(992234,'deals','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(992235,'deals','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(992236,'deals','.w-login-block .input','width_measure','%','','','.w-login-block'),(992237,'deals','.w-login-block .guest','width_measure','%','','','.w-login-block'),(992238,'deals','.w-login-block .new','width_measure','%','','','.w-login-block'),(992239,'deals','.w-login-block .returning','width_measure','%','','','.w-login-block'),(992240,'deals','.w-cart-order-total.box','width_measure','%','5630','','.w-cart-order-total'),(992241,'deals','.w-cart-give-away .ga_attributes select','width_measure','%','','','.w-cart-give-away'),(992242,'deals','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(992243,'deals','.b-email .totals-title','width_measure','%','','','.b-email'),(992244,'deals','.b-email .totals-table','width_measure','%','','','.b-email'),(992245,'deals','.w-login-block .input','width_measure','%','','','.w-login-block'),(992246,'deals','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(992247,'deals','.w-cart-order-total.box','width_measure','%','5630','','.w-cart-order-total'),(992248,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(992249,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(992250,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(992251,'deals','.pop-up-content .buttons .btn','width_measure','%','5639','',''),(992252,'deals','.pop-up-content .buttons .right-buttons','width_measure','%','5639','',''),(992253,'deals','.pop-up-content .buttons .btn-2','width_measure','%','5639','',''),(992254,'deals','.pop-up-content .buttons .left-buttons','width_measure','%','5639','',''),(992255,'deals','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(992256,'deals','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(992257,'deals','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(992258,'deals','.w-login-block .input','width_measure','%','','','.w-login-block'),(992259,'deals','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(992260,'deals','.w-filters .ui-slider','width_measure','%','','','.w-filters'),(992261,'deals','.w-cart-give-away .ga_column','width_measure','%','','','.w-cart-give-away'),(992263,'deals','.w-promo-code .promo-text','width_measure','%','5639','','.w-promo-code'),(992264,'deals','.w-tabs .tab-navigation','width_measure','%','','','.w-tabs'),(992265,'deals','.p-quote-checkout-login .col-left, .p-quote-checkout-login .col-right','width_measure','%','','','.p-quote-checkout-login'),(992266,'deals','.b-products-listing .select-attributes select','width_measure','%','','','.b-products-listing'),(992267,'deals','.w-cart-listing .right-area','width_measure','%','5639','','.w-cart-listing'),(992268,'deals','.p-quick-order-index .all-scroll-div','width_measure','%','','','.p-quick-order-index'),(992269,'deals','.w-cart-order-total.box','width_measure','%','5630','','.w-cart-order-total'),(992270,'deals','.view-all','width_measure','%','3','',''),(992271,'deals','.b-form .columns .col-2','width_measure','%','','','.b-form'),(992272,'deals','.b-email .totals-title','width_measure','%','','','.b-email'),(992273,'deals','.w-cart-order-total.box','width_measure','%','5630','','.w-cart-order-total'),(992275,'deals','.b-bottom .popup-box.popupCompare','width_measure','%','','','.b-bottom'),(992276,'deals','.w-cart-order-total.box','width_measure','%','5630','','.w-cart-order-total'),(992277,'deals','.w-promo-code .promo-text','width_measure','%','5639','','.w-promo-code'),(992278,'deals','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(992279,'deals','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(992280,'deals','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(992281,'deals','.b-form .login-col-1','width_measure','%','','','.b-form'),(992282,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(992283,'deals','.b-email .products-table','width_measure','%','','','.b-email'),(992284,'deals','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(992285,'deals','.w-list-b2b .select-attributes','width_measure','%','','','.w-list-b2b'),(992286,'deals','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(992287,'deals','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(992288,'deals','.w-checkout-shipping-choice label','width_measure','%','','','.w-checkout-shipping-choice'),(992289,'deals','.b-products-listing .btn-choose-options','width_measure','%','','','.b-products-listing'),(992290,'deals','.b-email .products-table','width_measure','%','','','.b-email'),(992291,'deals','.w-checkout-create-account .col-2','width_measure','%','5639','','.w-checkout-create-account'),(992292,'deals','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(992293,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(992294,'deals','.b-email .products-table','width_measure','%','','','.b-email'),(992295,'deals','.b-email .totals-title','width_measure','%','','','.b-email'),(992296,'deals','.b-email .totals-value','width_measure','%','','','.b-email'),(992297,'deals','.b-email .totals-table','width_measure','%','','','.b-email'),(992298,'deals','.b-email .products-table','width_measure','%','','','.b-email'),(992299,'deals','.w-cart-continue-btn a','width_measure','%','5630','','.w-cart-continue-btn'),(992300,'deals','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(992301,'deals','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(992302,'deals','.w-promo-code .promo-code-form','width_measure','%','5639','','.w-promo-code'),(992303,'deals','.w-promo-code .promo-text','width_measure','%','5639','','.w-promo-code'),(992304,'deals','.b-form .columns .col-2','width_measure','%','5660','','.b-form'),(992305,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(992306,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(992307,'deals','.w-login-block .input','width_measure','%','','','.w-login-block'),(992308,'deals','.w-login-block .returning','width_measure','%','','','.w-login-block'),(992309,'deals','.w-login-block .new','width_measure','%','','','.w-login-block'),(992310,'deals','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(992311,'deals','.w-login-block .col-2:nth-child(2n + 1)','width_measure','%','','','.w-login-block'),(992312,'deals','.w-login-block .guest','width_measure','%','','','.w-login-block'),(992313,'deals','.b-form .col-left','width_measure','%','','','.b-form'),(992314,'deals','.w-cart-give-away .ga_attributes > div','width_measure','%','','','.w-cart-give-away'),(992315,'deals','.w-image-maps .svg-wrap svg','width_measure','%','','','.w-image-maps'),(992316,'deals','.b-form .form-inputs textarea, .b-form .form-inputs select, .b-form .form-inputs input[type=\"text\"], .b-form .form-inputs input[type=\"email\"], .b-form .form-inputs input[type=\"password\"]','width_measure','%','','','.b-form'),(992317,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(992318,'deals','.w-cart-listing .links','width_measure','%','','','.w-cart-listing'),(992319,'deals','.w-login-block .returning','width_measure','%','','','.w-login-block'),(992320,'deals','.w-login-block .col-2:nth-child(2n)','width_measure','%','','','.w-login-block'),(992321,'deals','.w-login-block .guest','width_measure','%','','','.w-login-block'),(992322,'deals','.w-login-block .new','width_measure','%','','','.w-login-block'),(992323,'deals','.w-cart-shipping-estimator .left-area','width_measure','%','','','.w-cart-shipping-estimator'),(992324,'deals','.b-form .col-right','width_measure','%','','','.b-form'),(992325,'deals','.b-email .totals-title','width_measure','%','','','.b-email'),(992326,'deals','.b-email .products-table','width_measure','%','','','.b-email'),(992327,'deals','.b-bottom .cart-options .option-item','width_measure','%','','','.b-bottom'),(992328,'deals','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(992329,'deals','.b-bottom .cart-options .cart-item','width_measure','%','','','.b-bottom'),(992330,'deals','.w-login-block .guest','width_measure','%','','','.w-login-block'),(992331,'deals','.b-email .totals-table','width_measure','%','','','.b-email'),(992332,'deals','.b-email .totals-value','width_measure','%','','','.b-email'),(992333,'deals','.w-promo-code .promo-text','width_measure','%','5639','','.w-promo-code'),(992334,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(992335,'deals','.w-login-block .returning','width_measure','%','','','.w-login-block'),(992336,'deals','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(992337,'deals','.w-cart-continue-btn a','width_measure','%','5630','','.w-cart-continue-btn'),(992338,'deals','.b-email .totals-value','width_measure','%','','','.b-email'),(992339,'deals','.b-form .col-left','width_measure','%','5639','','.b-form'),(992340,'deals','.b-form .middle-form .dob-input input[type=\"text\"]','width_measure','%','','','.b-form'),(992341,'deals','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(992342,'deals','.w-checkout-billing-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-billing-address'),(992343,'deals','.w-checkout-shipping-address .addresses.address-main .address-item','width_measure','%','','','.w-checkout-shipping-address'),(992344,'deals','.w-cart-order-total.box','width_measure','%','5630','','.w-cart-order-total'),(992345,'deals','.w-cart-continue-btn a','width_measure','%','5630','','.w-cart-continue-btn'),(992346,'deals','.w-promo-code .promo-text','width_measure','%','5639','','.w-promo-code'),(992347,'deals','.w-promo-code .promo-code-form','width_measure','%','5639','','.w-promo-code'),(992348,'deals','.w-promo-code .promo-text','width_measure','%','5639','','.w-promo-code'),(992349,'deals','.w-checkout-billing-address .addresses .address-item','width_measure','%','','','.w-checkout-billing-address'),(992350,'deals','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(992351,'deals','.b-products-listing .products-listing .buyButton .btn','width_measure','%','','','.b-products-listing'),(992352,'deals','.b-select-suggest .select2-search input','width_measure','%','','','.b-select-suggest'),(992353,'deals','.b-select-suggest .select2-search','width_measure','%','','','.b-select-suggest'),(992354,'deals','.b-select-suggest .select2-container .select2-choice .select2-arrow b','width_measure','%','','','.b-select-suggest'),(992355,'deals','.b-select-suggest .select2-drop','width_measure','%','','','.b-select-suggest'),(992356,'deals','.w-product-promotions .select-box','width_measure','%','','','.w-product-promotions'),(992357,'deals','.w-login-block .input','width_measure','%','','','.w-login-block'),(992358,'deals','.w-login-block .new','width_measure','%','','','.w-login-block'),(992359,'deals','.w-login-block .returning','width_measure','%','','','.w-login-block'),(992360,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(992362,'deals','.w-login-block .returning','width_measure','%','','','.w-login-block'),(992363,'deals','.w-cart-continue-btn a','width_measure','%','5630','','.w-cart-continue-btn'),(992364,'deals','.w-account-addresses-list .addsess-suggestion-item','width_measure','%','','','.w-account-addresses-list'),(992365,'deals','.b-products-listing .BlockBox.type-10 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992366,'deals','.b-products-listing .BlockBox.type-10 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992367,'deals','.b-products-listing .BlockBox.type-11 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992368,'deals','.b-products-listing .BlockBox.type-11 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992369,'deals','.b-products-listing .BlockBox.type-12 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992370,'deals','.b-products-listing .BlockBox.type-13 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992371,'deals','.b-products-listing .BlockBox.type-12 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992372,'deals','.b-products-listing .BlockBox.type-13 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992373,'deals','.b-products-listing .BlockBox.type-14 > .col','width_measure','%','','','.b-products-listing'),(992374,'deals','.b-products-listing .BlockBox.type-13 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(992375,'deals','.b-products-listing .BlockBox.type-15 > .col','width_measure','%','','','.b-products-listing'),(992376,'deals','.b-products-listing .BlockBox.type-3 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992377,'deals','.b-products-listing .BlockBox.type-2 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992378,'deals','.b-products-listing .BlockBox.type-3 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992379,'deals','.b-products-listing .BlockBox.type-2 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992380,'deals','.b-products-listing .BlockBox.type-4 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992381,'deals','.b-products-listing .BlockBox.type-5 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992382,'deals','.b-products-listing .BlockBox.type-4 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992383,'deals','.b-products-listing .BlockBox.type-3 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(992384,'deals','.b-products-listing .BlockBox.type-5 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992385,'deals','.b-products-listing .BlockBox.type-6 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992386,'deals','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992387,'deals','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992388,'deals','.b-products-listing .BlockBox.type-8 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992389,'deals','.b-products-listing .BlockBox.type-6 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992390,'deals','.b-products-listing .BlockBox.type-8 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992391,'deals','.b-products-listing .BlockBox.type-8 > .col:nth-child(3)','width_measure','%','','','.b-products-listing'),(992392,'deals','.b-products-listing .BlockBox.type-9 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992393,'deals','.b-products-listing .BlockBox.type-9 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992394,'deals','.b-products-listing .loader','width_measure','%','3','','.b-products-listing'),(992395,'deals','.b-products-listing .products-listing .attribute-qty-block > span','width_measure','%','','','.b-products-listing'),(992396,'deals','.b-products-listing .products-listing .attributes select','width_measure','%','','','.b-products-listing'),(992397,'deals','.b-products-listing .products-listing .btn-buy','width_measure','%','','','.b-products-listing'),(992398,'deals','.b-products-listing .products-listing .item','width_measure','%','','','.b-products-listing'),(992399,'deals','.w-catalog-b2b-add-button ','width_measure','%','','','.w-catalog-b2b-add-button'),(992400,'deals','.b-products-listing .products-listing .qty-input.hidden','width_measure','%','3','','.b-products-listing'),(992401,'deals','.b-products-listing .products-listing.list-type-1_2 .item, .b-products-listing .products-listing.list-type-2_2 .item, .b-products-listing .products-listing.list-type-1_3 .item','width_measure','%','','','.b-products-listing'),(992403,'deals','.b-products-listing .products-listing .in-cart','width_measure','%','','','.b-products-listing'),(992404,'deals','.b-select-suggest .select2-container','width_measure','%','','','.b-select-suggest'),(992405,'deals','.b-tracking-numbers .tracking-numbers .tracking-products','width_measure','%','','','.b-tracking-numbers'),(992406,'deals','.b-email .totals-table','width_measure','%','','','.b-email'),(992407,'deals','.b-email .totals-value','width_measure','%','','','.b-email'),(992408,'deals','.b-email .totals-title','width_measure','%','','','.b-email'),(992409,'deals','.b-fancybox .fancybox-image, .b-fancybox .fancybox-iframe','width_measure','%','','','.b-fancybox'),(992410,'deals','.w-promo-code .promo-code-form','width_measure','%','5639','','.w-promo-code'),(992411,'deals','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(992412,'deals','.w-communication-new-topic .middle-form select','width_measure','%','','','.w-communication-new-topic'),(992413,'deals','.b-form .hide-billing-address','width_measure','%','','','.b-form'),(992414,'deals','.b-email .totals-value','width_measure','%','','','.b-email'),(992415,'deals','.b-email .products-table','width_measure','%','','','.b-email'),(992416,'deals','.b-bottom .popup-credit-amount .popup-box','width_measure','%','','','.b-bottom'),(992417,'deals','.w-promo-code .promo-code-form','width_measure','%','5639','','.w-promo-code'),(992418,'deals','.w-login-block .new','width_measure','%','','','.w-login-block'),(992419,'deals','.w-promo-code .promo-text','width_measure','%','','','.w-promo-code'),(992420,'deals','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(992421,'deals','.b-compare .col-two label','width_measure','%','','','.b-compare'),(992422,'deals','.b-form .addresses .address-item','width_measure','%','','','.b-form'),(992423,'deals','.w-cart-continue-btn a','width_measure','%','5630','','.w-cart-continue-btn'),(992424,'deals','.w-cart-shipping-estimator .right-area','width_measure','%','','','.w-cart-shipping-estimator'),(992425,'deals','.w-cart-listing .right-area','width_measure','%','','','.w-cart-listing'),(992426,'deals','.w-cart-listing .item .remove','width_measure','%','5639','','.w-cart-listing'),(992427,'deals','.w-cart-give-away .ga_img','width_measure','%','','','.w-cart-give-away'),(992428,'deals','.w-cart-give-away .ga_column','width_measure','%','5630','','.w-cart-give-away'),(992429,'deals','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(992430,'deals','.b-fancybox .fancybox-nav','width_measure','%','','','.b-fancybox'),(992431,'deals','.w-promo-code .promo-code-form','width_measure','%','5639','','.w-promo-code'),(992432,'deals','.w-promo-code .promo-code-form','width_measure','%','','','.w-promo-code'),(992433,'deals','.w-login-block .input','width_measure','%','','','.w-login-block'),(992434,'deals','.w-login-block .new','width_measure','%','','','.w-login-block'),(992435,'deals','.w-login-block .guest','width_measure','%','','','.w-login-block'),(992436,'deals','.b-tracking-numbers .tracking-numbers .tracking-code-left','width_measure','%','','','.b-tracking-numbers'),(992437,'deals','.w-checkout-shipping-address .addresses .address-item','width_measure','%','','','.w-checkout-shipping-address'),(992438,'deals','.w-login-block .guest','width_measure','%','','','.w-login-block'),(992439,'deals','.w-filters .handle-from','width_measure','%','','','.w-filters'),(992440,'deals','.w-promo-code .promo-code-form','width_measure','%','5639','','.w-promo-code'),(992441,'deals','.w-brands .brands-listing > div','width_measure','%','','','.w-brands'),(992442,'deals','.w-filters .handle-to','width_measure','%','','','.w-filters'),(992443,'deals','.p-wedding-registry-search .search-list input','width_measure','%','','','.p-wedding-registry-search'),(992444,'deals','.b-compare .col-two select','width_measure','%','','','.b-compare'),(992445,'deals','.b-email .totals-table','width_measure','%','','','.b-email'),(992446,'deals','.b-form .col-3','width_measure','%','','','.b-form'),(992447,'deals','textarea','width_measure','%','','',''),(992448,'deals','.b-products-listing .products-listing .btn-preloader','width_measure','%','','','.b-products-listing'),(992449,'deals','.b-form .middle-form input[type=\"text\"], .b-form .middle-form input[type=\"email\"], .b-form .middle-form input[type=\"password\"], .b-form select','width_measure','%','','','.b-form'),(992450,'deals','.b-email .totals-title','width_measure','%','','','.b-email'),(992451,'deals','.b-email .totals-value','width_measure','%','','','.b-email'),(992452,'deals','.b-email .totals-table','width_measure','%','','','.b-email'),(992453,'deals','.w-filters .input-txt-keywords','width_measure','%','','','.w-filters'),(992454,'deals','.w-filters .input-txt','width_measure','%','','','.w-filters'),(992455,'deals','.b-menu-lev_display-slide .menu-style[data-lev2_display=\"slide\"] ul.level-2','width_measure','vw','','','.b-menu-lev_display-slide'),(992456,'deals','.b-menu-lev_display-slide .menu-style[data-lev3_display=\"slide\"] ul.level-3','width_measure','%','','','.b-menu-lev_display-slide'),(992457,'deals','.b-menu-lev_display-slide .menu-style[data-lev4_display=\"slide\"] ul.level-4','width_measure','vw','','','.b-menu-lev_display-slide'),(992458,'deals','.b-menu-lev_display-slide .menu-style[data-lev5_display=\"slide\"] ul.level-5','width_measure','vw','','','.b-menu-lev_display-slide'),(992459,'deals','.b-menu-lev_display-slide .menu-style[data-lev6_display=\"slide\"] ul.level-6','width_measure','vw','','','.b-menu-lev_display-slide'),(992460,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_measure','vw','','','.b-menu-open_from-left'),(992461,'deals','.b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_flex\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(992462,'deals','.b-trade-approval .steps-bar','width_measure','%','','','.b-trade-approval'),(992463,'deals','.b-trade-approval .col-right','width_measure','%','','','.b-trade-approval'),(992464,'deals','.b-trade-approval .col-left','width_measure','%','','','.b-trade-approval'),(992465,'deals','.b-trade-approval input[type=\'text\'], .b-trade-approval input[type=\'password\'], .b-trade-approval input[type=\'number\'], .b-trade-approval input[type=\'email\'], .b-trade-approval input[type=\'search\'], .b-trade-approval select','width_measure','%','','','.b-trade-approval'),(992466,'deals','.b-trade-approval .col-3','width_measure','%','','','.b-trade-approval'),(992467,'deals','.w-account-personal-catalog .list-switcher','width_measure','%','','','.w-account-personal-catalog'),(992468,'deals','.w-catalog-compare .cross-box .different-all > div','width_measure','%','','','.w-catalog-compare'),(992470,'deals','.lowestPricedBox .w-banner .single_banner','width_measure','%','','','.lowestPricedBox'),(992471,'deals','.b-products-listing .products-listing.list-productlisting .BlockBox.type-2 > .col:nth-child(1)','width_measure','%','','','.b-products-listing'),(992472,'deals','.b-products-listing .products-listing.list-productlisting .BlockBox.type-2 > .col:nth-child(2)','width_measure','%','','','.b-products-listing'),(992473,'deals','.shopByCollectionBox .w-banner .single_banner','width_measure','%','','','.shopByCollectionBox'),(992474,'deals','.w-product-sale-ends .left-count','width_measure','%','','','.w-product-sale-ends'),(992475,'deals','.w-product-sale-ends .left-text-left','width_measure','%','','','.w-product-sale-ends'),(992476,'deals','.w-product-sale-ends .left-text-right','width_measure','%','','','.w-product-sale-ends'),(992477,'deals','.w-product-buttons .notify-form input','width_measure','%','','','.w-product-buttons'),(992478,'deals','.w-product-bonus-points > div > div','width_measure','%','','','.w-product-bonus-points'),(992479,'deals','.w-files-catalog-widgets-files-catalog .item','width_measure','%','','','.w-files-catalog-widgets-files-catalog'),(992480,'deals','.w-files-catalog-widgets-files-catalog .item','width_measure','%','5644','','.w-files-catalog-widgets-files-catalog'),(992481,'deals','.w-files-catalog-widgets-files-catalog .item','width_measure','%','5639','','.w-files-catalog-widgets-files-catalog'),(992482,'deals','.w-files-catalog-widgets-files-catalog .item','width_measure','%','5630','','.w-files-catalog-widgets-files-catalog'),(992483,'deals','.w-cart-discount-coupon input[type=\"text\"]','width_measure','%','','','.w-cart-discount-coupon'),(992484,'deals','.w-cart-sub-total .price-row','width_measure','%','','','.w-cart-sub-total'),(992485,'deals','.w-cart-sub-total .price-row > div','width_measure','%','','','.w-cart-sub-total'),(992486,'deals','.w-cart-gift-certificate .gift-code input','width_measure','%','','','.w-cart-gift-certificate'),(992487,'deals','.w-cart-gift-certificate .input-apple','width_measure','%','','','.w-cart-gift-certificate'),(992488,'deals','.w-cart-gift-certificate .input-apple div','width_measure','%','','','.w-cart-gift-certificate'),(992489,'deals','.w-cart-order-reference .input-apple','width_measure','%','','','.w-cart-order-reference'),(992490,'deals','.w-cart-order-reference .input-apple div','width_measure','%','','','.w-cart-order-reference'),(992491,'deals','.w-cart-order-reference .input-apple div input','width_measure','%','','','.w-cart-order-reference'),(992492,'deals','.w-product-bundle .attributes-item','width_measure','%','','','.w-product-bundle'),(992493,'deals','.w-product-bundle .attributes-select','width_measure','%','','','.w-product-bundle'),(992494,'deals','.w-product-bundle .bundle_image','width_measure','%','','','.w-product-bundle'),(992495,'deals','.w-product-bundle .bundle_item','width_measure','%','','','.w-product-bundle'),(992496,'deals','.w-product-bundle .bundle_item','width_measure','%','5639','','.w-product-bundle'),(992497,'deals','.w-product-bundle .bundle_item','width_measure','%','5630','','.w-product-bundle'),(992498,'deals','.w-product-in-bundles .attributes-item','width_measure','%','','','.w-product-in-bundles'),(992499,'deals','.w-product-in-bundles .attributes-select','width_measure','%','','','.w-product-in-bundles'),(992500,'deals','.w-product-in-bundles .bundle_item','width_measure','%','5639','','.w-product-in-bundles'),(992501,'deals','.w-product-in-bundles .bundle_item','width_measure','%','5630','','.w-product-in-bundles'),(992502,'deals','.w-product-in-bundles .bundle_image','width_measure','%','','','.w-product-in-bundles'),(992503,'deals','.w-product-in-bundles .bundle_item','width_measure','%','','','.w-product-in-bundles'),(992504,'deals','.w-product-quantity-discounts .item','width_measure','%','','','.w-product-quantity-discounts'),(992505,'deals','.w-product-multi-inventory .select-box:nth-child(2n)','width_measure','%','','','.w-product-multi-inventory'),(992506,'deals','.w-product-multi-inventory .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-multi-inventory'),(992507,'deals','.p-sample-checkout-index .order-summary .heading-2','width_measure','%','3','','.p-sample-checkout-index'),(992508,'deals','.p-sample-checkout-index .order-summary .heading-2','width_measure','%','4','','.p-sample-checkout-index'),(992510,'deals','.w-product-multi-inventory .radio-attributes > label','width_measure','%','','','.w-product-multi-inventory'),(992511,'deals','.w-product-multi-inventory .radio-attributes .option-item','width_measure','%','','','.w-product-multi-inventory'),(992512,'deals','.w-product-multi-inventory .radio-attributes > label','width_measure','%','5644','','.w-product-multi-inventory'),(992513,'deals','.b-products-listing .BlockBox.type-7 > .col:nth-child(1)','width_measure','%','5644','','.b-products-listing'),(992514,'deals','.b-products-listing .BlockBox.type-7 > .col:nth-child(2)','width_measure','%','5644','','.b-products-listing'),(992515,'deals','.b-products-listing .products-listing .radio-attributes .option','width_measure','%','','','.b-products-listing'),(992516,'deals','.b-products-listing .products-listing .radio-attributes > label','width_measure','%','','','.b-products-listing'),(992517,'deals','.w-product-collection .chosen-products','width_measure','%','','','.w-product-collection'),(992518,'deals','.w-product-collection .current-product','width_measure','%','','','.w-product-collection'),(992519,'deals','.w-product-collection .right-area','width_measure','%','','','.w-product-collection'),(992520,'deals','.w-product-collection .select-box select','width_measure','%','','','.w-product-collection'),(992521,'deals','.w-product-collection .current-product, .w-product-collection .chosen-products','width_measure','%','5639','','.w-product-collection'),(992522,'deals','.w-product-collection .right-area','width_measure','%','5639','','.w-product-collection'),(992523,'deals','.w-product-attributes .radio-attributes .option-item','width_measure','%','','','.w-product-attributes'),(992524,'deals','.w-product-attributes .radio-attributes > label','width_measure','%','','','.w-product-attributes'),(992525,'deals','.w-product-attributes .select-box:nth-child(2n)','width_measure','%','','','.w-product-attributes'),(992526,'deals','.w-product-attributes .select-box:nth-child(2n+1)','width_measure','%','','','.w-product-attributes'),(992527,'deals','.w-product-attributes .radio-attributes > label','width_measure','%','5644','','.w-product-attributes'),(992528,'deals','.w-product-properties .properties-table','width_measure','%','','','.w-product-properties'),(992529,'deals','.w-product-properties .property-ul','width_measure','%','','','.w-product-properties'),(992530,'deals','.w-product-properties li','width_measure','%','','','.w-product-properties'),(992531,'deals','.w-product-groups .radioBox label','width_measure','%','5660','','.w-product-groups'),(992532,'deals','.w-product-custom-bundle .chosen-products','width_measure','%','','','.w-product-custom-bundle'),(992533,'deals','.w-product-custom-bundle .current-product','width_measure','%','','','.w-product-custom-bundle'),(992534,'deals','.w-product-custom-bundle .right-area','width_measure','%','','','.w-product-custom-bundle'),(992535,'deals','.w-product-custom-bundle .select-box select','width_measure','%','','','.w-product-custom-bundle'),(992536,'deals','.w-product-custom-bundle .chosen-products','width_measure','%','5639','','.w-product-custom-bundle'),(992537,'deals','.w-product-custom-bundle .right-area','width_measure','%','5639','','.w-product-custom-bundle'),(992538,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width_measure','%','','','.w-catalog-pages-category-pages-last-list'),(992539,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width_measure','%','5639','','.w-catalog-pages-category-pages-last-list'),(992540,'deals','.w-catalog-pages-category-pages-last-list .catalog-pages-listing-ul > li','width_measure','%','5630','','.w-catalog-pages-category-pages-last-list'),(992541,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width_measure','%','','','.w-catalog-pages-category-pages-last-list-block'),(992542,'deals','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-top-location-list'),(992543,'deals','.w-delivery-location-location-list .deliveryList li','width_measure','%','','','.w-delivery-location-location-list'),(992544,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width_measure','%','5639','','.w-catalog-pages-category-pages-last-list-block'),(992545,'deals','.w-catalog-pages-category-pages-last-list-block .catalog-pages-listing-ul > li','width_measure','%','5630','','.w-catalog-pages-category-pages-last-list-block'),(992546,'deals','.w-delivery-location-location-list .deliveryList li','width_measure','%','5639','','.w-delivery-location-location-list'),(992547,'deals','.w-delivery-location-location-list .deliveryList li','width_measure','%','5630','','.w-delivery-location-location-list'),(992548,'deals','.w-delivery-location-top-location-list .deliveryList li','width_measure','%','5630','','.w-delivery-location-top-location-list'),(992549,'deals','.w-delivery-location-featured-list .deliveryList > ul > li','width_measure','%','','','.w-delivery-location-featured-list'),(992550,'deals','.w-delivery-location-featured-list .deliveryList > ul > li','width_measure','%','5660','','.w-delivery-location-featured-list'),(992551,'deals','.w-sale-category .holder-1','width_measure','%','','','.w-sale-category'),(992552,'deals','.w-sale-category .holder-2','width_measure','%','','','.w-sale-category'),(992553,'deals','.w-sale-category .image','width_measure','%','','','.w-sale-category'),(992554,'deals','.w-sale-category .left-count','width_measure','%','','','.w-sale-category'),(992555,'deals','.w-sale-category .left-text-left','width_measure','%','','','.w-sale-category'),(992556,'deals','.w-sale-category .left-text-right','width_measure','%','','','.w-sale-category'),(992557,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width_measure','%','','','.w-catalog-pages-category-pages-last-list-by-catalog'),(992558,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width_measure','%','5630','','.w-catalog-pages-category-pages-last-list-by-catalog'),(992559,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width_measure','%','','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(992560,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width_measure','%','5630','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(992561,'deals','.w-catalog-pages-category-pages-last-list-by-catalog-block .catalog-pages-listing-ul li','width_measure','%','5639','','.w-catalog-pages-category-pages-last-list-by-catalog-block'),(992562,'deals','.w-catalog-pages-category-pages-last-list-by-catalog .catalog-pages-listing-ul li','width_measure','%','5639','','.w-catalog-pages-category-pages-last-list-by-catalog'),(992563,'deals','.w-delivery-location-list-by-page .item','width_measure','%','','','.w-delivery-location-list-by-page'),(992564,'deals','.w-delivery-location-list-by-page .item','width_measure','%','5639','','.w-delivery-location-list-by-page'),(992565,'deals','.w-delivery-location-list-by-page .item','width_measure','%','5660','','.w-delivery-location-list-by-page'),(992566,'deals','.w-product-properties-icons .hover-box-content','width_measure','%','','','.w-product-properties-icons'),(992567,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','width_measure','%','5660','','.w-product-properties-icons'),(992568,'deals','.w-delivery-location-cross-pages .item','width_measure','%','','','.w-delivery-location-cross-pages'),(992569,'deals','.w-delivery-location-cross-pages .item','width_measure','%','5639','','.w-delivery-location-cross-pages'),(992570,'deals','.w-delivery-location-cross-pages .item','width_measure','%','5660','','.w-delivery-location-cross-pages'),(992571,'deals','.w-delivery-location-product-categories .item.category-link','width_measure','%','','','.w-delivery-location-product-categories'),(992572,'deals','.w-delivery-location-product-categories .item.category-link','width_measure','%','5639','','.w-delivery-location-product-categories'),(992573,'deals','.w-delivery-location-product-categories .item.category-link','width_measure','%','5660','','.w-delivery-location-product-categories'),(992574,'deals','.w-delivery-location-product-categories .item.category-link','width_measure','%','5630','','.w-delivery-location-product-categories'),(992575,'deals','.w-catalog-delivery-locations .item','width_measure','%','','','.w-catalog-delivery-locations'),(992576,'deals','.w-catalog-delivery-locations .item','width_measure','%','5630','','.w-catalog-delivery-locations'),(992577,'deals','.w-product-bonus-points .bonus-points-cost','width_measure','%','','','.w-product-bonus-points'),(992578,'deals','.w-product-designer-designer .prodDesignerType','width_measure','%','','','.w-product-designer-designer'),(992579,'deals','.w-product-designer-designer .productDesignerBox input','width_measure','%','','','.w-product-designer-designer'),(992580,'deals','.w-press-reviews-widgets-press-reviews-small .link-to-press-review','width_measure','%','','','.w-press-reviews-widgets-press-reviews-small'),(992581,'deals','.w-press-reviews-widgets-press-reviews-small .small-press-review','width_measure','%','','','.w-press-reviews-widgets-press-reviews-small'),(992582,'deals','.w-support-system-listing .product_icon','width_measure','%','','','.w-support-system-listing'),(992583,'deals','.w-rma-returns-history input[type=\'text\'], .w-rma-returns-history input[type=\'password\'], .w-rma-returns-history input[type=\'number\'], .w-rma-returns-history input[type=\'email\'], .w-rma-returns-history input[type=\'search\'], .w-rma-returns-history select','width_measure','%','','','.w-rma-returns-history'),(992584,'deals','.b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_left\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(992585,'deals','.b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_center\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(992586,'deals','.b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > a, .b-menu-position .menu-style[data-position=\"horizontal_right\"] .menu-content > ul > li > .no-link','width_measure','%','','','.b-menu-position'),(992587,'deals','.w-product-configurator .pc_item select','width_measure','%','','','.w-product-configurator'),(992588,'deals','.w-product-configurator .item-content','width_measure','%','5639','','.w-product-configurator'),(992589,'deals','.w-product-configurator .pc_item','width_measure','%','5639','','.w-product-configurator'),(992590,'deals','.b-products-listing .products-listing .bonus-points-cost','width_measure','%','','','.b-products-listing'),(992591,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width_measure','%','','','.w-catalog-pages-category-pages-list'),(992592,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width_measure','%','5639','','.w-catalog-pages-category-pages-list'),(992593,'deals','.w-catalog-pages-category-pages-list .catalog-pages-listing-ul > li','width_measure','%','5630','','.w-catalog-pages-category-pages-list'),(992594,'deals','.w-predefined-promotion .nextdiscount .item-holder .image','width_measure','%','','','.w-predefined-promotion'),(992595,'deals','.w-predefined-promotion .nextdiscount .item-holder .name','width_measure','%','','','.w-predefined-promotion'),(992596,'deals','.w-predefined-promotion .prom-multi-discount .list','width_measure','%','','','.w-predefined-promotion'),(992597,'deals','.w-predefined-promotion .promo-cart-discount > div','width_measure','%','','','.w-predefined-promotion'),(992598,'deals','.w-predefined-promotion .promo-salemaker .item','width_measure','%','','','.w-predefined-promotion'),(992599,'deals','.w-predefined-promotion .promo-salemaker > div','width_measure','%','','','.w-predefined-promotion'),(992601,'deals','.w-subscribers .left_box','width_measure','%','','','.w-subscribers'),(992602,'deals','.w-subscribers .right_box','width_measure','%','','','.w-subscribers'),(992603,'deals','.w-subscribers .sb_tc','width_measure','%','','','.w-subscribers'),(992604,'deals','.filterLine .w-catalog-sorting','width_measure','%','','','.filterLine'),(992605,'deals','.filterLine .w-filters','width_measure','%','','','.filterLine'),(992606,'deals','.filterLine > .block','width_measure','%','','','.filterLine'),(992607,'deals','.w-product-buttons .btn, .w-product-buttons .btn-1, .w-product-buttons .btn-2, .w-product-buttons .btn-3','width_measure','%','','','.w-product-buttons'),(992608,'deals','.w-product-quantity-discounts .quantity-discounts-content .item','width_measure','%','','','.w-product-quantity-discounts'),(992609,'deals','.w-product-quantity-discounts .quantity-discounts-content .item > span','width_measure','%','','','.w-product-quantity-discounts'),(992610,'deals','.homeBanner .carousel .bottom-center > span','width_measure','%','','','.homeBanner'),(992611,'deals','.bannersWrap .box-block.type-12 > .block:nth-child(1)','width_measure','%','5630','','.bannersWrap'),(992612,'deals','.bannersWrap .box-block.type-12 > .block:nth-child(2)','width_measure','%','5630','','.bannersWrap'),(992613,'deals','.w-subscribers .left_box, .w-subscribers .right_box','width_measure','%','5630','','.w-subscribers'),(992614,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','width_measure','%','5639','','.w-filters'),(992615,'deals','.filterLine .w-filters','width_measure','%','5639','','.filterLine'),(992616,'deals','.filterLine .w-catalog-sorting','width_measure','%','5639','','.filterLine'),(992617,'deals','.w-filters .filter-widget-horizontal .filter-box-content','width_measure','%','5639','','.w-filters'),(992618,'deals','.filterLine .w-filters, .filterLine .w-catalog-sorting','width_measure','%','5660','','.filterLine'),(992619,'deals','.b-products-listing .products-listing.list-productlisting .attributes select','width_measure','%','','','.b-products-listing'),(992620,'deals','.b-products-listing .products-listing.list-productlisting .radio-attributes > label','width_measure','%','','','.b-products-listing'),(992622,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','width_measure','%','5630','','.headerWrap'),(992623,'deals','.w-account-personal-catalog .buy-box .btn, .w-account-personal-catalog .buy-box .btn-1','width_measure','%','','','.w-account-personal-catalog'),(992624,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li','width_measure','%','','','.preFooter'),(992625,'deals','.preFooter .menu-style[data-style=\"3\"] .level-1 > li','width_measure','%','5630','','.preFooter'),(992626,'deals','.w-product-wishlist-button .btn','width_measure','%','5630','','.w-product-wishlist-button'),(992627,'deals','.w-catalog-compare .cross-box','width_measure','%','','','.w-catalog-compare'),(992628,'deals','.homeBanner .banner-item .banner-text-holder','width_measure','%','','','.homeBanner'),(992629,'deals','.w-promotions-widgets-promotion-icons-desc .promo-icon','width_measure','%','','','.w-promotions-widgets-promotion-icons-desc'),(992630,'deals','.w-promotions-widgets-promotion-icons-desc .promos-info .promo-name','width_measure','%','','','.w-promotions-widgets-promotion-icons-desc'),(992631,'deals','.w-cart-shipping-estimator .left-area','width_measure','%','5630','','.w-cart-shipping-estimator'),(992632,'deals','.w-cart-shipping-estimator .right-area','width_measure','%','5630','','.w-cart-shipping-estimator'),(992633,'deals','.w-promotions-widgets-promotions .select-box','width_measure','%','','','.w-promotions-widgets-promotions'),(992646,'deals','.account-address-book .address_book_row .column, .account-address-book .topInfo > div','width_measure','%','','','.account-address-book'),(992647,'deals','.account-address-book .address_book_row .column','width_measure','%','5630','','.account-address-book'),(992648,'deals','.account-address-book .address_book_row .column + .column','width_measure','%','5630','','.account-address-book'),(992649,'deals','.account-address-book .topInfo > div','width_measure','%','5630','','.account-address-book'),(992650,'deals','.account-address-book .topInfo > div + div','width_measure','%','5630','','.account-address-book'),(992654,'deals','.account-order-pay .history_info > div','width_measure','%','','','.account-order-pay'),(992655,'deals','.account-order-pay .history_info > div','width_measure','%','5639','','.account-order-pay'),(992656,'deals','.account-samples .orders-table .td-alignright','width_measure','%','5639','','.account-samples'),(992657,'deals','.account-sample-info .history_info > div','width_measure','%','','','.account-sample-info'),(992658,'deals','.account-sample-info .history_info > div','width_measure','%','5639','','.account-sample-info'),(992659,'deals','.checkout-index-wrap .dob-hide > div','width_measure','%','','','.checkout-index-wrap'),(992660,'deals','.checkout-index-wrap .edit-address-popup .addresses .address-item','width_measure','%','','','.checkout-index-wrap'),(992661,'deals','.checkout-index-wrap .edit-address-popup .addresses .buttons','width_measure','%','','','.checkout-index-wrap'),(992662,'deals','.checkout-index-wrap .order-summary2 .btn-2','width_measure','%','','','.checkout-index-wrap'),(992663,'deals','.checkout-order-confirmation .order-summary2 .btn-2','width_measure','%','','','.checkout-order-confirmation'),(992664,'deals','.checkout-login-wrap .col-left, .checkout-login-wrap .col-right','width_measure','%','','','.checkout-login-wrap'),(992665,'deals','.checkout-login-wrap .middle-form .btn-2','width_measure','%','','','.checkout-login-wrap'),(992666,'deals','.b-form .password-row, .b-form .col-gender','width_measure','%','','','.b-form'),(992667,'deals','.b-form .center-buttons','width_measure','%','','','.b-form'),(992668,'deals','.hide-page','width_measure','%','','',''),(992670,'deals','.bannersWrap .leftBanner .banner-text','width_measure','%','','','.bannersWrap'),(992673,'deals','.footer-menu .level-2 > li','width_measure','%','5644','','.footer-menu'),(992674,'deals','.footer-menu .level-3 > li','width_measure','%','5639','','.footer-menu'),(992675,'deals','.w-account-customer-additional-field .field-type-checkbox label','width_measure','%','','','.w-account-customer-additional-field'),(992676,'deals','.w-account-customer-additional-field .field-type-text input, .w-account-customer-additional-field .field-type-text select','width_measure','%','','','.w-account-customer-additional-field'),(992677,'deals','.w-account-customer-additional-field .field-type-text label','width_measure','%','','','.w-account-customer-additional-field'),(992678,'deals','.w-banner .banner-text-holder','width_measure','%','','','.w-banner'),(992679,'deals','.w-banner .carousel-text','width_measure','%','','','.w-banner'),(992680,'deals','.w-banner .image-text-banner.middle-center .text-banner-1, .w-banner .image-text-banner.middle-center .text-banner-2','width_measure','%','','','.w-banner'),(992681,'deals','.w-banner .image-text-banner.top-center .text-banner, .w-banner .image-text-banner.middle-center .text-banner, .w-banner .image-text-banner.bottom-center .text-banner','width_measure','%','','','.w-banner'),(992686,'deals','.w-menu-slider > ul > li > ul','width_measure','%','','','.w-menu-slider'),(992687,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','width_measure_important','important','','','.b-menu-open_from-left'),(992688,'deals','.w-cart-discount-coupon input[type=\"text\"]','width_measure_important','important','','','.w-cart-discount-coupon'),(992689,'deals','.w-catalog-compare .cross-box','width_measure_important','important','','','.w-catalog-compare'),(992690,'deals','.footer-menu .level-2 > li','width_measure_important','important','5644','','.footer-menu'),(992691,'deals','.b-form .same-address','z-index','80','','','.b-form'),(992692,'deals','.b-switch .bootstrap-switch input[type=\'radio\'], .b-switch .bootstrap-switch input[type=\'checkbox\']','z-index','-1','','','.b-switch'),(992693,'deals','.b-fancybox .filter-listing-loader','z-index','100000','','','.b-fancybox'),(992694,'deals','.b-fancybox .filter-listing-preloader','z-index','100001','','','.b-fancybox'),(992695,'deals','.w-promotions .prom-multi-discount .promo-range','z-index','1','','','.w-promotions'),(992696,'deals','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(992699,'deals','.p-sample-checkout-success .page-success > div','z-index','1','','','.p-sample-checkout-success'),(992700,'deals','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(992701,'deals','.b-preloader .preloader','z-index','10','','','.b-preloader'),(992702,'deals','.b-messages .messMenuButton span','z-index','1','','','.b-messages'),(992703,'deals','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(992704,'deals','.b-fancybox #fancybox-loading','z-index','8060','','','.b-fancybox'),(992705,'deals','.b-fancybox .fancybox-wrap','z-index','8020','','','.b-fancybox'),(992706,'deals','.w-upload-customer-id-upload-customer-id-form .upload-file','z-index','10','','','.w-upload-customer-id-upload-customer-id-form'),(992707,'deals','.w-menu-horizontal > ul > li > ul > li > ul > li > ul','z-index','24','','','.w-menu-horizontal'),(992708,'deals','.w-menu-horizontal > ul > li > ul > li > ul > li > ul > li > ul','z-index','25','','','.w-menu-horizontal'),(992709,'deals','.w-menu-horizontal > ul > li > ul > li > ul','z-index','23','','','.w-menu-horizontal'),(992710,'deals','.w-quote .cart-box-link','z-index','1','','','.w-quote'),(992711,'deals','.b-switch .bootstrap-switch','z-index','0','','','.b-switch'),(992713,'deals','.b-info-popup .info-popup div','z-index','1000','','','.b-info-popup'),(992714,'deals','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(992715,'deals','.edit-link','z-index','1','','',''),(992716,'deals','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(992717,'deals','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(992718,'deals','.b-switch .candlestick-wrapper.candlestick-contents .candlestick-bg .candlestick-toggle','z-index','0','','','.b-switch'),(992719,'deals','.b-switch .bootstrap-switch .bootstrap-switch-label','z-index','100','','','.b-switch'),(992720,'deals','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(992721,'deals','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(992722,'deals','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(992723,'deals','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(992724,'deals','.b-fancybox .fancybox-overlay','z-index','8010','','','.b-fancybox'),(992725,'deals','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(992726,'deals','.w-menu-horizontal > ul','z-index','21','','','.w-menu-horizontal'),(992727,'deals','.b-switch .candlestick-wrapper .candlestick-bg .candlestick-toggle','z-index','1','','','.b-switch'),(992730,'deals','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(992731,'deals','.w-promotions .promo-cart-discount .slave .condition','z-index','1','','','.w-promotions'),(992732,'deals','.w-menu-horizontal > ul > li > ul','z-index','22','','','.w-menu-horizontal'),(992735,'deals','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(992736,'deals','.b-fancybox .fancybox-close','z-index','8040','','','.b-fancybox'),(992737,'deals','.b-fancybox .fancybox-opened','z-index','8030','','','.b-fancybox'),(992738,'deals','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(992739,'deals','.b-datepicker .datepicker-dropdown','z-index','1000','','','.b-datepicker'),(992740,'deals','.w-quote .cart-box','z-index','100','','','.w-quote'),(992741,'deals','.p-sample-checkout-success .page-success','z-index','-1','','','.p-sample-checkout-success'),(992742,'deals','.b-switch .bootstrap-switch .bootstrap-switch-handle-on, .b-switch .bootstrap-switch .bootstrap-switch-handle-off','z-index','1','','','.b-switch'),(992743,'deals','.b-select-suggest .select2-search','z-index','10000','','','.b-select-suggest'),(992744,'deals','.b-select-suggest .select2-drop-mask','z-index','9998','','','.b-select-suggest'),(992745,'deals','.b-select-suggest .select2-drop','z-index','9999','','','.b-select-suggest'),(992748,'deals','.w-menu-big li','z-index','20','','','.w-menu-big'),(992749,'deals','.b-bottom .pop-up-close','z-index','1','','','.b-bottom'),(992750,'deals','.w-catalog-b2b-add-button ','z-index','111','','','.w-catalog-b2b-add-button'),(992751,'deals','.b-products-listing .promos-info','z-index','1','','','.b-products-listing'),(992752,'deals','.b-autocomplete .ui-autocomplete','z-index','1000','','','.b-autocomplete'),(992754,'deals','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(992755,'deals','.b-form .form-inputs div.required-message','z-index','1','','','.b-form'),(992756,'deals','.b-fancybox .fancybox-title','z-index','8050','','','.b-fancybox'),(992757,'deals','.b-fancybox .fancybox-title-float-wrap','z-index','8050','','','.b-fancybox'),(992758,'deals','.p-quote-checkout-success .page-success > div','z-index','1','','','.p-quote-checkout-success'),(992759,'deals','.p-quote-checkout-success .page-success','z-index','-1','','','.p-quote-checkout-success'),(992760,'deals','.b-form .eye-password-wrap','z-index','1','','','.b-form'),(992761,'deals','.b-form .eye-password','z-index','1','','','.b-form'),(992762,'deals','.b-form .hide-billing-address','z-index','70','','','.b-form'),(992763,'deals','.b-dropdown .dropdown .dropdown-menu','z-index','200','','','.b-dropdown'),(992765,'deals','.b-fancybox .fancybox-nav span','z-index','8040','','','.b-fancybox'),(992766,'deals','.b-fancybox .fancybox-nav','z-index','8040','','','.b-fancybox'),(992768,'deals','.w-menu-big > ul > li > ul','z-index','100','','','.w-menu-big'),(992769,'deals','.w-image-maps .products-items .item, .w-image-maps .default-links .item, .w-image-maps .categories-items .item, .w-image-maps .float-items .item','z-index','1000','','','.w-image-maps'),(992770,'deals','.b-product-images .media-popup .mp-close','z-index','1','','','.b-product-images'),(992771,'deals','.b-product-images .mp-shadow, .b-product-images .media-popup','z-index','1000','','','.b-product-images'),(992772,'deals','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-1 > li:hover > ul','z-index','100','','','.b-menu-lev_vis'),(992773,'deals','.b-menu-lev_vis .menu-style[data-lev3_vis=\"over\"] .level-2 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(992774,'deals','.b-menu-lev_vis .menu-style[data-lev4_vis=\"over\"] .level-3 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(992775,'deals','.b-menu-lev_vis .menu-style[data-lev5_vis=\"over\"] .level-4 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(992776,'deals','.b-menu-lev_vis .menu-style[data-lev6_vis=\"over\"] .level-5 > li:hover > ul','z-index','1','','','.b-menu-lev_vis'),(992777,'deals','.b-menu-lev_vis .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(992778,'deals','.b-menu-lev_vis .menu-style[data-lev3_vis=\"click\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(992779,'deals','.b-menu-lev_vis .menu-style[data-lev4_vis=\"click\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(992780,'deals','.b-menu-lev_vis .menu-style[data-lev5_vis=\"click\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(992781,'deals','.b-menu-lev_vis .menu-style[data-lev6_vis=\"click\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis'),(992782,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(992783,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(992784,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(992785,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(992786,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li.vis-show > ul','z-index','1','','','.b-menu-lev_vis-click_icon'),(992787,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev3_vis=\"click_icon\"] .level-2 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(992788,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev2_vis=\"click_icon\"] .level-1 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(992789,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev4_vis=\"click_icon\"] .level-3 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(992790,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev5_vis=\"click_icon\"] .level-4 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(992791,'deals','.b-menu-lev_vis-click_icon .menu-style[data-lev6_vis=\"click_icon\"] .level-5 > li > .open-close-ico','z-index','1','','','.b-menu-lev_vis-click_icon'),(992792,'deals','.b-menu-open_from-left .menu-style[data-open_from=\"left\"] .menu-content','z-index','1000','','','.b-menu-open_from-left'),(992793,'deals','.b-slick button.slick-prev, .b-slick button.slick-next','z-index','1','','','.b-slick'),(992794,'deals','.w-compare ','z-index','100','','','.w-compare'),(992795,'deals','.w-sample .cart-box','z-index','100','','','.w-sample'),(992796,'deals','.w-sample .cart-box-link','z-index','1','','','.w-sample'),(992797,'deals','.w-product-properties-icons .hover-box:hover .hover-box-content','z-index','9','','','.w-product-properties-icons'),(992798,'deals','.w-product-designer-designer .productDesignerBox input','z-index','1','','','.w-product-designer-designer'),(992799,'deals','.w-predefined-promotion .prom-multi-discount .promo-range','z-index','1','','','.w-predefined-promotion'),(992800,'deals','.w-predefined-promotion .promo-cart-discount .slave .condition','z-index','1','','','.w-predefined-promotion'),(992802,'deals','.headerWrap .menu-style[data-lev2_vis=\"click\"] .level-1 > li.vis-show > ul','z-index','99','','','.headerWrap'),(992803,'deals','.filterLine .before','z-index','11','','','.filterLine'),(992804,'deals','.w-filters .filter-widget-horizontal .filter-box-content','z-index','9','','','.w-filters'),(992805,'deals','.filterLine .w-catalog-sorting .sort-select','z-index','12','','','.filterLine'),(992806,'deals','.w-filters .filter-widget-horizontal .content-filter-widget','z-index','2','5639','','.w-filters'),(992807,'deals','.filterLine .w-catalog-sorting','z-index','0','5660','','.filterLine'),(992808,'deals','.headerWrap .menu-style[data-style=\"3\"] .level-2 > li > a','z-index','10','5630','','.headerWrap'),(992809,'deals','.w-account-personal-catalog .list-row-action .copy, .w-account-personal-catalog .list-row-action .move','z-index','1','','','.w-account-personal-catalog'),(992810,'deals','.w-account-personal-catalog .list-row-action ul','z-index','1','','','.w-account-personal-catalog'),(992813,'deals','.b-menu-lev_vis .menu-style[data-lev2_vis=\"over\"] .level-2','z-index','100','','','.b-menu-lev_vis'),(992814,'deals','.checkout-success-wrap .page-success','z-index','-1','','','.checkout-success-wrap'),(992815,'deals','.checkout-success-wrap .page-success > div','z-index','1','','','.checkout-success-wrap'),(992816,'deals','.hide-page','z-index','100000','','',''),(992817,'deals','.success-page .page-success > div','z-index','1','','','.success-page'),(992818,'deals','.w-banner .banner img + img','z-index','-1','','','.w-banner'),(992819,'deals','.w-banner .banner-text','z-index','1','','','.w-banner'),(992822,'deals','.w-menu-slider > ul > li > ul','z-index','100','','','.w-menu-slider'),(992823,'splash','.main .main-width, .main .type-1 > .block','max-width','1250','','',''),(992824,'splash','.main .main-width, .main .type-1 > .block','margin','0 auto','','',''),(992825,'splash','.main .main-width, .main .type-1 > .block','max-width','1250','','',''),(992826,'splash','.main .main-width, .main .type-1 > .block','margin','0 auto','','',''),(992827,'splash','.mainbg > .block','max-width','1250','','','.mainbg'),(992828,'splash','.mainbg > .block','margin','0 auto','','','.mainbg'),(1447980,'watch','body','background_color','','','',''),(1447981,'watch','body','background_position','','','',''),(1447982,'watch','body','background_repeat','','','',''),(1447983,'watch','body','background_size','','','',''),(1457812,'furniture','.w-currencies ','position','relative','','','.w-currencies'),(1457813,'furniture','.w-currencies .currencies','background-color','$currencies-widget-bg-2','1','','.w-currencies'),(1457814,'furniture','.w-currencies .currencies','color','$currencies-widget-color-2','1','','.w-currencies'),(1457815,'furniture','.w-currencies .currencies','display','inline-block','','','.w-currencies'),(1457816,'furniture','.w-currencies .currencies','position','relative','','','.w-currencies'),(1457817,'furniture','.w-currencies .currencies','z-index','101','','','.w-currencies'),(1457818,'furniture','.w-currencies .currencies-title','background-color','$currencies-widget-bg-1','','','.w-currencies'),(1457819,'furniture','.w-currencies .currencies-title','border-bottom-color','$currencies-widget-border-1','','','.w-currencies'),(1457820,'furniture','.w-currencies .currencies-title','border-bottom-width','2','','','.w-currencies'),(1457821,'furniture','.w-currencies .currencies-title','border-left-color','$currencies-widget-border-1','','','.w-currencies'),(1457822,'furniture','.w-currencies .currencies-title','border-left-width','2','','','.w-currencies'),(1457823,'furniture','.w-currencies .currencies-title','border-right-color','$currencies-widget-border-1','','','.w-currencies'),(1457824,'furniture','.w-currencies .currencies-title','border-right-width','2','','','.w-currencies'),(1457825,'furniture','.w-currencies .currencies-title','border-top-color','$currencies-widget-border-1','','','.w-currencies'),(1457826,'furniture','.w-currencies .currencies-title','border-top-width','2','','','.w-currencies'),(1457827,'furniture','.w-currencies .currencies-title','color','$currencies-widget-color-1','','','.w-currencies'),(1457828,'furniture','.w-currencies .currencies-title','display','block','','','.w-currencies'),(1457829,'furniture','.w-currencies .currencies-title','font-weight','600','','','.w-currencies'),(1457830,'furniture','.w-currencies .currencies-title','line-height','15','','','.w-currencies'),(1457831,'furniture','.w-currencies .currencies-title','line_height_measure','px','','','.w-currencies'),(1457832,'furniture','.w-currencies .currencies-title','padding-bottom','2','','','.w-currencies'),(1457833,'furniture','.w-currencies .currencies-title','padding-left','10','','','.w-currencies'),(1457834,'furniture','.w-currencies .currencies-title','padding-right','10','','','.w-currencies'),(1457835,'furniture','.w-currencies .currencies-title','padding-top','5','','','.w-currencies'),(1457836,'furniture','.w-currencies .currencies:hover .select','display','block','','','.w-currencies'),(1457837,'furniture','.w-currencies .current','color','$currencies-icon-color-1','3','','.w-currencies'),(1457838,'furniture','.w-currencies .current','content','\\e902','3','','.w-currencies'),(1457839,'furniture','.w-currencies .current','font-family','trueloaded','3','','.w-currencies'),(1457840,'furniture','.w-currencies .current','font-size','26','3','','.w-currencies'),(1457841,'furniture','.w-currencies .current','line-height','1','3','','.w-currencies'),(1457842,'furniture','.w-currencies .current','min-height','31','','','.w-currencies'),(1457843,'furniture','.w-currencies .current','padding-bottom','4','','','.w-currencies'),(1457844,'furniture','.w-currencies .current','padding-left','10','','','.w-currencies'),(1457845,'furniture','.w-currencies .current','padding-right','27','','','.w-currencies'),(1457846,'furniture','.w-currencies .current','padding-top','4','','','.w-currencies'),(1457847,'furniture','.w-currencies .current','position','relative','','','.w-currencies'),(1457848,'furniture','.w-currencies .current','position','absolute','3','','.w-currencies'),(1457849,'furniture','.w-currencies .current','right','0','3','','.w-currencies'),(1457850,'furniture','.w-currencies .current','top','2','3','','.w-currencies'),(1457851,'furniture','.w-currencies .select','background-color','$currencies-select-bg-1','','','.w-currencies'),(1457852,'furniture','.w-currencies .select','border-bottom-color','$currencies-select-border-1','','','.w-currencies'),(1457853,'furniture','.w-currencies .select','border-bottom-width','1','','','.w-currencies'),(1457854,'furniture','.w-currencies .select','border-left-color','$currencies-select-border-1','','','.w-currencies'),(1457855,'furniture','.w-currencies .select','border-left-width','1','','','.w-currencies'),(1457856,'furniture','.w-currencies .select','border-right-color','$currencies-select-border-1','','','.w-currencies'),(1457857,'furniture','.w-currencies .select','border-right-width','1','','','.w-currencies'),(1457858,'furniture','.w-currencies .select','border-top-color','$currencies-select-border-1','','','.w-currencies'),(1457859,'furniture','.w-currencies .select','border-top-width','1','','','.w-currencies'),(1457860,'furniture','.w-currencies .select','color','$currencies-select-color-1','','','.w-currencies'),(1457861,'furniture','.w-currencies .select','display','none','','','.w-currencies'),(1457862,'furniture','.w-currencies .select','padding-bottom','20','','','.w-currencies'),(1457863,'furniture','.w-currencies .select','padding-left','30','','','.w-currencies'),(1457864,'furniture','.w-currencies .select','padding-right','30','','','.w-currencies'),(1457865,'furniture','.w-currencies .select','padding-top','20','','','.w-currencies'),(1457866,'furniture','.w-currencies .select','position','absolute','','','.w-currencies'),(1457867,'furniture','.w-currencies .select','right','0','','','.w-currencies'),(1457868,'furniture','.w-currencies .select','top','100','','','.w-currencies'),(1457869,'furniture','.w-currencies .select','top_measure','%','','','.w-currencies'),(1457870,'furniture','.w-currencies .select','z-index','10','','','.w-currencies'),(1457871,'furniture','.w-currencies .select-link','background-color','$currencies-select-bg-2','1','','.w-currencies'),(1457872,'furniture','.w-currencies .select-link','color','$currencies-select-color-2','1','','.w-currencies'),(1457873,'furniture','.w-currencies .select-link','display','flex','','','.w-currencies'),(1457874,'furniture','.w-currencies .select-link','padding-bottom','5','','','.w-currencies'),(1457875,'furniture','.w-currencies .select-link','padding-left','10','','','.w-currencies'),(1457876,'furniture','.w-currencies .select-link','padding-right','10','','','.w-currencies'),(1457877,'furniture','.w-currencies .select-link','padding-top','5','','','.w-currencies'),(1457878,'furniture','.w-currencies .select-link','text-decoration','none','1','','.w-currencies'),(1457879,'furniture','.w-currencies .select-link','white-space','nowrap','','','.w-currencies'),(1457880,'furniture','.w-currencies .select-link span','padding-bottom','0','','','.w-currencies'),(1457881,'furniture','.w-currencies .select-link span','padding-left','4','','','.w-currencies'),(1457882,'furniture','.w-currencies .select-link span','padding-right','4','','','.w-currencies'),(1457883,'furniture','.w-currencies .select-link span','padding-top','0','','','.w-currencies'),(1457884,'furniture','.w-languages .current','color','$languages-icon-color-1','3','','.w-languages'),(1457885,'furniture','.w-languages .current','content','\\e902','3','','.w-languages'),(1457886,'furniture','.w-languages .current','font-family','trueloaded','3','','.w-languages'),(1457887,'furniture','.w-languages .current','font-size','26','3','','.w-languages'),(1457888,'furniture','.w-languages .current','line-height','1','3','','.w-languages'),(1457889,'furniture','.w-languages .current','min-height','31','','','.w-languages'),(1457890,'furniture','.w-languages .current','padding-bottom','5','','','.w-languages'),(1457891,'furniture','.w-languages .current','padding-left','10','','','.w-languages'),(1457892,'furniture','.w-languages .current','padding-right','27','','','.w-languages'),(1457893,'furniture','.w-languages .current','padding-top','5','','','.w-languages'),(1457894,'furniture','.w-languages .current','position','relative','','','.w-languages'),(1457895,'furniture','.w-languages .current','position','absolute','3','','.w-languages'),(1457896,'furniture','.w-languages .current','right','0','3','','.w-languages'),(1457897,'furniture','.w-languages .current','top','1','3','','.w-languages'),(1457898,'furniture','.w-languages .image','width','40','','','.w-languages'),(1457899,'furniture','.w-languages .lang-link','background-color','$languages-select-bg-2','1','','.w-languages'),(1457900,'furniture','.w-languages .lang-link','color','$languages-select-color-2','1','','.w-languages'),(1457901,'furniture','.w-languages .lang-link','display','flex','','','.w-languages'),(1457902,'furniture','.w-languages .lang-link','padding-bottom','10','','','.w-languages'),(1457903,'furniture','.w-languages .lang-link','padding-left','20','','','.w-languages'),(1457904,'furniture','.w-languages .lang-link','padding-right','20','','','.w-languages'),(1457905,'furniture','.w-languages .lang-link','padding-top','10','','','.w-languages'),(1457906,'furniture','.w-languages .lang-link .image','width','50','','','.w-languages'),(1457907,'furniture','.w-languages .lang-link .image img','width','34','','','.w-languages'),(1457908,'furniture','.w-languages .languages','display','inline-block','','','.w-languages'),(1457909,'furniture','.w-languages .languages','position','relative','','','.w-languages'),(1457910,'furniture','.w-languages .languages:hover .current','background-color','$languages-widget-bg-2','','','.w-languages'),(1457911,'furniture','.w-languages .languages:hover .current','color','$languages-widget-color-2','','','.w-languages'),(1457912,'furniture','.w-languages .languages:hover .select','display','block','','','.w-languages'),(1457913,'furniture','.w-languages .select','background-color','$languages-select-bg-1','','','.w-languages'),(1457914,'furniture','.w-languages .select','border-bottom-color','$languages-select-border-1','','','.w-languages'),(1457915,'furniture','.w-languages .select','border-bottom-width','1','','','.w-languages'),(1457916,'furniture','.w-languages .select','border-left-color','$languages-select-border-1','','','.w-languages'),(1457917,'furniture','.w-languages .select','border-left-width','1','','','.w-languages'),(1457918,'furniture','.w-languages .select','border-right-color','$languages-select-border-1','','','.w-languages'),(1457919,'furniture','.w-languages .select','border-right-width','1','','','.w-languages'),(1457920,'furniture','.w-languages .select','border-top-color','$languages-select-border-1','','','.w-languages'),(1457921,'furniture','.w-languages .select','border-top-width','1','','','.w-languages'),(1457922,'furniture','.w-languages .select','color','$languages-select-color-1','','','.w-languages'),(1457923,'furniture','.w-languages .select','display','none','','','.w-languages'),(1457924,'furniture','.w-languages .select','padding-bottom','20','','','.w-languages'),(1457925,'furniture','.w-languages .select','padding-left','30','','','.w-languages'),(1457926,'furniture','.w-languages .select','padding-right','30','','','.w-languages'),(1457927,'furniture','.w-languages .select','padding-top','20','','','.w-languages'),(1457928,'furniture','.w-languages .select','position','absolute','','','.w-languages'),(1457929,'furniture','.w-languages .select','right','-1','','','.w-languages'),(1457930,'furniture','.w-languages .select','top','100','','','.w-languages'),(1457931,'furniture','.w-languages .select','top_measure','%','','','.w-languages'),(1457932,'furniture','.w-languages .select','z-index','110','','','.w-languages'),(1457933,'furniture','.w-languages a.lang-link','text-decoration','none','1','','.w-languages'),(1457934,'furniture','.header-middle ','padding-right','60','5140','','.header-middle'),(1457935,'furniture','.header-middle ','position','relative','','','.header-middle'),(1457936,'furniture','.header-middle .w-logo','align-items','center','5140','','.header-middle'),(1457937,'furniture','.header-middle .w-logo','display','flex','5140','','.header-middle'),(1457938,'furniture','.header-middle .w-logo','flex-grow','1','5140','','.header-middle'),(1457939,'furniture','.header-middle .w-logo','max-width','none','5140','','.header-middle'),(1457940,'furniture','.header-middle .w-logo','max-width_important','important','5140','','.header-middle'),(1457941,'furniture','.header-middle .w-logo','min-height','40','5140','','.header-middle'),(1457942,'furniture','.header-middle .w-logo img','max-height','40','5140','','.header-middle'),(1457943,'furniture','.header-middle > .block','align-items','center','','','.header-middle'),(1457944,'furniture','.header-middle > .block','display','flex','','','.header-middle'),(1457945,'furniture','.header-middle > .block','justify-content','space-between','','','.header-middle'),(1457946,'furniture','.w-search ','flex-grow','1','','','.w-search'),(1457947,'furniture','.w-search ','flex-grow','0','5140','','.w-search'),(1457948,'furniture','.w-search .background','background-color','$search-popup-shadow','','','.w-search'),(1457949,'furniture','.w-search .background','bottom','0','','','.w-search'),(1457950,'furniture','.w-search .background','display','none','','','.w-search'),(1457951,'furniture','.w-search .background','left','0','','','.w-search'),(1457952,'furniture','.w-search .background','position','fixed','','','.w-search'),(1457953,'furniture','.w-search .background','right','0','','','.w-search'),(1457954,'furniture','.w-search .background','top','0','','','.w-search'),(1457955,'furniture','.w-search .background','z-index','100','','','.w-search'),(1457956,'furniture','.w-search .background.show','display','block','','','.w-search'),(1457957,'furniture','.w-search .button-search','background-color','transparent','','','.w-search'),(1457958,'furniture','.w-search .button-search','border-bottom-width','0','','','.w-search'),(1457959,'furniture','.w-search .button-search','border-left-width','0','','','.w-search'),(1457960,'furniture','.w-search .button-search','border-right-width','0','','','.w-search'),(1457961,'furniture','.w-search .button-search','border-top-width','0','','','.w-search'),(1457962,'furniture','.w-search .button-search','color','$search-widget-color-2','3','','.w-search'),(1457963,'furniture','.w-search .button-search','content','\\e90a','3','','.w-search'),(1457964,'furniture','.w-search .button-search','font-family','trueloaded','3','','.w-search'),(1457965,'furniture','.w-search .button-search','font-size','23','3','','.w-search'),(1457966,'furniture','.w-search .button-search','height','30','','','.w-search'),(1457967,'furniture','.w-search .button-search','line-height','1.3','3','','.w-search'),(1457968,'furniture','.w-search .button-search','position','absolute','','','.w-search'),(1457969,'furniture','.w-search .button-search','right','5','','','.w-search'),(1457970,'furniture','.w-search .button-search','top','0','','','.w-search'),(1457971,'furniture','.w-search .button-search','width','30','','','.w-search'),(1457972,'furniture','.w-search .extra','content','\\f115','3','','.w-search'),(1457973,'furniture','.w-search .extra','font-family','fontAwesome','3','','.w-search'),(1457974,'furniture','.w-search .extra','font-size','12','','','.w-search'),(1457975,'furniture','.w-search .extra','font-size','16','3','','.w-search'),(1457976,'furniture','.w-search .extra','margin-right','10','3','','.w-search'),(1457977,'furniture','.w-search .image','align-items','center','','','.w-search'),(1457978,'furniture','.w-search .image','display','flex','','','.w-search'),(1457979,'furniture','.w-search .image','max-height','80','','','.w-search'),(1457980,'furniture','.w-search .image','max-width','40','','','.w-search'),(1457981,'furniture','.w-search .item','display','block','','','.w-search'),(1457982,'furniture','.w-search .item','overflow','hidden','','','.w-search'),(1457983,'furniture','.w-search .item + .item','border-top-width','1','','','.w-search'),(1457984,'furniture','.w-search .item a','color','$search-popup-color-2','1','','.w-search'),(1457985,'furniture','.w-search .item a','display','flex','','','.w-search'),(1457986,'furniture','.w-search .item a','text-decoration','none','1','','.w-search'),(1457987,'furniture','.w-search .item a','transition','0.1s','','','.w-search'),(1457988,'furniture','.w-search .items-title','display','block','','','.w-search'),(1457989,'furniture','.w-search .items-title','padding-bottom','5','','','.w-search'),(1457990,'furniture','.w-search .items-title','padding-left','0','','','.w-search'),(1457991,'furniture','.w-search .items-title','padding-right','0','','','.w-search'),(1457992,'furniture','.w-search .items-title','padding-top','10','','','.w-search'),(1457993,'furniture','.w-search .name','display','block','','','.w-search'),(1457994,'furniture','.w-search .name','font-size','12','','','.w-search'),(1457995,'furniture','.w-search .name','padding-bottom','5','','','.w-search'),(1457996,'furniture','.w-search .name','padding-left','10','','','.w-search'),(1457997,'furniture','.w-search .name','padding-right','0','','','.w-search'),(1457998,'furniture','.w-search .name','padding-top','5','','','.w-search'),(1457999,'furniture','.w-search .name','width','calc(100% - 40px)','','','.w-search'),(1458000,'furniture','.w-search .opened','background-color','$search-popup-bg-1','3','','.w-search'),(1458001,'furniture','.w-search .opened','bottom','0','3','','.w-search'),(1458002,'furniture','.w-search .opened','display','block','3','','.w-search'),(1458003,'furniture','.w-search .opened','left','0','3','','.w-search'),(1458004,'furniture','.w-search .opened','position','fixed','3','','.w-search'),(1458005,'furniture','.w-search .opened','right','0','3','','.w-search'),(1458006,'furniture','.w-search .opened','top','0','3','','.w-search'),(1458007,'furniture','.w-search .opened','z-index','2','3','','.w-search'),(1458008,'furniture','.w-search .products','background-color','$search-popup-bg-2','','','.w-search'),(1458009,'furniture','.w-search .products','display','block','','','.w-search'),(1458010,'furniture','.w-search .products','flex-grow','1','','','.w-search'),(1458011,'furniture','.w-search .products','order','2','','','.w-search'),(1458012,'furniture','.w-search .products','padding-bottom','25','','','.w-search'),(1458013,'furniture','.w-search .products','position','relative','','','.w-search'),(1458014,'furniture','.w-search .products','width','100','','','.w-search'),(1458015,'furniture','.w-search .products','width_measure','%','','','.w-search'),(1458016,'furniture','.w-search .products','z-index','2','','','.w-search'),(1458017,'furniture','.w-search .products .item','background-color','$search-popup-bg-2','','','.w-search'),(1458018,'furniture','.w-search .products .item','padding-left','20','','','.w-search'),(1458019,'furniture','.w-search .products .item','padding-right','20','','','.w-search'),(1458020,'furniture','.w-search .products .item a','border-bottom-color','$search-popup-border-2','','','.w-search'),(1458021,'furniture','.w-search .products .item a','border-bottom-width','1','','','.w-search'),(1458022,'furniture','.w-search .products .item a','padding-bottom','5','','','.w-search'),(1458023,'furniture','.w-search .products .item a','padding-left','0','','','.w-search'),(1458024,'furniture','.w-search .products .item a','padding-right','0','','','.w-search'),(1458025,'furniture','.w-search .products .item a','padding-top','5','','','.w-search'),(1458026,'furniture','.w-search .products .item:last-child a','border-bottom','none','','','.w-search'),(1458027,'furniture','.w-search .products .items-title','padding-left','20','','','.w-search'),(1458028,'furniture','.w-search .search','display','none','5140','','.w-search'),(1458029,'furniture','.w-search .search','position','relative','','','.w-search'),(1458030,'furniture','.w-search .search-ico','background-color','$search-icon-bg-1','','','.w-search'),(1458031,'furniture','.w-search .search-ico','border-bottom-left-radius','50','','','.w-search'),(1458032,'furniture','.w-search .search-ico','border-bottom-right-radius','50','','','.w-search'),(1458033,'furniture','.w-search .search-ico','border-top-left-radius','50','','','.w-search'),(1458034,'furniture','.w-search .search-ico','border-top-right-radius','50','','','.w-search'),(1458035,'furniture','.w-search .search-ico','border_radius_1_measure','%','','','.w-search'),(1458036,'furniture','.w-search .search-ico','border_radius_2_measure','%','','','.w-search'),(1458037,'furniture','.w-search .search-ico','border_radius_3_measure','%','','','.w-search'),(1458038,'furniture','.w-search .search-ico','border_radius_4_measure','%','','','.w-search'),(1458039,'furniture','.w-search .search-ico','color','$search-icon-color-1','','','.w-search'),(1458040,'furniture','.w-search .search-ico','content','\\e90a','','','.w-search'),(1458041,'furniture','.w-search .search-ico','content','\\f002','3','','.w-search'),(1458042,'furniture','.w-search .search-ico','cursor','pointer','','','.w-search'),(1458043,'furniture','.w-search .search-ico','display','none','','','.w-search'),(1458044,'furniture','.w-search .search-ico','display','block','5140','','.w-search'),(1458045,'furniture','.w-search .search-ico','font-family','$font-icons-2','','','.w-search'),(1458046,'furniture','.w-search .search-ico','font-family','$font-icons-1','3','','.w-search'),(1458047,'furniture','.w-search .search-ico','font-size','22','','','.w-search'),(1458048,'furniture','.w-search .search-ico','font-weight','normal','','','.w-search'),(1458049,'furniture','.w-search .search-ico','height','48','','','.w-search'),(1458050,'furniture','.w-search .search-ico','height','40','5140','','.w-search'),(1458051,'furniture','.w-search .search-ico','line-height','48','','','.w-search'),(1458052,'furniture','.w-search .search-ico','line-height','36','5140','','.w-search'),(1458053,'furniture','.w-search .search-ico','line_height_measure','px','','','.w-search'),(1458054,'furniture','.w-search .search-ico','line_height_measure','px','5140','','.w-search'),(1458055,'furniture','.w-search .search-ico','text-align','center','','','.w-search'),(1458056,'furniture','.w-search .search-ico','width','48','','','.w-search'),(1458057,'furniture','.w-search .search-ico','width','40','5140','','.w-search'),(1458058,'furniture','.w-search .search-input','background-color','$search-widget-bg-1','','','.w-search'),(1458059,'furniture','.w-search .search-input','border-bottom-color','$search-widget-border-1','','','.w-search'),(1458060,'furniture','.w-search .search-input','border-bottom-width','1','','','.w-search'),(1458061,'furniture','.w-search .search-input','border-left-color','$search-widget-border-1','','','.w-search'),(1458062,'furniture','.w-search .search-input','border-left-width','1','','','.w-search'),(1458063,'furniture','.w-search .search-input','border-right-color','$search-widget-border-1','','','.w-search'),(1458064,'furniture','.w-search .search-input','border-right-width','1','','','.w-search'),(1458065,'furniture','.w-search .search-input','border-top-color','$search-widget-border-1','','','.w-search'),(1458066,'furniture','.w-search .search-input','border-top-width','1','','','.w-search'),(1458067,'furniture','.w-search .search-input','font-size','14','','','.w-search'),(1458068,'furniture','.w-search .search-input','height','33','','','.w-search'),(1458069,'furniture','.w-search .search-input','margin-bottom','0','','','.w-search'),(1458070,'furniture','.w-search .search-input','margin-left','0','','','.w-search'),(1458071,'furniture','.w-search .search-input','margin-right','0','','','.w-search'),(1458072,'furniture','.w-search .search-input','margin-top','0','','','.w-search'),(1458073,'furniture','.w-search .search-input','padding-bottom','5','','','.w-search'),(1458074,'furniture','.w-search .search-input','padding-left','10','','','.w-search'),(1458075,'furniture','.w-search .search-input','padding-right','40','','','.w-search'),(1458076,'furniture','.w-search .search-input','padding-top','5','','','.w-search'),(1458077,'furniture','.w-search .search-input','width','100','','','.w-search'),(1458078,'furniture','.w-search .search-input','width_measure','%','','','.w-search'),(1458079,'furniture','.w-search .search.opened','background-color','$search-widget-border-1','5140','','.w-search'),(1458080,'furniture','.w-search .search.opened','display','block','5140','','.w-search'),(1458081,'furniture','.w-search .search.opened','left','0','5140','','.w-search'),(1458082,'furniture','.w-search .search.opened','padding-bottom','10','5140','','.w-search'),(1458083,'furniture','.w-search .search.opened','padding-left','20','5140','','.w-search'),(1458084,'furniture','.w-search .search.opened','padding-right','20','5140','','.w-search'),(1458085,'furniture','.w-search .search.opened','padding-top','10','5140','','.w-search'),(1458086,'furniture','.w-search .search.opened','position','absolute','5140','','.w-search'),(1458087,'furniture','.w-search .search.opened','top','100','5140','','.w-search'),(1458088,'furniture','.w-search .search.opened','top_measure','%','5140','','.w-search'),(1458089,'furniture','.w-search .search.opened','width','calc(100% + 60px)','5140','','.w-search'),(1458090,'furniture','.w-search .search.opened','z-index','1','5140','','.w-search'),(1458091,'furniture','.w-search .suggest','background-color','$search-popup-bg-1','','','.w-search'),(1458092,'furniture','.w-search .suggest','border-top-width','1','','','.w-search'),(1458093,'furniture','.w-search .suggest','box-shadow','0 5px 15px 5px rgba(0,0,0,.5)','','','.w-search'),(1458094,'furniture','.w-search .suggest','color','$search-popup-color-1','','','.w-search'),(1458095,'furniture','.w-search .suggest','display','flex','','','.w-search'),(1458096,'furniture','.w-search .suggest','left','0','','','.w-search'),(1458097,'furniture','.w-search .suggest','max-height','500','','','.w-search'),(1458098,'furniture','.w-search .suggest','min-width','600','','','.w-search'),(1458099,'furniture','.w-search .suggest','min-width','400','5140','','.w-search'),(1458100,'furniture','.w-search .suggest','overflow','auto','','','.w-search'),(1458101,'furniture','.w-search .suggest','padding-bottom','0','','','.w-search'),(1458102,'furniture','.w-search .suggest','padding-left','0','','','.w-search'),(1458103,'furniture','.w-search .suggest','padding-right','0','','','.w-search'),(1458104,'furniture','.w-search .suggest','padding-top','0','','','.w-search'),(1458105,'furniture','.w-search .suggest','position','absolute','','','.w-search'),(1458106,'furniture','.w-search .suggest','text-align','left','','','.w-search'),(1458107,'furniture','.w-search .suggest','top','100','','','.w-search'),(1458108,'furniture','.w-search .suggest','top_measure','%','','','.w-search'),(1458109,'furniture','.w-search .suggest','width','100','','','.w-search'),(1458110,'furniture','.w-search .suggest','width_measure','%','','','.w-search'),(1458111,'furniture','.w-search .suggest','z-index','500','','','.w-search'),(1458112,'furniture','.w-search .wrap','height','100','','','.w-search'),(1458113,'furniture','.w-search .wrap','height_measure','%','','','.w-search'),(1458114,'furniture','.w-search .wrap','order','1','','','.w-search'),(1458115,'furniture','.w-search .wrap','padding-bottom','25','','','.w-search'),(1458116,'furniture','.w-search .wrap','padding-left','20','','','.w-search'),(1458117,'furniture','.w-search .wrap','padding-right','10','','','.w-search'),(1458118,'furniture','.w-search .wrap','width','50','','','.w-search'),(1458119,'furniture','.w-search .wrap','width_measure','%','','','.w-search'),(1458120,'furniture','.w-search .wrap + .products','width','60','','','.w-search'),(1458121,'furniture','.w-search .wrap + .products','width_measure','%','','','.w-search'),(1458122,'furniture','.w-search .wrap .history .image','display','none','3','','.w-search'),(1458123,'furniture','.w-search .wrap .image','content','\\f115','3','','.w-search'),(1458124,'furniture','.w-search .wrap .image','font-family','fontAwesome','3','','.w-search'),(1458125,'furniture','.w-search .wrap .info-suggest .image','content','\\f219','3','','.w-search'),(1458126,'furniture','.w-search .wrap .info-suggest .image','font-family','fontAwesome','3','','.w-search'),(1458127,'furniture','.w-search .wrap .info-suggest .image','font-size','12','3','','.w-search'),(1458128,'furniture','.w-search form','position','relative','','','.w-search'),(1458129,'furniture','.w-search form','z-index','101','','','.w-search'),(1458130,'furniture','.w-cart .buttons','padding-bottom','15','','','.w-cart'),(1458131,'furniture','.w-cart .buttons','padding-left','15','','','.w-cart'),(1458132,'furniture','.w-cart .buttons','padding-right','15','','','.w-cart'),(1458133,'furniture','.w-cart .buttons','padding-top','15','','','.w-cart'),(1458134,'furniture','.w-cart .buttons .btn','font-size','14','','','.w-cart'),(1458135,'furniture','.w-cart .buttons .btn','padding-bottom','4','','','.w-cart'),(1458136,'furniture','.w-cart .buttons .btn','padding-left','15','','','.w-cart'),(1458137,'furniture','.w-cart .buttons .btn','padding-right','15','','','.w-cart'),(1458138,'furniture','.w-cart .buttons .btn','padding-top','5','','','.w-cart'),(1458139,'furniture','.w-cart .cart-box','position','relative','','','.w-cart'),(1458140,'furniture','.w-cart .cart-box','z-index','100','','','.w-cart'),(1458141,'furniture','.w-cart .cart-box-link','-ms-transform','rotate(45deg)','4','','.w-cart'),(1458142,'furniture','.w-cart .cart-box-link','-webkit-transform','rotate(45deg)','4','','.w-cart'),(1458143,'furniture','.w-cart .cart-box-link','align-items','center','','','.w-cart'),(1458144,'furniture','.w-cart .cart-box-link','background-color','$account-icon-bg-1','3','','.w-cart'),(1458145,'furniture','.w-cart .cart-box-link','border-bottom-color','$cart-widget-color-2','4','','.w-cart'),(1458146,'furniture','.w-cart .cart-box-link','border-bottom-left-radius','50','3','','.w-cart'),(1458147,'furniture','.w-cart .cart-box-link','border-bottom-right-radius','50','3','','.w-cart'),(1458148,'furniture','.w-cart .cart-box-link','border-bottom-width','1','4','','.w-cart'),(1458149,'furniture','.w-cart .cart-box-link','border-right-color','$cart-widget-color-2','4','','.w-cart'),(1458150,'furniture','.w-cart .cart-box-link','border-right-width','1','4','','.w-cart'),(1458151,'furniture','.w-cart .cart-box-link','border-top-left-radius','50','3','','.w-cart'),(1458152,'furniture','.w-cart .cart-box-link','border-top-right-radius','50','3','','.w-cart'),(1458153,'furniture','.w-cart .cart-box-link','border_radius_1_measure','%','3','','.w-cart'),(1458154,'furniture','.w-cart .cart-box-link','border_radius_2_measure','%','3','','.w-cart'),(1458155,'furniture','.w-cart .cart-box-link','border_radius_3_measure','%','3','','.w-cart'),(1458156,'furniture','.w-cart .cart-box-link','border_radius_4_measure','%','3','','.w-cart'),(1458157,'furniture','.w-cart .cart-box-link','color','$account-icon-color-1','3','','.w-cart'),(1458158,'furniture','.w-cart .cart-box-link','content','\\e90d','3','','.w-cart'),(1458159,'furniture','.w-cart .cart-box-link','content','\\_','4','','.w-cart'),(1458160,'furniture','.w-cart .cart-box-link','display','flex','','','.w-cart'),(1458161,'furniture','.w-cart .cart-box-link','display','inline-block','3','','.w-cart'),(1458162,'furniture','.w-cart .cart-box-link','display','inline-block','4','','.w-cart'),(1458163,'furniture','.w-cart .cart-box-link','display','none','5140,4','','.w-cart'),(1458164,'furniture','.w-cart .cart-box-link','font-family','trueloaded','3','','.w-cart'),(1458165,'furniture','.w-cart .cart-box-link','font-size','18','','','.w-cart'),(1458166,'furniture','.w-cart .cart-box-link','font-size','30','3','','.w-cart'),(1458167,'furniture','.w-cart .cart-box-link','font-size','22','5140','','.w-cart'),(1458168,'furniture','.w-cart .cart-box-link','font-size','22','5140,3','','.w-cart'),(1458169,'furniture','.w-cart .cart-box-link','font-weight','bold','','','.w-cart'),(1458170,'furniture','.w-cart .cart-box-link','font-weight','normal','3','','.w-cart'),(1458171,'furniture','.w-cart .cart-box-link','height','48','3','','.w-cart'),(1458172,'furniture','.w-cart .cart-box-link','height','10','4','','.w-cart'),(1458173,'furniture','.w-cart .cart-box-link','height','40','5140','','.w-cart'),(1458174,'furniture','.w-cart .cart-box-link','height','40','5140,3','','.w-cart'),(1458175,'furniture','.w-cart .cart-box-link','line-height','48','3','','.w-cart'),(1458176,'furniture','.w-cart .cart-box-link','line-height','40','5140','','.w-cart'),(1458177,'furniture','.w-cart .cart-box-link','line-height','40','5140,3','','.w-cart'),(1458178,'furniture','.w-cart .cart-box-link','line_height_measure','px','3','','.w-cart'),(1458179,'furniture','.w-cart .cart-box-link','line_height_measure','px','5140','','.w-cart'),(1458180,'furniture','.w-cart .cart-box-link','line_height_measure','px','5140,3','','.w-cart'),(1458181,'furniture','.w-cart .cart-box-link','margin-top','-5','4','','.w-cart'),(1458182,'furniture','.w-cart .cart-box-link','padding-bottom','0','','','.w-cart'),(1458183,'furniture','.w-cart .cart-box-link','padding-bottom','0','5140','','.w-cart'),(1458184,'furniture','.w-cart .cart-box-link','padding-bottom','0','5140,3','','.w-cart'),(1458185,'furniture','.w-cart .cart-box-link','padding-left','10','','','.w-cart'),(1458186,'furniture','.w-cart .cart-box-link','padding-left','0','5140','','.w-cart'),(1458187,'furniture','.w-cart .cart-box-link','padding-left','0','5140,3','','.w-cart'),(1458188,'furniture','.w-cart .cart-box-link','padding-right','10','','','.w-cart'),(1458189,'furniture','.w-cart .cart-box-link','padding-right','0','5140','','.w-cart'),(1458190,'furniture','.w-cart .cart-box-link','padding-right','0','5140,3','','.w-cart'),(1458191,'furniture','.w-cart .cart-box-link','padding-top','0','','','.w-cart'),(1458192,'furniture','.w-cart .cart-box-link','padding-top','0','5140','','.w-cart'),(1458193,'furniture','.w-cart .cart-box-link','padding-top','0','5140,3','','.w-cart'),(1458194,'furniture','.w-cart .cart-box-link','position','relative','','','.w-cart'),(1458195,'furniture','.w-cart .cart-box-link','rotate','45','4','','.w-cart'),(1458196,'furniture','.w-cart .cart-box-link','text-align','center','3','','.w-cart'),(1458197,'furniture','.w-cart .cart-box-link','width','48','3','','.w-cart'),(1458198,'furniture','.w-cart .cart-box-link','width','10','4','','.w-cart'),(1458199,'furniture','.w-cart .cart-box-link','width','40','5140','','.w-cart'),(1458200,'furniture','.w-cart .cart-box-link','width','40','5140,3','','.w-cart'),(1458201,'furniture','.w-cart .cart-box-link','z-index','1','','','.w-cart'),(1458202,'furniture','.w-cart .cart-box.hover-box .cart-content','display','none','','','.w-cart'),(1458203,'furniture','.w-cart .cart-box.hover-box .cart-content','position','absolute','','','.w-cart'),(1458204,'furniture','.w-cart .cart-box.hover-box .cart-content','width','410','','','.w-cart'),(1458205,'furniture','.w-cart .cart-box.hover-box:hover .cart-content','display','block','','','.w-cart'),(1458206,'furniture','.w-cart .cart-box.hover-box:hover .cart-content','display_important','important','','','.w-cart'),(1458207,'furniture','.w-cart .cart-content','background-color','$cart-popup-bg-1','','','.w-cart'),(1458208,'furniture','.w-cart .cart-content','border-bottom-color','$cart-popup-border-1','','','.w-cart'),(1458209,'furniture','.w-cart .cart-content','border-bottom-width','1','','','.w-cart'),(1458210,'furniture','.w-cart .cart-content','border-left-color','$cart-popup-border-1','','','.w-cart'),(1458211,'furniture','.w-cart .cart-content','border-left-width','1','','','.w-cart'),(1458212,'furniture','.w-cart .cart-content','border-right-color','$cart-popup-border-1','','','.w-cart'),(1458213,'furniture','.w-cart .cart-content','border-right-width','1','','','.w-cart'),(1458214,'furniture','.w-cart .cart-content','border-top-color','$cart-popup-border-1','','','.w-cart'),(1458215,'furniture','.w-cart .cart-content','border-top-width','1','','','.w-cart'),(1458216,'furniture','.w-cart .cart-content','color','#141412','','','.w-cart'),(1458217,'furniture','.w-cart .cart-content','padding-bottom','5','','','.w-cart'),(1458218,'furniture','.w-cart .cart-content','padding-left','15','','','.w-cart'),(1458219,'furniture','.w-cart .cart-content','padding-right','15','','','.w-cart'),(1458220,'furniture','.w-cart .cart-content','padding-top','15','','','.w-cart'),(1458221,'furniture','.w-cart .cart-total','border-bottom-color','$cart-popup-border-1','','','.w-cart'),(1458222,'furniture','.w-cart .cart-total','border-bottom-width','1','','','.w-cart'),(1458223,'furniture','.w-cart .cart-total','font-size','1.2','','','.w-cart'),(1458224,'furniture','.w-cart .cart-total','font-weight','600','','','.w-cart'),(1458225,'furniture','.w-cart .cart-total','font_size_measure','em','','','.w-cart'),(1458226,'furniture','.w-cart .cart-total','padding